// Copyright (c) 2009 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
//
// Created by postproc-shortwords 1.8 on 2009-08-26 16:42:07
// From input file /export/hda3/cld/text_2008_quads_plus_sort.utf8
// See compact_lang_det.cc for usage
//
#include "encodings/compact_lang_det/cldutil.h"

// Included:
//      af-Latn ar-Arab be-Cyrl bg-Cyrl bs-Latn ca-Latn cs-Latn cy-Latn da-Latn
// de-Latn el-Grek en-Latn es-Latn et-Latn fa-Arab fi-Latn fr-Latn ga-Latn
// hi-Deva hr-Latn hu-Latn id-Latn is-Latn is-Latn it-Latn iw-Hebr ja-Hani
// ko-Hani lt-Latn lv-Latn mk-Cyrl ms-Latn nl-Latn no-Latn pl-Latn pt-Latn
// ro-Latn ru-Cyrl sh-Cyrl sh-Latn sk-Latn sl-Latn sr-Cyrl sv-Latn sw-Latn
// th-Thai tl-Latn tr-Latn uk-Cyrl vi-Latn xxx-Latn yi-Hebr zh-Hani zh-TW

// Remapped:
//      xxx-Latn=>ut-Latn sh-Latn=>hr-Latn sh-Cyrl=>sr-Cyrl

// ms/id probabilities leveled

static const int kQuadTableBuildDate = 20090826;    // yyyymmdd

COMPILE_ASSERT(MONTENEGRIN == 160, k_montenegrin_changed);
COMPILE_ASSERT(EXT_NUM_LANGUAGES == 209, k_ext_num_languages_changed);

// Nil-grams: 18 languages
//     GREEK MALAYALAM TELUGU TAMIL GUJARATI THAI KANNADA PUNJABI
//     GEORGIAN SINHALESE ARMENIAN LAOTHIAN KHMER DHIVEHI CHEROKEE
//     SYRIAC ORIYA INUKTITUT

// Uni-grams: 6 languages
//     Japanese Korean Chinese VIETNAMESE ChineseT ZHUANG

// Words/Quads/Gibberish: 47 languages in range ENGLISH..AFRIKAANS:
//     ENGLISH DANISH DUTCH FINNISH FRENCH GERMAN HEBREW ITALIAN
//     NORWEGIAN POLISH PORTUGUESE RUSSIAN SPANISH SWEDISH CZECH
//     ICELANDIC LATVIAN LITHUANIAN ROMANIAN HUNGARIAN ESTONIAN
//     Ignore BULGARIAN CROATIAN SERBIAN IRISH TAGALOG TURKISH
//     UKRAINIAN HINDI MACEDONIAN INDONESIAN LATIN MALAY WELSH
//     BELARUSIAN ARABIC CATALAN SWAHILI SLOVENIAN MARATHI VIETNAMESE
//     SLOVAK PERSIAN NORWEGIAN_N YIDDISH AFRIKAANS

//  ENGLISH 6041
//  DANISH 2009
//  DUTCH 2291
//  FINNISH 5068
//  FRENCH 3532
//  GERMAN 4895
//  HEBREW 28055
//  ITALIAN 1534
//  NORWEGIAN 2098
//  POLISH 8303
//  PORTUGUESE 2348
//  RUSSIAN 6301
//  SPANISH 2055
//  SWEDISH 3256
//  CZECH 6990
//  ICELANDIC 5154
//  LATVIAN 5706
//  LITHUANIAN 4856
//  ROMANIAN 3611
//  HUNGARIAN 8204
//  ESTONIAN 5248
//  Ignore 42
//  BULGARIAN 5834
//  CROATIAN 4082
//  SERBIAN 6161
//  IRISH 3822
//  TAGALOG 1816
//  TURKISH 6112
//  UKRAINIAN 9725
//  HINDI 14453
//  MACEDONIAN 4401
//  INDONESIAN 2100
//  LATIN 2
//  MALAY 2026
//  WELSH 5143
//  BELARUSIAN 11926
//  ARABIC 23951
//  CATALAN 1989
//  SWAHILI 2597
//  SLOVENIAN 2813
//  MARATHI 318
//  VIETNAMESE 3944
//  SLOVAK 4357
//  PERSIAN 13411
//  NORWEGIAN_N 422
//  YIDDISH 7557
//  AFRIKAANS 2010


static const int kQuadTableSize = 65536;    // Bucket count
static const int kQuadTableKeyMask = 0xffff0000;    // Mask hash key

// 521808 possible entries:
// 257317 filled (49%), 1252 merged (0%), 263239 dropped (50%)
static const cld::IndirectProbBucket4 kQuadTable[kQuadTableSize] = {
  // key[4], words[4] in UTF-8
  // value[4]
  { {0xcb670001,0x7fe90002,0xbddb0003,0x69260004}},	// [000] шате_, _حروف_, rtèr, имаа
  { {0x20070005,0xbddb0006,0x7bc40007,0xfe9b0008}},	//   _kuni_, stèr, sniu, _סיימ
  { {0x5d3b0008,0x65630009,0xad1b000a,0x52e2000b}},	//   _בתיא, denh, _שוטר, _पर्स
  { {0x63bb000c,0x07a6000d,0x2007000e,0xf989000f}},	//   jiun, јадн, _muni_, ור_
  { {0xa7730010,0x20070011,0x65630012,0x63a90013}},	//   ўліч, _luni_, fenh, dhen
  { {0xef1f0014,0x94760015,0x24510016,0x64430017}},	//   tjük_, لدعا, _bơm_, funi
  { {0x28160018,0x64430019,0x24510016,0x63a9001a}},	//   _خوزس, guni, _cơm_, fhen
  { {0xef1f0014,0x63bb001b,0xdb0d001c,0x63a9001d}},	//   rjük_, giun, riaç, ghen
  { {0x3667001e,0x6d47001a,0x6563001f,0x32060003}},	//   _като_, ygja, benh, _quoy_
  { {0x63a90020,0xc5690021,0x3f730016,0x20070022}},	//   ahen, _محمل_, _ệu_, _buni_
  { {0x2b9c0023,0x75280024,0x3ff9000d,0x75d30015}},	//   _tích_, _iedz, лноќ_, _بيلا
  { {0x63bb0011,0x63a90025,0x749b000a,0xe3b20015}},	//   ciun, chen, _שיאפ, _برئ_
  { {0x69c50026,0x69dc0027,0x6fdd0003,0x6f1d0028}},	//   ynhe, _okre, xécu, rbsc
  { {0x71730029,0x92b7000a,0x7528002a,0x50b7002b}},	//   _وهنا, _דפדף_, _jedz, ادید_
  { {0x7528002c,0x212c002d,0x6d47002e,0xd0100015}},	//   _medz, madh_, rgja, _علة_
  { {0x212c002f,0x6d47002e,0x3fb40015,0x78700030}},	//   ladh_, sgja, _وإيس, zóvá
  { {0xafb80031,0x6b8d0032,0x9bc40033,0x6e240034}},	// [010] _خطوط_, rjag, цёрк, _gwib
  { {0x212c002f,0x63bb0011,0x64430035,0x7ac40036}},	//   nadh_, ziun, yuni, істе
  { {0x65630037,0x63a90038,0x27ed0039,0x6aad0030}},	//   venh, yhen, _phen_, szaf
  { {0x63bb0011,0x212c002d,0xa8040033,0x69dc003a}},	//   xiun, hadh_, ізіл, _ekre
  { {0xd6ab003b,0x63a9003c,0x9878003d,0x7528002a}},	//   خدام_, vhen, kšķa_, _bedz
  { {0x27ed003e,0x26df003f,0xb9950015,0x98170040}},	//   _when_, _vyuo_, _الآب, _نبرا
  { {0x27ed0041,0x63bb0042,0xf5560029,0x63a90043}},	//   _then_, tiun, صليب_, then
  { {0x7e6d0044,0xdce50045,0x69dc0046,0x67d40047}},	//   _osap, _zahă, _zkre, _досу
  { {0x67290048,0x212c002d,0x63a90049,0x1306004a}},	//   _ieej, fadh_, rhen, щный_
  { {0x212c002f,0x02020010,0x24750024,0xdb09002e}},	//   gadh_, язьн, _tām_, _ánæg
  { {0xddc4004b,0xc50c004c,0x63a9004d,0x5f06004e}},	//   _priž, _סלאָ, phen, йзна
  { {0xedb2000b,0x23740015,0xf456004f,0xd808004f}},	//   ुच्छ, _وانح, _ליער_, יִשָ
  { {0x66010050,0x7e6d0014,0x20000051,0x67ea0052}},	//   _kilk, _csap, _viii_, nýja
  { {0x212c002f,0xb2760053,0xd5f90053,0x41290054}},	//   cadh_, _לענג_, רפֿר, _соко_
  { {0x5cb70010,0x10150002,0xfce60055,0x66010056}},	//   блёў_, _ابتد, сово, _milk
  { {0xee3f0057,0x260a000b,0x28bd000b,0x7b9a002b}},	//   brý_, ादमी_, ्पनि, دپرس_
  { {0x6d41002d,0x8f1b000a,0x68e30012,0xba290058}},	// [020] ólac, _גופת, ündn, لسلم_
  { {0x0ae90029,0x44250059,0x31a9005a,0x6601005b}},	//   شرقي_, _owl_, _fúze_, _nilk
  { {0x75280048,0x7995005c,0x4d7b0053,0x31ba004c}},	//   _redz, _dozw, _ערטע, נזענ
  { {0xbb86003b,0xa3e7005d,0xf62a005e,0xccf3000a}},	//   _الحي, _मील_, гіки_, _מכת_
  { {0x6594005f,0x96330033,0x65a6001a,0xd765002b}},	//   жалу, зніц, _aðha, زنوی
  { {0x291e002e,0x69dc0060,0xdb16002e,0x5e57004c}},	//   _ýta_, _ukre, ábær, מינע_
  { {0xb8960029,0xe6440061,0x44250034,0x212c0062}},	//   _الزع, ğlığ, _cwl_, vadh_
  { {0x53980063,0xe6440064,0xdb0d002e,0x289b000a}},	//   рвия_, şlığ, nnað, _גילא
  { {0x212c002d,0xb355002b,0x70b20065,0x66010066}},	//   tadh_, تینا_, ुप्ल, _filk
  { {0xdbde0045,0x316a0054,0xf617000a,0x21b4005e}},	//   nţân, ушио_, _לחמש_, ійня
  { {0x212c002f,0x89db000a,0x74130067,0xdb0d001a}},	//   radh_, רחיי, _فولا, knað
  { {0x212c002f,0x7bc80068,0xee3f0069,0x0000006a}},	//   sadh_, édul, trý_,
  { {0x27fc002c,0x212c002d,0xa3c5000b,0x6ea8006b}},	//   ívny_, padh_, उचर_, бърг_
  { {0xe56e0010,0x98b80064,0xf237000a,0x8167006b}},	//   дзi_, _ları_, _פרוץ_, _гръб_
  { {0x79950050,0x71bb0008,0xdb0d002e,0x63b90026}},	//   _rozw, _תצוג, fnað, _ymwn
  { {0xdb0d001a,0x2d8c006c,0x80370015,0x0000006a}},	//   gnað, öder_, _اسوأ_,
  { {0x79950050,0x7e6d0035,0xedd50015,0xa9070015}},	// [030] _pozw, _usap, _ويبد, مبان
  { {0x67290020,0x5a34006d,0xddeb006e,0x67ea006f}},	//   _seej, янут, _حربه_, výja
  { {0xe7190070,0x515b000a,0x6d88000a,0xfd56000a}},	//   ليات_, רכבו, _הָרְ, _ושתי_
  { {0xe00b005d,0x66010071,0x6d5a0072,0xddc40073}},	//   _संसद_, _silk, õtav, _isiš
  { {0xd2460074,0x66010075,0xcdd5000a,0xf7480015}},	//   _تن_, _pilk, ֗ךְ_, إلهي_
  { {0xa2cc000b,0x44150076,0x75ed0077,0xd0060058}},	//   _तख़्, офит, dúzc, _يل_
  { {0x66010078,0x2d910079,0x67290072,0x0000006a}},	//   _vilk, ijze_, _teej,
  { {0xe3b10031,0x1309007a,0xe4560033,0x36d5007b}},	//   برت_, шний_, іжы_, _добр
  { {0x6609007c,0x6601007d,0x6790002b,0x0000006a}},	//   _uuek, _tilk, _سیوط,
  { {0x11d60029,0x8698007e,0x98b8007f,0x0000006a}},	//   يوية_, _укус_, _zarı_,
  { {0x98b80064,0xfbd9000b,0xe2a8002b,0x0000006a}},	//   _yarı_, भकाम, لاین_,
  { {0x14d60053,0x22590080,0x9f06002b,0x33f40058}},	//   _וועל_, _виды_, توحو, _فسنس
  { {0xc8e6000b,0xddc40081,0x0000006a,0x0000006a}},	//   _कर्म_, _asiš,   ,
  { {0x8024002b,0xa0a50082,0x867a000a,0xa1560054}},	//   _کروم, _малд, ברשו, _даљу_
  { {0x3b960083,0x8fe6003b,0xdb0d0084,0x68e30012}},	//   ојат, _وأعم, tnað, ündl
  { {0xc052000a,0x2fd70015,0xfbd10015,0x7ff6006e}},	//   _חזה_, _ووود_, ّتْ_, _بستا
  { {0xda660029,0x891a0015,0xdb0d001a,0x7c290085}},	// [040] غاري, لغاز_, rnað, ćera
  { {0x2b580086,0x98b80061,0x61340046,0x9992006f}},	//   _گیرد_, _sarı_, mýlí, kryť_
  { {0xd90d0086,0xc8ca0087,0x9f420046,0xd70a0088}},	//   ایف_, جوان_, elké_, анее_
  { {0xddcd0089,0xe8e00016,0xa6e6008a,0x47d30058}},	//   _vrať, hiệu_, ожел, ويلر
  { {0x3ce80065,0x0000006a,0x0000006a,0x0000006a}},	//   ज़ेरे_,   ,   ,
  { {0x7aeb0012,0x45b7008b,0xdb21008c,0x95f40065}},	//   ügte, огію_, ätöv, इगेट_
  { {0x07a6008d,0x53460033,0x0000006a,0x0000006a}},	//   _давн, охпа,   ,
  { {0xd3260036,0x68b7000a,0xbc1b000a,0xd3d70015}},	//   цьки, _וללא_, בוקש, يبيا_
  { {0xdcfe0048,0x3266005e,0x6722008e,0x6e36005a}},	//   _kopē, ітив, mboj, _nvyb
  { {0xd257008f,0xa697000a,0x27e60090,0x67220091}},	//   іцы_, _וכמה_, llon_, lboj
  { {0xdb060014,0x26100092,0xc0ca0001,0xb97b0008}},	//   _elké, _hào_, рупе_, בניי
  { {0x28bd000b,0xc2760015,0x75ed0093,0x27e60094}},	//   ्पति, _وُضع, púzc, nlon_
  { {0xa2d60074,0xd250003b,0x5f940063,0x20180095}},	//   _بيشت, _أنت_, фият, ūri_
  { {0x98a3003d,0xdcfe003d,0x158a000a,0x27e60096}},	//   _lejā_, _nopē, ׁנָֽ, hlon_
  { {0x26100092,0x2ca50097,0xac190098,0x4c95005e}},	//   _lào_, áld_, собу_, чивс
  { {0x68e3007c,0x7b880099,0xda150054,0x7dc9006f}},	//   ündm, ољуб_, здањ, oľsk
  { {0x26100023,0x27e60026,0xdc3c003d,0x61fd0046}},	// [050] _nào_, dlon_, kšķe, ůsle
  { {0xceb20053,0x27e60003,0x19b80015,0x828b000a}},	//   _ניי_, elon_, يطلة_, יְבֶ
  { {0x9783002b,0xfeb8009a,0x984b009b,0x0000006a}},	//   ویسه, _هایت_, ряза_,
  { {0xdc880008,0x26100092,0x201e0007,0xf093000a}},	//   _וְשָ, _bào_, ipti_, ונע_
  { {0xff7c0053,0x6b7a0008,0x79a7009c,0x4e1e000b}},	//   יטאמ, _פרשנ, _дрве, _बढ़ाई_
  { {0x8afa009d,0x5a34009e,0xbafa0008,0x9964009f}},	//   _להרי, _інст, _להרש, _отсл
  { {0x96bb005d,0xf992000a,0xd5120015,0x27e600a0}},	//   _शेरॉ, _ארם_, رِيد, blon_
  { {0xf7730021,0x0000006a,0x0000006a,0x0000006a}},	//   _غاز_,   ,   ,
  { {0xf6770086,0x82350015,0x76420003,0x261000a1}},	//   _بازخ, أربا, croy, _gào_
  { {0xd6c60086,0x14190029,0x20d50033,0x1996004f}},	//   _عملی, _هيئة_, зімс, ִ֣יר_
  { {0x3cdb000b,0xe8e00016,0x77f5004f,0x0000006a}},	//   _खुले_, riệu_, ּמָד_,
  { {0x940400a2,0x6d41002e,0xc4d2000a,0xb4c7000b}},	//   _قوله, ólan, _אגב_, ईपी_
  { {0xd5c80092,0xdb0d007c,0x7052002b,0x261000a1}},	//   iền_, nnaõ, ونیا, _xào_
  { {0xdd920074,0x98ab005d,0x427a00a3,0x67e3007c}},	//   روز_, चनाए, _לאנג, mõju
  { {0xc0e20036,0xa0a500a4,0x67220091,0xdce7002a}},	//   _пошк, _хайд, yboj, odję
  { {0x5f760086,0xeef60033,0x70b6000a,0xf0b6000a}},	//   _رابر, _няпэ, _מהצד_, _מלצר_
  { {0x4a460010,0x0b430010,0xfe720015,0xeb9700a5}},	// [060] янав, энтн, _أدب_, чит_
  { {0xfa490029,0xdebb000a,0xbed7000a,0x26100016}},	//   تشفى_, _למפל, _מופז_, _rào_
  { {0xd884002b,0xca29000a,0xbb860015,0x98dd0033}},	//   بهای, רם_, _فلدي, асцi
  { {0x2d9a003e,0x403a004c,0xd6c4002b,0x27e600a6}},	//   _hope_, מגעג, ومای, ulon_
  { {0x67220048,0xa6130036,0x0d96000a,0xd6a90021}},	//   rboj, еміч, ּכֶם_, يدهم_
  { {0x261000a7,0x63ab0020,0x6d5c00a8,0x201e008c}},	//   _vào_, _algn, nfra, ypti_
  { {0x661b008c,0x6d5c00a9,0x6d4e00aa,0x291800ab}},	//   _etuk, ifra, igba, _ifra_
  { {0x34370029,0xa857000f,0x883b000a,0x764200ac}},	//   أسود_, _מילה_, _לתלו, proy
  { {0x41e60010,0x6d5c00ad,0x644300ae,0xd62700af}},	//   зіна, kfra, arni, _ноте_
  { {0x56370053,0x4a9b0053,0x361b000a,0x6d4e0079}},	//   _מאמע_, צייג, _לומד, jgba
  { {0xf9930008,0x30a30063,0x14c80086,0xe8df0092}},	//   תרת_, еряв, _بهای_, _trục_
  { {0xd36f00b0,0x201e0007,0x69de00b1,0x926a0054}},	//   _مهم_, rpti_, hope, _грка_
  { {0xe3b300b2,0x82330015,0xc7b3000a,0x644a00b3}},	//   _אױף_, _كروا, תבר_, lufi
  { {0x72eb00b4,0xdb0d0003,0x12fb000a,0x2d9a00b5}},	//   _פֿאַ, phaë, _ההדב, _cope_
  { {0xd5c80023,0x515b0008,0x415b000a,0xc1780091}},	//   yền_, _הכוו, _הדוג, mdė_
  { {0x6d4e00b6,0x6d5c002e,0xc1780091,0x69de00b7}},	//   agba, afra, ldė_, eope
  { {0x6d5c00b8,0x4a550033,0xd5dc000b,0x5f740067}},	// [070] bfra, ькас, मकाज, _ساير
  { {0x5c0700b9,0xc1780007,0x7ae600ba,0x69de00bb}},	//   _няма, ndė_, _dykt, gope
  { {0x3ea60048,0x8d5a000a,0xdd16002b,0x661c00bc}},	//   _ļoti_, _וכתי, _توپخ, _črka
  { {0x644300bd,0xa714005e,0xdc36004c,0xc017000a}},	//   vrni, емці, _קארט_, פקדו_
  { {0x4b7a000a,0xa5090004,0xb5fd003d,0xc1780091}},	//   _וארו, оела_, _apša, kdė_
  { {0xf6500086,0xf6d4002b,0x7bdf00be,0xddd600bf}},	//   طئه_, رزند, loqu, _kryš
  { {0x645800c0,0x05740021,0x644300c1,0x33f500c2}},	//   gtvi, عاهد, urni, мчис
  { {0x8235002b,0xe3b100c3,0xdc8c000a,0x7bcd00c4}},	//   ورخا, ضرب_, מְחָ, nnau
  { {0x6d5c0026,0x645800c5,0x28bd000b,0xd24e0021}},	//   yfra, atvi, ्पवि, لني_
  { {0x81f60029,0xd059005e,0xeeeb0016,0x7bcd00c6}},	//   وفير_, ормі_, ýờng_, hnau
  { {0xc9480008,0xc1050015,0x2d9a00c7,0x7bcd0091}},	//   הֲרֹ, بودي, _rope_, knau
  { {0xd24e0086,0xe2910086,0x201800c8,0x0000006a}},	//   دنی_, _لذت_, íria_,
  { {0x2d9a003e,0x69de003f,0xc1780091,0x76590034}},	//   _pope_, yope, bdė_, ntwy
  { {0x42fa000a,0xdce5006f,0x90c500c9,0x12fa000a}},	//   _והנס, _dohľ, _обле, _והנב
  { {0x6d5c00ca,0xed570063,0x70b20015,0x7e7d00cb}},	//   rfra, ьор_, _لموض, avsp
  { {0x8ffa0086,0x6c070029,0x5ea60029,0x5e460015}},	//   _برتر_, ِيِّ_, _يمثل, _قَبْ
  { {0x69de00cc,0x8f8b000a,0xcbc50015,0x2fd70015}},	// [080] tope, _וְיֵ, رزفي, _تويد_
  { {0x7bcd00cd,0x7ae60091,0xee3700ce,0x4c6a00cf}},	//   anau, _vykt, _юнь_, _дион_
  { {0x8b2600d0,0x69de00d1,0xd8390033,0xdce5006f}},	//   _одне, rope, зэі_, _zohľ
  { {0x46ea00d2,0xfaa60033,0x86c60067,0x3207002a}},	//   оден_, _жамо, ويان, _liny_
  { {0x69de00d3,0xd6170058,0xe67700d4,0x0000006a}},	//   pope, وتوا_, _aţâţ,
  { {0x644a00d5,0x645800d6,0x5ee9004f,0xaac50058}},	//   tufi, ttvi, הַצְ, _ستُن
  { {0xd90d0086,0x84380029,0x645800cb,0x799c0034}},	//   _ایم_, أكبر_, utvi, _iorw
  { {0xc27400d7,0xb8d2000b,0x7469005e,0x02a600d8}},	//   елиј, टन_, ярів_, дром
  { {0x6aa400d9,0x026a005e,0xd7570015,0x870b000a}},	//   nyif, іший_, _تلقت_, _וּבֶ
  { {0xb5aa0029,0xc1780091,0x680c0061,0x569b000a}},	//   _بارك_, udė_, _eşde, _וימצ
  { {0xc1780007,0x61e800da,0x799c00db,0xa1b70015}},	//   rdė_, rldl, _morw, بطيء_
  { {0xdce5002c,0xd5c80016,0x73360015,0xdfd10067}},	//   _pohľ, iềm_, _آرائ, ايح_
  { {0x69cb00dc,0x799c00dd,0x7bdf00de,0xc3fb000a}},	//   égek, _oorw, voqu, _ולאש
  { {0x290700df,0x6c1b0015,0x6282007c,0x799c00e0}},	//   žnai_, قترح_, _iroo, _norw
  { {0x7bcd0007,0x7bdf00e1,0xd13900e2,0x3a2b00e3}},	//   tnau, toqu, _ххі_, _swcp_
  { {0x628200e4,0x442c0034,0x26ee000b,0xc8d90065}},	//   _kroo, _mwd_, _जरूर_, _बुगट
  { {0x2aab0036,0x8ff80086,0xa3d6005d,0xdee700e5}},	// [090] цтво_, _ترور_, _सदन_, _تأثي
  { {0xf99300e6,0xdb0d0003,0x799c00e7,0x9a36005e}},	//   خبر_, chaî, _corw, вiти_
  { {0x200900e8,0x1dd80015,0x7bdf00e9,0xddcd0091}},	//   _kiai_, _تبيع_, poqu, _kraž
  { {0xa6350036,0xacfa000a,0x3b270015,0x9989006f}},	//   енді, _מהתכ, _تعدّ, dsať_
  { {0x799c00ea,0xcfb8000a,0x68e7002a,0x2bb6000a}},	//   _forw, ולאי_, _wyjd, _נפשך_
  { {0xba430007,0xc58b0080,0x799c0026,0xc86700eb}},	//   žįst, ющее_, _gorw, _отби
  { {0x645c0020,0xc01c0092,0x76590026,0x98140015}},	//   _äril, rước_, stwy, _لبقا
  { {0x58050029,0x6f0d00ec,0xf3f10015,0x628200ed}},	//   _أورك, _ngac, دأت_, _broo
  { {0xc6740015,0x628200ee,0x6b9d00ef,0x85b90099}},	//   _لطلب, _croo, _mosg, _елас_
  { {0x69c50084,0x7c3a00f0,0xe5c400f1,0x95d8004a}},	//   nihe, štri, _исхо, _ждут_
  { {0x69c500f2,0xf99200f3,0x3cf9000b,0x60e900f4}},	//   iihe, ארי_, ंधों_, ямом_
  { {0x43840015,0x3207002a,0x04c80015,0x547a000a}},	//   _للمق, _winy_, _تومي_, _מטעו
  { {0xee3700f5,0x628200f6,0x3207003e,0x69c5008c}},	//   ння_, _groo, _tiny_, kihe
  { {0x63a900f7,0x0000006a,0x0000006a,0x0000006a}},	//   lken,   ,   ,
  { {0x61d60008,0xe3c90016,0x20090030,0x69c50034}},	//   _אוסף_, hằm_, _fiai_, dihe
  { {0xebe30036,0x20090092,0xddcd0007,0x61e1008c}},	//   госп, _giai_, _graž, loll
  { {0x799c00f8,0x661c00bd,0x7bc4007c,0x6b630033}},	// [0a0] _porw, _črko, riiu, ыкта
  { {0xf2d200b2,0x61e100f9,0x63a900fa,0x0000006a}},	//   װעב_, noll, hken,
  { {0x7c960029,0x799c00b8,0x9f7a000a,0x6ab6002a}},	//   _أشخا, _vorw, ּנְח, szyf
  { {0xf4f30036,0x69c500f2,0x1bba00e5,0x8c1b000a}},	//   _якiй_, aihe, _راجع_, _מוטי
  { {0x63a900fb,0x99800007,0xe7b3002b,0x7d110046}},	//   dken, usių_, دمند, řesň
  { {0xcb0a002b,0x63a900fc,0xc6f700fd,0x61e100fe}},	//   _ويگن_, eken, хніх_, joll
  { {0x61e100f2,0xb1980092,0x186700ff,0x443a0030}},	//   doll, _nhưỡ, _пари_, ép_
  { {0x62820100,0x645c007c,0x61e1008c,0x63a90101}},	//   _proo, _ärim, eoll, gken
  { {0x81c6006b,0x61e10102,0x6d410052,0x66080103}},	//   ещне, foll, ólak, _tidk
  { {0x7abb0008,0xf6090015,0xc223002b,0x26890015}},	//   פציו, _قتله_, اکنو, _تخفي_
  { {0x69cb00dc,0x79b70053,0xddcd0104,0x316c003d}},	//   égei, גליד_, _praž, redz_
  { {0xd4690029,0xd3790036,0x657a0105,0x62820106}},	//   _تحكم_, _очі_, _hath, _troo
  { {0x71a6008f,0xddcd0107,0x657a0108,0x61e10109}},	//   _падз, _vraž, _kath, boll
  { {0xd12f0074,0x40940029,0x61e1010a,0x01640015}},	//   _همه_, _للتر, coll, _شُعَ
  { {0xddcd010b,0xfbd3002b,0x657a010c,0x6b9d010d}},	//   _traž, هتر_, _math, _posg
  { {0x657a010e,0xddcd005a,0x0000006a,0x0000006a}},	//   _lath, _uraž,   ,
  { {0x3df5010f,0xef640063,0xb955006b,0x657a00da}},	// [0b0] _изис, _също, кващ, _oath
  { {0xdb0d002d,0xc4b0000b,0x3eb30061,0xd9440054}},	//   mhaí, जनाओ, ıntı_, леђи
  { {0xf84b0010,0xd64d0033,0x71d7000a,0xda080021}},	//   ячай_, _вiле, עובד_, ريمه_
  { {0x2eab000a,0x07a4005e,0xdc88000a,0x0000006a}},	//   ּשַּ, лаєн, _נְתָ,
  { {0x8b9a0008,0xf6530029,0x64c9000b,0xcb36000a}},	//   _חברת, ائص_, िप्श, _בארי_
  { {0x65940036,0x657a0110,0xb6a2004a,0xd5e5006b}},	//   лачу, _cath, ришл, ъжли
  { {0x69d50111,0x657a0112,0xad1c000a,0x61e10113}},	//   _ijze, _dath, לוגר, voll
  { {0x68e300b8,0xc1780007,0x657a002d,0xe4c80015}},	//   ündu, klės_, _eath, عبون_
  { {0x657a0114,0x853c0007,0x7d0800dc,0xd5fb0016}},	//   _fath, _plėt, _kérü, _trù
  { {0x36040029,0x92640115,0x657a0116,0x61e1008c}},	//   _موقف, اديم, _gath, uoll
  { {0xddcd002a,0x9f420046,0x63a900aa,0xc1780091}},	//   _draż, elká_, pken, elės_
  { {0x61e100f2,0x43740117,0x0000006a,0x0000006a}},	//   soll, _бушт,   ,
  { {0x7dc60015,0xc73a000a,0x63a60118,0x61e10119}},	//   نتسك, ותרת, ökne, poll
  { {0x6145011a,0xddcd002a,0xdd920015,0x67f8005a}},	//   _река, _graż, جوس_, míje
  { {0xb0240023,0xfce6011b,0x84ac000a,0x1fb6011c}},	//   _trườ, тово, ִימִ, _аспр
  { {0x1e86011d,0x8e4a0058,0x5ed60058,0xbb43011e}},	//   _алим, _قلبك_, _لتخز, иеск
  { {0xc332011f,0x7f7700f3,0xdcfe003d,0x49ba0015}},	// [0c0] יון_, _יעקב_, _kopī, وائد_
  { {0xa96a0015,0xadfa0015,0xe9d70120,0x2d950121}},	//   ظمام_, _تربط_, вку_, _брюс
  { {0xde890086,0xdd050011,0x657a0122,0x6d8b000a}},	//   _قضیه_, ăsăt, _rath, _חָכְ
  { {0xe3b80064,0x62840007,0x7bda0003,0xb09a004c}},	//   _atın_, _šiom, étud, ויער
  { {0x66730015,0xfecd000a,0x0af60033,0x657a010c}},	//   لدور, ּמוּ, _шчоў, _path
  { {0x7c3a002c,0x645c0020,0xa2d5000b,0xe4e6005e}},	//   štru, _ärik, _बख़्, кійн
  { {0xd4670001,0x397b000a,0xe5a30054,0x629d0123}},	//   вије_, _קטלנ, рији, äson
  { {0x07a30124,0xe76a0015,0x853c0091,0xdb040125}},	//   _касн, _تحسن_, _plės, dhiú
  { {0xa66500e5,0x657a0126,0xe284009a,0x0000006a}},	//   _مطلو, _tath, اطبی,
  { {0x601e0048,0x657a002f,0x90980004,0xd5fb0016}},	//   _līme, _uath, евот_, _trú
  { {0x9f350127,0x8937000a,0xdb040030,0x8f350128}},	//   лені, כריע_, ghiú, ленц
  { {0xdb0d002f,0xddcd005c,0x67f80046,0x1fa70129}},	//   thaí, _wraż, bíje, трог
  { {0xf773000a,0x7c22006f,0xd345002b,0xecdb000b}},	//   בקר_, _čora, _صفوی, _मुजफ
  { {0xdcf50024,0xc237000a,0x3134012a,0x0000006a}},	//   edzā, _ירדו_, _секр,
  { {0xa3d6000b,0x3ead0046,0xc1780091,0x9d18012b}},	//   _सदा_, šet_, slės_, тост_
  { {0x644a002d,0x6bd40015,0x7d080030,0xc1780091}},	//   irfi, لتقر, _sérü, plės_
  { {0x62840007,0xdd910029,0xba550015,0x8ae7005e}},	// [0d0] _šioj, _هوة_, طناع, тівл
  { {0x23b1002c,0x9935012c,0xa907002b,0x3ea40123}},	//   _mája_, افات, نبان, ämte_
  { {0x98140029,0x2907012d,0xadd6000a,0x09070033}},	//   لبنا, äna_, _תותח_, тчам
  { {0xc864012e,0x8c1a000a,0x4735012f,0x0000006a}},	//   ртфи, _רורי, ундс,
  { {0x644a0130,0x7bda0003,0x9f440003,0x75ed0030}},	//   erfi, étue, ômé_, lúzi
  { {0x27310023,0x601e0024,0x6d550131,0xf483002b}},	//   ạn_, _zīme, ngza, لاعی
  { {0x87db0086,0xe8940080,0x2c37000a,0x19580132}},	//   _قبرس_, _карь, דָ֖ם_, _шары_
  { {0xb8f7000b,0xe3e9002b,0x29070091,0x58d40133}},	//   ाप_, رکان_, žnas_, _тост
  { {0x443e0134,0x3878005c,0x11e5006b,0x68fa001a}},	//   _evt_, _zsrr_, лжим, _útdr
  { {0xc5b9000a,0x67f8006f,0xdb040125,0x05770015}},	//   _אֶ֣ר, ríje, thiú, _جارد
  { {0xcea90135,0x8fa60136,0xf992000a,0x9fca0137}},	//   _צי_, гане, צרט_, егна_
  { {0xa8a8000a,0x99de0138,0x261900a1,0x0000006a}},	//   דֹשִ, бiла_, _kèo_,
  { {0xe1ee0139,0x2bc6000b,0xe7f6000b,0xc7d6004f}},	//   _гг_, रोफा, ेषता_, רורי_
  { {0x26190016,0xd00e002b,0x2bc60065,0x0000006a}},	//   _mèo_, _کلي_, रोना,
  { {0x225f00dc,0xec160018,0x90e4002b,0x26190016}},	//   ltuk_, اورد, _پسون, _lèo_
  { {0xc052013a,0x8b08005a,0x7538013b,0x0000006a}},	//   _הזה_, jpří, zavz,
  { {0xdd040064,0x225f013c,0x5b350033,0x6fb30015}},	// [0e0] ırıs, ntuk_, рэсу, _دميا
  { {0x6e240064,0x5ebb00a3,0x8b080046,0x62840091}},	//   _itib, _נזיק, epří, _šiok
  { {0x601e0048,0x3136004c,0xad1b000a,0xddc6002a}},	//   _tīme, רנעם_, _רוטר, pukł
  { {0x645c0020,0xbddb0003,0x07e50033,0x48130033}},	//   _ärii, quèr, ацім, ёміс
  { {0x47330036,0x7f3b000a,0x225f0030,0xe5c6013d}},	//   сніс, תענו, jtuk_, лско
  { {0x28160086,0x225f00dc,0x4edb0053,0x8b080089}},	//   _موسس, dtuk_, ײַדנ, apří
  { {0xf8780008,0xb4660015,0x3545008b,0xa96700ce}},	//   _בְּל, ادته, рхів, _щира_
  { {0x5c37004c,0x722a013e,0x9f42013f,0x7f440140}},	//   ארקן_, нцов_, boké_, _ndiq
  { {0x85560031,0xd2140054,0x27e60141,0x0000006a}},	//   _مخاط, јмоћ, moon_,
  { {0x104a0142,0x27e60143,0x98a7002a,0x9a420016}},	//   нями_, loon_, źną_, _đẳn
  { {0x2a600020,0x6e24003f,0x2508002b,0x645e0144}},	//   htib_, _atib, _شرطی_, àpid
  { {0x27e60145,0x41b4002b,0x2366013b,0x0000006a}},	//   noon_, امگر, _uboj_,
  { {0xf1940146,0x63a20147,0xf1f7002b,0x62340148}},	//   _виль, _ioon, ضعیت_, _телу
  { {0x63a20020,0x3cb50010,0x27e60149,0x2002002a}},	//   _hoon, айгр, hoon_, amki_
  { {0x63a20020,0x27e6014a,0x14d8004f,0x0000006a}},	//   _koon, koon_, דַּמ,
  { {0x63a20020,0x764b0026,0x3013006b,0x27e6014b}},	//   _joon, yrgy, _удър, joon_
  { {0x63a2014c,0x1a5b0015,0xc987014d,0xdb240030}},	// [0f0] _moon, عشرة_, лужи, árár
  { {0x7e6d00b6,0x2bc6014e,0x60d30024,0x2618000b}},	//   _ipap, रोबा, ņemš, _पढ़ी_
  { {0x6d45003f,0x225f014f,0x27e60150,0xe8590151}},	//   _idha, ztuk_, foon_, таеш_
  { {0xbddb0152,0xd5b60001,0xd5c80092,0x63a20035}},	//   ssèd, cикл, iều_, _noon
  { {0xbb3a009d,0x69cb00dc,0xe6c7002b,0x959500ce}},	//   _בערי, éges, دتاي, ишкі
  { {0xd5bb0010,0xce38000a,0x75ed0030,0x94750015}},	//   эсе_, נאות_, húzv, لدبا
  { {0x05760015,0x63a20153,0x9f420154,0xd5380058}},	//   شمية_, _boon, soké_, اثها_
  { {0x225f00dc,0xdb040030,0xc2450155,0x86570015}},	//   ttuk_, lkiá, аник, _مخطئ
  { {0x6d450156,0xc7b2000a,0xa3d60157,0x63a20158}},	//   _odha, _ובן_, _सदर_, _doon
  { {0xf4850086,0x6d45003f,0xd2680015,0x1306004a}},	//   _پائی, _ndha, اصين_, шный_
  { {0x229a00df,0x40490063,0x225f0159,0x7e6d015a}},	//   ešką_, ъпно_, stuk_, _apap
  { {0x225f00dc,0xa856000a,0xc49a015b,0x6d45015c}},	//   ptuk_, סירה_, _בשעת, _adha
  { {0x7c25015d,0x69c70085,0x0000006a,0x0000006a}},	//   _athr, _omje,   ,
  { {0xb2ba000a,0x63a2015e,0x291f0061,0x82d6000a}},	//   _שמסר, _zoon, _şuan_, _דונג_
  { {0x41740074,0x30790053,0x40790053,0x2d840089}},	//   _دانس, _יאַנ, _יאַװ, ěme_
  { {0x4b260010,0x63a2015f,0x69c70160,0x2a600072}},	//   рмав, _xoon, _amje, ttib_
  { {0x9a250029,0xfd1200a2,0x2a360033,0xba23006b}},	// [100] معلن, _وجد_, рэбр, ждук
  { {0x1e3b013a,0x64410089,0x27e60161,0x96df0033}},	//   _שגיא, _ovli, woon_, _лiку_
  { {0xa3e5005d,0xb607003d,0xe73a0162,0x27e60163}},	//   पका_, _mašī, вее_, toon_
  { {0xd8230036,0x78a300f2,0xd62a0164,0xc6a60165}},	//   ідчи, änva, воде_, ирли
  { {0x27e60166,0x6d41002e,0xfc480046,0x64410167}},	//   roon_, ðlag, říč_, _avli
  { {0x36190010,0xa4f8002b,0x224d007c,0xef1f0061}},	//   уццю_, هکار_, drek_, zcü_
  { {0xb7960001,0x94230054,0x27e60168,0x224d0169}},	//   _краћ, омје, poon_, erek_
  { {0x987b015b,0x67f8006f,0x3266016a,0xdb0d0072}},	//   _באלט, bíja, атов, aiaõ
  { {0xfbb70008,0xe57a0001,0xf6690002,0x64410061}},	//   יפקת_, _иза_, _محله_, _evli
  { {0x2bc6005d,0x63a2016b,0x865b000a,0xdce7002a}},	//   रोता, _woon, _בדמי, leją
  { {0x09f70008,0x3d1d000b,0x55bb000a,0xd0100015}},	//   שמים_, _मलबे_, _שמבו, ثلج_
  { {0x3f80001c,0xc477000a,0x9f530061,0x224d016c}},	//   _caiu_, _כתבו_, _ödül_, brek_
  { {0x539b0008,0xef1f0061,0x6253016d,0x0000006a}},	//   _שידו, rcü_, ržoá,
  { {0xdb0d016e,0x3ea40123,0xc534000a,0x38610034}},	//   lhaç, ämta_, מָֽה_, ythr_
  { {0xab950124,0x51fb0008,0xd138005c,0x81fb000a}},	//   бављ, _שהוצ, ając_, _שהוז
  { {0x69c7016f,0xbf350063,0x5b150170,0x309b000a}},	//   _smje, _унищ, смат, _ישומ
  { {0x2bc6000b,0x3377000a,0x6d41001a,0xa9270058}},	// [110] रोधा, סתמך_, ólas, لعاه
  { {0x6d45003f,0xdcb10092,0x28870054,0x8ae40033}},	//   _udha, ở_, ићев, цісл
  { {0xcd760008,0x4dda0008,0xa34c0091,0x0c840033}},	//   _העתק_, _תחתו, dėžė_, _дыям
  { {0x2d8300dc,0x44250171,0xc60f000b,0x93bc0045}},	//   ldje_, _rtl_, ाद्य_, _stăn
  { {0x2d810020,0x7bcd0007,0xe758005e,0x61e80172}},	//   _kahe_, miau, ричі_, kodl
  { {0x85e80036,0x69c7016f,0x7bcd0007,0x09e40010}},	//   адів_, _umje, liau, _моўн
  { {0x23b10014,0x2db8000a,0xf773002b,0x6498006b}},	//   _fájl_, שלון_, _وار_, итър_
  { {0x2d810020,0x7bcd0173,0x9cd8000a,0xe3b10015}},	//   _lahe_, niau, יווה_, ثرت_
  { {0x27ed0061,0x61e80034,0x46150015,0x11390174}},	//   _iken_, fodl, _طوار, ляны_
  { {0x2d8100b8,0x224d00dd,0x3f80001c,0xb5fd0007}},	//   _nahe_, rrek_, _saiu_, _apšv
  { {0x7bcd0007,0x600a0175,0xa0690054,0x81a40015}},	//   kiau, лном_, ћама_, تحيل
  { {0x25a50176,0x224d0177,0x1fb6004a,0xa4f6000a}},	//   _holl_, prek_, ссор, _הצעד_
  { {0x73c40029,0x21690178,0x4ac7005d,0x25a50179}},	//   _بينم, _били_, _रेलव, _koll_
  { {0x2d83016f,0x4126017a,0xdce7002a,0x8e750138}},	//   gdje_, _лошо_, zeją, цуюч
  { {0x645c0020,0x27ed017b,0x6c360015,0x0136000a}},	//   _ärit, _oken_, إفرا, _הרצת_
  { {0x7bcd0007,0x8b95017c,0x802400e6,0x7fc50015}},	//   giau, оруч, _بروم, _وآيل
  { {0x39460010,0xe9da017d,0x63bb0012,0xef22002a}},	// [120] йнаг, гка_, ihun, ążą_
  { {0x25a500c0,0xbdfa0015,0xb9c50015,0x2fc900bc}},	//   _noll_, _حربا_, يتله, _zmag_
  { {0x6c86003b,0xddd60007,0x7bcd0007,0xe4640061}},	//   _الجم, _kryž, biau, ülüğ
  { {0x27ff017e,0xb73a0029,0xe7e9017f,0x7bcd0003}},	//   _chun_, اثاء_, афік_, ciau
  { {0x67630029,0x66e60036,0x95ca0180,0xd7ef0015}},	//   سُول, щода, лука_, ركه_
  { {0x63bb00b8,0x7a410089,0x27ed0181,0x4e7b004c}},	//   ehun, sátý, _eken_, טאנצ
  { {0x628b0182,0x29cf003d,0x6e360034,0x61e80183}},	//   _argo, aļas_, _lwyb, vodl
  { {0xb8cc000b,0xe44f0015,0x29150061,0xcb12000a}},	//   गह_, رضى_, ğdaş_, ּל֙_
  { {0xd130003b,0x1a9a00b2,0xdb9b004c,0x61e80061}},	//   ومة_, ריִע, רספר, todl
  { {0x361b0008,0x25a50026,0x15430184,0xf991000a}},	//   _עובד, _goll_, _неум, ֵ֨י_
  { {0x63bb002d,0x9f990185,0xa99b004c,0x2d830085}},	//   bhun, авну_, אביר, vdje_
  { {0xf8b3013a,0x753a0186,0x63bb0187,0x6b840079}},	//   פשר_, _hetz, chun, jdig
  { {0x61e80188,0x753a0012,0x7bcd00cd,0xddc400bf}},	//   podl, _ketz, viau, _spiš
  { {0x753a00b8,0x645c0020,0x52d7000a,0x0dc80189}},	//   _jetz, _äris, _פוגע_, буси_
  { {0x2d810020,0x7bcd018a,0x2d19000b,0xe0d30054}},	//   _vahe_, tiau, _दलील_, _ношњ
  { {0x753a018b,0xddc4018c,0x2636002a,0x5ba4018d}},	//   _letz, _vpiš, kło_, пруз
  { {0x6e360176,0x7bcd018e,0xaa59018f,0x2d81007c}},	// [130] _gwyb, riau, ризу_, _tahe_
  { {0x753a018b,0x2636005c,0x79c80029,0x7bcd0007}},	//   _netz, dło_, موقف_, siau
  { {0xddc4016f,0x90d50092,0x2636002a,0x27ff0016}},	//   _upiš, hàn, eło_, _phun_
  { {0x25a5018b,0xd6d10015,0x2bf40033,0xaa950190}},	//   _soll_, وقا_, _няўр, _димч
  { {0x95990191,0xb5fd010b,0xe7380010,0x2636005c}},	//   итку_, _opšt, сеі_, gło_
  { {0x5e580008,0x5c8b0008,0x7afd0192,0xe918005e}},	//   מידע_, ָאֵ֔, _izst, _горі_
  { {0x4d5c0053,0x799500b8,0x2636005c,0x25a500b8}},	//   אדוצ, _inzw, ało_, _voll_
  { {0x27ed003c,0x213e0193,0xe795002b,0xd36e0015}},	//   _uken_, eath_, _باسک, نهى_
  { {0x25a50100,0xdcfc003d,0x11890015,0x63bb0194}},	//   _toll_, idrā, لَةً_, rhun
  { {0xdb1d001a,0xc5fb0015,0x50450195,0x61420046}},	//   _umsæ, _إعرض_, оеоб, vílí
  { {0xc952013a,0x00e2008f,0xc0580010,0x3205003e}},	//   ומי_, джэн, біў_, rmly_
  { {0xe3b30196,0x661b0197,0x92950010,0x628b0198}},	//   _عرض_, _kuuk, _маец, _trgo
  { {0x645c0020,0x644300c0,0x333f0152,0x61450199}},	//   _ärir, lsni, maux_, _дела
  { {0x1167002b,0x661b019a,0x90d50021,0x6443019b}},	//   _طلبی_, _muuk, _وآثا, osni
  { {0x8fa6019c,0x70520029,0x1dbb000b,0x2636002a}},	//   _маке, _قنوا, _उतरत, zło_
  { {0x333f0152,0x2636005c,0xab660010,0x601e0024}},	//   naux_, yło_, ўвал, _zīmo
  { {0x49ca0001,0xba290029,0xbab60033,0x99630046}},	// [140] алан_, مسلم_, цёвы, líři_
  { {0x6b84019d,0x6443019e,0x0000006a,0x0000006a}},	//   sdig, ksni,   ,
  { {0x2d95008f,0x3e6400f2,0x9c660015,0xc7d0004a}},	//   _хрыс, löt_, _بهجو, е́ни
  { {0x753a00b8,0x08090015,0x6443019f,0xf989000a}},	//   _setz, مزني_, dsni, כר_
  { {0x96b70001,0x3e6401a0,0x96330010,0x7c2e00dd}},	//   жују_, nöt_, дніц, lpbr
  { {0x27380023,0xc7b900dc,0xd6390036,0x64430134}},	//   ẩn_, _elő_, сяці_, fsni
  { {0x26360050,0x644301a1,0xe73a01a2,0x291801a3}},	//   sło_, gsni, _веб_, _igra_
  { {0x8c1b0008,0x6d5c0026,0x889b000a,0x66e601a4}},	//   סופי, hgra, _דבלי, _доба
  { {0x82a60010,0xd6250029,0xf1aa00c3,0x644301a5}},	//   юшке, _فعلي, لاده_, asni
  { {0x62840007,0x71740029,0xfa97000a,0xa1580054}},	//   _šios, أهدا, קדיש_, љану_
  { {0xdfd100e6,0x79fb000a,0x333f0003,0x6d5c01a6}},	//   فيد_, שליח, baux_, dgra
  { {0x442e00b8,0x333f0152,0x4fc70010,0x74130015}},	//   mpf_, caux_, існа, _قولا
  { {0x22940063,0x8d770015,0xdefb0033,0x9f4e0030}},	//   _хиля, ياسا, рын_, ónál_
  { {0x64580089,0xe2a90086,0x6d5c01a7,0x201801a8}},	//   ouvi, _دامن_, ggra, íris_
  { {0xe0d40053,0x60210024,0x2ba7009c,0x5ba701a9}},	//   _מײַ_, _tēma, ојав, ораз
  { {0x3f850024,0xc0530008,0x6d5c01aa,0xcfe90115}},	//   ēlus_, _חזק_, agra, _دفعه_
  { {0x201c0020,0x0a150015,0xaa55006b,0x6443003d}},	// [150] _huvi_, سواح, яваш, zsni
  { {0x644301ab,0x645800f2,0xdce7005c,0x1a580015}},	//   ysni, kuvi, zeję, تشفة_
  { {0x7d7a0008,0xe7190029,0xf8b1002b,0x333f0003}},	//   _הנתו, ميات_, رکس_, yaux_
  { {0x6c7a0053,0x5c7a0053,0x644301a7,0x7f5d0012}},	//   _פארפ, _פארה, vsni, ngsq
  { {0x7afd0048,0x333f0152,0xcb9a0008,0xcdd5000a}},	//   _uzst, vaux_, _הסרט, ֔ךְ_
  { {0xae7c0008,0x3d19005d,0xae5801ac,0xca36000a}},	//   שְׁת, _दलों_, קסוס_, _מנשה_
  { {0x8cd1005d,0xe3b10029,0x333f0152,0x645801ad}},	//   _डेमो, فرة_, taux_, guvi
  { {0x644301ae,0x8cdc000a,0xdb1d0012,0x3e64008c}},	//   rsni, יחות, _umsä, yöt_
  { {0x333f0152,0x644301af,0xfa6b000a,0xb6350015}},	//   raux_, ssni, ׁכֵּ, _رفاع
  { {0x644300df,0x7abc0008,0x23b1006f,0x64580091}},	//   psni, יצחו, _máji_, buvi
  { {0x645c0020,0x333f0152,0xc9520053,0x602501b0}},	//   _ärip, paux_, עמט_, ядна
  { {0xb4fa0008,0x34fa000a,0x3e64008c,0xa3b4005e}},	//   _הפעי, _ההעד, töt_, _обхі
  { {0x3fc90086,0x9756000a,0xcaea000b,0x6d5c01b1}},	//   تگوی_, הירו_, _झुंड_, tgra
  { {0xda1f000b,0xd184005e,0x91f70058,0x0000006a}},	//   _बढ़त_, _олій, _بأصا,
  { {0x3e6400f2,0x31560053,0x9f9201b2,0x2b4001b3}},	//   söt_, _זיצן_, lší_, taic_
  { {0x6d5c01b4,0xba260033,0x9f42005a,0x3a26004e}},	//   sgra, здак, boká_, змаг
  { {0x6e46003b,0x9f920107,0x2b4001b5,0x2bad000b}},	// [160] _عندم, nší_, raic_, _टकरा
  { {0x2b4001b6,0x67f8006f,0x48e601b7,0x7c2e01b8}},	//   saic_, ríjm, позв, ppbr
  { {0x7d7b000a,0x9d1b015b,0x9f92006f,0x7d37000a}},	//   _פנטו, _לויט, hší_, _מניב_
  { {0x7872002e,0x4c9b000a,0xdc9b000f,0xd70a004a}},	//   _aðvö, _הבטו, _היטל, бнее_
  { {0x9f920107,0x9b17000a,0xeb91000a,0x28de0065}},	//   jší_, _מחכה_, _בָם_, _मशवि
  { {0x8afb0008,0xbafb000a,0x645801b9,0x9f92013f}},	//   _להכי, _להכש, tuvi, dší_
  { {0xdd570053,0x69ce01ba,0x986c003d,0x0ee90065}},	//   לבסט_, _imbe, rķēt_, _ऐड्स_
  { {0x7d0701bb,0xc8db000a,0xb7da002b,0xf2c6005e}},	//   léré, _הקלט, _اورا_, зсон
  { {0x201c01bc,0x645801bd,0x326600ce,0x518600af}},	//   _suvi_, suvi, їтив, пуна
  { {0x7d070152,0xb6bb000a,0x645801be,0x9f420046}},	//   néré, _הצמי, puvi, voká_
  { {0xf9930008,0x9f920089,0x601e0024,0x89eb000a}},	//   גרת_, aší_, _zīmj, מַטֵ
  { {0x78fb0053,0x60280089,0xb4fb0053,0x09b9000b}},	//   מפיו, _něme, _פלאר, _इत्य
  { {0x7d0700dc,0xc7b3000a,0x69ce01bf,0x7e7d0079}},	//   kéré, גבר_, _ombe, uwsp
  { {0x127b004c,0xc27b000a,0x527b000a,0x9f4201c0}},	//   _לאדע, _לרדי, _לנדא, roká_
  { {0x7d070152,0x4094002b,0x9f420057,0x6b8601c1}},	//   déré, _آلبر, soká_, _bakg
  { {0x60db000a,0x442c01c2,0x50db000a,0x69ce01c3}},	//   _לקונ, _mtd_, _לקוא, _ambe
  { {0xdcf20024,0x7d0701c4,0x6a1501c5,0xda7801c6}},	// [170] īgāk, féré, дмау, зях_
  { {0xceb20053,0xdebc000a,0x99d70015,0xbef80021}},	//   _סיי_, _למחל, أترا, _عريض_
  { {0xf1b30053,0xdcee0011,0xa3be000b,0x3137004c}},	//   עסע_, rebă, ीफा_, פראך_
  { {0x256f0064,0x69ce01c7,0x5a470033,0x9f920046}},	//   zılı_, _embe, _нэга, yší_
  { {0xeafa005d,0x1a940010,0x442c0089,0x256f0064}},	//   ्धृत_, _заяў, _atd_, yılı_
  { {0xcb1201c8,0x93b50023,0x9f9201c9,0x95c50015}},	//   _שלך_, _cũn, vší_, بيته
  { {0x628200dd,0xf992000a,0x9f420046,0x659201ca}},	//   _asoo, _ברם_, elký_, тају
  { {0xdcfe0024,0x9f9201cb,0xd347002b,0x442c01cc}},	//   _japā, tší_, سیته_, _dtd_
  { {0xa3be005d,0x256f0064,0xa3cc000b,0x1c1f000b}},	//   ीफ़_, tılı_, रफ़_, _मूसल_
  { {0xdcfe0048,0xab5b00b8,0x9f920107,0x98ba003d}},	//   _lapā, _flüg, rší_, lapā_
  { {0xd371003b,0x4105005f,0x256f0064,0xc0580010}},	//   _لها_, ьзов, rılı_, піў_
  { {0x256f0064,0x22520064,0x9f920107,0xdcfc0091}},	//   sılı_, ünkü_, pší_, ndrą
  { {0xa294017f,0xee3700a4,0x1efa0015,0x0eba0033}},	//   _паці, мня_, تعدة_, іумы_
  { {0x79870050,0x6e2d002d,0x63ab01cd,0x0000006a}},	//   _najw, _dtab, _hogn,
  { {0x2c870089,0x80240015,0x9b960067,0x7d0701ce}},	//   vídá_, _كريم, ولست, véré
  { {0x70760086,0xeb9701cf,0x672901d0,0x0000006a}},	//   _آميز_, мис_, _nfej,
  { {0x63a601d1,0xc9aa0010,0x7d0701bb,0xfe720015}},	// [180] ökni, овае_, téré, _شدة_
  { {0xc8d60015,0x0000006a,0x0000006a,0x0000006a}},	//   وزاع,   ,   ,
  { {0x07a6004a,0x1d0a0004,0xa2d4000b,0x2a69007c}},	//   мажн, _фени_, _बेन्, atab_
  { {0x7d070003,0xe73701d2,0x2d8a01d3,0x0000006a}},	//   séré, дец_, ldbe_,
  { {0x47330036,0x7d070152,0x442c01d4,0x0000006a}},	//   тніс, péré, _std_,
  { {0x2d8a0030,0x69ce01d5,0x442c01c2,0xf2020065}},	//   ndbe_, _umbe, _ptd_, _रीढ़_
  { {0xd75a0015,0xd823006b,0x644d003d,0xe4b80138}},	//   _ولست_, _адси, ņain, ялкі_
  { {0x8c1b000a,0xdc89000a,0x63ab01d6,0x57460058}},	//   חוקי, לְפָ, _cogn, _زخرف
  { {0x5313002b,0x03a7002b,0xa2940033,0x6ac7000b}},	//   پذير, بگلو_, хапі, _रेफ़र
  { {0x60280089,0xea9b004c,0x442c01d7,0x2508002b}},	//   _němc, קסיש, _ttd_, _فرضی_
  { {0x19570008,0x63ab00dc,0xf9570008,0x395701d8}},	//   וביל_, _fogn, וסית_, ושים_
  { {0xe29a01d9,0x33930029,0xd36f0086,0x6282007c}},	//   _мае_, _للمز, _نهم_, _tsoo
  { {0xc333000a,0x81a60015,0x31c601da,0x0000006a}},	//   _סוס_, _يحتل, _оскв,
  { {0xe0cf0074,0x12fb0008,0x0000006a,0x0000006a}},	//   ازی_, _והדב,   ,
  { {0xdb060014,0x415b000a,0x515b000a,0xfbab0033}},	//   _elkü, _ודוג, _וכוו, отай_
  { {0x9fe70029,0xcf270040,0x648b000a,0x2cac0123}},	//   _تسته, _غربي, חְמְ, ädda_
  { {0xdd95008f,0x9e070036,0x6e2d003f,0xef1f0061}},	// [190] _запы, _очол, _utab, ndüm_
  { {0x89340015,0x3df4004a,0x6f000061,0xb45e00af}},	//   نعما, _изыс, ümce, _боxо
  { {0x2a690005,0x917b0023,0x2251005c,0xf84b0033}},	//   stab_, _hệ_, ązki_, ючай_
  { {0xf093000a,0xaad0000b,0x957c002a,0x3ec4007f}},	//   כנע_, _सेवक, _skąp, _örtü_
  { {0xcb36013a,0xc5f5006b,0x7987002a,0x63ab01db}},	//   _ראשי_, някъ, _tajw, _rogn
  { {0x659401dc,0xd7c9002b,0x05790015,0x63ab01dd}},	//   качу, _کوره_, سمعة_, _sogn
  { {0x917b0023,0x6d3c0008,0x577b0015,0xd9140033}},	//   _lệ_, חתונ, _وصرح_, _адры
  { {0xd2a9004a,0xe3b100c3,0x0d18004f,0x99920138}},	//   зкие_, طرب_, וקוט_, лiзм_
  { {0xd24e00e6,0x614500e2,0x63ab01de,0x7bda0003}},	//   مني_, непа, _vogn, étui
  { {0x15150010,0xd1c6004a,0xd6180015,0xe5070067}},	//   _здзя, елье_, _قتلا_, _قباي
  { {0x672401df,0x833500ce,0x63ab01e0,0xddcb007f}},	//   žije, _знех, _togn, _şişe
  { {0xa856000a,0xdd92002b,0x8fa601e1,0x0000006a}},	//   עירה_, گوس_, хаме,
  { {0xf1a8002b,0xeef50033,0x0000006a,0x0000006a}},	//   سایه_, вярэ,   ,
  { {0x92c101e2,0xd245002b,0x11d70015,0xc0e501e3}},	//   ığın, یچ_, _تتصد, _полк
  { {0xddcd0011,0x61e600dc,0x60a40015,0x6cd6002b}},	//   _spaţ, ékle, _لإيق, رقرا
  { {0xba1a0058,0xfaa60138,0x0000006a,0x0000006a}},	//   كيرا_, набо,   ,
  { {0xc33201e4,0x6e930029,0x3956000d,0xf4120053}},	// [1a0] טון_, _مليا, ењет, רפן_
  { {0xac860083,0xdcfe0011,0x4c8601e5,0x7bdf01e6}},	//   _згол, _capă, _злов, anqu
  { {0xc1720008,0xa81a0087,0xfd120015,0x0d3b000a}},	//   רחב_, ستار_, _حجة_, _מגיב
  { {0xfaa601e7,0xdeba000a,0x999f003d,0xe66601e1}},	//   _замо, ּמַל, āršo_, етко
  { {0xcb150033,0x3c3e0046,0xd5c5005e,0x0000006a}},	//   _афры, lův_, _кiмн,
  { {0xa4d40127,0xe3b80061,0xe5a301e8,0x94d401e9}},	//   колі, _atıp_, личи, колц
  { {0xa3cc000b,0xe44f0015,0x3c3e0046,0x52b80065}},	//   रफल_, مضي_, nův_, इन्स
  { {0xc29800f4,0x7669008c,0xb806009a,0x6f0401ea}},	//   дких_, ösyö, _سبزه, _ozic
  { {0xdac2005e,0x66e301eb,0x280201ec,0x0000006a}},	//   кцiя_, _бота, ārnē_,
  { {0x64a601ed,0xbbad000b,0xb5ca002b,0x2fc00030}},	//   _паза, _टक्क, _عوام_, _alig_
  { {0x8f350010,0x320c0034,0xdb12001a,0x7bd601c2}},	//   кенц, rmdy_, _ágæt, kiyu
  { {0x83360029,0x83690015,0xe457000a,0xf8db000a}},	//   _أراض, _يصنف_, _טיבט_, לחימ
  { {0x82b30086,0xddcd0091,0x2e260034,0x644a01ee}},	//   _محوط, _apaš, _côf_, lsfi
  { {0x9f4b0089,0x917b0092,0xe29b000a,0x09af000b}},	//   mocí_, _vệ_, _משדר, _टवेय
  { {0x661a00f2,0x4c840033,0xdcfc002a,0xef1f0061}},	//   _mitk, ллёв, odrę, ndük_
  { {0xd13800df,0x749b0053,0x917b0092,0x7bdf01ef}},	//   lbą_, הילפ, _tệ_, unqu
  { {0x66d30014,0x4fd80008,0x3ced000b,0xd138002a}},	// [1b0] _műkö, _רוחב_, _आँके_, obą_
  { {0x644a01f0,0x317e01f1,0x661a01f2,0xe89501f3}},	//   ksfi, netz_, _nitk, казь
  { {0x200901f4,0x6d4701f5,0x2fc000cb,0x201b01f6}},	//   _khai_, maja, _ylig_, _épis_
  { {0x18980029,0x6d4701f7,0x7bc401f8,0x661a01f9}},	//   عضلة_, laja, chiu, _aitk
  { {0x6b9d00b8,0x46a40036,0x661a01fa,0xcf2c000a}},	//   _insg, лаїв, _bitk, הֽוֹ
  { {0xab5b00b8,0x6d4701fb,0x6b8d01fc,0xe52e007f}},	//   _flüc, naja, ldag, _güüğ
  { {0xab5b00b8,0x443e00e7,0x69d701fd,0xd49b01fe}},	//   _glüc, _cwt_, mixe, ярд_
  { {0xe65d0064,0x6d4701ff,0x20090016,0x6b8d0200}},	//   ştığ, haja, _nhai_, ndag
  { {0x74120086,0x6b8d0020,0x64580201,0xc6740018}},	//   جويا, idag, arvi, _مطلب
  { {0x27fd0026,0x461500e6,0x93bc0045,0x76590034}},	//   llwn_, _شوار, _stăt, mrwy
  { {0xf992013a,0x6d470202,0x76590026,0xe0d1002b}},	//   ברי_, daja, lrwy, شزد_
  { {0xc3cb0021,0x6b8d0079,0x20090203,0x1fb60204}},	//   _عظام_, jdag, _chai_, тсор
  { {0x93b6013a,0x63a9010b,0xddcd0085,0x76590034}},	//   _שלנו_, mjen, _spaš, nrwy
  { {0x865a0008,0xd2560008,0x6b8d0205,0x63a90206}},	//   ודשי, _ישנה_, edag, ljen
  { {0x2251005c,0xc5f20008,0xf1a8002b,0x6b8d001a}},	//   ązku_, ידך_, _ساوه_, fdag
  { {0x6b8d00b6,0xa00a00e6,0x63a90207,0x3c3e0046}},	//   gdag, _تقبل_, njen, rův_
  { {0x4b230191,0x63bb003f,0x63a9016f,0x6d470208}},	// [1c0] рмув, ikun, ijen, baja
  { {0xfe1e005d,0x63a90209,0x63bb007c,0x76590034}},	//   _यूएस_, hjen, hkun, drwy
  { {0x7659020a,0x8c430064,0x661a00dc,0x63a9020b}},	//   erwy, üşte, _ritk, kjen
  { {0x6e24003f,0x69d70144,0x76590034,0x18670054}},	//   _kuib, aixe, frwy, ђачи_
  { {0x76590176,0x661a00f2,0xcf930135,0x63a9020c}},	//   grwy, _pitk, יטא_, djen
  { {0x69c5020d,0x35f301f3,0xd5af0021,0x64580085}},	//   chhe, апір, يفن_, trvi
  { {0xd5b10092,0x04940015,0xa4d80033,0x76590034}},	//   _tín_, البح, эдку_, arwy
  { {0xfe1e005d,0x64a30001,0x63a9020e,0xe3b20021}},	//   _यूऍस_, раћа, gjen, شرع_
  { {0xfbd3013a,0x20090176,0x661a00dc,0x6d47003f}},	//   יתה_, _rhai_, _titk, yaja
  { {0xa3f50089,0x6feb005c,0x6b8d00dc,0xdcfe002c}},	//   ější_, ięce, zdag, _dopĺ
  { {0xd1380007,0x6d47020f,0x20090016,0xbfd9005e}},	//   rbą_, vaja, _phai_, еднє_
  { {0x63bb00b8,0x317e00b8,0xde590210,0x63a90211}},	//   ckun, setz_, намі_, cjen
  { {0x42540029,0x6d470212,0x8504002b,0x6e240045}},	//   _إنتر, taja, _شوچن, _cuib
  { {0x20d60058,0x3df4009b,0x0000006a,0x0000006a}},	//   _لتعج, изяс,   ,
  { {0x80a30086,0x6d470213,0x0fdb0015,0x621b000a}},	//   _نمون, raja, _يبعث_, _קווק
  { {0x5f770087,0x76590034,0x8117000a,0x5c070214}},	//   _شاعر, yrwy, _בחוג_, тяга
  { {0xf8eb000b,0xf96b0215,0xbf9b00aa,0x69c500da}},	// [1d0] _जुड़ा_, дрей_, glêe, thhe
  { {0x49540015,0x68fc0216,0x79c80015,0x6b8d0217}},	//   لخمس, _byrd, نوقف_, sdag
  { {0xf7950010,0x6b8d0218,0xa2d4000b,0xd7590015}},	//   лажэ, pdag, _बेस्, فلات_
  { {0x76590176,0xfecb000a,0x3dcf002a,0x98b80045}},	//   trwy, ֽמַּ, żową_, _seră_
  { {0x61e10026,0xe7840219,0xe7360054,0xc6a7006b}},	//   ynll, рухо, ћеш_, ържи
  { {0xe6180036,0x66d20064,0xa934021a,0x63bb0079}},	//   вді_, _sıkç, _верш, wkun
  { {0x76590026,0x63bb021b,0x0554005e,0x63a9021c}},	//   srwy, tkun, ртія, tjen
  { {0x93bc0011,0x9f42006f,0x7c2501d7,0x787a000a}},	//   _stăr, sokú_, _muhr, _אָמו
  { {0x63a9021d,0x59b7021e,0x63bb021f,0x66120030}},	//   rjen, _आकार, rkun, ókkö
  { {0x6d4500bd,0xa855000a,0x0574002b,0x7afd0220}},	//   _neha, ְיָה_, _نامد, _myst
  { {0x1c1f005d,0xf1c30007,0x361a0008,0x04670221}},	//   _मंगल_, _ryšį_, _נועד, _штам
  { {0x08760053,0xc43a0008,0xdb060222,0xdb0f016e}},	//   נערט_, _נתני, _loká, _você
  { {0x4425020a,0x69d50111,0x4e27006b,0x6d450223}},	//   _hul_, _omze, лоян_, _beha
  { {0x6145000d,0x4ed50036,0xbbbc000b,0x4252002b}},	//   _сека, рюют, ईस्क, _انور
  { {0xe0550029,0xfd450033,0x224d01d7,0xc172000a}},	//   _إختب, шэўн, lsek_, _לחג_
  { {0x44250020,0xdcf50024,0x224d005c,0x7afd0224}},	//   _mul_, edzē, osek_, _byst
  { {0xa95a0225,0x7afd0226,0xdcfc0227,0x7e9700c3}},	// [1e0] فجار_, _cyst, merč, _منير_
  { {0xd5b10023,0x3f820005,0x386100b8,0x7c2501f1}},	//   _nó_, leku_, fuhr_, _fuhr
  { {0x31ba0053,0xdb060057,0xd910002b,0x9f4b016e}},	//   עזענ, _doká, زیر_, locá_
  { {0x224d01e2,0x3f820020,0xc66a0001,0xccf3000a}},	//   ksek_, neku_, ешке_, _לכת_
  { {0x7f3b00b2,0x7afd0026,0x68fc0034,0x3f820228}},	//   גענו, _gyst, _wyrd, ieku_
  { {0xd5b100a7,0x44250064,0xd5b00015,0x64410034}},	//   _có_, _bul_, تفت_, _bwli
  { {0xd4670001,0x8884002b,0xfbd2000a,0xe56f006e}},	//   гије_, _خیان, ֶת֙_, سطو_
  { {0x4425002f,0x53980229,0x3f82016f,0x389b000a}},	//   _dul_, твия_, jeku_, _אילנ
  { {0xdb0600dc,0x316a006b,0x9f4b0144,0x8233002b}},	//   _elkö, ншно_, vocà_, یریا
  { {0x60210024,0x867b0008,0xc05a022a,0x20740033}},	//   _lēmu, _ארמו, нім_, алоў
  { {0x09f70008,0x89db000a,0xdfd10015,0x224d002a}},	//   רמים_, תחיי, قيد_, asek_
  { {0xdcf50024,0x98b80007,0x6d45013c,0x6d5a001a}},	//   zdzē, _gerą_, _seha, ótan
  { {0x6d45022b,0x4425022c,0x0000006a,0x0000006a}},	//   _peha, _zul_,   ,
  { {0xbb1b0152,0x98ad0046,0xeb9f00cb,0x7afd0013}},	//   _maît, _řeč_, _snø_, _ryst
  { {0x6c54005e,0x5478000a,0xd9fa000b,0x4bf9002b}},	//   йкру, כְּנ, ्तनत_, نبرگ_
  { {0x7afd022d,0xa09b0008,0xb09b000a,0xdb060030}},	//   _pyst, _טיוט, _טיור, _soká
  { {0x79d50036,0x6d450020,0xbb1b0003,0xdb060046}},	// [1f0] ажає, _teha, _naît, _poká
  { {0xa9070067,0xdcf5003d,0x5d670054,0x7afd022e}},	//   هبان, udzē, _стиз, _vyst
  { {0x7afd0050,0xd7c80086,0xd6ab002b,0xdb06022f}},	//   _wyst, گونه_, کدام_, _voká
  { {0xe7190029,0xdcfe005c,0x7afd0230,0x31e10231}},	//   نيات_, _napę, _tyst, _पद्ध
  { {0x98aa0024,0x44250232,0xa2d4000b,0xb6a5004a}},	//   ējām_, _sul_, _बेल्, рилл
  { {0x93bc0011,0xf4830086,0x2d830233,0xdcfc006f}},	//   _stăp, ماعی, neje_, zerč
  { {0xe3b1003b,0x75d2002b,0xf8b9000b,0xa889004f}},	//   قرة_, تيوا, _इथिय, _בָּ֥
  { {0xe3b10029,0xdb1d002e,0x44250234,0x58d40054}},	//   ترت_, _umsó, _vul_, _уост
  { {0xa2350010,0x290c002d,0xdcfc0007,0x42250004}},	//   шэйш, _údar_, verč, јдов
  { {0x41b50235,0x601f0091,0xca38000a,0x224d0236}},	//   рсит, _rūma, אנזה_, rsek_
  { {0x66ca00dc,0x3f820237,0xcea9000a,0x3fe60238}},	//   _töké, teku_, _קי_, ижов
  { {0xe0d60063,0x52d9004a,0xdb1d0052,0x0000006a}},	//   рвю_, _имею_, _alsí,
  { {0xe285002b,0xab5b0012,0x8db600fd,0x9e630239}},	//   _خطای, _plün, асві, овяд
  { {0x7bc8003d,0xae870004,0x3f82023a,0xdcfe002a}},	//   īdum, јбрз_, seku_, _zapę
  { {0xdd0e0064,0xe588000a,0x8c46023b,0xab5b0030}},	//   _dışa, נָשָ, ребе, _vlün
  { {0xc0520008,0x3ff30015,0xb92b0016,0xfce300ce}},	//   _וזה_, _وكور, _thuỵ_, іото
  { {0xaae50015,0xab290015,0xeab7023c,0x3946023d}},	// [200] مسكو, اسفل_, айт_, инаг
  { {0xc896023e,0x28960054,0x7d090046,0xdd2c0073}},	//   ирењ, ијес, řesa, lėži
  { {0xc8ca0087,0x2609000b,0xfeba002b,0x8726023f}},	//   خوان_, ितनी_, _ساکت_, амеж
  { {0x628b0026,0xeef60053,0xd7ef0015,0x6e93002b}},	//   _osgo, ֱמַר_, وكل_, _الیا
  { {0xb8fd000b,0x23a9000b,0x6b840240,0x55580033}},	//   _ते_, कानद, meig, галя_
  { {0xd5e3005e,0x6b840241,0x8e97004f,0x99800073}},	//   ожчи, leig, ידנו_, rpių_
  { {0x2927002c,0x26c00242,0x6feb002a,0xd5490015}},	//   ávať_, šio_, hęca, اجهم_
  { {0x6b840243,0x290a0244,0x25b20091,0x0000006a}},	//   neig, _izba_, _žalą_,
  { {0xa3c7000b,0xc1a600d7,0xe61a0245,0x27e60246}},	//   _उतर_, ајни, _ада_, mnon_
  { {0xda16005d,0x62990034,0x22590247,0xc1730248}},	//   थगित_, _drwo, áska_, ольщ
  { {0xc95301e4,0xd4d50010,0x629900b8,0xc0ca0249}},	//   חמת_, _ліцэ, _erwo, тупе_
  { {0x27e6024a,0x04db000a,0xa857000a,0x2fe40015}},	//   nnon_, _בקבל, סיכה_, ْكَف
  { {0x5f94010f,0xf7730008,0x93250086,0x22580080}},	//   цият, חקר_, _ارمن, _силы_
  { {0x7bc6022d,0xb2bb0008,0x627b000a,0x51f30015}},	//   _alku, _במדר, _סנונ, _وسور
  { {0x70540087,0x6b84024b,0xac95004a,0x2d83024c}},	//   _انبا, feig, щавш, reje_
  { {0x628b0176,0xe0fb0008,0x2ba4000d,0xe4570053}},	//   _ysgo, _שלהל, ојув, יילט_
  { {0x8ed80086,0x0a6b006b,0x2905024d,0xac18024e}},	// [210] _پذير_, ърви_, _šla_, роту_
  { {0x780f000b,0x99d40015,0x7bc60030,0x0000006a}},	//   िष्क_, يتلا, _elku,
  { {0x6b840048,0x6d41001a,0x4c95024f,0x63a20250}},	//   beig, ðlau, _уинс, _onon
  { {0x20140251,0x27e60252,0xdc9a004c,0x7d08007c}},	//   _èxit_, gnon_, _עירל, üdse
  { {0x23da005d,0x4b7a004f,0xdcfc01ec,0x0000006a}},	//   _बग़द, _גארו, merā,
  { {0xce38013a,0x63a20253,0x7ad0000b,0x7c94002b}},	//   סאות_, _anon, _सेटअ, _اشیا
  { {0x05740086,0xd64d0036,0xd7950063,0x97a70254}},	//   تاند, _гiпе, _ливъ, _крал
  { {0xc2450036,0xdcfc003d,0xab5b0255,0xb8dd000b}},	//   бник, nerā, _olüm, ेन_
  { {0x65870256,0xdd2c0091,0x248c01d7,0xe730006e}},	//   _выез, vėži, _esdm_, _آصف_
  { {0x6b84018b,0x13a7002b,0xbec40091,0xeab2004f}},	//   zeig, انکی_, šūki, לֹת_
  { {0x7dc2002c,0xeae4000b,0xa988000a,0x1600000b}},	//   _dôsl, _गश्त_, בָרִ, _लीटर_
  { {0x7dc2002c,0x87790053,0x487a000a,0xe8d6000a}},	//   _pôso, נאָי, נטרס, מותר_
  { {0x8287002b,0xdcfc003d,0xc2c40015,0x69c70257}},	//   _خجال, derā, _ويمي, _olje
  { {0xb6da0053,0x8cb6000b,0x8e07005e,0x6b840258}},	//   אַלט, ैनलो, йняв_, weig
  { {0x7d090089,0x8c9500fd,0x27e600e7,0x6b840259}},	//   řesn, орті, ynon_, teig
  { {0xbbe90015,0x0056000a,0x6fc60125,0xdb24002b}},	//   لرقم_, _השקת_, _fóca, زوئی
  { {0x7f3b0053,0xda650015,0x6b84025a,0x69c70085}},	// [220] _געפו, قالي, reig, _blje
  { {0x5d860029,0x6b84025b,0xbddb0003,0x49960054}},	//   _الدل, seig, ssèr, љшат
  { {0x6d4e00b6,0x97260029,0x3f920049,0xca29000a}},	//   maba, مفاو, _kayu_, תם_
  { {0x6d4e025c,0xa3d9000b,0x78a30123,0x69c7025d}},	//   laba, डोम_, ånva, _elje
  { {0x6f7b000a,0xd6770015,0x276b002b,0xef1f0061}},	//   רְבו, محوا_, اشمی_, ldür_
  { {0x6d4e025e,0x9e7b000a,0x3f9201d7,0xe1e7006e}},	//   naba, רנספ, _layu_, _رس_
  { {0x2bbf005d,0xef1f0064,0x225f01c2,0x8c1a000a}},	//   _एकमा, ndür_, eruk_, ְוִי
  { {0xa3d2005d,0xa8570008,0x136a025f,0x6d4e0260}},	//   हों_, _לילה_, ушки_, haba
  { {0xe6430083,0x7dcb0064,0x6d4e0261,0x06ea0262}},	//   _нетп, _hüse, kaba, _смак_
  { {0xd9fa005d,0x018a0146,0x75d30015,0x9f420227}},	//   ्तित_, ущий_, _فيقا, roký_
  { {0x20d30010,0x672d0263,0xa98b000a,0x9f420264}},	//   зіўс, žaje, אָכִ, soký_
  { {0xf8b3000a,0x69de0265,0x926a0004,0x225f0266}},	//   לשת_, hipe, _брка_, bruk_
  { {0x2bbf000b,0x69de0267,0x394a0085,0x0000006a}},	//   _एकबा, kipe, _oebs_,
  { {0xbd450029,0x3fc90086,0x30a60268,0x12e7000a}},	//   تنسي, ادگی_, _грив, _לֽוֹ_
  { {0x2a600020,0x69de0269,0xbfd50015,0x10530015}},	//   erib_, dipe, _ويتع, _فضيح
  { {0x69c7010b,0xeb4800fd,0x6e46001a,0x940b000a}},	//   _slje, йчук_, ðubú, ָּלֵ
  { {0x6d4e00b6,0x59d90010,0x539b0008,0xddeb0086}},	// [230] baba, адаў_, נימו, _مرده_
  { {0x49bb0086,0x2489005c,0x35be000b,0x99d70015}},	//   دارد_, łami_, ्सफ़, حترا
  { {0x2010005c,0x6d410061,0xdcfc003d,0x3915002b}},	//   łnił_, ılad, perā, آواز
  { {0x61fa0079,0xd6390033,0x225f0061,0x6457026a}},	//   hotl, аякі_, yruk_, áxim
  { {0x7bdf026b,0xe611002b,0x600c000a,0x7bcd026c}},	//   miqu, وشت_, נִבְ, mhau
  { {0x7bdf026d,0x69de026e,0x69c70085,0x06840033}},	//   liqu, cipe, _ulje, ягін
  { {0xddcc00df,0xf992000a,0x8d4c000a,0xa3d5000b}},	//   _žiūr, _קרל_, אֲחֵ, सफल_
  { {0x05770086,0x61e8026f,0x7bdf0270,0x7bcd0271}},	//   _گارد, endl, niqu, nhau
  { {0x6603002c,0xd24e0029,0x961d003d,0xb6340015}},	//   plnk, نني_, _apņe, _فعلت
  { {0x7bdf0152,0x4206005e,0xef1f0061,0x225f00cb}},	//   hiqu, жньо_, ydür_, rruk_
  { {0x0fda0029,0xbddb0251,0xe5700086,0x6d4e0272}},	//   لبحث_, ipèd, _سطل_, vaba
  { {0x61fa0020,0x69de003f,0x6d4e0273,0xf3f00015}},	//   aotl, zipe, waba, _كأن_
  { {0x7bdf0274,0xd808000a,0x61fa0061,0x6f0d002a}},	//   diqu, מִשָ, botl, _czac
  { {0x112b0036,0x8e75005e,0x7bcd0012,0xf194004a}},	//   _сюди_, чуюч, ehau, _ничь
  { {0x6d4e0275,0x6c360015,0x2fc90276,0xdcfc0045}},	//   raba, تفزا, _flag_, deră
  { {0x7bdf0277,0x6d41002e,0x6d4e0278,0x27ed01a3}},	//   giqu, ðlar, saba, _njen_
  { {0x6d4e0279,0xba1a0015,0xed5a027a,0x38cb002b}},	// [240] paba, ليرا_, _коп_, یامی_
  { {0xdcf50064,0xdcfc0011,0x6f040061,0x84e90065}},	//   _çağr, geră, _iyic, टपाट_
  { {0x881a0010,0x3205027b,0x7bdf01e6,0xe8f7027c}},	//   аўду_, illy_, biqu, олф_
  { {0xfaa60010,0x394a027d,0x7bcd027e,0xeb9a027f}},	//   _дамо, _webs_, chau, _тим_
  { {0x7f8d0053,0xdcfc0045,0xba760015,0xe5340280}},	//   טנאַ, beră, _باجت, пель
  { {0xfc4b0089,0x27ed00d9,0xfe9b004c,0x4e8b000a}},	//   říž_, _ejen_, יינמ, שָׁ֣
  { {0x60280089,0x69dc002d,0xa7860015,0xab5b0012}},	//   _těmi, _imre, _وشرو, _blüh
  { {0xd3770080,0x442200c0,0x7bc40007,0xa3ba0029}},	//   очь_, ök_, nkiu, شاعر_
  { {0x61fa0281,0x7bc40091,0xd3d70058,0xe3af0058}},	//   totl, ikiu, تبوا_, ضري_
  { {0x2fc90282,0x61e80283,0x443c01e0,0x0000006a}},	//   _slag_, undl, ppv_,
  { {0x6f0d005c,0x399b0053,0xeb07005d,0xdb1d001a}},	//   _szac, בייד, _शर्त_, _umsö
  { {0x93250074,0x32050041,0x7bdf0152,0xea010092}},	//   _فرهن, ally_, xiqu, _đập_
  { {0x6b960026,0x69dc0284,0x2fc9016b,0xdb0f0069}},	//   ddyg, _omre, _vlag_, _pocí
  { {0x72e90053,0xf5aa000a,0x442c0285,0x7d090046}},	//   _פֿײַ, ׁבָּ, _kud_, řesm
  { {0x4c940286,0x7bdf0287,0xd53b000a,0x7bcd0288}},	//   мирс, tiqu, שתלט, thau
  { {0x5a350289,0x69dc028a,0x442c028b,0x7dcb0012}},	//   знат, _amre, _mud_, _büsc
  { {0x7bdf028c,0x6d410064,0x2d93028d,0x7bcd028e}},	// [250] riqu, ılab, _taxe_, rhau
  { {0x7bdf028f,0x442c0161,0x88c7002b,0x7bcd0290}},	//   siqu, _oud_, يتال, shau
  { {0x7bdf0291,0x1e180015,0x20ca000b,0xf77100c3}},	//   piqu, _بغية_, ानिध, ّات_
  { {0xacfa000a,0x5a470033,0x69dc0061,0xdcfc0045}},	//   _להתכ, _мэга, _emre, seră
  { {0xd6db0292,0xf77000e5,0xe7980015,0x53a9000b}},	//   јте_, ضان_, تخلص_, कासश
  { {0x3aba0008,0x2aba000a,0xdcf5003d,0x9555002b}},	//   _המשנ, _המשא, jdzī, سختا
  { {0xdd7c0053,0x7d7c000a,0xf5560015,0x27ed0293}},	//   יטגל, ינגו, سليب_, _tjen_
  { {0xdcf5003d,0x398a002a,0xc2450294,0x69c501f9}},	//   edzī, rósł_, пник, lkhe
  { {0x23620014,0xe6880015,0x8c1c000a,0x69dc0034}},	//   ókja_, _ونفى_, סוחי, _ymre
  { {0x69c500b8,0xdb06002c,0x442c002d,0x320500da}},	//   nkhe, _pokú, _fud_, ully_
  { {0x7bc40007,0x3815000a,0x442c0295,0x10a50296}},	//   ykiu, ּקָם_, _gud_, чинн
  { {0x547a0008,0x27fd003e,0x76490297,0x02450015}},	//   _לטעו, nown_, _kwey, _فَصَ
  { {0xadf8005d,0xc7d6000a,0xd1bb002b,0x92640015}},	//   ंकलन_, פושי_, _پاشا_, _قدوم
  { {0x79950050,0x69c50298,0x64600091,0xa2d40065}},	//   _nazw, jkhe, ūziš, _बेट्
  { {0xdca30299,0x61e1029a,0x63b9002a,0x1d0a029b}},	//   нари, mill, _kown, севи_
  { {0x60d60008,0x61e1029c,0x3ce50030,0xdb16008c}},	//   _מוצא_, lill, úlva_, ykyä
  { {0x3c19008f,0x6b630010,0x5e570029,0x61e1029d}},	// [260] іўся_, экта, _فليس_, oill
  { {0xa96a0029,0x6d410064,0x61e1029e,0xfe9b000a}},	//   إمام_, ılac, nill, _פיימ
  { {0x5dbb0008,0x79950012,0x7786029f,0xd910002b}},	//   _הזיה, _dazw, злез, ئیز_
  { {0x442c002f,0x2d9802a0,0x61e102a1,0x2d8a02a2}},	//   _rud_, ldre_, hill, lebe_
  { {0x96b70001,0xd5ba0256,0x963302a3,0x61e102a4}},	//   зују_, йск_, еніц, kill
  { {0x61e102a5,0x46390036,0x8e5700a3,0x2d9802a6}},	//   jill, іччя_, לינג_, ndre_
  { {0x95530086,0x7c26003f,0xf74602a7,0x2d8a0012}},	//   رخوا, _kikr, _нево, iebe_
  { {0x9f590152,0x7995005c,0x3373006b,0x82380004}},	//   posé_, _zazw, егър, озис_
  { {0x60330011,0xe3af0015,0x5a9c000a,0xf1aa0067}},	//   _răma, ارى_, שׁ֖ו, ماده_
  { {0xe1d80036,0xdcf50024,0xa63b0008,0x442c02a8}},	//   ідні_, udzī, _לגמר, _tud_
  { {0xdcf50024,0x442c00e8,0x853b000a,0x653b000a}},	//   rdzī, _uud_, _הגבי, _העבד
  { {0x3ea002a9,0x61e102aa,0x8366002b,0x74130015}},	//   _brit_, aill, _ردصل, _كولا
  { {0x1ee70086,0x539b000a,0x61e102ab,0x93b7000a}},	//   سوسی_, _ליאו, bill, _מלאו_
  { {0x4426003f,0x21f40015,0x61e102ac,0x2d8a02ad}},	//   _hio_, _تكتس, cill, gebe_
  { {0x317b0008,0x717b0008,0xb17b0008,0x417b0008}},	//   _הרומ, _הנוס, _הטור, _הנוב
  { {0xcf270029,0xddeb002b,0xf993002b,0x3ea002ae}},	//   _عربي, _گربه_, کبر_, _frit_
  { {0x61eb0014,0x442602af,0x6dd50015,0xadf502b0}},	// [270] _állí, _mio_, _يقبض, _опиш
  { {0x2d8a001c,0x9aa40015,0xbdfb0015,0xc1780091}},	//   cebe_, عملو, _درعا_, mnės_
  { {0x27fd02b1,0x721b000a,0x7d7a000a,0x9d190099}},	//   town_, מומח, _ונתו, _фонт_
  { {0xc7940010,0x629b0007,0xa037000a,0xf6f5002b}},	//   ершы, yvuo, פאדה_, وزشگ
  { {0x63b90026,0x0f580008,0x27fd003e,0xdb23002b}},	//   _rown, ליאם_, rown_, _سوسی
  { {0xd126003b,0x06f40086,0x63b90034,0x65920054}},	//   _لم_, رسنج, _sown, ваљу
  { {0x4426010b,0x94750086,0x61e102b2,0x8d5c000a}},	//   _bio_, بگذا, vill, זכוי
  { {0x61e102b3,0xd794006b,0x3d150065,0x7c3801f6}},	//   will, _писъ, _धरने_, _évre
  { {0x61e102b4,0x52a9005e,0x442602b5,0x3f8b0085}},	//   till, івом_, _dio_, decu_
  { {0x5555002b,0x20c5005e,0x3216002b,0x629b0091}},	//   _آپار, дйом, وييد_, rvuo
  { {0x7dd0022d,0x63b9003e,0xb9360008,0xc952000a}},	//   _jäse, _town, ונתו_, כמי_
  { {0x3ea00152,0xb4fa009d,0xdee602b6,0x61e102b7}},	//   _prit_, _ולער, доми, sill
  { {0x7dd000c0,0x03d6000a,0x61e102b8,0xb1b50058}},	//   _läse, _קונם_, pill, _يحتش
  { {0x7c260293,0xa3d9000b,0x442602b9,0xb4f9004c}},	//   _sikr, डोर_, _zio_, ַפּי
  { {0x3b96000d,0x3e760134,0xc1050015,0xc1040015}},	//   мјат, sæt_, _توثي, _كوهي
  { {0x6ff60029,0xea010016,0x2d8a02ba,0xd48f00ce}},	//   _تستط, _đạp_, sebe_, трi_
  { {0x3b07010f,0x3a2602bb,0x6bd70058,0x7c2602bc}},	// [280] дето_, дмаг, ذوكس_, _vikr
  { {0xc9860029,0x60280089,0x7dcb0061,0xbd46006e}},	//   بشري, _těmt, _hüsn, _تندي
  { {0x8cb5014e,0x7c2600df,0x19b90286,0x2fd7002b}},	//   _उपयो, _tikr, чуть_, _روید_
  { {0x672d016f,0xb0b60053,0x4c9b000a,0xe0b6004c}},	//   žajn, ופעס_, _ובטו, ולעט_
  { {0x442602bd,0x501b000a,0xed56004f,0x667302be}},	//   _rio_, קונו, ֥בֶר_, ندور
  { {0x4426003f,0x15140033,0x0000006a,0x0000006a}},	//   _sio_, ндля,   ,
  { {0xd49702bf,0xe5a30054,0x52b8000b,0x442602c0}},	//   дры_, тији, ेन्स, _pio_
  { {0x2918002a,0xc1780091,0xdb0d001a,0xf2c6007e}},	//   ągać_, ynės_, okað, дсон
  { {0xd1660063,0x8cb5005d,0x442602c1,0xdb0d001a}},	//   мъни, _उपभो, _vio_, nkað
  { {0xe29f0084,0x7c3e016f,0x7dd00123,0x6ff2003d}},	//   æða_, _otpr, _läsb, vāca
  { {0xf9930008,0xf9460010,0x442602c2,0xdcfe003d}},	//   דרת_, чнiк_, _tio_, _mapē
  { {0x443e02c3,0xdb0d002e,0xa857000a,0x72c602c4}},	//   _itt_, kkað, ויטה_, _обез
  { {0x441b0053,0xc7b3000f,0xff0402c5,0x753d0030}},	//   _וואס, דבר_, вярн, _őszi
  { {0x7ae900bd,0x41770015,0x3f8b02c6,0x443e01d7}},	//   _žeto, _يمنح_, secu_, _ktt_
  { {0xc1780007,0xc1730008,0x40940015,0x7e6600cb}},	//   snės_, _יחס_, _ألبر, arkp
  { {0x5f950063,0xd01100c3,0x6fc60125,0x645802c7}},	//   _чиит, _حلب_, _nóch, isvi
  { {0x6feb0050,0xda15009c,0xbbbf000b,0xda7802c8}},	// [290] jęci, едањ, _एकीक, дях_
  { {0x62770008,0x443e02c9,0xac950054,0x645802ca}},	//   וגמא_, _ott_, _заош, ksvi
  { {0xab5b00b8,0x6d5502cb,0x9f4b0003,0x2907001a}},	//   _blüt, maza, encé_, æna_
  { {0x6d5502cc,0xad1a0008,0x645802cd,0x7dd00123}},	//   laza, _מותר, dsvi, _väse
  { {0x46480010,0x6fc6002d,0x443e02ce,0xbb3a000f}},	//   дзін_, _dóch, _att_, _מערי
  { {0xdcee0007,0xb6320015,0x6d5502cf,0x6b8d02d0}},	//   gebė, دفوع, naza, leag
  { {0x26c9016f,0xd138005c,0x67d5004a,0xd6180015}},	//   šao_, dcą_, _зову, ذتها_
  { {0xa3d9005d,0x03790015,0x6b8d02d1,0xdc6c000a}},	//   डों_, سحبت_, neag, ק֣וֹ
  { {0x443e02d2,0x60160107,0x6d5502d3,0xa8020061}},	//   _ett_, náme, kaza, ğıta
  { {0xf1b10029,0x66e40054,0x6b8d0125,0x6d5502d4}},	//   اءة_, _рођа, heag, jaza
  { {0x672402d5,0x9f420046,0x657c0123,0x14740015}},	//   žijt, liké_, _örha, _لانج
  { {0x649a0008,0xd4360053,0x72d50004,0x644302d6}},	//   _מסעד, _טרעק_, _поеф, mpni
  { {0xe1ee0063,0x6d410064,0x3f9e0089,0x63ab0035}},	//   _бг_, ılan, ětu_, _ingn
  { {0x7bcf02d7,0x76590034,0x200b02d8,0x443e00d6}},	//   _alcu, iswy, alci_, _ytt_
  { {0xb0420023,0xc5f20008,0x6feb002a,0xdb860170}},	//   _trưở, אדם_, zęci, нгви
  { {0x212b0046,0x8b2602d9,0x9f990030,0x0000006a}},	//   ěchu_, едбе, _táás_,
  { {0xada602da,0x4d3a02db,0x7dd002dc,0x49ca02dd}},	// [2a0] _запл, _няня_, _väsb, план_
  { {0xdb0d0084,0x200200f2,0x0b170015,0x6d5e02de}},	//   rkað, loki_, رقلة_, _udpa
  { {0x7dcb0064,0x7c3e02df,0x7de50015,0x9f9a000a}},	//   _müsl, _utpr, _جسيم, ּסְפ
  { {0x2ca50134,0x601602e0,0xdc3b004f,0x2d9a0072}},	//   ælde_, lámb, _מעטר, _hape_
  { {0xdcee0007,0x569402e1,0x69d1003d,0x473300e2}},	//   tebė, талт, _ūdeņ, уніс
  { {0xab5b00b8,0x245a0024,0x443e02e2,0xc5d8002b}},	//   _flüs, tīm_, _ptt_, بوتص_
  { {0xc977000a,0x7d090046,0x6458008c,0x7a290091}},	//   _רגלי_, řesv, usvi, _užta
  { {0xf7530086,0x987b0053,0xd138005c,0xd90d002b}},	//   _منفج, _מאלט, wcą_, _بیم_
  { {0x9f42008c,0x249c0091,0x200202e3,0x290a01c0}},	//   inkä_, _žymė_, doki_, _hyba_
  { {0x91e30001,0x27e602e4,0x9aeb000a,0xaa77000a}},	//   лоње, lion_, לַיִ, עתיד_
  { {0xc32a0029,0xc05702e5,0x443e0024,0x6d5502e6}},	//   _فكان_, нія_, _utt_, vaza
  { {0xde590010,0xd65e005e,0x27e602e7,0xc7e6000a}},	//   мамі_, _вiдд, nion_, תוֹ֙_
  { {0x0e340080,0x6d5502e8,0xb7db000a,0xdb06006f}},	//   лняю, taza, לקטי, _poký
  { {0xbbc9005d,0x7d0302e9,0x27e60026,0xdb060064}},	//   रस्क, _ønsk, hion_, _dokü
  { {0x5ff50063,0x31370008,0xfc64006b,0x2137000a}},	//   _изку, _ארוך_, лътн, _אטול_
  { {0xfc30003b,0x6d5a002e,0x40eb000a,0x2cac0123}},	//   صحف_, ótar, _מַחֲ, ådda_
  { {0x27e602ea,0x6b8d02eb,0x6ffc000a,0x497502ec}},	// [2b0] dion_, reag, _מההפ, клас
  { {0x601602c1,0x22f7004f,0xd91b02ed,0x0000006a}},	//   ráme, תזמן_, пье_,
  { {0x27e60026,0x4ddc0008,0x6fc6016e,0x98480033}},	//   fion_, _מחזו, _sóci, еяча_
  { {0xbcb60008,0x76590026,0xfecb000a,0x27e6026e}},	//   _ספרו_, tswy, ּמַּ, gion_
  { {0xa3b4014e,0x601600dc,0x8bba000a,0x7e7d02ee}},	//   ञान_, lámc, _חזרת, ntsp
  { {0x85780063,0x7d090046,0xd5bb0174,0x7e9c000a}},	//   есът_, řesu, ясе_, פסוו
  { {0x27e60176,0xcd980008,0x02c9000b,0xd90f002b}},	//   bion_, גדות_, िन्न, _ایا_
  { {0x47340029,0xdc8c0008,0xe3b10029,0x644302ef}},	//   _مركز, לְחָ, شرب_, rpni
  { {0x7dd000c0,0x62720015,0xdb16008c,0x0ee00065}},	//   _läsa, لهيئ, shyö, _पेंड
  { {0x644302f0,0x10a502d9,0x7e7d01d0,0x0000006a}},	//   ppni, вион, dtsp,
  { {0x55ba000a,0x2d9a00da,0x200202f1,0x63ab02f2}},	//   _קמעו, _rape_, toki_, _tngn
  { {0x34b60008,0xe458005e,0x23e9002b,0xb4bf000b}},	//   _בפעם_, _їжі_, _غذای_, ुनी_
  { {0x66030020,0x2d9a02f3,0x200202f4,0x7e7d01d0}},	//   oonk, _pape_, roki_, gtsp
  { {0xd656000a,0x80e50015,0x27e602f5,0x200202f6}},	//   כישת_, _لأعل, zion_, soki_
  { {0x8d76002b,0x7e7d02f7,0x7dd00012,0x207501b0}},	//   _یادا, atsp, _cäsa, _рулё
  { {0x27e602f8,0x660302f9,0x290a02fa,0x2259005a}},	//   xion_, honk, _ryba_, šsku_
  { {0x3ae80074,0x2d9a02fb,0xf1b5000b,0x501b000a}},	// [2c0] ربری_, _tape_, _अचान, _קופו
  { {0xdcfc0024,0x2492005c,0xdb06002a,0xba17002b}},	//   ndrī, łymi_, _sokó, پيما_
  { {0xdcfc0024,0xdb06005c,0x27e602fc,0x8e3a002b}},	//   idrī, _pokó, tion_, _عسکر_
  { {0x6c57000a,0x4c79000a,0x0000006a,0x0000006a}},	//   _ביטא_, _אָשׁ,   ,
  { {0xa3ab014e,0x644102fd,0x7d090089,0x27e602fe}},	//   खाई_, _atli, řest, rion_
  { {0xdb06005c,0x27e602ff,0xd9430300,0xc8660015}},	//   _wokó, sion_, _вери, _لطري
  { {0x94730015,0x9f590030,0x27e60301,0x09e30302}},	//   لديا, őzés_, pion_, _торн
  { {0xb8f6005d,0xc274000d,0xdcfc0024,0xccf30008}},	//   िन_, глиј, edrī, יכו_
  { {0x877b0053,0x7791002b,0x2348002b,0x64410303}},	//   _קאמי, _دینا, وسکی_, _etli
  { {0x75d30086,0xc05a0033,0x64530030,0xf1a60189}},	//   _پيما, мім_, údió, трин
  { {0xc60e005d,0x799c0304,0x43860015,0xf957000a}},	//   ितीय_, _marw, _للاق, כסית_
  { {0x6d410064,0x9f4b0077,0x185b004c,0xd5fb0016}},	//   ılam, vocó_, וכטע, _trụ
  { {0x7ee4005e,0xf2d70015,0x2e4b02ed,0xdbdc0052}},	//   ацре, _لبوش_, ьяно_, _ráðn
  { {0x9a090033,0x3d95004a,0x2d8500bf,0x709a0015}},	//   аiне_, ыигр, ýle_, _ينشأ_
  { {0xf4140053,0x2ca5002e,0x61e80293,0xe7f3000b}},	//   ָפּ_, íld_, midl, _अदला_
  { {0x3ec7008f,0xef67010f,0xa3ab005d,0xc3340008}},	//   _асоб, _ръко, खाए_, רוּ_
  { {0x799c0305,0x5b1502c8,0x2009003d,0x6603007f}},	// [2d0] _barw, умат, _ikai_, yonk
  { {0xc27b0008,0x799c0034,0xdd910015,0x79d4005e}},	//   ורמי, _carw, _اود_, ажує
  { {0xa9280033,0x2d910306,0x60160307,0xd246002b}},	//   віце_, meze_, láma, _گن_
  { {0x1b4b0029,0x2d910011,0x58840033,0x6603002a}},	//   _تؤدي_, leze_, рыфа, wonk
  { {0x799c0026,0xd2460067,0x7bcd0308,0x6fdc000a}},	//   _farw, _دن_, mkau, וקאס
  { {0xca7a0053,0x2d910011,0x7bcb001a,0x7dd00309}},	//   _אנשט, neze_, öguf, _läsn
  { {0x6016002e,0xb4bf000b,0x20090030,0x61e801c0}},	//   háma, ुने_, _okai_, didl
  { {0xe2b90001,0x61e8003d,0xddc60091,0x6603030a}},	//   ећој_, eidl, iukš, sonk
  { {0xd179005e,0x56f50004,0x2fc0030b,0x87e4030c}},	//   нсні_, _спаѓ, _roig_, _тюре
  { {0xe5730031,0x46150015,0x2d910022,0x2d830079}},	//   _خطر_, _صوار, jeze_, jfje_
  { {0x7bcd00f2,0x43750002,0x41b40033,0x2d91030d}},	//   kkau, _مهار, рсыт, deze_
  { {0xbb1b0003,0x14da004c,0xeb9f02de,0x5275030e}},	//   _abîm, _אַדמ, _skøn_, _буку
  { {0xd5a7005e,0xd6cf005e,0xee37006b,0x61e80125}},	//   _пiдп, йтi_, лня_, bidl
  { {0x63bb030f,0x6da60054,0x61e80310,0x16db000b}},	//   ljun, ћива, cidl, _मेज़ब
  { {0xdca10036,0x6c360002,0x8fa601b7,0x6b9d0311}},	//   остi_, افرا, _байе, _basg
  { {0x6b9d0176,0x8cb5005d,0x7bcd0035,0xdb0f016e}},	//   _casg, _उपरो, gkau, _incê
  { {0xc332011f,0xa3b4005d,0x7fd7000a,0x4b55006b}},	// [2e0] מון_, ञात_, _תופס_, ръст
  { {0xfd4a0036,0x3c94002b,0x7bcd0312,0x63bb007c}},	//   _язок_, _پیرز, akau, hjun
  { {0xe4e3005d,0x63bb002e,0xa1560008,0x6b9d0034}},	//   _केलि_, kjun, רבעה_, _fasg
  { {0x6b9d0313,0x60330045,0x18670004,0x38670314}},	//   _gasg, _cămi, ѓачи_, ánra_
  { {0xb7d70002,0x63bb0315,0x799c0316,0x320501c0}},	//   دونا_, djun, _tarw, koly_
  { {0x99d60015,0xd49a0317,0x6b840318,0x09e602ed}},	//   _إتحا, ери_, lfig, _согн
  { {0x61e80107,0x3957000a,0xdb1d00e9,0x8898000a}},	//   vidl, _תשלם_, _rosé, _בֹּה
  { {0x2d910319,0x6f09002a,0x7dcb0061,0xfdd1000b}},	//   zeze_, żeci, _püsk, _हत्फ
  { {0xd130003b,0xdb0f0003,0xdb1d00e9,0x6b84031a}},	//   يمة_, _ancê, _posé, ifig
  { {0xfa970053,0x2d910011,0xda7b0053,0x82330015}},	//   נדיש_, xeze_, עניר, حريا
  { {0xe4750010,0x3386006b,0xa0730033,0x2d91031b}},	//   _вучэ, _булв, быўш, veze_
  { {0x2d91003f,0xb4fb0008,0x8f4702bf,0x7cf20030}},	//   weze_, _אלבר, ыход, zűré
  { {0x61e8031c,0x2d91031d,0x60da0030,0x1eab0015}},	//   pidl, teze_, sztm, راحي_
  { {0x7dcb0005,0x6016002d,0x6aa90085,0x2327031e}},	//   _küsi, ráma, _šefo, _сочи_
  { {0xa1570008,0xd13f005c,0x75370053,0x2d91031f}},	//   _גבוה_, łącz_, ראלד_, reze_
  { {0x2d910320,0x7bcd0321,0x9ee90015,0xcc170015}},	//   seze_, ukau, _لفعل_, اذسب
  { {0x6b9d00dd,0xb955006b,0x15f6000b,0x63bd0123}},	// [2f0] _vasg, иващ, ेवार_, ösni
  { {0x6b9d0034,0x7bcd0322,0x0000006a,0x0000006a}},	//   _wasg, skau,   ,
  { {0x6b9d0034,0xdd15002b,0x47350323,0x61ef0324}},	//   _tasg, _خودخ, анес, écli
  { {0xf77300e6,0xd6d10115,0x6b9d0125,0x3ea90325}},	//   صاص_, يقا_, _uasg, _krat_
  { {0x9f820079,0x9f4c0030,0x29180326,0x07b60058}},	//   _zóó_, élék_, _ezra_, شهوة_
  { {0x4ade014e,0xb5fd0089,0x5e580053,0x2e3c004c}},	//   _नेटव, _ovše, ריגע_, עגונ
  { {0xb4650086,0xdb0600dc,0xf8ae002b,0x5d9c000a}},	//   شگاه, _inká, _يکم_, גבוה
  { {0xea010092,0xd26501b7,0x63bb0327,0x62650328}},	//   _đẹp_, акий, ujun, авиа
  { {0xd7f80329,0x63bb032a,0xe3b60174,0xeab7000a}},	//   _сур_, rjun, рбы_, רִ֔י_
  { {0xfa98004c,0x6ff2003d,0x7dcb007c,0x98a10061}},	//   רדזש_, māci, _füsi, lahı_
  { {0xf9920008,0x6ff20024,0x7dd000c0,0x63bb0091}},	//   חרי_, lāci, _säso, pjun
  { {0x0876004c,0xf1d9000b,0xdfcf0015,0xa3ab000b}},	//   סערט_, योजन, ِيَ_, खाओ_
  { {0x6ff20024,0x94040086,0x3205032b,0x0efa0138}},	//   nāci, _اونه, poly_, тэны_
  { {0xc5f20053,0x69c30061,0xd24e0015,0x8e0701c5}},	//   ַדן_, önel, _غنى_, иняв_
  { {0x2d9e032c,0xa3cc005d,0x442f0134,0xc0a80018}},	//   ľte_, _रकम_, _kig_, _مايل_
  { {0x6ff20048,0x2d9e0107,0xaec6005e,0x81140067}},	//   kāci, žte_, _вбил, _اذها
  { {0x601600dc,0x3e7f0045,0x99e60033,0xeb97013e}},	// [300] lámo, cît_, ажад, шит_
  { {0xae5b000a,0xdb1d0030,0x6ff2003d,0xe9d7032d}},	//   _שכיר, _alsó, dāci, аку_
  { {0xd9100086,0x6d4e00dc,0x6fcd0003,0x290e001a}},	//   سیر_, mbba, _bûch, æfa_
  { {0xc60e000b,0x60160030,0x684300fd,0x3cfb000a}},	//   ित्य_, zámn, інча, _ילינ
  { {0x7f3b0053,0xeb970063,0x6ff20024,0x3c3c00dc}},	//   דענו, _тия_, gāci, _hív_
  { {0x7dcb0020,0x6594000d,0x0466032e,0xf48a004a}},	//   _püsi, саку, атим, вщик_
  { {0x601d0152,0x442f032f,0xe006000b,0xfbd2000a}},	//   léme, _big_, रवाद_, ַת֙_
  { {0xdc370053,0x442f0026,0x395800ea,0x889b000a}},	//   סאפט_, _cig_, _hers_, _בבלי
  { {0x442f0330,0x601d0152,0xd80b000a,0x6d5c0331}},	//   _dig_, néme, _יִמָ, kara
  { {0x867b000a,0x6d5c0332,0x91b80004,0x60330045}},	//   _ברמו, jara, угот_, _lămu
  { {0xdfd10029,0x54730029,0xb937000a,0x225f013c}},	//   كيد_, _وهكذ, יניו_, asuk_
  { {0x3ea90333,0x644a0334,0x442f0335,0xb7bd0045}},	//   _prat_, mpfi, _gig_, _fiţu
  { {0x6d5c0336,0x7c2f02b9,0xa2d30015,0x32b70015}},	//   fara, _ricr, _ويمت, _ندوة_
  { {0x7c2f0176,0x3f550092,0xf2db000a,0x6d5c0337}},	//   _sicr, ấu_, _שַׁל, gara
  { {0x6ff20048,0x61ef0152,0x91bb000a,0x621b000a}},	//   zāci, ècle, _במגי, _שווק
  { {0x3ea900b8,0x6029005c,0xc1780091,0xcbf80015}},	//   _trat_, _ośmi, lgė_, لرقص_
  { {0xba550029,0x6d5c0338,0x6d570339,0x69d5033a}},	// [310] صناع, bara, _texa, _plze
  { {0xe29f0084,0xc1780007,0x6d990080,0xad27002b}},	//   æði_, ngė_, _своё_, _پرخو
  { {0xf7730021,0x9f420046,0x3958033b,0xdce50061}},	//   قاش_, liká_, _ders_, _tahı
  { {0x395800dd,0x6ff20024,0xbb94004a,0x7c240045}},	//   _eers_, tāci, _дающ, cmir
  { {0x601600dc,0xb6a50036,0x442f014c,0xfbb6000a}},	//   zámo, силл, _rig_, _הפרת_
  { {0x6ff20048,0xe578005e,0x442f033c,0x0608008b}},	//   rāci, изі_, _sig_, анік_
  { {0xe3b10029,0x6ff2003d,0xd466033d,0x442f033e}},	//   كرة_, sāci, бище_, _pig_
  { {0x1bf9005d,0x225f0030,0x39410012,0xc4f80015}},	//   ्किल_, tsuk_, lchs_, جعها_
  { {0xa5670086,0xfbb80008,0x36d4033f,0xeb92000a}},	//   _ندان, שפחת_, _дотр, פָה_
  { {0x7c240340,0xd6280054,0x6d5c0341,0xd1990342}},	//   zmir, _вође_, xara, утич_
  { {0x225f00dc,0x442f002d,0x1bf9000b,0x39410012}},	//   ssuk_, _tig_, ्काल_, ichs_
  { {0xcdc9013a,0x6d5c0343,0x672d0085,0x60160344}},	//   _אך_, wara, žaju, rámo
  { {0x1e830010,0xdb240064,0x539a000a,0x6d5c0332}},	//   плям, üsün, _תינו, tara
  { {0x32b8003b,0x7dd000f2,0xd1b8002b,0x229a000a}},	//   _خدمة_, _täsm, _پاها_, _תֹאמ
  { {0x2fd70074,0x8c460345,0x91ba000a,0x1c39004a}},	//   _گويد_, себе, _תמצי, иять_
  { {0x6bb50036,0xa3ca005d,0x9f82002e,0x7dd00209}},	//   осує, रॉप_, _góð_, _käsk
  { {0x09360029,0x39580346,0x7c240347,0x6d5c0348}},	// [320] مراج, _pers_, rmir, para
  { {0x60160014,0x601d0152,0x8d560001,0x2489002a}},	//   záml, réme, _утич, łamy_
  { {0x88860080,0x601d0152,0x39580349,0xfbd200e5}},	//   слеж, séme, _vers_, _فتح_
  { {0xca29000a,0xc8850061,0x39580034,0x872601c6}},	//   גם_, daşı_, _wers_, бмеж
  { {0xe5c6034a,0x39580061,0x6d410061,0xada9002b}},	//   йско, _ters_, ılav, _صدیق_
  { {0xa3ca005d,0xa5f80054,0x7bc6034b,0x0000006a}},	//   रॉन_, јеку_, _hoku,
  { {0xe9d70286,0x66d10030,0x54a60015,0x2246034c}},	//   _укр_, tókö, إحتف, _stok_
  { {0xebd6000a,0x7dcb0072,0x0000006a,0x0000006a}},	//   מֵ֥י_, _hüst,   ,
  { {0x7ae90084,0x6029005c,0x7dcb034d,0x32ba0015}},	//   _þett, _uśmi, _küst, ادعة_
  { {0xba9b0008,0xdcfc0024,0x104a034e,0x7bc6034f}},	//   נסיי, nerē, лями_, _loku
  { {0xe4520002,0x672d00bc,0xdb1d0069,0x5f950350}},	//   _رضا_, žajt, _rosí, оинт
  { {0x601600dc,0x7bc600dd,0xb4d4000b,0x9f42006f}},	//   lámj, _noku, हनी_, tiká_
  { {0xdb1d02d5,0x93a90015,0xd80b000a,0x5f94006b}},	//   _posí, _خالف_, רִיָ, чият
  { {0x270700a7,0xc27b0008,0x63a20125,0x7e640351}},	//   ống_, _תרגי, _haon, _dvip
  { {0xb1e50029,0x7a290007,0xdcfc0024,0x853b00a3}},	//   _بأنه, _užti, derē, רגלי
  { {0x4a550010,0xd0f7000a,0x7c15005e,0x27370046}},	//   жкас, _למות_, ідає, ižní_
  { {0x63a2000c,0x39410152,0x7a570015,0x200b01df}},	// [330] _maon, tchs_, إضرا, moci_
  { {0x531b004c,0x39a70054,0x39410012,0x9faf0046}},	//   רומצ, љшав, uchs_, iří_
  { {0x8d5a000a,0xdcf5003d,0x60160030,0xb8950015}},	//   _דכתי, iezī, zámm, تلاع
  { {0x61c5014e,0xc8850064,0xb6c50015,0x907b000a}},	//   _लक्ष, vaşı_, يْضً, רטאי
  { {0x4ae40010,0xb5fd0227,0x8f8c000a,0xef12000a}},	//   _еўра, _avša, רְבֵ, ֵּד_
  { {0x96280029,0x3e5c0053,0xdcfc0024,0x7bc600aa}},	//   مكنك_, נדוס, cerē, _zoku
  { {0xdb060123,0x7bc60352,0x05760058,0xb4b60058}},	//   _enkä, _yoku, زمية_, قُوا_
  { {0x04560015,0x77d70015,0xc245030e,0x7dcb0353}},	//   آلية_, _اغسط, оник, _küss
  { {0x69c7010b,0x63a2002d,0x85b90354,0x200b0085}},	//   _koje, _daon, _клас_, doci_
  { {0x7dcb018b,0x91e50036,0xd24e002b,0x80650355}},	//   _müss, іоне, کنی_, овож
  { {0x7e64002e,0x8c430064,0xcea9000a,0x7649008c}},	//   _svip, üşle, _שי_, _htey
  { {0x200b0251,0x24650024,0x187a000a,0xcfd30015}},	//   goci_, mēm_, סטרב, ِيَة
  { {0xa294009e,0x24650024,0x68e1007c,0xa3b8002b}},	//   _наці, lēm_, _üldf, _دالر_
  { {0x7dd00356,0xe29f002e,0xa2040036,0x63a2003f}},	//   _käsi, æðu_, _епід, _zaon
  { {0x7bc60357,0x63a20358,0x60160057,0x7dcb0359}},	//   _poku, _yaon, námk, _rüst
  { {0x7dcb0005,0xb0680087,0x1b4a000d,0x7769035a}},	//   _süst, _اصول_, рзаи_, _ndex
  { {0x7dcb0020,0x7e64003f,0xda650029,0x39ea0001}},	// [340] _püst, _uvip, كالي, адао_
  { {0xfd120029,0xba170021,0x6e93002b,0x7bc6035b}},	//   _يجد_, قيقا_, _کلیا, _woku
  { {0x764902f2,0x291c0123,0xd7c6004a,0xa3ca000b}},	//   _atey, åva_, жёло, रॉड_
  { {0x510c00b4,0x24650024,0xddcd005c,0x2d98035c}},	//   נהאַ, dēm_, _gwał, lere_
  { {0xd5ba005f,0x63a20251,0x601d0003,0x98bf003d}},	//   иск_, _raon, néma, ērām_
  { {0xe452003b,0x2d98035d,0x63a2035e,0x69c7035f}},	//   وضع_, nere_, _saon, _goje
  { {0x2609005d,0xb4d4000b,0xd64b005e,0xf7460004}},	//   ाक़ी_, हने_, _дiял, _мево
  { {0x98ba00df,0x2d980360,0x9faf0089,0x32660361}},	//   lapį_, here_, tří_, отов
  { {0xa2940010,0x7e600045,0x2d980362,0x200b0363}},	//   чапі, âmpl, kere_, voci_
  { {0x601d0152,0x2d980364,0xb97a000a,0xcb13000a}},	//   déma, jere_, ׁנִי, ולח_
  { {0x63a20365,0x2d980366,0x2465003d,0x3ea00061}},	//   _taon, dere_, cēm_, _asit_
  { {0x8c430061,0x7a290091,0x289b004f,0xb4250058}},	//   üşme, _užtv, ביטא, _فعنو
  { {0x57fb000a,0x2d980367,0x200b0368,0x41e60369}},	//   שלכו, fere_, roci_, _وستف
  { {0xddcf0011,0x2d98036a,0x68e1007c,0x2a720034}},	//   ducţ, gere_, _üldg, dryb_
  { {0xa1770008,0xa8020064,0xfbd30115,0x69c7036b}},	//   _ועוד_, şıya, وتر_, _roje
  { {0xa0080015,0x320c036c,0x69c7036d,0x7dcb007c}},	//   _وقول_, lody_, _soje, _püss
  { {0x539b0008,0x24650024,0x69c7036e,0x8f88000a}},	// [350] סימו, zēm_, _poje, _וְתֵ
  { {0x7a38005e,0x2d98036f,0x61fa0012,0xc237000a}},	//   цпфр_, cere_, nntl, קרבו_
  { {0xdb1d0089,0x69c70057,0x61fa01f1,0x26cf0034}},	//   _dosá, _voje, intl, wygo_
  { {0x69c70050,0x4c9a0008,0x320c0370,0x3f990371}},	//   _woje, _פברו, hody_, nesu_
  { {0x9bba0008,0x320c002a,0x501c000a,0x3bba000a}},	//   _הצרפ, kody_, בואו, _המרד
  { {0x53a30372,0x85e80036,0x24650024,0x27ef0373}},	//   _खोजश, одів_, tēm_, sign_
  { {0xf7730067,0xd5ae0015,0x94790033,0xed58004f}},	//   _يار_, طفي_, ёску_, חבור_
  { {0x3cfc0135,0xe4d20015,0x2cfc000a,0x6cfc000a}},	//   ילונ, عقيد, ילוא, יפוס
  { {0x2d98003c,0x24650024,0xa2630092,0x6d5a002e}},	//   yere_, sēm_, _giố, ðtak
  { {0x320c005c,0x2465003d,0x2d980374,0x42220138}},	//   gody_, pēm_, xere_, ндыв
  { {0x601602c1,0x224d0375,0x27ed0046,0xa0690054}},	//   lámi, spek_, _kmen_, љама_
  { {0xd8d60008,0x224d00dc,0x25a50376,0x351a000a}},	//   פורט_, ppek_, _hall_, _הוענ
  { {0x320c0377,0x60160378,0x1719000a,0x25a50379}},	//   body_, námi, מוֹע, _kall_
  { {0x7bcb002e,0xd1bb0015,0x44d70016,0x6fe40030}},	//   ögun, _خاصا_, õ_, tőcs
  { {0x81bc0024,0x71d6000a,0x61d6000a,0x91ba000a}},	//   kmēj, _מוסד_, _מוסף_, _למסי
  { {0x63760064,0x2d98037a,0xd12e0015,0x9e6600d7}},	//   münü, sere_, _حمى_, _евид
  { {0x6d4101e2,0x63760064,0xba1a0015,0x8f7b000a}},	// [360] ılar, lünü, ميرا_, _הנפק
  { {0xddcf0011,0x2a6f0030,0x8d56004a,0xdb04037b}},	//   rucţ, ágba_, _этич, ndié
  { {0x6d5e0048,0x63760064,0x5d3b000a,0x7d57000a}},	//   _iepa, nünü, _לתיא, _מייד_
  { {0x1cbb000a,0xf1ba0016,0x7bdf01f1,0x320c037c}},	//   _המטע, _nhơn_, chqu, zody_
  { {0x44d70092,0x6d5e0375,0x25a5037d,0xbddb0003}},	//   ẽ_, _kepa, _ball_, mpèr
  { {0x6d5e00e8,0x25a5037e,0x2b470046,0xdb1d02de}},	//   _jepa, _call_, ěnce_, _bosæ
  { {0x25a502d7,0x320c0107,0x39130033,0x0000006a}},	//   _dall_, vody_, _змёр,
  { {0x320c005c,0x6d5e0375,0x78fb000a,0x5334004a}},	//   wody_, _lepa, _הפלו, мейт
  { {0x44d70092,0x320c037f,0x25a50380,0x8506002b}},	//   ã_, tody_, _fall_, _کوان
  { {0x6720010b,0x2003010b,0x7dd00020,0x7ae40381}},	//   _izmj, čkim_, _käsu, izit
  { {0x63760064,0x99de0033,0x9316002b,0x9f990382}},	//   günü, нiка_, _کوشش, овну_
  { {0x6720005d,0xc43b0008,0x68e1007c,0x2d810383}},	//   _बराक_, _התאי, _ülde, _sche_
  { {0xb80d014e,0xe80d005d,0x6d5e0384,0x7c3e0152}},	//   िकतम_, िकता_, _bepa, _aupr
  { {0x3f990026,0x224b002c,0x7ae4002c,0x6d5e0049}},	//   sesu_, ícke_, dzit, _cepa
  { {0x7c3e0011,0x3f990020,0x63760061,0x9f4b0046}},	//   _cupr, pesu_, cünü, licí_
  { {0xec340036,0xd0110002,0x69dc0385,0x30830015}},	//   енсь, _جلب_, _alre, _أليف
  { {0x25ed005d,0x5a3500ff,0x9f4b0046,0x5e440015}},	// [370] _अगली_, днат, nicí_, _كَيْ
  { {0x11590053,0x443e0386,0x9d55002b,0x44d70016}},	//   ַדױע, _out_, _تندت, ỹ_
  { {0x99d40015,0x7c670002,0x718b000a,0xdb0d007c}},	//   رتكا, _عادل, מְאַ, ljaü
  { {0x69dc00dc,0x98170015,0x3789005e,0x2d840030}},	//   _elre, أبطا, ібло_, őmet_
  { {0x81bc0024,0x999f00dc,0xf7700031,0x63760061}},	//   rmēj, őről_, طان_, zünü
  { {0xf650003b,0x443e003e,0x6d47005c,0x60160387}},	//   ائن_, _but_, ncja, rámi
  { {0x98170029,0x64a20063,0x443e0388,0x25a50389}},	//   _فبرا, ваща, _cut_, _vall_
  { {0x74150087,0x04b40010,0x7dd0038a,0x25a50116}},	//   بوعا, эсія, _häst, _wall_
  { {0x443e0152,0x6d47005c,0x25a5038b,0x7dd0038c}},	//   _eut_, kcja, _tall_, _käst
  { {0x443e038d,0x63760064,0xc5fb0029,0xdb040012}},	//   _fut_, tünü, _اعرض_, heiß
  { {0x7bdd0064,0x6563038e,0x443e0334,0x260a000b}},	//   _olsu, manh, _gut_, िवरी_
  { {0x637601e2,0x7bcb0084,0x27fd0034,0x7dd0038f}},	//   rünü, ögul, nnwn_, _läst
  { {0x2e2400b8,0x7dcb00dc,0x63760061,0x7c3e0390}},	//   höfe_, _püsp, sünü, _supr
  { {0x7dd001d1,0xf2d2000a,0x3f5c0016,0x12e8000a}},	//   _näst, _בעד_, ậu_, _מַצּ
  { {0x62890391,0x3178002a,0x4cb70033,0x63a90392}},	//   lteo, órze_, млёю_, oden
  { {0x7bc4003f,0x305a000a,0xab7a0015,0x6289008c}},	//   ujiu, _ודקד, تمرا_, oteo
  { {0x7dd000c0,0xde1a0029,0x6d5e013c,0x62890393}},	// [380] _bäst, _وقعت_, _tepa, nteo
  { {0x63a900f2,0x673b0394,0x62890395,0xbddb00e9}},	//   hden, _aguj, iteo, spèr
  { {0xd7ef0396,0xd910002b,0x9f4b0046,0xb8650015}},	//   ву_, ایز_, zicí_, فانو
  { {0xf98900b2,0x38cb002b,0x63a90397,0xdb1d0123}},	//   יר_, غالی_, jden, _bosä
  { {0x443e0176,0x7dd000c0,0x77910086,0x96b70054}},	//   _sut_, _fäst, طیلا, дују_
  { {0x443e0398,0x69c30399,0x63a9039a,0x7dd0039b}},	//   _put_, önet, eden, _gäst
  { {0x97be0010,0xa4d80036,0x6feb005c,0x78450007}},	//   _краi, ядку_, ręcz, _tėva
  { {0x7a290007,0x60080061,0xd499005e,0xf3ca0015}},	//   _užtr, nımd, ярі_, تبته_
  { {0xa80201e2,0x443e0012,0x6563016e,0xcb89000a}},	//   ğıda, _wut_, banh, פְקֹ
  { {0x7abb0008,0x05760021,0x63a9039c,0x9f4b0125}},	//   קציו, _زائد, aden, ricí_
  { {0x7dd000b8,0x653b000a,0xc057022a,0x60080061}},	//   _läss, _ועבד, мія_, kımd
  { {0x601d0152,0x2918039d,0xb4aa0065,0xd25a009b}},	//   rémo, _myra_, गटी_, _дцк_
  { {0x03d7039e,0x5e84018d,0x6289039f,0x6008007f}},	//   _קודם_, курз, cteo, dımd
  { {0xd337000a,0xdb040012,0x160e0065,0x02ca0065}},	//   _חרדה_, weiß, ाकिर_, िहीन
  { {0x2bbb0029,0x2ba7000d,0xab950001,0x2d870064}},	//   يارة_, мјав, нављ, _önem_
  { {0xe451000a,0x8b5b0015,0x6e2003a0,0x0000006a}},	//   רֶם_, تجسس_, ïmbr,
  { {0x160e005d,0xdb040012,0x6d47002a,0x6b8d03a1}},	// [390] ाकार_, reiß, pcja, rfag
  { {0xdeb60008,0x442603a2,0x63a903a3,0xf9930021}},	//   _נפתח_, _lho_, zden, ضبط_
  { {0x7dd003a4,0xd7590015,0x5dc8000a,0x60080061}},	//   _väst, كلات_, _חֶרְ, bımd
  { {0x44260092,0xe758005e,0x9cd6000a,0xb7940054}},	//   _nho_, диці_, _נורה_, вршћ
  { {0xda670074,0x2003010b,0x7dd0022d,0x6563001c}},	//   _تاجي, čkih_, _täst, tanh
  { {0x291800c0,0xd1260015,0xd5f30033,0x7c2d03a5}},	//   _fyra_, _مم_, _лiнг, lmar
  { {0xfc46002c,0x683a0089,0x656303a6,0x23d503a7}},	//   žíva_, _vůdc, ranh, ецпр
  { {0x442600a7,0xa3ca000b,0xe8940033,0xad38000a}},	//   _cho_, रॉल_, _шась, ונוס_
  { {0x6563001c,0x46580029,0x66f3021e,0xe7300015}},	//   panh, _يؤكد_, _अधिक_, _نصك_
  { {0x7e7d0020,0x7582002b,0xc5170015,0x60e903a8}},	//   dusp, _میهم, _قبضت, змом_
  { {0x94a803a9,0x7c2d03aa,0x60160030,0x9f4b0144}},	//   _отца_, kmar, zámu, ficà_
  { {0x2a690020,0x644103ab,0xb4db000b,0x93940015}},	//   ksab_, _iuli, डनी_, _لجها
  { {0x644103ac,0x201e0024,0x7e7d0171,0x81d503ad}},	//   _huli, ēti_, gusp, _подх
  { {0x270e0023,0x64410278,0xa2f6000a,0xdca603ae}},	//   ộng_, _kuli, _אמנה_, наги
  { {0x656103af,0x644103b0,0xfce603b1,0x442d03b2}},	//   _melh, _juli, хово, ome_
  { {0xf0620063,0x442d0064,0x7c2d03b3,0x644103b4}},	//   _скъп, nme_, gmar, _muli
  { {0x160f014e,0x291e010b,0x442d03b5,0x4c350033}},	// [3a0] िवार_, _šta_, ime_, тэрт
  { {0xdb0602d5,0x442d03b6,0x5e570053,0xd23a004c}},	//   _jaké, hme_, _רייע_, פגעל
  { {0x644103b7,0x7c2d03b8,0x442d03b9,0x7dd00012}},	//   _nuli, bmar, kme_, _wäss
  { {0x7dd0022d,0xe8530086,0x3f820375,0x69c303ba}},	//   _täss, انند, ngku_, öner
  { {0xceb30008,0x442d03bb,0xeb3b000a,0x601603bc}},	//   ָיו_, dme_, _מעכש, láms
  { {0x9916008f,0x7a8b000a,0x442d03bd,0x86230342}},	//   _зьбі, _מָלַ, eme_, льще
  { {0xdcfc0048,0xb7960001,0xd49703be,0x44260016}},	//   derī, _праћ, еры_, _pho_
  { {0x442d03bf,0x68e1007c,0x6561007c,0x9f4b0144}},	//   gme_, _ülda, _eelh, xicà_
  { {0x656103c0,0x179b0053,0x23270054,0x316503c1}},	//   _felh, _צימב, ноћи_, falz_
  { {0x442603c2,0x7e7d0020,0x442d03c3,0x96a70033}},	//   _who_, vusp, ame_, _якуб_
  { {0x33d60191,0xf9930008,0xdfd103c4,0x09f7000a}},	//   _підт, ארת_, ليد_, תמים_
  { {0x04db0008,0x442d002d,0xa2e603c5,0x9f4b016e}},	//   _מקבל, cme_, _поед, ficá_
  { {0x9f4b0251,0x0cc9000b,0xa3d5000b,0xb3e9002b}},	//   ricà_, रह्म, _सकत_, _تعلل_
  { {0x2d850064,0x69ce03c6,0x3f710016,0x7afb0085}},	//   üle_, _nobe, ễu_, _žuto
  { {0x246c0046,0xac1903c7,0x0217000a,0xe1330033}},	//   něm_, дову_, _רחום_, _йншы
  { {0x7c2d03c8,0xdb060030,0x7e7d02f2,0xf0b7004f}},	//   umar, _zaké, pusp, _טלור_
  { {0x9f4b0020,0x7c2d03c9,0x9963006f,0xda7803ca}},	// [3b0] öjõu_, rmar, ríži_, еях_
  { {0x4efc000a,0x601d0046,0x69ce03cb,0x7c2d03cc}},	//   _מהחו, kémk, _cobe, smar
  { {0xe3c301e2,0x99840029,0x69ce03cd,0xfe36000a}},	//   ngıç_, المو, _dobe, _שרתי_
  { {0x65610089,0x6441003e,0x96f9004a,0x58b80015}},	//   _selh, _ruli, меет_, عالج_
  { {0xe72e0001,0xb6a50080,0xe7e2000b,0x85b8002b}},	//   ре_, тилл, _खतरा_, کانس_
  { {0x69ce03ce,0x7b070045,0x644103cf,0x0000006a}},	//   _gobe, ăptă, _puli,
  { {0x656103d0,0xd61800e6,0xdb060030,0x442d03d1}},	//   _velh, رتها_, _raké, tme_
  { {0x7bcf0011,0x14190015,0x4cbc000a,0x656103d2}},	//   _jocu, بيعة_, למוג, _welh
  { {0x69d80014,0x13090191,0x442d03d3,0x656103d4}},	//   öveg, ьний_, rme_, _telh
  { {0x7bcf03d5,0x644103d6,0xb5fd006f,0x442d03d7}},	//   _locu, _tuli, _ovši, sme_
  { {0xdb1d002f,0xf8e1005d,0xc0580010,0x80cb000b}},	//   _cosú, पनिय, ніў_, ाहें
  { {0x13a70086,0x60080064,0x31650012,0x0000006a}},	//   _سنتی_, dımc, salz_,
  { {0x3f8c005c,0x69c4005d,0xdb06002c,0x73c40015}},	//   ędu_, रामी, _také, _حينم
  { {0x82760053,0x63ab002e,0xd24e0015,0x867a000a}},	//   _יענע_, _hagn, _بنو_, ורשו
  { {0xa3d5005d,0xa0a50036,0x40940010,0xe588000a}},	//   _सका_, _райд, _брыт, עָשָ
  { {0x7ff60086,0xd00f00e6,0xddcd002a,0x79950012}},	//   _جستا, _ولو_, _kwaś, _abzw
  { {0xe7f7005d,0xd9460001,0x69ce03d8,0x78b5003d}},	// [3c0] ूचना_, вези, _pobe, _arzv
  { {0xdb0d002e,0xbd460029,0x7e600045,0x3856006b}},	//   rjað, _جندي, âmpu, въдс
  { {0xfeba0086,0x7bcf00d1,0x8ddb000a,0x81bc003d}},	//   _راکت_, _focu, _חקיק, mmēt
  { {0xd7ef0029,0x27e003d9,0x69ce03da,0x63ab03db}},	//   يكل_, óin_, _wobe, _nagn
  { {0xe7f3000b,0x34da000b,0x68e1007c,0x200203dc}},	//   _आगरा_, बन्द, _üldn, inki_
  { {0xa6130010,0x69d80030,0x8b0b004f,0x6b840072}},	//   аміч, öved, _חִלֵ, lgig
  { {0x44a30029,0x02ca000b,0x3545005e,0x9f42006f}},	//   لموق, िह्न, ухів, ahké_
  { {0x60160030,0x7174002b,0x601d0046,0x9f650030}},	//   zámr, گهدا, rémk, étük_
  { {0x41e60010,0x8c1b000a,0x81bc003d,0x99830091}},	//   віна, ווקי, kmēt, _gijų_
  { {0x60080064,0xdb1d002c,0xd657000a,0x7d090061}},	//   yımc, _posú, _סיבת_, şesi
  { {0xb97b013a,0x161b000b,0x897b000a,0x30a3006b}},	//   וניי, _पीटर_, וריצ, аряв
  { {0x63ab03dd,0x14d7000a,0xe3c30061,0x5436006e}},	//   _gagn, _שואל_, rgıç_, _شرار
  { {0xd336008f,0xd2500029,0xf8bf000b,0xa19403de}},	//   _рэжы, _انت_, _एप्प, _балч
  { {0x63ab03df,0xe0d20015,0x6b84007c,0x91e30054}},	//   _zagn, _نزع_, egig, _воље
  { {0x7dcb00dc,0xa3d6000b,0x9f420046,0xfe6e002b}},	//   _küsz, _हवा_, liký_, يگی_
  { {0x313700f3,0x60080061,0x3ed5012c,0x7b770040}},	//   _ברוך_, rımc, _مقبر, ضطرا
  { {0xfc300015,0x63a0002a,0x3b64006b,0xbbd3000b}},	// [3d0] زحف_, iemn, ръсв, _सवीक
  { {0x601d03e0,0x6b8402f2,0x60080061,0x60160077}},	//   démi, agig, pımc, lámp
  { {0xf1ba0092,0xf7750127,0x628003e1,0xec6b0033}},	//   _chơi_, гулю, humo, _ўрок_
  { {0xf09300b2,0x2e24002e,0x628003e2,0xf7700015}},	//   ינע_, nöfn_, kumo, قاه_
  { {0x62800024,0x60080064,0xdb7a000a,0x35d5004a}},	//   jumo, nıma, _אנרכ, лодё
  { {0x16a603e3,0x68e1007c,0x27e602f2,0x2e24001a}},	//   увши_, _üldo, ahon_, höfn_
  { {0x478b0001,0x63ab03e4,0xcd98000f,0x2002002a}},	//   _осам_, _pagn, דדות_, ynki_
  { {0x3d3c0008,0x24960086,0x3ea900f2,0xe3b10015}},	//   וגוס, انيد_, _osat_, صرب_
  { {0x62800007,0x7c3d03e5,0x63ab03e6,0x92b50021}},	//   gumo, _misr, _vagn, احبا
  { {0xb0ae005d,0x55bb0015,0x3f890034,0x00c9004a}},	//   टिंग, _تطرح_, _acau_, елок_
  { {0x228b003c,0xf4840010,0x70520086,0x88f6000a}},	//   søk_, _вучн, ینیا, ָ֖יו_
  { {0x5f760086,0xdb0d0020,0x653a004c,0x92b5012c}},	//   دادر, ljaõ, _װענד, _محتا
  { {0xfeba002b,0x7f19005e,0xe2990033,0x3ea90045}},	//   راحت_, віру_, _чал_, _csat_
  { {0xc332000a,0xd24e0015,0xdb1d01f6,0x5d760138}},	//   _הוד_, _عنى_, _insè, ыумф
  { {0x3ea90048,0x81bc0024,0xeb9a03e7,0xfce303e8}},	//   _esat_, rmēt, нив_, боро
  { {0x81bc03e9,0x5f76006e,0xfaa603ea,0xa09a004f}},	//   smēt, _صابر, лабо, _נספח
  { {0xac070080,0x7c3d003e,0xda650029,0xfe72002b}},	// [3e0] унта_, _disr, لالي, _ادب_
  { {0xd6c40086,0x7a22002c,0x69c4000b,0x443d0034}},	//   یمای, rôto, राधी, _liw_
  { {0x81bc03eb,0x68e1007c,0x8e37000a,0xcb6a03ec}},	//   slēg, _üldl, _תניא_, _пане_
  { {0x4b550063,0xd70a004a,0x48060033,0x81bc003d}},	//   _върт, ннее_, ыпев, nmēr
  { {0xcc3b0053,0xddc400bd,0x6d5c03ed,0x25ac0046}},	//   _רעכט, _zviš, obra, _padl_
  { {0xe9df002f,0x86750010,0x7d1e01be,0x6d5c03ee}},	//   _dtús_, рыцц, _kyps, nbra
  { {0xe0c703ef,0x601d0003,0x2a07027a,0x27e603f0}},	//   _از_, sémi, _серп_, phon_
  { {0xc27403f1,0xb908021e,0x75240046,0x443d0034}},	//   алиј, यन_, řizo, _ciw_
  { {0xfbd30008,0x26c200bc,0x37060151,0x63a003f2}},	//   מתה_, _škof_, _спаг, remn
  { {0xe6170010,0x81bc0024,0x63a003f3,0x569b000a}},	//   _бду_, emēr, semn, _אימצ
  { {0x43860086,0xe97b0053,0xb97b0053,0x5a17000a}},	//   _ملاق, ענטש, ענטי, רקין_
  { {0x75280048,0x273a0064,0x8937004c,0x75250012}},	//   _izdz, _günü_, טריע_, ühze
  { {0x7a2b0353,0x7413009a,0x6d5c02ad,0x0000006a}},	//   lüte, _اونا, fbra,
  { {0xf1a3006b,0xc333004c,0x81bc003d,0x2e24001a}},	//   _грън, _פוס_, rmēs, söfn_
  { {0x721b0008,0xdb1d0152,0x55bb000a,0x61fa03f4}},	//   _רווח, _insé, עמלו, mitl
  { {0x81bc0024,0x3b55000d,0xa4e7000a,0x3c440033}},	//   slēd, ркар, רֵךְ_, сэрв
  { {0x6d5c03f5,0x9f490061,0xef1f0012,0x3ea90144}},	// [3f0] bbra, _amaç_, afür_, _usat_
  { {0x6d5c001c,0xdcfc0024,0x61fa03f6,0x6d5a0061}},	//   cbra, sgrā, nitl, ıtac
  { {0xa3d5000b,0xa8020061,0xf7550015,0x317b000a}},	//   _सकल_, ğına, لناج, תאבד
  { {0xa8020064,0x68e1007c,0x61fa03f7,0x7e7d03f8}},	//   şına, _üldm, hitl, orsp
  { {0xa635005e,0xa7640033,0xd90f002b,0x600c000a}},	//   анді, скід, _کیا_, עִבְ
  { {0xaaa80063,0x81bc0024,0xab5b0012,0xf98900c3}},	//   _съюз_, zmēr, _unüb, _جنسي_
  { {0xadd8000a,0x8235002b,0x7e7d0012,0x7a2b0012}},	//   רווח_, یرخا, hrsp, güte
  { {0x6d5c03df,0x6d410064,0x7bcd0375,0xc4f80015}},	//   zbra, ılay, njau, دعها_
  { {0xd1b90087,0x7aed03f9,0x11e503fa,0x59c9000b}},	//   نادا_, nzat, ижим, रापर
  { {0x43750074,0x8467010f,0x20b50010,0x7bcd00f2}},	//   _چهار, _бъде, аёмс, hjau
  { {0x23c5005d,0x55ba039e,0xe5c403fb,0x43750021}},	//   वादद, _שמעו, _усто, _نهار
  { {0x229503fc,0x7aed0030,0x61fa0125,0x44270067}},	//   _видя, kzat, aitl, _صراف
  { {0x81bc0024,0x1e8301b7,0x78450091,0xe1f1012c}},	//   rmēr, олям, _dėvi, _وست_
  { {0x61fa031c,0xa252002b,0x7aed006f,0xdb04016e}},	//   citl, _بپوش, dzat, ldiç
  { {0x8f76017f,0xad250015,0x6d5c03fd,0x6f0d03fe}},	//   _купі, مرفو, rbra, _exac
  { {0x2fc00176,0x35c7014e,0xdb0403af,0x78ba002c}},	//   _unig_, लाड़, ndiç, _štvo

  { {0x4b550063,0x89660292,0x68e103ff,0xc9660355}},	// [400] съст, икаж, _üldj, ивай
  { {0x48b60063,0x7edb0053,0x99980046,0x7d1e0400}},	//   ищет, _סקיצ, _virů_, _typs
  { {0x3205003e,0x6d7b000a,0x98740046,0x7d7b000a}},	//   inly_, _באיח, _týče_, _בריג
  { {0x2cac001a,0x7b96005e,0x37760033,0x31670401}},	//   æddu_, _трої, рыжс, _lenz_
  { {0xbad50033,0x46f60004,0xe5c60402,0x7aed002a}},	//   _ліры, јчет, иско, czat
  { {0x5d7a00b2,0xd49a0403,0x36330015,0x6729003d}},	//   דאַק, ври_, يروس, _dzej
  { {0x53e60404,0x26c20046,0x399b000a,0x94aa004a}},	//   ициа, _škod_, _שילד, ттла_
  { {0xe3b20015,0x7a2b0405,0x656a019f,0x7afb0160}},	//   زرع_, rüte, safh, _žuti
  { {0x61fa0406,0xe7b30015,0x7a2b0030,0x41c60033}},	//   titl, _بمقد, süte, аёна
  { {0x6b960034,0x90e60058,0x9f5901f6,0x244a00a1}},	//   hfyg, لسجن, misé_, _tùm_
  { {0x7aed02d7,0x9f59038d,0xe1ef0015,0x3015005e}},	//   zzat, lisé_, بسي_, йдор
  { {0xf8b30008,0x61fa0407,0xde590210,0x44200408}},	//   קשר_, sitl, ламі_, _ói_
  { {0x7e7d0409,0x9f590003,0x6b96040a,0x42540040}},	//   ursp, nisé_, dfyg, _انتر
  { {0x752d0089,0xdef80010,0x60080064,0x7aed0107}},	//   řaze, рыю_, lıml, vzat
  { {0x31570008,0x7b670080,0x7bcd0024,0x30840029}},	//   _דיון_, итае, tjau, _العف
  { {0x600801e2,0x7aed0251,0x113b0008,0x7ff400a2}},	//   nıml, tzat, _בתול, _وسيا
  { {0x6e95040b,0x7bcd022d,0x5e95003b,0xadbd0033}},	// [410] _الخا, rjau, _الخط, _запi
  { {0x68e10020,0xa8020064,0xbd2b0029,0x2019040c}},	//   _üldk, şıla, _لأجل_, losi_
  { {0x7aed00dc,0x58870010,0x60080061,0x18a4005e}},	//   szat, рыза, kıml, жаєм
  { {0x27690086,0x2019040d,0xd874012c,0x6675009a}},	//   اشای_, nosi_, زامب, مدتر
  { {0xef1f0064,0xcfb8000a,0x60080061,0x601d0046}},	//   zgün_, ילאי_, dıml, léms
  { {0xe6180036,0xbb3a0008,0xc98403e3,0x2019040e}},	//   аді_, _תעשי, _муси, hosi_
  { {0x33f5005e,0x86240033,0x2019040f,0x65680383}},	//   йчис, цьце, kosi_, _dedh
  { {0xd77403c4,0x316702b9,0x58050015,0xeb91000a}},	//   _واقع, _senz_, _اورك, הָ֙_
  { {0x6d45002d,0x65680410,0x68f70091,0x9f59008c}},	//   _ogha, _fedh, žadė, insä_
  { {0x6d450176,0x27fd0026,0xdb060089,0x86c40015}},	//   _ngha, liwn_, _jaká, _بيكن
  { {0x27330023,0xa87900b2,0xcea90008,0x69d50411}},	//   _ảnh_, װאָר, _רי_, _moze
  { {0x6d45002f,0xdb060412,0x0394005e,0xd24e002b}},	//   _agha, _inkö, _мрія, بنی_
  { {0xc2cb0029,0x1dc3000b,0xdb1d0030,0xc43a004f}},	//   _جبال_, शांत, _mosó, _עתני
  { {0x9f5900f2,0xd336000a,0x644801d7,0x831a000a}},	//   ensä_, _פרסה_, _yudi, _גונז
  { {0xe0550029,0x68e10020,0x409200e5,0x76410413}},	//   _اختب, _üldh, _فلور, _mily
  { {0x2d8c005c,0x66180227,0x77690414,0x9955006f}},	//   żde_, zovk, _neex, výši_
  { {0x4a430415,0xbf890015,0x27fd0416,0xdd110417}},	// [420] знув, _ضئيل_, diwn_, _výši
  { {0x9f590152,0x7bcb002e,0xe9d70418,0x0d76002b}},	//   visé_, ögur, бку_, _دیسک_
  { {0xb8650029,0x60080064,0xa8020064,0x7c960031}},	//   قانو, yıml, şıma, _اشخا
  { {0x6448000c,0x263d006f,0x76410034,0x61e6003d}},	//   _rudi, _dňom_, _aily, īkli
  { {0x501b000a,0xa6fa0015,0x25560015,0xd5b10016}},	//   נונו, دعاء_, منشآ, _bá_
  { {0x9f590152,0x644802c1,0xd5b10092,0xceb30008}},	//   risé_, _pudi, _cá_, פיו_
  { {0xd4670124,0x76410176,0x65680134,0x60080061}},	//   бије_, _dily, _vedh, tıml
  { {0x9473003b,0x32540419,0xdb060227,0xe6460033}},	//   أدوا, овир, _zaká, _геап
  { {0x60080064,0xaac8000b,0xf1aa006e,0x2019041a}},	//   rıml, रमिक, هاده_, vosi_
  { {0x9098000d,0x76410026,0x31c60080,0xa074041b}},	//   авот_, _gily, ссив, огоч
  { {0x6448041c,0x2019041d,0xe28f002b,0x3ea001d7}},	//   _uudi, tosi_, وذی_, _apit_
  { {0x493b000a,0x5f39005e,0x2019008c,0x77ca000a}},	//   טגיו, ипня_, uosi_, אמֹ֗
  { {0x22570086,0x2d98041e,0x2019041f,0xc0e7009a}},	//   _هلند_, ffre_, rosi_, لفین_
  { {0xddcd0050,0x93250029,0xa1580036,0x7c240399}},	//   _stał, _برمن, _таку_, elir
  { {0x9cc80010,0xe4780008,0x69d50420,0xd12f0421}},	//   быта_, יָּש, _roze, _хх_
  { {0x68e10005,0xdfd10015,0x9fe7002b,0xa4fb004c}},	//   _üldi, _آية_, _دسته, אללט
  { {0xdd910029,0x69d50107,0x77690422,0x44240423}},	// [430] _قوة_, _poze, _reex, ilm_
  { {0xceb40053,0x9e15005e,0x78eb004a,0x62800424}},	//   _זיץ_, _єдні, льев_, irmo
  { {0x7afb002c,0x58840010,0x69d50425,0xdb1d0426}},	//   _ľutu, зыча, _voze, _insí
  { {0xe76b002b,0xdcfc0091,0xdb0f0003,0x76b90427}},	//   احان_, ugrą, _lacé, илер_
  { {0xdb230074,0xdc0f0046,0x59c9000b,0xdb060428}},	//   _روسی, něčn, रादर, _taká
  { {0x27fd0176,0x4efc0008,0x49cb004a,0xdce50046}},	//   siwn_, נהגו, _сумм_, _lehč
  { {0x9475002b,0xdb07001a,0xdb1d0125,0x64b3000b}},	//   تگذا, álæg, _tosó, ंटेश
  { {0xd794006b,0xdc6c004f,0x84360058,0x0000006a}},	//   _нисъ, נ֣וֹ, يكور_,
  { {0x72c5005e,0x0000006a,0x0000006a,0x0000006a}},	//   ібоз,   ,   ,
  { {0xbb3c00b2,0xfaff00dd,0xef1f0064,0x85bb0015}},	//   נעזי, _reël_, rgül_, _حارس_
  { {0xa0690124,0x23790086,0xe5c40256,0x600a0429}},	//   јама_, _نماد_, _эсто, ином_
  { {0xd9a6005d,0xcdc90008,0x6442042a,0xc4d80054}},	//   _ऑस्ट, _בך_, _gioi, _уђу_
  { {0x8db60036,0x11d5042b,0x51f500a2,0xb1d50058}},	//   осві, _мікр, _وستر, _ويؤث
  { {0x11440015,0x73040033,0x8c4602ed,0x4df502ed}},	//   _فَهُ, _эпіз, жеве, пяст
  { {0x10d50033,0x7a300123,0xfce601c5,0xee3700ce}},	//   _філё, näte, цово, інс_
  { {0xec160086,0xdb0d002d,0xf092000a,0x7c24042c}},	//   آورد, adaí, _חנה_, ulir
  { {0x533600b2,0x3ea0016f,0xdde9002b,0xeab7042d}},	// [440] ַנען_, _upit_, _گريه_, ойт_
  { {0xc9860029,0x998a0091,0x3ead0061,0x2afe000b}},	//   تشري, _ribų_, çete_, _रेणु_
  { {0xa17a0053,0xb17a0053,0xfc320015,0x78660033}},	//   שטעט, שטער, _يحج_, ікдз
  { {0xb09a0053,0x7a3000f2,0xca290008,0x7794002b}},	//   ייער, däte, דם_, ثیرا
  { {0xdce70024,0xf1a9000b,0xdb040125,0xc7a30004}},	//   majā, क़ान, hdiú, ќичк
  { {0x78af022d,0xdce70024,0xfa67042e,0xa96a00af}},	//   äivä, lajā, _фарк_, _њива_
  { {0x37e60036,0x14ca004a,0x0000006a,0x0000006a}},	//   _довг, рыли_,   ,
  { {0xdce70024,0xd6aa002b,0x97c60015,0x7dd0008c}},	//   najā, _پدرم_, _بتسم, _väsy
  { {0xc1a600d7,0x7bdb000a,0x6442008c,0x320a00af}},	//   ојни, שקפו, _vioi, ихон_
  { {0x68e90089,0x1a9b000a,0x81bc003d,0x6016001a}},	//   _ředi, סייע, alēn, mámy
  { {0xc9530008,0xa0540036,0xdce70024,0x7bc6042f}},	//   ומת_, явні, kajā, _onku
  { {0x429a0015,0x251b000a,0x645a0430,0xc034002b}},	//   _ننصح_, _דובא, _itti, وژيک
  { {0xf7730008,0x2ef40010,0xf1a9002b,0x68e1007c}},	//   וקר_, дзяр, _گانه_, _üldv
  { {0x69d800dc,0x9f590046,0x683102de,0x7bc60353}},	//   övel, misí_, måde, _anku
  { {0xdb0d002f,0x9f59002d,0x9b6b000d,0xf1a9002b}},	//   rdaí, lisí_, ишаа_, _دانه_
  { {0x3eb000f2,0xda670029,0xaa55006b,0x0077000a}},	//   ältä_, قائي, зваш, _ותהי_
  { {0x2aab0431,0x161a005d,0x03d7000a,0x7e2b0033}},	// [450] штво_, धवार_, קומם_, _віна_
  { {0x645a02d7,0x7c3a0007,0x5a340432,0xbf340015}},	//   _otti, įtra, днут, _غريغ
  { {0x6d55005c,0x9f59002d,0x8b670015,0xd60402a3}},	//   mcza, hisí_, _واحم, _лiкв
  { {0x99980007,0x27e900dc,0x6d55005c,0x0137000a}},	//   _virš_, óan_, lcza, קראת_
  { {0x4fbc0053,0xf1bc005d,0x645a0433,0x5b56000a}},	//   יזאצ, ्ञान, _atti, _מירב_
  { {0x7a3000b8,0xbb3a0008,0x8f1c000a,0x6b8d007c}},	//   täte, _לערי, בודת, lgag
  { {0x05760029,0xcd7c000a,0x69c70434,0x4d7c000a}},	//   سمية_, שְׂכ, _inje, שָׂא
  { {0x7a300435,0x6d55002a,0xf7730040,0x6b8d0436}},	//   räte, hcza, _زار_, ngag
  { {0x645a01e2,0xc7b2000f,0xae0b000b,0xf647005e}},	//   _etti, _אבן_, हचान_, _єхан
  { {0x200b005c,0x7a300437,0x2297006f,0x64b70058}},	//   enci_, päte, eľká_, _وحضر
  { {0x6d550050,0xc617005d,0x68310123,0x7e7b003d}},	//   dcza, दकीय_, pådd, šupl
  { {0xdd920086,0x34b6000a,0x6d55002a,0x24770045}},	//   کوس_, _מפעם_, ecza, măm_
  { {0x33f40029,0x24770011,0x63a90438,0xdce7003d}},	//   _تسلس, lăm_, meen, vajā
  { {0x725a0008,0x63a90439,0x52d6000a,0x224b006f}},	//   _הכספ, leen, _מונע_, ícku_
  { {0xdce70048,0x24770011,0xa2a3000b,0xdb0f0061}},	//   tajā, năm_, कबक्, _encü
  { {0x78ba00dc,0x6b8d043a,0x24510057,0x60dc043b}},	//   _átvi, ggag, _mám_, ärme
  { {0x24770092,0xdce7003d,0x200202f1,0x8a460015}},	// [460] hăm_, rajā, miki_, سَان
  { {0x4efb0008,0x63a9043c,0x6b8d02f2,0xe9d7043d}},	//   _להפו, heen, agag, пку_
  { {0x4ddb013a,0x24770011,0x24510264,0x63a9043e}},	//   _החיו, jăm_, _nám_, keen
  { {0x2002043f,0x63a90079,0xf989000a,0x24770045}},	//   niki_, jeen, טר_, dăm_
  { {0xa3cf005d,0xdb0600c0,0xf6d3002b,0x869a033d}},	//   शान_, _bakå, فزود, стет_
  { {0xf1d00092,0xe5b30010,0x9f590057,0x746a005e}},	//   _mạch_, ейшы, visí_, брив_
  { {0x24770440,0xd4670001,0x24510092,0x200203d6}},	//   găm_, пије_, _cám_, kiki_
  { {0x6d55005c,0x2002003f,0x24510441,0xd4670054}},	//   zcza, jiki_, _dám_, чиће_
  { {0x6d55005c,0xdce50024,0xa3530015,0x36670442}},	//   ycza, _mehā, رخيص, _нато_
  { {0x68310443,0x51f8005e,0x2b46006f,0x27e60444}},	//   råde, інню_, ľoch_, lkon_
  { {0x20020445,0xf1af0029,0x24770011,0x68e10020}},	//   fiki_, اءً_, căm_, _üldt
  { {0x6d55005c,0xf1d00092,0xa2630092,0x27e60446}},	//   wcza, _bạch_, _khố, nkon_
  { {0xf19401c5,0x234b002b,0x41e601f3,0xb3bb000a}},	//   _жиль, _اسمی_, _ніка, _למאכ
  { {0x127b0053,0x7a2b0064,0xc27b039e,0xf27b000a}},	//   _פאוע, gütl, _פרוי, _פרוש
  { {0x6d55005c,0x819b000a,0xf19b0447,0x319b000a}},	//   rcza, _הסוצ, _השוש, _הבונ
  { {0x40eb000a,0x321e0448,0x1bd40449,0x3015005e}},	//   _לַחֲ, loty_, нося, _ідпр
  { {0x24770011,0x59d90010,0xf1d00092,0xdb23002b}},	// [470] zăm_, одаў_, _gạch_, روطی
  { {0x96b3005d,0xceb4000a,0xdce70045,0x27e6008c}},	//   _इनबॉ, _טיפ_, gajă, ekon_
  { {0x4ddc0008,0x67d5044a,0x24770045,0x986b0015}},	//   _לחזו, можу, xăm_, صحاف_
  { {0xdb0f02c1,0x24770011,0xa08b000a,0xeabf0016}},	//   _hací, văm_, מְדִ, _trù_
  { {0xa2630092,0x24510057,0x9bba000a,0x9f4b0077}},	//   _chố, _sám_, _וצרפ, licó_
  { {0x24770011,0x2002044b,0x27e6044c,0x63a9044d}},	//   tăm_, ziki_, akon_, ween
  { {0x5884044e,0x63a9044f,0x4424002b,0xe5700040}},	//   _пыта, teen, کروف, اطه_
  { {0xf8b20008,0x24770450,0x7a300451,0x24510107}},	//   _בשל_, răm_, mäta, _vám_
  { {0x24770011,0x63a900ed,0x27ff01c2,0x0000006a}},	//   săm_, reen, _imun_,
  { {0x1306005f,0x81bc0048,0x68e10005,0x24510092}},	//   ьный_, blēm, _ülds, _tám_
  { {0xf1d00092,0x1faa000d,0x66030452,0xa988000a}},	//   _sạch_, окни_, mink, הָרִ
  { {0x9f4b02c1,0x351a004c,0x66030453,0x320c0454}},	//   dicó_, _ווענ, link, andy_
  { {0x20020455,0x69d800dc,0x23740067,0x784c0061}},	//   riki_, övek, _سانح, _işve
  { {0xc332013a,0x9f4b02c1,0x66030456,0xdca60457}},	//   _סוג_, ficó_, nink, маги
  { {0x81bc0048,0x27ed0458,0x2d840061,0x80160459}},	//   klēj, _olen_, ğme_, _офиц
  { {0x2d840064,0xc8f9000b,0x7a2b007c,0x6603045a}},	//   şme_, ्पैम_, sütl, hink
  { {0x1ee8002b,0xa037000a,0x6603045b,0x4a46045c}},	// [480] _رودی_, _קאפה_, kink, днав
  { {0x6603045d,0xbf9b016e,0x9059000a,0xe800000b}},	//   jink, niên, ַכְת, लोना_
  { {0x16c6005d,0x6603045e,0xdce70045,0x27e6008c}},	//   लम्ब, dink, rajă, tkon_
  { {0xa2630092,0xdb0f0089,0xcc360010,0xbf9b0092}},	//   _phố, _zací, _іхны, hiên
  { {0x27e600f2,0xfbdf0092,0xa73a0015,0xf743045f}},	//   rkon_, _kiên_, آثار_, вецо
  { {0xdef7000a,0xe5340121,0x66030460,0x186a0461}},	//   ומנט_, нель, gink, _маги_
  { {0x64a30001,0x81bc0024,0xdcfe0064,0x7ae400f2}},	//   ваја, blēj, _kapı, lyit
  { {0xfbdf00a7,0xa2630023,0xbf9b0152,0x248002c6}},	//   _liên_, _thố, nnêt, čim_
  { {0x23270001,0xe3af0015,0xdce7002a,0x321e002a}},	//   моћи_, شري_, mają, toty_
  { {0xfbdf0092,0x6603005c,0xdce7005c,0x22590462}},	//   _niên_, cink, lają, íska_
  { {0x69dc0463,0x22470464,0x321e0465,0xf1f7002b}},	//   _more, _dink_, roty_, بعيت_
  { {0xdce7005c,0xd0110115,0xa2a9000b,0xe3630317}},	//   nają, الح_, _जैक्, _акци
  { {0xfbdf0023,0xe81f005d,0x69dc00dd,0x3f850064}},	//   _biên_, यकता_, _oore, ğlu_
  { {0xbf9b0466,0xf1aa0029,0x9f4b0077,0x70540015}},	//   ciên, _ذاته_, ticó_, _كنتا
  { {0xdb0f0467,0xdce7005c,0x26c20046,0xfbdf0468}},	//   _vací, kają, _škol_, _diên_
  { {0xdb0d001c,0xdce7005c,0x1bb800e6,0x66030469}},	//   ndaç, jają, واقع_, zink
  { {0xdce70050,0x3c440010,0x63a2046a,0x69dc046b}},	// [490] dają, тэрв, _mbon, _bore
  { {0x7e6d003f,0x69dc046c,0x58870033,0xad270058}},	//   _iwap, _core, дыда, _يردو
  { {0x69dc046d,0x6603046e,0x81bc003d,0x27ed046f}},	//   _dore, vink, elēk, _plen_
  { {0xdd0d005c,0xdce7005c,0x58840033,0x66030470}},	//   półp, gają, тыфа, wink
  { {0x660300df,0xcff8013a,0x7af60050,0xf77003c4}},	//   tink, וצאה_, czyt, شان_
  { {0x04b50063,0x6603008c,0xcb12000a,0x69dc0471}},	//   есия, uink, _תלך_, _gore
  { {0xdcfe01e2,0x66030472,0x24e9005e,0xa3e3000b}},	//   _yapı, rink, ямки_, _नकद_
  { {0x4788000d,0xdce7005c,0xdb06002c,0x66030473}},	//   _осум_, cają, _rakú, sink
  { {0x52a60256,0xc24503e7,0x69c4000b,0x22470474}},	//   евым_, нник, राची, _pink_
  { {0x7bdd0050,0xdb1d00c0,0xf652000a,0x54a70015}},	//   _losu, _insä, _עצב_, _يحاف
  { {0x05960086,0xbf9b001c,0xc0580010,0x22470111}},	//   _سالگ, riên, міў_, _vink_
  { {0x34bd005d,0x35c7005d,0x6e2500d9,0x44290016}},	//   ्मीद, लाक़, _akhb, _óa_
  { {0x62640036,0x63b90026,0x56b5004c,0x63bb0475}},	//   _авіа, _iawn, עפֿן_, mdun
  { {0x63bb018b,0xdce7005c,0xf1d00092,0x409503fc}},	//   ldun, zają, _hạnh_, _зрит
  { {0x32050041,0xfbdf0023,0x63bb0064,0x9d530015}},	//   mily_, _viên_, odun, انفت
  { {0xc4d200b2,0x63b9002a,0x32050046,0x63bb0476}},	//   נגן_, _jawn, lily_, ndun
  { {0xfbdf0023,0xf1d00023,0x63bb00b8,0x7bdd0089}},	// [4a0] _tiên_, _mạnh_, idun, _dosu
  { {0xdce7005c,0xf1d00092,0x629b0007,0x63b900ea}},	//   wają, _lạnh_, ituo, _lawn
  { {0x69dc00fb,0xdce7005c,0x629b0020,0xc6d60086}},	//   _vore, tają, htuo, کتات
  { {0x629b0007,0x2917006e,0xd917002b,0xe73a0477}},	//   ktuo, رقند_, رينش_, пее_
  { {0xdce70050,0xd6d00015,0x862601f3,0x69dc0478}},	//   rają, ؤقت_, ньке, _tore
  { {0x32050046,0xdce7002a,0x69dc008c,0x63bb0012}},	//   jily_, sają, _uore, edun
  { {0x68e10020,0xf7720029,0x32050479,0x48b4000a}},	//   _üldp, _ماء_, dily_, _בִּן_
  { {0xf1d00023,0xd3700029,0x7e7b0024,0x7648047a}},	//   _cạnh_, جهة_, šupi, _widy
  { {0x7528005c,0xeb9f003c,0x63b9047b,0x4c3b000a}},	//   _wydz, _kjør_, _dawn, התקב
  { {0xfa970053,0x7528005c,0x51f7004a,0x867b004f}},	//   עדיש_, _tydz, енью_, _מרמו
  { {0x6815005c,0x09f7000a,0xdb0f0125,0xeb0d000b}},	//   ląda, גמים_, _macá, _सख्त_
  { {0x63a2003f,0x20d50007,0xdfd2002b,0x3205047c}},	//   _ubon, džią_, ليپ_, aily_
  { {0xe04a0074,0x4426003f,0x91e6047d,0x2d85047e}},	//   _کشته_, _iko_, _поде, óleo_
  { {0x92f20064,0x320500da,0x7c26047f,0x0000006a}},	//   ığım, cily_, _akkr,
  { {0x9e080015,0x7bdd0480,0x23c4000b,0x7c840481}},	//   ريفك_, _posu, _वफाद, луте
  { {0x7e6d003f,0x7a2b0012,0x6838001a,0xa097000a}},	//   _twap, müti, nídd, _נדחק_
  { {0xe9870001,0xdb26002b,0xbbe1000b,0x6a25002b}},	// [4b0] ећен, پولی, _नवीक, نفرم
  { {0x99990007,0xd6d1002b,0xe981005e,0x7b440015}},	//   _rusų_, یقا_, ражi_, ائِل
  { {0x4426010b,0xef20005c,0x78ba002c,0xfd560008}},	//   _oko_, ążek_, _štvr, _בשתי_
  { {0xdb1d00c0,0xe9380015,0x6675002b,0x6b670003}},	//   _anså, رسلت_, ندتر, _dégâ
  { {0x212b00a7,0x7c2d0482,0xd126002b,0xbb76000a}},	//   ́ch_, mlar, _چم_, _שעשו_
  { {0xeb9f003c,0xdcee0024,0x85e80036,0x44260483}},	//   _gjør_, labā, ндів_, _ako_
  { {0x34bd014e,0x66e70024,0x97a70484,0x32050485}},	//   ्मेद, _sīkā, _прал, vily_
  { {0x7c2d0482,0x629b0486,0xd7c90067,0x3ea90487}},	//   nlar, ttuo, _توره_, _opat_
  { {0x52a90036,0x6265006b,0x75240046,0xfbdf0016}},	//   євом_, ъвпа, řizp, _niêm_
  { {0x3d1a005d,0x22920086,0x7c2d03ba,0x629b0488}},	//   _मुझे_, گلیس, hlar, rtuo
  { {0x23e70191,0x32050041,0x00850063,0xc952000f}},	//   _підв, rily_, ълно, ימי_
  { {0x7c2d0064,0x3205031c,0xd00f0015,0x629b0489}},	//   jlar, sily_, ْلَ_, ptuo
  { {0x443f048a,0x7c2d048b,0x877a000a,0xc7d6000a}},	//   mmu_, dlar, וארי, דורי_
  { {0x644b00b6,0x6289002d,0x7c2d048c,0x600b00f2}},	//   _higi, mreo, elar, tömä
  { {0x7b960191,0x7c2d01e2,0xeb9a0036,0x644b003f}},	//   краї, flar, мив_, _kigi
  { {0x442d01e2,0xd0120087,0xd116000a,0x60080061}},	//   nle_, _خلع_, _בקצה_, rıms
  { {0xdb0f002d,0x3b070063,0xbf9b000a,0x8eb3002b}},	// [4c0] _pacá, вето_, _חיפש, _نميش
  { {0x442d048d,0x09f70015,0x644b048e,0x69c00091}},	//   hle_, نفقة_, _ligi, _ėmes
  { {0x7db5008f,0x442d048f,0x7d7b000a,0x9f06002b}},	//   _ёсьц, kle_, _קנטו, _سوگو
  { {0x7aeb0014,0x60da0053,0x5fb2000b,0x7c2d0490}},	//   ölté, וקענ, ज़िल, clar
  { {0x96960491,0x442d0492,0x7c240493,0x6d5c0494}},	//   треш, dle_, moir, ocra
  { {0x6d480007,0xceb3039e,0xa6650015,0x7c240003}},	//   ždau, ייד_, اطنو, loir
  { {0xeb9f003c,0x442d0495,0x69ce0496,0x1da4000b}},	//   _kjøp_, fle_, _inbe, ख्यत
  { {0xe4e30191,0x68e30497,0xad1b000a,0x644b0125}},	//   рішн, ände, ווצר, _cigi
  { {0x644b0498,0x3714000a,0x26c4007c,0xf7430499}},	//   _digi, _עַֽל_, _urmo_, _вето
  { {0x644b0084,0x7c2d0064,0xa6970008,0x7c24049a}},	//   _eigi, zlar, _בכמה_, hoir
  { {0xf9930008,0x7c2d049b,0x4426016f,0xdfd10031}},	//   ברת_, ylar, _tko_, ميد_
  { {0xb4fb00b2,0x6289002d,0x4426003f,0x683801cb}},	//   _קלאר, breo, _uko_, bíde
  { {0x69ce049c,0xfaff00dd,0x41b60015,0xc1b7002b}},	//   _onbe, _leër_, _لمشر, رایط_
  { {0x827700b2,0x24580092,0x20c6005e,0xfbdf0016}},	//   _יעדע_, _kém_, _асиг, _viêm_
  { {0x7c2d01e2,0x7c24002d,0x2d580142,0xdc74004a}},	//   tlar, foir, тись_, игры
  { {0xfbdf0092,0x24580089,0x69ce0293,0x0a6b049d}},	//   _tiêm_, _mém_, _anbe, држи_
  { {0x7c2d01e2,0x6d5c00fb,0x644000f2,0xba740015}},	// [4d0] rlar, bcra, immi, لالت
  { {0x442d01e2,0x7c2d0064,0x4424049e,0x7d0e0030}},	//   zle_, slar, hom_, ánsá
  { {0x7c2d01e2,0xd141005c,0x394700c0,0x24580092}},	//   plar, cząć_, äns_, _ném_
  { {0x3b640063,0x4424049f,0x8cfa000a,0x2057000a}},	//   _върв, jom_, _נִיח, דיאל_
  { {0x644b04a0,0x68e30123,0xc1780091,0xf7940033}},	//   _rigi, ändb, nkės_, рачэ
  { {0x69d80014,0xdb060089,0xf6240036,0x1a68002b}},	//   övet, _jaký, адіо, _شیمی_
  { {0xe3b10029,0x18b80080,0xa3cf000b,0xd90f002b}},	//   مرة_, _игры_, शाल_, _بیا_
  { {0x442404a1,0x443f04a2,0x7e7d04a3,0x628904a4}},	//   gom_, umu_, kssp, treo
  { {0x32d40010,0x11d90029,0xeb92000a,0x6815002a}},	//   ацэс, فوظة_, צָה_, lądo
  { {0x644000f2,0x628904a5,0x2e36001a,0x442d04a6}},	//   ammi, rreo, kæfa_, sle_
  { {0x91050080,0x644b04a7,0x442d04a8,0x89da000a}},	//   упне, _tigi, ple_, תחתי
  { {0x4424049f,0xd00f0015,0xdea2002b,0x629c0045}},	//   com_, كلٍ_, میبی, ăror
  { {0x7c240152,0xfe710015,0x3f9e002a,0x6d5c04a9}},	//   voir, ْدِ_, ętu_, tcra
  { {0xa0c50086,0x8e75005e,0xdb04016e,0x2c51002a}},	//   _ميتو, шуюч, leiç, _lądu_
  { {0x7c24038d,0x6d5c003e,0x201904aa,0x0c7904ab}},	//   toir, rcra, éric_, ксты_
  { {0xf0920008,0xabf50248,0xd12e0015,0x9ad602a3}},	//   _הנה_, ачущ, _عمي_, люзі
  { {0x7c2404ac,0xed5a01e1,0x6fd10065,0xbb75009b}},	// [4e0] roir, _поп_, धारू, русъ
  { {0x7bcf0467,0x7a2b0020,0xbb43005e,0x7c2404ad}},	//   _encu, kütu, сеук, soir
  { {0x2fd70086,0x81760053,0x5d9b000a,0xfce604ae}},	//   _شوید_, רגעס_, _אביה, _соно
  { {0x27e00084,0x788004af,0xdb04001c,0x61e0021e}},	//   ðin_, _návš, jeiç, _पक्ष
  { {0x4a75044e,0x5b7b0008,0x69d800dc,0xbad50010}},	//   _выст, _ארכא, öves, _кіры
  { {0x69ce04b0,0x4424002a,0xe8560015,0x75d40015}},	//   _unbe, wom_, _منسد, شيبا
  { {0x54a60029,0xdb04016e,0x6ab60034,0x442404b1}},	//   احتف, feiç, lwyf, tom_
  { {0xd90d0074,0xccf3000a,0x2676002b,0xb8da000b}},	//   _تیم_, מכו_, _مهرآ, ॅट_
  { {0x81bc0048,0x65960086,0x75d3002b,0x9963006f}},	//   klēt, _مجار, _گيلا, líši_
  { {0x68380089,0xdd1f002c,0xd7070033,0x245804b2}},	//   bídc, _líši, _снуе_, _tém_
  { {0xf993013a,0x30a30063,0xddcd0011,0x3d00005d}},	//   זרת_, бряв, _ataş, ोपों_
  { {0xde59008f,0x1e1d005d,0xd36f0115,0x7e7d04b3}},	//   камі_, पक्ष_, _فهم_, tssp
  { {0x0f540015,0x6815002a,0x7e7d0012,0x81d404b4}},	//   صَّح, ządo, ussp, _волх
  { {0xdb070014,0x52830029,0xdb0600dc,0x27230016}},	//   ámít, _الوك, _lakó, ựng_
  { {0xa0c30015,0x7c090067,0x7e7d0012,0x709404b5}},	//   _هيوو, نيسف_, sssp, _тайф
  { {0xf1d2005d,0x7a2b00b8,0xdb060061,0x49bb002b}},	//   तावन, hütt, _fakü, کارد_
  { {0xdb06002c,0x497503e7,0x7a570015,0x5fb2000b}},	// [4f0] _taký, илас, اضرا, ज़रल
  { {0xdd9104b6,0xd91b0080,0x2c51002a,0x7d200030}},	//   _بود_, нье_, _sądu_, ézsé
  { {0xd7e70127,0x48ab0010,0x6d480007,0x8d5a000a}},	//   лідо, этам_, ždar, _בכתי
  { {0xf3f10023,0x200b04b7,0x69d804b8,0xf8680015}},	//   _mục_, nici_, över, امني_
  { {0xb5fd00df,0x7c3a0152,0x4b7a000a,0x6fa7000b}},	//   _atša, ître, _בארו, ट्यू
  { {0xdb1f0020,0x48770031,0xdb0e001a,0x7bd70091}},	//   övõi, _مدرس, _þjál, šbuč
  { {0xdb1d00fb,0x200b0064,0x62860107,0x25b60015}},	//   _ansø, kici_, ákon, شهيد_
  { {0x69c9000b,0x62d50015,0x81bc003d,0x73e504b9}},	//   _होती, لآخر, klēs, роиз
  { {0x91d50036,0x200b04ba,0x221504bb,0x7a2b02ad}},	//   ацні, dici_, ифор, bütt
  { {0x7a3000f2,0x7d080046,0xdb0600bf,0xe12504bc}},	//   vätk, údsk, _zakó, импи
  { {0x200b04bd,0xf3f10016,0x7e6404be,0x81bc003d}},	//   fici_, _cục_, _stip, vlēt
  { {0x200b04bf,0x92b50015,0xf1a8002b,0xf3f10016}},	//   gici_, _نحتا, پایه_, _dục_
  { {0xd343002b,0xeef50033,0x3f8c0061,0x7f1a005e}},	//   _افشی, бярэ, ğdu_, тіну_
  { {0x7e6404c0,0x752d0046,0xc332000a,0x12fa004f}},	//   _vtip, řazu, _ווד_, _שהסב
  { {0x200b04c1,0xf1d20065,0x0000006a,0x0000006a}},	//   bici_, तारन,   ,
  { {0x61e300dc,0x9f1a0015,0xb09a000a,0x78450091}},	//   _honl, _لآخر_, _סיפר, _tėvy
  { {0x39560083,0x1a0604c2,0xda6500e5,0xb9560054}},	// [500] ањет, апам, مالي, атећ
  { {0x8e7b0008,0xba170015,0x2fc004c3,0x5ee9004f}},	//   _שניה, ليقا_, _haig_, _תַקְ
  { {0xd826006b,0x2cba04c4,0x8ba604c5,0x0000006a}},	//   аджи, _uspd_, _кинж,
  { {0x443d0176,0x68e301d1,0xb8ce005d,0x46ea0063}},	//   _nhw_, ända, _कह_, кден_
  { {0x2fc00251,0xa6b60063,0x59760010,0xddd60227}},	//   _maig_, рсещ, _выбу, _zvyš
  { {0xd6cf0086,0x645e001c,0xc6f7017f,0x200b04c6}},	//   بقه_, ípio, шніх_, zici_
  { {0x200b0064,0x7a3000f2,0xa5f70063,0xab5b0012}},	//   yici_, jäti, рещу_, _knüp
  { {0xd7f20029,0x25a00089,0xe8d70008,0x22b6002a}},	//   _بكر_, řil_, _דולר_, _płk_
  { {0xd5b20015,0xf805004a,0x9f490061,0xa3b700c3}},	//   _وفر_, _учён, _ilaç_, شاير_
  { {0xc05a008f,0xd578000a,0x5578000a,0x61e304c7}},	//   кім_, _תָּר, _תְּד, _conl
  { {0x3a37013a,0x39570008,0xe97b0053,0xf957000a}},	//   שרים_, ישים_, כניש, יסית_
  { {0x82a60132,0x0000006a,0x0000006a,0x0000006a}},	//   _вадж,   ,   ,
  { {0xe1fa0001,0x61e30064,0x66f8000b,0xdcef0046}},	//   _игд_, _fonl, ्छिक_, ědču
  { {0xf3f10023,0xdb04007c,0x2d850003,0x200b04c8}},	//   _tục_, ndiõ, ûle_, sici_
  { {0x52b6014e,0x2fc00144,0x6e270085,0xb23b000a}},	//   _अनुस, _faig_, rojb, _שעוז
  { {0xd0f70008,0x1ee70086,0x2d98003c,0x62820020}},	//   _כמות_, _نوعی_, agre_, _kvoo
  { {0xe8e00092,0xa3a8021e,0x61fa007c,0x80be000b}},	// [510] ưới_, ख्य_, ohtl, षिके
  { {0x683802d5,0xf99304c9,0x996704ca,0x23a6000b}},	//   vída, تبر_, ртал, क्तद
  { {0xb9c40029,0xf7550058,0xd7770058,0x0000006a}},	//   تقلي, مناج, لاشع,
  { {0xd7880029,0x96f9004a,0x628001ee,0x3f9904cb}},	//   لنمو_, леет_, ksmo, ngsu_
  { {0xc7b8004a,0x7d1b0061,0x27e40045,0x6f7a000a}},	//   рёх_, ğusu, _domn_, רְעו
  { {0x9985002b,0x628004cc,0x660804cd,0x443d04ce}},	//   _دلسو, dsmo, _cmdk, _shw_
  { {0xfc3f0023,0xdb0d001a,0xd7590015,0x200902b9}},	//   _khí_, ndaþ, _ملأت_, _omai_
  { {0x61e30064,0xd7940063,0x04560029,0x1d18000a}},	//   _sonl, _мисъ, حلية_, יקור_
  { {0x645c00dc,0xfc3f002d,0xdb1d0152,0x7aed04cf}},	//   _érin, _mhí_, _basé, nyat
  { {0x61fa04d0,0x7a300437,0x7aed0061,0x201901f6}},	//   ghtl, täti, iyat, érin_
  { {0xb8750484,0x40940121,0xfbdf0016,0xafdb04d1}},	//   алiз, орят, _hiêu_, rmøn
  { {0x25f5000b,0x7aed0049,0xfbdf0016,0x61fa04d2}},	//   ऍसवी_, kyat, _kiêu_, ahtl
  { {0x7a30022d,0x0cd0005d,0xd436000a,0x2fc00144}},	//   säti, हम्म, _פרנק_, _vaig_
  { {0x6da60001,0xfbdf0092,0xfc3f02c1,0x61fa04d3}},	//   љива, _miêu_, _ahí_, chtl
  { {0x4095040b,0xfc3f002f,0x9c590001,0xfbdf0016}},	//   _العر, _bhí_, ишту_, _liêu_
  { {0xfc3f0023,0x44f30092,0x7ff60086,0x3ce500c0}},	//   _chí_, ị_, _دستا, älva_
  { {0x68e304d4,0x89aa0004,0xbb4304d5,0x0000006a}},	// [520] ändn, лкав_, зетк,
  { {0xc3320008,0x200e005c,0xdb040003,0xb9560054}},	//   לון_, ślić_, nfié, стаћ
  { {0xe93a0180,0x19b9005e,0xb17a004c,0x224b006f}},	//   учај_, шуть_, רטער, ícky_
  { {0x8b960286,0x41ae000b,0x7d1b0061,0x60dc04d6}},	//   _уроч, _जॉनस, ğust, ärmi
  { {0x68380089,0x673b005c,0xe7f9000b,0x661a01d7}},	//   bídn, _czuj, ्फ़ा_, _pjtk
  { {0x99d603c4,0xd6270342,0x95c40015,0xd49a04d7}},	//   _اتحا, боче_, زيعه, гри_
  { {0x75890036,0x64c30058,0x6aa404d8,0xdb1d01f6}},	//   рсів_, كيول, ltif, _rasé
  { {0x62860007,0xe3b20015,0x20dc006f,0x7bc404d9}},	//   škom, سرع_, nšiť_, ndiu
  { {0x6aa404da,0x6815002a,0xd80b000a,0x44f30016}},	//   ntif, ządk, _עִלָ, ạ_
  { {0x7abb000a,0x61fa007c,0x611402ed,0x645c01f6}},	//   נציו, uhtl, ждоу, _ério
  { {0x2019001c,0x546a0004,0x64c60040,0x320c00bf}},	//   ério_, _саем_, _ديال, ridy_
  { {0x7a30008c,0xf537000a,0x62820079,0x6aa404db}},	//   mätu, _פנאי_, _tvoo, ktif
  { {0x73360086,0xde590010,0x7a30008c,0x8336012c}},	//   _ارائ, рагі_, lätu, _اراض
  { {0x831b0053,0x329b04dc,0x9e15005e,0xa2b7000b}},	//   _גודז, _עבוד, ідві, ्टर्
  { {0xfc3f0023,0xf1a90074,0x657a04dd,0xc237000a}},	//   _phí_, _خانه_, _meth, _הרגו_
  { {0x317e04de,0x99940046,0x9ee90015,0xf3f1000a}},	//   latz_, _češi_, _نفعل_, ֵ֣ן_
  { {0x1a5b0029,0xd00c0008,0x4a54006b,0x7c3a0003}},	// [530] اشرة_, _תּוֹ, зкус, îtra
  { {0x645a038d,0x9f4b0089,0x657a04df,0xeef8000a}},	//   _outi, nkcí_, _neth, _למחר_
  { {0xe8e000a7,0x31780050,0x7a30022d,0xfc3f0092}},	//   ười_, órzy_, jätu, _thí_
  { {0xd7580029,0x473504e0,0x7ce8000a,0xa09b000a}},	//   مجها_, онес, _הַשֶ, ריאט
  { {0x62860007,0x20190152,0xe70b0018,0x6aa404e1}},	//   škoj, insi_, دتان_, ctif
  { {0x19580010,0xa87b0015,0x96ba000b,0x25a90085}},	//   _гары_, _محرر_, _एनरॉ, đalo_
  { {0x8ccc005d,0x69d504af,0x44f30092,0x657a0026}},	//   हियो, _inze, ụ_, _deth
  { {0xfbdf0023,0x645a04e2,0x69c504e3,0x9f4b005a}},	//   _tiêu_, _duti, ldhe, ekcí_
  { {0x657a04e4,0xe1f9023c,0xb5a704e5,0xdb1d04e6}},	//   _feth, иги_, _грей, _insó
  { {0xf0a90033,0xda7a000a,0x80a904e7,0x657a04e8}},	//   акол_, סנתר, авов_, _geth
  { {0x32f40023,0xf992011f,0x7a3000f2,0x645a04e9}},	//   ày_, ורי_, mätt, _guti
  { {0x81bc0024,0xc2c50029,0x4429002e,0x7a3004ea}},	//   slēp, _ويضي, _ða_, lätt
  { {0xeef5008f,0x3f890176,0x69d504eb,0x8708000a}},	//   пярэ, _ddau_, _onze, ֶּשֶ
  { {0x27fd0034,0x2259001a,0x201901d7,0x02440015}},	//   hhwn_, ísku_, ansi_, _فَنَ
  { {0xb147002b,0x68e303c1,0xb489000a,0x2715000b}},	//   _دیدم_, ändl, יָּ֙, तपुर_
  { {0x69d504ec,0x6aa404ed,0x9963006f,0x63a904ee}},	//   _anze, ttif, _ríšu_, nfen
  { {0x6aa4003e,0x261a005d,0x63a904ef,0xaf03006b}},	// [540] utif, _बदली_, ifen, _опъл
  { {0x238c0007,0xe9d704f0,0x69c50159,0x20f50016}},	//   mėjų_, оку_, gdhe, ói_
  { {0x20dc002c,0x02b6005d,0x7a3000f2,0x9b760015}},	//   pšiť_, _अन्न, dätt, _واحص
  { {0xc66a0054,0x6aa40003,0x0d3b000a,0x645a04f1}},	//   ашке_, ptif, _כגיב, _ruti
  { {0x645a04f2,0x777b0152,0x657a0026,0x26cd04f3}},	//   _suti, _deux, _peth, _creo_
  { {0x62860007,0x76410026,0x7aeb0012,0x7c36001a}},	//   škok, _chly, ägte, llyr
  { {0x4ddb000a,0x63a904f4,0x78800046,0xd6d9002a}},	//   יחסו, ffen, _dává, _mgły_
  { {0x63a90026,0x0443000d,0x238c0091,0x27fd0034}},	//   gfen, мејн, kėjų_, chwn_
  { {0x442f00dc,0x7a3003a4,0x32f40092,0x23a6000b}},	//   _dkg_, bätt, ùy_, क्षद
  { {0x51f804f5,0xe4d60015,0x238c0091,0x645a04f6}},	//   сною_, _وتاب, dėjų_, _tuti
  { {0x42540086,0x69b70008,0x645a00f2,0x403504f7}},	//   _کنتر, חליף_, _uuti, зенс
  { {0x317e00b8,0x69c500dc,0x800700ce,0x0000006a}},	//   satz_, zdhe, ічне,
  { {0x41e60010,0x7a300123,0x238c0091,0x2259001a}},	//   _міка, näts, gėjų_, ískt_
  { {0x81f80002,0xd337000a,0x9f540033,0xc693000a}},	//   _دفتر_, _ורדה_, ьвяч, ואש_
  { {0x271c0023,0x80270029,0x1bd50063,0x71260015}},	//   ỉnh_, _وربم, повя, _برشل
  { {0xdfd1003b,0x6024009c,0xe0fb000a,0x929d002a}},	//   _أية_, _одја, _כלול, szłe
  { {0xe451000a,0x34b7000b,0x9e670015,0xc95b0033}},	// [550] תֶם_, _आन्द, _بابن, аўе_
  { {0x78a5002e,0xadb9002b,0xa9970015,0x826b000a}},	//   tthv, _اهدا_, تشرت, ׁ֣בַ
  { {0x9f40002e,0xd7590115,0x7a3004f8,0x67b50054}},	//   _hlið_, ملات_, vätt, збеђ
  { {0x080b0015,0x0000006a,0x0000006a,0x0000006a}},	//   جزئي_,   ,   ,
  { {0x7bda0008,0x7a3000b8,0xc6680004,0xdb1d00bf}},	//   _הקרו, tätt, ошје_, _kasí
  { {0x7c2d04f9,0x26cd0011,0x1dcb000b,0x29070125}},	//   loar, _vreo_, ायित, únas_
  { {0x7a3004fa,0xdb1d04fb,0x63a902ad,0x0000006a}},	//   rätt, _masí, tfen,
  { {0xc2c5003b,0x7a3004fc,0x26cd04fd,0x64420110}},	//   كيبي, sätt, _treo_, _choi
  { {0x44240029,0x69c1002e,0xd5bb04fe,0xa2350033}},	//   بروف, _óles, _все_, зэнш
  { {0x238c0007,0xfad6000a,0x1306004a,0x63a9047f}},	//   vėjų_, פותך_, яный_, sfen
  { {0xf99200b2,0x6442002f,0x63a904ff,0xa1e80015}},	//   ערט_, _fhoi, pfen, تريك_
  { {0xa3bb0074,0xb4d7005d,0x60160007,0xe53a0008}},	//   _خاطر_, ामी_, kšme, _התער
  { {0x7c2d0500,0x4dd6005e,0x64490501,0xb796000a}},	//   doar, півф, mmei, הכרח_
  { {0x7c2d0011,0x82370015,0xa1c4005e,0x8b08002a}},	//   eoar, _برصا, _обід, nięż
  { {0xf1b2013a,0xfce6005e,0x7c3a0003,0x644903f8}},	//   _נסה_, чово, îtro, omei
  { {0x7c2d0011,0x64490028,0x1e86030e,0xdb520015}},	//   goar, nmei, _елим, َّر_
  { {0x6ffb000a,0x442d0034,0xf992002b,0x8f9b000a}},	// [560] _להקפ, ioe_, فبا_, _היפי
  { {0x3f82013c,0x7d270030,0x64490502,0x442d0503}},	//   laku_, érsé, hmei, hoe_
  { {0x23bd014e,0x64490020,0x53bd000b,0x6ee5002b}},	//   ्याद, kmei, ्याश, _فسیل
  { {0xca290008,0xdb1d0089,0x7a3000b8,0x3f82016f}},	//   אם_, _zasí, täts, naku_
  { {0x64490020,0xf3f10092,0x2907001a,0x64420034}},	//   dmei, _cụm_, únar_, _rhoi
  { {0x7bc60504,0xeb3b0008,0x3f8200f2,0x6e2e02b9}},	//   _haku, _לעכש, haku_, nobb
  { {0x6442002d,0x7bc60505,0xdb0d001a,0x20190030}},	//   _phoi, _kaku, ldað, érik_
  { {0x29370053,0xa2c8005d,0x7bc60506,0x3f820507}},	//   _זאלן_, ़िल्, _jaku, jaku_
  { {0x7bc60508,0x9bb7000a,0xdb0d001a,0x722a004a}},	//   _maku, להקה_, ndað, йцов_
  { {0x7bc60509,0x6e2e050a,0x75350030,0xa5650015}},	//   _laku, jobb, ögzí, _قدمن
  { {0x6442002f,0x30730010,0xdfd10087,0x656801d7}},	//   _thoi, нуўс, نيد_, _ifdh
  { {0x04db013a,0xe2aa002b,0x3f82050b,0x7bc6050c}},	//   _לקבל, _هاتن_, gaku_, _naku
  { {0x7c2d0011,0x80a3002b,0xdb0d016e,0x63a2050d}},	//   voar, ومین, meaç, _icon
  { {0x6114050e,0x91e3050f,0x52d7000a,0xb2bb000a}},	//   _одлу, _поче, _מודע_, _למדר
  { {0x7c2d04f9,0xecf80033,0xa0a3012e,0x7d240510}},	//   toar, перш_, _зајд, ефте
  { {0x80a30015,0x7bc601d7,0x6c540511,0x2137000a}},	//   _أمين, _caku, ексу, _מטול_
  { {0xdd0c002a,0xba550054,0x7c2d0512,0x4a550513}},	// [570] góła, двај, roar, дкас
  { {0x5a340124,0x68380089,0x7c2d0011,0xa93d0033}},	//   енут, bídk, soar, адзi
  { {0x7c2d04f9,0x41ae000b,0x7bc60514,0x6449008c}},	//   poar, ज्यस, _faku, ymei
  { {0x2d9c01d1,0x27e90084,0xf5400033,0xa7a90033}},	//   _över_, ðan_, _якiм_, ікла_
  { {0x6fa5005d,0x7e690011,0xe69b002a,0xe72e0515}},	//   _कानू, _împă, _żołą, те_
  { {0x7bc60516,0xddc40045,0x2d830517,0x63a20518}},	//   _zaku, _itiţ, naje_, _acon
  { {0x64490519,0xfdf8000a,0xb4d7000b,0x784c0061}},	//   tmei, הצגת_, ामे_, _aşvu
  { {0x3cfc0053,0x9cd8000a,0x8b08002a,0xf7730021}},	//   מלונ, לווה_, sięż, _سار_
  { {0x6449051a,0x442d051b,0xdcfc00bc,0x3f82051c}},	//   rmei, roe_, varč, vaku_
  { {0xa87900b2,0x4209005e,0x63a203b8,0x61ea0034}},	//   ֿאָר, інно_, _econ, _cofl
  { {0x93270086,0x0519002b,0x7e6d051d,0x3f82051e}},	//   _کران, _بياب_, _atap, taku_
  { {0x63a2002d,0x68380046,0xa2cd000b,0x15180015}},	//   _gcon, vídk, तिद्, _عزلة_
  { {0xa2e4005e,0x63bb051f,0x3f820520,0x7bc60521}},	//   _поїд, meun, raku_, _raku
  { {0x8d760015,0x69c70522,0xdd920002,0xc2440033}},	//   باحا, _naje, ضور_, _знік
  { {0xa00a0029,0x7bc60523,0x2fe60015,0x7e6d0524}},	//   _وقتل_, _paku, _يكتف, _etap
  { {0x5baa0033,0x8c430499,0xaac9000b,0x63bb0525}},	//   ўкам_, весе, रिंक, neun
  { {0xf4120008,0x69c700d9,0x62860526,0xcf26002b}},	// [580] דפן_, _baje, škov, _ترغي
  { {0x7bc6000c,0xfe460036,0x2aa6006f,0x68380527}},	//   _waku, _інно, rôb_, mídi
  { {0x4ddb000a,0xb4d7000b,0x1c4603ae,0x7bc60528}},	//   _וחיו, ामो_, _оном, _taku
  { {0xd6d9002a,0x63bb0529,0xdd0c002a,0x3f800073}},	//   _szła_, jeun, póła, _jeiu_
  { {0xa3e1021e,0xf5e6005e,0x4e7a004c,0x8bbb000a}},	//   दान_, дійм, קאַצ, _וזכת
  { {0x6b84002f,0x63a2052a,0xaa46005e,0x746a052b}},	//   laig, _scon, _цегл, орив_
  { {0xf79a0015,0x9e49000a,0x4d7b000a,0xe9a30165}},	//   _ونسب_, הֲקִ, קרקע, _шарп
  { {0x6b84017e,0x69c7052c,0x1bfb0053,0x828a03a9}},	//   naig, _zaje, ַליב, особ_
  { {0x752d0064,0xf6970015,0x27e6052d,0x7d010030}},	//   ğaza, _ينفع_, mjon_, úlsz
  { {0x6b84052e,0x24f60457,0x27e6052f,0x64b60015}},	//   haig, _очер, ljon_, _يحار
  { {0x20d30010,0x72330029,0xa9bb000a,0x7e6d00ed}},	//   віўс, خريط, חזיר, _stap
  { {0x2d83003f,0x68e30530,0xa8670008,0xb4bc000b}},	//   waje_, ändi, וֹךְ_, ेटी_
  { {0x6b84002f,0x41e60015,0xe46a001a,0xfe6e002b}},	//   daig, _يستف, blöð_, یگی_
  { {0x828b000a,0x41b30015,0x0357000a,0xa28b004f}},	//   _וְהֶ, _لمهر, _חידש_, _וְה֖
  { {0x6b84002d,0xebc70001,0xb19b000a,0xfc330015}},	//   faig, мљан, _ויוכ, نحر_
  { {0xa0080029,0x2d830531,0x9b450015,0xa3e1000b}},	//   _يقول_, saje_, فنزو, दाय_
  { {0x27e600dc,0x7e6d003f,0x68380532,0xdb1d0533}},	// [590] djon_, _utap, cídi, _basá
  { {0x2fc90534,0x68150535,0xdb1d0536,0x0000006a}},	//   _haag_, jądr, _casá,
  { {0x6b8400df,0x61e700c0,0x321e003e,0x28a70033}},	//   baig, öjli, inty_, ьшаг
  { {0xf7700029,0x5fbc0053,0x69c7003f,0x6b840537}},	//   لاه_, ַצונ, _waje, caig
  { {0xdb1d0538,0x69c70539,0x2fc9053a,0xdcfc01ec}},	//   _ansö, _taje, _maag_, marā
  { {0x7a2b00b8,0xa5940063,0xfcab0008,0x2fc9016b}},	//   hütz, връщ, ַיִּ, _laag_
  { {0x63bb0384,0x2d810020,0xd46601b7,0x97a7012b}},	//   teun, _mehe_, нище_, _орал
  { {0xee3f002c,0x2d810020,0xdb1d0089,0xdd58000a}},	//   dtým_, _lehe_, _zasá, ובוט_
  { {0xb06500f2,0x17f80015,0xc6a4053b,0x63bb053c}},	//   kyää, _غرفة_, _архи, reun
  { {0xc5fb0029,0x6b8400dc,0xdb04001c,0xddc4016f}},	//   _بعرض_, zaig, nfiá, _otiš
  { {0x83fc016f,0x86080015,0x27ed053d,0x9324009a}},	//   _suđe, _تقلق_, _koen_, فرین
  { {0xc476000a,0x73c50015,0x27ed008c,0xb5fd053e}},	//   _נתנו_, _سيتم, _joen_, _duše
  { {0x798501c2,0xc7f6000a,0x92a70054,0xdcfc003d}},	//   kahw, גזרת_, _цјел, darā
  { {0x27ff0176,0x6289002d,0x27ed007c,0x6b840012}},	//   _llun_, mseo, _loen_, waig
  { {0x27ff01e2,0x6286053f,0xc5f20135,0x6b840540}},	//   _olun_, škot, נדל_, taig
  { {0x27ed003c,0xb9c6002b,0xfc1a0015,0x6b840125}},	//   _noen_, کتره, أقرب_, uaig
  { {0x6b840541,0x6459003f,0x6996007a,0x6c330067}},	// [5a0] raig, _miwi, ерех, افقا
  { {0x6b84002f,0x2d810012,0x64590542,0x27ff0543}},	//   saig, _gehe_, _liwi, _alun_
  { {0x7d7b000a,0xdd7b000a,0x27ed0034,0xdb1d0030}},	//   _מניו, _מטיל, _boen_, _vasá
  { {0xe108000a,0xf989000a,0x08090015,0xc6a6008a}},	//   וּנָ, מר_, وزني_, ерки
  { {0x27ed00f6,0x27e600dc,0xc0530053,0xa73a0058}},	//   _doen_, rjon_, אזא_, أثار_
  { {0x27e60544,0x8f1b000a,0x3e660016,0x7af6008c}},	//   sjon_, הונת, _môt_, myyt
  { {0x8cd3000b,0x7af6008c,0x64a30054,0x27e60030}},	//   डियो, lyyt, гаја, pjon_
  { {0x34470010,0xa3d4006b,0x27ed01d7,0x64590034}},	//   нчын_, тоич, _goen_, _ciwi
  { {0x64590026,0xe3af0015,0x7af6008c,0x02bc000b}},	//   _diwi, صري_, nyyt, ्टेन
  { {0x22580084,0x44ce0050,0x84e60080,0x171b0053}},	//   örk_, _tę_, _позж, _זומע
  { {0x7a2b018b,0x5a170008,0x85060015,0x8997004c}},	//   tütz, תקין_, _ثوان, עכטס_
  { {0x6d5e0035,0x889b000a,0x2d810012,0xa3760015}},	//   _agpa, הבטי, _sehe_, _أداؤ
  { {0xb065008c,0xee3f013f,0x69dc0545,0x2fc90546}},	//   tyää, stým_, _onre, _vaag_
  { {0x30a6005e,0xbf9b016e,0xa0a6005e,0x2fc90547}},	//   _зрив, chên, _зшил, _waag_
  { {0x11e90029,0x9c4704ab,0xdfd10015,0x61f50548}},	//   _تعني_, ехал, _نيث_, özle
  { {0x69dc00b8,0xc1780091,0x913b000a,0xa4e7000a}},	//   _anre, lbė_, _מעוק, תֵךְ_
  { {0x5a350549,0x600c0008,0x93b7000a,0x9058000a}},	// [5b0] внат, _מִזְ, עלמו_, _אבהו_
  { {0x20fc0016,0x9b440015,0xd6d9002a,0x49d90033}},	//   ỏi_, انكو, _szło_, ьдзю_
  { {0xdcfc0024,0x718b000a,0x1dde000b,0xfe38000a}},	//   parā, לְאַ, मारत, _ארזי_
  { {0xe7190029,0x69dc054a,0x6d45054b,0x87e4054c}},	//   ويات_, _enre, _izha, люче
  { {0x02bc000b,0xb7f2000b,0xf770012c,0x7bdd054d}},	//   ्टोन, _अकरम_, صان_, _insu
  { {0x27e00048,0x0c740086,0xceb400a3,0x7bcd054e}},	//   ķina_, _جدید, ריס_, ldau
  { {0x27ed0298,0xdb04002e,0xf4b30086,0x2c51002a}},	//   _toen_, leið, اشتگ, _sądy_
  { {0x7bcd0084,0x62890020,0x6aad003f,0x1958054f}},	//   ndau, tseo, otaf, _часы_
  { {0x2480016f,0x7c3a0152,0x7bcd0091,0xb2250054}},	//   ćima_, îtri, idau, кмил
  { {0x929d005c,0x6aad003f,0xf61900c3,0x62890550}},	//   szło, itaf, _غياث_, rseo
  { {0xa3e1005d,0x7ff60029,0x00e20010,0x62890551}},	//   दाद_, نسحا, ажэн, sseo
  { {0x339b003b,0xdb04002e,0x94740058,0x62890552}},	//   _رخصة_, keið, _إدلا, pseo
  { {0x7648022d,0x20fc0092,0x6d450553,0x6286008c}},	//   _yhdy, ải_, _azha, škor
  { {0x7af600f2,0x7bdd01c2,0x8e590054,0xc27a000a}},	//   vyyt, _ansu, ејсу_, _חרסי
  { {0x15f4005d,0x20190144,0xc172000a,0xbd830554}},	//   _अवसर_, èric_, _דחו_, ргск
  { {0x3e660152,0xdca301ca,0x20190003,0x20c80058}},	//   _tôt_, јати, érit_, _أبوي_
  { {0x09fa0029,0x32050046,0xa037004f,0x0ba90058}},	// [5c0] وفرة_, ohly_, _שאפה_, عافى_
  { {0xfe9b013a,0x7bcd0026,0x7bdd0493,0xab550015}},	//   _קיימ, adau, _ensu, ائِش
  { {0x7af600f2,0x7e6400f2,0x18a60256,0x765a008c}},	//   syyt, _huip, таем, _rity
  { {0x66010020,0xdb04002e,0x41be000b,0x752d0061}},	//   _allk, beið, _ऍसऍस, ğazl
  { {0xc1780007,0xf62a0036,0x7791002b,0xcb8b000a}},	//   ybė_, міки_, صیلا, _קְטֹ
  { {0x96330010,0x6838001c,0x69dc0334,0x0000006a}},	//   аніц, vídu, _unre,
  { {0xf9b7000a,0x7e640547,0x48e30555,0xafdb01d0}},	//   _שהלך_, _luip, _корв, lløe
  { {0xccf3000a,0xa7da0015,0xdcfe0085,0x8cd30065}},	//   שכה_, _تورط_, _nepč, डितो
  { {0x2a66002d,0xe737004a,0x6d480046,0xd40300eb}},	//   íobh_, _ает_, ýdaj, рящи
  { {0x32050556,0x88ca004f,0xa9b80138,0x0000006a}},	//   ghly_, ֵמָ֖, дзiр,
  { {0xa99b0053,0xbb1b0011,0x09f70008,0x20c30151}},	//   וביר, _neîn, דמים_, асяг
  { {0xc058008f,0xdfd10115,0xc4f7004f,0x3205016d}},	//   кія_, حيح_, _שמאז_, ahly_
  { {0xa2940010,0x82fa002b,0x92940099,0xf457004f}},	//   _салі, _تراز_, _салц, _סידר_
  { {0x27310092,0xdb04001a,0x0e3400f4,0xdef80033}},	//   ỡng_, veið, иняю, тыю_
  { {0xab950185,0xde580036,0xc1bb000a,0x9c650021}},	//   ливі, тарі_, _חמוש, اهرو
  { {0x6aad0557,0xb157000a,0xa4b7000a,0x6b680030}},	//   ttaf, _בסוג_, כללה_, _régó
  { {0xab840558,0xfb840010,0x6aad003f,0x59d90010}},	// [5d0] руск, рысн, utaf, ндаў_
  { {0xdb040084,0xd91b0080,0x66180559,0x7bcd0012}},	//   reið, мье_, jivk, sdau
  { {0x67d5000d,0x58870010,0x2bab000b,0x7d7a000a}},	//   ложу, тыза, _छापा, _אנתו
  { {0xc794008f,0xba7700a2,0x442600bd,0xe8940484}},	//   аршы, _لاست, _njo_, раць
  { {0x4b7a011f,0xd6390010,0xd6a80067,0x7cfc008c}},	//   _ראשו, някі_, ندوم_, pärö
  { {0xa2b8014e,0xd12603c4,0x68e300c0,0x2019055a}},	//   ्बन्, _هم_, änds, hisi_
  { {0x64b50029,0x24960015,0x2019055b,0x60060052}},	//   احتر, هنود_, kisi_, _hóme
  { {0x20190064,0x42c9033d,0xb5fd055c,0x34b60058}},	//   jisi_, егин_, _duša, اهيج_
  { {0x2019055d,0x3205055e,0xdb0f0046,0xe3b6055f}},	//   disi_, thly_, _obcí, убы_
  { {0xe4d70015,0x2019007c,0xe5690015,0x60e90560}},	//   _لتصب, eisi_, _أمضى_, емом_
  { {0x5f06000b,0xafdb02de,0xfbdf0034,0x6e35002a}},	//   सैन्_, dløb, _phêl_, dozb
  { {0xbb1b0011,0x889a000a,0xdee60561,0x320500da}},	//   _reîn, עברי, гоми, shly_
  { {0x443f0562,0xd24e0086,0xc7d6000a,0x20190144}},	//   mlu_, تنی_, אורי_, èria_
  { {0x22920029,0x831a0053,0x20190563,0x443f0564}},	//   _الوس, _אונז, érir_, llu_
  { {0x2fe60015,0x20190565,0xb0f60015,0x443f0566}},	//   _مكثف, bisi_, _مفوض_, olu_
  { {0x3ec900f2,0x20190567,0x443f0568,0x0c850033}},	//   ättä_, cisi_, nlu_, рыём
  { {0x8eb30086,0x6295005c,0x8c43017a,0x6e350030}},	// [5e0] _هميش, ązow, сете, bozb
  { {0x99860015,0x7a300012,0x443f0569,0x0000006a}},	//   الاو, lätz, hlu_,
  { {0x443f056a,0x3ea2056b,0x6d8b000a,0x3ce50123}},	//   klu_, lukt_, _אָכְ, älvt_
  { {0xdc9b0008,0xad1b0053,0x9d1b0053,0x443f0085}},	//   _איטל, _טויר, _טויט, jlu_
  { {0x443f0176,0x68e300c0,0xa3d7000b,0xce36000a}},	//   dlu_, ändr, ायन_, ְאֶת_
  { {0x7a3000b8,0x629b0007,0x7c240011,0x2019056c}},	//   hätz, druo, lnir, zisi_
  { {0x2955010f,0x2a3b000a,0xd497056d,0x24800085}},	//   _вътр, _נעלמ, гры_, ćimo_
  { {0x68e3056e,0x443f056f,0xa3ab000b,0x9cd7000a}},	//   ånde, glu_, गभग_, רוקה_
  { {0x629b0091,0x2d8a0570,0x20190571,0x87260572}},	//   gruo, kabe_, visi_, _смаж
  { {0x32b70029,0x51f80036,0x20190573,0x236d006f}},	//   ادية_, тною_, wisi_, acej_
  { {0xaa370053,0x3a370008,0xe020000b,0xca37000a}},	//   רטיק_, ררים_, मचंद_, רניה_
  { {0x7c24016f,0x69ce0574,0x2d8a007c,0x9f49001a}},	//   jnir, _labe, eabe_, _blað_
  { {0xa3e1005d,0x743b0053,0x20190575,0xbea40033}},	//   दार_, _װעגװ, risi_, баўк
  { {0xd25000e6,0x20190332,0x2fcd0085,0x2d8a0576}},	//   _بنت_, sisi_, žeg_, gabe_
  { {0x02170008,0xafdb02de,0xd23b000a,0x64400577}},	//   _תחום_, rløb, _רגול, olmi
  { {0xfbdf00a7,0xeaf8002b,0x38ae001a,0x2d85002a}},	//   _thêm_, گرفت_, dýr_, źle_
  { {0x4424002d,0x7a3000f2,0x7c280152,0xdd950010}},	// [5f0] inm_, läty, édra, _капы
  { {0xceb40053,0x69ce0578,0x0c75002b,0xd99900c3}},	//   _היץ_, _cabe, _نگرد, ئنات_
  { {0x69ce018b,0xa3d7000b,0xa9080015,0x7a30008c}},	//   _dabe, ायम_, هيكل_, näty
  { {0x8d740074,0xf0930008,0x6c7a0053,0xedc5000b}},	//   _پایا, מנע_, _שארפ, _लघुछ
  { {0x66e50579,0x68e304d1,0x69ce057a,0x958502ed}},	//   рола, åndb, _fabe, алле
  { {0x44a50029,0xcdd5000a,0xd6780015,0x69ce057b}},	//   لمتق, יךְ_, احنا_, _gabe
  { {0xfdf80008,0xf3e50286,0x7a30008c,0x443f057c}},	//   רצות_, ижко, jäty, tlu_
  { {0xc2c50029,0x7a30008c,0xd7c9002b,0xdc6c000a}},	//   ليبي, däty, _جوره_, ע֣וֹ
  { {0x443f0375,0x020500d7,0xa3d7000b,0x91f50015}},	//   rlu_, изин, ायब_, لأدا
  { {0xd24e00e6,0x443f057d,0x64400044,0x5155004a}},	//   وني_, slu_, almi, итну
  { {0xd00a057e,0xd59a000a,0xd12e0015,0x443f057f}},	//   вене_, _יֹאכ, ِمٍ_, plu_
  { {0xdcfe0024,0xc0590010,0x83350010,0x2d8a0035}},	//   _nepā, ліў_, _кнех, wabe_
  { {0x629d00dc,0x7995005c,0x60170033,0x91e50580}},	//   ásod, _odzw, роўя_, _воле
  { {0x44d503eb,0x7a30018b,0xd1670063,0x3ea20581}},	//   _kā_, sätz, _съди, rukt_
  { {0x6b66010f,0x2d8a0582,0x44d50024,0x6c360015}},	//   иква, rabe_, _jā_, لفسا
  { {0x69ce0583,0x8b26012e,0xf092004f,0x9e6600af}},	//   _sabe, адбе, _ונה_, _квид
  { {0xcb00005d,0x69ce0584,0x70530087,0x78bc0559}},	// [600] लैंड_, _pabe, _بنيا, _sprv
  { {0x0b5902bf,0xa95a00c3,0x7e7602f2,0x2d960585}},	//   урсы_, نجار_, _ityp, _трис
  { {0xa7660083,0x44c700dc,0xa90a0015,0x61ee007c}},	//   акед, _nő_, خيال_, öbli
  { {0xf0b60053,0x69ce0586,0xb5fd0085,0xb9550054}},	//   ילער_, _wabe, _bušo, стућ
  { {0xe7b3002b,0x7bc40045,0x69ce0587,0x16a70588}},	//   تمند, meiu, _tabe, ивци_
  { {0xa6130191,0x96f7000d,0x2888002b,0x94aa0015}},	//   оміч, решт_, _مصری_, نطبق_
  { {0xb4e0000b,0xe0c7002b,0x291e0123,0x628200da}},	//   दमे_, _بز_, _äta_, _swoo
  { {0x39470061,0xdc9b000a,0xf3f8003d,0x4c9b000a}},	//   ünse_, דיקל, _kuģi_, דבקו
  { {0x5214005f,0x41e60010,0xa320000b,0x3f8b0085}},	//   йдит, аіна, मपेज_, vacu_
  { {0x44c700dc,0x7178056d,0x41b4002b,0xe2140174}},	//   _fő_, ыбор_, حمدر, ёмны
  { {0xf993013a,0x30a3006b,0x69d9004c,0xbb1b0045}},	//   חרת_, оряв, אַרו, _reîm
  { {0xa2b8005d,0xdb1d00dc,0xa3e1000b,0x34fb000a}},	//   ्बद्, _vasú, दाः_, _שהאד
  { {0xc7b3000f,0x69a7000b,0x8857004c,0x7a30008c}},	//   חבר_, _चाली, ישטע_, säty
  { {0x27230092,0x82330021,0x8d740015,0x7bcf0589}},	//   ằng_, _وروا, قافا, _sacu
  { {0x4094040b,0x4c940080,0x9cf4005e,0x7bcf058a}},	//   _البر, жисс, озрі, _pacu
  { {0x515b0008,0x415b000a,0x3ced0085,0x2723006f}},	//   _בכוו, _בדוג, ćev_, nčnú_
  { {0x1a5b0029,0x9967058b,0xa3d7000b,0x20120079}},	// [610] نشطة_, ател, ायत_, ëzie_
  { {0x2b850092,0x0357000a,0xac9500af,0x0000006a}},	//   ặc_, שימש_, _лаош,
  { {0x6d5a0091,0x2723006f,0xc7c7058c,0x7bcf058d}},	//   žtar, kčnú_, исди, _tacu
  { {0xf7f40086,0x7bc40045,0x7d36004f,0x6e88009a}},	//   يسند, ceiu, _לנתב_, _حنیف_
  { {0xd6d90050,0xa3ea021e,0x25f5000b,0x87d40021}},	//   _była_, मान_, ्सली_, تغلا
  { {0x8578006b,0x9991002a,0xc4c50015,0x05a8005e}},	//   асът_, żały_, متعو, ивій_
  { {0x69c50020,0x18a40010,0xcd980008,0xe89401c5}},	//   mehe, _маём, בדות_, _марь
  { {0x69c50005,0xf8b2000a,0xe45f007c,0x53c9058e}},	//   lehe, _משל_, öö_, угим_
  { {0x60320024,0xe2990054,0xe5c7058f,0x60060533}},	//   lāmg, ћао_, _всео, _nóma
  { {0x44d50048,0xd49b0033,0xcb12000a,0x9f590125}},	//   _tā_, _ард_, פלי_, bhsú_
  { {0xa3d7005d,0x3f890590,0x629d0264,0x7e76002a}},	//   ायद_, _beau_, ásob, _styp
  { {0x69c500b8,0x34b6000a,0x263f002a,0x88ba000a}},	//   hehe, _לפעם_, _dłoń_, נזרי
  { {0x83b6000a,0xe3b0002b,0xaac6000b,0x63a90591}},	//   _הִוא_, _آرم_, _रैंक, mgen
  { {0x3f9e0064,0xc27a0053,0x63a90592,0xdcfe0045}},	//   ştu_, _ערצי, lgen, _nepă
  { {0x61e30593,0xddcd0011,0x1ee8002b,0x61fc0594}},	//   _innl, _staţ, _چوبی_, örle
  { {0xb09a0053,0x60160007,0x60dc0595,0x200b0046}},	//   _עיפר, kšmi, ærme, chci_
  { {0xfe72003b,0x63a90596,0x6da60597,0xada60598}},	// [620] _عدة_, igen, _липа, _лапл
  { {0x200200f2,0xcaa50015,0x443d0012,0x69c50599}},	//   lkki_, تصفي, _lkw_, gehe
  { {0xa3d7014e,0xdcfe0011,0x395c00c0,0xa3ea000b}},	//   ाया_, _depă, ävs_, माम_
  { {0x2002022d,0xa6e90023,0x63a90079,0x68e30123}},	//   nkki_, _trự, jgen, ånda
  { {0xadec0372,0x6c57000a,0xa3e1000b,0x37ab002b}},	//   ञापन_, _ליטא_, दाई_, ائمی_
  { {0x47330036,0x60320024,0x63a9059a,0xb8660115}},	//   чніс, lāmd, egen, _هارو
  { {0x7d7b0053,0x18a30010,0xf8780008,0x63a9059b}},	//   אנצו, _нарм, _כְּל, fgen
  { {0x3a3a01d1,0x6815005c,0xb274059c,0xc274009c}},	//   lopp_, ządz, олиш, олиј
  { {0xfbd30008,0x42540021,0x443d059d,0x0000006a}},	//   לתה_, ينبر, _dkw_,
  { {0x60060097,0xe2140033,0x63a9059e,0x25a8002b}},	//   _róma, імны, agen, _خضری_
  { {0x3f890152,0x63a9059f,0xd577004f,0x60060052}},	//   _peau_, bgen, _התבה_, _sóma
  { {0x82a60457,0xc4d3000a,0x61e300cb,0x7f590461}},	//   _гадж, _מגע_, _ennl, ианс_
  { {0x60dc0134,0x3f890003,0xa194009b,0xddcd013b}},	//   ærmb, _veau_, _далч, _ataš
  { {0xddcd005c,0xf0b7002b,0xcd74006b,0x6b8d05a0}},	//   _uważ, جایش_, згръ, waag
  { {0xf0b70086,0x321e05a1,0x69c505a2,0x1df8004a}},	//   _هايش_, mity_, vehe, щеры_
  { {0x321e05a3,0x6815002a,0x0077000a,0x600605a4}},	//   lity_, sądz, _פתחי_, _tóma
  { {0xeab00029,0x69c505a5,0x6b8d0159,0x7dc70033}},	// [630] فعل_, tehe, raag, _лёнд
  { {0x996705a6,0xddab05a7,0x321e05a8,0x7e7d05a9}},	//   стал, _стил_, nity_, mpsp
  { {0x69c503d6,0xa9280033,0x321e008c,0x094b05aa}},	//   rehe, біце_, iity_, учаи_
  { {0x69c5018b,0xad1a0008,0x69da002e,0xb8f1021e}},	//   sehe, _כותר, _óten, _वन_
  { {0xcf940053,0x8f9c000a,0xa635005e,0xe7390054}},	//   פטס_, רידי, онді, јел_
  { {0x20090026,0x75d50058,0x60160160,0x0000006a}},	//   _llai_, زيعا, ršmi,
  { {0x2002002e,0xe5c40033,0xc87f0061,0xa026008c}},	//   ykki_, ясцо, ışsa_, ntöä
  { {0x58050015,0xdb0d0077,0xad1c000a,0xdc8c000a}},	//   _بورك, leañ, טוור, רְגָ
  { {0x23290185,0xb725002b,0x42090054,0xf6740015}},	//   ропи_, _بکاه, инио_, _فالخ
  { {0x31250080,0xb5fd016f,0xb2360015,0x62320054}},	//   ждог, _mušk, يكيا_, мењу
  { {0x63a90079,0x443d01d7,0xd4980099,0x320701c0}},	//   pgen, _tkw_, _грч_, _vlny_
  { {0xa3ea005d,0x20560010,0xb4d5005d,0xf487002b}},	//   माण_, ўтор, िटी_, _ناچی
  { {0x2002022d,0xce4a05ab,0x321e05ac,0x2a7901f9}},	//   rkki_, изме_, bity_, _ntsb_
  { {0x27380023,0x27e00024,0x321e05ad,0x8cc6000b}},	//   ứng_, ķini_, city_, ाबलो
  { {0xdbc70084,0xed5a05ae,0x3e6f007c,0x8d630004}},	//   töðu, ров_, _eüt_, двре
  { {0xc4d205af,0x1c46017f,0xcb67006b,0x2004003d}},	//   וגל_, інам, жате_, ījis_
  { {0xdbc7002e,0x3a3a05b0,0x0000006a,0x0000006a}},	// [640] röðu, topp_,   ,
  { {0x497a008f,0x718c0053,0x68fe02ad,0x0000006a}},	//   рсаў_, ָװאַ, typd,
  { {0xd6d90050,0x3a3a00d6,0x0000006a,0x0000006a}},	//   _było_, ropp_,   ,
  { {0x321e00bf,0x574602db,0x6e3c02ad,0x386d005a}},	//   zity_, онеб, lorb, _čert_
  { {0x62860089,0x6e3c016b,0x66730058,0x2441016d}},	//   škoz, oorb, ودور, nómu_
  { {0x2ba8005d,0x3ecb0008,0xd49a05b1,0xd4da0015}},	//   गलवा, שֶׁ֣, ари_, لبعض_
  { {0x25a001e2,0x1db2005d,0xe4a6005e,0x321e05b2}},	//   ğil_, _जानत, ірко, vity_
  { {0x25a00064,0x321e005c,0x6e3c002d,0x18670004}},	//   şil_, wity_, horb, _фати_
  { {0x6ab60050,0x24890085,0x320c0034,0xe7f9000b}},	//   ntyf, ćama_, thdy_, ूसरा_
  { {0x6acb000a,0x3abb004f,0xa5730058,0xd2500369}},	//   בֶטַ, סמינ, _يُقت, عند_
  { {0x104b005f,0x3cf6005d,0xb3ca05b3,0x321e05b4}},	//   иями_, ीनों_, _влез_, rity_
  { {0x321e003e,0xd7e60015,0xdb21013f,0x8f3505b5}},	//   sity_, رك_, _štíh, земц
  { {0xa3d7005d,0x14390086,0x6e3c01f0,0x14170015}},	//   ायर_, _اينک_, forb, _بينة_
  { {0x40940015,0x6e3c05b6,0x0000006a,0x0000006a}},	//   _فلتر, gorb,   ,
  { {0x317b0008,0x5478000a,0x4478000a,0xb478000a}},	//   _דרומ, מְּנ, מְּא, מָּי
  { {0x80c7005d,0x6ff40015,0xbc27005e,0x23bc000b}},	//   ़बरे, _يسيط, ієви, ्जिद
  { {0xf96b033d,0x6e3c05b7,0x0000006a,0x0000006a}},	// [650] арей_, borb,   ,
  { {0x527b00b2,0xa2b2005d,0xc27b000a,0xa907006e}},	//   ינמא, _आमन्, ירמי, يبان
  { {0x81bc0024,0x602400dc,0x18a40036,0x60320024}},	//   tnēj, sőme, даєм, sāme
  { {0x2d91016f,0xfd56000a,0x7b040030,0x61f801de}},	//   laze_, _משתי_, ötté, _lovl
  { {0xeb760053,0x76c70002,0x501c000a,0x0000006a}},	//   _מערץ_, تغال, סודו,
  { {0xe6180036,0xe7300015,0x8f38000a,0x2d9105b8}},	//   оді_, خصم_, קאגו_, naze_
  { {0xf5050210,0xd4d90033,0xe3c50015,0x7e6d050b}},	//   язко, сьлі_, كْثَ, _luap
  { {0xb8ff000b,0x787a000a,0x6006006f,0x69d505b9}},	//   ति_, _לָמו, _rómo, _haze
  { {0x29ff005c,0xa2d20015,0x69d505ba,0x2d9105bb}},	//   ałań_, فييت, _kaze, kaze_
  { {0x11d5003b,0xddc4016f,0x46150067,0x35f80067}},	//   ستخد, _stiž, _عوار, _ورلد_
  { {0xcea90135,0x38b505bc,0x61fc0123,0xa85505bd}},	//   _תי_, når_, örla, ּיָה_
  { {0x6e3c00b8,0x69d505be,0xafdb01d0,0x3f82005a}},	//   worb, _laze, lløj, ubku_
  { {0x93270087,0x94db000b,0xd00f0015,0x63bb05bf}},	//   _بران, _मछुआ, الُ_, mfun
  { {0x2d8c03af,0xa2f60008,0x01650015,0xdb1d002a}},	//   úde_, _ממנה_, _عُبَ, _lasó
  { {0xe1660086,0x40920015,0x1d0705c0,0x59df000b}},	//   _عضوی, _كلور, пери_, _नफ़र
  { {0xc4d200b2,0x25e2005d,0xbc6305c1,0xd116000a}},	//   עגן_, _टोनी_, евск, _מקצה_
  { {0x2fc000b6,0x02b60053,0x63bb003f,0x69d505c2}},	// [660] _ibig_, ּלעך_, ifun, _baze
  { {0xa3e2005d,0x25db005d,0x6ab6005c,0x4a4305c3}},	//   _फोन_, _गोली_, rtyf, енув
  { {0x5dfb0008,0xa9670063,0x3dfb000a,0x8dfb000a}},	//   _הפינ, чиха_, _הליד, _ההית
  { {0xde6d0092,0x46ea05c4,0x83fc0085,0xcc77004f}},	//   _hươn, йден_, _tuđi, _מעטה_
  { {0x69d503af,0x073a003b,0x6d400064,0xa3ea000b}},	//   _faze, حساب_, şmad, मास_
  { {0x69d505c5,0x6b840012,0x2816002b,0x63bb05c6}},	//   _gaze, lbig, _کورس, efun
  { {0xdb0f038d,0x2d8500dc,0x629d00dc,0x63bb05c7}},	//   _accè, űleg_, áson, ffun
  { {0xde6d0092,0x929d002a,0xf8b7000a,0x02a605c8}},	//   _lươn, zyłe, _מפלי_, пром
  { {0x6b840035,0x61f802c6,0x35a60033,0x6aa400a9}},	//   ibig, _povl, _нааг, nrif
  { {0x27e00048,0x320a005c,0x6faa005d,0x9098000d}},	//   ķinu_, óby_, _काउं, овот_
  { {0x6aa405c9,0x2ee00049,0x2d9105ca,0xb5a90015}},	//   hrif, _arif_, vaze_, _ذالك_
  { {0xe45a05cb,0x2ee00026,0x44200064,0xc4c50015}},	//   _уже_, _brif_, _öi_, _تتكو
  { {0xf206010f,0x2d91006f,0xeb9f02de,0x7de7005e}},	//   _няко, taze_, _fløj_, півд
  { {0x9c8305cc,0x3205003e,0x6aa405cd,0xde6d0092}},	//   účov, ckly_, drif, _cươn
  { {0xc1bb0008,0xde6d0092,0x69d505ce,0x38a00045}},	//   _המוש, _dươn, _raze, nără_
  { {0x6aa40176,0x6b8400b6,0xdfd10002,0x929d002a}},	//   frif, gbig, _شيخ_, syłe
  { {0x8f9c0008,0x6aa405cf,0x69d50024,0xb03800a3}},	// [670] _היחי, grif, _paze, _מנהג_
  { {0x6f0f0064,0xde6d0092,0x6b8405d0,0x3ea4006f}},	//   ıncı, _gươn, abig, ámte_
  { {0x60320048,0x799c0026,0xe3c70007,0x2988006b}},	//   lāma, _ddrw, ščių_, ясто_
  { {0x290f005c,0x7af20046,0xdc88000a,0x8d87002b}},	//   ąga_, _šetř, _מְשָ, _بشکن
  { {0x16a90036,0x290702c6,0x7bda000a,0x6032003d}},	//   івки_, šna_, _וקרו, nāma
  { {0x68e100dc,0x45d20001,0xde6d0092,0xc60405d1}},	//   _áldo, вољс, _xươn, нзій
  { {0x2489016f,0x8cd3000b,0x7c2d05d2,0x63bb05d3}},	//   ćamo_, डिटो, onar, tfun
  { {0x63bb003f,0xdb0f05d4,0x1309006d,0x25eb000b}},	//   ufun, _accé, жний_, चाही_
  { {0x2d9e002e,0x35b50054,0x17f80015,0x7c2d05d5}},	//   ótek_, _обар, _عرفة_, inar
  { {0x3eab05d6,0x22560115,0x86c40015,0xaa7b006f}},	//   duct_, وليد_, _سيمن, _zrýc
  { {0xc609005d,0x7c2d05d7,0xf992000a,0x33b5004a}},	//   वसीय_, knar, כרי_, _жёлт
  { {0x2ee00176,0xde6d0016,0x001a0033,0xa03a0015}},	//   _prif_, _sươn, іўны_, تأخر_
  { {0xa3ea005d,0x7c2d00bd,0x644905d8,0x93940015}},	//   मार_, dnar, mlei, _سجنا
  { {0x3f82005c,0x442d05d9,0x4df50033,0x443f05da}},	//   dłuż_, lne_, няст, lou_
  { {0x442d05db,0x3eb90111,0xde6d0092,0x9e6303f1}},	//   one_, atst_, _vươn, тврд
  { {0x442d05dc,0x443f05dd,0xdbf20046,0x645b008c}},	//   nne_, nou_, přís, nmui
  { {0xde6d0023,0xc0530008,0x6aa40020,0x8c430345}},	// [680] _tươn, _בזה_, urif, тете
  { {0x2b8c0023,0x443f05de,0xab290015,0x644905df}},	//   ếc_, hou_, أسفل_, hlei
  { {0xe9470086,0xd23a0053,0xc8ca0018,0x851c000b}},	//   ورمی, קגעל, توان_, _भेंट_
  { {0x798e020a,0x442d05e0,0x443f05e1,0xccf3000a}},	//   _webw, jne_, jou_, _סכר_
  { {0xb8650086,0x629d00dc,0x443f05e2,0x442d05e3}},	//   رامو, ásol, dou_, dne_
  { {0x44ce0089,0x644905e4,0xa4d801f3,0x442d05e5}},	//   _př_, elei, здку_, ene_
  { {0xa3ea005d,0x3e7400c0,0x55e305e6,0x94aa05d1}},	//   माल_, _lät_, тојб, ітка_
  { {0x443f001c,0x27e00024,0x68e30134,0xaa7b002c}},	//   gou_, ķins_, ænde, _urýc
  { {0x61fc0123,0x3e740123,0x0000006a,0x0000006a}},	//   örlo, _nät_,   ,
  { {0x442d05e7,0xcb57000a,0x60dc02de,0xf12601c5}},	//   ane_, וספה_, ærmo, дьмо
  { {0x85060074,0x25eb005d,0xdfd10002,0x7c24014b}},	//   _توان, चारी_, هيد_, kiir
  { {0x443f05e8,0x6032003d,0x442d05e9,0x60240030}},	//   cou_, tāma, cne_, tőma
  { {0xdefb0010,0x64400007,0x9f050029,0x442405ea}},	//   цын_, momi, روسو, mim_
  { {0x60320024,0x644005eb,0x3eab05ec,0x6e440015}},	//   rāma, lomi, ruct_, َنَم
  { {0x718b000a,0x6440007c,0x6032003d,0x61ea05ed}},	//   _וְחַ, oomi, sāma, _infl
  { {0x442405ee,0xfc3000c3,0x2bdf000b,0x644005ef}},	//   nim_, لحق_, _पोशा, nomi
  { {0xa3b6005d,0xcd040089,0x8fa40001,0x7c2d05f0}},	// [690] _जान_, vněž_, _рање, rnar
  { {0x443f05f1,0x442d05f2,0x442405f3,0x7c2d05f4}},	//   zou_, zne_, him_, snar
  { {0x5a440010,0x39470134,0x8e380015,0x644005f5}},	//   тэта, æns_, _تسير_, komi
  { {0x443f001c,0x64400007,0x442405f6,0x27e90077}},	//   xou_, jomi, jim_, ñan_
  { {0x443f0264,0x4b7a000a,0x7bcd0003,0x442d05e3}},	//   vou_, _מארו, meau, vne_
  { {0x442d0050,0x9f5900c0,0x442405f7,0x64490034}},	//   wne_, ckså_, eim_, wlei
  { {0xe3b1003b,0x6006002d,0xfdf80008,0x442d05e3}},	//   هرة_, _fómh, וצגת_, tne_
  { {0x442d04f9,0x645b003f,0x644000f0,0x36d505f8}},	//   une_, umui, gomi, _побр
  { {0x442d05f9,0x7bcd0024,0xf77201ac,0x443f05fa}},	//   rne_, ieau, _תקמ_, rou_
  { {0xe1f1003b,0x443f05da,0x442d05fb,0x64b70015}},	//   اسة_, sou_, sne_, _يحضر
  { {0x659405fc,0x443f05e2,0x2c750123,0x602605fd}},	//   _раху, pou_, _nåd_, една
  { {0xa3b6000b,0x44270015,0x442405e0,0x644005fe}},	//   _जाय_, _غراف, cim_, comi
  { {0x2ac30024,0x7c2405ff,0xdd02006f,0x7bcd0600}},	//   nībā_, viir, ľuču, deau
  { {0xa3d7005d,0x2d9e0152,0xdd920031,0xb5fd0085}},	//   ायक_, ûte_, طور_, _gušt
  { {0xd00a0001,0xa3b6000b,0x91b6000a,0x7c240601}},	//   _неке_, _जाम_, _נפקא_, tiir
  { {0x711a000a,0x7bcd0602,0x611a004f,0x3e7402dc}},	//   _מוצפ, geau, _מוצה, _tät_
  { {0x1f660036,0xf4120053,0x60060603,0xeb750033}},	// [6a0] _яким, אפן_, _rómh, тысэ
  { {0xa3b1005d,0x7c240604,0xe9d70605,0x44240606}},	//   फ़्त_, siir, нку_, zim_
  { {0x44240064,0x7c240607,0x1bea0608,0x3fda000a}},	//   yim_, piir, _едни_, ּקְב
  { {0x44240609,0x95fa000b,0x929d002a,0x7d01060a}},	//   xim_, ्स्ट_, zyła, älse
  { {0x4424060b,0x60060077,0x2f97000a,0xb7d70015}},	//   vim_, _cómi, תכנן_, عوها_
  { {0x44240026,0x999a002a,0x0f37004c,0x6440002a}},	//   wim_, żyły_, ערסט_, womi
  { {0x7c2f002d,0x8c1a0008,0x81bc0024,0x4424060c}},	//   _áirí, ּוִי, inēt, tim_
  { {0xd4670124,0x644000f2,0xccf301d8,0x937a0015}},	//   није_, uomi, רכה_, أصغر_
  { {0x07b7003b,0x2ac30024,0x4424060d,0xa2260015}},	//   _سهلة_, cībā_, rim_, فرده
  { {0x4424060e,0x6440060f,0x872300ce,0x66130535}},	//   sim_, somi, _смуж, ądkó
  { {0xe9f90016,0x44240610,0x64400611,0x64a30612}},	//   huế_, pim_, pomi, _баха
  { {0x929d0050,0x28970008,0xdfd10087,0x2c750613}},	//   syła, עדכן_, جيح_, _råd_
  { {0x7bcd0614,0x93fb0008,0xaacf000b,0x33fb000a}},	//   veau, _מלאי, _सैंक, _מהאנ
  { {0x91e30054,0x81bc003d,0xd6eb000a,0xaa7b001a}},	//   _боље, gnēt, הַלָ, _brýn
  { {0x8c250015,0x7bcd0615,0xc534000a,0x2ac3003d}},	//   نفسه, teau, דָּה_, zībā_
  { {0x7c84000d,0x59c6000b,0x8cc2000b,0xdbf20046}},	//   ѓусе, _रॉबर, _लहरो, třás
  { {0x7b740029,0xc334000f,0x49cb056d,0xda090015}},	// [6b0] اطفا, דוּ_, зуем_, ويره_
  { {0x7bcd0616,0x1a65002b,0x9aa40015,0x2bcf000b}},	//   seau, ئیسی_, املو, हजहा
  { {0x48ab0617,0xae1c000a,0x5d55009c,0x7bcd0618}},	//   ятам_, _מוזכ, _шкот, peau
  { {0xfbab005f,0x629d0014,0x200b0089,0x4c9a000a}},	//   _этой_, ások, nkci_, _קברו
  { {0x79a700d7,0xc66b004a,0x8f9c004c,0xe56e012e}},	//   _прве, чшее_, לסאה, из_
  { {0x2ac30024,0x64a504c2,0x06080033,0xb5fd0091}},	//   rībā_, вака, ннік_, _aušr
  { {0xda3404ab,0x69c1000b,0x2ac3003d,0x7d7c000a}},	//   _серы, र्णी, sībā_, לנגו
  { {0x73e501e9,0x0000006a,0x0000006a,0x0000006a}},	//   тоиз,   ,   ,
  { {0x961d003d,0xe3b1002b,0x02bd000b,0x27ed0619}},	//   _atņe, هرک_, ्बेन, _inen_
  { {0x96df008f,0x85b80180,0xd5d40015,0x64c50058}},	//   _нiву_, _плус_, _متمث, _ليطل
  { {0xd656000a,0x7643061a,0xb97a000a,0x21690004}},	//   _סיעת_, mony, ונתי, ќини_
  { {0x7d07005c,0x27ed0012,0x94740067,0x7643061b}},	//   dyjs, _jnen_, _صدما, lony
  { {0x93940029,0x441a00f3,0x60240030,0x0f360033}},	//   _إجما, _קונס, sőmo, тэня
  { {0x6f06002a,0x7643061c,0xed5a00af,0x0000006a}},	//   rykc, nony, дог_,
  { {0xdcfc0048,0xdde400dc,0xb1160015,0x201a0015}},	//   varē, ésőb, _لقوا_, _يتبع_
  { {0xd164006b,0x27ff00da,0x764300a6,0x7ae90085}},	//   _съчи, _noun_, hony, _šeta
  { {0xee3a061d,0xab27061e,0xab660617,0x7643061f}},	// [6c0] _они_, вота_, твал, kony
  { {0x48e60001,0x7d010012,0x7643002a,0x629b0620}},	//   козв, älsc, jony, isuo
  { {0x2d980621,0x7d07002a,0x35c4000b,0x76430622}},	//   mare_, cyjs, ल्फ़, dony
  { {0x661d0007,0x8b260010,0x2d980623,0x3156004c}},	//   _įska, _адме, lare_, דיען_
  { {0x76430034,0xc6d30015,0x2d980045,0x4b55009b}},	//   fony, لتوت, oare_, _бърт
  { {0x8f1b0008,0x2d980624,0xeb00000b,0xceb5004c}},	//   וונת, nare_, ोनीत_, ריװ_
  { {0xd5e90092,0x6d480061,0x4c9b004f,0x64b30058}},	//   _qué, üdah, ֵ֑הו, لحير
  { {0x64590625,0x9836008f,0xd90d0086,0x20000011}},	//   _chwi, _рэгі, _عین_, _noii_
  { {0x20d304f9,0x7643000c,0x2d9801d1,0x69dc0626}},	//   _aţi_, bony, kare_, _kare
  { {0x69dc0298,0x7643005c,0x2d980627,0x69de0628}},	//   _jare, cony, jare_, ndpe
  { {0x50f30010,0x2d980629,0x32530033,0x98c50085}},	//   азэт, dare_, рвэр, čuće_
  { {0x351b000a,0x289b004c,0x0326062a,0x03a3029f}},	//   _קואנ, ויטא, _иден, _вицо
  { {0xdcf50048,0x4ea70063,0x63a2062b,0x69dc0011}},	//   pazī, ърна, _idon, _oare
  { {0xc0aa00b0,0x69dc0198,0x2d980629,0x7d07002a}},	//   _قابل_, _nare, gare_, tyjs
  { {0x20d30225,0x6d40062c,0xdfd10015,0x6272002a}},	//   _نتيج, şman, _هيث_, _błog
  { {0xec34062d,0x7d07005c,0x7643062e,0xd0f7000f}},	//   ансь, ryjs, zony, _ימות_
  { {0x7d07005c,0xbfb40015,0x69de0079,0x3b55062f}},	// [6d0] syjs, _ضحيت, fdpe, укар
  { {0x2d980630,0x69dc0631,0x58870033,0x0e470033}},	//   care_, _care, выда, _шэйм
  { {0xd8740021,0x320c013f,0x7c30001a,0xad19000a}},	//   لانب, ikdy_, ðirð, _נוֹר
  { {0xac190036,0xe10b0008,0xc7c4004a,0x6272002a}},	//   _чому_, וּדָ, исчи, _kłod
  { {0x07a4008f,0x7c3a0014,0xf77003c4,0x501c0632}},	//   раін, étre, زان_, וואו
  { {0x6272005c,0x7643003f,0x69dc0633,0xfb1a004c}},	//   _młod, uony, _gare, _טורמ
  { {0x5e580053,0x25a90064,0x7bdd0634,0x3f990635}},	//   דיגע_, ğal_, _kasu, kasu_
  { {0x2d9804f9,0x3f990085,0xa3ea000b,0x27ed0636}},	//   zare_, jasu_, माग_, _unen_
  { {0x3f990026,0x36d4059c,0x76430637,0x04560015}},	//   dasu_, _котр, pony, دلية_
  { {0x81850010,0x2d980011,0x386d0638,0x7bdd007c}},	//   ыгож, xare_, _hier_, _lasu
  { {0x63ae002d,0x2d980639,0x45b6000a,0x98480045}},	//   áiné, vare_, _תפעל_, _uşă_
  { {0x7bdd063a,0xafdb063b,0xc952000a,0x6d5a006f}},	//   _nasu, dløs, ממי_, ýtam
  { {0x539a0008,0x765a00f2,0x7e600111,0x2d98063c}},	//   _ניסו, _yhty, ïmpo, tare_
  { {0xb7c20024,0xc332000a,0xf2d2000a,0x386d063d}},	//   ēģin, _פוג_, _לעד_, _lier_
  { {0x7bdd063e,0x2d9803c9,0x721a000a,0x69dc063f}},	//   _basu, rare_, _רוצח, _rare
  { {0x44e301e2,0x59c6005d,0x69dc0640,0x2d980641}},	//   _mı_, र्नर, _sare, sare_
  { {0xc017000a,0x6272002a,0x44e30061,0x69dc0642}},	// [6e0] _תקפו_, _głod, _lı_, _pare
  { {0xeef70643,0x3d070030,0x38bc0052,0x0000006a}},	//   _עמיר_, ívvá_, tír_,
  { {0x44e30064,0x3ea000cb,0x290e001a,0x778603ae}},	//   _nı_, _hvit_, áfa_, глез
  { {0xe73a005f,0xb8dc005d,0xaaac005d,0xf0b60053}},	//   нее_, _आम_, _चिपक, טלער_
  { {0xc7a30063,0x69dc0644,0x386d016b,0x8f9b000a}},	//   сичк, _tare, _dier_, תיני
  { {0x386d0645,0xceb3039e,0x7995059b,0x3f99002a}},	//   _eier_, מיד_, _gezw, zasu_
  { {0x6282014c,0x7ae40646,0xd4c60015,0xa8d8000a}},	//   _stoo, lvit, اغتي, _בַּת
  { {0x7995005c,0x28030089,0x386d0647,0x7ae40648}},	//   _zezw, ěrná_, _gier_, ovit
  { {0xf5b60115,0xd40303a9,0x7ae40649,0x7bdb000a}},	//   _مصاد, сящи, nvit, תקפו
  { {0xddcd0089,0x660100e8,0x7e600079,0x7ae4064a}},	//   _staž, _golk, ïmpl, ivit
  { {0x463b00b2,0xddcd0011,0x09f70008,0x3f99064b}},	//   _טעמע, _luaţ, אמים_, tasu_
  { {0xb84a0010,0x63a2003f,0x6272002a,0xb4fb000a}},	//   млiв, _udon, _płod, _רפאי
  { {0x6d4001e2,0xcf270029,0x7bdd0375,0x20190091}},	//   şmal, ارجي, _rasu, ūrio_
  { {0xd2b7013a,0x27310023,0x44e30064,0x21760004}},	//   _עלות_, ạng_, _yı_, _судр
  { {0xdb0d002d,0x317b0135,0x7514000a,0x6272002a}},	//   rgaí, _ארומ, בַּע_, _włod
  { {0x6006001a,0x60c5007c,0xafdb064c,0x0000006a}},	//   _dóms, _ähma, rløs,
  { {0x7ac70010,0xdcfc0091,0x7ed70015,0x59c6000b}},	// [6f0] ысве, karė, _إزعا, र्भर
  { {0x386d003c,0xdb16002e,0xafdb0293,0xfaa80015}},	//   _sier_, reyð, pløs, اهلي_
  { {0x7bdd0005,0xdcfc0007,0x4426064d,0x7d7a000a}},	//   _tasu, darė, _omo_, _בנתו
  { {0x7995005c,0xe84b0115,0x2ee901c2,0xa09b000a}},	//   _wezw, رجان_, _kraf_, תיאט
  { {0x2d94002c,0x6b8d064e,0xcb9a0008,0xf7450001}},	//   ždeň_, mbag, _בסרט, јело
  { {0x6b8d064f,0x68e30650,0x59840033,0x386d0651}},	//   lbag, ånds, _глёб, _wier_
  { {0xd6180015,0x386d0652,0x66010653,0xa9c400e2}},	//   دتنا_, _tier_, _volk, _усяк
  { {0x66010654,0x92f50058,0xf2d9009a,0x0000006a}},	//   _wolk, لأخض, نبخش_,
  { {0x21f50191,0xa3ea000b,0x929d002a,0xe2990054}},	//   аїнс, माज_, myłk, њао_
  { {0x0322008f,0x20c50036,0xcad8000a,0x20da0085}},	//   ідэн, айом, רוזת_, kšić_
  { {0x2ee90026,0x6032003d,0xd3b9005e,0x7ae40655}},	//   _araf_, lāmi, _алеї_, zvit
  { {0xa4fa00b4,0x2ee90026,0x7ae400f2,0xb4fa000a}},	//   _בלעט, _braf_, yvit, _בפעי
  { {0x636b01e2,0xc7d60008,0x7d0100c0,0x60320024}},	//   _dönü, בורי_, älsn, nāmi
  { {0x91fc03eb,0x6d400064,0x62890656,0x6b8d0049}},	//   rmāc, şmam, mpeo, ebag
  { {0x3b960657,0x8b960658,0x6da3006b,0x2ee90546}},	//   ијат, ирач, юира, _eraf_
  { {0xe8e00023,0x6b8d0035,0xba760029,0x3911004c}},	//   _hiệp_, gbag, لائت, _סטאַנ
  { {0xba260033,0x6032003d,0xa3d6000b,0x6da60659}},	// [700] адак, jāmi, ाजत_, _кипа
  { {0xac760086,0x5e9b0008,0x7ae4065a,0x0e9b000a}},	//   _پادش, _שביק, rvit, _ששיל
  { {0xa3b6014e,0x636b0064,0x6b8d065b,0xdb0d0264}},	//   _जाल_, _yönü, bbag, čkác
  { {0xdb2000dc,0xbc7b0008,0x929d005c,0xf8a90018}},	//   ítóg, _שנכת, szły, ادله_
  { {0x6aad065c,0xdcfc0091,0x3946002a,0x2c7c0030}},	//   craf, tarė, łos_, _híd_
  { {0x4426065d,0x7aeb0134,0xceb30008,0xe4a60076}},	//   _smo_, ægte, קיו_, арио
  { {0xd497065e,0x44260020,0xdcfe003d,0xa3ba00c3}},	//   ары_, _pmo_, _iepē, ناظر_
  { {0x7c360026,0xa686065f,0xb7da0015,0xf2c60660}},	//   nnyr, _влад, _جورا_, асон
  { {0xd4670054,0xcb36004f,0x76d30058,0xf74a02be}},	//   шиће_, יאֵי_, _ويفض, _شجره_
  { {0xdb0d002e,0x82330015,0x69c80061,0xafdb00cb}},	//   ngaá, ْرَا, _öded, eløp
  { {0x9f91002e,0xe3ba0661,0xe8e00016,0x8027012c}},	//   _búðu_, _абе_, _diệp_, لرحم
  { {0x10730010,0x2ee90045,0xaffd005e,0x20730033}},	//   ўляю, _praf_, хомi, ўляў
  { {0x2bba000b,0x2475003d,0xd6220138,0x0000006a}},	//   इलना, _rāmi_, _лiда,
  { {0xf0b7002b,0x7126002b,0xd24f005e,0x6f1d0662}},	//   دایش_, _پرتل, _єц_, rzsc
  { {0xac19017c,0x61fc0123,0xdde10030,0xd01b0663}},	//   гову_, örlu, ítői, _афп_
  { {0xb0680010,0xa3b6000b,0x2ee90664,0x8fa40054}},	//   _крыж_, जलि_, _traf_, _даће
  { {0x6b8d0665,0xf9930029,0xda780666,0xbb840015}},	// [710] rbag, قبض_, аях_, تلقي
  { {0xd999003b,0xa3c8000b,0xe9990015,0x6272002a}},	//   انات_, _लॉस_, اناغ_, _złoc
  { {0x6aad0064,0xf0930053,0x29070011,0xa3d6000b}},	//   sraf, ַנס_, âna_, ाजा_
  { {0x6aad0667,0x6032003d,0xd7590015,0x9cd6000a}},	//   praf, tāmi, هلات_, _פורה_
  { {0x7c2d0668,0x929d002a,0xa6c902ed,0x0000006a}},	//   miar, ryłk, улла_,
  { {0x929d005c,0x5a440033,0xea76000a,0x7c2d0669}},	//   syłk, _дэса, _לגשר_, liar
  { {0x361a002b,0x6032003d,0x5884066a,0x0000006a}},	//   درنگ_, sāmi, _мыта,
  { {0xf77f01e2,0xa9540036,0xad3800a3,0xc2c50015}},	//   _üç_, _єкті, ינוס_, ميبي
  { {0xa3d6005d,0xa7150001,0x26cd003f,0x97150033}},	//   ाज़_, _удаљ, _upeo_, _умац
  { {0xe61300b0,0x7c2d066b,0x03220033,0xe1f905a7}},	//   _بشر_, hiar, ядын, уго_
  { {0xd24e0086,0x6272002a,0xb636004c,0xafdb00cb}},	//   رچه_, _płoc, _פרעס_, tløp
  { {0x9f06003b,0x6d400064,0x60060077,0x629d0030}},	//   موجو, şmak, _cómp, ásos
  { {0x201e00df,0x5285003b,0x91e5066c,0xc1780007}},	//   ėti_, _التك, _голе, odėl_
  { {0xe29f0084,0x6272005c,0x442d066d,0x644903f8}},	//   áðu_, _włoc, lie_, loei
  { {0x0c790080,0x7c2d066e,0xf652000a,0x6272002a}},	//   исты_, fiar, פצל_, _tłoc
  { {0x442d066f,0x2c7c0046,0x01340067,0x7c2d0670}},	//   nie_, _víd_, _بعهد, giar
  { {0xc27a0053,0x63a60671,0x627a004c,0x4c350033}},	// [720] ָרעי, ókni, ָנענ, цэрт
  { {0xb95a0015,0x69c10030,0x442d0672,0xceb3004f}},	//   هجاء_, _ölel, hie_, _זיז_
  { {0xf8aa0001,0xcb09000f,0x442d0673,0xe7860674}},	//   увек_, על_, kie_, було
  { {0x442d0675,0xdcfc003d,0x7c2d0676,0x0000006a}},	//   jie_, harī, ciar,
  { {0xdcfc0048,0xf62a0036,0xf7460080,0x3ea20677}},	//   karī, ліки_, щедо, nskt_
  { {0x442d0020,0x9e7b0053,0x96330033,0x27e00678}},	//   eie_, אנספ, пніц, žin_
  { {0xdcfc0048,0x485a0010,0x54e60015,0x344a0004}},	//   darī, _браў_, إستق, лчин_
  { {0xccf3000a,0x442d0679,0x4c9b000a,0x3cc9000a}},	//   לכו_, gie_, אבקו, ׁלוּ_
  { {0x386600c0,0x6032003d,0xe73a067a,0x41e600e2}},	//   mmor_, nāmu, _сеа_, біна
  { {0x7c2d04ed,0x442d067b,0x867b000a,0xdcf5002a}},	//   ziar, aie_, _ערבו, lczą
  { {0xf9930008,0xdcf5005c,0x442d067c,0xa158067d}},	//   הרת_, oczą, bie_, рану_
  { {0x3957013a,0xa93b0053,0x442d067e,0xb0a9000b}},	//   משים_, רײטי, cie_, _किरग
  { {0x7c2d067f,0xdcf50535,0x0000006a,0x0000006a}},	//   viar, iczą,   ,
  { {0x633b0053,0xdb0d016e,0x7c2d002a,0x211a0015}},	//   _געדױ, lgaç, wiar, _متعب_
  { {0x0ba70010,0x6c850015,0xe0860015,0x6a690091}},	//   йшам, تلزم, _اجتي, _užfi
  { {0x388100df,0x0000006a,0x0000006a,0x0000006a}},	//   _nėra_,   ,   ,
  { {0xda6700c3,0xdb0d016e,0x99990680,0xb9990681}},	// [730] مائي, igaç, икат_, ивах_
  { {0x6fb50074,0xff180008,0x127b0053,0xdd910015}},	//   _امکا, _לקחת_, טאמע, _تود_
  { {0x7c2d0682,0x6d8c000a,0x75e90030,0x58d9009b}},	//   piar, _עָזְ, nöző, рдея_
  { {0xc1c4005d,0x442d010c,0x69d8006f,0x2a7901c2}},	//   वभुग, xie_, ôver, _tusb_
  { {0xb9e7005e,0x442d0683,0xb6c7004a,0xc9870684}},	//   _ліви, vie_, ссей, _губи
  { {0xd9fd005d,0x442d0685,0x2d83005c,0x853c0007}},	//   _उचित_, wie_, ncje_, _idėj
  { {0xf6500086,0x442d0686,0x16380015,0xdcfc003d}},	//   رئه_, tie_, حسنة_, varī
  { {0x24090080,0x1d180008,0xbd18000a,0xd2a9004a}},	//   рнии_, מקור_, מחוז_, акие_
  { {0x2d83005c,0x13060080,0x764a003f,0x03250036}},	//   kcje_, жный_, bofy, юдин
  { {0xaadc0053,0x442d0687,0x764a002a,0x69d70688}},	//   רחזר, sie_, cofy, nexe
  { {0x7bd6003f,0xdbc6007c,0x442d0689,0x89ec004f}},	//   yeyu, mööd, pie_, רַחֵ
  { {0xa3b6014e,0x6286006f,0xe29f001a,0x3ea202dc}},	//   _जाए_, íkoc, áðs_, tskt_
  { {0x2d9a000c,0xb7da0008,0x6d580046,0x7f19005e}},	//   _pepe_, בקרי, _úvaz, біру_
  { {0xf2670054,0x667a004c,0xdcf5002a,0xc5f9000a}},	//   _уђем, יטשק, zczą, ׁפָט
  { {0xd24e003b,0xc5f20008,0xdcf5005c,0x69d7068a}},	//   _جنو_, ודם_, yczą, dexe
  { {0x6ab6002e,0x3ea2001a,0x63bb068b,0x6e2e0030}},	//   tuyf, pskt_, ngun, sibb
  { {0x8d760087,0xa3ab000b,0x2d9a068c,0xfaaa002b}},	// [740] _وادا, कृय_, _tepe_, شهاي_
  { {0x38660034,0xdb0d001a,0x63bb0049,0x200202d8}},	//   wmor_, rfað, hgun, ljki_
  { {0x69d9005d,0x39350010,0x61e3068d,0x0000006a}},	//   नज़ी, пэцс, _manl,
  { {0xb8f2014e,0x46ea068e,0x6d5e0192,0x8bb60015}},	//   _वह_, иден_, _izpa, _بإدا
  { {0x4e0e005d,0x8703004a,0x66da004a,0x3860003d}},	//   _हवाई_, дяще, рьер_, ķir_
  { {0xa3cc000b,0xb0a9000b,0x5ee9000a,0xcb13000a}},	//   श्न_, _किंग, מַצְ, _חלש_
  { {0x9f450089,0x6272002a,0x38810091,0x08c302d9}},	//   ělé_, _błon, _tėra_, _обрн
  { {0x61e30234,0x63bb0509,0x2c17004c,0x799c068f}},	//   _aanl, ggun, ַקיש_, _herw
  { {0xe8530086,0x75d60002,0x6272002a,0x2d83002a}},	//   _آنقد, _ويرا, _dłon, ycje_
  { {0x32180050,0x61e30690,0xd25a0180,0x27e402ce}},	//   óry_, _canl, јци_, _hamn_
  { {0xb97b0008,0xd499005e,0xe97b004c,0x27e60577}},	//   יניי, _грі_, יניש, odon_
  { {0x68e30134,0x69ca005d,0x27e60691,0x661d0091}},	//   ændi, स्ती, ndon_, _įski
  { {0xee3f0089,0xc2c40015,0x91780016,0x69ce0692}},	//   krýt_, _ريغي, hởi_, _obbe
  { {0xd3440074,0x61e30176,0x2e4b02c8,0x799c002a}},	//   _ویژه_, _ganl, рямо_, _nerw
  { {0x2d83002a,0x2cb80693,0xbc0702ed,0x660801d0}},	//   rcje_, gurd_, очай, _modk
  { {0x27e60694,0x6aa4003f,0x27e402ce,0x61e30061}},	//   jdon_, fsif, _namn_, _zanl
  { {0xa3cc005d,0x9b6b0063,0x61e30064,0x2d83005c}},	// [750] श्य_, ршва_, _yanl, pcje_
  { {0x3eb90020,0xdb040695,0xfe730015,0x27e60696}},	//   must_, egió, _تدع_, edon_
  { {0x3eb90005,0xb86b000d,0x4dda000a,0x25fe000b}},	//   lust_, ајде_, _החתו, लानी_
  { {0x69ce0697,0xc157000a,0x63a00085,0xaa7b001a}},	//   _ebbe, חשבו_, jamn, _brýt
  { {0xf770003b,0x3eb90020,0xdbc60020,0xd7c8002b}},	//   ناه_, nust_, tööd, تونه_
  { {0x6272005c,0xd5b10015,0x8a7a000a,0x6604005e}},	//   _słon, رفع_, _לאשת, мпіа
  { {0x1c0f014e,0x79850026,0xcd980008,0x3eb9007c}},	//   _सवाल_, mchw, חדות_, hust_
  { {0xd7c90074,0x3eb90698,0x6d3c0008,0x63bb00b8}},	//   _دوره_, kust_, יתונ, ugun
  { {0x61e30035,0x97150033,0xf2c50015,0x3eb90699}},	//   _panl, _эмац, أْخُ, just_
  { {0x3eb9069a,0x321e069b,0x2ea8000b,0x35b40342}},	//   dust_, ghty_, _कटौत, _обур
  { {0x61e3069c,0xf5590015,0xa3bb0115,0x79850012}},	//   _vanl, _الاب_, _ناشر_, ichw
  { {0xd3b80036,0x54370086,0x3dd80034,0xb4e7000b}},	//   _душі_, _برطر, werw_, यटी_
  { {0xdbd90084,0x2f560142,0x237600a2,0xe803000b}},	//   væðu, ятос, _عمود_, _रचना_
  { {0x32130016,0x4df50033,0xb5fd0091,0x1d0a004a}},	//   _ôxy_, мяст, _pušy, беги_
  { {0xdbd9002e,0xed5a069d,0x7aef069e,0x27e6069f}},	//   tæðu, сов_, _arct, ydon_
  { {0x799c06a0,0x6c360029,0xa09a015b,0x3eb906a1}},	//   _serw, أفرا, _פיפט, bust_
  { {0xdbd9002e,0x799c013c,0x25fe000b,0x5fbb000a}},	// [760] ræðu, _perw, लामी_, _הצפנ
  { {0xa3ab014e,0x19b90010,0x6aa406a2,0x2cb80012}},	//   कृत_, жуць_, rsif, purd_
  { {0xa3cc000b,0x6d7b000a,0x7d7b000a,0x48b6006b}},	//   श्ड_, _לאיח, _לניו, ящат
  { {0xdcf5005c,0x799c00dd,0x798506a3,0x6b9d0034}},	//   jczę, _werw, achw, _gesg
  { {0x799c06a4,0x6f7b000a,0x1779005e,0x27e606a5}},	//   _terw, צְאו, ісць_, rdon_
  { {0x26c600f2,0xd6220033,0x69ce0079,0xd49a06a6}},	//   rtoo_, _кiна, _ubbe, бри_
  { {0x628b0026,0x80da000b,0xa5070054,0x25fe000b}},	//   _atgo, _बनें, зеја_, लाबी_
  { {0xb6030048,0x493b000a,0xb4ac000b,0xa2d3000b}},	//   īšan, _הגלו, _कटी_, _बैङ्
  { {0x27f70107,0x1867005e,0xb603003d,0xf2c30033}},	//   šení_, _хати_, ūšan, нсэн
  { {0x3eb90005,0x63a006a7,0xe8e00016,0xdcf5002a}},	//   vust_, samn, _nhịp_, aczę
  { {0x3eb906a8,0x63a00030,0x41af0065,0x69c10065}},	//   wust_, pamn, _फ़ारस, र्टी
  { {0x3eb90005,0x9f350036,0x8fa400d7,0x34fb000a}},	//   tust_, демі, наџе, _להבד
  { {0x79850026,0x6b9d06a9,0xb4ac000b,0x0000006a}},	//   ychw, _resg, _कटु_,
  { {0x7e280033,0x3eb906aa,0xacf906ab,0x20d60058}},	//   піса_, rust_, онгу_, _فتعج
  { {0x3eb90020,0x61f80161,0xb2290015,0xd657000a}},	//   sust_, _invl, _بأنك_, פילת_
  { {0x5c7406ac,0xb1570008,0x31570008,0x9f050015}},	//   елст, _מסוג_, _מיון_, _يوغو
  { {0x8e840015,0x600c000a,0x7cf6001a,0xdce70061}},	// [770] _كليه, _לִזְ, týrð, rajı
  { {0xdce70064,0xdcf5005c,0xf1cf000b,0xa3cc000b}},	//   sajı, zczę, त्पन, श्त_
  { {0xdb0d002e,0x798506ad,0x6d88000a,0x91fc003d}},	//   ngaú, rchw, _מָרְ, emāk
  { {0x7985018b,0x69c80064,0xe719006e,0x48150033}},	//   schw, _öden, ييات_, ьмес
  { {0xf7730015,0x79850034,0xe6880058,0x0000006a}},	//   راص_, pchw, كننى_,
  { {0x8afa0008,0x7aed0546,0x0000006a,0x0000006a}},	//   _והשי, mvat,   ,
  { {0x7bcd003f,0xa506006b,0x7aed06ae,0x999a0030}},	//   ofau, деща_, lvat, cipő_
  { {0xfcaa00b4,0x3ea9022d,0x61e80026,0x657a00aa}},	//   קיפּ, _ovat_, eddl, _egth
  { {0x69ca005d,0x37c40015,0x7aed06af,0x66120030}},	//   स्वी, _سيلف, nvat, ükkö
  { {0x7aed00dc,0x80a9004a,0x063b00c3,0xa22900fd}},	//   ivat, овов_, _اسرع_, іжна_
  { {0x7aed06b0,0x34940063,0xa3c8000b,0x4420005e}},	//   hvat, _захр, _लॉक_, _зi_
  { {0x7aed06b1,0xa29500ce,0x0000006a,0x0000006a}},	//   kvat, _жаді,   ,
  { {0x6d490011,0xd4340015,0x5f7600c3,0x6272002a}},	//   şeal, _ثعلب, بادر, _złom
  { {0x7a200014,0x7aed060a,0x59cf000b,0x32450058}},	//   _köte, dvat, स्मर, _تنتف
  { {0xc0a80086,0x7aed06b2,0x602606b3,0x25fe000b}},	//   _فايل_, evat, _одка, लाती_
  { {0xa09a0008,0x8fa60086,0x7a2000c0,0xb09a039e}},	//   _ויקט, _کمکه, _möte, _ויקר
  { {0x0b170029,0x2eff00b8,0x6d450390,0x7aed025d}},	// [780] وقفة_, äuft_, _exha, gvat
  { {0xe9d706b4,0x9f9d001a,0x4a4306b5,0xed5a00ce}},	//   мку_, læði_, внув, _моп_
  { {0x49990036,0xd7e60036,0x8dfb000a,0x18a3006b}},	//   яття_, діло, _והית, вахм
  { {0x6d4001e2,0x9f4006b6,0xc7af0015,0x2ef200aa}},	//   şmas, _unió_, لّم_, _kryf_
  { {0xc7a303f1,0xa5f80010,0xa3c8005d,0x61e80026}},	//   тичк, зелу_, _लॉग_, yddl
  { {0x6272002a,0xe1cf000b,0x3eaf02de,0xd90d002b}},	//   _płom, त्मघ, _ægte_, _گیم_
  { {0xa5c4000b,0x68e3063b,0x442f06b7,0x0000006a}},	//   _राठौ, ændt, _bmg_,
  { {0xd4670001,0x690b0008,0xd90d002b,0x6b9606b8}},	//   мије_, _וּמְ, _دیم_, nbyg
  { {0x94020086,0xc2740054,0x86c6002b,0xd40306b9}},	//   فوژه, нлиј, _زيان, тящи
  { {0xf8d2014e,0x8afb0053,0xe4d60015,0xdb1506ba}},	//   _सहाय, קהיי, _يتاب, ébéc
  { {0xd130003b,0xe8df0092,0x9f450089,0x7aed044c}},	//   امج_, _buộc_, ělí_, zvat
  { {0xe8df0023,0x7aed0057,0x2497002b,0xeb9f00cb}},	//   _cuộc_, yvat, _آنند_, _fløy_
  { {0xd6d90050,0x2ef20026,0x6b9606bb,0x98b80073}},	//   _były_, _cryf_, dbyg, _tyrė_
  { {0xe7310008,0x6ab600dd,0x2ef200aa,0x3e64008c}},	//   אֵל_, dryf, _dryf_, yöte_
  { {0x1bd50063,0xfe240080,0x645c0024,0xc1bb000a}},	//   новя, тьян, _īrij, _ומוש
  { {0xec680036,0xa08b000a,0x2019003d,0x6b9606bc}},	//   друк_, _וְזִ, īris_, gbyg
  { {0x2ef206bd,0xc054000a,0xcb34006b,0xeaf80015}},	// [790] _gryf_, _בזק_, ветъ, وركت_
  { {0xe9d30029,0xc95b0010,0x9e67002b,0xdcfc0045}},	//   ضغط_, оўе_, _تابن, ucră
  { {0x7aed0607,0x5884054f,0x5c750666,0x2019008c}},	//   svat, выча, _плот, oksi_
  { {0x201900e8,0xad26002b,0x0137000a,0xe894005e}},	//   nksi_, _سرپو, ורבת_, таць
  { {0x201900f2,0xfbb6000a,0x59c7000b,0x76c40015}},	//   iksi_, _אפרת_, _लापर, نغول
  { {0x644200f2,0x06080010,0xff180008,0x56920054}},	//   _ajoi, мнік_, וקדת_, ћајт
  { {0x57b70058,0xbd9c004f,0x0000006a,0x0000006a}},	//   _يحرز, חסות,   ,
  { {0xe7950086,0xc4f80029,0x13090036,0xe7390026}},	//   _سارک, بعها_, зний_, _ddŵr_
  { {0x9f9d0084,0xeb920008,0x7c3a06be,0xc8790061}},	//   væði_, נָה_, étri, _iiş_
  { {0x201900f2,0x7a2000b8,0xcb58000a,0x410506bf}},	//   eksi_, _töte, וסחה_, езов
  { {0x79a8000a,0x2089006b,0xd5a6002b,0x6e3506c0}},	//   וֹרַ, яйни_, _سلنی, dizb
  { {0xcdc9013a,0x59cf000b,0x80a0000b,0x3cf90065}},	//   _לך_, स्तर, _खबरे, _उपजे_
  { {0xef17005f,0x9f9d0084,0x1e83005e,0x443f06c1}},	//   емя_, ræði_, ллям, mnu_
  { {0xc6920135,0x201906c2,0xfce606c3,0x443f06c4}},	//   ראם_, aksi_, ного, lnu_
  { {0xa3cc005d,0x52740086,0x621a00f3,0x443f06c5}},	//   श्व_, _شاهز, _מוסק, onu_
  { {0x443f06c6,0x98ac003d,0xaec60098,0x68e2002a}},	//   nnu_, ūlīt_, _збил, łodk
  { {0xdd2f0089,0xbdfa0087,0x645b008c,0x6c750033}},	// [7a0] _měře, _فردا_, ilui, турх
  { {0x2b9e0092,0x8e970008,0x6b9606c7,0x443f06c8}},	//   ắc_, _רדיו_, sbyg, hnu_
  { {0x69c801e2,0xcd360086,0xf1c2000b,0x2d9806c9}},	//   _ödem, _سردب, _शासन, mbre_
  { {0xad370008,0xc1bd005d,0x96ea017f,0xad1b000a}},	//   _טניס_, ्भुग, зька_, _זוטר
  { {0x68e30134,0x443f06ca,0xc8790061,0x2d9806cb}},	//   ændr, dnu_, _diş_, obre_
  { {0xd49a06cc,0x7f3b000a,0x7c2406cd,0x97130033}},	//   при_, התנג, lhir, ыміц
  { {0x443f06ce,0x24e7000d,0x2019008c,0x1dd2000b}},	//   fnu_, емји_, yksi_, द्यत
  { {0x6b7b0053,0x443f06cf,0x66e606d0,0xb866002b}},	//   ּרינ, gnu_, _поба, _سازو
  { {0xe7d501e2,0x41c60033,0x7c2406d1,0xe3af0015}},	//   lığı, нёна, ihir, حرى_
  { {0xd5e90029,0xe8df0016,0x69de06d2,0x443f06d3}},	//   _يعلن_, _nuớc_, nepe, anu_
  { {0x3a37013a,0x9f40002e,0x94d30029,0xd13a0036}},	//   תרים_, _snið_, _ميلش, яхи_
  { {0x645b06d4,0x443f06d5,0x351b000a,0x69de06d6}},	//   clui, cnu_, _מובנ, hepe
  { {0x4ea70010,0x7c24003f,0xdefb0033,0x6e350012}},	//   эрна, dhir, чын_, tizb
  { {0x127b0053,0xa3cc000b,0x12fb000a,0x7c240405}},	//   _זאגע, श्र_, _מהדב, ehir
  { {0xc0e300d0,0x70f30015,0x5d840015,0x69de06d7}},	//   _бојк, _مسيئ, الفل, depe
  { {0xe7d501e2,0x515b0008,0x8bc402bb,0x7c2406d8}},	//   dığı, _מכוו, лсуд, ghir
  { {0xc87f0064,0x61ea002e,0x2d9806d9,0x4a5506da}},	// [7b0] ışma_, _kafl, bbre_, вкас
  { {0xa93d0010,0xe919005e,0x443f06db,0x69de06dc}},	//   одзi, мозі_, znu_, gepe
  { {0x443f06dd,0x69c2000b,0x59c40015,0xe578003d}},	//   ynu_, _लारी, ايمك, _kaķu_
  { {0xf773002b,0x787a0046,0x63a206de,0x7c2406df}},	//   هاش_, _půva, _neon, chir
  { {0x4424002f,0x91780092,0x7ac70286,0x443f06e0}},	//   dhm_, hời_, _ясне, vnu_
  { {0x3eb9003e,0x69de0011,0xc1780007,0xe6180036}},	//   irst_, cepe, ndės_, нді_
  { {0x443f06e1,0xdb0d002e,0xd7950015,0x9f4c0046}},	//   tnu_, ngaþ, _للأخ, ědé_
  { {0x443f06e2,0xb6f50054,0xd87402be,0x645b005b}},	//   unu_, _избј, _ماقب, ului
  { {0x04560029,0x320e003f,0x645b06e3,0xe2910015}},	//   خلية_, _bofy_, rlui, جذب_
  { {0xd24e06e4,0x645b049c,0x443f06e5,0x44240012}},	//   يني_, slui, snu_, ahm_
  { {0x443f06e6,0x61ea0034,0x59c6000b,0x65190015}},	//   pnu_, _dafl, र्टर, _تقاس_
  { {0x69de06e7,0xc952015b,0x6272002a,0x7a200123}},	//   zepe, שמט_, _ołow, _möta
  { {0x69c7016f,0x0ef90010,0xdb060264,0x44e30030}},	//   _ocje, нэры_, _odká, _hű_
  { {0xdd920087,0xc332039e,0xc58e0016,0xdee30099}},	//   شور_, _דוד_, hồng_, јори
  { {0x6da30124,0x27310092,0xa00a0029,0x7c2406e8}},	//   риса, ạnh_, _يقتل_, thir
  { {0x8c43000d,0x60d60008,0x69d50012,0xc1780091}},	//   аесе, _יוצא_, _abze, adės_
  { {0xf9920115,0xaf4a0015,0xd5e1000b,0x7c2406e9}},	// [7c0] لبا_, _تشغل_, फ़ाज, rhir
  { {0x59760086,0xba230010,0xceb90089,0xe7d50064}},	//   نداز, адук, áře_, tığı
  { {0x7bdf001c,0x07a60010,0x291c0264,0x69de06ea}},	//   bequ, ваен, áva_, repe
  { {0xe73a06eb,0xca29000a,0x69de06ec,0x0000006a}},	//   мее_, חם_, sepe,
  { {0xa6fa0029,0x6272005c,0x91780016,0x7c3a0003}},	//   بعاء_, _głow, iới_, étru
  { {0xceb30008,0x4a750080,0x63a20020,0xb8960015}},	//   שיג_, _быст, _seon, _للسع
  { {0x04c70029,0xa491002b,0x7a200123,0xf79a0015}},	//   نووي_, میلت, _göta, _ينسب_
  { {0x61ea0176,0x94230001,0xa7850015,0x3eb9001a}},	//   _safl, имје, _مشكو, yrst_
  { {0x7c2304f9,0x59cf005d,0x3254067a,0xa6ca012c}},	//   _înre, स्वर, лвир, _زوال_
  { {0x6625002a,0xd5af00c3,0x05c9000b,0x3f80016e}},	//   ątkó, _وفق_, _रायब, _agiu_
  { {0x859b011f,0x850603c4,0x9f4e0227,0x3ea002f2}},	//   _חשבו, _جوان, čným_, _awit_
  { {0xc953013a,0x94a90029,0xdcea0046,0x7ae406ed}},	//   ימת_, _أطلق_, šněj, kwit
  { {0x61ea06ee,0x3eb9044d,0xf38f0016,0xd5c90065}},	//   _tafl, urst_, oảng_, _रामज
  { {0x6e940080,0xf773011f,0x7bc406ef,0x82d7000a}},	//   риру, יקר_, egiu, _סווג_
  { {0x62720050,0xfb87008f,0xc1030029,0x1dd2005d}},	//   _słow, вызн, _نووي, द्धत
  { {0xd10f014e,0x5fa7014e,0x7bc402d7,0xa1770008}},	//   ाहरण_, _ख़िल, ggiu, _בעוד_
  { {0xc3340008,0xda670015,0x7bdf06f0,0x49cb055f}},	// [7d0] אוּ_, نائي, requ, дуем_
  { {0xf7f40086,0x4d990127,0x2ee906f1,0x200b06f2}},	//   یسند, _якою_, _isaf_, ljci_
  { {0x5fa7000b,0x3da40033,0x6d41006f,0xbc8b0015}},	//   _ख़ाल, _трыб, úlad, _تضخم_
  { {0x787a0089,0xd7890087,0xc86406f3,0x9d1a004f}},	//   _důvo, رنتو_, атчи, _נורט
  { {0x1754005e,0xdb0d007c,0xd7e400ce,0xc58e00a1}},	//   авця, ngaü, ріхо, rồng_
  { {0x2636005c,0xc98706f4,0xbb76004f,0x1994058c}},	//   słon_, _шуми, _תעשו_, _варя
  { {0xadd8000a,0x64e80015,0xc9580033,0x7a200030}},	//   דווח_, َّهِ_, _аўт_, _kötn
  { {0x32cb06f5,0xd46602c8,0x1be3000b,0x7d7c000a}},	//   tøy_, лище_, ख़िल_, ונוו
  { {0x659506f6,0x27ff008c,0xdb040030,0x923906f7}},	//   _базу, _inun_, taié, ечну_
  { {0x2d810023,0xc5fb00a2,0x95d8004a,0x6d5a007c}},	//   _nghe_, _تعرض_, _идут_, ütak
  { {0xe4cb0074,0x69c506f8,0x64c40015,0x7bc40091}},	//   _زبان_, ighe, _نيلل, ygiu
  { {0xf3f00029,0x25a506f9,0x91fc003d,0xdb040030}},	//   _وأن_, _hell_, elād, saié
  { {0x27ed0176,0x25a506fa,0x2fdf0020,0xdcee0061}},	//   _maen_, _kell_, õuga_, vabı
  { {0x02450015,0x63a906fb,0xf1c60046,0x3d28002b}},	//   _حَتَ, laen, žáru_, نتزی_
  { {0x91fc0048,0xdcee0064,0x27ff0064,0x61e106fc}},	//   rmāt, tabı, _onun_, mell
  { {0x61e1022d,0x75160053,0x63a906fd,0x40920015}},	//   lell, אַמע_, naen, _الير
  { {0xab6606fe,0xcaa50015,0x4a4606ff,0xab270148}},	// [7e0] увал, لصلي, гнав, гота_
  { {0x25a502d7,0xdcee01e2,0x787a0089,0xef1f0064}},	//   _nell_, sabı, _půvo, zcük_
  { {0x32360053,0x60c10700,0x63a90701,0x27ed0702}},	//   נטען_, nulm, kaen, _baen_
  { {0x63a9003f,0x7e7e010c,0x76430703,0x385a012c}},	//   jaen, _hipp, enny, رشاد_
  { {0x61e10704,0xf6d30015,0x8f9b000a,0x25a50116}},	//   kell, مزود, גיני, _bell_
  { {0xf38f0023,0x25a50705,0x60c10706,0x4add000b}},	//   uảng_, _cell_, kulm, _नैटव
  { {0x83fd00dc,0xda5b0008,0x25a5052a,0x61e10707}},	//   klőd, _נכלל, _dell_, dell
  { {0x44220014,0x61e100f2,0x83fd00dc,0x76430049}},	//   ók_, eell, jlőd, anny
  { {0xe3af0029,0x25a50708,0x57460709,0xe64a006b}},	//   سري_, _fell_, _снаб, _зпад_
  { {0xf1c60089,0x20000011,0x2fc9002d,0x61e1070a}},	//   _část_, _anii_, _scag_, gell
  { {0x31780012,0xdb0602de,0x73c60040,0x63a9070b}},	//   ärz_, _udkæ, _ميام, baen
  { {0x0eeb0080,0xd259003d,0x82a6070c,0x25a502ad}},	//   ньги_, ruņa_, _бадж, _zell_
  { {0xe296000d,0x6fc6000b,0x33170015,0x6272002a}},	//   _среќ, _वारं, _مزود_, _błot
  { {0x6d5e04a9,0x61e1070d,0x50d3002b,0xc0aa0015}},	//   _bypa, cell, جزیر, _كابل_
  { {0xec6b070e,0x7e7e00da,0x91fc003d,0x224b006f}},	//   ерак_, _dipp, rlād, écke_
  { {0x60df0030,0xdb060123,0x9b950195,0x5d7802bb}},	//   őzmé, _odkä, риац, уйся_
  { {0x91fc0024,0xdfd8006b,0xdefb0033,0x5a35070f}},	// [7f0] plād, _същ_, _чый_, анат
  { {0x321e005c,0x633b004c,0xc7b90030,0x69c50710}},	//   nkty_, געמױ, _elől_, ughe
  { {0xae5c000a,0x9e7a000a,0xf9900015,0x69c50711}},	//   _אכזר, _שנתפ, سبل_, rghe
  { {0x62720712,0x765a0713,0x25a5003e,0x4c9a000a}},	//   _złot, _akty, _sell_, _שברו
  { {0x65640089,0x8f9c000a,0x61e10618,0x63a9014b}},	//   řihl, תידי, yell, vaen
  { {0xf77004c9,0x60c10064,0x2aba000a,0x3aba000a}},	//   سان_, yulm, _במשא, _במשנ
  { {0xe8940010,0x25a50714,0x61e10715,0x63a90716}},	//   _гась, _vell_, vell, taen
  { {0x25a50495,0x321e002a,0x5d7c004c,0x27ff0061}},	//   _well_, ekty_, ערהײ, _unun_
  { {0x7412003b,0xcb1200b2,0x25a5003e,0x52a602bf}},	//   تويا, ַלט_, _tell_, авым_
  { {0x60c10717,0xe9c90033,0xdb0d0077,0xe4a703ae}},	//   tulm, евiч_, ngañ, _брдо
  { {0xc5fa0053,0xb5fa0053,0x35470010,0x69ca000b}},	//   _שפעט, _שלעכ, _схав, स्टी
  { {0x60c101e2,0x1603005d,0x43750718,0xb4670067}},	//   rulm, लावर_, _култ, _صداه
  { {0x20550010,0x83fd00dc,0xa856000a,0x61e10220}},	//   стэр, rlőd, שירה_, pell
  { {0x5332000d,0x437200e6,0x6da30719,0x387f01c2}},	//   _фељт, _ظهور, жира, _liur_
  { {0xed5a071a,0x62860227,0xc0a90067,0xfce6005e}},	//   тов_, íkov, _شاغل_, шово
  { {0x6d5e0107,0x83fd0030,0x2000071b,0x70530015}},	//   _vypa, llőb, _unii_, _ونوا

  { {0x6272005c,0x6d5e005c,0xdcfc0024,0x7e7e071c}},	// [800] _głos, _wypa, obrī, _tipp
  { {0x1daa014e,0x3c3f00f2,0x6d41002d,0x4efb000a}},	//   _क़ित, tävä_, úlac, _יהפו
  { {0x5dbb000a,0x6fd3000b,0xd7ef0296,0x7786071d}},	//   _בזיה, ध्वं, оу_, алез
  { {0x386d071e,0xa7850015,0xd90d002b,0x7d1c008c}},	//   _cher_, مشهو, ریق_, myrs
  { {0xc6a3006d,0x66f4071f,0xa6c700af,0x26360535}},	//   орщи, сплу, илца_, słom_
  { {0x386d00b8,0x68fa0030,0xc8960099,0x963301f3}},	//   _eher_, _átdo, _врањ, оніц
  { {0x75890036,0x95080015,0xc918000a,0x29070123}},	//   усів_, اقعك_, _גֵּר, änat_
  { {0x6a6b00b8,0x6e3c0720,0x68e2002a,0xd3d70015}},	//   rüfe, hirb, łods, لبًا_
  { {0xf5ea0254,0x92940054,0x5433002b,0x3373006b}},	//   _имал_, љаоц, ترور, огър
  { {0xd4d6008f,0xb066008c,0x51f7004a,0x0000006a}},	//   _відэ, yvää, анью_,
  { {0xdcb10092,0x74160086,0x6e3c0721,0x20c3005e}},	//   ởi_, _پوشا, dirb, осяг
  { {0x6e3c002d,0x853b000a,0xcfab0015,0x74130015}},	//   eirb, _בגבי, خادم_, _وولا
  { {0x3294003b,0x22940722,0xfe7300a2,0x44260141}},	//   _التأ, _التس, قدس_, _ilo_
  { {0x12fb000a,0x91e3004a,0xf1a3006b,0x7658006f}},	//   _שהגב, _моче, _дрън, novy
  { {0x6272005c,0xda05005d,0x2ba703f1,0x442606c2}},	//   _włos, रासत_, ијав, _klo_
  { {0x717b013a,0x417b0008,0x5bb80080,0xd0080001}},	//   _בנוס, _בנוב, ился_, _веће_
  { {0xb0660020,0xe9870001,0xaed50001,0xab280004}},	// [810] svää, аћен, _уопш, аоѓа_
  { {0x7ac40121,0x387f01d7,0x7d1c0723,0x0000006a}},	//   юссе, _siur_, byrs,
  { {0xda7803ad,0xa3d6000b,0x4ddc000a,0x4f58002b}},	//   рят_, िभा_, _יחזו, _مجید_
  { {0xe8df00a7,0xfd56000a,0x3858005e,0x6d490045}},	//   _quốc_, _לשתי_, арію_, şeas
  { {0xd6390033,0x8b03002a,0x87040015,0x8b6700c3}},	//   лякі_, łębs, قبول, _خادم
  { {0xcb12000a,0x2d91002a,0xd1260015,0xe5a20724}},	//   _צלם_, ncze_, _فم_, пиши
  { {0x29070123,0x386d00da,0xe4c800c3,0xe8df00a1}},	//   ånad_, _ther_, لبين_, _tuốc_
  { {0xd4e40036,0x43690725,0x44260726,0x5fc60065}},	//   юючи, лайн_, _clo_, _वाइल
  { {0x32d00092,0xdcfc003d,0xd8380033,0x0000006a}},	//   gày_, tbrī, _тэр_,
  { {0x32d40033,0xe2440015,0x69c80727,0x7658006f}},	//   іцыс, ْخَي, _ödet, covy
  { {0x6d400064,0x2d91002a,0x786a0069,0x34940138}},	//   şmaz, dcze_, lýva, _дахр
  { {0x44260728,0x6e3c0012,0x33f40015,0x2d91002a}},	//   _glo_, wirb, _وسنس, ecze_
  { {0x2bcb005d,0xf412000a,0x9dba0033,0xcf3a008b}},	//   िलना, _מפא_, лыву_, учні_
  { {0x51950029,0x2374002c,0xe29c004c,0x44260729}},	//   _الغذ, ňajú_, _ישׂר, _zlo_
  { {0x1d190191,0x82340225,0x50db005d,0x6e3c001a}},	//   ають_, _برنا, _बहिष, rirb
  { {0x711a0008,0x6096002b,0x20d10030,0xd116000a}},	//   _תוקפ, _انيس_, mái_, _לקצה_
  { {0xc0530008,0x629b00f2,0x3b07017a,0x6272002a}},	// [820] _מזה_, npuo, бето_, _kłop
  { {0x7dea0080,0xdb0d001a,0xf9c4009a,0x0000006a}},	//   _смог_, rgað, تحری,
  { {0xd23a0053,0x7cd60015,0x8c26002b,0x20d10030}},	//   נגעל, _اتخذ, _هفده, nái_
  { {0xdb0600dc,0xa2aa005d,0xf0b60053,0xa9670063}},	//   _leké, _फ़िल्, מלער_, щиха_
  { {0x20d10092,0x29070123,0x83fd0030,0x628f072a}},	//   hái_, änar_, zlőc, ícol
  { {0x442600cb,0x20d10030,0xa5f803ea,0xdb06006f}},	//   _slo_, kái_, реку_, _odkú
  { {0xd4970010,0x6f1d005c,0x8898000a,0xd5b9005e}},	//   бры_, zysc, _כֹּה, рсі_
  { {0x94180080,0x2d91005c,0x786a01b2,0x53e60033}},	//   ржит_, zcze_, býva, сцка
  { {0x59cf005d,0x5b3b004c,0x6a700123,0x7a200123}},	//   स्कर, ָגיק, räff, _nötk
  { {0x6d4001e2,0xf238000d,0xa697000a,0xeab1000a}},	//   şmay, рпош_, _לכמה_, וֹט_
  { {0xc0aa0029,0x69dc002d,0x09f7000a,0x4a5b000a}},	//   داخل_, _mbre, זמים_, רדיו
  { {0x43860029,0x44200092,0x2d91005c,0x28c9000b}},	//   _الإق, _ôi_, wcze_, ांति
  { {0x316b002a,0xa857000a,0x69dc072b,0x3c270072}},	//   ęcza_, מיטה_, _obre, _nõva_
  { {0x2ceb0033,0x44f80016,0x27e6072c,0xd250009a}},	//   льбо_, _kĩ_, heon_, _تنت_
  { {0xb425005c,0x786a0264,0x80a40015,0x2d91002a}},	//   łżeń, zýva, _بمعن, rcze_
  { {0xd0110015,0x44f80016,0x01630015,0x69dc0676}},	//   _آلة_, _mĩ_, _عُيَ, _abre
  { {0x7b67072d,0x27e6072e,0x7a20072f,0x7de702a3}},	// [830] стве, deon_, _köth, _лінд
  { {0x3da702ed,0x0000006a,0x0000006a,0x0000006a}},	//   _уриб,   ,   ,
  { {0xdd920086,0xf96b0033,0x44f80016,0xa8cb006e}},	//   _توپ_, урай_, _nĩ_, طباق_
  { {0x7aee00f2,0x7c670225,0xdc88000a,0x27e60730}},	//   äntä, _داخل, _לְשָ, geon_
  { {0x95850731,0x7c2d0732,0xdcf50061,0xad8b004f}},	//   олле, mhar, mazı, ְנֵ֥
  { {0xc1b7000b,0x7c2d0733,0x7a200012,0x69d8000b}},	//   _आयेग, lhar, _nöth, न्दी
  { {0x44f80023,0xafdb02de,0x25fe000b,0x24090734}},	//   _cĩ_, rnøj, लाजी_, инки_
  { {0x44f80092,0x7afd0735,0x69c80061,0x7c2d0736}},	//   _dĩ_, _krst, _öder, nhar
  { {0xc7b900dc,0x20f70011,0x7bfa000a,0x7bcf0737}},	//   _idő_, _săi_, בִיה, _mccu
  { {0xdcf50064,0xd179005e,0x22560067,0x20d10030}},	//   hazı, исні_, يليد_, tái_
  { {0x7412002b,0x7bcf0738,0x629b0739,0x7c2d073a}},	//   سویا, _occu, spuo, khar
  { {0x629b008c,0x20f70045,0x20d1073b,0x38a70034}},	//   ppuo, _văi_, rái_, iŵr_
  { {0x442d002f,0xdcb10092,0xc7d60008,0x7c2d073c}},	//   mhe_, ẩn_, חורי_, dhar
  { {0x442d001c,0xc6920053,0x443f073d,0x7bcf073e}},	//   lhe_, ואך_, liu_, _accu
  { {0x7afd0020,0x442d073f,0xa06a0740,0x628b0741}},	//   _arst, ohe_, _кака_, _hugo
  { {0x628b003f,0x38a70026,0x442d0742,0x645b0743}},	//   _kugo, dŵr_, nhe_, noui
  { {0xda05005d,0x63ab0744,0x89aa0268,0xcfb7000a}},	// [840] रांत_, _megn, икав_, _ולפי_
  { {0x62830089,0x64490745,0x4ce6006b,0x7c2d00e7}},	//   _jino, hnei, _джоб, ahar
  { {0x7c2d002f,0x443f0007,0x7afd0746,0x1d0a004a}},	//   bhar, kiu_, _erst, _тени_
  { {0x6299005c,0x2f8d000a,0x7c2d02ff,0x645b0003}},	//   _otwo, ְרוּ, char, joui
  { {0x44f80023,0x98ab0024,0x629900dd,0x6684002b}},	//   _sĩ_, āmās_, _ntwo, سیال
  { {0x7c240005,0x35e1000b,0x4efb000a,0xafdb00cb}},	//   lkir, फ़ग़, יהנו, tnøk
  { {0x7a2000b8,0x291c0020,0x443f002c,0x1cba000a}},	//   _nöti, ävad_, fiu_, ׁמַע
  { {0x6283022d,0x44f80092,0x24e50010,0x64490134}},	//   _aino, _vĩ_, яціг, gnei
  { {0x63ab02b9,0xafdb00cb,0x8c1b000a,0x7c240747}},	//   _degn, snøk, שופי, ikir
  { {0x628b0748,0x442d0749,0x3866074a,0x6449074b}},	//   _dugo, ahe_, llor_, anei
  { {0x7233003b,0xf99301e4,0x59cf005d,0x69fb000f}},	//   بريط, ורת_, स्टर, בליק
  { {0xe3b20086,0x63ab074c,0x443f074d,0x63060015}},	//   _آرا_, _gegn, ciu_, _ووال
  { {0xe1ef0074,0xd5b10023,0xc7b30008,0x38660011}},	//   رسی_, _hóa_, ובר_, ilor_
  { {0x22570015,0x6440074e,0x35d2000b,0x7c24074f}},	//   _وجوب_, limi, _साफ़, ekir
  { {0x56370053,0xfe6e002b,0x64400750,0x7c2d0751}},	//   קאלע_, دگي_, oimi, thar
  { {0x59dd005d,0x7c2d0752,0x62830753,0x28c9000b}},	//   न्नर, uhar, _zino, ांसि
  { {0xdceb01e2,0x7c2d0754,0x8d870755,0x5f77009a}},	// [850] ınız, rhar, _мунд, _باغر
  { {0x7c2d000c,0x7afd0198,0x7c2400f2,0x61e80756}},	//   shar, _vrst, akir, nedl
  { {0xab950036,0x7c38002e,0x644900f2,0xf8b10086}},	//   _нині, ðará, ynei, عکس_
  { {0xdce50023,0x443f0251,0x7be50264,0x38660757}},	//   _nghĩ, xiu_, íruč, glor_
  { {0xe8e00092,0x66050758,0x69d8000b,0x443f0759}},	//   _khớp_, зпла, न्ही, viu_
  { {0x63ab02d7,0x61e8010b,0x65650020,0x443f005c}},	//   _segn, jedl, ühho, wiu_
  { {0x442d017e,0x6299005c,0x2bb2005d,0x85780063}},	//   the_, _stwo, _ज़मा, осът_
  { {0x6440075a,0xe3d50015,0x2409004a,0xa026008c}},	//   gimi, ستبع, снии_, isöä
  { {0x63ab075b,0x442d075c,0xe2990001,0x1306004a}},	//   _vegn, rhe_, љао_, зный_
  { {0x442d075d,0xd6280001,0x61e800da,0x7ae00012}},	//   she_, _дође_, gedl, _ämte
  { {0x91fc0024,0x6440075e,0x0ef4000b,0x442d075f}},	//   plān, bimi, इट्स_, phe_
  { {0x64400467,0x628b0035,0x1603005d,0xdee60760}},	//   cimi, _tugo, लाकर_, поми
  { {0x62990050,0xeef50033,0x7c2400cb,0x2bb20065}},	//   _utwo, мярэ, vkir, _ज़बा
  { {0x863500b2,0xe6070067,0xe1f1002b,0x7aed055e}},	//   לאָג_, رش_, _سست_, dwat
  { {0xd5b10023,0xdd8f0029,0x3207005c,0xad250015}},	//   _xóa_, اوف_, _inny_, ورفو
  { {0x7aed003f,0xdddc0227,0x8c46006b,0x7c24005b}},	//   fwat, zorň, чебе, ukir
  { {0x0ae90029,0x6fa2005d,0x443d00dd,0x7c240747}},	// [860] يركي_, _क्यू, _mmw_, rkir
  { {0x4efb0053,0x7c240761,0x1efb004c,0x64400762}},	//   _פליג, skir, _פליע, zimi
  { {0x64400064,0xae1b01ac,0x7aed01c2,0xd9430763}},	//   yimi, _הויכ, awat, нефи
  { {0x64400764,0x7a2002dc,0x0000006a,0x0000006a}},	//   ximi, _nötv,   ,
  { {0xabfb0008,0xa2bd000b,0x38660765,0xeb91000a}},	//   _ההכר, _शिष्, rlor_, _יָם_
  { {0x64400034,0xe4a60766,0x0000006a,0x0000006a}},	//   wimi, прио,   ,
  { {0x80c0005d,0x25ac0089,0x64400767,0x61e80768}},	//   _विधे, _vedl_, timi, vedl
  { {0x3298000d,0xb7da0029,0xdc9b0008,0x61e80026}},	//   овиќ_, _دورا_, זיקל, wedl
  { {0x61e80769,0x6440076a,0x6234006b,0x9393002b}},	//   tedl, rimi, депу, رجيا
  { {0x80c0014e,0x4b3700f3,0x248c01c2,0x6440076b}},	//   _विदे, פריל_, _tudm_, simi
  { {0x64a3076c,0x66080134,0x859b000f,0xd59b000a}},	//   _заха, _indk, _השבו, _הבבל
  { {0x7aed0050,0xa3e3005d,0xdcb10092,0x35d2000b}},	//   ywat, _पॉप_, ẩm_, _साड़
  { {0x82fa0086,0xd5b10016,0xbea40033,0x661a076d}},	//   _دراز_, _món_, наўк, _kotk
  { {0x661a022d,0xb4b60065,0x0000006a,0x0000006a}},	//   _jotk, _जिफ़_,   ,
  { {0x61db0008,0x11db0008,0x6ce4005e,0xcd74006b}},	//   _הקוד, _החוב, ніте, егръ
  { {0xc49b000a,0x7e600045,0x7bcd0091,0x661a051e}},	//   משלת, împr, ugau, _lotk
  { {0xa3de005d,0x35d2000b,0x5e450015,0xda090015}},	// [870] द्य_, _साढ़, _يَعْ, ييره_
  { {0x91fc03eb,0x2bcb014e,0x661a0084,0x2486002d}},	//   klām, िलहा, _notk, _liom_
  { {0x7aed076e,0x98c701b7,0xac19076f,0x4dda004f}},	//   swat, ясал, _дону_, _וחתו
  { {0xa2bd000b,0x6fbf000b,0x6608007c,0x6ca8004f}},	//   _शिल्, ्लिं, _andk, _מֹשְ
  { {0xd6db0770,0x907c000a,0xa6c9005e,0x9f520003}},	//   сте_, צטדי, ілка_, _payé_
  { {0x9aa4002b,0x64990054,0xcf2c000a,0x7a200123}},	//   _سمفو, отир_, מֽוֹ, _sötv
  { {0xcd980008,0xf8ae002b,0x661a0771,0x0000006a}},	//   הדות_, _نکن_, _dotk,
  { {0x3e640030,0x99840015,0x66080012,0x442b0772}},	//   lött_, _ألفو, _endk, óc_
  { {0x661a01b2,0x15f5000b,0x2636002a,0x13090138}},	//   _fotk, _इसपर_, głos_, іной_
  { {0x80d90036,0x02390015,0x2509002b,0x45d4067a}},	//   оєму_, تثبت_, _ورای_, _поус
  { {0xb7bd0011,0x9f450046,0x7a20001a,0x2127002b}},	//   _alţi, ělý_, _götu, سيحی_
  { {0x59dd014e,0xa3ae005d,0x155a000a,0x46d1000b}},	//   न्तर, करण_, _וכעב, _समाह
  { {0x9f5f002e,0xb7da000a,0xdb060077,0x7f1a0033}},	//   ðuð_, חקרי, _pekí, ціну_
  { {0x1e83008f,0xfce60036,0x3e6400dc,0x76430049}},	//   клям, мого, jött_, niny
  { {0x91fc0024,0x3e6400dc,0x7a200123,0x10f50033}},	//   klāj, dött_, _mött, _цяля
  { {0xe0560015,0x69c30077,0x6ab60773,0x76430774}},	//   _تختب, ónen, tsyf, hiny
  { {0x09ba0029,0xcb670775,0xae9a0015,0x3a06002b}},	// [880] قطاع_, дате_, _بضبط_, وکسی_
  { {0x6722003f,0x19b90033,0x3e640030,0xda05000b}},	//   vyoj, зуць_, gött_, रागत_
  { {0x76430776,0x6ab60123,0xdb160030,0x49060058}},	//   diny, ssyf, tgyó, بواق
  { {0xfbb2014e,0x0fee000b,0xd7e3005e,0xacfb000a}},	//   _ज़िम, ज़िश_, вішо, _והטכ
  { {0xe7320040,0x764301d7,0xc68f0015,0x9e65002b}},	//   خصا_, finy, لِن_, _زاین
  { {0xd10d005d,0x24860026,0xceb90089,0x59dd000b}},	//   िमाण_, _siom_, áři_, न्दर
  { {0xf9830777,0xfbb2000b,0x7a200123,0xa5070099}},	//   _агро, _ज़ाम, _dött, деја_
  { {0xa8030063,0xa957000a,0x7d010778,0x493b004f}},	//   _изсл, _חילק_, ålsi, _וגלו
  { {0xa01b0084,0xe3af0015,0xe6930015,0x41c60033}},	//   lmög, جرى_, _للقد, мёна
  { {0x7a200779,0xc5760015,0xeae9004c,0x764301d7}},	//   _gött, _قطاع, פֿפֿ, ciny
  { {0x644b002e,0xd46a0054,0xa01b0012,0x0000006a}},	//   ðmið, _диже_, nmög,
  { {0x3e640014,0xf537000a,0x7a200030,0x53460245}},	//   zött_, _קטאר_, _köts, _охла
  { {0x80c0005d,0xa2d30015,0xe1fa0138,0x0000006a}},	//   _विवे, _لينت, _мгд_,
  { {0xe24600e6,0xfc3f0046,0x20090034,0x7d00003d}},	//   _تخصي, _smí_, _wnai_, āmsn
  { {0x463b0053,0xdcb10015,0x0cd40342,0x3d9400af}},	//   קעלע, طىء_, корю, тиср
  { {0xe0d1000a,0xbb4b005e,0x9ee90015,0x20090034}},	//   _עֲו_, оїзд_, _ففعل_, _unai_
  { {0x3e6400dc,0x3a75077a,0xcb550054,0xf3f90045}},	// [890] tött_, елар, хваћ, ulţi_
  { {0x61f8044c,0x99870046,0xf96b004a,0x61fa077b}},	//   _javl, ónů_, орей_, ndtl
  { {0x91fc0024,0xa3ae000b,0xe9d00015,0x18a4005e}},	//   elāk, करा_, شغل_, ваєм
  { {0x2c270191,0x38c4002e,0xb17b0053,0x7643077c}},	//   _цьог, _sérð_, קטאר, winy
  { {0x7643013c,0x6b9a000a,0xcb9a000a,0x91fc003d}},	//   tiny, _משרד, _מסרט, glāk
  { {0xf7700074,0x321c077d,0x20d80030,0x61f8077e}},	//   جام_, _novy_, kéi_, _navl
  { {0x9f4e0089,0x35f8002b,0x7643077f,0xa01b02ad}},	//   čném_, برند_, riny, omöd
  { {0x7643064e,0xb465002b,0x97c50015,0x91fc003d}},	//   siny, رگاه, _سقطو, blāk
  { {0xa3de021e,0xd5b10016,0x786a006f,0xe8df0016}},	//   द्ध_, _hóm_, zývk, _khỏa_
  { {0x80c0021e,0xaac70065,0x7ac70065,0x0000006a}},	//   _विशे, _लिनक, _लिनअ,
  { {0xa87901ac,0xf4d40015,0x64450003,0xc10500c3}},	//   ּאָר, _لتنظ, éhis, روحي
  { {0x44f10780,0xb4fa0008,0xdb06002c,0xc9520008}},	//   _iš_, _מפעי, _leká, רמט_
  { {0xd24e0074,0x69d5005c,0xd12e0086,0x93270087}},	//   _گنو_, _ocze, لمی_, _تران
  { {0x69c30077,0x2d980781,0x2d8c0723,0xb374009a}},	//   ónel, ucre_, øde_, _شدنش
  { {0xdb040782,0x81f60002,0xc0a8002b,0x68e2002a}},	//   mbié, _سفير_, _قايل_, łodz
  { {0x3c2e006f,0xd259003d,0x7a200061,0x224502f2}},	//   _býva_, ruņu_, _nötr, lilk_
  { {0x5aca0033,0x2f550033,0xcaca0033,0xa9a60783}},	// [8a0] ялам_, _атэс, ягае_, еизд
  { {0x4a430784,0x2bb2000b,0xa01b0012,0x224502f2}},	//   гнув, _ज़वा, tmög, nilk_
  { {0x4c860785,0x35c9000b,0xa96a0015,0xd82601b7}},	//   _плов, _राज़, أمام_, нджи
  { {0xdc9b0053,0x76410026,0xa01b05f7,0xfaa60033}},	//   _מיטל, _amly, rmög, _памо
  { {0x44f100df,0x8c1b000a,0x45d40658,0xbc1b004c}},	//   _aš_, _זוכי, волс, _זוכש
  { {0xdcfc0482,0xceb30786,0xf7470015,0xd4910016}},	//   ları, ניו_, علوي_, _bù_
  { {0xb5a5005e,0x64c30058,0x85b70058,0x0000006a}},	//   трій, هيول, راوس_,
  { {0x6f0404f9,0xd4910016,0xdcfc0061,0x76410034}},	//   _oric, _dù_, narı, _emly
  { {0x32540054,0x9961003d,0x61f80787,0xe7370788}},	//   квир, _cīņa_, _pavl, _зет_
  { {0x2d8c002c,0x442f0789,0xc217005e,0xdcfc0061}},	//   ždej_, _elg_, еєю_, harı
  { {0xdcfc01e2,0x3a370008,0x6d490011,0x52730015}},	//   karı, גרים_, şeaz, دايز
  { {0x6f040043,0xf9460033,0x0000006a,0x0000006a}},	//   _bric, ьнiк_,   ,
  { {0xdcfc0064,0x92930033,0x76410034,0x2fc00034}},	//   darı, _баіц, _ymly, _ddig_
  { {0xbe880080,0x68e2002a,0x9a090033,0xe731000a}},	//   ессе_, łody, лiне_, בֵל_
  { {0xf1b30008,0x2d85078a,0xd12f00fd,0x6f04078b}},	//   _עסק_, äle_, _сх_, _eric
  { {0x6565007c,0xb062008c,0xac18078c,0x5bcb000b}},	//   ühhi, ääte, носу_, िलेव
  { {0xf9c7078d,0x628a0030,0xd0740015,0x0fa8000a}},	// [8b0] ещен, _kifo, _حدوث, _אֹתֽ
  { {0x1ed80015,0x69da078e,0x8b080046,0x78710123}},	//   _أبيب_, _ötel, _spřá, gåvn
  { {0xa9280010,0xbc790036,0xdcfc0061,0x78470033}},	//   ніце_, _обох_, barı, нэдж
  { {0x69d5005c,0x628a0034,0x612b0030,0x6d08004f}},	//   _wcze, _lifo, lölö, _נִתַ
  { {0xe8df0023,0x80380053,0x799c0026,0x8c1a000a}},	//   _thỏa_, ענדע_, _ffrw, _חורי
  { {0x69d5005c,0xd5b10092,0xb5c2078f,0x9665006b}},	//   _ucze, _tóm_, айшл, ъкле
  { {0x224500bd,0x19580010,0xe8df0016,0xd5b10016}},	//   vilk_, _зары_, _muịc_, _vé_
  { {0xd138005c,0xb8e7005d,0x13090142,0x44f10790}},	//   dzą_, ों_, дний_, _vš_
  { {0x56950063,0x95d9000d,0x628a0791,0x28c9000b}},	//   _разт, _одат_, _bifo, ांकि
  { {0xdcfc0064,0x02020033,0x7641001a,0x2019002a}},	//   zarı, азьн, _umly, ejsi_
  { {0xa2bd005d,0xf9920008,0xdcfc0064,0xc4c70015}},	//   _शिक्, ירי_, yarı, _ستاو
  { {0x50460054,0x7d1a0123,0x6f040792,0xd496000a}},	//   темб, ätsm, _pric, _סכנת_
  { {0xdcfc0064,0x539a039e,0x63a90793,0xc2c400c3}},	//   varı, _חינו, mben, _ميني
  { {0x6fa2005d,0x01350015,0x78780794,0x4df5027a}},	//   _क्रू, _لعبد, míve, ляст
  { {0xd138005c,0xdcfc0064,0x63a900bd,0x61d600f3}},	//   czą_, tarı, oben, _יוסף_
  { {0x218800b2,0xec160086,0x31560053,0x518405fc}},	//   _אָפּ, خورد, _שיקן_, _суча
  { {0x787803af,0x27fd0176,0xdcfc0064,0xea8a0180}},	// [8c0] níve, ddwn_, rarı, дбал_
  { {0x5ee90008,0xdcfc0064,0x26cf0085,0xde8a0015}},	//   _נַפְ, sarı, dugo_, _تضعه_
  { {0xdcfc0064,0x5f46002b,0x7d010795,0xd7fa0763}},	//   parı, _سنگل, ålst, дул_
  { {0xc7c30080,0x63a90085,0x3ead0045,0xb6a6067a}},	//   асши, jben, ţete_, видл
  { {0x63a90796,0xfaa60099,0x56f30015,0x0000006a}},	//   dben, _јаго, لأوز,
  { {0x78780089,0xd5e3005e,0x9f42008c,0x4733005e}},	//   díve, ижчи, mekä_, шніс
  { {0x628a04ed,0xd9460797,0xdb0f016e,0xe4d30015}},	//   _rifo, _реви, _recé, لتيب
  { {0x7c360176,0xa5070124,0x63a90798,0x628a0799}},	//   nhyr, ђења_, gben, _sifo
  { {0x26dd005c,0x96e50015,0x7878016e,0xa2b30033}},	//   ctwo_, _مثلم, gíve, абыч
  { {0x62060036,0x067601b0,0xf992000a,0x96760033}},	//   тчиз, _рубя, יר֙_, _рыбі
  { {0x1be2000b,0xd4c50015,0x83fd0030,0x79ab000a}},	//   खभाल_, _مغني, zlői, וֹכַ
  { {0xd138005c,0x14d7000a,0x70550067,0x23ba006e}},	//   rzą_, _יובל_, انحا, _آداب_
  { {0xd1380050,0x30280033,0x628a079a,0x7878059d}},	//   szą_, тоўп_, _tifo, cíve
  { {0xa3de014e,0xbbcb000b,0xdd1c0046,0xc693000a}},	//   द्र_, िल्क, láře, יאש_
  { {0x69c80064,0x70f30058,0x7d24011e,0x26dd0535}},	//   _ödey, _نسيئ, афте, ztwo_
  { {0xdfd10029,0xb4fb000a,0xe8e00016,0xc61f000b}},	//   _اية_, ופלי, ýời_, _भव्य_
  { {0x4a550033,0xe451000a,0xba5500af,0x0000006a}},	// [8d0] гкас, צֶל_, гвај,
  { {0x63a9020c,0x5b340015,0x5a340262,0xbdf502d9}},	//   zben, جعفر, анут, _спој
  { {0x98480064,0x27ef079b,0x09e4005e,0x0178000a}},	//   _ağı_, tegn_, роєн, תָּל
  { {0xdcb10023,0xdb06079c,0x3e76001a,0x97c50015}},	//   ẩu_, _bekä, mæta_, اقشو
  { {0x7878016e,0x27ef079d,0x7c2d079e,0xe70b0058}},	//   xíve, regn_, mkar, بتان_
  { {0xd7740029,0xbb3a004c,0x7c2d079f,0x26cf02d8}},	//   جامع, _טערי, lkar, rugo_
  { {0x26dd005c,0x245a0024,0xd4690175,0xdb060061}},	//   stwo_, zīme_, нике_, _pekç
  { {0x7c2d07a0,0x63a907a1,0xa3b900c3,0x787807a2}},	//   nkar, uben, رابر_, tíve
  { {0x17550010,0xc7b2000f,0xdb060012,0x069b002b}},	//   _свая, _לבן_, _gekä, _آخرت_
  { {0x96f80115,0x7d0807a3,0x63a907a4,0x7878016e}},	//   _جعفر_, ådsk, sben, ríve
  { {0x7878001c,0x9f4e0089,0xd5b10092,0x7c2d07a5}},	//   síve, čním_, _nói_, kkar
  { {0xddd50089,0xdb0a0227,0x7c2d07a6,0x05df0065}},	//   mozř, šnéh, jkar, प्रब
  { {0x91e507a7,0xa856000a,0x442d07a8,0x7c2d07a9}},	//   _боле, רירה_, mke_, dkar
  { {0xf77600b2,0xdd920070,0x2edc000b,0xfcaa0015}},	//   טערי_, صور_, मझौत, فارو_
  { {0x8cd4005d,0x8c7a0063,0x51840054,0x62810012}},	//   बंधो, ещат_, _кућа, mmlo
  { {0x7c2d00b6,0x2bf60033,0x442d07aa,0x64490045}},	//   gkar, ыягр, nke_, niei
  { {0x9b93003b,0x442d07ab,0x69da0061,0xf99200c3}},	// [8e0] إلكت, ike_, _ötek, مبا_
  { {0x3e76002e,0xe9d707ac,0x3b8307ad,0x05d2000b}},	//   bæta_, лку_, слуг, _साइब
  { {0x442d07ae,0xd5b10016,0x4ddb000a,0x08c606b5}},	//   kke_, _gói_, _אחיו, убен
  { {0x442d07af,0xca290008,0xdbd700b8,0xa3e3000b}},	//   jke_, הם_, mäßi, _पॉल_
  { {0xd707004a,0x8d76002b,0xdd1c0046,0x442d07b0}},	//   лнце_, _جاکا, váře, dke_
  { {0x442d07b1,0x38c8002b,0x8b0b000a,0x7af60034}},	//   eke_, _لاری_, _אִלֵ, mwyt
  { {0x64490176,0x54e60029,0x7af60026,0xc8f8000a}},	//   fiei, استق, lwyt, _בִּכ
  { {0x25f0005d,0xd4670001,0x4d7b0053,0x78a3001a}},	//   _इसकी_, лије_, ערקע, ínve
  { {0xa6ca0086,0x7af60026,0x91fc0024,0xd5d6002b}},	//   _سوال_, nwyt, klāt, _متاث
  { {0xe29f0084,0xd6cf0196,0x268a0015,0x442d07b2}},	//   íða_, _رقم_, _أخري_, ake_
  { {0xf593003b,0x20d30010,0x055602c5,0xddce0091}},	//   _المج, біўс, _стая, albū
  { {0x557700b2,0x442d07b3,0x38660177,0xe29a0254}},	//   _געבן_, cke_, noor_, _зад_
  { {0x80c0005d,0x6e9506f7,0xd3b90033,0x5f020065}},	//   _विके, ригу, _рухі_, शिष्_
  { {0x38660409,0x6e94004a,0x764a0034,0xd357000a}},	//   hoor_, сиру, nify, _גידי_
  { {0x16d1014e,0x7c2d0048,0x28c9000b,0xc534000a}},	//   _सम्ब, tkar, ांछि, בָּה_
  { {0xd1750010,0x7c2d07b4,0xa3e7000b,0x80a3006e}},	//   _тычы, ukar, म्प_, _امين
  { {0xc3340008,0x386605d6,0x7c2d07b5,0xead502e1}},	// [8f0] בוּ_, door_, rkar, розь
  { {0x7f3c00b4,0x442d07b6,0x7c2d07b7,0x38660546}},	//   _רעזו, zke_, skar, eoor_
  { {0x290707b8,0x442d07b9,0x64490034,0x68270033}},	//   ína_, yke_, yiei, льдз
  { {0x80d70053,0x386607ba,0x0000006a,0x0000006a}},	//   רואװ_, goor_,   ,
  { {0x76ab0124,0x9bba0008,0x6f1b00b8,0x442d07bb}},	//   хтев_, _בצרפ, äuch, vke_
  { {0xa3e7005d,0x19940036,0xa594006b,0x95c80054}},	//   म्न_, _гаря, бръщ, гућа_
  { {0x3d08005d,0x845907bc,0x74f60015,0x442d05e3}},	//   हिये_, крит_, لفوز_, tke_
  { {0xdd1d002c,0x6a6b00b8,0x91fc0024,0x142507bd}},	//   ráňt, rüfu, klās, рдим
  { {0x02d60015,0x7cec0030,0x425507be,0x644907bf}},	//   لويب_, _körö, итот, riei
  { {0x27ff00f2,0xcb120008,0x442d07c0,0xdb0f0247}},	//   _haun_, קלי_, ske_, _necí
  { {0x30760004,0x62810028,0x69dd000b,0x06840015}},	//   иумс, rmlo, _पानी, _اللُ
  { {0x649a01ac,0xdb0f016e,0x70530015,0x749a000a}},	//   _סינה, _mecâ, ْنَا, _סינפ
  { {0x92b70029,0x02a707c1,0xf1dd000b,0xe2980033}},	//   _إحصا, _срем, _मापन, _баі_
  { {0xed5a0124,0xd3560008,0xf652004c,0x45b5004c}},	//   вог_, _דיני_, ַצן_, יפֿל_
  { {0xdb0f02c1,0x32f6002a,0xa01b07c2,0x614207c3}},	//   _decí, _zły_, mmön, _меша
  { {0xbb760063,0x7c3a003d,0x7aa60015,0x7af60034}},	//   аузъ, ītro, لإطل, twyt
  { {0x4a4601d9,0x38660111,0xa3e7000b,0xcaa50015}},	// [900] анав, voor_, म्य_, مصلي
  { {0x78780089,0x7af60026,0xdebb0008,0x2bb20065}},	//   díva, rwyt, _שמיל, _ज़का
  { {0xf1dd005d,0x2619005d,0x91fc0024,0x41dd005d}},	//   _मानन, पानी_, olār, _मानस
  { {0x63bb0048,0xdb0f04f9,0xdc9b000a,0xa96701b7}},	//   jaun, _decâ, _שיכל, шиха_
  { {0x8f9b0008,0x9b030010,0x386600dd,0x46f6068e}},	//   דיני, _дзяд, roor_, рчет
  { {0x7cec00dc,0x5b57000a,0xddc707c4,0x386607c5}},	//   _görö, _כיכב_, oljš, soor_
  { {0xa3e7005d,0x764a07c6,0x5dc9000a,0x7a8b000a}},	//   म्भ_, rify, אֶפְ, _יָלַ
  { {0x63bb07c7,0x8ba9000a,0x27ff07c8,0x69c30030}},	//   gaun, ְׁתִ, _gaun_, ónev
  { {0xd6cf0015,0xd377004a,0xe3af0015,0x46a307c9}},	//   _يقف_, ичь_, ذري_, _матв
  { {0xc50a0015,0xa3e7000b,0xf991000a,0x2258007c}},	//   _لتصل_, म्ब_, ּ֨י_, õrk_
  { {0xd1300029,0x73c6002b,0x64a301f3,0x7bc607ca}},	//   سمح_, _نيام, _даха, _odku
  { {0x27e60176,0x92020024,0x04db0008,0x78a10030}},	//   nfon_, _šāda, _יקבל, _élve
  { {0x20050089,0xa8570008,0xc43b000a,0x83fd0030}},	//   ěli_, שיכה_, _בתאי, rlőt
  { {0x20050050,0x7a320134,0xf1dd000b,0x290a07cb}},	//   śli_, _sætn, _मायन, _orba_
  { {0xcd04004a,0xc534000a,0x2ca500aa,0x41270004}},	//   очти, זָּה_, ëld_, _војо_
  { {0x70550074,0xec340036,0xc3340008,0x69dc07cc}},	//   _دنبا, онсь, ֖וּ_, _acre
  { {0x290a0780,0x207c0053,0x27ff002e,0x44f80092}},	// [910] _arba_, _באהא, _raun_, _lũ_
  { {0xe919005e,0x9abe01f3,0xa93d0033,0x27ff007c}},	//   лозі_, вiта_, ндзi, _saun_
  { {0x7cec00dc,0xa3e7000b,0xad19000a,0x27e607cd}},	//   _vörö, म्ड_, _עוֹר, ffon_
  { {0xb8ef000b,0x787807ce,0x97150033,0x3157000a}},	//   _शि_, tíva, ймец, סיאן_
  { {0x7cec0014,0x8c1a0008,0x290a02b9,0x63bb008c}},	//   _törö, _עושי, _erba_, vaun
  { {0x27ff0034,0x69dc0125,0x248f01d7,0x59c50015}},	//   _waun_, _gcre, _sigm_, _ديسك
  { {0xe802005d,0x44f80092,0xce380008,0x05790015}},	//   _रोका_, _cũ_, שאות_, دمغة_
  { {0xed580008,0xd64d0010,0x80c0005d,0x6d48002d}},	//   יבור_, _лiпе, _विजे, údai
  { {0xdb0607cf,0xc6d40015,0x473507d0,0x869807d1}},	//   _sekú, _وتكت, _унас, _вкус_
  { {0xe4e70191,0x629b0152,0xb06300f2,0xdb0f0144}},	//   _відн, rquo, äänt, _mecà
  { {0x63a20026,0x9f5e0089,0xe4e40036,0xcf89000a}},	//   _ffon, ětí_, _міцн, _נט_
  { {0xaac7005d,0x660107d2,0x44e10387,0xc952000f}},	//   _लिंक, _halk, mó_, למי_
  { {0x43850015,0x539a000a,0x44e107d3,0x69c707d4}},	//   _الشق, _עיסו, ló_, _odje
  { {0xf6790053,0x660100f2,0x877a0053,0x6da307d5}},	//   טאָמ, _jalk, טארי, зира
  { {0x80ce000b,0xc27a000a,0x44e107d6,0x660107d7}},	//   _थिये, _גרסי, nó_, _malk
  { {0xdb0a0089,0x69dc07d8,0x3e7d0046,0xcb6a07d9}},	//   šníh, _scre, _pátý_, габе_
  { {0x63b90176,0x290a016f,0x44e10092,0x629901d7}},	// [920] _mewn, _srba_, hó_, _juwo
  { {0xbf9b03af,0x4229000a,0x499601b7,0xb40b002a}},	//   ndên, נֵּ֣, сшат, ążył
  { {0x31ba00b2,0x497a0010,0x387f0125,0x44e107da}},	//   רזענ, усаў_, _bhur_, jó_
  { {0xe73a005f,0x387f002f,0x07b70029,0x44e107db}},	//   лее_, _chur_, مهمة_, dó_
  { {0x27e60026,0xa01b007c,0xd62a0248,0x4b55006b}},	//   rfon_, dmöl, лоде_, _дърт
  { {0x63a204ed,0xceb300a3,0x7ae407dc,0x54e60015}},	//   _sfon, ליד_, mtit, مسبق
  { {0x96c4005d,0x44e107dd,0xc7a6004a,0xe4ea00c3}},	//   _रिकॉ, gó_, _гибк, اعته_
  { {0x44f80023,0x39570008,0xd5b10016,0x9cd7000a}},	//   _vũ_, _השלם_, _sót_, צופה_
  { {0x8c1b0008,0x85060086,0x326607de,0xd3700029}},	//   רופי, _گوان, йтов, بهة_
  { {0x11d8003b,0xd6250029,0x3e7f0152,0x8afb0135}},	//   جودة_, _وعلي, oîte_, נהיי
  { {0x0496003b,0x7174003b,0x44e102c1,0x63b90026}},	//   _الصح, تهدا, có_, _fewn
  { {0x6e250064,0x7c2607df,0xbfab004a,0x787804b2}},	//   _sohb, _nokr, ытое_, zívn
  { {0x447b00b4,0x1fa40033,0xa3760015,0x78780030}},	//   _ענדע, ярэг, _اداؤ, hívo
  { {0x63b90050,0xbc95000d,0x39dd005d,0xa2f7000a}},	//   _zewn, жавј, न्फ़ि, _למדה_
  { {0x90a60225,0x7c2607e0,0x7ae407e1,0x6d340148}},	//   _احتم, _bokr, etit, перф
  { {0x98c50024,0xb157000a,0x7d030030,0x3157000a}},	//   ūtīt_, _לסוג_, eírá, _ליון_
  { {0x44e10014,0x7878002c,0x9e660086,0x2fc901a7}},	// [930] zó_, tívn, _ژاپن, _idag_
  { {0x98b80064,0x44e102c1,0x442607e2,0x7d030030}},	//   _ayrı_, yó_, _loo_, gírá
  { {0x35d2000b,0xda78023c,0x25d2000b,0xb8f50015}},	//   _साज़, сят_, सलैण, تكاب
  { {0x44e102c1,0x6f0d07e3,0x60db004c,0xdd25003d}},	//   vó_, _krac, רקאנ, tīņa
  { {0xfaff0024,0x7d0307e4,0xba770015,0x660107e5}},	//   šību_, bírá, _هاست, _palk
  { {0x44e107e6,0xd1260196,0xaa5d005e,0x69c707e7}},	//   tó_, _قم_, _регi, _udje
  { {0xe3b1003b,0x63b90050,0x660107e8,0x5e580053}},	//   ورة_, _pewn, _valk, זיגע_
  { {0x386d003c,0x3ea900f2,0x660107e9,0x44e107ea}},	//   _uker_, _otat_, _walk, ró_
  { {0x660107eb,0xe2990054,0x44e107ea,0x1c2c000a}},	//   _talk, јао_, só_, רֽוּ
  { {0x63b9005c,0x44e10077,0x60e907ec,0x0000006a}},	//   _wewn, pó_, амом_,
  { {0x6f0d01e2,0xfbdf001c,0xf652000a,0x3ea90045}},	//   _arac, _ocê_, _קצב_, _atat_
  { {0x44c50024,0x93150015,0xa01b0123,0x7ae407ed}},	//   mē_, _وواش, lmöj, ytit
  { {0x44c50024,0x6da6004a,0x6f0d07ee,0x0d9a02ed}},	//   lē_, жига, _crac, итвы_
  { {0x442605d6,0x6f0d07ef,0x7c2607f0,0x0000006a}},	//   _zoo_, _drac, _sokr,
  { {0x27ed00b8,0x44c50024,0x7d030046,0xafe601b0}},	//   _oben_, nē_, vírá, _дойл
  { {0xeb970080,0x6a7000b8,0x320500da,0x2ca5001a}},	//   жит_, häft, ldly_, ílda_
  { {0x3b070254,0x6f0d07f1,0xaac50015,0x3a2607f2}},	// [940] оето_, _grac, كتلن, омаг
  { {0x3205003e,0x0b590033,0x7ae407f3,0x787807f4}},	//   ndly_, ёрты_, rtit, tívo
  { {0xd23a0053,0x7ae407f5,0x7c2607f6,0x27ed0030}},	//   סגעל, stit, _tokr, _bben_
  { {0x44c50024,0x7d030030,0x6bd6012c,0x4d7b004f}},	//   dē_, sírá, _بتدر, _כריע
  { {0xc7a307f7,0x7d030046,0xfaa607f8,0x0000006a}},	//   фичк, pírá, _фаго,
  { {0x3af900b2,0xe4a6000d,0x27ed00b8,0xa3e7005d}},	//   _פּרע, орио, _eben_, म्स_
  { {0xd497054f,0xc8b50033,0xc7a6006b,0x47d60015}},	//   оры_, _нсты, _мивк, _ويسر
  { {0xe4660061,0x320500da,0xf2c607f9,0x0000006a}},	//   _önüş, edly_, осон,
  { {0x83fd00dc,0x69da0064,0xb2860033,0xd25a011d}},	//   rlőp, _ötes, жынк, ицо_
  { {0xc5160015,0x89da000a,0x26c00091,0x52830015}},	//   _وبات, ׁחִי, šios_, وليك
  { {0x4a7b00b2,0xfbca014e,0xd2570010,0x64950089}},	//   שריב, िणाम, ўцы_, _všic
  { {0x320500da,0x4034004a,0x6f0d0771,0x0000006a}},	//   adly_, деюс, _prac,
  { {0xe67b0092,0x3d950763,0xa3560058,0xf8d70065}},	//   _hưở, зигр, _بخاص, _डम्प
  { {0xdef8008f,0x6f0d07fa,0x68e50416,0x0000006a}},	//   цыю_, _vrac, ythd,
  { {0x6ce40191,0xbc4b0010,0x6f0d07fb,0xd1300015}},	//   міте, ачае_, _wrac, _سمة_
  { {0x2611005d,0x6f0d07fc,0xafdb04d1,0x0c840138}},	//   _धोनी_, _trac, riøs, дыум
  { {0x93fb0008,0x44c50024,0x97ea0064,0xe9ab0021}},	// [950] סלמי, zē_, ışlı, لدان_
  { {0xf8b10086,0x78a300dc,0xceb2000a,0xeab00015}},	//   فکر_, ínvo, _ריי_, ضعك_
  { {0x57f5006b,0x6e2102ad,0x0000006a,0x0000006a}},	//   зпет, ölbu,   ,
  { {0x9cd60008,0x68e50495,0x44c5003d,0xa8020061}},	//   _צורה_, rthd, vē_, _çılg
  { {0x8c1a000f,0xbc1a000a,0x99d70015,0x8bc40033}},	//   _הורי, _הורש, _وتسا, _ўсюд
  { {0x1efc0053,0xafdb003c,0x2efc000a,0x44c5003d}},	//   ילדע, rnøy, שִׁב, tē_
  { {0x6a7007fd,0x2db8000a,0x7af90061,0xafdb00cb}},	//   räft, חלון_, şatı, snøy
  { {0xf9920008,0x98170029,0x8d5c0008,0x44c50024}},	//   _טרם_, _ببسا, יכוי, rē_
  { {0xf749003b,0xe3b10086,0x24480086,0xe3b60010}},	//   _الذي_, ورک_, تجوي_, чбы_
  { {0x36370074,0xeb920008,0x44c50024,0x9b16000a}},	//   _بررس, עָה_, pē_, פחתה_
  { {0x216907fe,0x3205003e,0x8622002b,0xdb1d02de}},	//   сини_, rdly_, _سکول, _udsæ
  { {0x29360053,0xd12e0015,0xa936000a,0x3ea4013f}},	//   פארן_, امَ_, פטרה_, ímto_
  { {0x2004002c,0x539a0447,0xc7d6000a,0x3e76001a}},	//   ľmi_, _הסנא, הורי_, læti_
  { {0x161e000b,0xa3e7000b,0xf3f90045,0xa0c50015}},	//   पायर_, म्र_, leţ_, _فيتو
  { {0xc692013a,0x91ba0008,0x443f07ff,0xed52002b}},	//   תאם_, _המצי, ohu_, رپر_
  { {0xc0a80029,0x01340002,0xaac7000b,0x7aa6004a}},	//   _باول_, _تعهد, _लिखक, зиаз
  { {0xf093000a,0x99830046,0x89f60033,0xe085012c}},	// [960] _אנה_, _bojů_, зяец, _تجوي
  { {0xb4bb005d,0x499a04ab,0xda650021,0x97ea0061}},	//   _अबू_, стая_, والي, ışmı
  { {0x9e650015,0xa96a0015,0xd7ef0800,0x7d0102de}},	//   _تاين, حمام_, ну_, ælst
  { {0xfc32003b,0xdb040111,0xc0ac000a,0x7a32001a}},	//   _أحد_, ncië, ׁיבָ, _mæti
  { {0xfbd3013a,0xf3f90045,0x7c360123,0x96b70054}},	//   _אתר_, deţ_, mkyr, пују_
  { {0xe8df0023,0xd6a90086,0x4b7b0008,0xdb0f016e}},	//   _giữa_, زدهم_, _לאכו, _secç
  { {0x4dfb004c,0x9abe0033,0x5ede000b,0xdb060030}},	//   מפסא, вiча_, कंड्_, _lekü
  { {0xb3c6000b,0xe73a067a,0xdbcf0046,0x895b000a}},	//   रृंख, _леб_, ožád, _הדלת
  { {0xdb0600dc,0x8c1b000a,0x75960015,0xf74307f9}},	//   _nekü, מוקי, _فجاء, _зето
  { {0x7a32002e,0xe67b0092,0x443f0801,0x83330015}},	//   _bæti, _tưở, ahu_, عريض
  { {0x2619005d,0xf1dd005d,0xa01b008c,0x75d30015}},	//   पारी_, _मारन, lmöi, _أيما
  { {0xc4860802,0xdb0600dc,0xb97b0008,0x73e60010}},	//   _элек, _bekü, מניי, _ходз
  { {0xee87004a,0x7a3202de,0xbf3401b7,0x9471002b}},	//   зыво, _tæth, енящ, _جگوا
  { {0x13170008,0xf0b70086,0x12fb000a,0xc333000a}},	//   _מחדל_, _کاوش_, _להדב, _רוס_
  { {0x7a320084,0xc27b0008,0xe9ff0092,0xa1570803}},	//   _gæti, _הרגי, _ngạc_, _нашу_
  { {0x415b013a,0x31c60089,0x2d580036,0x515b0008}},	//   _לדוג, bízí_, чись_, _לכוו
  { {0xdb040152,0x8f9c039e,0xdb060012,0xdb0d0003}},	// [970] nciè, _פיזי, _gekü, rbaï
  { {0x61fa0407,0x7a570015,0xca73002b,0xe29f001a}},	//   netl, أضرا, رناک, íði_
  { {0x60da0064,0x2489002c,0x53dc0065,0x6ca402db}},	//   nutm, ňami_, _यांश, _пряж
  { {0xf7700074,0x3755002b,0xf77500fd,0x61fa0804}},	//   گام_, وپاس, мулю, hetl
  { {0x61fa01e2,0x6440002d,0x2619005d,0x66050805}},	//   ketl, dhmi, पाली_, дпла
  { {0x61fa016f,0xf7700806,0xf3f90045,0x78780030}},	//   jetl, دام_, inţe_, hívh
  { {0x443f0807,0x61fa0808,0xd5e80058,0x91b300a1}},	//   thu_, detl, سعون_, _đèn_
  { {0xc9520008,0x52a90809,0x7cec000a,0xd2a905ab}},	//   _סמן_, овим_, צַוֶ, окие_
  { {0x13060080,0xa3df005d,0xf3f90045,0x61fa080a}},	//   дный_, तलब_, reţ_, fetl
  { {0x68e100c0,0x64400064,0x61fa078e,0x645b080b}},	//   _älds, ahmi, getl, snui
  { {0x95c40086,0xdcf6003d,0xa2cf000b,0xf3f90045}},	//   _سينه, ācīb, _दिव्, enţe_
  { {0xcdc9013a,0x6440080c,0x78a900bc,0xdbcf0046}},	//   _כך_, chmi, _čevl, yžád
  { {0xdb040111,0x43740180,0x61fa080d,0x0000006a}},	//   rcië, _пушт, betl,
  { {0xa294005e,0x0caa0015,0xc1050021,0x329a000a}},	//   _зачі, قطري_, _يوشي, _ובסד
  { {0xe2900015,0xebe6005e,0x1d07080e,0xf3f90045}},	//   _إذن_, мовп, мери_, anţe_
  { {0x6e21001a,0x0000006a,0x0000006a,0x0000006a}},	//   ölbr,   ,   ,
  { {0x29030020,0xfaff0024,0xba1a0015,0x5e460015}},	// [980] _asja_, šīnu_, ييرا_, _يَبْ
  { {0x7c36080f,0x64850810,0xf9920015,0x29110085}},	//   skyr, lóid, نبا_, _brza_
  { {0x32070041,0xac860036,0xae1b0053,0x3ea00152}},	//   _many_, _огол, _וויכ, _huit_
  { {0xc9850015,0x38cb002b,0x68e30144,0x999a0091}},	//   رشلي, زامی_, ànda, tipų_
  { {0x46a30010,0x61fa0700,0xabfb000a,0x1bfb000a}},	//   вачв, yetl, _והכר, _ולכב
  { {0x443d0026,0x28db000b,0x8a060033,0xd5af0040}},	//   _alw_, मूहि, _ўзве, لفه_
  { {0x5e5700b2,0xe0c70086,0xab5b0012,0xa7da0015}},	//   ויסע_, _جز_, _geüb, _ووسط_
  { {0x47d30029,0x2816002b,0x61fa0811,0xdb04039f}},	//   _ليفر, _تورس, wetl, ecié
  { {0x3ea00152,0x68e100c0,0x61fa00dc,0xa3df000b}},	//   _nuit_, _äldr, tetl, _तार_
  { {0x443d0026,0xdb040003,0x64400812,0xa683012e}},	//   _elw_, rciè, shmi, _алуд
  { {0x60da0020,0x61fa0813,0x659b000a,0xa055005e}},	//   uutm, retl, _ויבק, евні
  { {0xf9930008,0x68e100c0,0x3ea00814,0x61fa0815}},	//   כרת_, _ålde, _buit_, setl
  { {0xc7b30008,0x3cf1000b,0x69ce0816,0x741300c3}},	//   כבר_, ँढ़ने_, _odbe, _جونا
  { {0x3ea00817,0x799c0034,0x52130033,0x43930033}},	//   _duit_, _ngrw, _адшт, _раіс
  { {0xd3080023,0x6e940818,0x41db000a,0x41c30015}},	//   _hệ_, тиру, _וחוס, _شقيق
  { {0x1bbb0029,0x3ea00003,0xd3080016,0xdb5b0121}},	//   تاسع_, _fuit_, _kệ_, оюз_
  { {0x629800dc,0x7a32002e,0x661a0234,0xae0c000b}},	// [990] _kivo, _lætu, _ontk, िएशन_
  { {0x200903f8,0xdcfc007f,0x66080819,0x0000006a}},	//   _haai_, abrı, _nadk,
  { {0xd3080023,0xb86b0004,0xa9280033,0xdb1d0030}},	//   _lệ_, ојде_, міце_, _mesé
  { {0xa2cf014e,0xec350053,0x31570053,0xf8680015}},	//   _दिल्, _נאָר_, ויבן_, وملي_
  { {0xd7580015,0xe7240015,0x8bd6000a,0x0aeb0015}},	//   وجها_, َّمَ, _אורו_, _برجي_
  { {0x2009020a,0xdb1d002c,0xfb160053,0x629801a3}},	//   _laai_, _odsú, _אַלט_, _nivo
  { {0x67d50001,0x3207002a,0x69c5081a,0x46120015}},	//   _пову, _rany_, mahe, طوير
  { {0xcd98011f,0x69c50020,0xdcb10092,0x83fd00dc}},	//   ודות_, lahe, ẩy_, llőz
  { {0xb7bd0045,0x2fc003a0,0x6298081b,0x0000006a}},	//   _noţi, _reig_, _bivo,
  { {0x64950007,0x5999000a,0xd70202a3,0x7a32001a}},	//   _išim, ּשֹׁ, _вiта, _fætu
  { {0x7a32002e,0x245a0024,0x3ea00493,0x20090079}},	//   _gætu, zīmi_, _suit_, _baai_
  { {0x7a320084,0x78780227,0xf99200f3,0xe8d6000a}},	//   _hætt, tívi, טרי_, עורר_
  { {0x6485081c,0x3ea000da,0x2fc00144,0x200900aa}},	//   róid, _quit_, _veig_, _daai_
  { {0xe29f0084,0x6485002d,0xd356000a,0x3ea00144}},	//   íðu_, sóid, _איני_, _vuit_
  { {0x75f30064,0x7a32081d,0x63a9081e,0xab5b01d3}},	//   mızı, _mætt, ocen, _odüs
  { {0x98a70089,0x6f04002d,0xa156000a,0x91fc003d}},	//   šně_, _tsic, _רבקה_, anād
  { {0xfc3f002d,0x6f04003f,0xada6081f,0x6da6018d}},	// [9a0] _dlí_, _usic, _папл, _пипа
  { {0x75f301e2,0x19b9008f,0x09e30033,0xba260033}},	//   nızı, дуць_, лоун, эдзк
  { {0x27fd0026,0x3236004c,0x4236004c,0xba3b0144}},	//   fewn_, עטען_, ענעל_, _suïc
  { {0xe7860036,0xc18c0053,0x248d0820,0x59e2000b}},	//   нуло, קטאָ, jmem_, _पावर
  { {0x7a320821,0x2ba8005d,0xcfb7000a,0x9e65002b}},	//   _bætt, _ज़्या, גלני_, _ساین
  { {0x69ce0134,0x672d008c,0x25780822,0x63a90823}},	//   _udbe, äaja, мбль_, ecen
  { {0x629804ed,0xa507011e,0x0000006a,0x0000006a}},	//   _rivo, ееја_,   ,
  { {0x47d600a2,0x5503004a,0x63a902de,0xf1dd0065}},	//   _سيطر, учша, gcen, _माउन
  { {0xa01b0084,0x8857000a,0xdb080003,0x41e60033}},	//   llög, _נשמע_, élèv, ніна
  { {0xd3080023,0x24860041,0x63a90824,0xddc700bd}},	//   _vệ_, _whom_, acen, kojš
  { {0xb7bd0011,0xa3e8000b,0x45b7000a,0xa01b001a}},	//   _soţi, _बाप_, _נפאל_, nlög
  { {0x44cc0089,0xd3080092,0x653b0008,0x853b000a}},	//   mě_, _tệ_, _מעבד, _מגבי
  { {0x8457004c,0x62980825,0x0000006a,0x0000006a}},	//   _אבאס_, _tivo,   ,
  { {0x61460152,0xfc3f002d,0x28d1000b,0x200900aa}},	//   _célé, _slí_, _हिलि, _waai_
  { {0x69c50005,0x44cc0089,0x61460152,0x2009042f}},	//   vahe, ně_, _délé, _taai_
  { {0x8aa70080,0x717b000a,0x317b000a,0x9f520077}},	//   ержд, _מנוס, _מרומ, _cayó_
  { {0x657a0026,0xa3e8000b,0x69c50826,0x61460030}},	// [9b0] _lyth, _बान_, tahe, _félé
  { {0xbbeb0086,0x248d005c,0xbb840015,0xf3f90045}},	//   _کردم_, zmem_, الكي, inţa_
  { {0xe61f0023,0x18a4005e,0x78780030,0x657a0827}},	//   _đô_, гаєм, hívu, _nyth
  { {0x44cc0089,0x7a320134,0xd7590031,0x69c50828}},	//   dě_, _sætt, ولات_, sahe
  { {0xd763002b,0x245a003d,0x657a0123,0xab840829}},	//   دنشی, nīmu_, _ayth, _бурк
  { {0x657a0026,0x64950107,0x7aed082a,0xcad6004f}},	//   _byth, _všim, mtat, _בושת_
  { {0xf3f90011,0x8578006b,0x1600000b,0x657a082b}},	//   enţa_, нсът_, ऊज़र_, _cyth
  { {0xf8b2000a,0x99840015,0x657e0061,0x612a0061}},	//   _כשל_, _إلفو, üpha, zölç
  { {0x48640063,0x14220010,0x7a32063b,0xb722002b}},	//   _сърб, рдым, _tætt, _نکوه
  { {0x44cc0089,0x25ac082c,0xd64b005e,0x63a9082d}},	//   bě_, _gfdl_, _пiсл, scen
  { {0x387d0026,0x63a9082e,0xf3f90045,0x657a0034}},	//   olwr_, pcen, anţa_, _gyth
  { {0x321c082f,0x73390248,0x7aed0830,0x614601f6}},	//   _envy_, _озер_, ktat, _sélé
  { {0xe28e0831,0x7aed0030,0x387d0034,0x20550138}},	//   _ва_, jtat, ilwr_, утэр
  { {0xc0a80086,0x7aed0832,0x0dba00e6,0x82d6015b}},	//   بایل_, dtat, باحث_, _יונג_
  { {0x7aed0667,0x442f0085,0x2175004c,0x1fb60833}},	//   etat, _kog_, _בײַם_, _испр
  { {0x442f0834,0xb06300f2,0xe8df0016,0xc4d205bd}},	//   _jog_, äätt, _nhựa_, יגל_
  { {0x6146038d,0x7aed00b6,0x442f016f,0x80bd000b}},	// [9c0] _télé, gtat, _mog_, वीरे
  { {0x4a430835,0xd5e0000b,0x8f37000a,0x78780030}},	//   анув, _नाइज, _סניף_, hívt
  { {0x4dd900b2,0x2dd90053,0xd5be0024,0x387d0026}},	//   _אַרױ, _אַרב, šāka_, flwr_
  { {0x44cc0089,0xbb860015,0x657a0003,0xd7f70033}},	//   vě_, _للجي, _ryth, вуш_
  { {0xb606006b,0x657a0034,0x7aed0836,0xb865006e}},	//   вяйк, _syth, ctat, دالو
  { {0x44cc0089,0x98a70011,0xdb0600dc,0x7673042b}},	//   tě_, ână_, _bekö, аліф
  { {0xe9760086,0xdff4000b,0x04660054,0x8503002b}},	//   _شهرد, ेजाद_, ктим, لوون
  { {0x24650024,0xd4670054,0x78780030,0x6f160837}},	//   tēma_, кије_, tívu, _oryc
  { {0x657a0176,0xa01b002e,0x442f0838,0x65c60839}},	//   _wyth, kmör, _dog_, _абза
  { {0x44cc0046,0x442f0034,0x0000006a,0x0000006a}},	//   pě_, _eog_,   ,
  { {0x7aed03c0,0x442f0014,0x320a002c,0x3a370008}},	//   ztat, _fog_, ľby_, דרים_
  { {0x7658000c,0xe5370053,0x7aed00dc,0x320a0107}},	//   livy, _שטאט_, ytat, žby_
  { {0x7641008c,0x2d8c0046,0xbf0d000b,0x6442083a}},	//   _ylly, ýden_, िटेन_, _iloi
  { {0x442f00b8,0x539b0008,0x12a90029,0x7c2f083b}},	//   _zog_, _חידו, _أدنى_, _socr
  { {0xbca5003b,0xe29b0008,0x16df000b,0xe04b0015}},	//   امري, _קשור, _नम्ब, _يشبه_
  { {0xbf670029,0x7658003f,0x46d2000b,0x7aed083c}},	//   _لدخو, hivy, _सिंह, ttat
  { {0x4c940731,0x5b150033,0x7aed083d,0xfb340033}},	// [9d0] ритс, ымат, utat, антэ
  { {0x201e0024,0x7aed083e,0x27140016,0x99d40015}},	//   ētie_, rtat, _ình_, لتما
  { {0xda7803ad,0x39a40784,0x59c40015,0xdd910067}},	//   тят_, ршув, شينك, _دود_
  { {0xdd3a0008,0x87d40033,0x7aed083f,0x672d008c}},	//   _נערכ, аўшч, ptat, äajo
  { {0xd7ee0029,0x16350063,0x442f0011,0x7bda000a}},	//   سكو_, ледя, _rog_, _אקרו
  { {0x6442022d,0x7f3c0008,0x6d580007,0x442f00b8}},	//   _aloi, ועדו, _žvai, _sog_
  { {0x7878032c,0xe4c80029,0x56920001,0x78ac006f}},	//   tívt, نبين_, љајт, ľové
  { {0x130905cb,0x84580080,0xe80b000b,0x3c57000a}},	//   ений_, крыт_, _सोचा_, כֹ֖ל_
  { {0x628a002f,0x97ea01e2,0xe5e5002b,0x26cd0085}},	//   _bhfo, ıştı, _مزای, _uveo_
  { {0xa3e8000b,0x42250840,0xa3df0065,0xfad6004f}},	//   _बाथ_, удов, _ताक_, נותך_
  { {0xf3f50086,0xe4e40036,0xa2cf000b,0x6ec6000b}},	//   _متشک, _вічн, _दिक्, ़ीनु
  { {0x64420152,0x6138002d,0x63050058,0xab5b0546}},	//   _gloi, _súlú, _موصل, _reün
  { {0xa3e8005d,0x63bb0841,0x93270015,0x60da015e}},	//   _बात_, mbun, _جران, artm
  { {0xa2d8005d,0xb0630020,0x63bb0842,0x7a1b003d}},	//   _मित्, äärt, lbun, _jātē
  { {0xdb1d0089,0xa01b0843,0x2bba0015,0x5d860015}},	//   _desí, rmör, فاءة_, الأل
  { {0x40950010,0x6e3c0844,0x6f160845,0x6bb5005e}},	//   _крыт, skrb, _tryc, исує
  { {0x63bb00b8,0xc0530008,0x6f160089,0xcaa60015}},	// [9e0] ibun, _לזה_, _uryc, اصري
  { {0xbf9b000a,0x20020846,0x996c003d,0x8f9b004f}},	//   _איפש, leki_, _vēža_, _איפי
  { {0x9c66002b,0x38cb002b,0x1e97000a,0x46c6000b}},	//   _مهدو, فانی_, _תכיל_, रीनह
  { {0x46a60010,0xdb1d0046,0xeef6000a,0x20020847}},	//   гадв, _zesí, ָמַר_, neki_
  { {0xa2cf000b,0x601b008c,0x929d002a,0x2907001a}},	//   _दिग्, _hämä, zwła, ænar_
  { {0xb5aa0029,0x6442002d,0x63bb00b8,0xa5f80848}},	//   راتك_, _sloi, ebun, теку_
  { {0xa3e8014e,0x7bc60849,0x6442084a,0xbf9b00aa}},	//   _बाद_, _keku, _ploi, ndêr
  { {0x53e60010,0x7658084b,0x200201d7,0xb509000b}},	//   уцка, sivy, jeki_, विजय_
  { {0x3855010f,0xc1ea008f,0x200201e2,0x41c604f7}},	//   _търс, ньне_, deki_, лёна
  { {0x64a60036,0x27e60123,0x06760033,0xc5d50033}},	//   _бажа, lgon_, _субя, _віць
  { {0xdb1d016e,0x601b008c,0x8936000a,0x64850030}},	//   _resí, _nämä, רָ֥א_, móin
  { {0x6485084c,0xa3bb0157,0x7bc6084d,0x27e6084e}},	//   lóin, _अभय_, _neku, ngon_
  { {0xa857013a,0x73360015,0x27e60034,0x90540033}},	//   ריכה_, _حرائ, igon_, свяц
  { {0x539b00a3,0xe731000a,0xdb1d016e,0xa194084f}},	//   _ניגו, חֵל_, _lesã, _калч
  { {0xe7a4014e,0xdd95008f,0x523b0053,0x56370053}},	//   _ओलंप, равы, _אײגנ, נאלע_
  { {0x200201e2,0x7bc601d7,0x5b270822,0x0000006a}},	//   ceki_, _ceku, льза,
  { {0xba55009c,0xe451000a,0xb09c004c,0xadd50054}},	// [9f0] авај, קֶל_, _איהר, _копљ
  { {0x63bb0045,0x5d550850,0x27e60079,0x5eec000a}},	//   zbun, _вкот, egon_, _נַחְ
  { {0x3eb90024,0x63bb005c,0x648503d9,0x7e9a000a}},	//   lpst_, ybun, dóin, _שסתו
  { {0x64b10048,0x63a20297,0x27e9007c,0x2ca5001a}},	//   _jāie, _ngon, üan_, íldu_
  { {0x291800d9,0xd00c0008,0x67d4000d,0x7c2b0020}},	//   _erra_, גּוֹ, сочу, ögru
  { {0xbada0008,0x6485002d,0x20020851,0x99870030}},	//   _בקשת, góin, zeki_, űnő_
  { {0xce38013a,0x7dd000dc,0x91f50092,0x15450286}},	//   ראות_, lósí, híc, рейм
  { {0xd3f90010,0x63a20125,0x7c2d0852,0x63bb0853}},	//   тэкі_, _cgon, njar, ubun
  { {0x787a000a,0xe4320015,0x63bb0854,0x3aef0061}},	//   _יָמו, تفيد, rbun, nüp_
  { {0x63bb0855,0x5b7c004c,0x7e0f000b,0x994a0061}},	//   sbun, ערזא, ायोग_, nışa_
  { {0xd567000d,0x1021005d,0xafdb0134,0x80660342}},	//   _стап, यांश_, dkøb, ивож
  { {0xdd2f0089,0x8464006b,0x7afd0856,0x3aef0061}},	//   _běže, _лъче, _opst, küp_
  { {0x387e038d,0x343a0053,0x64490857,0xa01b001a}},	//   _être_, _שײנע, mhei, rmöp
  { {0x69c70522,0x442d0858,0xa695000a,0x443f0859}},	//   _neje, lje_, יכָה_, lku_
  { {0x7afd0048,0x31790053,0x27e60026,0x7bc602e8}},	//   _apst, _באַד, ygon_, _peku
  { {0x62060024,0x44f10092,0xef1a0661,0x442d085a}},	//   ārlū, _mơ_, _ами_, nje_
  { {0x69c70014,0x207b0053,0x442d016f,0x64490437}},	// [a00] _beje, _באקא, ije_, ihei
  { {0x601b022d,0xa2d8005d,0x6f090064,0x442d0201}},	//   _tämä, _मिस्, çece, hje_
  { {0x443f0005,0x6449020a,0x4ddb0008,0x7bc6085b}},	//   kku_, khei, _בחיו, _teku
  { {0x1ae6005f,0xf0930053,0x64490111,0xca2900a3}},	//   _комм, ַנג_, jhei, ום_
  { {0x69c700dc,0x648500dc,0xa3df000b,0x442d085c}},	//   _feje, tóin, _ताज_, dje_
  { {0x442d005c,0xaa46085d,0x443f0340,0x91a7000b}},	//   eje_, _тегл, eku_, _फ़्लै
  { {0x44f10023,0x7ae4085e,0x6d4e0012,0x86070015}},	//   _cơ_, luit, nzba, شقيق_
  { {0x644900f6,0x6281085f,0x645b0045,0x18a3067a}},	//   ghei, ello, giui, _фатм
  { {0x2338005f,0xdc370053,0x77940086,0x55e60860}},	//   уппы_, שאפט_, _ایشا, _возб
  { {0x11d80029,0x443f0861,0x75d30015,0x442d0862}},	//   دودة_, aku_, _ويقا, aje_
  { {0x85060074,0x442d00bd,0x7ae4002d,0x8233006e}},	//   _خوان, bje_, huit, تريا
  { {0x442d0050,0x63a20863,0x68e30144,0x38660864}},	//   cje_, _ugon, àndi, nnor_
  { {0x11f80086,0xd372002b,0xfe7f0865,0x9316002b}},	//   _موشک_, _بهش_, juïc_, _خوشش
  { {0x7ae40866,0x234b002b,0x02fb000a,0x66fa003d}},	//   duit, _جسمی_, _סלומ, mākā
  { {0x69c70867,0x6c970015,0x7c970015,0x0ed3000b}},	//   _reje, لشرط, لشرا, _तिकड
  { {0xe517014e,0xb19b000a,0x219b000a,0xf19b000a}},	//   थिति_, _ביוכ, _בבוא, _בשוש
  { {0x7ae40868,0x228b003c,0x994a0061,0x66fa003d}},	// [a10] guit, søke_, tışa_, nākā
  { {0x443f0107,0x3aef0061,0xd2b7000a,0x442d0869}},	//   zku_, rüp_, ילמת_, zje_
  { {0x442d086a,0x69c7086b,0x35e0000b,0x6449086c}},	//   yje_, _veje, _नाज़, yhei
  { {0x7ae4086d,0x3ea90509,0xad1a000a,0xc864086e}},	//   buit, _kuat_, _עורר, отчи
  { {0x44f10023,0x3b640063,0x442d00bd,0x7ae40011}},	//   _sơ_, _дърв, vje_, cuit
  { {0xcb360008,0x85e8005e,0x443f002a,0x2fc90125}},	//   _הנשק_, идів_, wku_, _leag_
  { {0x3ea90011,0xd5ae00e6,0x6449086f,0xfdf8000a}},	//   _luat_, رفي_, thei, יצגת_
  { {0xa2d8005d,0x442d0870,0x44f10016,0x7bcd0871}},	//   _मिश्, uje_, _vơ_, naau
  { {0xa3e8005d,0x442d0872,0xd408002b,0x66fa003d}},	//   _बार_, rje_, شتيم_, gākā
  { {0xa2d8005d,0x82f40010,0xf8d9000a,0x44f10016}},	//   _मिर्, ічыц, ְחָמ, _tơ_
  { {0x8467010f,0x2fc9002d,0x65150029,0x867a000a}},	//   _къде, _beag_, _دوائ, _ערעו
  { {0xa3bb005d,0x3ea90375,0xd079005e,0x66fa003d}},	//   _अभि_, _buat_, исяч_, bākā
  { {0x14740029,0x91fc0024,0x6f630256,0x94740021}},	//   _بالج, onāl, звяз, _بدلا
  { {0x28d8005d,0x6d4e00b8,0x877a000a,0xf776004c}},	//   _डिलि, tzba, ראשי, מערי_
  { {0xc2120008,0x3205003e,0x6efd00c0,0x6f0d00e8}},	//   _זהו_, mely_, _påbö, _esac
  { {0xa01b00f2,0xb6030107,0x32050769,0x2fc900aa}},	//   llön, _hráč, lely_, _geag_
  { {0xfb8a0010,0x6d4e0030,0x3ed3012c,0xb603013f}},	// [a20] убак_, szba, _فقير, _kráč
  { {0x239b0007,0x88c60015,0x32050873,0x27ed00a6}},	//   mąjį_, متصل, nely_, _acen_
  { {0x39790010,0xa3e8005d,0x7ae40874,0x64590079}},	//   асцю_, _बाल_, suit, _omwi
  { {0xb17a0053,0x2bba0015,0x7ae40875,0xa2d80065}},	//   אטער, _حادة_, puit, _मिल्
  { {0x3205003e,0xd7f90036,0x38660876,0x46f603a9}},	//   kely_, рує_, rnor_, счет
  { {0x2bd0005d,0x91fc0024,0xe4b80010,0x8f9b000a}},	//   तःका, gnāl, алкі_, איני
  { {0x2a6f00dc,0x32050873,0x186a0877,0x78a00123}},	//   égbe_, dely_, _бави_, _timv
  { {0xfbdf0026,0x91fc0024,0x66fa0024,0xe8e00092}},	//   _llên_, anāl, tākā, _chụp_
  { {0x661100f2,0x6440002e,0x239b0007,0x320500da}},	//   ökkä, rkmi, jąjį_, fely_
  { {0xd6cf0029,0x64400020,0x66fa0024,0x92b30029}},	//   _أقل_, skmi, rākā, أحيا
  { {0x53160074,0x20120049,0x66fa003d,0xda7b000a}},	//   _گذار, _bayi_, sākā, רניר
  { {0xa2e60010,0x0eeb0342,0xf3f90045,0x3ea1007c}},	//   _годд, льги_, tiţe_, _siht_
  { {0xe3160015,0x05ac000b,0x28af000b,0xd6c6012c}},	//   _دباب, _चलाब, _जूनि, بق_
  { {0x6d14000b,0xb3850015,0x25fb000b,0x32050878}},	//   डिंग_, _بجمه, ल्पी_, cely_
  { {0x725b0008,0x463b0053,0x7bcd002e,0x60b4002b}},	//   _תכופ, נעלע, taau, _بمبئ
  { {0xe1650086,0xc334000a,0x91fc003d,0x4fb7002b}},	//   _بدهي, ֗וּ_, inām, _اصغر
  { {0x6a350124,0xc3340008,0x6008000a,0x0ab80015}},	// [a30] онађ, חוּ_, _הִתְ, مطلب_
  { {0x91f50092,0xa381007c,0x7bcd001a,0x27ed0879}},	//   hín, öõig, saau, _scen_
  { {0xa3e8000b,0xcdf6000a,0x25fb0065,0xc0b200a1}},	//   बला_, _ומתי_, ल्फी_, _rưởi_
  { {0xac19087a,0xb901005d,0x3205087b,0xb17b000a}},	//   _тому_, _दि_, zely_, נטאר
  { {0xb06600f2,0xcff8000a,0x1dbf000b,0x6675002b}},	//   ltää, מצאה_, ्रपत, يدتر
  { {0xf770087c,0x1a940010,0x79c9002b,0x4b7a000a}},	//   ران_, _наяў, _خوسف_, _כארו
  { {0x32050041,0xb066022d,0x91fc0024,0x2e3c0008}},	//   vely_, ntää, rnāl, רגונ
  { {0xb066008c,0x32050034,0x64a2006b,0xe4c80015}},	//   itää, wely_, маща, حبون_
  { {0x32050041,0xe7330031,0x52a6054f,0xb066008c}},	//   tely_, _عصر_, овым_, htää
  { {0xe4e70036,0x239b0091,0xa2bf000b,0x22920058}},	//   _гідн, vąjį_, लीग्, وليس
  { {0x386d018c,0x3205003e,0x53fb0029,0xcf89000a}},	//   _kjer_, rely_, _مرشح_, _סט_
  { {0xdb1d00f2,0x6459003f,0x44f3001c,0x60dc087d}},	//   _kesä, _umwi, mã_, árma
  { {0x02450015,0x2d85068c,0xc7f6000a,0x32450015}},	//   _وَصَ, ülen_, חזרת_, _ونصف
  { {0xa01b008c,0x239b0091,0xdca60076,0xdb160061}},	//   llöl, rąjį_, жави, rayü
  { {0xf3f904f9,0x2d8c087e,0x387f0061,0x7643058a}},	//   enţi_, åde_, _okur_, ikny
  { {0x4c860033,0xac8600fd,0x6fb60058,0xbca30058}},	//   ілав, ігал, _بمظا, ِمِي
  { {0xe7ff005d,0x49ca0001,0x8b260033,0xdcef003d}},	// [a40] ोजना_, илан_, ўдзе, ījāt
  { {0x5e570029,0x25fb000b,0xceb90046,0x387f01c2}},	//   _وليس_, ल्मी_, íře_, _akur_
  { {0xf3f90045,0xad59006b,0xba170015,0xd7ef087f}},	//   anţi_, _грях_, تيلا_, му_
  { {0x225e00bd,0xafad000a,0xfe7f0144,0x77860880}},	//   zitk_, ְיוֹ, nuïn_, олез
  { {0x6009000a,0x59c60015,0x7c260881,0x98a30882}},	//   מִסְ, _ويحك, _inkr, фице
  { {0x9633008f,0x386d0134,0x6b8b00dc,0xc4da0001}},	//   мніц, _ejer_, ügge, ађи_
  { {0x86750010,0x344a03e7,0xdb07001a,0x7e9b000a}},	//   чыцц, ичин_, élög, בססו
  { {0x9cd70008,0x3957000a,0x66e60883,0x7e7c0884}},	//   קופה_, _ושלם_, _моба, horp
  { {0xe3af0029,0x16660063,0xcc3b0053,0x213e0026}},	//   خرى_, _двам, שעפט, wyth_
  { {0x7af600df,0xb06600f2,0xa646002b,0x8afb0447}},	//   ityt, ytää, _بخرن, ספיק
  { {0xf21f005d,0xea420033,0x7c260885,0x6e370886}},	//   बाज़_, явiў_, _onkr, _roxb
  { {0x91fc003d,0xc05b00ce,0x0000006a,0x0000006a}},	//   onāk, ріо_,   ,
  { {0x889b000a,0x289b004c,0xdefb0033,0x64b1003d}},	//   יבטי, ייטא, шын_, _jāin
  { {0x3f850048,0xb06600f2,0x7c260887,0x5e450015}},	//   ālu_, ttää, _ankr, أَسْ
  { {0x91bb0008,0xdfdb006b,0xac950888,0xf3f90045}},	//   _דמוי, _къп_, завш, liţa_
  { {0x1bbb0029,0x2bbb0015,0xb066008c,0x8cdc000b}},	//   شارع_, شارة_, rtää, _फिरो
  { {0xe8df0092,0xb06600f2,0x4426003f,0xdce70064}},	// [a50] _thừa_, stää, _mno_, ğlıd
  { {0x539b0008,0x7c2600bd,0x7e7c0390,0xe9870054}},	//   שימו, _enkr, corp, оћен
  { {0x7af60007,0x3a38016b,0x99910046,0xf3f90045}},	//   atyt, _dorp_, _vozů_, hiţa_
  { {0xa6c90029,0x38350010,0x7d7a000a,0x3858005e}},	//   موصل_, янер, _לנתו, орію_
  { {0x9bb6000a,0x8707002b,0xc8c9002b,0x2b52002a}},	//   _מהרה_, تبال, _گوزن_, czyc_
  { {0xd1260029,0xbb3a0008,0x44260889,0xcb9a000a}},	//   _كم_, _העשי, _ano_, _לסרט
  { {0x044502e1,0x4dfc004c,0xc5080015,0x91fc003d}},	//   зейн, יפגא, قتيل_, anāk
  { {0x44f3016e,0x94790054,0x387f088a,0x69d80030}},	//   rã_, љску_, _ukur_, óvev
  { {0x78240058,0x4426088b,0x44f3059d,0x0000006a}},	//   _تعّل, _dno_, sã_,
  { {0x4426018c,0x3a36000a,0xe6800045,0x64aa0046}},	//   _eno_, ִ֨ים_, ălţă, _břid
  { {0x05190058,0xfe7f03a0,0x7e7c088c,0x0000006a}},	//   _دياب_, tuïn_, vorp,
  { {0x44d704f9,0xe8df0023,0xb4fa0008,0xa06a088d}},	//   mă_, _chứa_, _לפעי, сама_
  { {0x44d704f9,0x644b088e,0x7d1e088f,0x27ff002d}},	//   lă_, _ilgi, _srps, _mbun_
  { {0x629d0089,0x539a000a,0xb2ba000a,0x8756000a}},	//   ůsob, _פיסו, _המסר, לברג_
  { {0x44d704f9,0x44260176,0xc0d20015,0xa8bc0061}},	//   nă_, _yno_, _كيوب, örüş_
  { {0xdb0d002d,0x0baa0015,0x7c9500fd,0x5baa0890}},	//   acaí, صارى_, друц, скам_
  { {0x78bb016f,0xaa46000d,0x290300dc,0x9aa60015}},	// [a60] _čuva, пеал, _apja_, سماو
  { {0x7af6014c,0x3af40123,0xaccb002a,0x69960891}},	//   rtyt, räp_, _żółw, прех
  { {0xbe3b0008,0x44d70011,0x18a60892,0xe8fa0893}},	//   _העית, jă_, чаем, сле_
  { {0x44d70011,0xa3ea005d,0xafdb0293,0x2cac001a}},	//   dă_, _टाइप_, lhør, íddu_
  { {0xf7430894,0x8c1b000a,0x91fc003d,0xdd8f002b}},	//   нецо, _הוכי, unāk, _لوی_
  { {0x7bc40007,0x76a90036,0xceb3000a,0xf3f90045}},	//   lbiu, ітів_, עיו_, viţa_
  { {0x44d70011,0x69dc0895,0xdb070030,0xf8e00065}},	//   gă_, _idre, ömör, _पटिय
  { {0xb60303eb,0x64a3000d,0x68e30896,0xad1b000a}},	//   ēšan, наја, ánde, מוצר
  { {0x69ce064e,0xf3630010,0x96b90897,0x7ae40898}},	//   _kebe, етэн, _духу_, nrit
  { {0x64aa0089,0x44d70011,0xb6bb000a,0x25fb000b}},	//   _přid, bă_, _לצמי, ल्दी_
  { {0x44d704f9,0x55bb0008,0x7ae400b8,0x64b30089}},	//   că_, _המבו, hrit, _přiř
  { {0x69ce018b,0x6f04002d,0x44260899,0x7d1c06c0}},	//   _lebe, _bpic, _uno_, dvrs
  { {0x69dc052c,0xa8570008,0xa87b004c,0x9f60001a}},	//   _odre, ליטה_, מאטר, órðu_
  { {0x539b0008,0x8cb1005d,0x62660086,0xe04b002b}},	//   _הידו, _आंदो, _عاشق, _گشته_
  { {0x01fb0008,0x51fb0008,0xd2170008,0xab5b00dc}},	//   _הפול, _ההוצ, _זקוק_, _leüt
  { {0x3cf6000b,0x7ae4089a,0x69dc089b,0xfe70002b}},	//   ँढ़ें_, frit, _adre, ندۀ_
  { {0x44d70440,0x69ce013c,0x1dbf000b,0xfaf30015}},	// [a70] ză_, _bebe, ्रदत, عثر_
  { {0x19ab000d,0x69ce089c,0xab840004,0x200b089d}},	//   стап_, _cebe, хуск, leci_
  { {0x3d24008f,0x7ae4089e,0x629a0091,0x44d70045}},	//   _зьяв, arit, imto, xă_
  { {0xf990003b,0x44d70011,0x9cd60008,0xc19b0053}},	//   ابك_, vă_, _קורה_, זשבי
  { {0x200b005c,0x7ae4089f,0x8c1a000a,0xbc1a000a}},	//   ieci_, crit, _וורי, _וורש
  { {0x44d70440,0xcb120008,0xa5650086,0xff18000a}},	//   tă_, _שלם_, وگان, פקות_
  { {0xdb1d002c,0x78a20057,0x7bcf0049,0x6d550012}},	//   _nesú, ňova, _kecu, nzza
  { {0x44d704f9,0x4439002e,0x200b016f,0xa01b00c0}},	//   ră_, ðs_, jeci_, slöj
  { {0xd5b100a7,0x44d704f9,0x04560029,0x7d1c0796}},	//   _các_, să_, بلية_, zvrs
  { {0x44d70011,0xd5d5002b,0xe0d908a0,0x6145070c}},	//   pă_, _آقاخ, ово_, деоа
  { {0x7ae4002c,0x69c50125,0xd00a006b,0x6fd8006f}},	//   zrit, ibhe, оене_, júcí
  { {0x7ae400f2,0x7bcf0011,0xe3b30029,0xd05a005e}},	//   yrit, _necu, _أرض_, ірні_
  { {0x73c40015,0x63050015,0xe1ee033d,0x82350015}},	//   _أيهم, _آوتل, _иг_, _يرتا
  { {0xf2d20008,0x91fc0024,0x3d0a005d,0x0165023e}},	//   _יעד_, riāc, ाबले_, _окло
  { {0x7ae408a1,0x91ba000a,0x69ce08a2,0xbea308a3}},	//   writ, _ומצי, _rebe, тарк
  { {0x7bcf0011,0x69ce08a4,0x50590033,0x69c50030}},	//   _cecu, _sebe, _ншыя_, ebhe
  { {0xd5b10023,0xf0930008,0xfeba0086,0x7bcf08a5}},	// [a80] _xác_, _בנה_, _بابت_, _decu
  { {0xff5f038d,0x6aa70111,0xe8df0092,0x41ba004c}},	//   raît_, _cijf, _chữa_, ַזנװ
  { {0xa90a0029,0x27fd0026,0x38cb002b,0xfbc608a6}},	//   تيال_, ffwn_, قانی_, _обно
  { {0x313600b2,0xa3c3005d,0xab2a08a7,0xad1b000a}},	//   ונעם_, ्रफ_, _дома_, _ווטר
  { {0x39460024,0xa09b0135,0x69ce08a8,0x628308a9}},	//   ņos_, קינט, _tebe, _okno
  { {0xd5b10092,0x454a005e,0x69ce0012,0x27f2002a}},	//   _rác_, жчим_, _uebe, żyn_
  { {0xaaa7000b,0xe4d30015,0x69350046,0xdb0601d0}},	//   _कूटक, نتيب, _přeš, _afkø
  { {0x64aa0089,0xd7060001,0xe314000d,0xdb1d0077}},	//   _přib, _озби, емињ, _resú
  { {0x41e602e5,0x27f70015,0xb66a0004,0x64aa0046}},	//   міна, _تفقد_, _диаз_, _břic
  { {0xd25003c4,0xd6260196,0x51f80036,0xa50a0054}},	//   اند_, _تعري, чною_, _меза_
  { {0xa01b00f2,0x92570029,0x45460115,0x63b90034}},	//   llöi, بشير_, _تناق, _ffwn
  { {0xc32a003b,0xd5b10023,0xe58b004f,0xb84a0138}},	//   _وكان_, _tác_, _וָדָ, йлiв
  { {0x200b0064,0x20190020,0xa2d8000b,0x7bcf08aa}},	//   reci_, rdsi_, _मिट्, _recu
  { {0x200b044c,0x1cbb0015,0x7bcf08ab,0x44cc002a}},	//   seci_, قارب_, _secu, oś_
  { {0x320c069b,0x1df8056d,0x7bcf08ac,0x6ca708ad}},	//   medy_, ьеры_, _pecu, драж
  { {0x28d8000b,0xc173000a,0x320c0046,0xa3c3000b}},	//   _डिजि, _שחק_, ledy_, ्रय_
  { {0x7b6700d7,0xa3b3000b,0x7bcf003d,0x6d550030}},	// [a90] фтве, जुट_, _vecu, szza
  { {0x22f7000a,0x1600000b,0x996705c0,0x648508ae}},	//   וזמן_, ल्मर_, мтел, lóit
  { {0x6aa70111,0xa3c3021e,0x320c005c,0x44cc002a}},	//   _vijf, ्रम_, iedy_, jś_
  { {0x3858002b,0xbbeb002b,0x99830091,0x7ae2003d}},	//   وشند_, _بردم_, _sojų_, šota
  { {0x320c002c,0x6c56000a,0xe70b002b,0x44cc002a}},	//   kedy_, _נישא_, تتان_, eś_
  { {0x24510107,0x88c70015,0x59c50015,0x7aed0375}},	//   _máme_, _يتأل, _سيرك, muat
  { {0x7aed08af,0xfe38000a,0xf8b40033,0xd8770058}},	//   luat, ורגי_, _абсэ, _قارب
  { {0xdb1d0293,0x0000006a,0x0000006a,0x0000006a}},	//   _besø,   ,   ,
  { {0x25a90086,0x64aa0089,0x1306004a,0x44cc002a}},	//   _فضای_, _přic, еный_, aś_
  { {0xcb120008,0x291e0007,0x320c00da,0x05b80040}},	//   נלי_, _štai_, gedy_, _قدمت_
  { {0x50b50010,0x1a160053,0xb899000a,0xca36000a}},	//   эспу, ײַיש_, ּבָש, תנתה_
  { {0x7aed0049,0x351a000a,0xdee608b0,0xa924006f}},	//   kuat, _מוענ, номи, _ôžet
  { {0x644900b8,0x64aa0089,0x201e0089,0x2bd3000b}},	//   mkei, _třic, ěti_, तरना
  { {0x443d003e,0x644908b1,0x24510227,0x7aed08b2}},	//   _how_, lkei, _dáme_, duat
  { {0x644900f2,0x52380015,0x27e00030,0x28af000b}},	//   okei, _تسنح_, óink_, _जूलि
  { {0x7aed000c,0x301a0015,0x6da30054,0x78a908b3}},	//   fuat, _رتبة_, уиса, _niev
  { {0x3b07010f,0x644900f2,0x1600000b,0x7aed08b4}},	// [aa0] нето_, ikei, ल्डर_, guat
  { {0x9b93003b,0x443d003e,0x2fe8002a,0x5e460015}},	//   الكت, _low_, ługą_, _أَدْ
  { {0x6449022d,0xef180024,0x628108b5,0xd94302ed}},	//   kkei, āļu_, iolo, лефи
  { {0x443d003e,0x68e30077,0x7aed013c,0x78a9006f}},	//   _now_, ánda, buat, _ciev
  { {0x0c230063,0x68430010,0x91fc03e9,0x78a908b6}},	//   _смян, ынца, onāt, _diev
  { {0x25fb014e,0x246c0046,0x7bd608b7,0x16d00065}},	//   ल्ली_, měmi_, layu, _हबीब
  { {0xb8660029,0x443d08b8,0xc8660015,0xf5170015}},	//   _كارو, _bow_, _كطري, فتيش_
  { {0x6449018b,0xd6d200e5,0x628108b9,0x85030021}},	//   gkei, _مقر_, eolo, اوين
  { {0xa3b70029,0x0edc000b,0xc7d7000a,0x4c9b000a}},	//   راير_, _बिगड, _רומי_, השקע
  { {0x644900df,0x2451006f,0xdb070003,0xf92a000a}},	//   akei, _ráme_, élég, ִוָּ
  { {0xc5f3000a,0x75d30015,0xd4c50033,0x320c08ba}},	//   _תדע_, _إيما, _асіп, redy_
  { {0xa3c3005d,0xd2500086,0x386608bb,0x1957000a}},	//   ्रण_, انگ_, nior_, תבטל_
  { {0xc43b0008,0xe29a0063,0x6485002d,0x2d8c0405}},	//   _מתאי, _еад_, róit, üden_
  { {0x661a022d,0x23690015,0xbea40033,0x44fa00aa}},	//   _jatk, _تحمي_, лаўк, oë_
  { {0xdcb10023,0x7c3d08bc,0x6ce4005e,0x661a08bd}},	//   ể_, _posr, літе, _matk
  { {0xdddc0046,0x7aed0043,0x661a08be,0x64850030}},	//   borů, tuat, _latk, lóir
  { {0xeab300a2,0xde79006b,0x49d90033,0x648b000a}},	// [ab0] اعر_, _обич_, ддзю_, פְלְ
  { {0x83fd00dc,0x78a908bf,0xbae40015,0x60cd002a}},	//   lnőt, _siev, اكلي, _łami
  { {0xdd9104b6,0x78a90048,0xd5b10092,0x7aed08c0}},	//   _خود_, _piev, _bán_, suat
  { {0x6485002d,0x386602b9,0x8c44012e,0x628108c1}},	//   hóir, gior_, _беџе, zolo
  { {0xdb0700f2,0xd5b10092,0x44fa00dd,0xab5b0111}},	//   ämäs, _dán_, eë_, _geüp
  { {0xa5090083,0x443d00d9,0xceb40008,0x99d40002}},	//   дека_, _sow_, איס_, _متفا
  { {0x6485002d,0xd61800a2,0x443d08c2,0xa01b001a}},	//   dóir, عتها_, _pow_, llöu
  { {0x6281002a,0x38660045,0xd5b10016,0xed6401c0}},	//   wolo, cior_, _gán_, loží_
  { {0xf7730029,0x644908c3,0x8c1c000a,0xc7b2000a}},	//   _صار_, rkei, לוהי, _כבן_
  { {0x6485002d,0x644908c4,0x629804b2,0xe607008c}},	//   góir, skei, _chvo, äpää
  { {0x2127002b,0x443d08c5,0x628108c6,0x8a16004f}},	//   ريحی_, _tow_, rolo, דחתו_
  { {0xa3d2014e,0x200404af,0xf76700e6,0x91fc0024}},	//   वरण_, ými_, لا_, liāl
  { {0x60c400bd,0xb7da000a,0x249f001a,0x6d47001a}},	//   _čime, וקרי, mmum_, eyja
  { {0x3f8c0024,0x9f6100dc,0x63bb08c7,0xfce6006d}},	//   ādu_, ását_, lcun, кого
  { {0x7bd60035,0xc5f2000a,0x9c860015,0x957c002a}},	//   tayu, ידם_, نشره, _idąc
  { {0x3ce500dc,0xa3c3000b,0x0701000b,0x248d0061}},	//   álva_, ्रि_, लझाव_, nlem_
  { {0x3866003e,0x248d08c8,0xcb6708c9,0x6e3e08ca}},	// [ac0] vior_, ilem_, вате_, _topb
  { {0x6fa7000b,0x3cea000b,0xae9a0015,0x7bd608cb}},	//   _गणतं, _छिपे_, _تضبط_, sayu
  { {0xfe370008,0xa3c3021e,0x661a08cc,0x6c860015}},	//   _סרטי_, ्रा_, _ratk, _للدم
  { {0xd5b10023,0xb90a005d,0x60dc00dc,0x83fd00dc}},	//   _báo_, _मि_, ármi, inős
  { {0xd5b100a7,0x69ca0084,0x2ca00020,0x248d08cd}},	//   _cáo_, ðfes, mmid_, dlem_
  { {0xe7370001,0x2ca0007c,0x44fa08ce,0x629d08cf}},	//   тељ_, lmid_, të_, ïsol
  { {0x386600c0,0xa2d4002b,0xd6270054,0xbf9b00aa}},	//   pior_, گيخت, тоје_, neêr
  { {0x7467004a,0x248d08d0,0x291808d1,0x661a08d2}},	//   крыв_, glem_, _isra_, _watk
  { {0x6d470050,0x2ca0002d,0xdb0d001c,0x6485002d}},	//   zyja, imid_, rcaç, tóir
  { {0x91fc0048,0xe731000a,0xae04000b,0xe61a005e}},	//   ciāl, _לֵב_, श्मन_, _іде_
  { {0x672208d3,0x248d08d4,0xd657000a,0x24f60033}},	//   lvoj, blem_, _שיבת_, _шчар
  { {0xdb040467,0x64850125,0xd8db000a,0x60da08d5}},	//   nció, sóir, וקטר, rstm
  { {0xf09f0251,0x733600e5,0xdb040077,0xb3e90015}},	//   rmà_, _جرائ, ició, _أعمل_
  { {0x2ca00020,0xc6940053,0x52d70008,0x672208d6}},	//   emid_, טאָ_, _יודע_, ivoj
  { {0xdb0400dc,0x7e670079,0x4fc708d7,0x6722005b}},	//   kció, rijp, _испа, hvoj
  { {0x30a40010,0x57cc000b,0x5577004c,0x09cb000b}},	//   _крыв, ारोह, דעלן_, िर्य
  { {0x6e450029,0xddc700bc,0x0bb4008b,0x69d708d8}},	// [ad0] _منظم, anjš, рбую, taxe
  { {0x2ca00020,0x68e30387,0x672202c6,0x64850125}},	//   amid_, ándo, dvoj, hóip
  { {0xb8b40029,0xa3d2000b,0xc7b10015,0x249f001a}},	//   لإنت, वरा_, مّا_, ymum_
  { {0x69ca002e,0x7ce8000a,0xa01b08d9,0x0000006a}},	//   ðfer, _בַשֶ, mlös,
  { {0x64aa0089,0xa01b00f2,0xa3c3000b,0x7c2f0390}},	//   _přin, llös, ्रस_, _incr
  { {0xe29a00a7,0xdb040467,0xf3f904f9,0xcb120008}},	//   _như_, ació, miţi_, _הלך_
  { {0x91fc0048,0xf3f90011,0x58d408da,0x79a4012e}},	//   riāl, liţi_, _вост, _врте
  { {0xdb040467,0x63bb0003,0xc9840054,0x0574012c}},	//   cció, ucun, _ђури, جاهد
  { {0x69d50014,0xf3f90011,0x2c36004c,0x64aa0046}},	//   _keze, niţi_, אָים_, _třin
  { {0x248d08db,0xa3c3021e,0x25ed000b,0xe29a0016}},	//   slem_, ्रह_, _घाटी_, _chư_
  { {0x10a608dc,0xa855000a,0x69d508dd,0xfe7f0144}},	//   лион, ָיָה_, _meze, nuïu_
  { {0xcea900b2,0x69d50111,0xf992000f,0x7f1a01f3}},	//   _זי_, _leze, מרי_, нігу_
  { {0xe28e08de,0xa2e5007a,0xeef60033,0x643a000a}},	//   _га_, _солд, ыянэ, _רעננ
  { {0xa01b00b8,0xe732000a,0x8234002b,0xf3f90045}},	//   flös, צֵר_, _پرها, diţi_
  { {0x2d8c0134,0xc236000a,0xdc9a0004,0xed5a08df}},	//   æde_, _תרצו_, еташ_, хов_
  { {0xfe7f08e0,0x2ca0007c,0x61f10045,0x6d41008c}},	//   duïu_, umid_, şelă, älaa
  { {0x69d508e1,0x70530086,0x2ca00020,0xf3f90045}},	// [ae0] _beze, _دنيا, rmid_, giţi_
  { {0xa01b0123,0x7c2f08e2,0x2ca008e3,0x442f08e4}},	//   slöt, _encr, smid_, _lng_
  { {0x2d8500dc,0xbd460015,0xd910002b,0x69d508e5}},	//   ület_, _إنجي, غیر_, _deze
  { {0xf3f90045,0x97c50015,0x3e6d00bf,0x2814009a}},	//   biţi_, لتهم, ržte_, شوتس
  { {0xdb0402c1,0x4c79000a,0xd7a9002b,0xe0c7002b}},	//   rció, _יָשׁ, ندهٔ_, _گز_
  { {0x442f08e6,0xdd250024,0x9f97000a,0xb9c50015}},	//   _ang_, līša, נדסה_, _نتفه
  { {0x20d1018c,0xdb0408e7,0xdcfe0024,0x7a410046}},	//   jši_, pció, _izpē, _dítě
  { {0xdd250024,0x6d5c003d,0x20d105ca,0x0000006a}},	//   nīša, izra, dši_,
  { {0x15f60115,0x76410030,0x91a90016,0xdc370643}},	//   _مساح, _foly, _đá_, ראפט_
  { {0x76410176,0xda14000b,0xcb13000a,0xd4d60033}},	//   _goly, ड़ित_, צלת_, _бідэ
  { {0x74130086,0x2d8c005c,0x3a370008,0xd48f0758}},	//   _گونا, żdej_, ארים_, _гр_
  { {0xd0e5000b,0x4254002b,0xd3ba005e,0x78a20077}},	//   _किरण_, انگر, _чужі_, nmov
  { {0xe29a0023,0xdd250048,0x2618000b,0x7413012c}},	//   _thư_, dīša, फ़पी_, _دونا
  { {0x98bc0089,0x33930015,0xf3f90045,0x20d100bc}},	//   ávě_, _الهز, viţi_, bši_
  { {0x442f0176,0x3d0f014e,0xfe7f08e0,0x78a200bd}},	//   _yng_, ाबें_, duït_, kmov
  { {0xf3f904f9,0x859b0008,0x78a2016f,0xac1808e8}},	//   tiţi_, תשלו, jmov, лосу_
  { {0x909800b0,0x4c940731,0xa01b08e9,0x9aa50015}},	// [af0] _حضور_, ситс, slös, لمرو
  { {0xf3f904f9,0x7f9c000a,0xa01b0123,0x9f400012}},	//   riţi_, _אבחז, plös, _heiß_
  { {0xf3f904f9,0x98510050,0x64aa0089,0x69d508ea}},	//   siţi_, nąć_, _přil, _veze
  { {0xdddc0011,0xf3f90011,0x69d508eb,0x64420150}},	//   porţ, piţi_, _weze, _nooi
  { {0x7bda009d,0x2d9c006f,0xfe7f0144,0x1707002b}},	//   _בקרו, _úver_, buït_, افتی_
  { {0xb5c20036,0xdebc000a,0x7bcd01f1,0x7aed08ec}},	//   ойшл, עמול, lbau, mrat
  { {0xe3b1003b,0x7a410089,0x9851005c,0x764108ed}},	//   يرة_, _vítě, jąć_, _voly
  { {0x13090191,0x2901002d,0x20d1044c,0xa8a40033}},	//   вний_, mtha_, vši_, _грук
  { {0x644200dd,0x76410007,0xf7940033,0x44230046}},	//   _dooi, _toly, _гатэ, ěj_
  { {0x2480010b,0x7aed08ee,0xdd25003d,0x02020033}},	//   čima_, irat, zīša, озьн
  { {0x27e0002e,0x3d0f000b,0x7aed08ef,0xdddc0085}},	//   ðing_, ाबों_, hrat, jorš
  { {0xa06a0001,0xe53a000a,0x8235002b,0xff2601c5}},	//   тама_, _בתער, ارکا, аммо
  { {0x083a0053,0x8db6005e,0xef1708f0,0x7aed0030}},	//   דערל, исві, амя_, jrat
  { {0x7aed08f1,0x8cb1000b,0xf2d00015,0x7bcd0012}},	//   drat, _आंखो, _رآه_, ebau
  { {0xdd250048,0xabd60001,0x7bcd00b8,0xada608f2}},	//   tīša, ицај, fbau, равл
  { {0x417a0008,0xe588000a,0x672908f3,0x7aed08f4}},	//   _שנקב, רָשָ, _orej, frat
  { {0xfe7f0251,0x2d8508f5,0x290108f6,0xdd25003d}},	// [b00] tuït_, üler_, etha_, rīša
  { {0xdd250024,0x6edb000a,0x9958006f,0x09e608f7}},	//   sīša, _שחיפ, ráža_, рожн
  { {0x2901002f,0xaa7b0089,0x1bea0004,0x672908f8}},	//   gtha_, _svýc, _идни_, _arej
  { {0xafdb0134,0x64aa0089,0x4d7b000a,0x2bba0015}},	//   lkør, _přim, _יריע, _جادة_
  { {0x2bd3005d,0x2901002d,0x78a20057,0x6442042f}},	//   तररा, atha_, rmov, _rooi
  { {0x3916002b,0x672908f9,0x78a208fa,0x24e6009b}},	//   _پورز, _drej, smov, ациг
  { {0x98a60036,0xd5b908fb,0x25080086,0x2901002d}},	//   _виве, усі_, ارتی_, ctha_
  { {0x3205003e,0x91680092,0x9418004a,0x44a30015}},	//   efly_, _lực_, ужит_, يموق
  { {0xa2b3004a,0x72d70033,0xd1ca08fc,0x672908fd}},	//   обыч, адыё_, кунд_, _grej
  { {0xd5d8000a,0xdcfe002a,0x26c00045,0x166308fe}},	//   _תַּש, _wypę, ţios_, _двум
  { {0x91a900a7,0x6729002c,0x6f0d08ff,0xe1660015}},	//   _đã_, _zrej, _spac, شددي
  { {0x90e70015,0x506701e1,0xb4fb004f,0x7aed0900}},	//   جَّل_, ртоа, _ילבר, yrat
  { {0xd2520015,0xfe7f0144,0x0000006a,0x0000006a}},	//   _ونص_, duïr_,   ,
  { {0x69d80084,0x9f4000b8,0x2d840064,0x7ea000b8}},	//   ðvel, _weiß_, ğmen_, höpf
  { {0xdd950010,0x929b000a,0xa3bd000b,0x7ea00012}},	//   савы, _שיות, _आलम_, köpf
  { {0x228b003c,0x31570008,0x7aed0901,0x6e95002b}},	//   søkt_, _כיון_, trat, _گلخا
  { {0x7bcd0048,0x64aa0089,0x907c0008,0xdb990902}},	// [b10] rbau, _přij, _שטחי, увач_
  { {0xe9ab0074,0xab840431,0x62880903,0x7aed0904}},	//   ندان_, цуск, nodo, rrat
  { {0x3d24004a,0x39470045,0x7aed0905,0xd8b80058}},	//   _дьяв, âns_, srat, لدنا_
  { {0x67290906,0x29010541,0x8c19000a,0x7aed0907}},	//   _prej, rtha_, _גוֹי, prat
  { {0xdd280048,0xd00c000a,0xdc360643,0x070900c3}},	//   mēša, דּוֹ, _הארט_, ايتي_
  { {0xdd280048,0x3eda0053,0xb607087a,0x2901002d}},	//   lēša, אַקא, рядк, ptha_
  { {0xd4690848,0x8938005e,0x99140015,0xddd50091}},	//   лике_, _кпрс_, _وبفض, enzū
  { {0x9cd80008,0xdd280024,0xa4840015,0xd5b10016}},	//   בוהה_, nēša, يجين, _mái_
  { {0x6729018c,0x62880176,0x9f440064,0x82350067}},	//   _urej, fodo, ümü_, مردا
  { {0x8b580008,0xe7300015,0xf6530015,0x62880908}},	//   ייחס_, _تصف_, _بئر_, godo
  { {0xf5950115,0xd6980033,0xdd28003d,0x32050909}},	//   _الاج, _лiто, kēša, rfly_
  { {0xa2d2002b,0x2056090a,0x7ae20160,0xb7bd00d4}},	//   _کيوت, стор, šoti, _faţe
  { {0x443f0024,0xdd280024,0x316b005c,0x8779004c}},	//   mju_, dēša, ńcz_, ראָי
  { {0xddc3023e,0x93940015,0x443f090b,0xc332000a}},	//   збри, _بجما, lju_, _מוד_
  { {0x91680092,0xc6920135,0xdd920002,0x6e930015}},	//   _vực_, פאל_, سور_, سلفا
  { {0x443f090c,0x645b0111,0xd5b10092,0x78a3016b}},	//   nju_, nhui, _cái_, ïnvl
  { {0x4e7a0029,0x8c430661,0xcff7004f,0x0000006a}},	// [b20] _محدد_, чете, _הצפה_,
  { {0x443f0020,0x64aa0089,0xda660015,0x7aeb0030}},	//   hju_, _přik, حاري, ágta
  { {0xcdb7000a,0xa96a0015,0xafdb00cb,0x645b0079}},	//   _לפיה_, دمام_, sjøe, khui
  { {0xdd280024,0xb7d70015,0x6288090d,0x0000006a}},	//   cēša, موما_, zodo,
  { {0xeb750010,0x6288003f,0x443f01a3,0xcc8a002b}},	//   _дырэ, yodo, dju_, _لنگه_
  { {0x89f5008f,0x7c24090e,0x443f090f,0x8f9b000f}},	//   _мясц, ldir, eju_, ניסי
  { {0x89db0008,0x62880910,0xa2da000b,0xba57000a}},	//   _תחלי, vodo, पीन्, _פסלו_
  { {0xa3a9005d,0x6288005c,0x63bc0089,0x24800796}},	//   _गृह_, wodo, ěrno, čimo_
  { {0x7c24003f,0x35fa012c,0x62880911,0x55e60912}},	//   idir, _مراد_, todo, _гозб
  { {0xdd280024,0x628800f2,0x69de0913,0xb6bb000a}},	//   zēša, uodo, nape, _עצבי
  { {0x443f00bd,0x212a002d,0x62880914,0x7c240915}},	//   bju_, íbh_, rodo, kdir
  { {0x62880916,0x32020089,0xa4b7000a,0x7537000a}},	//   sodo, řky_, _הלאה_, _לאבד_
  { {0x7c240026,0xdd280024,0x69de0917,0x62880918}},	//   ddir, vēša, kape, podo
  { {0xdce5002c,0xc2c4002b,0x69de0919,0xd0d4006b}},	//   _vzhľ, _هيچي, jape, _докъ
  { {0x64aa02d5,0xdd280024,0x2600000b,0x20040144}},	//   _přih, tēša, _रानी_, òmic_
  { {0xa177000a,0x60c7091a,0x2177000a,0x3cec0030}},	//   _לעוד_, íjme, _לתור_, ádva_
  { {0xdd280048,0xeabf0016,0xda14000b,0xe9d90004}},	// [b30] rēša, _trùm_, ड़ंत_, имач_
  { {0x7b740029,0x443f00bd,0xdd280024,0x7f3c000a}},	//   أطفا, zju_, sēša, _תעזו
  { {0x39150015,0xd5b10016,0xdd28003d,0x984b091b}},	//   تواز, _tái_, pēša, ляда_
  { {0x19a8091c,0x987c0046,0x69de0601,0x6446008c}},	//   ступ_, bíč_, aape, ökil
  { {0xac240033,0x443f091d,0x29d50015,0x7b080046}},	//   _эфэк, vju_, _ويحس, ěstí
  { {0xdb1d01d1,0xd6290724,0x8f9c000a,0x8f8c000a}},	//   _besö, роке_, אידי, נְאֵ
  { {0xf5320083,0x443f091e,0x645b091f,0x2eb5000b}},	//   дејќ, tju_, thui, ंदुत
  { {0x94790001,0x9cd8000a,0x443f0073,0x645e0073}},	//   јску_, זוהה_, uju_, ūpin
  { {0xa5f90001,0x645b0161,0xd7c80015,0x92390920}},	//   _везу_, rhui, _طوله_, ачну_
  { {0x645b0921,0x7bdf0140,0xdd1c013f,0x7c2406d1}},	//   shui, haqu, váže, zdir
  { {0x93270086,0x443f0922,0xf4870923,0x61450924}},	//   _گران, pju_, _лудн, цена
  { {0x78fa00a3,0x6d4e006f,0x1faa0925,0xbbb8000b}},	//   ספרו, vyba, икни_, _अलेक
  { {0x92b700a2,0x9327002b,0x7c240926,0x1600000b}},	//   _احصا, _دران, vdir, ल्कर_
  { {0xdd1c01cb,0xda0b000b,0xa3c3000b,0x7ea00123}},	//   ráže, स्मत_, ्रक_, köpe
  { {0xa3bd0157,0x69de0927,0xa247009a,0x7bdf059d}},	//   _आला_, vape, _نیکل_, faqu
  { {0xdb1d0928,0x69de08cf,0x6d4e0929,0xe93a009a}},	//   _lesõ, wape, ryba, یسات_
  { {0xf412011f,0x69de092a,0x7c24092b,0x4a46071f}},	// [b40] ופן_, tape, rdir, онав
  { {0x224700aa,0x499601ca,0x19960099,0x7c24092c}},	//   _jonk_, ошет, ојер, sdir
  { {0xdd0f01e2,0x8c46092d,0x2f04002e,0x6bd60029}},	//   mışt, _дене, lög_, _وتحر
  { {0xdd0f01e2,0x394700c0,0xc1720008,0xca29000a}},	//   lışt, änsa_, וחב_, כם_
  { {0x69de029e,0xc6f700fd,0xd7f9005e,0xc07b004c}},	//   pape, жніх_, сує_, סטנש
  { {0xf4ea0080,0x25080086,0x8f9b0135,0x7ae4092e}},	//   афий_, مربی_, ביני, msit
  { {0xd90d0074,0x7ae4092e,0x26000065,0xd5af0058}},	//   _میل_, lsit, _राठी_, نفه_
  { {0xfc570053,0x87060015,0x69dc092f,0xdb1d007c}},	//   ַביש_, _وبذل, _here, _eesõ
  { {0x69dc0930,0xdd0f0064,0x2f04001a,0x91fc03e9}},	//   _kere, kışt, jög_, mnāz
  { {0x2451002d,0x7bdf001c,0xdb210030,0x3cf80789}},	//   _lámh_, zaqu, étév, kurv_
  { {0xd257008f,0x69dc0931,0xa9bb0053,0x7ae40125}},	//   іць_, _mere, יזיר, hsit
  { {0xe0cf0086,0x66180932,0xdfd8006b,0x50670033}},	//   کزی_, levk, жър_, ітна
  { {0x2005005c,0x94a90015,0xf487002b,0x7bdf0933}},	//   ęli_, _اطلق_, _بالی, vaqu
  { {0x2489002c,0x479b000a,0x69dc0934,0x7ae40935}},	//   čame_, ייכס, _nere, dsit
  { {0x7648005c,0x16d7000b,0x7bdf0936,0xec6b0937}},	//   _mody, _डब्ब, taqu, арак_
  { {0x69dc04ed,0x415b0008,0xa068009c,0x3ced0796}},	//   _aere, _כדוג, _маја_, čev_
  { {0xc3340008,0x764500f2,0xb606002c,0x7ae40938}},	// [b50] הוּ_, öhyk, _kráľ, gsit
  { {0x76480026,0x69dc0939,0xeaf80015,0x2019093a}},	//   _nody, _cere, ترفت_, lesi_
  { {0x7ae4093b,0x4815093c,0x3983002b,0x2d870003}},	//   asit, змес, ذیرف, _âne_
  { {0x9d1a013a,0xb17b00b2,0x765a093d,0x8cf40033}},	//   _פורט, סטאר, _alty, _ўзяц
  { {0x27e00084,0x4c3a0008,0x69dc093e,0xd5b10016}},	//   ðina_, _התרב, _fere, _lát_
  { {0x2ca90020,0x3aba000a,0xa7380015,0x2aba000a}},	//   lmad_, _למשנ, تثمر_, _למשא
  { {0x67d50139,0x2019093f,0x7bdd0375,0xe4510015}},	//   _нову, kesi_, _kesu, فضة_
  { {0x4d7c0008,0x69c50940,0x7d7c01ac,0x20190941}},	//   ירוע, lche, ינוו, jesi_
  { {0x69dc01e2,0x76d50115,0x7bdd0942,0x2ca9007c}},	//   _yere, _رياض, _mesu, imad_
  { {0xddce0024,0xd5b10016,0x2019008c,0x69c5010c}},	//   ribū, _sáu_, eesi_, nche
  { {0x69c5018b,0x20190943,0x2618000b,0x867a000a}},	//   iche, fesi_, फ़री_, _פרעו
  { {0x7bdd0944,0xd59a0008,0x859a0008,0x2d840064}},	//   _nesu, _הבעל, _השעו, şmek_
  { {0x64aa0089,0x24510089,0x749a004c,0xdd0f0061}},	//   _přiv, _námi_, _פינפ, tışt
  { {0x2f04087d,0xe2980484,0x2ca9007c,0x7524003d}},	//   rög_, _даі_, emad_, āizv
  { {0x61e10945,0x7bdd018b,0x6da30292,0x6abd00b8}},	//   mall, _besu, еира, _ausf
  { {0x0d99008f,0x248d00dd,0x2ca9016f,0x69c50220}},	//   ітры_, noem_, gmad_, eche
  { {0xdd0f0064,0x7bc40946,0x7ae40947,0x2d9e0227}},	// [b60] pışt, rciu, usit, ťte_
  { {0x7bc404ed,0xada6009c,0x61e10948,0x2d8c007c}},	//   sciu, _напл, nall, üdes_
  { {0x764800df,0xda02005d,0x7bdd0026,0x5dbb000a}},	//   _rody, र्गत_, _fesu, _לזיה
  { {0xc8650029,0x717a0053,0x69dc0949,0x7bdd094a}},	//   وطني, זנעס, _were, _gesu
  { {0x387f00c0,0x61e1094b,0xdc8b000a,0x4adb000b}},	//   _djur_, kall, _לְךָ, मीदव
  { {0x6594000d,0x69c5094c,0x61e1094d,0x78bc0607}},	//   малу, cche, jall, _turv
  { {0x20c10023,0x20190064,0x7c2600bd,0x7bdd00e8}},	//   _nói_, yesi_, _kakr, _yesu
  { {0x6d41008c,0xa97b000a,0x04630342,0x297b004f}},	//   älai, _האלכ, етьм, _הטלא
  { {0x6618002c,0x6720016f,0xd5b10092,0x61e1094e}},	//   pevk, _usmj, _sát_, fall
  { {0x201900e8,0x3f850064,0x21540033,0x20c10016}},	//   wesi_, şluk_, дкоў, _bói_
  { {0x69c300bd,0x2019094f,0x92570015,0x20d30033}},	//   žneg, tesi_, ثشير_, ніўс
  { {0x2bb8000b,0x853b000a,0x653b000a,0x34aa0054}},	//   _अलगा, _לגבי, _לעבד, _увео_
  { {0xaa7b0089,0x8fe40010,0x20190950,0x61e10951}},	//   _svým, эцэд, resi_, ball
  { {0x61e10952,0x7bdd0849,0x20190953,0x44260954}},	//   call, _sesu, sesi_, _hao_
  { {0x44260955,0x8d770087,0x4c950956,0x20c10016}},	//   _kao_, ساسا, дивс, _gói_
  { {0x7c2600e8,0x317b000a,0x5c990033,0xfad9006b}},	//   _cakr, _לרומ, ікая_, ждащ_
  { {0x7643005c,0x2d8c00b8,0x69c50957,0xb606006f}},	// [b70] yjny, üder_, tche, _zráž
  { {0x27e00084,0x24510089,0x68e30011,0x44260958}},	//   ðinn_, _vámi_, ândo, _lao_
  { {0x291903c4,0xa01b002e,0x69c502ff,0x91bb000a}},	//   تقاد_, rnöf, rche, צמאי
  { {0x69c50959,0xd75900e6,0x4426095a,0x779907d1}},	//   sche, يلات_, _nao_, окер_
  { {0x69c5002d,0x7995005c,0xba7700a2,0x7ea00123}},	//   pche, _wyzw, _فاست, löpa
  { {0x7c26095b,0x4efc000a,0x8f9c000a,0xbb3a000a}},	//   _zakr, מהדו, ציגי, _ועשי
  { {0x44260023,0x7c3a002d,0x61e1095c,0x55040054}},	//   _bao_, _úcrá, vall, ечња
  { {0x44260023,0x45180036,0xe8940010,0x8d5c000a}},	//   _cao_, яція_, _зась, מכוי
  { {0xe73f001c,0x59e1005d,0xb6060046,0x61e1095d}},	//   _çõ_, _फ़ार, _sráž, tall
  { {0x25a00089,0x81bc003d,0x60e9076f,0x6304009a}},	//   řila_, ldēj, омом_, روپل
  { {0x64aa0089,0x4426095e,0x35550015,0x61e1095f}},	//   _přit, _fao_, _تناز, rall
  { {0xd36e0074,0x81bc003d,0x61e10960,0x387d0034}},	//   اهی_, ndēj, sall, nnwr_
  { {0x81bc0024,0xd12e002b,0x61e10961,0xb066008c}},	//   idēj, همی_, pall, erää
  { {0x44260962,0x644b0026,0xe0d9005e,0x11f5002b}},	//   _zao_, _hogi, _двк_, _آتشگ
  { {0x4426003f,0x90460029,0x7c260963,0xc69200a3}},	//   _yao_, _ينته, _pakr, דאם_
  { {0x27ed0964,0x44260016,0x7188004f,0x26cd0160}},	//   _nden_, _xao_, _מְפַ, _oteo_
  { {0xeb970965,0x644b08f8,0x0a4a0033,0x7c2600cb}},	// [b80] дит_, _mogi, озай_, _vakr
  { {0x248000bd,0x7c26003f,0x39ea005e,0x63bc0046}},	//   čimi_, _wakr, ідео_, ěrni
  { {0xa806008f,0x7c260966,0x387d0034,0xa3c2000b}},	//   дзел, _takr, fnwr_, ्डम_
  { {0xd7ef0015,0xd6d20015,0x649e0079,0xdb0d00bf}},	//   لكم_, نقص_, eëin, škán
  { {0x47360029,0xda660015,0xdd8f002b,0xdb1d02de}},	//   براز, _قاسي, _موی_, _afsæ
  { {0x44260023,0xdd1d0107,0x27ed0967,0xceb3000a}},	//   _sao_, lášt, _eden_, ֣יו_
  { {0x44260968,0x34940969,0x644b096a,0x7af601d0}},	//   _pao_, накр, _bogi, lryt
  { {0x7af6005c,0xfc3f0016,0xd4970033,0x4cbb000a}},	//   oryt, _khía_, мры_, חזקו
  { {0xb2860010,0xd7030063,0x84ea000b,0xd5cf0065}},	//   дынк, _изти, _टिकट_, _स्वज
  { {0x64aa0089,0x6579002d,0x4426003f,0xf6260036}},	//   _přis, ábhá, _wao_, _ідео
  { {0x442600b6,0x09f7013a,0x55bb000a,0x99f7000a}},	//   _tao_, ומים_, _ומבו, וזיה_
  { {0xdbd60209,0x644b096b,0x7af6096c,0x781c000b}},	//   _jääd, _gogi, kryt, _नसोक_
  { {0xfe730002,0xd5b10016,0x9343096d,0x0000006a}},	//   ندس_, _háp_, _инце,
  { {0x7ea000f2,0x539b000a,0x72040015,0x7af6002a}},	//   töpa, _וידו, _أوغم, dryt
  { {0xdd94008f,0x01fb0008,0x387d0026,0x51fb000a}},	//   вары, _ופול, ynwr_, _והוצ
  { {0xaa7b0046,0x629a096e,0x0000006a,0x0000006a}},	//   _zvýh, llto,   ,
  { {0xda67003b,0xf0940008,0x5a350063,0x5b150010}},	// [b90] وائي, _בנק_, ннат, эмат
  { {0x99d40015,0x2600000b,0x7ea00123,0x51b6004f}},	//   نتما, _राषी_, löpn, ֵּ֑ן_
  { {0x7af60091,0xceb4000a,0x2907096f,0x629a0970}},	//   aryt, _ביץ_, îna_, ilto
  { {0xc19b0008,0x7af60971,0x81bc003d,0x63a20972}},	//   חשבי, bryt, udēj, _ozon
  { {0x6d5500dc,0x387d0026,0xa3c2000b,0x2600000b}},	//   lyza, rnwr_, ंशन_, _राशी_
  { {0xcf58000a,0xf5050973,0xe5a50974,0x629a0975}},	//   ובדת_, езко, нили, jlto
  { {0x63a20014,0x98c30024,0xd5b10016,0x04b501b7}},	//   _azon, ēvēt_, _cáp_, нсия
  { {0x27ed00fb,0x64a20063,0x2db8000a,0xc952000a}},	//   _uden_, лаща, ולון_, _גמל_
  { {0xe6100086,0x200c00dc,0x64aa0089,0x662800f2}},	//   _چشم_, ődik_, _přir, öskä
  { {0x64b10048,0x60c701c9,0xdcff0046,0x245101c0}},	//   _jāiz, íjmo, ívěj, _rámu_
  { {0x6f16002a,0xafdb00cb,0x0000006a,0x0000006a}},	//   _spyc, lkøy,   ,
  { {0x88f6000a,0x74280015,0x7e75003d,0x20040072}},	//   עזרו_, _يكلف_, eizp, ümi_
  { {0xa856000a,0x83640015,0x0000006a,0x0000006a}},	//   גירה_, _لدول,   ,
  { {0x42550015,0x60c400bc,0x02450058,0x0000006a}},	//   _سنعر, _čimv, _سَبَ,
  { {0xdd9200e5,0xf652000a,0x725a000a,0x50960054}},	//   اوز_, נצל_, _מכספ, _приђ
  { {0xfc3f0023,0x6aa8000b,0x7c650015,0x80a70065}},	//   _phía_, कग्र, ناقل, _टीपे
  { {0xa089000a,0x539a004f,0x7c930058,0x0000006a}},	// [ba0] _קְצִ, ִיעו, القص,
  { {0xdbd600f2,0xcfb70008,0x9f420107,0x5dda004a}},	//   _sääd, _אלפי_, jaké_, _эфир_
  { {0x8d76006e,0x4ddb000a,0xd7ef00fd,0xdbd601be}},	//   _سادا, _מחיו, лу_, _pääd
  { {0x27e00976,0xe3a70021,0xd7f20015,0x2002088a}},	//   úin_, _مر_, اكش_, ngki_
  { {0x5ac700ce,0x2d9a0977,0x0000006a,0x0000006a}},	//   _плям_, _hype_,   ,
  { {0x8b0b000a,0x96b70054,0xf5260588,0x4d7a004f}},	//   _מִלֵ, нују_, ефин, ּרֵע
  { {0x88c50015,0x63a20030,0x2451001a,0x6a97004f}},	//   _لتقل, _szon, _náms_, _נכלא_
  { {0x7ea0022d,0x25a00089,0xccf3000a,0x69a5000b}},	//   köpo, řilo_, אכה_, _करती
  { {0x08770053,0xa6860010,0xf2060805,0x8c1b000a}},	//   _נעמט_, _злад, няно, לוקי
  { {0xaa160010,0x629a0978,0xe60e0054,0x32540979}},	//   дзiц, ulto, вдe_, твор
  { {0xf506005e,0x64a6052b,0x629a097a,0xe50502be}},	//   _їздо, _зажа, rlto, _لبني
  { {0x20b40010,0x25a10012,0xb97b000a,0x297b000a}},	//   лёўс, ühle_, לניי, לטיא
  { {0x8cd9000b,0x6722002a,0x64a30033,0xf1d10065}},	//   _फौजो, nwoj, _саца, _द्वन
  { {0x61140010,0xfc3f0092,0x6d55005c,0x83b7000a}},	//   _адку, _chín_, tyza, _נפגע_
  { {0xdd950010,0x6ca706eb,0xeca70054,0x321e097b}},	//   тавы, ераж, ејан, mety_
  { {0x6d55005c,0xc19b0008,0x219b000a,0x80a50015}},	//   ryza, _משוי, _מבוא, _جمعن
  { {0x30840015,0x7bf80033,0xcf270015,0x27e60030}},	// [bb0] _حليف, энтр_, _أربي, daon_
  { {0x3f7c000a,0x6722002a,0x9e670015,0x321e097c}},	//   _מאחס, dwoj, _ساخن, nety_
  { {0xa3c2005d,0xfe7f0144,0xdeb6004f,0x4de60065}},	//   ्डा_, duïx_, _שפתח_, _क़तई_
  { {0x9cd6000f,0x80a7000b,0xb7d6002b,0x69d8001a}},	//   _שורה_, _टीमे, پووا_, ðver
  { {0xe7580036,0x38a70020,0x58b80029,0xd6290660}},	//   ниці_, võrd_, رامج_, доле_
  { {0x7c2d0084,0xf6d40086,0xe736006b,0x1af6004f}},	//   ldar, ازند, теш_, _במשל_
  { {0x64aa0089,0xc984097d,0xceb4000a,0xce38000a}},	//   _přip, _бути, ניצ_, תאות_
  { {0x24890582,0xd9e1005d,0x93590004,0x3d19000b}},	//   čamo_, _फ़ुट, дроу_, _पहने_
  { {0x13060080,0x321e065b,0xa6ab00e6,0x58840033}},	//   вный_, fety_, _فائق_, _сыра
  { {0x68e10134,0xcb12000a,0x321e006f,0x7c2d0034}},	//   _ælds, סלי_, gety_, hdar
  { {0x320b005c,0xb1420033,0x3eba02f2,0x1636004f}},	//   ęcy_, анэл, _ript_, _שנער_
  { {0x7c2d0048,0x64550054,0x6446005b,0x0000006a}},	//   jdar, _швеђ, ökit,
  { {0xf8b200b2,0x7c2d097e,0x442d097f,0x443d0079}},	//   ישט_, ddar, mde_, _inw_
  { {0x645b00f2,0x64490980,0xa2f6000a,0x7c2d0981}},	//   lkui, ljei, _ימנה_, edar
  { {0x6722005c,0x0c96004a,0x7c2d0079,0x5cf50033}},	//   zwoj, вшая, fdar, ляту
  { {0x64490982,0x645b0983,0xf19a000a,0x7c2d0984}},	//   njei, nkui, _קשקש, gdar
  { {0xc0530008,0xe9d20015,0x6009000a,0x645b008c}},	// [bc0] _כזה_, لغا_, _נִקְ, ikui
  { {0x442d022d,0x0f570008,0x64490604,0xda790036}},	//   hde_, _סיים_, hjei, няє_
  { {0x27e600b6,0x37e6004a,0x7c2d0985,0xbf9b016e}},	//   taon_, воег, bdar, ngên
  { {0x3860002f,0x78a90493,0x321e037c,0xa96703ae}},	//   óir_, _chev, zety_, њица_
  { {0xe1e70074,0xf11e005d,0xa3c2000b,0x27e60986}},	//   _پس_, _बन्द_, ्डस_, raon_
  { {0xd6270054,0x78a90012,0x91fc003d,0x442d0987}},	//   воље_, _ehev, ehān, ede_
  { {0x442d0161,0x60c30012,0xd5d50033,0xa8060988}},	//   fde_, _nunm, уючы, _извл
  { {0xd6d20029,0x442d0989,0x98a6098a,0x78a90546}},	//   _نقر_, gde_, _рибе, _ghev
  { {0xdc9b0053,0x68e10134,0x799c0026,0x8463006b}},	//   ויקל, _ældr, _hyrw, ръще
  { {0x443d0176,0x386603af,0xe617098b,0x7c2d098c}},	//   _enw_, lhor_, _иду_, zdar
  { {0x9a350053,0xa5d8005d,0x867b000a,0xd166006b}},	//   אָרד_, _न्यौ, _קרבו, тъпи
  { {0xf99301e4,0x3866001c,0x68e3098d,0x3947008c}},	//   ירת_, nhor_, ândi, änsi_
  { {0x24580030,0x69ce001a,0x2d9e0359,0x26c4098e}},	//   _némi_, _ofbe, üten_, _jumo_
  { {0xdce505cc,0xd3570008,0xc7b30008,0x425600d7}},	//   _vyhľ, _בידי_, יבר_, _штет
  { {0xac19098f,0x5db40015,0x7c2d0990,0x7db40015}},	//   нову_, لإفر, tdar, لصفا
  { {0xfbd30074,0x69ce0991,0xdd250024,0x6abc00da}},	//   شتر_, _afbe, gūša, _airf
  { {0xfaf30029,0x7c2d0992,0xe5020065,0xeeab0993}},	// [bd0] ؤثر_, rdar, रूति_, _оток_
  { {0x442d0994,0xa2c3005d,0xf09f0251,0x99980091}},	//   zde_, रदत्, llà_, _norų_
  { {0x9f4e0030,0x442d0995,0xdbd1007c,0x98e40058}},	//   önöm_, yde_, _küüd, لكلو
  { {0x61e80996,0x24860085,0x7c3d0012,0x6abc0034}},	//   hadl, _njom_, _unsr, _eirf
  { {0xdbd10020,0xe72e03ad,0xe7080115,0x442d0997}},	//   _müüd, ще_, نتون_, vde_
  { {0x442d0111,0x6a60002e,0x99d40015,0x7aed0998}},	//   wde_, _höfn, _نتفا, msat
  { {0x799c0026,0xceb4000a,0x6b9d0034,0x64490030}},	//   _gyrw, ביס_, _hysg, tjei
  { {0x29010035,0xdbd10020,0x6a60001a,0x645b008c}},	//   muha_, _nüüd, _jöfn, ukui
  { {0x3e660152,0x60c30064,0x387c0999,0x44240015}},	//   _hôte_, _sunm, èvre_, شريف
  { {0xb7bd04f9,0xd9e1005d,0xfc3f002d,0x645b099a}},	//   _naţi, _फ़ोट, _shíl_, skui
  { {0x61e300fb,0x290102f2,0x41b5004a,0x6281063b}},	//   _venl, nuha_, ысит, rnlo
  { {0x44e10780,0x83350086,0xf7670225,0xbf9b001c}},	//   mų_, _مرتض, ما_, rgên
  { {0x44e10007,0xa3c2021e,0x249f001a,0x6b9d04d1}},	//   lų_, ्डर_, mlum_, _nysg
  { {0x290100b6,0x3f9e0048,0x249f099b,0x7f750010}},	//   kuha_, ātu_, llum_, руюц
  { {0x44e100df,0x10f50010,0xd7ce005d,0x80f50015}},	//   nų_, _сяля, हुँच, _إستض
  { {0x44e10007,0xa3e6000b,0x7aed0012,0x6b9d0034}},	//   ių_, _बड़ा_, fsat, _bysg
  { {0xfc3f099c,0x6b9d0026,0x7fe90002,0x69c3006f}},	// [be0] _dní_, _cysg, _شريف_, ľnen
  { {0x32050041,0x6b9d0176,0x44e100df,0x81bc0024}},	//   ngly_, _dysg, kų_, rdēv
  { {0x44e100df,0x19b90010,0x3e66099d,0x3866099e}},	//   jų_, вуць_, _côte_, thor_
  { {0x44e10007,0xd7ce000b,0x6abc06ad,0x2cfb000a}},	//   dų_, हुंच, _wirf, _אלטא
  { {0xd7f90036,0x81bc0024,0xdd1d002c,0x7aed00dc}},	//   тує_, ldēt, ráťt, csat
  { {0xfe360053,0xfc3f0046,0x2ca0099f,0x249f058a}},	//   ראַך_, _zní_, llid_, elum_
  { {0x44e10007,0x81bc0024,0xa3c2000b,0xb9b5006b}},	//   gų_, ndēt, ्डल_, _встъ
  { {0x249f002e,0x95530029,0x54540661,0x28760892}},	//   glum_, إخوا, рвит, _сыгр
  { {0x18670001,0x41e60484,0x988b000a,0xa87b000a}},	//   _сати_, ліна, _טָמֵ, _נאמר
  { {0x471b0053,0xdbd10020,0x44e10007,0x95c60015}},	//   _אומג, _süüd, bų_, _إياه
  { {0xfa970053,0xdbd10020,0x5a170053,0x2ca0048c}},	//   רדיש_, _püüd, נקטן_, klid_
  { {0xfc3f0092,0xc0ab0002,0x90e70015,0x7095009b}},	//   _phím_, عادل_, دَّل_, рамф
  { {0x543b00b2,0x08770053,0x04930029,0xfebb0029}},	//   _רעדא, רעכט_, _النح, فاست_
  { {0x6a60002e,0x929d002a,0xfc3f005a,0x7e2809a0}},	//   _söfn, tułe, _sní_, ліса_
  { {0xf518000a,0xf09f0144,0x0000006a,0x0000006a}},	//   כֵּל, plà_,   ,
  { {0xe9450086,0x2ca00020,0x6b9d0026,0xd9dd000b}},	//   یرای, glid_, _pysg, यर्ट
  { {0x0ca80080,0x44e10091,0xba75006b,0x4fd8000a}},	// [bf0] утри_, zų_, агащ, _עוזב_
  { {0x2bb80029,0x7aed09a1,0x2ca00158,0x7bcd09a2}},	//   طاقة_, rsat, alid_, scau
  { {0x7aed09a3,0x47d50087,0x6675002b,0xfe9c000a}},	//   ssat, ليار, یدتر, _איזמ
  { {0x2c270191,0x44e10007,0xab950036,0x961d005d}},	//   _сьог, vų_, _вимі, फ़्ट_
  { {0xd5e50036,0x66b5000d,0xd6db00a4,0x2600000b}},	//   ажли, абду, хте_, _राखी_
  { {0x44e100df,0x5694005e,0x24580046,0xcb12000a}},	//   tų_, бачт, _mému_, _ולך_
  { {0x249f002e,0xda48000a,0x3666006b,0x2e3c000a}},	//   tlum_, _עֲשָ, ращо_, תגונ
  { {0x9984003b,0x44e10007,0x60c400bd,0x62860030}},	//   _الفو, rų_, _čimp, ékon
  { {0x44e10007,0x8c1c000a,0xc86409a4,0x2cbc004c}},	//   sų_, תוחי, _утри, ײמזײ
  { {0x249f002e,0xe4e70036,0xaa7b0227,0x22920015}},	//   slum_, _бідн, _zvýr, يليس
  { {0x9a760008,0x249f0700,0x03f50015,0x2ca00034}},	//   שתתף_, plum_, _نكاح, ylid_
  { {0xb4c1014e,0xcea90008,0x32c90092,0x91fc0024}},	//   ंदी_, _חי_, _túy_, ekād
  { {0x0000006a,0x0000006a,0x0000006a,0x0000006a}},	//     ,   ,   ,
  { {0x3ebe0014,0xa2d20021,0x442f09a5,0x8fa300ce}},	//   ött_, _بيوت, _hag_, іаре
  { {0x81bc0024,0xbda50029,0xc27a000a,0xfce607d0}},	//   udēt, محفو, _שרצי, робо
  { {0x442f01d1,0xa01b00f2,0xbc6309a6,0x2fdf001a}},	//   _jag_, nnöl, овск, ðugt_

  { {0x91fc0048,0x6b850029,0xc0a90029,0x59d60002}},	// [c00] bkād, مشكل, _حاول_, لغار
  { {0xda66003b,0x25a00089,0x27e9002e,0x4a4309a7}},	//   جاري, řili_, ðann_, онув
  { {0x2cba0029,0x5dfb000a,0x91f6000a,0x9d4609a8}},	//   _لاحظ_, _בפינ, שמעו_, _тенд
  { {0x442f09a9,0x7c960086,0x97c50029,0xd7f00058}},	//   _nag_, _خشخا, متهم, سكت_
  { {0x7c2403af,0x281300a2,0x45d403de,0xd70702d9}},	//   meir, تونس, болс, инце_
  { {0x7c2409aa,0xb4c1021e,0x9a9d0033,0x8f37000a}},	//   leir, ंदू_, _зусi, יאנו_
  { {0x394700c0,0x442f09ab,0x046609ac,0x3958000a}},	//   änst_, _bag_, итим, _גֻּב
  { {0x7c2403af,0xcdb7000a,0x7791002b,0x2c67007c}},	//   neir, ספקה_, _کیها, _tõde_
  { {0xd5b10023,0x27e0002e,0x7e7c0007,0x57fb000a}},	//   _máy_, ðinu_, kirp, _שלמו
  { {0x7d1e003c,0x80ca021e,0xcb13000a,0xf6290015}},	//   _opps, _संदे, קלת_, _مسمى_
  { {0xba370008,0x3a3704dc,0xd5750036,0xca370008}},	//   בטיח_, ברים_, _луць, בניה_
  { {0xd4090074,0x320a005c,0x442f09ad,0x7c2409ae}},	//   _متهم_, żby_, _gag_, jeir
  { {0x236d005c,0xe2f805d1,0x7c2409af,0x78a209b0}},	//   czej_, _селі_, deir, ilov
  { {0xa2c3014e,0x442f0111,0x831b000a,0xbe8809b1}},	//   रदर्, _zag_, _סווז, ассе_
  { {0x7c240176,0xd0870080,0x6d5c0026,0xb7f8000b}},	//   feir, _выпи, gyra, ुलाम_
  { {0x2458002c,0x2d58034e,0x442409b2,0xc1bb000a}},	//   _tému_, шись_, nem_, _במוש
  { {0x6a60002e,0xdee40054,0xf9c701e3,0x6d5c0061}},	// [c10] _töfl, _доњи, ащен, ayra
  { {0x8f9c000a,0x93b7000a,0x442409b3,0x78a209b4}},	//   _ביחי, שלמו_, hem_, elov
  { {0x391509b5,0x2600000b,0x7c2409b6,0x442409b7}},	//   смер, _राजी_, beir, kem_
  { {0x78a2018c,0x87d40010,0x28f8005e,0x7c24016e}},	//   glov, оўшч, рець_, ceir
  { {0x8c1a0008,0xbc1a000a,0xd7ee0015,0x5c36000a}},	//   _גורי, _גורש, ركو_, _פרשן_
  { {0x6442002f,0x44240234,0x929d002a,0x7ea0008c}},	//   _anoi, eem_, kuła, töpi
  { {0x442f025c,0x96080010,0xbdf8000f,0xd5080015}},	//   _pag_, рэча_, שֶׂה_, لغين_
  { {0xe8940010,0xe3e90086,0x442409b8,0x64b3005d}},	//   _дась, اکان_, gem_, ुदेश
  { {0x83fd0030,0x753a09b9,0x787a004f,0x36d409ba}},	//   lhők, _ertz, _עָלו, _мотр
  { {0x9f4201b2,0x387d0034,0x236d09bb,0x442f09bc}},	//   jaká_, liwr_, rzej_, _wag_
  { {0x236d0050,0x25570089,0xa4d4005e,0x442409bd}},	//   szej_, _dělá_, _дохі, bem_
  { {0x7c24001c,0xd0e6002b,0x442409be,0x387d0034}},	//   xeir, حکوم_, cem_, niwr_
  { {0xe3b00086,0x6d5c09bf,0x69c3006f,0x6d4109c0}},	//   _قره_, wyra, ľnej, ålan
  { {0xda03005d,0x387d0026,0x539a000a,0x42da004c}},	//   _लागत_, hiwr_, _גינו, _עקצע
  { {0x11440029,0x7c2409c1,0x98a70046,0x6da609c2}},	//   _وَهُ, teir, íně_, сива
  { {0xeb9a09c3,0x3fe609c4,0x7c24059d,0xab2a09c5}},	//   гиб_, _ужив, ueir, лоба_
  { {0x64aa02d5,0x387d0176,0x7c2409c6,0xf093000a}},	// [c20] _přiz, diwr_, reir, _מנה_
  { {0x0f370008,0x7c2409c7,0x442409c8,0x2fd7002b}},	//   _פריט_, seir, zem_, _پوید_
  { {0x1e570008,0x97c60029,0x7d1e09c9,0x387d0026}},	//   _השיר_, مقاو, _upps, fiwr_
  { {0x18a60457,0x673b04a5,0x387d0034,0x088a0033}},	//   щаем, _bruj, giwr_, ыбей_
  { {0x78a206db,0x442409ca,0x4c830033,0x18670054}},	//   rlov, vem_, _хляв, љачи_
  { {0x44240050,0x13e0005d,0x2816002b,0x78a209cb}},	//   wem_, नर्भ, _گورس, slov
  { {0x2609005d,0x78a209cc,0xa4f8002b,0x3984002b}},	//   _सारी_, plov, شکار_, _بیاف
  { {0xb8de005d,0x9cd70008,0x281600a2,0x387d0034}},	//   ुआ_, זוקה_, _دورس, ciwr_
  { {0xe737005f,0xc1ea0036,0xafdb003c,0x2bda000b}},	//   _лет_, льне_, kjør, युया
  { {0x3d19005d,0x6f0609cd,0x442409ce,0xdb1d0030}},	//   _पहले_, dukc, sem_, özép
  { {0x3a370008,0x1a9b0053,0xca37000a,0x7d1b002a}},	//   זרים_, רייע, זניה_, łusz
  { {0xc9530008,0x9f4b0152,0x20050091,0xa3d7000b}},	//   למת_, lacé_, ėlio_, ़ुद_
  { {0x80ca005d,0xa01b00dc,0x321a002b,0x0000006a}},	//   _संवे, lnök, _ميشد_,
  { {0x63a2025c,0xafdb003c,0x539b000a,0x3179002b}},	//   _iyon, gjør, _עיגו, اجیک_
  { {0x127b0053,0xdd3a0011,0x865b0135,0x0217000a}},	//   _גאגע, văţa, נדלי, _החום_
  { {0x69d800dc,0x63a209cf,0x4fc70937,0x629a09d0}},	//   űvel, _kyon, _уска, loto
  { {0x5ea50029,0x62880410,0xd1380007,0x6d480123}},	// [c30] _ومعل, ondo, lvą_, ädar
  { {0xe9ab0018,0x1ed80015,0x629a09d1,0x0000006a}},	//   هدان_, _ابيب_, noto,
  { {0x99d40015,0xdd3a0045,0x9cb500c3,0x63a209d2}},	//   ستلا, răţa, _ومخت, _lyon
  { {0xbd880086,0xf7700086,0x2616000b,0x27e90077}},	//   _چنین_, کام_, प्सी_, úan_
  { {0x387d0026,0x6d41001a,0x9f4b0003,0x65c509d3}},	//   riwr_, ælaf, facé_, обла
  { {0x34b3005d,0xddc50089,0xa565002b,0xa684005e}},	//   ुद्द, _pohř, يگان, плід
  { {0x69c7003c,0x0e5c000a,0x629a09d4,0x63a20003}},	//   _igje, רדוב, doto, _ayon
  { {0xe459030e,0xdd1d006f,0x7d7c000a,0x673b09d5}},	//   ржи_, kážt, טרוג, _truj
  { {0x60ca00b8,0x27ef001a,0x61ea0012,0x87e4006b}},	//   _aufm, magn_, _befl, _хюсе
  { {0x629a09d6,0x6e21007c,0x9958006f,0xc2c80058}},	//   goto, õlbl, láša_, حبيل_
  { {0xdddc0007,0x602609d7,0xf953005e,0x63a209d8}},	//   sirū, одна, жнiй_, _eyon
  { {0x50460124,0xe45f0020,0x316b005c,0x9958006f}},	//   цемб, ööd_, ącz_, náša_
  { {0xe1ee09d9,0x8e5a0054,0x623509da,0x629a09db}},	//   _ог_, ајву_, _меду, boto
  { {0x61ea0028,0x02450015,0x68f5013f,0x6f0609dc}},	//   _gefl, _ذَبَ, _ovzd, rukc
  { {0x8c7a0063,0x2c67007c,0xdd9200c3,0xdb1d001a}},	//   ащат_, _sõda_, ذور_, _ofsó
  { {0x69d50079,0x6097002b,0x8c4309dd,0x90730058}},	//   _afze, _ونوس_, месе, _يهوش
  { {0xe9da0015,0xda660015,0x4bd90033,0x20e70030}},	// [c40] لذات_, ياطي, сься_, lői_
  { {0x89f50010,0xcf93004f,0x6dfa00af,0x7d150052}},	//   зяцц, _קטז_, _тхис_, éfsá
  { {0x38cb0086,0xc92a0063,0x08fa0015,0xacf6002b}},	//   لانی_, роеж_, شراب_, _بسخت
  { {0x186a000d,0x69da005d,0x629a09de,0x69c70030}},	//   јади_, _प्री, zoto, _egje
  { {0x41c9005d,0x629a003f,0x501b000a,0xf1c9000b}},	//   रशास, yoto, שונו, रशान
  { {0x47330191,0xd1380007,0x8f9b0008,0x7f3b000a}},	//   ьніс, yvą_, סיסי, יענו
  { {0x629a09df,0x61ea09e0,0x27ef02f2,0xafdb00cb}},	//   voto, _refl, bagn_, kjøp
  { {0x60c4007c,0xa01b0030,0x20e70030,0xb426002b}},	//   _niim, rnök, dői_, زعبو
  { {0x629a09e1,0xf3f5009a,0x2451005a,0x0000006a}},	//   toto, ستيک, _jámy_,
  { {0xfb1b0008,0x5666002b,0x629a09e2,0x7ae90061}},	//   סוימ, _بدرف, uoto, _çete
  { {0x61ea002e,0x22570015,0x6e21007c,0x20d30033}},	//   _vefl, تجيب_, õlbm, міўс
  { {0x7ea00123,0xe4e90067,0x629a09e3,0x74140369}},	//   köps, _طعمه_, soto, _روتا
  { {0xdfa70029,0xa01b008c,0x628f0003,0x60c40509}},	//   تحدي, nnöi, écoc, _diim
  { {0xb2370015,0x6dc70058,0x0000006a,0x0000006a}},	//   _وكنا_, تزحل,   ,
  { {0xeda4005e,0x14d8000a,0xa6e90016,0x41db004f}},	//   дшто, מַּמ, _giươ, _דחוס
  { {0x4bdb002b,0x3e540061,0xb4fb0643,0x7f9502a3}},	//   شبرد_, _aştı_, יפלי, _найх
  { {0x27ef0123,0x0000006a,0x0000006a,0x0000006a}},	// [c50] vagn_,   ,   ,
  { {0x0b880036,0x3cfe01a3,0x1995006b,0xfaa700fd}},	//   істи_, štva_, пазя, ішан
  { {0xd9990015,0xfeb80021,0x320c002a,0xd6220033}},	//   حنات_, _بايت_, igdy_, _мiка
  { {0x88c80036,0x4878005e,0x0000006a,0x0000006a}},	//   ілів_, осія_,   ,
  { {0x87270029,0x8bd6000a,0x20e70030,0xe73904b9}},	//   تعام, _מורו_, zői_, сел_
  { {0x9bba000a,0xd62909c2,0x27ef0723,0x8f9c000a}},	//   _לצרפ, соке_, sagn_, בידי
  { {0xb066008c,0x673e003d,0xc9840054,0xa5f600af}},	//   nsää, āpja, _жути, чеју_
  { {0xb06600f2,0x17f80029,0xaaaf000b,0x929d002a}},	//   isää, _ورقة_, _जीतक, tuło
  { {0x66f40001,0xa3b5000b,0xc6a70099,0x60c409e4}},	//   _опту, छें_, _држи, _riim
  { {0xcb120008,0x20e700dc,0xe6640080,0xc7c40036}},	//   עלי_, tői_, _отхо, _істи
  { {0x60c40020,0x27ed00da,0x614509e5,0x2d840061}},	//   _piim, _keen_, чена, şmez_
  { {0xc4d20008,0x26c509e6,0x75d3002b,0xdb060030}},	//   _נגד_, _hilo_, _ريچا, _szkí
  { {0x60c409e7,0x92a4005c,0x25a50034,0x27ed042f}},	//   _viim, ółcz, _hyll_, _meen_
  { {0xd3560008,0xed5a09e8,0xdbf6000b,0xc332000a}},	//   _מיני_, бог_, ेल्ड_, _רוג_
  { {0x60c4022d,0x69d80030,0x628109e9,0x26c509ea}},	//   _tiim, űvek, milo, _milo_
  { {0x628109eb,0x27ed0079,0x6459002a,0xada30033}},	//   lilo, _neen_, _jowi, хасл
  { {0xb066007c,0x2d850003,0x645909ec,0x628100d4}},	// [c60] asää, ûler_, _mowi, oilo
  { {0x628104f9,0x26c509ed,0xcf250058,0xc9b6011e}},	//   nilo, _nilo_, _آريي, псењ
  { {0x27ed03c2,0x2f160134,0x3e5b000a,0x0e5b00a3}},	//   _been_, læg_, _הדיס, _הדיב
  { {0xa8000089,0x6459051e,0x9cd7000a,0x628109ee}},	//   příč_, _nowi, _מוטה_, hilo
  { {0x62810084,0x26c5060b,0x163409ef,0xd7ef0015}},	//   kilo, _bilo_, деля, اكه_
  { {0x6b8909f0,0x98ac0064,0xdef7000a,0x8f1b000a}},	//   _þega, ılır_, למנט_, מונת
  { {0x3494008f,0x628100bd,0x15170029,0x645909f1}},	//   макр, dilo, كزية_, _bowi
  { {0x27ed09f2,0xc9550010,0xc917000a,0x78fb000a}},	//   _geen_, _ўтры, _מחלת_, _לפלו
  { {0x6459005c,0x87f90010,0xa6ca0029,0x628109f3}},	//   _dowi, _фэст_, _طوال_, filo
  { {0x271e0024,0x25a50971,0xa3dc000b,0x628109f4}},	//   rānā_, _fyll_, _त्र_, gilo
  { {0x7648005c,0xc5690015,0xecbe000b,0xe4d70058}},	//   _indy, _وحمل_, ्दाफ, _فولت_
  { {0xa3e6014e,0x7af6022d,0xdfd8006b,0x94d30015}},	//   _बजट_, ksyt, зър_, _أينش
  { {0x6a600084,0x5334017a,0x6f640015,0xe455002b}},	//   _höfu, _целт, ّهُم, _تفنگ
  { {0x64470048,0x62810011,0x3ec40010,0x7af609f5}},	//   ējie, cilo, ессб, dsyt
  { {0x386600dc,0xc534000a,0xadbd0033,0x621b000a}},	//   kkor_, וָּה_, равi, _הווק
  { {0xea000092,0x9f4b0089,0x765a09f6,0x4fc7055f}},	//   _đạn_, lací_, _loty, _эска
  { {0xb06600f2,0xfbd00029,0x24b7000a,0x2ef50033}},	// [c70] ssää, اتف_, להלן_, _ўзор
  { {0x27ed003e,0xa01b00dc,0x9f4b0089,0xd9f90033}},	//   _seen_, gnöv, nací_, інец_
  { {0x80a40086,0x32d20092,0xacb50054,0x88c70067}},	//   _زمین, _lây_, _обољ, ستال
  { {0x2c090086,0x91bb000a,0x7ea0001a,0x628109f7}},	//   _بعدی_, זמבי, löpp, zilo
  { {0xcc560008,0x9f4b0089,0x765a0026,0x4c3a000a}},	//   _חברי_, kací_, _boty, _ותרב
  { {0x645909f8,0xdd1c0089,0x627901b2,0xc794002b}},	//   _sowi, láše, lňov, رشنب
  { {0x64590050,0x765a09f9,0x9f4b01b2,0x27ed014c}},	//   _powi, _doty, dací_, _teen_
  { {0x32d20023,0x386600c0,0xf6770086,0xdd1c0089}},	//   _bây_, ckor_, _کارخ, náše
  { {0x32d20092,0x2ca90026,0x27f80046,0x69ca0061}},	//   _cây_, ilad_, řený_, şleş
  { {0x32d20092,0x83640015,0x765a002a,0x0bb8000a}},	//   _dây_, عديل, _goty, הלחם_
  { {0x628104f9,0xd567054f,0x645900da,0x2ca909fa}},	//   rilo, _этап, _towi, klad_
  { {0xd59a0008,0xf76700e6,0x627901c9,0x628109fb}},	//   _ובעל, نا_, jňov, silo
  { {0x32d20023,0x6281052a,0x2ca909fc,0xc7f6000a}},	//   _gây_, pilo, dlad_, וזרת_
  { {0x7cd500df,0x248d00bd,0xe1f1002b,0x216909fd}},	//   _sąra, lnem_, _شست_, _мили_
  { {0x6da309fe,0x3f9e002a,0x9db90033,0x2d950510}},	//   вира, łtu_, зыту_, ертс
  { {0x248d09ff,0x40950010,0x3cfe0a00,0x4e1f000b}},	//   nnem_, _прыт, štvo_, म्बई_
  { {0x32d20023,0xa5a4005d,0x248d00b8,0x6097002b}},	// [c80] _xây_, _चुनौ, inem_, _تنيس_
  { {0x2bde005d,0x7af6005c,0x77f8005d,0x2ca904f6}},	//   _फ्रा, rsyt, ुल्क_, alad_
  { {0x386d0085,0x729a004c,0x9f42006f,0xda650015}},	//   _bler_, קסעס, jakú_, راكي
  { {0x31560053,0x9f4b0089,0x20d30092,0xe7aa03a9}},	//   ויען_, zací_, _mãi_, овел_
  { {0x20d30092,0xfc3f002d,0x248d0a01,0x38660a02}},	//   _lãi_, _thír_, dnem_, rkor_
  { {0xa3c1005d,0x8f9b000a,0x38660a03,0x96330033}},	//   ंधन_, חיני, skor_, кніц
  { {0x386d01d1,0xceb300b2,0x9f4b0156,0xa3d40010}},	//   _fler_, דיג_, vací_, нойч
  { {0x628f0003,0x833401b7,0x2ca00a04,0xa97b000a}},	//   écon, ених, noid_, _ואלכ
  { {0x41c9005d,0xd6260029,0xfa6a000a,0x9f4b0247}},	//   रशंस, _يعطي, ַכֹּ, tací_
  { {0x20d30092,0x32d20092,0x4154034e,0x2ca004f6}},	//   _bãi_, _vây_, евос, hoid_
  { {0x9f4b0089,0x20d30092,0x248d0a05,0x1bee0065}},	//   rací_, _cãi_, bnem_, जराल_
  { {0x32d20023,0x246c005c,0xc1780091,0xb4ca000b}},	//   _tây_, yśmy_, lbėk_, ऊदी_
  { {0x80ca005d,0x93140015,0x10740033,0xcfab002b}},	//   _संके, _أوتش, тляю, تادم_
  { {0x8d6b000d,0x2ca90026,0x20050064,0xf1940342}},	//   ојба_, wlad_, şli_, _пиль
  { {0x44fa0024,0x329b000a,0x62790069,0x27e60546}},	//   nī_, _ובגד, tňov, kbon_
  { {0xbae50029,0xf537000a,0xac740021,0x4fc7004a}},	//   فكري, ונלי_, ناقش, _оспа
  { {0x7b180080,0x2bbb0029,0x2d9e0012,0x62790107}},	// [c90] мотр_, زارة_, üter_, rňov
  { {0x248d0a06,0x7055002b,0x6279013f,0xce6b096d}},	//   znem_, _آنکا, sňov, _фрид_
  { {0x321e00da,0xdb060046,0x627901c0,0x248d0a07}},	//   ifty_, _vzká, pňov, ynem_
  { {0xf8b1002b,0x59df000b,0x3a380326,0x2ca001f9}},	//   اکس_, _प्रर, _earp_, coid_
  { {0xcc760008,0x290c0134,0x248d00bd,0x65630026}},	//   _נעשה_, _ådan_, vnem_, wynh
  { {0x8cb9014e,0xb0cf005d,0x66d2002b,0x4535006b}},	//   ्दको, _संलग, ديوئ, ехит
  { {0xe5a20036,0x248d00bd,0xa01b008c,0x27e6059f}},	//   лиши, tnem_, nnös, bbon_
  { {0x20d30092,0x387f0509,0x27e60016,0x7c2d0a08}},	//   _rãi_, _umur_, cbon_, near
  { {0x248d0a09,0xf6d7002b,0x0478002b,0x20d30016}},	//   rnem_, _آزرد, بليک_, _sãi_
  { {0x248d00bd,0x26df003f,0x7c2d0a0a,0xd567011e}},	//   snem_, _ituo_, hear, _отеп
  { {0x00860a0b,0xcf89000a,0x248d0a0c,0x1c0f0065}},	//   елно, _פט_, pnem_, िलाल_
  { {0xe53a000a,0x853a000a,0xcea905bd,0x6908000a}},	//   _מתער, _מגעי, _הי_, וּשְ
  { {0xf8b20053,0x2ca000da,0x442d0a0d,0x644b0a0e}},	//   טשט_, void_, mee_, _ingi
  { {0x442d0a0f,0x8235002b,0x877a000a,0xed5a0a10}},	//   lee_, _سرتا, לארי, пог_
  { {0xfcb60080,0x7c2d002d,0x6fa0000b,0x22580015}},	//   ещаю, fear, _गुरू, _تجنب_
  { {0x7c2d0a11,0x442d0a12,0xdca604bb,0xdca30a13}},	//   gear, nee_, хаби, гаси
  { {0xac07008f,0x2ca00a14,0xaa460a15,0xab270a16}},	// [ca0] энта_, roid_, неал, нота_
  { {0x27ff00d9,0x9abe0033,0x7c2d0034,0x442d0a17}},	//   _adun_, пiса_, aear, hee_
  { {0x442d0a18,0x49ba0015,0xa8060004,0x58060015}},	//   kee_, سائد_, езел, فواك
  { {0x7c2d0a19,0x6e2e00dc,0xd7ef0015,0x7d0e02f2}},	//   cear, lebb, مكم_, mubs
  { {0x3a3800df,0x27e60a1a,0xf093000a,0xda660015}},	//   _tarp_, rbon_, ננד_, _كاسي
  { {0xe45f00f2,0x644b02cd,0x200001d7,0x7ae40a1b}},	//   öön_, _angi, _ldii_, mpit
  { {0x8934000a,0xa5660015,0x2b400a1c,0x7ae40a1d}},	//   _בָּא_, عدتن, lvic_, lpit
  { {0x7ae4000c,0x44fa0024,0x442d0a1e,0x9417006b}},	//   opit, rī_, gee_, ежът_
  { {0x7ae400f2,0x44fa003d,0xd3d70015,0x136a0a1f}},	//   npit, sī_, ربيا_, яшки_
  { {0x75d60029,0xda10005d,0x6b7b01ac,0x644b0a20}},	//   _أيضا, ालित_, פרינ, _engi
  { {0x018a0146,0xd48f0a21,0x6d5a008c,0x91b801b0}},	//   ящий_, _бр_, ätal, ьгот_
  { {0xf9930008,0x7f440003,0x442d0a22,0x0000006a}},	//   טרת_, _briq, cee_,
  { {0x69dc0467,0x387b0053,0x82f70015,0x2617000b}},	//   _ofre, לטטױ, _كروز_, _नामी_
  { {0x6e2e00dc,0xd1300015,0xc7b3000a,0x9f4b0144}},	//   gebb, _نمت_, טבר_, racà_
  { {0xceeb0086,0xdd940033,0xdd980a23,0x3ced0085}},	//   _کربن_, гары, ешт_, ćevo_
  { {0x45b7000a,0x7f850015,0x6aa9000b,0x69a4000b}},	//   תפלל_, _للعن, कत्र, _कड़ी
  { {0x9f53005c,0xddc5002c,0x19eb0015,0x5f950a24}},	// [cb0] ędów_, _dlhš, كراً_, _шиит
  { {0x99d40015,0x7c2d0a25,0x1dd5000b,0xd5b8003d}},	//   هتما, sear, _दलित, _abām_
  { {0x7c2d0041,0xa8cb0015,0x6f1d0012,0x6e21007c}},	//   pear, سباق_, ltsc, õlbu
  { {0xdddc0007,0xddeb002b,0x76580046,0x6f1d0651}},	//   mirš, _برکه_, ejvy, otsc
  { {0x442d0a26,0x69dc0034,0x7528003d,0xe72e005e}},	//   vee_, _ffre, _apdz, ше_
  { {0x6d4a002f,0xad8b000a,0xfd8b000a,0x442d0a27}},	//   _áfac, ּנֵ֥, ּטֵּ, wee_
  { {0xdd030024,0x91810092,0x27e9001a,0x6f1d0028}},	//   ērķa, iệc_, ðans_, htsc
  { {0x6e2e0030,0xa3dc000b,0x20ee0046,0x0445012f}},	//   zebb, तुल_, dři_, теин
  { {0x36d50191,0x442d003e,0x2ba7005d,0x92f60029}},	//   _розр, ree_, _कुमा, نفيذ_
  { {0xb1450036,0x6f0f0a28,0x93240015,0x6f1d0012}},	//   внол, ducc, ارين, dtsc
  { {0x8ccd005d,0xd00a0a29,0xd24e002b,0xafe6005e}},	//   _दंगो, мене_, غچه_, конл
  { {0x59c3000b,0x6f1d0a2a,0xe588000a,0xd00f0058}},	//   वेयर, ftsc, _אָנָ, يلٍ_
  { {0x547a0008,0xa856000a,0x04160067,0x3e740123}},	//   _קטנו, דירה_, _شيوع_, _läte_
  { {0x33760008,0xdee30a2b,0xe72e00af,0x0000006a}},	//   _בתנך_, рори, сеy_,
  { {0x6e2e02d7,0xada60a2c,0x6f1d0111,0x2616000b}},	//   rebb, тавл, atsc, प्टी_
  { {0x6e2e00dc,0x2c7502df,0x6acd000b,0x69dc0a2d}},	//   sebb, _nådd_, ़दूर, _sfre
  { {0x6d45018b,0x6b6301d9,0x7d1c00bd,0x7ae40a2e}},	// [cc0] _erha, акта, strs, upit
  { {0x5db60029,0xeef7000a,0x0ae90015,0x09e60342}},	//   _لإجر, _שמיר_, عرقي_, тожн
  { {0xbca60015,0x1bea004a,0x7ae40a2f,0xb05b014b}},	//   _لمدي, _одни_, spit, smäe
  { {0xe45f007c,0xfd97000a,0xe3a7006e,0xe7860302}},	//   ööl_, _ידיך_, _نر_, куло
  { {0x2f8d00f3,0x78a2007c,0x6283006f,0xb05b0012}},	//   ּרוּ, roov, _omno, lmäc
  { {0x20ee0089,0xa9060029,0x78a2007c,0x68fc0a30}},	//   yři_, _لبرن, soov, _tvrd
  { {0x91fc0024,0x6e230064,0xc5130015,0x2a670030}},	//   skāk, _önbe, لبيت, önbe_
  { {0x39470134,0x63ab079b,0x0463004a,0xa937004f}},	//   ænse_, _bygn, итым, _בטלה_
  { {0xd4330029,0x9c0b0008,0xe61a059c,0x660d0030}},	//   شعيب, וִיִ, _ода_, ánké
  { {0x8556002b,0x20ee0046,0x63ab0a02,0x32540a31}},	//   _لیتر_, tři_, _dygn, увор
  { {0x60f8008f,0xb5050086,0x09f70008,0xe5050015}},	//   эння_, _مظنو, כמים_, _مبني
  { {0x64a30010,0xdddc0007,0x30a40063,0xc57b000a}},	//   _каха, virš, иряв, _קראת
  { {0xd36f00e6,0x6f1d034d,0x8143002b,0xbf340a32}},	//   _وهم_, utsc, هپیم, анящ
  { {0x2c7500fb,0x6f1d04ec,0x6f0f0a33,0x13c7000a}},	//   _måde_, rtsc, rucc, _בּוֹ_
  { {0xeca7000d,0x6f0f0a34,0x62880a35,0x2258001a}},	//   вјан, succ, mido, örku_
  { {0x853b000a,0x62880a36,0xdd0d002a,0x20050091}},	//   וגלי, lido, _półt, ėlis_
  { {0x09bd005d,0xfe6e0086,0xcaf40015,0x0ff80015}},	// [cd0] ्ख्य, زگی_, لسلب, _شعيب_
  { {0xadbd008f,0x7a570029,0x160e000b,0x62880a37}},	//   _напi, خضرا, _सागर_, nido
  { {0x49a400d7,0x60cd0a38,0xb8d40015,0x67290a39}},	//   ајца, _kiam, لتنش, _spej
  { {0xd5e80092,0x2458002c,0x8c19000a,0x2c750a3a}},	//   _đón, _témy_, _אוֹי, _både_
  { {0xef1f0064,0xf77000e6,0xb8fa000b,0x97250015}},	//   ntü_, ياه_, _डू_, افتو
  { {0x98b30064,0x7c3d0213,0x9f420107,0xc66b004a}},	//   ıdır_, _hasr, jaký_, ьшее_
  { {0x63ab005c,0x6ed5000b,0x95c50015,0x8578006b}},	//   _sygn, _यूसु, ديثه, ксът_
  { {0x62880024,0xef1f0061,0x04b502ed,0x60cd0a3b}},	//   eido, ktü_, ысля, _niam
  { {0x7c3d0064,0x58840033,0x8235002b,0x99830091}},	//   _masr, _тыра, هردا, _tajų_
  { {0x7c3d0125,0x60cd007c,0xe3b601b0,0x78a20a3c}},	//   _lasr, _aiam, ыбы_, čove
  { {0x64150029,0xd9190008,0x65940004,0x1a9c004c}},	//   _مواط, עוֹל, _кафу, ויזע
  { {0x82d9006b,0x7c3d0a3d,0x20560a3e,0xdee60a3f}},	//   _зддс_, _nasr, утор, ломи
  { {0x443f002e,0x62880a40,0xb4c1000b,0x60cd0a41}},	//   mdu_, bido, ूदी_, _diam
  { {0x443f0a42,0xc332000a,0xe3b0002b,0x62880a43}},	//   ldu_, _לוד_, _برم_, cido
  { {0xe814005d,0xc5f2000a,0x60cd02b9,0x829a004c}},	//   _डाला_, מדם_, _fiam, _אױסק
  { {0xb05b0012,0x645b0a44,0x60cd0a45,0x443d0a46}},	//   rmäc, njui, _giam, _jaw_
  { {0x4bd90a47,0x8c430063,0x3fe30010,0x443d0a48}},	// [ce0] ться_, щете, _ужыв, _maw_
  { {0x443d0495,0xfaaa002b,0x443f008c,0xda660040}},	//   _law_, رهاي_, hdu_, داري
  { {0x2bc5005d,0xb05b008c,0x63ae002a,0xfbc9000a}},	//   लेबा, lmäa, ębni, פת_
  { {0x38600084,0x26cc0a49,0xfc320029,0x78bb001c}},	//   ðir_, _sido_, _احد_, _chuv
  { {0x4bfb0008,0x443f06ce,0x57f3005e,0x38cb002b}},	//   _אלכס, ddu_, спіт, رامی_
  { {0x0f37013a,0x569401ca,0x443f0a4a,0x75d3009a}},	//   טרנט_, јакт, edu_, ميها
  { {0x86750033,0x443d0542,0xb05b008c,0x62880a4b}},	//   шыцц, _baw_, hmäa, vido
  { {0xdd0400df,0xccf3000a,0xb993002b,0x6288002a}},	//   ūrėt, זכה_, _الفب, wido
  { {0x60cd002d,0xb27400d0,0x443d0a4c,0x8463006b}},	//   _riam, илиш, _daw_, съще
  { {0x645b00f2,0x6e3e0a4d,0x443f0a4e,0x60cd0a4f}},	//   ajui, _napb, adu_, _siam
  { {0xa0550036,0x75d30087,0xb4260067,0xda7b004c}},	//   авні, _ايما, _معشو, גניר
  { {0xf5370008,0xdfd10029,0xc3d60015,0x62880a50}},	//   _תנאי_, تيح_, _إغاث, sido
  { {0x62880a51,0x0000006a,0x0000006a,0x0000006a}},	//   pido,   ,   ,
  { {0x6440002e,0xd5a60021,0xd2500015,0xef1f007f}},	//   ldmi, قف_, _ذنب_, rtü_
  { {0xdcbb0063,0xef1f0064,0x64400a52,0x61fa0a53}},	//   еща_, stü_, odmi, matl
  { {0x64400a54,0xaed5000d,0x61fa0a55,0xdc0f0065}},	//   ndmi, _коиш, latl, िलेड_
  { {0x6d4a0084,0x6e950036,0x50b80225,0x3b550001}},	// [cf0] _áfan, _випу, _حدود_, шкар
  { {0xdb2400dc,0x28d9000b,0x443f0a56,0x25a00046}},	//   ásán, _बंदि, zdu_, řily_
  { {0x3947002e,0xd7d50001,0x628f06ba,0x443f0a57}},	//   íns_, ажењ, écoi, ydu_
  { {0xfe7f0034,0x61fa0a58,0xc1780091,0x8d5a004f}},	//   opïo_, hatl, lbės_, _סכרי
  { {0x07a50292,0x443f06db,0xe7390a59,0xabfa000a}},	//   јалн, vdu_, тел_, _שהשר
  { {0x443d0a5a,0xb95b0015,0x6a72001a,0xa5090a5b}},	//   _saw_, _كجزء_, _hæfn, века_
  { {0x3e74007c,0xf993002b,0x61fa0a5c,0x443d0a5d}},	//   _jäta_, _طبس_, datl, _paw_
  { {0x443f0a5e,0x9cd8000a,0xb05b008c,0x3e740a5f}},	//   udu_, נוחה_, ymäa, _mäta_
  { {0xa3a8005d,0xe1f10086,0x443f0a60,0x43750a61}},	//   _खुद_, يسد_, rdu_, руйт
  { {0xc6a703f1,0x2ef20026,0xd3280015,0xfb1c000a}},	//   _срби, _rwyf_, اثيم_, תוזמ
  { {0x7c240084,0x6e3e00e8,0x443d0026,0x850400e6}},	//   yfir, _rapb, _taw_, _هولن
  { {0x44f30045,0x3f6a0a62,0x61fa0a63,0x10a600ce}},	//   mţ_, вимо_, aatl, римн
  { {0x8234002b,0x61fa0061,0x0000006a,0x0000006a}},	//   _گرنا, batl,   ,
  { {0x91e50001,0xe37a000a,0x7f750033,0x6145055f}},	//   _токе, _ברנר, суюц, _века
  { {0x44f30011,0xa3dc005d,0xabf6024f,0xb05b0a64}},	//   nţ_, तुक_, ичащ, mmän
  { {0x9ce50010,0x3e7b0089,0xb05b0a65,0xab2a0001}},	//   сцёл, eště_, lmän, коба_
  { {0xfc3f001c,0xb05b0123,0x6388003d,0x0b430a66}},	// [d00] _daí_, omän, cīnī, онтн
  { {0x4efb000a,0x7c240a67,0xab270a68,0x7bdf0a69}},	//   _שהיו, sfir, рофа_, acqu
  { {0xd00f0074,0x19b9008f,0x25f90065,0x673b0a6a}},	//   _علی_, гуць_, _ईज़ी_, _asuj
  { {0xc18c0053,0x07ba0015,0x61fa0a6b,0xa01b008c}},	//   עטאָ, نهضة_, zatl, tiöi
  { {0xbb430036,0x91680092,0x61fa0064,0x64970024}},	//   _деяк, _mức_, yatl, eģio
  { {0xbb43000d,0xa01b00f2,0x3cfe0263,0x2cb20034}},	//   _ќерк, riöi, štvu_, llyd_
  { {0x5e57004c,0x2617000b,0xa5070004,0x442401c2}},	//   ייסע_, _नारी_, аеја_, tfm_
  { {0x493b000a,0x98a30a6c,0x2bf6000a,0xd90d002b}},	//   _בגלו, _дисе, ׁמֶן_, _سیه_
  { {0xc1780007,0xd2500029,0x61fa00dc,0x23480086}},	//   ybės_, كنة_, tatl, اسبی_
  { {0x15f8000a,0xeb91000a,0xe3af0015,0x27e10046}},	//   _תִּמ, לָי_, برى_, ěhne_
  { {0x70550087,0xd25702bf,0x67220a6d,0x2c750123}},	//   مندا, рцы_, ltoj, _låda_
  { {0x61fa0a6e,0x67220a6f,0x251b000a,0x44320016}},	//   satl, otoj, _יובא, _úy_
  { {0x73360029,0x67220a70,0x9098006b,0xe47b004c}},	//   _خرائ, ntoj, рвят_, _בראכ
  { {0xea0000a7,0x672200df,0x237b0008,0x645d00f2}},	//   _đến_, itoj, _שָׁמ, ösiv
  { {0x672200f2,0xb2bb0008,0x161b005d,0x1df80080}},	//   htoj, _שמור, प्टर_, ресы_
  { {0x115b0008,0x2c7500c0,0x5c740a0b,0xf3f1000a}},	//   _ידוע, _båda_, олст, ּ֣ן_
  { {0xa9e70029,0xb09c000a,0x109c000a,0xdb230061}},	// [d10] لثان, _שיחר, _שבחב, _örüm
  { {0xd138005c,0x8e840015,0x4a54058c,0x3e740123}},	//   ową_, _وليه, окус, _täta_
  { {0x67220a71,0xb7d500a2,0xdd910002,0x2ba7000b}},	//   etoj, مقاب, _روح_, _कुरा
  { {0x315700b2,0x20190375,0x8cba000b,0xa3c8000b}},	//   ייבן_, ngsi_, ्षणो, ोखा_
  { {0x6d5a008c,0x27200016,0xb05b008c,0xd874006e}},	//   ätav, gòn_, ymän, غامب
  { {0xbb3a00b2,0x5a470010,0x78a204af,0xa6840036}},	//   _געשי, _тэма, čova, олід
  { {0x28f803e7,0x1994006b,0x4993002b,0x6e35002a}},	//   _весь_, _даря, _بیار, iezb
  { {0xd7c90086,0x0d980008,0xcd98000f,0xaadb000b}},	//   _موزه_, יכום_, ידות_, _बढाक
  { {0xf7850015,0xd2a9004a,0xb05b0400,0xb4e60065}},	//   _الذَ, лкие_, tmän, _बढ़ी_
  { {0x27fd0026,0x91680092,0xcb36000a,0x2ca90034}},	//   lawn_, _sức_, צאתי_, hoad_
  { {0x61f801e2,0x29010a72,0xa879000a,0xa06a0a73}},	//   _devl, nsha_, ָאָר, гана_
  { {0x45b60008,0x307a0029,0xf9920008,0x27fd0034}},	//   _הפעל_, احدة_, לרי_, nawn_
  { {0x248d0048,0x889a0135,0x7205002b,0xb05b008c}},	//   miem_, רברי, _هوشم, mmäl
  { {0xd5b10023,0x248d0024,0x27fd0026,0xee3a0010}},	//   _ký_, liem_, hawn_, ынг_
  { {0x91680092,0x7cda002b,0x628f0003,0x2d9e0061}},	//   _tức_, اورز_, écou, çte_
  { {0x672200df,0x248d0a74,0x60850015,0x80e40015}},	//   ytoj, niem_, _وشيك, _بأول
  { {0xd5b10023,0xf1bf0089,0x59d60015,0x7e760015}},	// [d20] _lý_, řád_, مغار, _هادئ
  { {0xb05b0a75,0x2f5b000a,0x6f0406f2,0x2cb20034}},	//   hmäl, _עדינ, _ivic, slyd_
  { {0xfe37013a,0x248d0a76,0x01fa004c,0x69260004}},	//   _פרטי_, kiem_, רפעל, смеа
  { {0x248d0048,0x91fc0048,0x17fa0029,0x718a0053}},	//   jiem_, nkār, اراة_, נװײַ
  { {0x248d0048,0xd138005c,0x501b01d8,0x366a0004}},	//   diem_, zwą_, רונו, ладо_
  { {0x5ee9000a,0x47330033,0x67220a70,0x27200016}},	//   בַקְ, яніс, rtoj, ròn_
  { {0x764100df,0x91fc003d,0x67220a77,0x9f590003}},	//   _daly, kkār, stoj, rasé_
  { {0xb1760092,0xb8960029,0x248d0a78,0x5997000a}},	//   _ngượ, _الرع, giem_, _הכלב_
  { {0xa3a8000b,0x988b000a,0xb3760058,0xa01b02dc}},	//   _खुश_, _עָלֵ, إدعش, lhög
  { {0xda7b0053,0xd138002a,0x51f8005e,0x7c360a79}},	//   ָנטר, twą_, шною_, heyr
  { {0xd0110031,0x142a005e,0x7c36008c,0xc604000b}},	//   ولد_, _біло_, keyr, रणीय_
  { {0xd138002a,0x248d0a7a,0xbec3003d,0x0000006a}},	//   rwą_, ciem_, ķīmi,
  { {0x3e970029,0x5f940063,0x94bb000a,0x0000006a}},	//   مؤسس, зият, _עמדת,
  { {0x539b0008,0x6442002d,0x7d15003d,0x91fc003d}},	//   _גידו, _haoi, tuzs, akār
  { {0xb05b00f2,0x90e600e5,0xa1930033,0x6d40002a}},	//   lmäm, _استن, _нашч, łman
  { {0x7d150030,0xb4fb004f,0x6b7500ce,0xbca5009a}},	//   ruzs, טפלי, олбу, آمري
  { {0x64420a7b,0x2ca90a7c,0xfbd00015,0xd9f903ae}},	// [d30] _maoi, road_, فتك_, инац_
  { {0xacf8005c,0xf9c70457,0x7f4d0a7d,0xd759002b}},	//   _żółt, бщен, _iraq, یلات_
  { {0xb05b00f2,0xb9250015,0xe10b000a,0xdb060046}},	//   ymäl, تفضي, ָּבָ, _vyká
  { {0x6d400048,0xdb0f0152,0xd8250036,0x07d80015}},	//   āmat, _lycé, ідли, مذهب_
  { {0xbc1a0008,0x76410007,0x248d0a7e,0x27fd0335}},	//   _דורש, _paly, viem_, rawn_
  { {0xf1c8014e,0x248d005c,0x91fc0024,0x5b56000a}},	//   रधान, wiem_, zkār, _וישב_
  { {0x248d0048,0x9f400084,0xf5560021,0x76410351}},	//   tiem_, _leið_, قلوب_, _valy
  { {0x7b080084,0x13090a7f,0x7aed0a80,0x628a0a81}},	//   _ástæ, аний_, opat, _amfo
  { {0xb7bd04f9,0x6442002f,0x248d0a7e,0xdc6c000a}},	//   _obţi, _daoi, riem_, ר֣וֹ
  { {0x248d0048,0xbb3c0053,0x2f10002e,0x41050a82}},	//   siem_, רעזי, _lögð_, озов
  { {0x6442002f,0x91fc0024,0x645d0a83,0x248d003d}},	//   _faoi, tkār, ösis, piem_
  { {0xf4350010,0x9fca0254,0xb184006f,0xb7bd0045}},	//   _федэ, игна_, íťaz, _abţi
  { {0xe28e076c,0x98c50007,0x083a0053,0xa2da000b}},	//   _жа_, štės_, בערל, नदण्
  { {0xc5f90053,0x6e960015,0xc2c40015,0x91fc003d}},	//   יפֿט, زلزا, _فيني, skār
  { {0xa3c1005d,0xa01b0a84,0x7aed0a85,0x6c360015}},	//   ंधक_, giös, epat, يفسا
  { {0x6f000014,0x7f4d016e,0xec160015,0x7188000a}},	//   ámcs, _fraq, تورد, _לְפַ
  { {0x7aed00b6,0xcb0a0067,0x2ab4007c,0xa01b008c}},	// [d40] gpat, شيان_, läbi_, riöt
  { {0xf9920115,0xf221000b,0x6d5a008c,0x63b600cb}},	//   وبا_, _माफ़_, ätas, _øyne
  { {0x6ee50086,0x64970024,0xdca60a86,0x7aed0a87}},	//   _وسیل, rģij, _маои, apat
  { {0x628600dc,0xd7ef0029,0xa01b0a88,0xb05b005b}},	//   ékoz, نكم_, rhög, ymäm
  { {0xf1ab000b,0xa6f30033,0x6d43001a,0xa01b0123}},	//   _घुसन, дзіш, _ánar, shög
  { {0x6b630010,0x6442002d,0xf1bb000b,0x64970045}},	//   _ўкра, _saoi, ैधान, nţif
  { {0x9e5b0643,0x9e0b000a,0xdddc0030,0x2aaf0012}},	//   יכסט, שִׂ֖, nkrő, rübt_
  { {0xe814005d,0xa3e5005d,0x9998003d,0x387d0034}},	//   _डाटा_, बुल_, _garš_, chwr_
  { {0xd5a4002b,0x66e50015,0xa01b02ad,0x0000006a}},	//   _کلای, _فألق, ziös,
  { {0x026a0036,0x3f820a89,0x3678000a,0x9f40001a}},	//   рший_, dzku_, _פְּע, _reið_
  { {0x3a37013a,0x7aed005c,0x8cd6000b,0x64420a8a}},	//   חרים_, zpat, _मंगो, _taoi
  { {0xb05b00f2,0x232a0317,0x91fc003d,0x628f0a8b}},	//   mmäk, _води_, akāp, écor
  { {0xe29a0124,0xd2520015,0xb05b008c,0x0000006a}},	//   _кад_, _ينص_, lmäk,
  { {0x29070014,0xa2c1000b,0x628a0012,0x2f10001a}},	//   ának_, _रीप्, _umfo, _sögð_
  { {0x12a90029,0xdb06008c,0xdc8b045f,0xb05b008c}},	//   _ادنى_, _lykä, асал_, nmäk
  { {0xe57100b2,0x69d80007,0x9b890029,0x317b000a}},	//   ײַל_, žvel, منزل_, _כרומ
  { {0x7aed003f,0x5b150a8c,0xda670015,0xddde002a}},	// [d50] upat, ямат, يائي, _dopł
  { {0x8e840054,0x7aed0a8d,0xbce70058,0xcce70058}},	//   _огње, rpat, _وأجو, _وسجي
  { {0xdc2f0024,0x629a0a8e,0xd8b9002b,0x7aed07fc}},	//   ažād, into, مگرا_, spat
  { {0x7c590015,0xf807005e,0x7aed0a8f,0x6d58013f}},	//   _الحر_, ічен, ppat, _švag
  { {0x8cba005d,0xfc5a0008,0xd00c000a,0x78ab02de}},	//   ्षरो, _הכרמ, בּוֹ, rogv
  { {0x1af6000a,0x7f3c004f,0x0000006a,0x0000006a}},	//   _ממשל_, יעדו,   ,
  { {0x2d83002a,0xa506006b,0xa9550033,0x929d002a}},	//   nzje_, пеща_, _экві, jsła
  { {0x629a0a90,0xc952004f,0xbd9c004f,0x0000006a}},	//   ento, _אמל_, יסות,
  { {0xf7730018,0x3834017f,0x9c08000a,0x91fc003d}},	//   _غار_, _інфр, חִתִ, tkāp
  { {0xaabd000b,0xc6d40015,0x7d080046,0xb05b0a91}},	//   ्गिक, _قتلت, ádsk, lmäh
  { {0x0202008f,0x85050086,0xe45f0020,0x91fc0024}},	//   эзэн, _روشن, öös_, rkāp
  { {0x55ba0008,0x629a0a92,0x92a4002a,0x8fa60a93}},	//   _המעו, anto, ółrz, заме
  { {0xc4840033,0xaabd0065,0x5f760058,0x2349009a}},	//   _ўлік, ्गाक, ساحر, _دسای_
  { {0x92b70015,0x02450015,0xb05b0a94,0x0000006a}},	//   _بحصا, _رَبَ, hmäh,
  { {0x7c2f0011,0xdd920115,0x3179004c,0x99930046}},	//   _bbcr, رور_, _לאַד, dexů_
  { {0x8fa6005e,0xec34002b,0xa7fd0030,0xaf0601e1}},	//   _найе, بورگ, _elűz, _епил
  { {0x207b0053,0x8e560036,0x6a72001a,0x69da0015}},	// [d60] _לאקא, _етні, _hæfi, مباح_
  { {0x7c2f0134,0xdb06005c,0x20020a95,0x1eaa0015}},	//   _ebcr, _szkó, laki_, _داعي_
  { {0xceb300b4,0x4ddb0008,0xe8530086,0x9ddb000a}},	//   _איז_, _לחיו, کنند, _לקיח
  { {0x38cb0074,0x18a3006b,0x6f0602de,0xdca60302}},	//   مانی_, нахм, oskc, _хами
  { {0x29130251,0x629a00e7,0x99f60033,0xb8650369}},	//   arxa_, ynto, _няві, بالو
  { {0xd6d90036,0x929d005c,0xdcdb0065,0x98b10535}},	//   іті_, ysła, _मूँछ, _mszę_
  { {0xe9a30a96,0x442f0a97,0x9538005e,0x20020a98}},	//   _зарп, _bbg_, ізит_, kaki_
  { {0x399b0008,0x499b0008,0x629a0a99,0x200201ff}},	//   _הילד, _השלב, wnto, jaki_
  { {0x200201e2,0x6b8400b8,0x291a0a9a,0x83fd0030}},	//   daki_, nzig, lupa_, rkőp
  { {0xb05b022d,0x877b0008,0x1546005e,0x629a0a9b}},	//   mmäi, _האמי, _незм, unto
  { {0x24970074,0xa6e90023,0x2bb9005d,0xdb2300dc}},	//   _کنند_, _chươ, _आर्थ, _öröm
  { {0x60c40738,0x35e2000b,0xb9bb004f,0x2fd90058}},	//   _chim, _पलड़, מצית, توحد_
  { {0x6b840a9c,0x60c4003f,0xa867000a,0xbfab0a9d}},	//   jzig, _dhim, לֹךְ_, стне_
  { {0x291a0a9e,0xd3570008,0x539b0008,0xe731000a}},	//   kupa_, _מידי_, _פיגו, כֵל_
  { {0x2002000c,0xeda40036,0xb2bb000a,0xd12f062f}},	//   baki_, ешто, _המגר, _ях_
  { {0x30a4008f,0x5cb90010,0x60d60061,0x319b000a}},	//   _прыв, ілаў_, _giym, _לבונ
  { {0x3f9e01e2,0xcb34006b,0x290e0052,0x0000006a}},	// [d70] ştur_, нетъ, áfan_,
  { {0x99d70029,0x3f7c000a,0x49cb0033,0x0b88005e}},	//   ستطا, _לאחס, буем_, їсти_
  { {0x290701cb,0x6d410061,0xf8b1002b,0x291a02f2}},	//   éna_, çlad, نکر_, gupa_
  { {0x38690084,0x6a730064,0x6b840012,0xec150058}},	//   ðar_, _sıfı, bzig, _توحد
  { {0xf72b0010,0x64970011,0x08d4002b,0x600c000a}},	//   сцей_, nţie, رآمد, מִגְ
  { {0x20020a9f,0x442f01d7,0x7c2d0aa0,0xf2180065}},	//   zaki_, _sbg_, lfar, _दाग़_
  { {0xa93405fc,0x6f090089,0xb93403ae,0x64a50aa1}},	//   _перш, šech, _перј, мака
  { {0x6d7c000a,0xf992000a,0xb4b7000b,0x200200aa}},	//   מאוח, _סרן_, छते_, xaki_
  { {0xd408002b,0x20020aa2,0x7c2d0aa3,0x63e40015}},	//   ستيم_, vaki_, ifar, رسيك
  { {0xa6e90023,0x3ce0000b,0x7c2d00a9,0x60c40aa4}},	//   _phươ, कदमे_, hfar, _shim
  { {0xb97a0053,0x213e0026,0x10a60805,0x20020aa5}},	//   ַנשי, gwth_, динн, taki_
  { {0x66030aa6,0xf4b6002b,0x0000006a,0x0000006a}},	//   lank, _قشنگ,   ,
  { {0x64490176,0x7d1506cd,0x7c2d0aa7,0x64590aa8}},	//   mdei, erzs, dfar, _inwi
  { {0xa6e90023,0x442d0aa9,0xe2c90031,0x60c400da}},	//   _thươ, lfe_, _بوتو_, _whim
  { {0x64970045,0x60c40aaa,0xa06a045f,0x20020aab}},	//   aţie, _thim, _мака_, paki_
  { {0xf1a70086,0x27ff00b8,0x64490aac,0x6b840012}},	//   _واژه_, _neun_, ndei, tzig
  { {0x64970011,0x3e740020,0x2bc3005d,0x442d0334}},	// [d80] cţie, _läti_, _शरणा, ife_
  { {0xcf250015,0x6b840012,0x19960054,0xe9d20015}},	//   _أريي, rzig, мјер, نغا_
  { {0xb80a0029,0x66030aad,0xcb090008,0xccc601c5}},	//   قيام_, dank, של_, _обой
  { {0x224700dd,0xccf30008,0xca29039e,0x291a0aae}},	//   _lank_, _שכר_, ים_, rupa_
  { {0x64490026,0x7d1c03ba,0xc6f7022a,0x073a00e6}},	//   ddei, lurs, дніх_, تساب_
  { {0xcb8b01d8,0x442d0aaf,0x929d002a,0xea000016}},	//   _וְלֹ, efe_, dsło, _đặn_
  { {0x69dc001c,0x442d0645,0x75d30067,0x45470033}},	//   _igre, ffe_, نيها, дчым_
  { {0x3ae400c0,0x442200dc,0x660300f2,0xb05b00f2}},	//   _köp_, ük_, aank, lmäv
  { {0x7ae2002d,0x22470ab0,0xbcb7000a,0x7d1c0ab1}},	//   íoth, _bank_, ופקו_, hurs
  { {0xb2380015,0x64490ab2,0x38660123,0x07a307c9}},	//   أكدا_, adei, ljor_, _раун
  { {0x018a0080,0x7c2d0026,0xd257005e,0x8a17000a}},	//   ющий_, yfar, єць_, וחיו_
  { {0x7d1c0084,0x73c60029,0x1c1d000b,0xb08b0033}},	//   durs, _قيام, _फाइल_, іёне_
  { {0x7d1c00dd,0xdfd80063,0xf487002b,0xd372002b}},	//   eurs, дър_, _تالی, _جهش_
  { {0x53330036,0x69dc0ab3,0x6a72001a,0x62810ab4}},	//   _решт, _ngre, _kæfu, chlo
  { {0xf1aa0086,0xc3480092,0xec6b09e8,0x764801c2}},	//   _باشه_, _hổ_, орак_, _mady
  { {0x69dc03b8,0x64970045,0x1bd5033d,0x90a70015}},	//   _agre, pţie, еобя, _تحتم
  { {0x7c2d0ab5,0xdfd10015,0xab940432,0x6f2a002a}},	// [d90] rfar, _حية_, ватљ, ępcó
  { {0x68fc0026,0x27ff00dd,0x1a65002b,0xaceb0015}},	//   _bwrd, _seun_, ریزی_, _ورجل_
  { {0x5e5600b2,0x64490026,0x68fc0026,0x7d1c0ab6}},	//   _װירע_, ydei, _cwrd, curs
  { {0xb8e7000b,0xe7d3002b,0x929d002a,0x765a0ab7}},	//   _उठ_, نماگ, ysło, _anty
  { {0x764800b6,0xc3480092,0xa6e70092,0x87d40015}},	//   _bady, _nổ_, _giữ, نغها
  { {0x8afa0008,0x68fc0026,0x8f9c000a,0x6f1d02b9}},	//   _מהשי, _fwrd, חידי, iusc
  { {0x66030ab8,0x2496002b,0x68fc0034,0x22470ab9}},	//   rank, کنيد_, _gwrd, _rank_
  { {0xc3480023,0x6d45003f,0x93450aba,0x765a05bc}},	//   _bổ_, _msha, ение, _enty
  { {0xc3480092,0x22470abb,0x62810495,0x6f1d0abc}},	//   _cổ_, _pank_, thlo, jusc
  { {0xe1f10029,0x272902c1,0xda0f005d,0xe5f50015}},	//   دسة_, mún_, ाणित_, _أكاد
  { {0x9f5e0064,0x442d00b8,0x386d007c,0x6e3c02b3}},	//   ştü_, pfe_, _koer_, verb
  { {0xf76700a2,0xc9520053,0x6e3c0abd,0x64590abe}},	//   ها_, אמט_, werb, _unwi
  { {0x24180036,0x22470abf,0x7f760054,0x249f001a}},	//   _цією_, _tank_, хунц, mnum_
  { {0xdce7005c,0x7f750010,0xe732000a,0x6e3c0012}},	//   zyją, туюц, נֵר_, uerb
  { {0x387f0064,0x7afd0026,0x11450029,0xd5b2000a}},	//   _olur_, _awst, _أَبُ, ָׁן_
  { {0x249f002e,0x660100dc,0x10690029,0x7d1c0ac0}},	//   nnum_, _lelk, _يحيى_, rurs
  { {0x249f002e,0xc4d200f3,0xb09b00f3,0x1fb6017f}},	// [da0] inum_, רגן_, _מיקר, _яскр
  { {0x7fd70008,0x32050046,0x387f088a,0x6497003d}},	//   _אופס_, naly_, _alur_, oģis
  { {0x249f0ac1,0x980a0015,0x8dfb000a,0x76480ac2}},	//   knum_, كتشف_, _מהית, _rady
  { {0x3f7a0135,0x76480035,0xe704002b,0x32050046}},	//   ּאַס, _sady, نستی, haly_
  { {0x61360014,0x27290467,0x32050046,0x66010ac3}},	//   _külö, gún_, kaly_, _belk
  { {0x66010156,0xe7690046,0xc3480016,0x8cba000b}},	//   _celk, nářů, _rổ_, ्षको
  { {0x249f0084,0xc3480092,0x76480007,0x2ca00020}},	//   fnum_, _sổ_, _vady, onid_
  { {0x249f0084,0x66010020,0x95530031,0x5454071a}},	//   gnum_, _eelk, اخوا, твит
  { {0xcc3b00b2,0xb05b00c0,0x9cd70008,0x64970024}},	//   לעקט, lläg, עופה_, eģis
  { {0x2ca0002d,0x179b000a,0x2c7c0077,0xb05b008c}},	//   hnid_, _זימב, _oído_, hmät
  { {0x2b91002c,0xb05b00c0,0xd6cf0115,0x5a17004c}},	//   môcť_, nläg, _اقل_, עקטן_
  { {0xc3480023,0x33f60029,0xa4fb0053,0x69c3005c}},	//   _tổ_, _أساس, _זלאט, żneg
  { {0xb05b00b8,0x93260086,0xf09f0144,0xdb1d0061}},	//   hläg, _سرشن, rnà_, üyük
  { {0x6f1d002f,0x877b000a,0xa01b0028,0xc7b1000a}},	//   rusc, לאכי, chön, ׁ֑ם_
  { {0xac95007a,0x4c95005e,0xc2c30015,0xc534000a}},	//   вавш, вивс, _حيوي, כָּה_
  { {0xdcb8010f,0x91bb000a,0xc1bb000a,0x31bb000a}},	//   ещу_, _ממוי, _ממוש, _מזונ
  { {0x649704f9,0x613600dc,0xc3340008,0xfaf000e6}},	// [db0] nţia, _fülö, כוּ_, مثل_
  { {0xdb260086,0x2ca0007c,0x6e250012,0xb05b0ac4}},	//   ئولی, anid_, _uchb, amät
  { {0x6d45003f,0xd7f10015,0x249f001a,0xad19004f}},	//   _usha, لكا_, ynum_, _קוֹר
  { {0x660100f2,0xb05b00f2,0xb06600f2,0x27290ac5}},	//   _selk, mmäs, mpää, tún_
  { {0xf7450ac6,0xd6db0ac7,0x386d049c,0xb05b0ac8}},	//   тело, чте_, _voer_, lmäs
  { {0xe9d30086,0x64970091,0x29070125,0x69350ac9}},	//   _مغز_, dţia, ánas_, _ингу
  { {0x32050089,0x386d00dd,0x2729002d,0x249f002e}},	//   valy_, _toer_, sún_, tnum_
  { {0x66010384,0x249f002e,0xddde0046,0x3e740012}},	//   _welk, unum_, _dopř, _hätt_
  { {0xb05b00f2,0x249f0aca,0x8c1c000a,0x0219005e}},	//   hmäs, rnum_, פוזי, мінь_
  { {0x249f001a,0x42550004,0x5edc000b,0x44260acb}},	//   snum_, ттит, _गूग्_, _eco_
  { {0x249f002e,0xb05b0ac8,0xa01b001a,0xc1780174}},	//   pnum_, ymät, rhön, есяц_
  { {0x3e7400c0,0xcea9000a,0xdee60acc,0xa01b001a}},	//   _lätt_, _וי_, коми, shön
  { {0xab5b00dc,0x10a30805,0x443f0acd,0xcf430088}},	//   _szün, риян, meu_, аняй
  { {0x63a400df,0x443f0ace,0x6f0d0089,0x644b0acf}},	//   _žing, leu_, _dvac, _hagi
  { {0x81740086,0xc69201ac,0x27ed0012,0x29070045}},	//   _منوچ, באם_, _ofen_, ânal_
  { {0x443f0ad0,0x7f860029,0x644b0ad1,0x6f960015}},	//   neu_, _للبن, _jagi, _للعض
  { {0x644b0ad2,0x443f0ad3,0xb0b7000a,0x7c2b0144}},	// [dc0] _magi, ieu_, _בפקס_, ògra
  { {0xaa7b002e,0x644b0ad4,0x6a830004,0x38bc0030}},	//   _stýr, _lagi, алуа, míri_
  { {0x4806005e,0xa9260457,0xb05b0309,0x6f0d0046}},	//   впев, тдел, mmär, _zvac
  { {0x644b0ad5,0xb05b0ad6,0x63a4001a,0xd6e2002a}},	//   _nagi, rläg, _þing, ykłą_
  { {0x443f0ad7,0xb05b00c0,0x27e00ad8,0x38130033}},	//   deu_, släg, žino_, рміё
  { {0x7bc600bd,0xb05b0ad9,0xddde0089,0x44260ada}},	//   _izku, pläg, _popř, _sco_
  { {0x443f0251,0x85460010,0x644b064e,0x75d40029}},	//   feu_, тэле, _bagi, ديثا
  { {0x38c80074,0x443f0adb,0x644b02b9,0x7c240adc}},	//   _سازی_, geu_, _cagi, ngir
  { {0xb05b00c0,0xf3630033,0xf2c60add,0x03c300f4}},	//   kmär, атэн, ксон, исьм
  { {0xb05b00f2,0x64970011,0x7af60091,0xd257005e}},	//   ymäs, rţia, ipyt, вцю_
  { {0x443f0ade,0x78a201a3,0xfa77000a,0x63a40091}},	//   beu_, onov, דעית_, _žind
  { {0x04460124,0x61f50064,0x443f0adf,0xe4d6002b}},	//   _једн, ızla, ceu_, _شتاب
  { {0x64400064,0x9f590123,0x62340ae0,0x78a20ae1}},	//   memi, kaså_, _белу, inov
  { {0x649704f9,0xd130002b,0x64400ae2,0x644b002a}},	//   nţin, _همت_, lemi, _zagi
  { {0xf7080092,0xac27000d,0x3e7400c0,0x4dd40058}},	//   hủ_, кфак, _rätt_, لتفس
  { {0x3e7401d1,0x64400ae3,0x6abd000b,0x7c2402b9}},	//   _sätt_, nemi, ्ग्र, ggir
  { {0x5a350403,0x3b550010,0xfbd00015,0x40bc000a}},	// [dd0] лнат, ыкар, قتك_, _קזחס
  { {0xdce7005c,0x443f0ae4,0x2489006f,0x753a0045}},	//   zyję, zeu_, ďami_, _optz
  { {0x83fd00dc,0x7af6005c,0x64400ae5,0x39150ae6}},	//   rkőz, apyt, kemi, умер
  { {0xc19b0008,0x443f0251,0x64970045,0x28f8005e}},	//   ושבי, xeu_, eţin, тець_
  { {0x8c1a0008,0x443f0ae7,0x6ca8000a,0x644b0ae8}},	//   _אורי, veu_, _יֹשְ, _ragi
  { {0x7624005e,0x644004f6,0xd6260054,0xe5a50974}},	//   иміз, eemi, гоше_, лили
  { {0x443f0ae9,0x644b0aea,0x2e38000a,0xce38000a}},	//   teu_, _pagi, דרוש_, דאות_
  { {0x64400005,0x69c70796,0x95740033,0x03250004}},	//   gemi, _izje, рышч, гдин
  { {0x443f0aeb,0x64970045,0xd29900fd,0x644b0aec}},	//   reu_, bţin, етні_, _vagi
  { {0x443f0ae9,0xeb92000a,0x00da002b,0x565b0015}},	//   seu_, מָת_, کبخت_, _تشرح_
  { {0xe4e70191,0x44f50063,0xab5b00dc,0xef1f00dc}},	//   _різн, _спес, _szül, szül_
  { {0xa3550002,0xa3ea000b,0xe588000a,0xa936000a}},	//   _مختص, _मलय_, _בָנָ, נטרה_
  { {0x6d410064,0x9975005c,0xa856000a,0xee160033}},	//   çlan, nęła_, אירה_, львэ
  { {0x539a00a3,0xdee30aed,0x78a20aee,0xc7b2004f}},	//   _אינו, сори, znov, צבם_
  { {0x64970011,0xc6920aef,0x81bc003d,0x621a000a}},	//   nţio, זאם_, sfēr, _טוסק
  { {0xb05b0005,0xdd8f0029,0x91ba000a,0x3e7405ff}},	//   smär, سوق_, _אמצי, _päts_
  { {0xb05b00c0,0x9975005c,0x5f46002b,0x5b260015}},	// [de0] pmär, jęła_, _صندل, طفال
  { {0x7f29000a,0xca4a0015,0x2d9e0003,0xb05b008c}},	//   _סֵפֶ, علاه_, ûtes_, lmäp
  { {0xaf360086,0x82960053,0xdce80024,0x64400061}},	//   _شرکت, נדעס_, ēlēt, yemi
  { {0xe3a70074,0x6440016e,0xad1b000a,0x6d400045}},	//   _هر_, xemi, _אוטר, ămad
  { {0x47330086,0x2bba0015,0xb8eb000b,0x78a20af0}},	//   مروز, _ساحة_, _री_, rnov
  { {0x78a201a3,0x69c30061,0x96b70054,0x96330033}},	//   snov, ünec, лују_, йніц
  { {0x64970011,0xafdb0293,0x64400af1,0xcdf7000a}},	//   rţin, ndør, temi, אמצי_
  { {0x64970011,0xe3140004,0x78a201c0,0x54360058}},	//   sţin, амињ, čovs, ارغر
  { {0xeb970053,0xf2060af2,0x64970045,0xdc3b004c}},	//   ָדיר_, ляно, aţio, געפר
  { {0x67220007,0xd9f6000b,0x64400af3,0x86c60021}},	//   muoj, ेरित_, semi, _صيان
  { {0xd657013a,0x64970011,0x3cf8002c,0xba9b000a}},	//   _תיבת_, cţio, jprv_, תסיי
  { {0xf9930008,0x64970011,0xe58b0008,0x9f59002d}},	//   מרת_, nţil, _אָדָ, masú_
  { {0x26de0007,0x67220007,0xf4870086,0x7ae6003f}},	//   _kito_, nuoj, _حالی, _nukt
  { {0xc7b3013a,0xb05b018b,0x0cbf005d,0x38bc0046}},	//   מבר_, fläc, ्ष्म, míru_
  { {0x6d58002e,0x765e00f2,0xc27b01ac,0x6ca70af4}},	//   _ával, öpyy, _ארגי, граж
  { {0x67220007,0x1f7509ef,0x7ae60509,0x44ea0016}},	//   kuoj, _влия, _bukt, _mù_
  { {0x26de001c,0x67220007,0xafdb0af5,0x2d9e0003}},	// [df0] _oito_, juoj, rdøs, ûter_
  { {0x44ea038d,0x26de00b6,0x200b06d5,0x67220007}},	//   _où_, _nito_, laci_, duoj
  { {0x629a0af6,0x60cd0af7,0x6288008c,0x2aa8030c}},	//   iito, _kham, ihdo, утто_
  { {0x8934003b,0xa5650086,0x6cfa000a,0x9be4005e}},	//   إعلا, یگان, _שפרס, _гірк
  { {0xe7580036,0x67220007,0x4804005e,0xd6d5004a}},	//   лиці_, guoj, спів, ажды
  { {0x99d70029,0x44ea0092,0x87040146,0x629a0af8}},	//   _متزا, _bù_, сяце, jito
  { {0x200b02d5,0x26de0af9,0x6f1d00b8,0xb05b008c}},	//   kaci_, _dito_, hrsc, ymäp
  { {0x44ea0023,0x628800f2,0x200b049f,0x9733002b}},	//   _dù_, ehdo, jaci_, _هکتا
  { {0xd627003b,0xc4820191,0xe3b10029,0x66270029}},	//   _معاي, ільк, غرب_, _مراك
  { {0xa7740afa,0x64970011,0x65950afb,0x629a0afc}},	//   _улуч, pţio, _казу, gito
  { {0x42540010,0x64970011,0x76430afd,0x628301c9}},	//   стыт, lţim, meny, _vlno
  { {0x628800f2,0x200b0afe,0xb4fa000a,0x60cd0aff}},	//   ahdo, gaci_, _יפעי, _cham
  { {0x60cd003f,0x23290457,0xe3b30021,0x9046002b}},	//   _dham, _роли_, _ارض_, هنگه
  { {0x62880b00,0xc7d6000a,0x78a90085,0x41e700e2}},	//   chdo, יורי_, _ljev, _сіда
  { {0x9cb60029,0x67220007,0x200b016f,0xc69201ac}},	//   لمست, zuoj, baci_, קאל_
  { {0x70b30015,0x200b0b01,0x3ceb0069,0x60cd01f9}},	//   _وموض, caci_, _živí_, _gham
  { {0x4e1a0080,0x3ae80086,0xc9f60015,0xed59003d}},	// [e00] _июня_, ابری_, لساع, āža_
  { {0xda790036,0xef1f00dc,0x6e930015,0xff7b015b}},	//   ляє_, zzük_, _وليا, _סטימ
  { {0x2bb8005d,0xfe370053,0x26de0b02,0xd82601b7}},	//   _आडवा, _דריי_, _rito_, иджи
  { {0x26de02d7,0x09c6005d,0x38cb0086,0x31360053}},	//   _sito_, _वरीय, نانی_, ינעם_
  { {0x64970011,0x87030b03,0x30d90053,0xabfb0008}},	//   rţil, ояще, אַװע, _בהכר
  { {0x7523000c,0x200b02d5,0x67220007,0x254700dc}},	//   funz, zaci_, ruoj, _ből_
  { {0x32180050,0x67220321,0x629a0b04,0xaa3b000a}},	//   órym_, suoj, vito, _שתלח
  { {0x660a0134,0x3c76000a,0x3eb80b05,0x67220091}},	//   safk, יתֶם_, hort_, puoj
  { {0xc3270015,0x200b0b06,0xe3af0015,0x628800e7}},	//   لكين_, vaci_, ِرٍ_, thdo
  { {0xab5b0014,0x44ea0092,0x78a90089,0x60cd0b07}},	//   _szük, _tù_, _zjev, _sham
  { {0x3207003e,0xa44603fc,0x25eb000b,0x68e00061}},	//   _deny_, _внед, _चलती_, _kimd
  { {0x859b0008,0x6d410064,0x757b0053,0x80a40015}},	//   _בשבו, çlam, _שטאפ, ْمَن
  { {0x200b036e,0xe8d7004c,0x6f1d06a8,0x3eb80043}},	//   raci_, יוטר_, ursc, fort_
  { {0x6f1d018b,0x92b30015,0x333b004f,0x02440058}},	//   rrsc, _وحوا, _סתומ, _طَعَ
  { {0xbc070b08,0xfce90015,0xacf70015,0x6d470079}},	//   ичай, افري_, ؤسست, uwja
  { {0x60cd003f,0xe58b000a,0x7e20000b,0x11db000a}},	//   _uham, דָמָ, बलॉग_, _בחוב
  { {0x6a15004a,0xfbd3002b,0x3b54052b,0x929d002a}},	// [e10] ймау, زتر_, октр, asłu
  { {0x78a9016f,0x929d005c,0x3eb80b09,0x7ac4030c}},	//   _sjev, bsłu, cort_, осхе
  { {0x7ed40029,0x78a9016f,0x29670001,0xda08002b}},	//   _بزيا, _pjev, шњав, شينه_
  { {0x7643000c,0x254700dc,0x320c0057,0xc052000a}},	//   weny, _ről_, hady_, ּ֖א_
  { {0xa01b00b8,0x9848006b,0x320c002a,0xec6801b0}},	//   rhöh, ряха_, kady_, _трэк_
  { {0x7bda0008,0x7523003f,0x2ee90061,0x8b76000a}},	//   _תקשו, tunz, _muaf_, _התשע_
  { {0xbe3c0008,0x361800ce,0x3634009a,0x6608013b}},	//   דעות, рцію_, ترنس, _dedk
  { {0x76430b0a,0x320c00da,0x63a40091,0x98140015}},	//   seny, eady_, _žina, _وبقا
  { {0x752302b9,0x76430b0b,0x437500c2,0x0000006a}},	//   sunz, peny, суйт,
  { {0xf6740029,0x16380029,0x254700dc,0x06380015}},	//   _والخ, _نسمة_, _től_, _نسمع_
  { {0x3eb8002e,0x05790015,0x7c360034,0xd00a0b0c}},	//   vort_, _حماة_, yfyr, лене_
  { {0xb7bd04f9,0x3eb800b8,0x1287009a,0x200900d4}},	//   _acţi, wort_, امگی_, _ceai_
  { {0xd12e0074,0x42d50036,0x998c002a,0x3eb80b0d}},	//   ومی_, _ліку, _łoże_, tort_
  { {0x201e0b0e,0xa2f6000a,0x412900af,0xddde00d4}},	//   şti_, _המסה_, _боко_, _copş
  { {0x70f50029,0xd1480086,0x80f50029,0x3eb80b0f}},	//   _استئ, _نشين_, _استض, rort_
  { {0x6f04003e,0xada30010,0x27e00796,0xd12e0015}},	//   _twic, часл, žini_, _أمي_
  { {0x7c360b10,0xc4d2000a,0x3eb80b11,0xcb67007e}},	// [e20] rfyr, לגל_, port_, бате_
  { {0xb05b079c,0xa96a0579,0xda0a0015,0x6e460015}},	//   nlän, лиза_, اياه_, _اندم
  { {0x660800bd,0xb05b0b12,0x628100bc,0x8c46009b}},	//   _redk, ilän, iklo, _лене
  { {0x510a0053,0x80ce0065,0x0aea0058,0xb05b02ad}},	//   רהײַ, _धीमे, _مرسي_, hlän
  { {0x4cbb0008,0x68fb02d8,0x68430033,0x6c57004f}},	//   _תזכו, _čude, янца, _היכא_
  { {0xfd650023,0x07070015,0x24860085,0x0000006a}},	//   _nguồ, حيوي_, _slom_,
  { {0x9986003b,0x5d7a00b2,0x27e90263,0xc8f8000a}},	//   _الأو, טאַק, žana_, _כִּכ
  { {0x4917000a,0xa2f404e5,0x320c0b13,0xb05b02ad}},	//   _לקלל_, опич, wady_, elän
  { {0xf3ef0029,0xc4450086,0x77860001,0x8c1b000a}},	//   رأي_, زیون_, _улаз, אופי
  { {0x27320011,0xb1140004,0xda08000b,0xb05b0b14}},	//   mân_, омош, षरित_, glän
  { {0x3abb00b2,0xd2570010,0xaabb0053,0x85f70008}},	//   רמינ, сцы_, רזיכ, _הצבע_
  { {0x320c0b15,0x629d0003,0xf08b0015,0x62810b16}},	//   sady_, ésor, ائده_, aklo
  { {0xa4b7000a,0xff04006b,0x489b004c,0x43430033}},	//   _פלדה_, зясн, ריכװ, _нецв
  { {0xa2d30015,0xacf90511,0x62810b17,0x0000006a}},	//   _فينت, ингу_, cklo,
  { {0x40350b18,0xf5180008,0x27320b19,0x667b000a}},	//   _дейс, יֵּל, hân_, נטלק
  { {0xa0a40b1a,0xce330086,0xa01b00c0,0x859b004c}},	//   _најд, _کودک, ehöv, אשלו
  { {0xba75004a,0xf09f0144,0x1eab0015,0xf1bf0046}},	// [e30] огащ, mià_, _مادي_, řát_
  { {0xf09f0251,0x51f8000a,0x9e0705aa,0x99d70058}},	//   lià_, שִּׂ, _учил, متضا
  { {0xe291004f,0x28150369,0x0000006a,0x0000006a}},	//   וְא_, قواس,   ,
  { {0x17fb0029,0x50c9005d,0xf09f0144,0x6281035f}},	//   ارضة_, रतिष, nià_, zklo
  { {0xf105014e,0x27320092,0xd5e509a7,0x6c56000a}},	//   _शब्द_, gân_, ожли, _וירא_
  { {0x45190404,0xb05b0123,0x2ca902dc,0x6d580073}},	//   ация_, xlän, lnad_, _švai
  { {0x2ca90b1b,0xf69600c3,0x1a68002b,0x4c4b004f}},	//   onad_, تنوع_, _دیلی_, ָתִ֑
  { {0x2ca90005,0x8339000d,0xf1c30089,0x1d0c000a}},	//   nnad_, ачот_, _liší_, נּוּ
  { {0x64970011,0xf09f0144,0x20d20030,0xb05b0400}},	//   nţii, dià_, láig_, tlän
  { {0xe2990001,0x2ca90026,0x92e80015,0x0000006a}},	//   рао_, hnad_, حريق_,
  { {0x63a409f0,0xc6680083,0x13f5008f,0xb05b0b1c}},	//   _þinn, _уште_, _дзея, rlän
  { {0x61fc0064,0xb05b07fd,0x45b6000a,0x10050033}},	//   ırla, slän, _ופעל_, зяём
  { {0x6b89002a,0x1eca006b,0xb05b0b12,0x61fc0030}},	//   _żegn, илми_, plän, űrla
  { {0xb7da0008,0x3f8c005c,0x20d20030,0x0eba0174}},	//   יקרי, ądu_, káig_, румы_
  { {0x3f84002c,0x1d0a01dc,0x6e21001a,0x248d02ad}},	//   šmu_, реби_, ólba, ohem_
  { {0x90c30b18,0xf09f0251,0x2ca900c0,0x248d0b1d}},	//   _обще, cià_, gnad_, nhem_
  { {0xdca30b1e,0x2002007c,0x6a160015,0x1db6000b}},	// [e40] фати, mbki_, قبار, _आँकत
  { {0x4a430004,0xa01b0012,0xdcf60015,0x076a002b}},	//   мнув, nkön, _وأجب, یماً_
  { {0x02b60053,0x57ea03de,0x64970045,0xdb060123}},	//   קלעך_, адем_, aţii, _nykö
  { {0xd7f00029,0xaf35002b,0x718a004c,0xa01b0b1f}},	//   ركت_, _بویژ, סװײַ, shöv
  { {0x64970011,0x27320092,0xa01b008c,0x249f0b20}},	//   cţii, uân_, kkön, dium_
  { {0x63a400df,0x057600e5,0xe6930015,0x8ab8000a}},	//   _žino, قاعد, ولند, _הֶֽח
  { {0x38cb002b,0x29070045,0x442f0b21,0x65140058}},	//   _چاقی_, ânat_, _bcg_, أوبئ
  { {0x69ce0582,0x7d7b0643,0xb866006e,0x249f0b22}},	//   _izbe, ינצו, _باسو, gium_
  { {0x6843008f,0xd7ef0029,0xf09f0144,0xb6a60acc}},	//   _інфа, _شكل_, vià_, _диал
  { {0xa5f70001,0xc2170036,0x2ca90085,0xd250012c}},	//   _међу_, оєю_, znad_, رنج_
  { {0xe3af0086,0x2166005e,0xdb0f00e9,0xf09f0144}},	//   فری_, ітог, _excè, tià_
  { {0x6e3e00d9,0x320a002a,0xb4e6000b,0x27e00b23}},	//   _abpb, źby_, पदी_, žinu_
  { {0xb4c8005d,0x98b3016f,0x5f940063,0x14d70053}},	//   ोगी_, žeća_, дият, _וואל_
  { {0xcd370015,0xc694004c,0xf09f0144,0x6722003d}},	//   يرزب, לאָ_, sià_, iroj
  { {0x66cd002c,0x2d850107,0xb05b0b24,0x2ca90123}},	//   núka, ále_, lläm, tnad_
  { {0xbca5003b,0xe571000a,0x67220b25,0x9f610045}},	//   أمري, עַם_, kroj, ăpân_
  { {0xcb340063,0x50d40015,0x20d40015,0x7de701f3}},	// [e50] метъ, _تزور, _تتوج, _мінд
  { {0x64970045,0x249f0b26,0x20d20030,0xa9c70b27}},	//   rţii, zium_, táig_, осек
  { {0xb05b008c,0xdcef003d,0x645c003d,0x2ca90123}},	//   yläl, ēdēt, ērij, pnad_
  { {0x63ad002e,0x64970045,0x20d20030,0xc4c60058}},	//   _þang, pţii, ráig_, _سْ_
  { {0xae1f005d,0x1798004a,0x20d20030,0x27e90b28}},	//   _बयान_, овцы_, sáig_, žano_
  { {0x7bda0008,0x5b7a0008,0x7c2d0b29,0x4b7a000a}},	//   _לקרו, _הרשא, lgar, _האשו
  { {0x2002005c,0xe918005e,0x6722008c,0x16a60248}},	//   ybki_, _морі_, aroj, явши_
  { {0xddc7002c,0x7c2d0b2a,0x1309005e,0xf9880015}},	//   rejň, ngar, бний_, _بنفي_
  { {0xec790092,0xe5e5002b,0x86c50015,0xf559002b}},	//   _độc_, _فزای, _فيرن, _گلاب_
  { {0xc8790064,0x7c2d0026,0x248d0b2b,0x249f0b2c}},	//   _hoş_, hgar, shem_, sium_
  { {0x6b89002a,0xb05b008c,0xa01b0b2d,0x63ad0b2e}},	//   _żegl, lmäy, rkön, _žand
  { {0x628a0014,0x2eb6005d,0x2eb4000b,0x9234004c}},	//   _elfo, ृत्त, ंक्त, _אַקט_
  { {0x44f10b2f,0x1eaa0015,0x442d0061,0x6d5e0085}},	//   _há_, ماسي_, mge_, _srpa
  { {0x12fa0008,0x442d0b30,0xa01b0030,0x44f10b31}},	//   _ההסב, lge_, lköl, _ká_
  { {0x44f10b32,0x52740067,0x442d0b33,0x42520058}},	//   _já_, _تانز, oge_, _سنير
  { {0x768f003c,0x201e0007,0x7c2d0b34,0x64490b35}},	//   _høyd, ėtis_, ggar, neei
  { {0x20d2002d,0xbae60029,0x44f10b36,0x442d0b37}},	// [e60] ráid_, سكاي, _lá_, ige_
  { {0x20d2002d,0x78ab0091,0x7c2d0b38,0x6d5e013f}},	//   sáid_, engv, agar, _trpa
  { {0xc8790064,0xc4cb005d,0xb90a0010,0x44f10b39}},	//   _boş_, ाताओ, ёндз_, _ná_
  { {0xc8790011,0xa01b0400,0x67220b3a,0x26c7035f}},	//   _coş_, lhör, troj, elno_
  { {0x27e0022d,0xf0930053,0x6d5c00dd,0x38cb0086}},	//   äin_, ענד_, lvra, حالی_
  { {0xab5b0030,0xa96a0719,0x44f10b3b,0x67220b3c}},	//   _ezüs, _лига_, _bá_, rroj
  { {0x44f10b3d,0x6d5c016b,0xa4f8002b,0x9c83036d}},	//   _cá_, nvra, زکار_, ščev
  { {0x44f10b3e,0x26c702c6,0x442d0b3f,0x64490012}},	//   _dá_, alno_, gge_, geei
  { {0x684302db,0x78a20b40,0x0000006a,0x0000006a}},	//   _янта, miov,   ,
  { {0x44f10b41,0x4b7b0053,0x442d0b42,0x46a30185}},	//   _fá_, צטיג, age_, _заув
  { {0x44f1002f,0x3a37000a,0x7c2d0b43,0x04460b44}},	//   _gá_, הרים_, ygar, _нежн
  { {0x66cd002c,0xa01b08e9,0x84960015,0x232a0b45}},	//   núkn, ehör, _عجائ, _годи_
  { {0x4abe014e,0xaabe005d,0xa01b0012,0xb05b04f8}},	//   ्ताव, ्ताक, fhör, lläk
  { {0x2ee500b8,0x68fc0b46,0xddc50046,0x1df8055f}},	//   ölf_, _otrd, _zahř, зеры_
  { {0xdb1d0089,0xd23b0008,0x44f10092,0x291c0b47}},	//   _vysí, _הגול, _xá_, ával_
  { {0x5d540010,0x718b000a,0xd1380b48,0x7c2d0b49}},	//   экст, _לְחַ, mtą_, ugar
  { {0x64970011,0x768f003c,0xdd31002a,0x1f150033}},	// [e70] cţiu, _høye, lęże, _ўмоў
  { {0x6ce70036,0x1eea002b,0xd1380091,0x7bc60091}},	//   _німе, _گویی_, otą_, _dyku
  { {0xd13800df,0x7bc6002e,0xa01b008c,0x442d0b4a}},	//   ntą_, _eyku, hköm, yge_
  { {0xd13800df,0x99d40015,0xe9d00015,0xc8640054}},	//   itą_, رتلا, اغك_, етљи
  { {0x2d8300df,0xb8f4005d,0x44f10b4b,0xf7730021}},	//   lyje_, _सी_, _sá_, عاص_
  { {0xd1380007,0xf62b005e,0x80c9000b,0xb05b008c}},	//   ktą_, сіди_, रतुं, rmäy
  { {0x442d0b4c,0x2d830007,0xa01b0030,0xe610006e}},	//   tge_, nyje_, tköl, اشه_
  { {0x44f10b4d,0x78a20227,0x05760015,0x336502a7}},	//   _vá_, ciov, ظمية_, двиг
  { {0x644900da,0xd138002a,0xa01b0b4e,0xafdb04d1}},	//   reei, etą_, rköl, nfød
  { {0x44f1017e,0x46150086,0xe2990036,0x6d450b4f}},	//   _tá_, _آوار, іан_, _opha
  { {0x672b002e,0x442d00c0,0xe507002b,0xd1380091}},	//   lugj, pge_, _رباي, gtą_
  { {0xa06a0001,0x7afd0020,0x55ba000a,0xd5140015}},	//   цама_, _otst, _ומעו, _أبلغ
  { {0xd1380b48,0x883a000a,0x6d450b50,0x6fde0065}},	//   atą_, חתרו, _apha, _नृशं
  { {0xdd920086,0xdea2002b,0x64970045,0xdbc7001a}},	//   پور_, ئیدی, rţiu, _röði
  { {0x6d4e0111,0x2d830007,0x7afd02fd,0x32050b51}},	//   uwba, gyje_, _atst, mbly_
  { {0x6d5c00c0,0x69da001c,0x64970011,0x6c55005e}},	//   rvra, _útei, pţiu, нтує
  { {0xa01b00c0,0xab5b00dc,0x76410034,0x7ae70079}},	// [e80] phör, _szür, _obly, _bijt
  { {0xf1d1000b,0xdddc00bc,0x6d5c0547,0x7aef0b52}},	//   _हरान, akrš, pvra, _duct
  { {0xceb300b2,0x994a0115,0x7bc6002a,0x6abe0012}},	//   _ביז_, تلال_, _wyku, ropf
  { {0x5ca60342,0x6abe0012,0xcb6a096d,0x0000006a}},	//   _цимб, sopf, _даме_,
  { {0x9b03006b,0xd138002a,0x0665002b,0x7bc60061}},	//   _изяд, ztą_, کانپ, _uyku
  { {0xd1380870,0x2f97000a,0xa926012e,0x3e74006f}},	//   ytą_, וכנן_, _одгл, _päty_
  { {0x68fc00bc,0x764a0034,0x98a602c4,0x2a57000a}},	//   _utrd, refy, _живе, _קבלן_
  { {0x764a0026,0x399b000a,0x93780a32,0x7ae70546}},	//   sefy, _וילד, збит_, _zijt
  { {0xa2260086,0xb05b0123,0xf3f5002b,0xdd31002a}},	//   ورده, släk, رتيک, węże
  { {0x60c40007,0x3254017f,0xa01b0012,0xdd31002a}},	//   _akim, хвор, rköm, tęże
  { {0x60f80127,0xd1380091,0xd1300015,0xa3ba000b}},	//   яння_, utą_, دمج_, _आँक_
  { {0xd1380b53,0x60d60026,0x2d830007,0x320500da}},	//   rtą_, _chym, vyje_, ably_
  { {0xd1380b54,0x64970045,0x6d450b55,0x93930058}},	//   stą_, rţit, _spha, _لجوا
  { {0x2d830007,0x9325002b,0x61560015,0xd1380091}},	//   tyje_, _سرهن, _ينشئ, ptą_
  { {0x72330021,0xdd950033,0x7ae70079,0x64970045}},	//   _شروط, хавы, _rijt, mţir
  { {0xbf350036,0x2d830007,0xa01b0012,0x64970045}},	//   _знищ, ryje_, chöp, lţir
  { {0xa01b008c,0x7ebf0046,0x3ea30079,0xac18005e}},	// [e90] hkök, tápě, pijt_, ьоту_
  { {0x2d8300df,0xd337000a,0x0ab8002b,0x64970045}},	//   pyje_, ורמה_, وطلب_, nţir
  { {0xb05b008c,0xf770009a,0x0000006a,0x0000006a}},	//   eläi, یاه_,   ,
  { {0xc87901e2,0x3cfe00dc,0x386902c1,0x69c701b2}},	//   _kişi_, ítve_, ñar_, _vyje
  { {0xfc3f0014,0x69c7005c,0xf74b0029,0x7afd0b56}},	//   _amíg_, _wyje, تجاه_, _utst
  { {0xaa4500f2,0x055501b7,0xe9190033,0x62880079}},	//   ävää_, етия, _ногі_, jkdo
  { {0xafdb00cb,0xaabe0065,0x0000006a,0x0000006a}},	//   rdøy, ्तरक,   ,
  { {0xa3ba000b,0x1309005e,0x7d1a001a,0xf992000a}},	//   _आँख_, пний_, átsi, _ערן_
  { {0x27ed0b57,0x60d60b58,0xe7300015,0xa2e50b59}},	//   _igen_, _rhym, _نصل_, ноид
  { {0xe3b60010,0x41050296,0x60c40b5a,0xc56b0058}},	//   эбы_, нзов, _skim, _وحال_
  { {0x68e90050,0x32050b5b,0xd8d9000a,0x21690b5c}},	//   _kied, rbly_, ּקָר, чини_
  { {0x037b0086,0x62880b5d,0x397a004f,0x43950138}},	//   _وحشت_, akdo, לטתנ, _паес
  { {0xb3870029,0x64970045,0x68e90b5e,0x130401f3}},	//   _تجاه, bţir, _mied, _азім
  { {0x523900b2,0x02440015,0xc8790061,0x443f0b5f}},	//   _זײַנ, _لَهَ, _dişi_, lfu_
  { {0x7bcb00b8,0x27ed0111,0xd1bb0015,0x64590b60}},	//   ügun, _ogen_, _باشا_, _kawi
  { {0x63a40007,0x68e90b61,0x60c4003f,0x645b0b62}},	//   _žini, _nied, _ukim, ndui
  { {0x6d4101e2,0x64590b63,0x0b460033,0x645b008c}},	// [ea0] çlar, _mawi, энан, idui
  { {0x6b96002a,0x27ed0b64,0x64590b65,0xaf49009a}},	//   rzyg, _agen_, _lawi, _آشيل_
  { {0x68e90b66,0x905a000a,0x9c8307c4,0x35c4000b}},	//   _bied, ּכְת, ščav, _लुढ़
  { {0x64590050,0x7e7e0b67,0x645b080b,0xacfb004f}},	//   _nawi, _hopp, jdui, _מהטכ
  { {0x17540080,0xc017000a,0x7e7e0b68,0x68e90b69}},	//   твля, תקנו_, _kopp, _died
  { {0xcfb7004c,0x66e3005e,0x27ed0a3a,0xb865009a}},	//   עלסי_, гоча, _egen_, _یاقو
  { {0x443f0026,0x6c9a000a,0x6abe000b,0x75d3002b}},	//   ffu_, ּשִׂ, ्तीर, هيها
  { {0x7e7e022d,0xd4970080,0x44f3002b,0x20120061}},	//   _lopp, ерь_, دسوز, _neyi_
  { {0x82a60256,0x68e30161,0x7e7e008c,0x64590b6a}},	//   ешне, ïnde, _oopp, _dawi
  { {0x87170008,0x68e90024,0xdbc70020,0xcb370008}},	//   _נקבע_, _zied, _tööi, עניק_
  { {0xc5690029,0x64970045,0x61ee0091,0xb373002b}},	//   _يحمل_, rţir, žblo, ندیش
  { {0x645900b6,0xa98b000a,0x0000006a,0x0000006a}},	//   _gawi, לָכִ,   ,
  { {0x547b000a,0xdfd8006b,0x389b000a,0x6d580085}},	//   _מטאו, еър_, ליטנ, _švap
  { {0xa6e700a7,0x64590050,0x7e7e052a,0xd5a600e6}},	//   _nhữ, _zawi, _copp, لف_
  { {0x765a00df,0x20d2002d,0xa01b00f2,0xe611000a}},	//   _maty, máin_, hköi, יִן_
  { {0x6ca40256,0x765a0b6b,0x27e90b6c,0xd6d9002a}},	//   груж, _laty, žani_, _ppłk_
  { {0x5a3505b3,0x6008000a,0xfaf3012c,0x7a4b004a}},	// [eb0] кнат, _אִתְ, اثر_, зяев_
  { {0x765a005c,0x20d2002d,0x645b0011,0x68e90b6d}},	//   _naty, náin_, zdui, _sied
  { {0xfe9c0008,0x768f003c,0x58390010,0x68e90b6e}},	//   _מיזמ, _nøya, дзея_, _pied
  { {0x20d2002f,0x9d1a000a,0x26c500bf,0xe7310015}},	//   háin_, _קורט, _sklo_, لصت_
  { {0xed590024,0x20d9002d,0x68e90b6f,0x1834002b}},	//   āžu_, méid_, _vied, ارمح
  { {0x945d0050,0x68e90b70,0x64590b71,0xf6510015}},	//   końc, _wied, _sawi, شئت_
  { {0x68e90945,0xe1f10086,0xc6680010,0x25f2000b}},	//   _tied, یسد_, эшце_, ुड़ी_
  { {0x929d005c,0xb8f5000b,0xd5ae0015,0x27ed02de}},	//   dpła, हत_, تفى_, _ugen_
  { {0x660c00dc,0x645b0b72,0xec68000a,0xb05b0012}},	//   élkü, rdui, ת֑וֹ_, nläu
  { {0x2362002e,0x387f0556,0x20d9002d,0xf7480015}},	//   ækja_, _hour_, héid_, _سلمي_
  { {0xb05b0012,0x273b0034,0xfa6f02a3,0x645902f2}},	//   hläu, lên_, рмiн_, _tawi
  { {0x387f038d,0x7e0a000b,0x25fd000b,0x7e7e0b73}},	//   _jour_, वर्ग_, रुरी_, _sopp
  { {0xa4d40191,0x08760053,0x929d002a,0x0478002b}},	//   _соці, דערט_, apła, _سلوک_
  { {0x273b0023,0x9f9e001c,0xe0df02b9,0xa3b80058}},	//   iên_, _ação_, amò_, _ثامر_
  { {0x71640029,0xd0aa0015,0x2d8c006f,0xdca60099}},	//   _مايك, _يطعن_, áde_, вави
  { {0xeaed005d,0xa0c60021,0xed570004,0x0000006a}},	//   जदूत_, _جيبو, њот_,
  { {0xf41200b2,0x2d980030,0xb05b0012,0x7e7e0b74}},	// [ec0] יפן_, szre_, gläu, _topp
  { {0xbab30015,0x64950125,0xdab90033,0x7e7e00cb}},	//   لمقب, _fáig, ныхі_, _uopp
  { {0xceb90046,0x765a002a,0x6495013f,0x0000006a}},	//   éře_, _raty, _káid,
  { {0x387f0152,0x2db7000a,0x4bd60033,0xb17a004c}},	//   _cour_, _ילין_, _аўгу, וטער
  { {0x69d50014,0x929d005c,0x765a0007,0x97c30b75}},	//   _ezze, zpła, _paty, айце
  { {0xba1a0086,0x6f020064,0xa6340036,0x6495002d}},	//   _زيرا_, _çocu, ункі, _láid
  { {0x387f003e,0x64b30011,0x69c300dc,0xfaa30b76}},	//   _four_, răin, ünet, _таро
  { {0x765a002a,0xa01b0030,0xc7b90030,0xa29f000b}},	//   _waty, lköv, _időn_, गोस्
  { {0xd2500029,0x20d2002d,0x4307004a,0x6ac7001a}},	//   منة_, táin_, кхэм_, _örfá
  { {0xa01b00c0,0xe3af0029,0x7bdb000a,0x51860033}},	//   nköv, ترى_, וקפו, вума
  { {0x63ad002e,0x387f0b77,0xd25704f7,0xa697000a}},	//   _þann, _your_, тцы_, _שכבה_
  { {0x63a400df,0x20d2002f,0x2ebd005d,0x945d002a}},	//   _žinu, sáin_, ोत्त, rońc
  { {0xa0a40010,0x20d20b78,0xb376002b,0x9098006b}},	//   раўд, máil_, _جداش, твят_
  { {0x6fe90024,0x2fcd005c,0x945d002a,0x661800bc}},	//   _rīcī, żego_, pońc, navk
  { {0x929d002a,0xfcc70054,0xac9505ab,0x9c8304b2}},	//   jsły, вљам, гавш, áčov
  { {0x273b00a7,0x3cfe00dc,0x7059000d,0x20d2002d}},	//   yên_, ítva_, _чаир_, náil_
  { {0x20190b79,0x8bd50033,0x308400c3,0x1af40681}},	// [ed0] masi_, ужац, _خليف, иптя
  { {0x20d2002f,0x7e550191,0x69070010,0x3ea700dc}},	//   háil_, _своє, вядз, _önt_
  { {0x387f0b7a,0x20d9002f,0x661804af,0x69c80293}},	//   _pour_, péid_, davk, _ødel
  { {0xdb1d00f2,0x05b6005d,0x5c04006b,0x47d50015}},	//   _pysä, _अख़ब, _вяра, هيار
  { {0xfeb80086,0x7ac70010,0xb05b00f2,0x9cd60b7b}},	//   _سایت_, _асве, lläs, _תורה_
  { {0x2ca90b7c,0x273b0023,0x44f80b7d,0x78a20b7e}},	//   liad_, rên_, _bé_, ďova
  { {0x44f8002f,0x88830086,0x5e560053,0xa3f50010}},	//   _cé_, _پیشن, טיװע_, ляпш
  { {0x2366010b,0x2ca90176,0x20d2002f,0x20190b7f}},	//   _broj_, niad_, gáil_, jasi_
  { {0x20190523,0x69da0b80,0xb05b0012,0xf4840054}},	//   dasi_, _úter, hläs, рујн
  { {0x2ca90026,0x85a70054,0x20190045,0x44f80b81}},	//   hiad_, _ијед, easi_, _fé_
  { {0x20190b82,0xe4d6002b,0xb05b008c,0xe4350021}},	//   fasi_, ضویت_, ylät, _مفاد
  { {0x20d2002f,0x20190b83,0xa988000a,0x94050015}},	//   cáil_, gasi_, דָשִ, _صوته
  { {0x2ca90176,0x3245030e,0x248d0046,0xa856000a}},	//   diad_, _белг, mkem_, נישה_
  { {0xed5a0124,0x248d0089,0xc7d60008,0xf207007a}},	//   ног_, lkem_, טורי_, _рядо
  { {0x2ca90176,0x6495002d,0xddc50061,0x44f80016}},	//   fiad_, _táid, _vahş, _xé_
  { {0x2ca90b84,0x6abe005d,0x1bea09dd,0x248d0b85}},	//   giad_, ्त्र, едби_, nkem_
  { {0xb2f60053,0xab66054f,0xb05b0123,0xceb60021}},	// [ee0] ָצעס_, ывал, rlät, _محدث
  { {0x248d0005,0xb8650086,0xdde400dc,0x3958003d}},	//   hkem_, یانو, űrűs, _psrs_
  { {0x2ca90026,0xb05b00d5,0x1ea9002b,0x248d0030}},	//   biad_, plät, _جايي_, kkem_
  { {0x98c50010,0x76430026,0x2ca90026,0x44f80b86}},	//   асіл, efny, ciad_, _ré_
  { {0x44f80b87,0x248d0089,0xdc9b0053,0x66180b88}},	//   _sé_, dkem_, _טיטל, tavk
  { {0xbb430001,0x4ab8000b,0xfaa60054,0x39580091}},	//   _ћерк, _आदिव, _саго, _tsrs_
  { {0x20d2002f,0x20190064,0xb82a005e,0x2b400b89}},	//   táil_, yasi_, _повз_, ltic_
  { {0x2b400a1c,0x7c360034,0x15f0000b,0x44f80b8a}},	//   otic_, ngyr, _चलकर_, _vé_
  { {0xb05b018b,0x20d2002d,0x36360225,0x2b400b8b}},	//   klär, ráil_, _مراس, ntic_
  { {0x20d2002d,0x44f80b8c,0x171b000a,0x86ea0015}},	//   sáil_, _té_, _נובע, _أعرف_
  { {0x32630010,0x20d2002d,0xd01100e6,0x1a9b004c}},	//   стыв, páil_, يلد_, גייע
  { {0x68e20b8d,0x6f1d0b8e,0x4035004a,0x248d0b85}},	//   nmod, tssc, шемс, ckem_
  { {0x6f1d00b8,0x20190b8f,0xb4c0000b,0x03a309c3}},	//   ussc, rasi_, ंकी_, _лицо
  { {0x256301e2,0x3eaa00b8,0x2ca90b90,0x20190b91}},	//   _yıl_, gibt_, wiad_, sasi_
  { {0x2ca90176,0x6f040b92,0x01fb00a3,0x69ce0b93}},	//   tiad_, _etic, _אפול, _nybe
  { {0xb05b00b8,0xd138005c,0xa01b0030,0x94040065}},	//   rläs, rząd_, gköt, रडिच_
  { {0x2ca90176,0xfbd00029,0xda150054,0xbae50015}},	// [ef0] riad_, كتك_, идањ, لكري
  { {0x2ca90026,0x8f9c0053,0x69ce0b94,0x248d0046}},	//   siad_, _ריזי, _bybe, zkem_
  { {0xb9b50029,0x4fb4002b,0x6e95002b,0x2b400b95}},	//   جماع, _نصیر, _ملکا, atic_
  { {0x5d7a004c,0x69ce0013,0xdd7a000a,0x7648002a}},	//   _סארק, _dybe, _סטרל, _abdy
  { {0xdc3600b2,0x6568003f,0x8c1a000a,0x248d0046}},	//   _דארט_, _ardh, _בורי, vkem_
  { {0x83fd00dc,0xab660024,0x68e203df,0xe5710015}},	//   zdőd, _daļē, amod, قطب_
  { {0x291c0089,0xd61800e6,0x248d0b96,0x98070033}},	//   ávat_, اتها_, tkem_, _бязд
  { {0x06b10046,0x03250b97,0xc4850888,0xc3250b98}},	//   _řídí_, адин, рлик, амик
  { {0x67d40036,0xd299005e,0x58040015,0x42550015}},	//   _готу, втні_, _طولك, لنظر
  { {0x78ab0b99,0x248d0b9a,0xb3c60b9b,0xc2420248}},	//   ligv, skem_, рльз_, оньк
  { {0xe0da0b9c,0x3941003e,0xca36000a,0x6f040b9d}},	//   кво_, nths_, בנתה_, _stic
  { {0x6f04044c,0xd3710015,0x78ab0079,0x2d8a0091}},	//   _ptic, _وها_, nigv, vybe_
  { {0xa8560008,0x7d05002d,0x5ea60029,0x6fd6005e}},	//   בירה_, _aths, لمحل, рінц
  { {0x539a009d,0x1167002b,0x4175006e,0x91e50189}},	//   _בינו, _ملتی_, _نابس, _коле
  { {0xcce60015,0xa283002b,0x26c702b9,0x68e20034}},	//   لسري, _نیکو, iono_, ymod
  { {0x91ba000a,0x62830b9e,0x26c70034,0x768f00cb}},	//   _במצי, _hono, hono_, _søyl
  { {0x6f04016f,0x26c7003f,0x7ed605d1,0x0c370015}},	// [f00] _utic, kono_, _вінч, شكلة_
  { {0xf9920115,0xb05b00f2,0x26c70b9f,0x62830ba0}},	//   يبا_, lläp, jono_, _jono
  { {0x20d9001c,0x26c70ba1,0x2b400ba2,0x6d400045}},	//   léia_, dono_, stic_, ămas
  { {0x69ce04af,0x2a61002d,0xfc320015,0x2b400ba3}},	//   _vybe, adhb_, _بحد_, ptic_
  { {0x47330036,0x91fc003d,0xe7370190,0x39410ba4}},	//   жніс, ndāc, иец_, aths_
  { {0x628302d7,0x454a005e,0xfaa60054,0xa01b0012}},	//   _nono, вчим_, _ђаво, nkör
  { {0x94aa0015,0xa01b0400,0xd5af0040,0xa3e30065}},	//   َابِ_, ljöe, وفه_, फेस_
  { {0xd5b10092,0xd70603ad,0xc977000a,0xb4c0000b}},	//   _séc_, _взаи, _דגלי_, ंके_
  { {0xa2c2014e,0xf7490074,0x389b000f,0xdc8b000a}},	//   रकल्, _مجله_, _סימנ, דְיָ
  { {0x62830ba5,0x20d9016e,0x92b30015,0x26c70ba6}},	//   _cono, déia_, ْحَا, cono_
  { {0x09f7013a,0x99f70008,0xd138005c,0xfad7000a}},	//   ימים_, יזיה_, dząc_, שויך_
  { {0x75d30074,0xdcee0007,0xe53b000a,0xb97b000a}},	//   _بيما, mybė, _יתבר, דנטי
  { {0xd36f0015,0xdcee0091,0x33930015,0x24b7000a}},	//   _يهم_, lybė, _ولمز, _דהאן_
  { {0x7dc70029,0x8027002b,0x62830ba7,0xddb70015}},	//   لتأك, درگم, _gono, لحزب
  { {0x6ca70210,0x44260820,0x127b004c,0xdcee0091}},	//   араж, _kdo_, _באגע, nybė
  { {0x1bf50010,0x26c70ba8,0x30150004,0x62830ba9}},	//   спаў, zono_, _удир, _zono
  { {0x26c700e8,0x7de000dc,0xaa070015,0x9be7005e}},	// [f10] yono_, tásé, لظاه, рівк
  { {0xdcee0007,0xd138005c,0x9967072d,0x539b000a}},	//   kybė, cząc_, ител, דימו
  { {0xd36604b6,0x161a005d,0x26c704ed,0x29c80029}},	//   _که_, _नज़र_, vono_, لِكَ_
  { {0x39410baa,0xa177000a,0xb4c0000b,0x26c701d7}},	//   rths_, יעבד_, ंको_, wono_
  { {0xcc760008,0xf74900c3,0x7c480030,0xc7b90030}},	//   _הערה_, التي_, éprő, _idők_
  { {0x1af60b7b,0x2bb4000b,0x394100da,0x24510016}},	//   _למשל_, ंपरा, pths_, _ạm_
  { {0x4518008f,0x26c702d7,0xb9950029,0x99850029}},	//   ацыя_, rono_, _الأب, _الزو
  { {0x629a022d,0xe5700086,0xa8a406b4,0x2db80008}},	//   ehto, بطه_, _друк, ילון_
  { {0x26c70bab,0x0219005e,0x1306004a,0xf7940033}},	//   pono_, лінь_, бный_, _датэ
  { {0xafdb01f0,0x02450015,0x7bc8000a,0x629a0bac}},	//   rføl, حَدَ, יֶתֶ, ghto
  { {0xb5a707de,0x1c17000b,0xa2020033,0x3a36000a}},	//   _трай, तराल_, япэд, זרתם_
  { {0x656e002f,0x160b014e,0xafdb0bad,0x628300e8}},	//   _ábha, _स्तर_, pføl, _wono
  { {0xafdb00fb,0xdee60036,0xa856000a,0xa01b0bae}},	//   lføj, йоми, זירה_, tkör
  { {0x20d9001c,0xde030758,0x78bb03e6,0xb05b0b1f}},	//   réia_, зпри, _ljuv, släp
  { {0x69a7005d,0xd138005c,0x753c00b8,0x7c960baf}},	//   _टेली, rząc_, _ärzt, брац
  { {0x20d9001c,0xd138005c,0xa01b0bb0,0xa5c3002a}},	//   péia_, sząc_, skör, ciół
  { {0xc9f6003b,0xa01b0030,0x6097009a,0x0000006a}},	// [f20] مساع, pkör, _دنيس_,
  { {0x7810005d,0xe810005d,0x4b23005e,0x9b930015}},	//   ार्क_, ार्थ_, ямув, ألكت
  { {0x6b8d02f2,0xe9da0054,0x186a0bb1,0x0000006a}},	//   ayag, ћке_, лажи_,
  { {0x38cb0086,0xdcee0007,0xe81a0002,0x87260015}},	//   هانی_, vybė, ازات_, معتم
  { {0xb8650040,0x07ba0058,0x0000006a,0x0000006a}},	//   تالو, دهشة_,   ,
  { {0xa01b022d,0xdcee0007,0x17530033,0xd6270054}},	//   hköp, tybė, явія, боље_
  { {0xd639005e,0xa01b02dc,0xdcfc0073,0x0000006a}},	//   рячі_, kköp, tyrę,
  { {0x9d1b000a,0xa4d80004,0x6f16002a,0xad1b000a}},	//   אוקט, јдиу_, _owyc, אוקר
  { {0xc3270029,0x649c002d,0xb8de005d,0xd6d20002}},	//   مكين_, _léig, ीक_, _فقر_
  { {0x3218002c,0xddc5002c,0x2002002a,0x60cd0bb2}},	//   úry_, _zahŕ, ecki_, _skam
  { {0xa0550036,0x7a7b015b,0x4a7b000a,0x6722003d}},	//   овні, אריס, אריב, lsoj
  { {0x557700b2,0x661a0356,0xf1a30174,0xd0110015}},	//   _לעבן_, _hetk, ярын, بلح_
  { {0x7e2b0010,0xbfab018f,0x9f60001a,0xbf9b00aa}},	//   ліва_, утне_, ýrðu_, ebêr
  { {0xd3570008,0x768f00cb,0x2002002a,0x0dcb09dd}},	//   _לידי_, _røyk, acki_, губи_
  { {0x321e0bb3,0xc2ed0046,0xdd940033,0x661a0bb4}},	//   maty_, řící, пары, _metk
  { {0x7b15006b,0x6fb50015,0xf1bf0046,0x67220bb5}},	//   ждах, _ومثا, ášek_, ksoj
  { {0x6f160026,0xfbd300e5,0x6d5e0bb6,0xd5b10016}},	// [f30] _gwyc, ستر_, _espa, _nén_
  { {0x661a0bb7,0x321e002a,0x7d5500fd,0x24860158}},	//   _netk, naty_, _двох, _loom_
  { {0x6f16005c,0x7e99002b,0x3a840033,0xf96b0033}},	//   _zwyc, _منکر_, чытв, ырай_
  { {0xd7d50001,0x2907003d,0xe3c70091,0x7c87011e}},	//   ожењ, īna_, ūčių_, _ѓуне
  { {0x69dc00dc,0x69cb00b8,0xf1cf000b,0x321e002a}},	//   _ezre, ßgeb, _सुनन, katy_
  { {0xda7b0010,0xe611002b,0x321e0046,0x64950125}},	//   _сям_, ذشت_, jaty_, _cáin
  { {0x7d02002c,0xc909000a,0x2002002a,0x46180033}},	//   _čosk, _כִּ֛, ycki_, сціў_
  { {0xcd980008,0x76b2002a,0x6d410061,0x1305007e}},	//   מדות_, głyb, çlay, озим
  { {0xdc8c000a,0x24860bb8,0x0000006a,0x0000006a}},	//   רְוָ, _doom_,   ,
  { {0x52a90bb9,0x321e0bba,0x31250bbb,0x443d0bbc}},	//   рвом_, gaty_, одог, _wcw_
  { {0x6f16005c,0xdb06001a,0x85040058,0xd5bb011e}},	//   _swyc, _ómög, _فولن, _сса_
  { {0x649c002d,0x493a0135,0x43750015,0x661a0bbd}},	//   _réig, סגרו, _وهار, _zetk
  { {0x661a01e2,0xd5b10092,0x2bd5000b,0x8f99006b}},	//   _yetk, _kéo_, _दरगा, бърт_
  { {0x21690bbe,0xdc12000b,0xddde0045,0xfc3f0144}},	//   _вики_, ़र्ड_, _nopţ, _ací_
  { {0x649c017e,0xed5a0268,0x98c9000b,0x8cb8000b}},	//   _féid, шов_, िकाए, ्कलो
  { {0x1c460010,0x6f16002a,0x64490bbf,0x6c36009a}},	//   ўнам, _twyc, nfei, تفرا
  { {0x6d5e005c,0xf200000b,0x8b26004a,0x4df60033}},	// [f40] _wspa, लुक़_, юдае, _мянт
  { {0x649c002f,0x1ae30bc0,0x0000006a,0x0000006a}},	//   _téig, доум,   ,
  { {0x4c160015,0xa967006b,0x62810045,0x661a0bc1}},	//   _وبحس, жиха_, ijlo, _retk
  { {0x50ca014e,0x661a037f,0x6722008c,0xd8f7005e}},	//   रविष, _setk, tsoj, інії_
  { {0x2486003e,0x67220007,0x4e1e000b,0x6756002b}},	//   _room_, usoj, _बजाई_, تخار
  { {0x6b8b0bc2,0x9614000b,0x99910030,0x76b2002a}},	//   ägge, डरेट_, _edző_, dłyc
  { {0x69dc0024,0x80ca000b,0x64490bc3,0xa5070004}},	//   _uzre, रवाइ, ffei, оеја_
  { {0xe9d70036,0x672d0024,0xb1980092,0xe4ea0015}},	//   _єкт_, šaja, _ngưỡ, جعته_
  { {0xc4450086,0x649c002d,0x76b2005c,0x160b000b}},	//   سیون_, _réid, głyc, _स्वर_
  { {0xfbd3000a,0x85760015,0x68fc0bc4,0xc5760058}},	//   ותח_, _ودائ, _kurd, _وطاع
  { {0xe45a0191,0xdd1c002c,0x321e0bc5,0x76b2002a}},	//   _вже_, yšše, raty_, ałyc
  { {0x23480086,0x68fc0100,0x765800f2,0x6d5c0b90}},	//   _هستی_, _murd, levy, dwra
  { {0x61010048,0x38660bc6,0xff04006b,0xdfdb006b}},	//   _vēla, idor_, дясн, рън_
  { {0xdee70015,0x68fc01f6,0x6298005b,0x6d5c0416}},	//   تأجي, _ourd, _ulvo, fwra
  { {0xbd6809c3,0x6d5c0034,0x764a0034,0x68fc0bc7}},	//   орте_, gwra, iffy, _nurd
  { {0x90c400d7,0x90e7002b,0x859b000a,0xdcb10015}},	//   _обје, _بستن, בשלו, رىء_
  { {0x1eab0029,0xe0d00086,0x38660bc8,0xdee70015}},	// [f50] _نادي_, _جزو_, ddor_, _وأخي
  { {0x8a370015,0x768f00cb,0x68fc0223,0x321c0046}},	//   تعرض, _høyv, _burd, _jevy_
  { {0xad270074,0x64490176,0xe9f80036,0xa9070086}},	//   _برخو, yfei, інці_, زبان
  { {0x68fc01e2,0xe8f802e5,0x6495002d,0x18a4005e}},	//   _durd, ілі_, _cáil, маєм
  { {0x0c240010,0xcb440797,0x2d9100da,0x87040015}},	//   _імён, _охри, lyze_, وبول
  { {0x8afa0008,0x6d47007c,0x20d20030,0x24670016}},	//   _להשי, otja, láit_, _ốm_
  { {0xceb400b2,0x85570086,0x6495002d,0x6d470446}},	//   ויס_, تیار_, _fáil, ntja
  { {0x6d470251,0x7afd0bc9,0xe4c80015,0x1d0c000a}},	//   itja, _kust, يبين_, סּוּ
  { {0xe3b1003b,0x1306004a,0x42d50033,0x91fc003d}},	//   عرب_, пный_, зіну, rdān
  { {0xe2990124,0xbb76000a,0x76b2002a,0x68fc0061}},	//   сао_, פעתו_, rłyc, _yurd
  { {0x76b2005c,0x20d200dc,0xda48000a,0x41750015}},	//   słyc, káit_, חֲרָ, سادس
  { {0xf992000a,0xf8db000b,0xcea9000a,0x7afd0bca}},	//   גרט_, बतिय, _גי_, _oust
  { {0x7afd00df,0xb4c9000b,0xbf9b016e,0x93fa000a}},	//   _nust, ोती_, scên, _הלני
  { {0xc2c80015,0xf1c6000b,0x649c0125,0x998c006f}},	//   _وبول_, _रुकन, _géib, _čože_
  { {0x7c9602e5,0xe7eb005d,0x6495002d,0xfce60361}},	//   прац, जेता_, _láim, зово
  { {0x249f03af,0x14d5004c,0x7af5003d,0x6d5c0034}},	//   nhum_, פוּל_, _aizt, rwra
  { {0x7af50014,0x7afd0bcb,0x90e50015,0xdca3005e}},	// [f60] _bizt, _cust, _تسون, хати
  { {0x64950125,0x7afd0bcc,0x68fc0bcd,0x3ea600af}},	//   _sáil, _dust, _purd, _хиог
  { {0x8dfb000a,0xb906005e,0x2bac000b,0x5dfb000a}},	//   _להית, їздк, _घेरा, _לפינ
  { {0x68fc0293,0x48a9005e,0xf7460004,0x7afd0bce}},	//   _vurd, отім_, зедо, _fust
  { {0x68fc0bcf,0x7afd0bd0,0x78a300aa,0x38660bd1}},	//   _wurd, _gust, ënva, rdor_
  { {0x35d40080,0xba550063,0xd6270054,0x68fc0bd2}},	//   молё, _отсъ, поље_, _turd
  { {0xd5b00029,0x6495002d,0x7afd059b,0xddc7005c}},	//   ضفة_, _táil, _zust, dejś
  { {0x7de70014,0x957c005c,0xf74600a5,0x2ca002f2}},	//   lésé, _rząd, _небо, nhid_
  { {0xa7860015,0xe77a004f,0x987b004f,0x07a3011e}},	//   _عشرو, _לָ֑ך, _פרמק, _затн
  { {0xcb130008,0x7de700dc,0x079b000a,0x6d47001a}},	//   עלת_, nésé, _הסמל, ytja
  { {0x59be000b,0xdc3f006f,0x3035004a,0x01d80015}},	//   ्थिर, víľk, менё, تودع_
  { {0x64a30010,0x7bc30011,0xf1af0015,0xe4fb000a}},	//   _паха, şnui, اءٌ_, _הפאש
  { {0x74130015,0x7ee7006b,0xfebb002b,0x91fc003d}},	//   _أوها, зцве, ماست_, ldām
  { {0xc7b900dc,0xfd130002,0x6d4707e0,0x7afd0bd3}},	//   _időt_, فجر_, ttja, _rust
  { {0x20d20bd4,0x7de700dc,0x7afd0bd5,0x71f7006e}},	//   táit_, désé, _sust, _عروس_
  { {0x113b0008,0x6d4700dc,0xc1bb000a,0x11430015}},	//   _התהל, rtja, _למוש, _أَيُ
  { {0x69d80064,0x83fd00dc,0x61080046,0x0aeb0015}},	// [f70] üven, zdőo, _děle, مرئي_
  { {0x8f9c000a,0x6f0d0bd6,0xbe150015,0x7de70030}},	//   _ליחי, _itac, _تودع, gésé
  { {0xbbeb002b,0x28c90065,0xe91900ce,0x7afd02ad}},	//   _گردم_, िकलि, іоді_, _wust
  { {0xddc7005c,0x69d5002c,0xddde016f,0x20d20bd7}},	//   zejś, _vyze, _uopš, láir_
  { {0x07080015,0x7afd007c,0x69d5002a,0xf7940138}},	//   كيني_, _uust, _wyze, нацэ
  { {0x20d2002d,0xfbd200a3,0xe5e50015,0x768f00cb}},	//   náir_, _סתם_, وثغي, _nøyt
  { {0x24e90286,0x249f0bd8,0xa5f600af,0x0000006a}},	//   омки_, thum_, мељу_,
  { {0x6495002d,0x9f65002c,0xb4c9000b,0x20d20125}},	//   _táim, _štýl_, ोते_, háir_
  { {0x7d1a00dc,0xe3b10015,0x8235006e,0x249f0bd9}},	//   átsz, ضرة_, وردا, rhum_
  { {0xaabf000b,0x20d2001a,0xe3b6055f,0xd2a90033}},	//   ्विक, jáir_, ьбы_, ікне_
  { {0x61010024,0x6729001a,0x6f0d0bda,0x71a50bdb}},	//   _vēlo, _hvej, _atac, фанз
  { {0x7de70014,0x6442002d,0xf4850086,0x69c30061}},	//   zésé, _gcoi, _تائی, üney
  { {0xe3ae008f,0x10a30956,0x987a004c,0x93240015}},	//   _рб_, тиян, קאשט, _كرون
  { {0x83fd0014,0xc2c40029,0x6f0d002d,0x12fa000a}},	//   zdől, _كيني, _dtac, _והסב
  { {0x768f00cb,0x2ca00125,0x30860015,0x443f0bdc}},	//   _høys, thid_, _يلتف, ogu_
  { {0x443f0bdd,0xe1640015,0x67290077,0x236d006f}},	//   ngu_, _أدوي, _ovej, ovej_
  { {0x7de70014,0x9f44022d,0x0b460010,0x32f6002a}},	// [f80] tésé, ämä_, ьнан, _młyn_
  { {0x8d760086,0x2ca00bde,0x6b8b0123,0x249d0034}},	//   _قاجا, shid_, ägga, _llwm_
  { {0x7de700dc,0x61080089,0x48660063,0x8e7b000a}},	//   résé, _těle, дълб, _וניה
  { {0x7de700dc,0x0000006a,0x0000006a,0x0000006a}},	//   sésé,   ,   ,
  { {0x7c240bdf,0x7de70030,0xa6ca00af,0x0000006a}},	//   mair, pésé, олда_,
  { {0x443f0be0,0x6442002d,0x9f400111,0x7c240be1}},	//   egu_, _scoi, _azië_, lair
  { {0xa01b002e,0xd82600d7,0x5ee9000a,0xa4f8002b}},	//   fjöl, _одви, הַקְ, سکار_
  { {0xddde005c,0x628a0aaf,0xa01b002e,0x7c240be2}},	//   _kapł, _sofo, gjöl, nair
  { {0x63ad0be3,0x68e300d4,0x0000006a,0x0000006a}},	//   _žanr, înde,   ,
  { {0x7c240be4,0x4b7b000a,0x5b7b000a,0x46130015}},	//   hair, קאיו, קריא, _لوكر
  { {0x3a3704dc,0xca370008,0x6f0d0be5,0x60cf0045}},	//   ורים_, וניה_, _stac, tocm
  { {0xe7f5005d,0x10740036,0xa01b0030,0xa19301c6}},	//   ुँचा_, влюю, lköz, таюч
  { {0x23e2005d,0x44240be6,0xddde002a,0x7c240618}},	//   _परिद, mam_, _napł, dair
  { {0x768f06f5,0x44240be7,0x0000006a,0x0000006a}},	//   _høyr, lam_,   ,
  { {0x20d2002e,0xa2cb005d,0x7c240493,0x20c70a21}},	//   ráir_, सकर्, fair, _осиг
  { {0x7c24002f,0x63a40091,0x44240be8,0x64400be9}},	//   gair, _žiny, nam_, ngmi
  { {0xfbd0003b,0xba2b0029,0x7b09006f,0x3b550033}},	// [f90] لتك_, قسام_, _sľub, экар
  { {0x8a140015,0xf2d8000a,0x010a000a,0xdb040003}},	//   نظما, פַּל, ַלְּ, iziè
  { {0x443f0176,0x7c24002d,0xedd50015,0x44240bea}},	//   ygu_, bair, _سيحد, kam_
  { {0xd0f90053,0xdbd9002e,0xbc19000a,0x44240beb}},	//   פּער, _fæði, _מוֹש, jam_
  { {0xe7080040,0xdbd9001a,0x44240bec,0xf3f900d4}},	//   وتون_, _gæði, dam_, neţe_
  { {0xa01b00dc,0x4519085d,0x7f3c0053,0xfb1a000a}},	//   gköz, пция_, קעוו, _מושמ
  { {0xddde005c,0xe576006b,0x76b2002a,0x645b0bed}},	//   _zapł, езщ_, płyn, teui
  { {0xfdf8013a,0x78a20107,0x3552002b,0x443f0bee}},	//   וצות_, chov, انيز, ugu_
  { {0x61010024,0x645b0bef,0x443f0bf0,0x83fd0030}},	//   _vēlm, reui, rgu_, ldők
  { {0x5778003b,0x443f0176,0x44240150,0xf3f90045}},	//   _تصفح_, sgu_, aam_, deţe_
  { {0xe2a80015,0xa06a0788,0x44240bf1,0x0000006a}},	//   باين_, пана_, bam_,
  { {0x2005005c,0x7ff7002b,0x649c0125,0xf3f90045}},	//   ślin_, کسپا, _héin, feţe_
  { {0x9f4c0064,0xa295005e,0x3cf3000b,0xb7bd0045}},	//   _ölüm_, _паді, ंगने_, _feţe
  { {0x78a20107,0xd336000a,0xc1050015,0xa3b80015}},	//   zhov, _נרצה_, _كوتي, _تامر_
  { {0x7c240bf2,0x6b8b00c0,0xc69200a3,0x78a20069}},	//   tair, äggn, נאל_, yhov
  { {0xa01b0014,0x7c24002d,0x649c002d,0x80890015}},	//   zköz, uair, _léin, _يضيف_
  { {0x7c240bf3,0x945d002a,0x69cb0061,0xdb24002b}},	// [fa0] rair, lońs, şgel, ئوئی
  { {0x4a4305b3,0xd00f002b,0x636a0030,0x44240bf4}},	//   лнув, _پلی_, löná, zam_
  { {0xf2960053,0x7c240bf5,0x8296004c,0x89f50033}},	//   עכער_, pair, עדעס_, вяцц
  { {0xafdb01f0,0x442403a6,0xc8d6002b,0x4c83005e}},	//   mfør, xam_, رزاع, _блюв
  { {0xa01b00dc,0xafdb0293,0xe80f000b,0x2bba0015}},	//   tköz, lfør, ाड़ा_, _راحة_
  { {0x78a20bf6,0x44240bf7,0x945d0535,0x0000006a}},	//   shov, wam_, końs,
  { {0xb7bd04f9,0x78a200c0,0xafdb0293,0x44240bf8}},	//   _reţe, phov, nfør, tam_
  { {0x60c401a3,0xf8a7000b,0x945d002a,0x94aa0033}},	//   _njim, _कॄपय, dońs, ятла_
  { {0x64400005,0x73d70063,0x649c002d,0x36c6005e}},	//   rgmi, ндър_, _féin, _збаг
  { {0x9757000a,0xc757000a,0x44240bf9,0x92940054}},	//   _אימו_, _אימץ_, sam_, таоц
  { {0xb1450086,0x5a9b0053,0x1a9b004c,0xf3f90045}},	//   نیوم_, פשטא, פיטע, veţe_
  { {0xafdb0293,0x859b000a,0x0000006a,0x0000006a}},	//   dfør, _משבו,   ,
  { {0x61080089,0x94a90029,0xf3f90045,0x83fd0030}},	//   _děla, _تطلق_, teţe_, zdők
  { {0xd36f0086,0x71260029,0x623404e5,0x2a6a02dc}},	//   _دهه_, _كربل, _реку, _nabb_
  { {0xafdb0bfa,0xf3f90045,0xc173002b,0x41730015}},	//   gfør, reţe_, _مديت, _مايس
  { {0x11db0008,0x61db000a,0x41db000a,0xf3f90045}},	//   _מחוב, _מקוד, _מחוס, seţe_
  { {0x6fb90036,0xcb34006b,0x9abe0033,0x629a0bfb}},	// [fb0] _ігор_, летъ, мiра_, okto
  { {0x213e003e,0x629a0bfc,0xaf340015,0x60dd0bfd}},	//   outh_, nkto, _إريت, llsm
  { {0x649c0152,0x629a0bfe,0x9a880015,0x76b2002a}},	//   _réin, ikto, عَمْ_, głym
  { {0x8934003b,0xb4ca000b,0x99640033,0x4c950555}},	//   اعلا, लको_, ытул, _римс
  { {0x649c002d,0x4804005e,0xa8040033,0x213e0012}},	//   _péin, упів, узіл, huth_
  { {0xd1380007,0xcb36000a,0xf1b2000b,0x38690b28}},	//   krą_, _בנשק_, ुपान, žar_
  { {0x6abf014e,0x569200d7,0xf5320004,0x195808f0}},	//   ्वीर, рајт, аејќ, _пары_
  { {0x629a0bff,0x25ba0125,0xd1380c00,0x98f40021}},	//   ekto, úpla_, drą_, _مثقا
  { {0x03220033,0x20050046,0x03a501eb,0xb8e70065}},	//   адын, ělil_, типо, ैक_
  { {0x649c002d,0xfb38004c,0x945d002a,0x29030573}},	//   _héil, גאזש_, tońs, _kuja_
  { {0x10a60c01,0x2bd8000b,0xd12e0015,0xbbde0065}},	//   винн, _भुना, يمٌ_, _मर्क
  { {0xf8b3000b,0x40960c02,0x09f6004f,0x629a0c03}},	//   ूचिय, трот, כמתם_, akto
  { {0x6f63008f,0xc7b2000a,0xd138002a,0x32f6002a}},	//   авяз, ֹ֑ר_, arą_, _złym_
  { {0x945d005c,0x76430849,0xd138002a,0xafdb00cb}},	//   pońs, ngny, brą_, tfør
  { {0xb05b0012,0x63a90012,0x6287008c,0x925607f9}},	//   unäc, lzen, öjou, _рајт_
  { {0x6fb60029,0x649c002d,0xafdb0293,0x68fb0091}},	//   _لمعا, _néil, rfør, _niud
  { {0x63a90c04,0x4a460004,0xab2709fd,0xf093004f}},	// [fc0] nzen, кнав, кота_, _כנה_
  { {0xafdb06f5,0x2f97000a,0x63a90c05,0xc9f60058}},	//   pfør, _סכין_, izen, نساع
  { {0x68fb00df,0x2903001c,0xda650015,0x8d76002b}},	//   _biud, _cuja_, داقي, _شادا
  { {0x68fb0c06,0x6f04003f,0x7794002b,0x38c8002b}},	//   _ciud, _kuic, هیزا, راضی_
  { {0x6f040c07,0x63a90c08,0xf7430004,0x7c2b001a}},	//   _juic, jzen, иецо, ðgre
  { {0x63a90c09,0xf7930010,0xfbd30008,0xc6f7005e}},	//   dzen, рашэ, _כתר_, вніх_
  { {0x649c002d,0x6d4e0c0a,0x2bd8000b,0xd90d002b}},	//   _féil, ntba, _भँडा, _فیل_
  { {0x68fb04ed,0x649c002d,0x3eb80c0b,0x6d4e0c0c}},	//   _giud, _géil, hirt_, itba
  { {0x44f70029,0x69dc06bb,0x6d4e0c0d,0x7afc0c0e}},	//   خروج_, _hyre, htba, _kirt
  { {0xd1380870,0x61080046,0xd9e6000b,0xfd5f0016}},	//   trą_, _děln, _करात_, guyễ
  { {0x7afc0472,0x9a3b000a,0xf992000a,0x27ff0061}},	//   _mirt, ותיק, ׁר֙_, _ygun_
  { {0x4035008f,0x213e01b3,0x69dc0c0f,0x629a0c10}},	//   ыемс, ruth_, _myre, skto
  { {0x63a90050,0x7afc002d,0xb4be000b,0xdfd8006b}},	//   czen, _oirt, ँची_, вър_
  { {0xf7730008,0xa2930036,0x7174002b,0x7afc01d7}},	//   בקש_, _ваші, _مهتا, _nirt
  { {0x5c07054f,0xf2d3004c,0x6d4e0c11,0xd5d8004f}},	//   вяза, _דעס_, gtba, גַּש
  { {0x672d0048,0xec340036,0x6ca40088,0x3eb80125}},	//   šaji, инсь, аруж, airt_
  { {0x68e90026,0x7afc0ab5,0x99810046,0xda090015}},	// [fd0] _rhed, _birt, tahů_, فيذه_
  { {0x6495002d,0x7e990015,0xdee4023e,0xe0df02b9}},	//   _háit, _أندر_, _коњи, llò_
  { {0x3f990026,0x68e90034,0x7afc0c12,0x2d8c0013}},	//   lysu_, _phed, _dirt, ødet_
  { {0x08d40036,0x91bb000a,0x99810046,0x69dc0c13}},	//   ація, ומבי, sahů_, _dyre
  { {0xab2b0029,0x649c002d,0x61010024,0x64950125}},	//   _تسجل_, _céim, _vēli, _máit
  { {0x6495002f,0x4aa7014e,0xf77003c4,0x8f9c000a}},	//   _láit, _गतिव, غان_, וידי
  { {0x85550015,0x95550067,0x20d904a4,0x6fd50065}},	//   اختط, اختا, néis_, _युसू
  { {0x20050050,0xe89401d9,0xf5560029,0x5dfc000a}},	//   ślij_, _кась, اليب_, ופונ
  { {0x61080089,0xe894004a,0xb3850015,0xf8b2000a}},	//   _bělo, _тать, اجعه, _השן_
  { {0x454504c9,0xed6001c9,0x63a90c14,0x69080030}},	//   _منطق, ážku_, rzen, _ördö
  { {0x63a90c15,0x61080046,0xd6e40033,0x386d01c2}},	//   szen, _dělo, _лiтв, _kaer_
  { {0x71a20010,0x493a004c,0xf8d3000b,0x3eb80012}},	//   саюз, עגרו, तविय, wirt_
  { {0xd12e0086,0x6f040c16,0x889a000a,0x386d0316}},	//   يمی_, _quic, גברי, _maer_
  { {0x386d00dd,0x61450b1e,0x2d980c17,0x6d4e0c18}},	//   _laer_, _бека, tyre_, ttba
  { {0x2d9e0264,0x387f0061,0x2d950174,0x6da30988}},	//   áte_, _onur_, артс, бира
  { {0x6d4e0c19,0x0b1a0015,0x00da0015,0x3f990034}},	//   rtba, فقرة_, _ثبتت_, bysu_
  { {0x30db0053,0x0aea006b,0x2d9e0c1a,0x3cc7006b}},	// [fe0] _אַזע, едай_, šte_, улто_
  { {0x9a6a003b,0x649c0c1b,0x9e660c1c,0x0e660c1d}},	//   عمال_, _réim, _свод, _скон
  { {0xd5b10023,0x7afc0c1e,0x48e60033,0xeef7000a}},	//   _xét_, _virt, гожв, _תמיר_
  { {0x20d9002d,0xad670010,0x7afc0c1f,0x98da002b}},	//   léir_, _саюз_, _wirt, رباز_
  { {0x7c26003d,0xf76f0015,0x7bdd0034,0xec77006b}},	//   _iekr, كاو_, _gysu, _спя_
  { {0x7afc002d,0xe9440086,0x20d9002d,0x96e7005e}},	//   _uirt, _پرسی, néir_, льща_
  { {0x2aa40014,0x6495002d,0x3a090086,0x91fc003d}},	//   _több_, _náis, _شکلی_, ndāt
  { {0xb4be005d,0x297b0053,0xb97b0008,0x397b000a}},	//   ँचे_, _אטלא, _אנלי, _אטלנ
  { {0x5c370053,0x6495002d,0xb8930015,0x46160015}},	//   ארפן_, _ráit, _القع, _موذر
  { {0x59b8005d,0xa5da0029,0x21540033,0x7414002b}},	//   _आधार, _كبار_, акоў, دوکا
  { {0x6e250064,0x7c260234,0xdd120061,0xcad7004f}},	//   _rehb, _oekr, _rüşv, רוית_
  { {0x99f7000a,0x69c3002a,0x7d050061,0x09f7000a}},	//   טזיה_, źneg, _ruhs, טמים_
  { {0xe29a0c20,0x61080046,0x14d7000a,0xe0df02b9}},	//   _пад_, _tělo, _גואל_, rlò_
  { {0x7bdd005c,0x44260016,0x64950c21,0x20d90c22}},	//   _rysu, _heo_, _fáis, téis_
  { {0xc2c30018,0xc534000f,0xd2b7000a,0x02b7000a}},	//   _ديوي, יָּה_, _תלות_, _תהום_
  { {0x6495002d,0x20d90c23,0x317b000a,0x44260085}},	//   _háir, réis_, _טרומ, _jeo_
  { {0xc3340008,0x2bbb0015,0xb6060107,0x2d8c063b}},	// [ff0] יוּ_, رارة_, _zváž, øder_
  { {0x20d90c24,0x44260c25,0x7e55005e,0x49cb0033}},	//   péis_, _leo_, _твоє, нуем_
  { {0xedf30086,0x7bdd005c,0x6495002d,0x4efa000a}},	//   _ديدگ, _wysu, _máir, _שהתו
  { {0xddde0089,0x7c260c26,0x44260c27,0x9d1a004f}},	//   _např, _gekr, _neo_, _שורט
  { {0xd36603ef,0x2ca9002f,0x501c000a,0x97d80a31}},	//   _به_, mhad_, תודו, льшу_
  { {0xca490086,0x3a870010,0x9a870484,0xe7eb000b}},	//   _جلسه_, _сымв, _сумл, जेगा_
  { {0x4426002d,0x1ddb0065,0xaa5800ce,0x35a50138}},	//   _beo_, _मुमत, _щиру_, райг
  { {0xf7950033,0x44260c28,0x2ca90416,0x0000006a}},	//   _кабэ, _ceo_, nhad_,
  { {0x6495002d,0x44260c29,0x7305049d,0xa3160054}},	//   _báir, _deo_, јпоз, ажњу_
  { {0xe2990001,0xd7940029,0xbb3c0053,0x7295006b}},	//   тао_, _الْخ, געזי, рших
  { {0x20c60036,0x067a0053,0x667a0053,0x008609fe}},	//   ийом, _שנעל, _שטעק, ално
  { {0x2c15005d,0xc952000a,0x672d0085,0x44260c2a}},	//   _फ्लू_, חמט_, šaju, _geo_
  { {0x20d9002d,0xe8d6000a,0x5339004c,0x6e3a001a}},	//   téir_, שורר_, _סײַד, ótbo
  { {0x6495002d,0x249f001a,0xe2960c2b,0xddde0046}},	//   _táis, lkum_, _ваш_, _zapř
  { {0x20d9002d,0xb6060264,0xfcb6004a,0x823a004c}},	//   réir_, _uváž, ащаю, _סעקצ
  { {0x248d060b,0x2ca9002d,0xb05b008c,0x7c850054}},	//   njem_, ghad_, nnäl, буђе

  { {0x3b0706ac,0x3a26005e,0x249f0c2c,0xdca3004a}},	// [1000] ието_, имаг, ikum_, цати
  { {0x8eb30015,0xbf9b000a,0x249f0061,0x248d0c2d}},	//   _وميش, _סייש, hkum_, hjem_
  { {0x7c2601e2,0xb4f7005d,0x249f002e,0xbe3b0008}},	//   _tekr, ुदाय_, kkum_, _בעית
  { {0x31560053,0xb17a0053,0x2ca90c2e,0xed570c2f}},	//   ייען_, כטער, chad_, _тою_
  { {0x248d00bd,0x91fc0024,0x7aeb0030,0x96660c30}},	//   djem_, ndār, ülté, икде
  { {0x4426017e,0xe6930002,0x05760015,0xdcfc0091}},	//   _seo_, يلند, لاعد, tyrė
  { {0xda5b000a,0x4426007c,0xfc3f006f,0x0000006a}},	//   _שכלל, _peo_, _ulíc_,
  { {0xd497004a,0x9417006b,0xd37a0c31,0x57160058}},	//   иры_, ажът_, вчо_, _نورذ
  { {0x6495002f,0x68e20034,0xb8dc0157,0x44260c32}},	//   _páir, mlod, ेच_, _veo_
  { {0xd2570036,0x68e20bc8,0x6d5e0c33,0x291a0c34}},	//   ацю_, llod, _oppa, oppa_
  { {0x672d0a00,0xfa77000a,0x64a60c35,0x44260c36}},	//   šajt, בעית_, _кажа, _teo_
  { {0xd83f0107,0xdfa70004,0x04930015,0x55bb000a}},	//   _účtu_, ајго, _وللح, _במבו
  { {0x58f70053,0x34b30029,0x6495002d,0xc43b000a}},	//   ימטע_, _بمنز, _táir, _יתאי
  { {0x539b000a,0x91b7002b,0x3ea50030,0xd5b10016}},	//   _בידו, اطیر_, ólt_, _kép_
  { {0xa2d3005d,0x61430180,0xdcf70015,0xf531000a}},	//   डवर्, _деја, لأرب, ּ֥ל_
  { {0xbd440029,0x76b2005c,0x51fb0008,0x01fb000a}},	//   تنفي, pływ, _בהוצ, _בפול
  { {0x5a350063,0x68e20026,0x2ca90c37,0x90a7002b}},	// [1010] йнат, dlod, rhad_, _محکم
  { {0xda78005f,0x249f0089,0x657a0541,0x68e20c38}},	//   иях_, zkum_, _orth, elod
  { {0xceb200b2,0xd7c9002b,0xe9870054,0x83fd0030}},	//   _זיי_, گوشه_, шћан, ndőr
  { {0x89340015,0x213e00da,0x99840015,0xc7b10015}},	//   زعما, irth_, تلمو, ًّا_
  { {0xe7680029,0x96b90001,0x07080015,0xa09c000a}},	//   لحون_, луку_, ليني_, כיאט
  { {0x68e20024,0x23ca005d,0xaa950015,0xff18000a}},	//   alod, ापनद, _الآث, סקות_
  { {0x248d00bd,0xce380008,0x25a10046,0xd5750c39}},	//   tjem_, באות_, áhl_, суль
  { {0x6495002d,0x250a0086,0x7c2d0c3a,0x7ccc0061}},	//   _cáip, دروی_, naar, oğra
  { {0xf7730074,0x657a0176,0x248d00bd,0x249f002e}},	//   _باز_, _erth, rjem_, rkum_
  { {0x249f0c3b,0xe610002b,0x7c2d0c3c,0x13020138}},	//   skum_, _قشم_, haar, язьм
  { {0x6f160c3d,0x7c2d0c3e,0x63ad002a,0x0000006a}},	//   _styc, kaar, _żand,
  { {0x8464006b,0x14740015,0xd3080016,0x7c2d0c3f}},	//   _мъче, _وانج, _iện_, jaar
  { {0x999100dc,0x442d0c40,0xf456006e,0x26c70c41}},	//   _mező_, mae_, _طلوع_, onno_
  { {0x442d0c42,0xc7d605bd,0xdc20000b,0x64490c43}},	//   lae_, מורי_, बर्ड_, lgei
  { {0xc6920c44,0x70560015,0x6da30c45,0xf1cf000b}},	//   האם_, _هنغا, пира, _सुचन
  { {0xdd8f0040,0xdca6006b,0x64490c46,0x442d0c47}},	//   روق_, щаби, ngei, nae_
  { {0x501b000a,0x7e9a012c,0x2ca00c48,0xbb4a0058}},	// [1020] _גופו, _منظر_, rkid_, طلان_
  { {0x7c2d00b6,0x2ca00c49,0x442d0c4a,0x0000006a}},	//   aaar, skid_, hae_,
  { {0x9e7b00b2,0x38cb0086,0x68e20024,0xbca6002b}},	//   _ענטפ, گالی_, tlod, _همدي
  { {0x6c86003b,0xb05b008c,0xf849005e,0x48e6006b}},	//   _الحم, enäj, ичій_, щоев
  { {0x30db0053,0xddd50089,0x97560054,0x4733005e}},	//   אַגע, dezř, стељ, зніс
  { {0xcd290086,0x7e7a0053,0xa7850029,0xfaa60004}},	//   _حسین_, ראַז, تشمو, _ѓаво
  { {0xb996003b,0x64950125,0x68e20c4b,0xd9430c4c}},	//   _الزب, _páip, plod, _нери
  { {0xe3140001,0x442d00ea,0x26c702b9,0x62830aa0}},	//   омињ, gae_, anno_, _anno
  { {0x213e0176,0x657a0176,0xdc9b0053,0x389b000a}},	//   wrth_, _wrth, טיקל, _עימנ
  { {0x86ea0029,0x78a20264,0x2d780844,0xe6c6002b}},	//   _إعرف_, lkov, _oče_, _اتري
  { {0x290a0005,0x867b0008,0xd4d60010,0x442d0035}},	//   _juba_, _תרבו, _лідэ, bae_
  { {0xa492002b,0x27e9002a,0x290a01d7,0xb97b0643}},	//   _ریخت, żane_, _muba_, אנטי
  { {0x290a0020,0x43940180,0x623400d7,0xb3850015}},	//   _luba_, _фалс, _делу, _وجهه
  { {0x29180467,0x9e140036,0xa01b002e,0x7c2d0161}},	//   _otra_, здрі, gjör, waar
  { {0x61020048,0x7095000d,0xb05b00f2,0x78a20c4d}},	//   _vēlr, _макф, nnäk, kkov
  { {0xf1b3000a,0x78a2055c,0x3c450058,0x2b400c4e}},	//   _מסצ_, jkov, تَرِ, fric_
  { {0x4054003b,0xfe6e0086,0xdfd10029,0xaa070029}},	// [1030] _رئيس, رگی_, _زيد_, مظاه
  { {0x539b0008,0x5a350036,0xff500015,0x2bb80015}},	//   אימו, інет, _أخي_, حافة_
  { {0x6d410bd7,0x98170015,0x290a0c4f,0xdb04006f}},	//   álad, مبشا, _cuba_, rziá
  { {0x6d5500b8,0xec6b03ad,0x2b4000da,0x182b012c}},	//   mtza, _срок_, bric_, اساً_
  { {0x61080046,0x170a002b,0x2058000a,0x6d470c50}},	//   _děli, لفنی_, מיאל_, luja
  { {0xb7c60048,0xcf58000a,0xf655005e,0x0f58015b}},	//   diģē, צבות_, ітлю, ציום_
  { {0x6d4700bd,0x78a201c0,0x64490c51,0x442d0c52}},	//   nuja, bkov, tgei, tae_
  { {0x6e2e00dc,0x94790c53,0x67d5005e,0xf3590054}},	//   zabb, рску_, _добу, ашој_
  { {0x442d0c54,0xc64b00e6,0x52a90809,0x290a0085}},	//   rae_, _مجال_, ивим_, _zuba_
  { {0xadf9000b,0x6d550079,0x6e2e0012,0x2918001a}},	//   ंधान_, ktza, xabb, _ytra_
  { {0x71b50080,0x208a0c55,0x442002e1,0xf6500015}},	//   ющих, айни_, _нi_, _سئل_
  { {0x25d600b2,0xd0060015,0xafdb00cb,0x6d470c56}},	//   _ווען_, توحً, lføy, duja
  { {0xa8560008,0xa01b001a,0x32f6002a,0xc4f8002b}},	//   חירה_, tjör, _płyt_, _اعلا_
  { {0x78a90c57,0x78a20264,0x61130045,0x62830b58}},	//   _llev, zkov, _călc, _unno
  { {0xde030191,0x78a90c58,0x80e60029,0x6d470c59}},	//   дпри, _olev, _وأعل, guja
  { {0x6e2e0c19,0x8b2609ef,0x2b400c5a,0xdd8f0015}},	//   sabb, ждае, tric_, خوف_
  { {0x765c002e,0x6d470007,0x20050089,0xe61f0092}},	// [1040] _öryg, auja, ělit_, _đôn_
  { {0xe822005d,0x61e3001a,0xea87006b,0x8d660c5b}},	//   मर्थ_, _kynl, обул_, _двое
  { {0x78a900fb,0x89160029,0x6abe0177,0xe96a030e}},	//   _blev, زبائ, ripf, раел_
  { {0x814c0053,0x80370053,0x78a90c5c,0x2b4000da}},	//   רעאַ, ַנצע_, _clev, pric_
  { {0x29070084,0x905b000a,0x78a20c5d,0xf873009a}},	//   ínar_, שכנת, rkov, بهنج
  { {0x649c002d,0xeafa0015,0x7b090085,0xeb9f04d1}},	//   _léit, _خرجت_, _džud, _tfør_
  { {0x27ed0014,0xd6390036,0xc8660015,0x186a005e}},	//   _ezen_, сячі_, _وطري, _кави_
  { {0xd91b0008,0xf9b7000a,0x09b7004f,0x9d1b004f}},	//   _כולל, _והלך_, _ופלט_, בוקט
  { {0xccf3000f,0xf366005e,0xe3b20015,0xb05b008c}},	//   וכה_, ітин, برغ_, snäk
  { {0xb7c60024,0x76a60015,0x78a90046,0xc1780091}},	//   riģē, _بحرك, _zlev, tvė_
  { {0x61e30176,0x76b2002a,0x27e40c5e,0x6108002a}},	//   _cynl, słys, _hymn_, _ośle
  { {0x6d4700f2,0xc4c60015,0x26dc0c5f,0xe4650061}},	//   vuja, _بتطو, lovo_, _çöpe_
  { {0x248601d1,0xc4f7000a,0xb05b008c,0xc1780091}},	//   _inom_, _ומאז_, nnäi, svė_
  { {0x6d470c60,0x26dc052c,0x29040c61,0xadbd0033}},	//   tuja, novo_, _lima_, гагi
  { {0xdcbb010f,0x61e30026,0x621b0008,0x361b0053}},	//   аща_, _gynl, _דווק, שולד
  { {0x290400bd,0x6298099c,0x67f500dc,0x5b150c62}},	//   _nima_, _hovo, nüjé, змат
  { {0x63a00264,0xe6bc000b,0x309c000a,0x24860085}},	// [1050] nymn, ्चाङ, _כשהמ, _mnom_
  { {0x93fb000a,0x60dd0c63,0x78a90c64,0x6d470c65}},	//   שלמי, losm, _slev, puja
  { {0xdfd10074,0x89d90029,0x8883002b,0xda080067}},	//   _زيگ_, حوار_, ویسن, زينه_
  { {0xf7710070,0x7d1a00dc,0x6f0d003f,0x60dd0c66}},	//   فات_, ítse, _kuac, nosm
  { {0xf7940010,0x0a6b0001,0x807c0053,0x78a90089}},	//   мацэ, _крви_, ינאצ, _vlev
  { {0xd6db0292,0x26dc02c6,0x62980c67,0xe7360c68}},	//   ште_, govo_, _novo, чеш_
  { {0xa9540036,0x6f0d002d,0xf5920029,0x60dd0c69}},	//   _окрі, _luac, فلوج, kosm
  { {0x442b0092,0xc8c9009a,0x78a9005a,0x20090c6a}},	//   úc_, _اورن_, _ulev, _ngai_
  { {0x6f0d002f,0x649c002d,0x61e30c6b,0xf770006e}},	//   _nuac, _réit, _synl, _لال_
  { {0xf3f904f9,0xd2a9005f,0xc6740015,0x29040c6c}},	//   neţi_, ское_, _يطلب, _zima_
  { {0x1a9c0053,0x21690956,0x62980c6d,0x61130045}},	//   ייזע, щини_, _dovo, _băla
  { {0x85040015,0x95c4002b,0x6f0d0125,0x61130045}},	//   _قولن, _تيمه, _buac, _căla
  { {0x7ea20152,0x61fe0227,0x6446002a,0x09b8000b}},	//   _hôpi, _úpln, ókie, _आध्य
  { {0x52390053,0x62980a00,0xe3b00087,0x63c80029}},	//   _הײַנ, _govo, _جرم_, _بِهِ_
  { {0xf3f904f9,0xb7bd0011,0x91e20883,0x10a6029b}},	//   deţi_, _deţi, _поше, _никн
  { {0x236d005c,0x649c002d,0x113a000a,0x6ab4000b}},	//   owej_, _héir, _התקל, ंफ्र
  { {0x6b630c6e,0x29040c6f,0x6f0d0c70,0x80e80065}},	// [1060] нкта, _rima_, _guac, _टीएओ_
  { {0xf3f904f9,0x645b002f,0x6d41002d,0x0f7b000a}},	//   geţi_, hfui, álac, _פריל
  { {0x7e9b0008,0x0e9b0008,0x5e9b0008,0xfe9b0135}},	//   _הסיו, _השיל, _הביק, _היימ
  { {0x649c002f,0x6f57002b,0xa2bb0065,0x29d30058}},	//   _léir, _بلیز_, षोत्, رينس
  { {0x66e60c71,0xf7170015,0x2cfa000b,0x26dc07d4}},	//   пода, كينغ_, ्दील_, tovo_
  { {0xf3f904f9,0x26dc04ed,0x8f37000a,0x649c0125}},	//   ceţi_, uovo_, לאנו_, _néir
  { {0xb05b007c,0x29040c72,0x26dc0c73,0x0000006a}},	//   snäi, _tima_, rovo_,
  { {0x493b0008,0x7b07002d,0x39570008,0x27e9002a}},	//   _לגלו, _órtá, _משלם_, żana_
  { {0x7d060604,0x62980107,0xf7430076,0x649c0003}},	//   _miks, _povo, _пето, _séis
  { {0x2cfa005d,0x7d060c74,0x0bb7000a,0xdb9b000a}},	//   ्दुल_, _liks, פלים_, מספר
  { {0xb7bd0011,0xf1a301c5,0x81c6004a,0x2a57000a}},	//   _reţi, ерян, ящие, הבין_
  { {0x62980012,0x7d060c75,0x0000006a,0x0000006a}},	//   _wovo, _niks,   ,
  { {0xdfdb0063,0x7c240c76,0x629800bc,0x6f0d0c12}},	//   сън_, dbir, _tovo, _quac
  { {0xd24f003b,0xb2d30029,0xb3e900a2,0xa2d30015}},	//   _منه_, _كينغ, _بعمل_, _كينت
  { {0xa2d9005d,0xf3f90011,0x625b000a,0xeca70004}},	//   नकर्, veţi_, _הכוה, пјан
  { {0xc1050015,0x6f0d0125,0x6108005a,0x2a7f007f}},	//   _توعي, _tuac, _dělt, _şub_
  { {0xf3f90440,0x2d8c0c77,0x1eab0015,0x7d060c78}},	// [1070] teţi_, äder_, _هادي_, _diks
  { {0x6f7a000a,0x7c240c79,0x0dcb0c7a,0x7d060073}},	//   _וְטו, abir, _гуми_, _eiks
  { {0xf3f90011,0xa9070115,0xceeb002b,0x09340015}},	//   reţi_, سبان, _پرکن_, فرنج
  { {0xe9f80036,0xd117000a,0x6ef202de,0x2d9e0072}},	//   їнці_, פקדה_, ræbe, ätee_
  { {0x3b64010f,0xf3f90011,0xe7380010,0xda7b006b}},	//   _първ, peţi_, зеі_, _ляв_
  { {0x644700df,0x4519006b,0xeb92000a,0xcd34009a}},	//   ėjim, оция_, _סָר_, _تریب
  { {0x67240024,0xdb080030,0x45180033,0x0000006a}},	//   ģija, ölöt, пцыя_,
  { {0x03190086,0xc9520008,0x649c0125,0xdddc003d}},	//   يتخت_, _שמן_, _séir, berņ
  { {0x3365005e,0x2d570061,0x649c0125,0x7eb0008c}},	//   євог, hçe_, _péir, _häpe
  { {0x2d570064,0x7c2400bd,0x957c005c,0x236d002a}},	//   kçe_, zbir, _cząs, rwej_
  { {0x90460074,0xda48000a,0xf487008b,0x9419009b}},	//   ونده, הֲרָ, _нудн, _джет_
  { {0xcea900b4,0x25af0061,0xb603006f,0xf992000a}},	//   _די_, ımlı_, _vtáč, דרט_
  { {0x7d0601bf,0x9836004f,0xe2a8009a,0x0000006a}},	//   _riks, וטרו_, زاین_,
  { {0xa1c50036,0x7d060c7b,0x93fa000a,0x442f00aa}},	//   _облд, _siks, _ולני, _heg_
  { {0x2d9e0045,0x14d5000a,0xfce60c7c,0x7d060c7d}},	//   âte_, ֥וּל_, дово, _piks
  { {0x5f460029,0x442f0293,0x3cf8000b,0xb05b0a64}},	//   _قنبل, _jeg_, ंगें_, liän
  { {0x442f0c7e,0xa08b0008,0x46dd000b,0x200f006f}},	// [1080] _meg_, _וְיִ, यवाह, ámiť_
  { {0xda660029,0x4a43000d,0x7c240c7f,0x8e4a0015}},	//   باري, кнув, sbir, _بلدك_
  { {0x7d060c80,0xd9100086,0xa96a00e6,0x442f0409}},	//   _tiks, ایر_, تمام_, _oeg_
  { {0x291c0024,0x3ce901b2,0x7c2f0596,0x18a3006b}},	//   īva_, clav_, _gecr, кахм
  { {0x69d50012,0x945d002a,0xd7f7067a,0xafdb02de}},	//   _exze, zińc, муш_, lgør
  { {0x442f0005,0xd7f90036,0xcfb7000a,0xb05b0123}},	//   _aeg_, чує_, ולני_, lnät
  { {0xd5b00015,0x442f0c81,0xafdb063b,0xa9260033}},	//   طفة_, _beg_, ngør, _ідал
  { {0x98550010,0x2a780c82,0x5454006b,0x8cc1000b}},	//   _птуш, _harb_, хвит, रोपो
  { {0x442f0c83,0xbc1b0008,0xfc3f002e,0xd2500015}},	//   _deg_, חופש, _slík_, هنة_
  { {0xa79b000a,0xb92b0016,0x079b000a,0x179b000a}},	//   _ושמח, _nguỵ_, _וסמל, _וימב
  { {0x67220048,0xe1340033,0xb05b0123,0xa29f0065}},	//   lpoj, энны, knät, _ओवर्
  { {0x3cfa014e,0x14170029,0x3cf8000b,0x442f0c84}},	//   ्दों_, _قيمة_, ंगों_, _geg_
  { {0xceeb0029,0x5f940063,0x7c2f0493,0x34fb000a}},	//   قرآن_, вият, _recr, _והאד
  { {0x2d5701e2,0x98ba0c85,0x442f0079,0xafdb02de}},	//   tçe_, rupę_, _zeg_, fgør
  { {0x443d0026,0xafdb0134,0x26ce0c86,0x9d180a0b}},	//   _ydw_, ggør, info_, дост_
  { {0x9f550036,0x2cb20026,0x55770053,0x113b000a}},	//   _звич, ghyd_, ועלן_, _ותהל
  { {0xd1380091,0x7e770c87,0x7c220077,0xcb34006b}},	// [1090] lsą_, _taxp, ñora, кетъ
  { {0xe9ab00e6,0x3ce90c88,0xd138002a,0x20190030}},	//   يدان_, slav_, osą_, lcsi_
  { {0x7c2f0064,0x2a78002d,0x7eab0020,0xd1380c89}},	//   _tecr, _darb_, _hüpo, nsą_
  { {0x2cb20176,0xd1380007,0xd8b80029,0xf9900015}},	//   chyd_, isą_, ودنا_, جبك_
  { {0xbc1a0008,0x8c1a0008,0x442f0c8a,0x2b570086}},	//   _מורש, _מורי, _reg_, _زیاد_
  { {0x442f003c,0xd1380007,0xddd500dc,0xbae50015}},	//   _seg_, ksą_, lező, _أكسي
  { {0x5eec000a,0xd9140033,0xb05b0c8b,0x26c90085}},	//   קַדְ, _адсы, nnäs, đao_
  { {0x628a0c8c,0x6d470c8d,0xf9880029,0x2ca90123}},	//   _anfo, irja, _تنفي_, nkad_
  { {0xe3b10029,0x442f0c8e,0x86c50015,0xd1380091}},	//   طرة_, _veg_, _كيرن, esą_
  { {0xeb92000f,0x442f0c8f,0x673b008c,0xe2910058}},	//   רָה_, _weg_, _ivuj, اذة_
  { {0xddd500dc,0x5fc5000b,0x2f140123,0x2ca904f6}},	//   kező, _लेबल, _säg_, kkad_
  { {0xddd500dc,0x90e50015,0x628a0c90,0x3f6a0c91}},	//   jező, َسَن, _enfo, пимо_
  { {0x6d410c92,0xc7b2000a,0xddd50030,0xe3ae0c93}},	//   álan, ָ֑ר_, dező, _сб_
  { {0xd2510029,0x2f1400c0,0x539a00a3,0x639a000a}},	//   _صنع_, _väg_, _מינו, _מסננ
  { {0x98a70089,0xacf600d0,0x9f630046,0xd24e0058}},	//   éně_, ечај, ěvák_, _انى_
  { {0xafdb0134,0x91ba000a,0x0000006a,0x0000006a}},	//   rgør, _ממצי,   ,
  { {0xcb670c94,0x60d7000a,0xab660033,0xcb0a00c3}},	// [10a0] нате_, _רופא_, эвал, سيان_
  { {0xb05b00c0,0xafdb02de,0x8c430061,0x60c60c95}},	//   snät, pgør, ışab, likm
  { {0xc8790064,0x3ad30015,0xc8660c96,0xc212000a}},	//   _baş_, ديلز, етли, אהב_
  { {0xd4910023,0x2ca900c0,0x60c60049,0x998a0046}},	//   _tùy_, ckad_, nikm, _webů_
  { {0x60c60020,0x1002000b,0xb05b0c97,0xfe36000a}},	//   iikm, ोशिश_, onär, ֲרֵי_
  { {0x2f3b0053,0x26ce0c98,0xfc3f0046,0xf5200033}},	//   לגנד, unfo_, _zdí_, анкi_
  { {0x6d5c03b8,0x6d4e0c99,0xe7c0000b,0xe4a60c9a}},	//   ntra, nuba, _शेरप, ерпо
  { {0x6722008c,0x67450030,0x6d5c0c9b,0x09e303a7}},	//   ppoj, ütjü, itra, _сосн
  { {0x68e20020,0xa2940010,0x7afe0ad3,0x6d5c0541}},	//   mood, вапі, ompt, htra
  { {0x6d4e000c,0x9bbb0008,0x276b002b,0x05b60033}},	//   kuba, פציפ, _عشقی_, _псеў
  { {0x51f80036,0xd46a0c9c,0xd1380007,0xe3af0086}},	//   ьною_, _ниже_, usą_, لری_
  { {0xe61f0092,0x19b7000a,0xd1380091,0x68e2053a}},	//   _đôi_, תפטר_, rsą_, nood
  { {0xdefb004a,0x6d5c0c9d,0x883b004f,0xddd501d3}},	//   зыв_, etra, התכו, vező
  { {0x628a003e,0x6d5c00b8,0xe2970033,0x60c60091}},	//   _unfo, ftra, _пач_, aikm
  { {0x68e20c8d,0x627b0008,0xc27b0008,0x68eb001a}},	//   kood, _מנגנ, _מרגי, ylgd
  { {0x61430001,0x60c60064,0xa3e4000b,0x6fb50015}},	//   _сећа, cikm, पअप_, _لمبا
  { {0xfbd00029,0x6d4e007c,0x2ca90c9e,0x6d5c0c9f}},	// [10b0] متك_, auba, rkad_, atra
  { {0x2ca90ca0,0x6d4e0ca1,0x6d5c0ca2,0x0000006a}},	//   skad_, buba, btra,
  { {0xc984049d,0xb835006b,0xe8590033,0x99670033}},	//   луци, веещ, даеш_, этал
  { {0xcd960008,0x6d88000a,0xd3080016,0x7afe00aa}},	//   _סדרת_, _נָתְ, _iệu_, ampt
  { {0x4c9a000f,0xd763002b,0xdc36000a,0xb05b008c}},	//   _חברו, انتی, _בארט_, jiäm
  { {0xc6680001,0xe5710015,0x64460030,0xff7c000a}},	//   ешће_, لطب_, ókin, פטומ
  { {0x20e1005d,0x68e200dd,0xc8790061,0xc9e50015}},	//   नवाध, bood, _taş_, _شكرً
  { {0xe8d5004f,0x0000006a,0x0000006a,0x0000006a}},	//   _סוּר_,   ,   ,
  { {0x6d5c0ca3,0xa3de000b,0x60c6001a,0x7eb0007c}},	//   ztra, _दुआ_, vikm, _läpa
  { {0x8cc1000b,0x17f80015,0xa3a80015,0x63a600cb}},	//   रोतो, _سرقة_, عطيك_, økna
  { {0x61ea0176,0x2a760008,0x4a5c0053,0x60c60007}},	//   _cyfl, דעתך_, לדזו, tikm
  { {0xf9920008,0x387d0034,0x26c70ca4,0x6d5c0ca5}},	//   ׁ֨ר_, ndwr_, lino_, vtra
  { {0x883a0008,0x3f8401b2,0x20550033,0xb05b0123}},	//   ותרו, ímu_, ытэр, tnär
  { {0x7d1a0030,0x6d4e0ca6,0x6d5c0ca7,0xdee2005e}},	//   ítso, tuba, ttra, румi_
  { {0x61ea0176,0xed570561,0x40960015,0x201b001a}},	//   _gyfl, кор_, _للغر, ægið_
  { {0x8c43000d,0x5cf6005e,0xf992002b,0xe6f20016}},	//   иесе, тягу, یبا_, _mườ
  { {0x6d4e00b6,0x25e8005d,0x387d0026,0x6d5c03b0}},	// [10c0] suba, _चुनी_, ddwr_, stra
  { {0x1f37000a,0x0f37004c,0x28c4000b,0x68e20ca8}},	//   _שריר_, _שריט_, लोनि, wood
  { {0xda650029,0x68e20020,0x26c70ca9,0x8d1a0058}},	//   طالي, tood, dino_, _تزخر_
  { {0xdb0d00dc,0xd3080016,0xa01b001a,0xccfa0033}},	//   szaá, _hệt_, rdög, _іхні_
  { {0xcee9002b,0xc017000a,0x2c17000b,0x68e20caa}},	//   _زرین_, דקנו_, धुओं_, rood
  { {0x68e20020,0xb05b008c,0xe9da01c6,0xcdc9002b}},	//   sood, viäm, _жкг_, _آذین_
  { {0xceb30008,0x95530029,0xd5af0002,0xd3080016}},	//   שיו_, لخيا, يفه_, _mệt_
  { {0xfbd2000a,0x18a30033,0xe6f20016,0x98a30cab}},	//   ֹת֙_, _касм, _dườ, _кисе
  { {0x26c7018c,0xd4670001,0x37060033,0x6ef202de}},	//   bino_, тиње_, _апаг, væbn
  { {0x26c70cac,0xc174004a,0x60c402f2,0xe4650052}},	//   cino_, глощ, _amim, þörf_
  { {0xaa370053,0x3a37000f,0x40350cad,0xe6f20016}},	//   כטיק_, כרים_, ленс, _gườ
  { {0x7ccc0064,0x94260004,0xd250002b,0x7eb0007c}},	//   oğru, _рмде, جنگ_, _räpa
  { {0x2d9e0cae,0xa3b7002b,0x2d8c0caf,0xddce0073}},	//   äten_, _لاور_, åden_, bebū
  { {0x41dd005d,0xd337000a,0x62340cb0,0x6d410900}},	//   _नुकस, _ירדה_, _секу, šlam
  { {0xd3080092,0x2d850cb1,0xe611000a,0x9e34004a}},	//   _dệt_, íle_, מִן_, ресч
  { {0xc0ab0067,0xf0470033,0x1fa70302,0x26c70cb2}},	//   _زابل_, _рэко, _арог, zino_
  { {0x09bd005d,0x9be70036,0x80a40086,0x1be3000b}},	// [10d0] ्प्य, тівк, _خمين, _कुशल_
  { {0xdd030064,0x7a350086,0x387d0034,0x6e990054}},	//   ırıc, افاص, wdwr_, _чвор_
  { {0x6cd50031,0x26c70cb3,0x61f8000a,0x77690123}},	//   _مقدا, vino_, תִּג, _spex
  { {0x64420cb4,0x9854005e,0x487800ce,0xbc9500af}},	//   _ndoi, итіш, ксія_, _самј
  { {0x3ea10020,0xa3e4000b,0x7b090091,0xa8480015}},	//   _koht_, पॅम_, _užuo, ئلهم_
  { {0xe7eb000b,0xc7320015,0x66f401f3,0x0000006a}},	//   ड़ेगा_, حفوظ, апчу,
  { {0xf999000a,0x95c80054,0x26c70cb5,0x0000006a}},	//   _אֱ֭ל, кућа_, rino_,
  { {0x94750029,0x3f8200bf,0x26c70cb6,0x3f8600bc}},	//   ادثا, yvku_, sino_, _šoum_
  { {0x26c70cb7,0xdce50024,0x1309006d,0xa2e50b59}},	//   pino_, _arhī, нний_, лоид
  { {0x6b670024,0x7dd20030,0xe6f20016,0xd7f80418}},	//   mīgā, nűsé, _tườ, _рус_
  { {0x27fa005c,0x24550031,0xaadc000a,0xd3080016}},	//   ępne_, _مناس, וחזר, _rệt_
  { {0x351a0008,0x629a0cb8,0xe3b902ed,0x409600af}},	//   _טוענ, ajto, _плеч_, урот
  { {0x7ae50356,0x239b0029,0x6b67003d,0xc476004f}},	//   koht, _تخضع_, nīgā, _תתנו_
  { {0x7ae500f2,0xe39a0008,0x02440015,0x91fc003d}},	//   joht, _רֹאש, _نَهَ, teāt
  { {0x92560cb9,0x270f000b,0x63bb0012,0x290d0077}},	//   _сајт_, ादुर_, lzun, _oiea_
  { {0x63a90003,0x4f960cba,0x68fb0034,0x7188004f}},	//   oyen, _броу, _nhud, _יְפַ
  { {0x8b26008f,0x63bb00b8,0xf4120053,0x4c350033}},	// [10e0] удзе, nzun, מפן_, рэст
  { {0xfeba0074,0x7e560054,0x63bb0012,0x6b67003d}},	//   _ساخت_, _стиц, izun, dīgā
  { {0x09f60457,0xaa570015,0xa84a0015,0x0e5b000a}},	//   учая, الما_, فلام_, _אדיב
  { {0xd7fa0080,0x7e7e0193,0x61130011,0x27ed0cbb}},	//   нул_, _happ, _căli, _byen_
  { {0x7c950010,0xddc704b2,0x46a606eb,0x96ea0a96}},	//   _трэц, mejš, ладв, нька_
  { {0x66e302bf,0xaf77004c,0x8b8b000a,0xddc70cbc}},	//   боча, טענס_, _אָלֶ, lejš
  { {0x7b09016f,0xb5aa0029,0x89780008,0xd639005e}},	//   _ožuj, عاتك_, _בָּה, тячі_
  { {0xddc70cbd,0x7e7e0cbe,0xb8660015,0x63bb0012}},	//   nejš, _lapp, _حاسو, fzun
  { {0x6b670024,0x63a900dc,0xa5070001,0xaaa8000b}},	//   cīgā, gyen, ћења_, _गवाक
  { {0x6b5b000a,0x53130015,0x6b84007c,0x3a3a0cbf}},	//   עדיפ, حذير, ivig, napp_
  { {0x6b840020,0x63bb003f,0xa52603ae,0x2348002b}},	//   hvig, azun, _смед, رسکی_
  { {0x7a480024,0x6fb50015,0x659b000a,0xb386006e}},	//   lītē, لمجا, _ריאק, _مجته
  { {0x4fc70cc0,0xdfd8006b,0x7e7e0cc1,0xa29400e2}},	//   усна, гър_, _bapp, _валі
  { {0x7e7e0cc2,0xb68a004f,0xa5c30535,0x7a4801ec}},	//   _capp, ׂרָ֥, skół, nītē
  { {0xccfb0124,0x7eb0007c,0xd5d8000a,0x6b67003d}},	//   ећа_, _täpn, דַּש, zīgā
  { {0x61f50061,0x61f80cc3,0x0000006a,0x0000006a}},	//   üzle, _izvl,   ,
  { {0x5a350549,0x6bd40029,0x68fb0034,0xfce80058}},	// [10f0] инат, متكر, _rhud, افقي_
  { {0x68fb00da,0xdb04002a,0x6b67003d,0x2004006f}},	//   _shud, dzió, vīgā, ýmie_
  { {0x7dd200dc,0xb815000d,0x1cd90033,0x2243002a}},	//   rűsé, адеј, _адны_, ójki_
  { {0xf7710806,0x3157000a,0x7ae5007c,0x6b67003d}},	//   قات_, ריאן_, soht, tīgā
  { {0xcc56039e,0x4c3a000a,0x4e19000b,0x7c2d0cc4}},	//   _דברי_, _בתרב, _दलाई_, mbar
  { {0x6b670024,0x63a90aa5,0xe4630061,0x8b88000a}},	//   rīgā, vyen, şmüş, _עָרֶ
  { {0x5e580053,0x7d0f00dc,0x68fb0026,0x04b5006b}},	//   טיגע_, _kics, _thud, исия
  { {0x63bb018b,0x58d50036,0x3f890026,0x27f2002a}},	//   tzun, _тобт, _orau_, żyna_
  { {0xe7ec000b,0x63bb0012,0x7c2d00aa,0x657a0cc5}},	//   _छुपा_, uzun, ibar, _esth
  { {0x63bb00b8,0x7982005c,0xd2a9004a,0x52a6004a}},	//   rzun, łowe, ткое_, ивым_
  { {0x3d11000b,0x80a60015,0x3f8901c2,0x7c2d0cc6}},	//   _दंगे_, لمدن, _arau_, kbar
  { {0x7c2d005c,0xd59a0008,0x859a000a,0x251a000a}},	//   jbar, _בבעל, _בשעו, _סונא
  { {0x442d0cc7,0xddc703cd,0x889a000a,0x7e7e0cc8}},	//   mbe_, vejš, דברי, _papp
  { {0x7d0f002d,0xdcfc0227,0x03d6000a,0x442d0cc9}},	//   _aics, tvrď, _דונם_, lbe_
  { {0x3f890011,0x3c4200dc,0xddc70cca,0x98b5000b}},	//   _erau_, _lévő_, tejš, ंसाए
  { {0xed570083,0x3f890ccb,0xd6f10033,0x7e7e0ccc}},	//   јот_, _frau_, _лiчб, _wapp
  { {0x7d0f00dc,0xddc70ccd,0x442d0012,0x8cb7000b}},	// [1100] _dics, rejš, ibe_, ोफ़ो
  { {0x628107e9,0x7c2d0cce,0xcf250015,0x6b840ccf}},	//   ndlo, abar, _اريي, rvig
  { {0x442d00dc,0x3af50080,0x02b60053,0x8cc6002b}},	//   kbe_, сятс, סלעך_, _نقده
  { {0x387f0048,0x442d0cd0,0xad1b000a,0x391302a3}},	//   _caur_, jbe_, _שוכר, імір
  { {0x442d0198,0xdddc00dc,0xf7170029,0xd7ef0015}},	//   dbe_, merő, لينغ_, وكم_
  { {0xdb040014,0x6b8b0134,0x7d040cd1,0x6e3c0cd2}},	//   rzió, ægge, lmis, narb
  { {0x38560063,0x5ee9000a,0x62810034,0x7d040cd3}},	//   _възс, נַנְ, ddlo, omis
  { {0x6d41002d,0x48e30127,0x442d0030,0x6d4e0091}},	//   álai, _досв, gbe_, irba
  { {0x9ae90036,0xb4d6000b,0x4616002b,0x2b4000da}},	//   нiше_, _सदी_, _نوذر, nsic_
  { {0x6d410cd4,0x7d040cd5,0x29180cd6,0xf3630033}},	//   šlai, hmis, _kura_, ітын
  { {0x442d02d7,0xf42600f2,0x6e3c0cd7,0x5a1700a3}},	//   bbe_, ääsi_, darb, יקין_
  { {0x38660cd8,0x29180cd9,0xd5770008,0x649c0251}},	//   nfor_, _mura_, _כתבה_, _néix
  { {0x7d040cda,0xdfdb0063,0x6e3c0cdb,0x4ea70cdc}},	//   dmis, тън_, farb, арва
  { {0x6e3c0cdd,0x13bb000a,0x7d040cde,0xa1580280}},	//   garb, _שֶׁמ, emis, _баку_
  { {0x42fb0008,0x12fb0008,0x51930029,0x7d0f0112}},	//   _שהוס, _שהוב, _ولهذ, _pics
  { {0xdddc0014,0xc0350180,0xb035049d,0x7d040cdf}},	//   gerő, _униј, _униш, gmis
  { {0x5c070063,0x2fcf00c0,0x29180ce0,0x4ae70033}},	// [1110] рява, _ägg_, _aura_, аўжа
  { {0x9be40010,0xe9870001,0x7d040ce1,0x7c2d0ce2}},	//   ціск, ићен, amis, sbar
  { {0x442d0ce3,0xdd840033,0x180f000b,0x7d040ce4}},	//   ybe_, _дыяп, िश्व_, bmis
  { {0x7c950029,0x29180ce5,0x78470033,0x7d04007f}},	//   _الحص, _dura_, рэжж, cmis
  { {0x7bd801e2,0x62810034,0x442d0ce6,0x6cfa000a}},	//   şvur, ydlo, vbe_, _תפרס
  { {0x45450015,0x36c4005e,0xdbdd0030,0x7a400046}},	//   منتق, обіг, jáér, rátí
  { {0x20d2002c,0x27fa005c,0x442d0ce7,0x29180022}},	//   lšie_, ępna_, tbe_, _gura_
  { {0x9dd80008,0xadd80008,0x80c6005d,0x442d0ce8}},	//   יווק_, יווח_, _लगें, ube_
  { {0x7c220077,0x442d0ce9,0x20d2006f,0x6e3c0cea}},	//   ñori, rbe_, nšie_, yarb
  { {0x0bb8000a,0x7d0402c6,0x3f84001a,0x78ba0091}},	//   ילחם_, zmis, æmum_, _įtvi
  { {0xd2980010,0x20d2002c,0x7d040ceb,0x442d0030}},	//   ртыі_, hšie_, ymis, pbe_
  { {0xcea9039e,0x6109002a,0xdcfc0045,0xa988004f}},	//   _אי_, _yśli, ivră, בָשִ
  { {0x20d2032c,0xd3080092,0xdfd20031,0x93940021}},	//   jšie_, _tệp_, سيس_, _وجها
  { {0x249f0084,0x6d550011,0xed5a0cec,0x63f40015}},	//   ljum_, fuza, лог_, _بأمر
  { {0x7d040005,0xb4f90053,0x6e3c0ced,0x91780016}},	//   tmis, ָפּי, rarb, _vợt_
  { {0xa01b0061,0x7d04014b,0x3a380144,0x11d40015}},	//   ldön, umis, _serp_, _بتهد
  { {0x6a160029,0x2918003f,0x7d040cee,0xdca306cc}},	// [1120] مبار, _sura_, rmis, чати
  { {0x3f8f001c,0x249f007c,0x7d040cef,0xda79005e}},	//   _água_, hjum_, smis, ияє_
  { {0x5d860029,0x8fc50086,0x249f002e,0xd23a0053}},	//   _الجل, _هزین, kjum_, רגעל
  { {0xcb09000a,0x7188000a,0x20d2006f,0x98c502a3}},	//   גל_, יְנַ, bšie_, осіл
  { {0xdd8f0086,0x38660293,0x69d90012,0xa8e90058}},	//   _قوی_, rfor_, ßwer, جعلك_
  { {0x66e30036,0xe944002b,0xb05b0012,0xa7730033}},	//   поча, _ورزی, chäf, яліч
  { {0xceb30008,0x249f001a,0xa56a0058,0x0000006a}},	//   היג_, fjum_, اصتك_,
  { {0x249f002e,0xd5370015,0x65b20052,0x0000006a}},	//   gjum_, حثوا_, eðhö,
  { {0x3636002b,0x5c5b004c,0xdbdd0030,0x644f01d3}},	//   _هراس, װדיק, táér, ócia
  { {0x25610014,0xe3af0015,0x28c4000b,0xa01b0030}},	//   ból_, عري_, लोरि, gdön
  { {0x76480176,0xf09f0251,0x6a9b0053,0x6d480cf0}},	//   _iddy, tjà_, אשינ, ádal
  { {0xdbdd00dc,0xe04b002b,0x09f7000a,0x26ce0034}},	//   sáér, دشده_, ממים_, lifo_
  { {0x33f603c4,0xfebb0086,0x2e4b006b,0xdcfc0045}},	//   _اساس, هاست_, ляво_, zvră
  { {0xd1300029,0x20d2002c,0x121a0010,0x62010064}},	//   _قمت_, všie_, _сюды_, öylü
  { {0x7e7500bc,0x82630015,0x21260058,0x0000006a}},	//   rezp, _رهين, _اعتُ,
  { {0x853b00b2,0x8cf506b4,0x20d2006f,0xde47002b}},	//   טגלי, ізац, tšie_, _گیسو_
  { {0xab94005e,0xa4b7000a,0xab87006b,0xeb090015}},	// [1130] питі, צלמה_, щувк, لقرى_
  { {0x20d2002c,0x70550086,0x249f002a,0x531b004f}},	//   ršie_, _انکا, zjum_, טומצ
  { {0xceb2000f,0x89d90040,0x249f001a,0xadbd02a3}},	//   _חיי_, جوار_, yjum_, _ранi
  { {0x76480176,0x20d2002c,0x515b00f3,0xb05b008c}},	//   _addy, pšie_, רכאו, miäs
  { {0xb05b00f2,0x46a50063,0xe7680015,0x7528003d}},	//   liäs, жалв, محون_, _atdz
  { {0x7982005c,0x25610744,0x7f3c0053,0xf7700031}},	//   łowa, tól_, נעוו, عان_
  { {0x04590029,0x249f002e,0x65920054,0xf505005e}},	//   للغة_, tjum_, дају, озко
  { {0x25610014,0x4439002d,0xc32503ad,0x7eab007c}},	//   ról_, ús_, омик, _küps
  { {0x249f002e,0xd2990036,0x0000006a,0x0000006a}},	//   rjum_, атні_,   ,
  { {0x02c50191,0xe3b60033,0x63a60123,0x68eb0cf1}},	//   ійно, юбы_, äkna, logd
  { {0xd4e70191,0x2bd0005d,0x21690cf2,0xe1f10015}},	//   _люди, _सेना, шини_, بسة_
  { {0xc1060015,0x33950015,0xd00a006b,0x439501e1}},	//   توجي, _ولاز, иене_, _маес
  { {0x443f0176,0xb4e5005d,0x10a3006b,0x33d40033}},	//   mau_, पकी_, фиян, _нішт
  { {0xdcb10023,0x6729003f,0x443f0cf3,0x6d480091}},	//   ển_, _mtej, lau_, šdam
  { {0xa1560001,0xa0c60015,0xc692000a,0x2d8c006f}},	//   _дају_, _ويتو, ואם_, íde_
  { {0x443f0cf4,0x645b0cf5,0xa01b0030,0x62830cf6}},	//   nau_, ngui, ndöl, _hano
  { {0x7eb000f2,0xbb4a0015,0x645b0cf7,0x62830cf8}},	// [1140] _läpi, شلان_, igui, _kano
  { {0x386d018b,0x443f0cf9,0x2ca008c0,0x0af60033}},	//   _aber_, hau_, sjid_, ічаў
  { {0x6d410014,0x68460029,0xdc6a00fd,0xdca60cfa}},	//   álat, قَال, _канд_, _дани
  { {0x872a0010,0xb05b0cfb,0x186a0cfc,0xfc320015}},	//   аўка_, chäd, ради_, _تحد_
  { {0x443f0b7c,0x27e001e2,0x47330036,0x07a30010}},	//   dau_, çin_, дніс, мацн
  { {0x9f610014,0xba760015,0xe666005e,0x443f0cfd}},	//   ését_, _باحت, ітло, eau_
  { {0x443f0026,0x26ce0026,0x2b4f0046,0x7eab007c}},	//   fau_, rifo_, ělců_, _küpr
  { {0x443f0176,0x636a0cfe,0x62830c99,0x7c240cff}},	//   gau_, арог_, _aano, ncir
  { {0xdc8b000a,0x6d48013f,0xf7530015,0xa8a50015}},	//   בְיָ, ádaj, _ينفج, _عصفو
  { {0x62830d00,0x75960015,0xe7d5002b,0x67450046}},	//   _cano, _وجاء, _عملگ, řují
  { {0xe29a0023,0x81c60080,0xa1940004,0xa1860033}},	//   _chưa_, ющие, чанч, цыпл
  { {0xb97b000a,0xb05b008c,0x75d3006e,0x443f0d01}},	//   בנטי, viäs, _تيما, cau_
  { {0x64d90053,0x62830d02,0x3f8d0144,0x1394005e}},	//   _פֿעס, _fano, íeu_, _хилю
  { {0x7c260134,0x62830d03,0xb05b008c,0x64400d04}},	//   _afkr, _gano, tiäs, lami
  { {0x9c830d05,0xeca70cb9,0x31c3006b,0xac950888}},	//   íčov, ојан, _осъв, павш
  { {0x4c940080,0x6aaa00b8,0x91bb000a,0xc1bb000a}},	//   мисс, öffn, _כמוי, _כמוש
  { {0xd1080086,0xdfd10002,0xfbd00015,0xa01b0123}},	// [1150] _بقيه_, _سيد_, نتك_, ndöm
  { {0x6d410014,0xba980036,0x64400d06,0x44240016}},	//   álas, овує_, hami, hcm_
  { {0xceb200b4,0xe2a60084,0x67290089,0x20d2006f}},	//   _ניט_, _áður_, _stej, lšia_
  { {0x5d7a0632,0xc19b000a,0xdcef0091,0xdbdd0030}},	//   _פארק, ישבי, _įdėj, láír
  { {0x4c9a000a,0x64400d07,0x386d0012,0x7b640d08}},	//   _הברו, dami, _vber_, _отре
  { {0xcf580008,0xb7d20029,0x443f0026,0x8f7c0008}},	//   קבות_, عقوب, wau_, ינדק
  { {0x60cd0d09,0xce38000a,0xb05b008c,0x7c3d01d7}},	//   _omam, חאות_, snäy, _kesr
  { {0xb4e5014e,0x64400d0a,0x6283022d,0xe5040015}},	//   पके_, gami, _sano, وبيي
  { {0x443f0176,0x20d2002c,0x7c3d0213,0x97250015}},	//   rau_, jšia_, _mesr, _رفضو
  { {0x44260176,0x443f0d0b,0x78a90161,0x64400209}},	//   _efo_, sau_, _hoev, aami
  { {0x443f0d0c,0x64400020,0xe2a80040,0x44260034}},	//   pau_, bami, تاين_, _ffo_
  { {0xe4d70015,0xd5fa000a,0x64400d0d,0x7c3d0d0e}},	//   _بتطب, _הפער, cami, _nesr
  { {0x628300b6,0xa2950036,0xdd0c005c,0x78bb0107}},	//   _tano, _наді, różn, _mluv
  { {0xe29a0092,0x78bb02c1,0xc332000a,0x2261002a}},	//   _thưa_, _lluv, _טוד_, órkę_
  { {0x6da60c1c,0x6df60015,0xc692000a,0x61ee01c0}},	//   чива, سكرا, עאל_, čilé
  { {0x61fc01e2,0x8b260080,0xc5f20008,0x443d00da}},	//   ürle, здае, גדל_, _jew_
  { {0x305b0008,0x905b0008,0x945d005c,0x6d41001a}},	// [1160] _הדפד, _הכפת, lińs, álar
  { {0x7c240d0f,0x09e602c4,0x7fe90067,0x9f4f0030}},	//   scir, позн, _ظريف_, _ágá_
  { {0xfbc90008,0xe9da0001,0x224a002a,0x945d002a}},	//   נת_, љке_, óbki_, nińs
  { {0xb4e5005d,0x7eab0020,0x443d0d10,0x7982002a}},	//   पको_, _hüpp, _new_, łowo
  { {0x64400d11,0x945d002a,0x28bd000b,0xe704002b}},	//   vami, hińs, ्फ़ि, وستی
  { {0xab27010f,0xabfb0008,0x78bb0020,0xd94600d0}},	//   _хора_, _להכר, _eluv, _неги
  { {0x64400100,0x3ea50030,0xc448002b,0x09e30d12}},	//   tami, ölti_, قیان_, _зорн
  { {0x89db0008,0xb9db000a,0x644001d7,0xe4520058}},	//   _החלי, _החלש, uami, رضع_
  { {0x8cc1005d,0xe737069d,0x64400d13,0xdc8b000a}},	//   रोटो, _нет_, rami, זְיָ
  { {0x64400d14,0x20d2006f,0xa01b0123,0x644b00da}},	//   sami, všia_, rdöm, _edgi
  { {0x443d0041,0xdbdd00dc,0x8506002b,0x7055006e}},	//   _few_, váír, _فوئن, وندا
  { {0xdfd50010,0x69c10020,0x859b000a,0xb97b000a}},	//   домы, _ülee, _לשבו, זנטי
  { {0xdcb10023,0xb465002b,0x74130015,0x2d8c02de}},	//   ểm_, _آدمه, _كوما, æden_
  { {0x945d002a,0x20d2006f,0x7bc40535,0x0000006a}},	//   bińs, ršia_, dziu,
  { {0xdd940010,0x945d005c,0x7eb00020,0x9cf50484}},	//   нары, cińs, _näpu, дзві
  { {0x20d2002c,0x41db000a,0x11db000a,0x515b000a}},	//   pšia_, _לחוס, _לחוב, _הכהו
  { {0x2bc7005d,0x9f540010,0xfbd30087,0x6c540033}},	// [1170] _रेखा, _звыч, رتر_, экту
  { {0x7b09010b,0x62880d15,0x6008000a,0x78a90d16}},	//   _ažur, nddo, _מִתְ, _soev
  { {0x2d8c0d17,0x2d9e0123,0x60dd0d18,0x62880034}},	//   ådet_, ätet_, onsm, iddo
  { {0x18690036,0x315701ac,0xda080015,0x99640033}},	//   іали_, ליבן_, سينه_, этул
  { {0x9be40036,0x6298016b,0x99620046,0x945d002a}},	//   _зірк, _onvo, _míře_, zińs
  { {0x6d550d19,0x6d470535,0x0000006a,0x0000006a}},	//   orza, osja,   ,
  { {0x78a90991,0x58d50036,0xb9250086,0x291c0089}},	//   _toev, _жовт, _آفري, ívat_
  { {0x62880026,0x6d48002d,0xcd98039e,0xe3b909a8}},	//   eddo, ádai, לדות_, жби_
  { {0x27ff0064,0xa3e7005d,0xf7700115,0x6d550012}},	//   _uzun_, _मुख_, _مال_, hrza
  { {0x25e8005d,0x6d470020,0x62880034,0xdb9c000a}},	//   _चुकी_, ksja, gddo, מסחר
  { {0x6d55005c,0x35f50010,0x443d0034,0x41b40c6e}},	//   jrza, _ўпер, _tew_, есят
  { {0x644b00fb,0x6d55016f,0x62980d1a,0xc4fb002b}},	//   _udgi, drza, _envo, _اعطا_
  { {0x4fa3005e,0x945d002a,0x7d1e0085,0x91fc003d}},	//   вияв, sińs, _sups, egād
  { {0xad3a005e,0x945d002a,0x76430d1b,0x03d6000a}},	//   жчає_, pińs, nany, _קוסם_
  { {0xf2e6002b,0x80a60015,0x9288002b,0x6d410030}},	//   _تکيه_, _يمتن, _رئوف_, álap
  { {0x7643013c,0xc1060369,0x0000006a,0x0000006a}},	//   hany, _توبي,   ,
  { {0x6d470020,0xab660033,0x76430d1c,0xf093000a}},	// [1180] asja, ьвал, kany, _ינה_
  { {0x0f570008,0x6d55002a,0x76430d1d,0x4bd902ed}},	//   _קיים_, brza, jany, чься_
  { {0xa9670063,0x7e9b000a,0x5e9b000a,0xfe9b000a}},	//   диха_, _וסיו, _וביק, _ויימ
  { {0x0c260010,0x395a0d1e,0x8b2601ca,0xeb9a0d1f}},	//   _імгн, rups_, _одме, _дим_
  { {0x62880176,0x7643000c,0xb906014e,0x6d5c0d20}},	//   yddo, fany, _पद_, lura
  { {0xfbd30008,0x07a307c1,0x5751004c,0x395a0d21}},	//   _יתר_, таљн, _אױפֿה, pups_
  { {0xf9830d22,0x6d5c0d23,0x7e7c0d24,0xa9230138}},	//   _игро, nura, ierp, _адсл
  { {0x2ebb021e,0xd250002b,0x764302f2,0x7e7c0651}},	//   _उत्त, گند_, aany, herp
  { {0x76430d25,0x7e7c03d2,0xc445002b,0x6d5c0d26}},	//   bany, kerp, ریون_, hura
  { {0xd2500074,0xeb9100b2,0xcb9b0053,0x6d5c0d27}},	//   دند_, אָט_, קסיט, kura
  { {0x62880176,0xf1aa0086,0x6d5c0509,0x2a57000a}},	//   rddo, زاده_, jura, ובין_
  { {0x04930029,0xe5e7002b,0x6d5c0d28,0x0000006a}},	//   _للمح, _غزلی, dura,
  { {0x6d5c022d,0xef64006b,0x99620046,0x8236002b}},	//   eura, къро, _víře_, _قرغا
  { {0xdcfe0089,0x6d55005c,0x629800b8,0x6d5c02e8}},	//   _trpě, trza, _unvo, fura
  { {0x6d5c0d29,0x20d70058,0xd0d5009b,0x9f990546}},	//   gura, _يتعج, _покъ, _dáár_
  { {0x76430d2a,0xe58b000a,0x90e70015,0x20c20125}},	//   zany, חָמָ, _تستن, _cóid_
  { {0x2d9e018b,0x3f850048,0x2d8c0d2b,0xce95006b}},	// [1190] äter_, ālus_, åder_, _запъ
  { {0x6d5c0d2c,0x1a5b0015,0x7e7c00da,0x9af50015}},	//   bura, تشرة_, cerp, ركات
  { {0x644f0014,0xe8550015,0x6d5c0d2d,0x6b8d0d2e}},	//   ócik, فناد, cura, svag
  { {0x2bd0014e,0x76430d2f,0x2bcb0001,0x18a4005e}},	//   _सेवा, wany, _дуго_, каєм
  { {0xf3880092,0x76430375,0x69c50030,0xb8d7000b}},	//   _nợ_, tany, szhe, _चक_
  { {0xbb3a000f,0x7d0d0d30,0x2f5c000a,0xddde0085}},	//   _מעשי, lmas, קדונ, _hapš
  { {0x76430d31,0x04b50033,0xc6a4006b,0x6d480091}},	//   rany, еспя, ърци, šdav
  { {0x7d0d01e2,0xd7c90015,0x76430cc4,0x9fa000aa}},	//   nmas, _فوزه_, sany, _wéér_
  { {0x37550086,0xd8280033,0x76430d32,0x6d5c0d33}},	//   _سپاس, _ціск_, pany, zura
  { {0x1306005f,0x96bb0040,0x7d0d0d34,0x6d5c0d35}},	//   нный_, _بارز_, hmas, yura
  { {0xd12e0086,0xe1f90010,0x7d0d048b,0xd2f6002b}},	//   یمی_, яго_, kmas, رکها_
  { {0x3cfb005d,0xd36e0086,0xf9920632,0x2ec8005d}},	//   ्षों_, جهی_, ארט_, रफ्त
  { {0x76410091,0x7e7c0d36,0x7d0d0d37,0xa85a004f}},	//   _kely, terp, dmas, הדרכ
  { {0x83fd00dc,0x3ebe002e,0x7288005e,0x91e5072d}},	//   ggőe, ótt_, _обіг_, _поле
  { {0xc5f200b2,0x76410d38,0x224500bc,0x27fa002a}},	//   ָדן_, _mely, malk_, ępni_
  { {0x301a0015,0x7eb00012,0xdb070046,0x6d5c0d39}},	//   _عتبة_, _päps, ělýc, rura
  { {0x245a0064,0x207b004c,0x5f930015,0x6d5c0d3a}},	// [11a0] lümü_, _זאפא, _مليئ, sura
  { {0xb05b08e9,0x6d5c0d3b,0x160f000b,0x76410091}},	//   nhän, pura, ाधार_, _nely
  { {0xcee90074,0x245a0064,0x2e3b000a,0xe947002b}},	//   _ترين_, nümü_, _מגינ, فرنی
  { {0x7eb00005,0xe8f6002b,0x645c0030,0x0d830d3c}},	//   _täps, رساخ, őriz, _слюн
  { {0x8c1b000a,0xbc1b000a,0x20d200bc,0x76410d3d}},	//   _מוכי, _מוכש, jšim_, _bely
  { {0x46a30033,0x76410034,0x9af60015,0x45d40d3e}},	//   лачв, _cely, _أكست, колс
  { {0xceb30008,0xf3880092,0x76410026,0x09e6005e}},	//   ריו_, _sợ_, _dely, _човн
  { {0x69c10020,0xd3a60294,0x75210077,0xa5d700c3}},	//   _ülea, ероп, _dulz, عبور_
  { {0x8c1b0008,0x76410034,0xb05b0012,0x0000006a}},	//   הופי, _fely, fhän,
  { {0x76410d3f,0xf3880092,0x7d0d0d40,0xc1ea01c6}},	//   _gely, _vợ_, zmas, зьме_
  { {0x83fd00dc,0x7d0d0d41,0xfb17004c,0x25a10012}},	//   ggőb, ymas, ײַזט_, ählt_
  { {0x254c0089,0x31c30033,0x59c2000b,0x61f80046}},	//   měl_, усьв, वैयर, _vyvl
  { {0x2245049c,0xb05b00b8,0x5f940063,0xe0df04ed}},	//   balk_, bhän, гият, rnò_
  { {0x539b00a3,0x245a0061,0x7f5d0003,0x0000006a}},	//   _מידו, bümü_, rusq,
  { {0x3f84001a,0x254c0046,0x7d0d0d42,0x626300af}},	//   æmur_, něl_, tmas, _свја
  { {0xccf80001,0x01fb000a,0x628a0034,0x7d0d0d43}},	//   ећу_, _מפול, _hafo, umas
  { {0x7d0d0d44,0x7e2b00e2,0x60d8000a,0x3ea50030}},	// [11b0] rmas, _ніна_, _רוחא_, ölts_
  { {0x7e650012,0x2b490003,0x7d0d0d45,0x0000006a}},	//   _uchp, rsac_, smas,
  { {0x7d0d0064,0x764100da,0xd99900c3,0x6d480d46}},	//   pmas, _rely, بنات_, ádat
  { {0x254c0089,0xb9540015,0x628a0529,0xc052004f}},	//   děl_, ائلت, _lafo, ֹ֖א_
  { {0x81bc0024,0x245a0061,0x2eab000a,0x76410d47}},	//   ucēj, zümü_, ּשֶּ, _pely
  { {0x8bd6000a,0x81bc003d,0x20d20085,0x2ca9060a}},	//   _יורו_, rcēj, všim_, ljad_
  { {0xb5c20036,0x81bc003d,0xd5e5009b,0x2f0402dc}},	//   ийшл, scēj, ъжки, nöga_
  { {0x69cc002c,0x6442002d,0x76410034,0x3af40123}},	//   ôlež, _ceoi, _wely, läpp_
  { {0xe3b10029,0x99980011,0x13090142,0x76410034}},	//   شرة_, _terţ_, мний_, _tely
  { {0x628a0176,0x7eb00604,0x2ca9007c,0x4225006b}},	//   _cafo, _näpp, hjad_, ъдов
  { {0xd7020010,0x2258002a,0x628a0034,0x8368002b}},	//   _лiта, órka_, _dafo, وصیف_
  { {0x245a0064,0xe3b00086,0x3cc6000b,0xe5080015}},	//   rümü_, _گرم_, रोफ़ा, _كيلو_
  { {0xb05b0400,0x22950029,0x22450d48,0x52850015}},	//   mhäl, _للإس, palk_, _للشك
  { {0x628a0176,0x79820050,0xe3b00086,0xe195004a}},	//   _gafo, łowi, _درم_, _ариэ
  { {0xb05b00b8,0xbea30180,0xdd920015,0x6cd60015}},	//   chäo, шарк, جوز_, نقسا
  { {0x248d0d49,0xb05b0d4a,0xa3e5000b,0x1fb60d4b}},	//   ndem_, nhäl, _नशा_, _асор
  { {0x248d0046,0x8fa6067a,0x0000006a,0x0000006a}},	// [11c0] idem_, _рапе,   ,
  { {0x248d0012,0x6a1600c3,0x63a60123,0x3ced0b28}},	//   hdem_, نبار, äkni, čeva_
  { {0xae570008,0x19b90010,0x1e57000a,0x7d0a0054}},	//   _בסיס_, нуць_, _בשיר_, _оног_
  { {0x38cb0086,0x7995005c,0x248d03cd,0x254c0046}},	//   وانی_, _drzw, jdem_, věl_
  { {0x248d0026,0x23d0005d,0x79950012,0x9cd7000a}},	//   ddem_, _तेंद, _erzw, _יוטה_
  { {0x254c0089,0x6442002d,0x98a7003d,0x645c0091}},	//   těl_, _seoi, īnā_, ėrim
  { {0xa01b00dc,0xd943004a,0xe9a30d4c,0x87e1002b}},	//   ldöt, _веси, _карп, _ﻳا_
  { {0x628a0176,0xb8660087,0xa4f8002b,0xd4670054}},	//   _safo, _جاسو, رکار_, виће_
  { {0x2c6d0014,0xd3a30010,0xaa82002e,0xa7660010}},	//   lódó_, арэп, _þýsk, _шкад
  { {0x254c0046,0x68e20d4d,0x0cde0065,0xe73700ce}},	//   pěl_, lnod, नचुम, _реф_
  { {0x4a5b000a,0x64420d4e,0xe3af002b,0xe1d4005e}},	//   ודיו, _teoi, مری_, ужнь
  { {0xd5d90053,0x68e20d4f,0xe3ba0164,0x138a0015}},	//   _אַנש, nnod, _обе_, _يخشى_
  { {0xe7030023,0x35a8005d,0xc4cf0015,0x628a0034}},	//   _hướ, _कपड़, _بْن_, _tafo
  { {0x11d60029,0x7a480024,0x9f34005e,0x6b840d50}},	//   _لتعد, nūtē, рері, dwig
  { {0x2ca90020,0xf27b000a,0xb05b0123,0x51f3002b}},	//   tjad_, _חרוש, lhäm, _پسور
  { {0x20d200bd,0x0217000a,0xa26300a1,0x68e2013b}},	//   jših_, _בחום_, _luồ, jnod
  { {0x3a750080,0x68e204af,0x9b450086,0x2ca9038a}},	// [11d0] ллар, dnod, انطو, rjad_
  { {0x2ca9007c,0x7a540015,0x6a340054,0xda6700c3}},	//   sjad_, لضما, инуђ, ضائي
  { {0x68e20176,0x68e302c1,0xe7030092,0x6b84005c}},	//   fnod, éndo, _nướ, awig
  { {0xc8640054,0x236d002a,0x0cd4030c,0x0000006a}},	//   атљи, ytej_, _воюю,
  { {0xdcb10023,0x27e90061,0xe9ff0016,0x97c70015}},	//   ểu_, çan_, _trắc_, ختام
  { {0xe7030023,0xda340010,0x7d1d0d51,0x20d202c6}},	//   _bướ, _веры, _hiss, aših_
  { {0xb05b00b8,0x451903fc,0x248d00b8,0x06960015}},	//   thäl, нция_, tdem_, طنية_
  { {0xe7030023,0x05760029,0xf5760015,0xdb1e0107}},	//   _dướ, امية_, اميع_, _švéd
  { {0xb05b00b8,0x7d1d0d52,0x248d0d53,0x93950015}},	//   rhäl, _miss, rdem_, اجبا
  { {0x7c2d00da,0x27e00125,0x236d0d54,0xe979000a}},	//   hcar, úine_, rtej_, ֲנָש
  { {0x291e038d,0x92590086,0x01650080,0x236d0d55}},	//   _état_, وشگر_, ыкно, stej_
  { {0xd5ba0053,0x2f04002e,0x6b8400aa,0x853a000a}},	//   _אזעל, gögn_, ywig, _נגני
  { {0xe28e0d56,0xddc70030,0x442d0d57,0x2c6d0030}},	//   _ла_, dejű, mce_, zódó_
  { {0x6449002d,0x442d07ca,0x7c2d0049,0x68e20d54}},	//   laei, lce_, ecar, znod
  { {0x628104f9,0x5de60063,0x68e20026,0x8db50036}},	//   melo, ужва, ynod, асті
  { {0x62810d58,0x27e9002a,0x442d0d59,0x7d030058}},	//   lelo, żany_, nce_, مِّه
  { {0xdcf70087,0x69030020,0x442d0d5a,0x20d20085}},	// [11e0] افقت_, tõen, ice_, vših_
  { {0x7f3b0008,0xc3320008,0xee3a0010,0xdd040064}},	//   _רעיו, צוב_, _яно_, ırır
  { {0x2d960292,0x442d0089,0x68e2049c,0x497a0010}},	//   _српс, kce_, tnod, эсаў_
  { {0xccfa0036,0xdca60d5b,0x7c2d0d5c,0xb7d7002b}},	//   _їхні_, _сами, ccar, گوها_
  { {0x38c80086,0x60c4003f,0x68e20d5d,0x62810d5e}},	//   _یاری_, _mlim, rnod, kelo
  { {0xaf770053,0x6d5c0d5f,0x62810d60,0x442d0d61}},	//   רעסס_, orra, jelo, ece_
  { {0x62810d62,0xf1a70015,0xcad7015b,0x7aeb0030}},	//   delo, _اء_, _עולת_, égte
  { {0x6f1e005c,0x4498004a,0xc35402d9,0x29070144}},	//   _lipc, твию_, акиј, ïnat_
  { {0xb4e4021e,0x6d5c0012,0x6906003d,0x68b7000a}},	//   _नदी_, hrra, ārdē, _עלמא_
  { {0x38660026,0x03770086,0x26c70d63,0x6c1b000a}},	//   lgor_, احيت_, chno_, עֵהו
  { {0x764a001a,0xa697000a,0x442d0d64,0x7c2d0d65}},	//   mafy, _תכבה_, bce_, ycar
  { {0x442d04ed,0x38660d66,0x60c40d67,0x62810034}},	//   cce_, ngor_, _clim, aelo
  { {0x2d9e02d2,0xb4c0000b,0x62810d68,0xd8d7004c}},	//   åten_, ँसी_, belo, רוכט_
  { {0x7d1d0005,0x38660026,0x62810d69,0x2f04001a}},	//   _siss, hgor_, celo, sögn_
  { {0x7c2d0298,0xd1300086,0xc6b7000a,0xd578000a}},	//   tcar, _بمب_, נהלי_, כָּר
  { {0xd1380007,0x28b9000b,0xed58006f,0xf047004a}},	//   mpą_, _आवधि, áľa_, _сэко
  { {0x4bdb0086,0x7d1d0d6a,0x7c2d0d6b,0x6d5c0d6c}},	// [11f0] ربرد_, _viss, rcar, arra
  { {0x6e670001,0x442d0d6d,0x7c2d03b0,0x7d1d0d6e}},	//   _стиж, zce_, scar, _wiss
  { {0x60c400f2,0xaae80036,0x7d1d0d6f,0xda780033}},	//   _ylim, уєте_, _tiss, ыят_
  { {0x69c10020,0x7f5d0152,0xdd3a000a,0x62810319}},	//   _ülem, orsq, _שערכ, zelo
  { {0xa8480015,0xa3d3000b,0x442d0d70,0x07a50718}},	//   الهم_, _हें_, vce_, ралн
  { {0x05550063,0x442d005c,0x62810d71,0x3869002a}},	//   атия, wce_, xelo, żar_
  { {0x442d037f,0x8aa8000a,0x62810090,0x8989000a}},	//   tce_, _עֹשֶ, velo, _בָּ֔
  { {0x47350956,0x62810d72,0xed640057,0xd5ae0015}},	//   _внас, welo, leží_, ظفي_
  { {0x56670002,0xe73000e5,0x62810d73,0x442d0d74}},	//   _مداف, _فصل_, telo, rce_
  { {0x6d5c0d75,0x442d0d76,0xd7740015,0x60c40d77}},	//   yrra, sce_, _دافع, _slim
  { {0xfad60008,0x62810d78,0x869a000a,0x4206006b}},	//   שותך_, relo, _שיעז, иньо_
  { {0x6563001c,0x8235002b,0x272b02de,0x62810d79}},	//   munh, درکا, _køn_, selo
  { {0x20c20125,0x6f630342,0x5f060d7a,0x62810d7b}},	//   _fóin_, овяз, изма, pelo
  { {0xed5a0124,0x6d4e020a,0x82370029,0x68e90085}},	//   ког_, tsba, _إرشا, _ljed
  { {0x68fb0064,0x272b02de,0x66c6001a,0x68e90d7c}},	//   _okud, _løn_, _uðke, _ojed
  { {0xdcfc016f,0x60c4003f,0x27ff0061,0x63bb0061}},	//   tvrđ, _ulim, _oyun_, oyun
  { {0x69c10020,0x3f8c0024,0x1eca0001,0x1efa0015}},	// [1200] _ülej, ādus_, _алпи_, _لعدة_
  { {0xcfb70008,0x3c190010,0x19960001,0x63a90251}},	//   _כלפי_, уўся_, ијер, ixen
  { {0xae5b000a,0x0e5b000a,0x7bcd003d,0x3e5b000a}},	//   _בכיר, _בדיב, azau, _בדיס
  { {0x26c504ed,0xe73a0d7d,0xdddc0d7e,0x22470073}},	//   _allo_, вед_, održ, _lenk_
  { {0x16340063,0xf1ba0016,0x9077000a,0xed64006f}},	//   беля, _ngơn_, שענא_, beží_
  { {0xafdb0134,0x68e902de,0x46d0000b,0x66e3006b}},	//   sbøg, _ejed, थोंह, ооча
  { {0x09fa0029,0x20d2002c,0x8a7b000a,0x45470033}},	//   _شفرة_, lšiu_, _שאלת, ачым_
  { {0x26c502c1,0xd4970080,0x4422003c,0x7982002a}},	//   _ello_, арь_, øk_, łows
  { {0xdc89000a,0x185b000a,0x82a60d7f,0x20d2006f}},	//   רְצָ, _שכמע, ашне, nšiu_
  { {0x291f04f9,0xc8850064,0xb2730139,0x9f4f0003}},	//   _ziua_, arşı_, ольш, _âgé_
  { {0x21630036,0x63bb0035,0xe1d80036,0x3abb0135}},	//   отяг, ayun, удні_, דמינ
  { {0xddc50089,0xc5f3000a,0x55bb000a,0xd1380091}},	//   _schů, _ודע_, _שמאו, rpą_
  { {0xa294008f,0x7648032c,0x20d2002c,0x251b0135}},	//   _галі, _kedy, jšiu_, _סודא
  { {0x76480050,0x7b1000b8,0x0ea7000b,0x92f30015}},	//   _jedy, läuf, खाधड, _وأوض
  { {0xc5340008,0xdddc0d80,0x76480d81,0xec6b0004}},	//   מָּה_, adrž, _medy, крак_
  { {0xc05b0191,0x26dc02c1,0x50d40031,0x718b000a}},	//   _рік_, hivo_, _وزير, _יְחַ
  { {0x75280050,0x2bba005c,0xc334000a,0x89d9002b}},	// [1210] _ludz, jącą_, מוּ_, گوار_
  { {0x69c10020,0x68e906e6,0x26dc02c6,0x7b100012}},	//   _ülek, _sjed, jivo_, häuf
  { {0xc8ab0063,0x272b0595,0x99d90015,0x7bcd0030}},	//   къде_, _søn_, دواء_, szau
  { {0xf771003b,0x19580033,0x67550015,0x38c9002b}},	//   كات_, рацы_, مختر, دائی_
  { {0x2bde005d,0x76480034,0x83fd0030,0x7528003d}},	//   _नेपा, _bedy, ggől, _audz
  { {0xd00c000a,0x752809bb,0xf770006e,0x8c1a000a}},	//   כּוֹ, _budz, ظان_, _תושי
  { {0xcb120008,0x78570086,0x68e9016f,0x22470064}},	//   _מלך_, _نیاز_, _tjed, _renk_
  { {0x68e90d82,0x15b80033,0x20d20046,0xe5760174}},	//   _ujed, рышы_, nšit_, ёзы_
  { {0x27ff0061,0x764800e7,0x60dd0d83,0x0000006a}},	//   _uyun_, _fedy, dism,
  { {0xfbd20008,0x6563016e,0x0574002b,0x60dd0d84}},	//   פתי_, punh, _ژاند, eism
  { {0x63bb0035,0x20c2002d,0x75280d85,0x7a88000a}},	//   syun, _fóil_, _gudz, בָרַ
  { {0x397a013a,0x297a0632,0xa8790053,0x224700dd}},	//   נטרנ, נטרא, נאָר, _wenk_
  { {0x660100f2,0x80aa005d,0x443f0d86,0x20d20085}},	//   _hylk, टाबे, mbu_, dšit_
  { {0x2418005e,0x20d2006f,0x7d180030,0x13040033}},	//   _тією_, všiu_, _évsz, _дзім
  { {0x71960074,0xdca60d87,0xa135002b,0x2d950d88}},	//   _هنوز_, бави, _ارتش, ортс
  { {0x386d01c2,0x9c260004,0x70560067,0xc5f2000a}},	//   _ncer_, сдад, _انظا, פדן_
  { {0x443f0d89,0x2d840046,0x1d070719,0xbf660015}},	// [1220] ibu_, ňme_, сети_, _ادعو
  { {0x8e860029,0x20d2006f,0x9e660d8a,0x386d0d8b}},	//   _الده, ršiu_, _увод, _acer_
  { {0xceb7000a,0x91fc003d,0xf8b9000b,0x499a055f}},	//   _הפיק_, egāj, _आवशय, ытая_
  { {0x20d2002c,0x61fc0012,0x77ca004a,0x443f00b3}},	//   pšiu_, ürli, ллег_, jbu_
  { {0x4b550063,0x67210d8c,0xc053015b,0x26dc0d8d}},	//   _мърт, _bilj, לזא_, tivo_
  { {0x6721065d,0x7d040d8e,0x386d00d9,0xcf93000a}},	//   _cilj, llis, _ecer_, פטו_
  { {0xb05b0d8f,0x26dc0d90,0x67210085,0x76480d91}},	//   mhäv, rivo_, _dilj, _vedy
  { {0x39570008,0x76480026,0x2d980d92,0x54b800a4}},	//   _לשלם_, _wedy, ivre_, ргия_
  { {0x47c6000d,0x7d040d93,0xfa6a000a,0x6cab000a}},	//   _убав, ilis, ְכֹּ, אֹיְ
  { {0x52d80036,0x0bb7000a,0x66010d94,0xfbb7000a}},	//   рмою_, צלים_, _fylk, צפית_
  { {0x8afb0135,0x7a8b000a,0x60dd0d95,0x7d040d96}},	//   רפיק, אָכַ, tism, klis
  { {0xef260061,0xe019005e,0x9f990248,0xa98b004f}},	//   ğüne_, ижні_, авму_, נָיִ
  { {0x833a0080,0x6d5a002c,0xe6c4002e,0x9e4b0011}},	//   _счет_, átan, _þjóð, ţămâ
  { {0x7d16002c,0x4357000a,0x7d040d97,0xf1a60724}},	//   emys, _פסול_, elis, _грин
  { {0xb6bb0008,0x6d5a0d98,0x60dd0d99,0xc0d50015}},	//   נצלי, štan, pism, _ويتب
  { {0xd9040074,0x9c3905c0,0x7d040d9a,0x69c1007c}},	//   _سی_, рпат_, glis, _ülei
  { {0x88bd005c,0x2d8c0134,0x5c070d9b,0x8cda000b}},	// [1230] _liśc, æder_, сява, _नगरो
  { {0x6bd40015,0x61ff0030,0x443f06ca,0x9be4005e}},	//   ستقر, _ízlé, zbu_, чіск
  { {0x20d20089,0x18370029,0x3ebe0d9c,0x7d040d9d}},	//   pšit_, مرشح, ötte_, blis
  { {0x44260d9e,0x7d040d9f,0x77990a24,0xe84b009a}},	//   _ngo_, clis, икер_, اجان_
  { {0xd3660067,0x67290077,0xdddc0045,0x68f900da}},	//   _ته_, _quej, perţ, rowd
  { {0xe80f005d,0x77840010,0x98aa0024,0x91fc003d}},	//   ़ेगा_, яліз, ājām_, rgāj
  { {0x03190086,0x443f04af,0x67210da0,0x5fe0000b}},	//   یتخت_, tbu_, _vilj, _पेनल
  { {0xe5760033,0x0000006a,0x0000006a,0x0000006a}},	//   ізы_,   ,   ,
  { {0x7b1000b8,0xe795002b,0xe0df02b9,0xb05b0012}},	//   bäud, _بازک, diò_, nhäu
  { {0x66010050,0x799c0034,0x798e0034,0x44260da1}},	//   _tylk, _yrrw, _ysbw, _ego_
  { {0xd2980033,0x7d040da2,0x7b100012,0x7d160da3}},	//   стыі_, ylis, säug, ymys
  { {0xcea900f3,0xc9520135,0x2eb4000b,0xb05b008c}},	//   _בי_, ומט_, ुस्त, tkäa
  { {0x7d040061,0xc2c50015,0x78fa000a,0x02d50058}},	//   vlis, _ويصي, שפרו, _وتتخ
  { {0x61450da4,0x7f750033,0x316504b2,0x0000006a}},	//   _дека, чуюц, pulz_,
  { {0x7e23000d,0x644b013c,0xc8b9000b,0x2d980da5}},	//   ддрж, _kegi, _आवंट, uvre_
  { {0xe0df02b9,0x691102de,0x1bea0b1e,0xb05b0b1f}},	//   ciò_, nåed, адби_, lkän
  { {0x7d04017e,0x8b260191,0xeb970da6,0xec35002b}},	// [1240] rlis, ідже, оит_, سولگ
  { {0xda660029,0xda650029,0x7d160046,0xb05b0da7}},	//   تاري, كامي, smys, nkän
  { {0x64590050,0xe9da0001,0x984a0033,0x7d040da8}},	//   _odwi, јке_, аяла_, plis
  { {0xb17a0053,0xa17a0053,0xa8a3009c,0xe8fa0da9}},	//   יטער, יטעט, дршк, шле_
  { {0xb05b0400,0xf76f0021,0x4733002b,0x16340daa}},	//   phäv, ناو_, وروز, пеля
  { {0x8f9b0dab,0xd7f90036,0xe0df04ed,0xbf9b01ac}},	//   ייני, щує_, ziò_, יינש
  { {0xb05b01d1,0x2bde005d,0xe5a30001,0xceb3000a}},	//   dkän, _नेता, дији, ויג_
  { {0xc4f70015,0x644b0dac,0x64400dad,0x186708a0}},	//   يعيا_, _cegi, ubmi, _маси_
  { {0xe0df02b9,0x83fd0030,0x644b0dae,0xa6e60daf}},	//   viò_, ngőh, _degi, _джал
  { {0xa2a7005d,0x3ce00020,0xd3770010,0xe6c60015}},	//   फ़ॉल्, hiiv_, ічы_, _بتري
  { {0x27300092,0x644b0144,0x75d600c3,0xc4c60015}},	//   _hàn_, _fegi, _بيضا, _وتصو
  { {0xa3460010,0x6ab7005d,0x44260db0,0x7fb90015}},	//   _дэкл, _आक्र, _ugo_, مهجر_
  { {0x69c10020,0x6d5a0db1,0xd36f0015,0x39470030}},	//   _ülev, štal, _لهن_, ánsz_
  { {0x20050048,0x27300092,0xdefb0256,0x3f8b002a}},	//   āli_, _màn_, рым_, rwcu_
  { {0x27300092,0xdd940010,0x853c0091,0xc8bc000b}},	//   _làn_, мары, _drėg, ्घाट
  { {0x5ce70036,0xe9ab002b,0x27300016,0x75350030}},	//   іюва, یدان_, _oàn_, _ézze
  { {0x60c00db2,0x10170015,0xe451000a,0x27300016}},	// [1250] ömme, _ببغد, גֶב_, _nàn_
  { {0x501c0008,0x7f840086,0xb4c7000b,0xb05b0012}},	//   _דוחו, _کلین, _उत्_, rhäu
  { {0xdc3f099c,0x41ca005d,0x62880db3,0xb05b0012}},	//   líčk, ानिस, iedo, shäu
  { {0x27300092,0xb17b0053,0xf8b10086,0x26f5005d}},	//   _bàn_, שטאר, رکز_, ेत्र_
  { {0x6d550014,0xa7870029,0xa3da000b,0xdc3f013f}},	//   lsza, تشاو, _डेल_, níčk
  { {0x853c0007,0x644b0ac1,0x628806cf,0xf1ca000b}},	//   _orėd, _segi, jedo, ानान
  { {0x6e35005c,0x645d0007,0x62880db4,0x19580033}},	//   iczb, ųsim, dedo, _мары_
  { {0x28f80036,0x6d5506cd,0xed17004f,0x33d500ce}},	//   _десь_, isza, חַ֖ת_, зіот
  { {0xf41f00f2,0xf773002b,0x644b0db5,0x6b8d0db6}},	//   ää_, _تاز_, _vegi, nwag
  { {0xeb920008,0x65950db7,0xe1610033,0xb5950a32}},	//   תָה_, _назу, нямi_, _низш
  { {0x644b0db8,0xb05b0b1f,0xd24e002b,0x6b8d01f1}},	//   _tegi, rkän, اچه_, hwag
  { {0xb05b0123,0x69c1007c,0xef260061,0x0000006a}},	//   skän, _üleu, şüme_,
  { {0x20040084,0x21b80086,0x6d55002a,0x68eb0db9}},	//   æmi_, مپیک_, esza, ingd
  { {0x539a01ac,0x141a004c,0x6d5a0dba,0x62880d67}},	//   _לינו, _פוסב, štam, cedo
  { {0x2d9e0156,0x6d5500dc,0x3ce0007c,0x6da30719}},	//   íte_, gsza, tiiv_, нира
  { {0x91ba0008,0x6b8d086c,0xb05b07c2,0xdc3f00bf}},	//   _למצי, fwag, nkäl, bíčk
  { {0xab6602c5,0xb05b008c,0x0efa0033,0x6b8d0dbb}},	// [1260] явал, ikäl, _гэны_, gwag
  { {0x0e66005f,0xff240086,0x3f920035,0x9f9b0008}},	//   _экон, _تبعی, _isyu_, _פסיפ
  { {0xdebb0008,0x3ebb0008,0x27300016,0x7b100012}},	//   _המיל, _הציב, _sàn_, täub
  { {0x186a09ac,0xba170015,0x62880dbc,0xeb9f0013}},	//   сади_, سينا_, zedo, _frø_
  { {0x47330036,0x4c9b0008,0x65630012,0xdc9b000a}},	//   еніс, _הבכו, ernh, _היכל
  { {0x99640089,0x29060020,0x6beb05bd,0x3739005e}},	//   může_, sloa_, _הַלַ, іччю_
  { {0xb0cc000b,0x65930015,0xe1e70015,0x673b008c}},	//   ासाग, فجير, _أس_, _etuj
  { {0x62880176,0x27300092,0x77620bf5,0xdc3a005e}},	//   wedo, _tàn_, prox, ацiї_
  { {0x2f04001a,0x6d55002a,0x6288092c,0x0000006a}},	//   lögu_, zsza, tedo,
  { {0x86ea0029,0x68e20026,0x6d55005c,0xd250002b}},	//   _اعرف_, liod, ysza, خند_
  { {0x6d5a010b,0x69c10020,0xd6cf0029,0x6a9b0053}},	//   štaj, _ület, _حقل_, זשינ
  { {0xeafa005d,0x68e209bf,0x62880dbd,0x2347002b}},	//   ्तुत_, niod, sedo, _کلوپ_
  { {0xa4b70008,0x04430a61,0xc4d3000a,0x78fb000a}},	//   _מלאה_, _чечн, _אגף_, מפטו
  { {0x68e20026,0x0eeb00f4,0x6d550dbe,0x43e50015}},	//   hiod, сьми_, tsza, _تأمّ
  { {0xf29701d8,0x127b004c,0xdcfe0046,0x68eb0034}},	//   _זכור_, _לאגע, _uspě, yngd
  { {0x6d550dbf,0x27f2005c,0x1cbb0015,0xf1ba0016}},	//   rsza, żyny_, حاسب_, _ngơi_
  { {0x6d5503c0,0x46be000b,0x68e20dc0,0xfc300021}},	// [1270] ssza, ्साह, diod, احف_
  { {0xb05b0012,0x88bd002a,0xc1780091,0x6b8d0009}},	//   chär, _ciśn, otė_, rwag
  { {0xc1780007,0xceb20053,0x68e20034,0x60cd0dc1}},	//   ntė_, _סיט_, fiod, _klam
  { {0xa3cc005d,0xa3be005d,0xfd56000a,0x7c670015}},	//   रना_, ीना_, _קשרי_, _عاجل
  { {0x69d8002e,0x205800a3,0x4c9a000a,0x96f9002b}},	//   úver, ליאל_, _וברו, يعتر_
  { {0x60cd0dc2,0xf7700015,0x25570045,0x7b100012}},	//   _llam, طاه_, tăl_, räuc
  { {0x60cd0064,0xf6500002,0xae5c000a,0xb05b0dc3}},	//   _olam, ائه_, זכור, tkäl
  { {0xe894008f,0x68e20011,0x2ee30111,0xf992000a}},	//   _пась, ciod, hijf_, _ברל_
  { {0xd7020010,0xc1780007,0x13a7002b,0xd3be004a}},	//   _кiра, etė_, سندی_, а́ть
  { {0x66cf06f5,0x69c10005,0x13060080,0x78bb0dc4}},	//   _bøke, _üles, мный_, _houv
  { {0x60cd003e,0x208a0063,0xca36000a,0xf674002b}},	//   _blam, ойни_, ונתה_, _سالخ
  { {0xafe60191,0xd00a000d,0x55580010,0xd36e0086}},	//   домл, жеме_, _хаця_, دهی_
  { {0x78bb0152,0x92b50029,0x3438002b,0xa856000a}},	//   _mouv, _يحتا, _رسند_, וירה_
  { {0x60cd0020,0xf412000a,0x78bb0dc5,0xa01b02dc}},	//   _elam, _ספג_, _louv, dföd
  { {0x60cd010c,0x78a90079,0xb05b0b14,0x90e60058}},	//   _flam, _onev, rhär, _يسعن
  { {0x78bb038d,0x80f60015,0x7c850054,0x60cd0dc6}},	//   _nouv, _تستض, нуђе, _glam
  { {0xa2d4005d,0x9f1a0015,0x95e9000b,0x32070034}},	// [1280] योक्, _وآخر_, टपुट_, _hyny_
  { {0x68e2005c,0x273b0011,0xba6a0015,0xd94607d9}},	//   wiod, _mână_, تحرك_, дежи
  { {0xdce90064,0x2d9c00dc,0x02fa004c,0x2241007c}},	//   _çoğu, _éve_, קלעמ, _õhku_
  { {0x78bb0152,0x588304ab,0x88bd002a,0xe7860c91}},	//   _couv, выша, _wiśn, дуко
  { {0x78a9065d,0x69030020,0xd5af0086,0xba560063}},	//   _dnev, võet, یفه_, _отвъ
  { {0x68e20dc7,0x6ea7000b,0x46a3006b,0x85ba0015}},	//   siod, खाएँ, качв, قاعس_
  { {0x78660015,0x68e200a6,0xf6000138,0x0000006a}},	//   _يدرك, piod, ымкi_,
  { {0x78bb0dc8,0x6abc001a,0x051700c3,0xe3c40015}},	//   _gouv, _horf, وزيع_, فْعَ
  { {0x66cf0c83,0x69c10020,0x25de000b,0x128a006b}},	//   _søke, _üler, _केरी_, ощни_
  { {0xc17a0036,0x76a60015,0x60cd0dc9,0xf7d7015b}},	//   оїм_, _تحرك, _slam, _חומש_
  { {0xa2d4000b,0xba9b000a,0xd6250015,0xb05b0dca}},	//   योग्, קסטי, _كعمي, skäm
  { {0xd4c60029,0xe4a50036,0xc1780007,0xc4c60015}},	//   _تغطي, _пріо, rtė_, _تتطو
  { {0xc1780007,0xe8f10008,0x351b0053,0x60cd0079}},	//   stė_, אֻם_, _וואנ, _vlam
  { {0x32070176,0xd3b70036,0xc2c40015,0x63a20dcb}},	//   _fyny_, _юлії_, _سيعي, _iron
  { {0x27fa005c,0x12fb0008,0x2ee30079,0x63a20dcc}},	//   ępny_, _והגב, rijf_, _hron
  { {0x6ee9016f,0x629a0409,0x62980c0a,0x9597000a}},	//   džbe, ldto, _havo, וכלו_
  { {0xa2a7000b,0x5b150137,0x660801de,0x62980091}},	// [1290] फ़ॉक्, емат, _lydk, _kavo
  { {0x6abc0026,0x29040035,0x78bb0dcd,0x0377000a}},	//   _corf, _akma_, _souv, ותמת_
  { {0x78bb038d,0x2d9e00c0,0x6abc00b8,0x6eff0089}},	//   _pouv, åtet_, _dorf, rábě
  { {0x629802d7,0xc052000a,0x200901d7,0x394100da}},	//   _lavo, ָ֖א_, _kyai_, rphs_
  { {0x28080015,0xe758005e,0x57480033,0x6abc0dce}},	//   وْمَ_, дичі_, дзім_, _forf
  { {0x6abc0176,0x66cf003c,0x62980dcf,0x3f4d003d}},	//   _gorf, _søkb, _navo, ižu_
  { {0xd5b10031,0x66360015,0x89340058,0x63a20dd0}},	//   افع_, ركيس_, _لعقا, _aron
  { {0x273b04f9,0xb9250029,0x78a900da,0x7ae5007c}},	//   _până_, _أفري, _unev, liht
  { {0x13e90036,0xf7700015,0x63a20dd1,0x32070dd2}},	//   ямий_, _نال_, _cron, _syny_
  { {0x7dee00dc,0x99980091,0x6d5a0091,0xf7700015}},	//   nősé, _gerų_, štai, _خاف_
  { {0x629800b8,0x13a7002b,0x2012002a,0x05740015}},	//   _davo, سنگی_, _szyi_, _لاند
  { {0x0ef8005d,0xe0d20086,0xf9da0053,0xd59a000a}},	//   ंक्स_, ازد_, פֿיל, _מבעל
  { {0x316c0024,0x62980dd3,0xcf3a005e,0x7ae5007c}},	//   audz_, _favo, ячні_, kiht
  { {0x62980007,0xe3b00086,0x248d0dd4,0x0000006a}},	//   _gavo, _خرم_, leem_,
  { {0xddc10036,0xdd92012c,0x3f4d0dd5,0x11d70058}},	//   аттi_, دوز_, ažu_, _تتشد
  { {0x248d00dd,0x91fc0024,0x8b660015,0x11da000a}},	//   neem_, rgāt, فاطم, _מחצב
  { {0xc4d20053,0x4c350033,0x6abd0065,0x6abc0dd6}},	// [12a0] אגן_, тэст, ोसूर, _porf
  { {0x89f60010,0x19f60180,0x88bd002a,0x9f7b000a}},	//   няец, нџер, _wiśl, _צניח
  { {0xa84a0029,0x19b90033,0x91fc003d,0x6abc0dd7}},	//   كلام_, муць_, lgār, _vorf
  { {0x7ae500f2,0xa2a10231,0x0000006a,0x0000006a}},	//   aiht, _कोस्,   ,
  { {0x66e60dd8,0x07a3005e,0x62830dd9,0x68430054}},	//   нода, лацн, _obno, унча
  { {0x69c500aa,0xb05b008c,0xda650015,0x0000006a}},	//   byhe, tkäk, _لافي,
  { {0x6728010b,0x69c1007c,0xf5260766,0x0000006a}},	//   _vidj, _ülep, нфин,
  { {0x62980dda,0x63a20ddb,0x692c0045,0xb7da0015}},	//   _savo, _pron, _eşec, _فوزا_
  { {0xe3b20115,0x62980ddc,0x53e60033,0x34370067}},	//   ارع_, _pavo, эцка, رسيد_
  { {0x629a02de,0xeb91000a,0x63a20ddd,0x0000006a}},	//   udto, בָט_, _vron,
  { {0x64a60010,0xb0cc005d,0x63a20dde,0x21670004}},	//   _пажа, ासंग, _wron, ниќи_
  { {0x63a200a7,0x45b7000a,0x34560015,0x3cfa000b}},	//   _tron, _רפאל_, _أنشأ, ंवों_
  { {0xd8db0008,0x62980ddf,0xbfa80bb9,0x09dd021e}},	//   לקטר, _tavo, нтре_, _मध्य
  { {0xb3e90029,0x7982005c,0x61eb00dc,0x8413005e}},	//   _تعمل_, łowy, állá, _сміх
  { {0xe29b0135,0x7ae500bc,0xa19401b7,0x7d090015}},	//   _זשור, viht, _райч, ِيزِ_
  { {0xb05b00f2,0x88bd002a,0x2f1602de,0x1c890015}},	//   kkäi, _piśm, væge_, بَرٌ_
  { {0x7dee0014,0xea670124,0x1b780029,0x9ee90029}},	// [12b0] tősé, ењен, فصلة_, _يفعل_
  { {0x69110613,0x63bd0595,0x3a74004a,0x2bb80058}},	//   gåen, øsni, ллур, راقة_
  { {0x1df90080,0x7ae50064,0xb9250015,0x7dee0030}},	//   _цены_, riht, نفطي, rősé
  { {0xf7710806,0xcdb6000a,0x7dee0030,0xa907006e}},	//   لات_, _ספרה_, sősé, ربان
  { {0x4cba000a,0xd8b80015,0x257a00aa,0x7d0d0de0}},	//   _חזרו, عدما_, eël_, mlas
  { {0x9f38000a,0x67d202d9,0x7d0d0de1,0x0000006a}},	//   תנגד_, рољу, llas,
  { {0xa2a1005d,0x6d5a016f,0x8aa40063,0x7d0d0de2}},	//   _कोष्, štav, _сряд, olas
  { {0x45180010,0x5925002b,0x7d0d0de3,0xddd50de4}},	//   нцыя_, _شکاف, nlas, razň
  { {0xf7730015,0x83fd0030,0x07350de5,0x7d0d0de6}},	//   _حاز_, egőr, _резю, ilas
  { {0x7d0d0156,0xc3c80029,0x25fa000b,0x97240040}},	//   hlas, عظيم_, _ऊँची_, _مفقو
  { {0x86020086,0xcb12000a,0x7d0d0de7,0x63ad0de8}},	//   _پژوه, שלי_, klas, _šand
  { {0xa2a1005d,0xf9920008,0x34950180,0x81d40033}},	//   _कोर्, ברט_, _јадр, уцьц
  { {0xf3670080,0xe28e0de9,0xe0d7006b,0x7d0d0dea}},	//   _чтен, _ка_, твя_, dlas
  { {0x200c0024,0x601e002c,0x11d50015,0x03d6004c}},	//   ādi_, _rámč, _لتبد, _בונם_
  { {0x82340029,0xfc3f002c,0xd24e0015,0xf1a9002b}},	//   _إرها, _kníh_, _بنى_, _زاغه_
  { {0x98b80024,0x7d0d0deb,0x753c0030,0x628103c1}},	//   _otrā_, glas, _érze, lflo
  { {0xd00f0015,0x69110dec,0xcf590033,0x1d070ded}},	// [12c0] _ولى_, tåen, _прэч_, тети_
  { {0x7d0d0209,0x4a430902,0xcf57000a,0xeb970054}},	//   alas, инув, _שבית_, ђих_
  { {0x442f0dee,0x7d0d0def,0x27e90052,0x0000006a}},	//   _ogg_, blas, úann_,
  { {0xc863005e,0x91ba000a,0xf7460df0,0x6d5c0dca}},	//   атши, ומעי, ведо, msra
  { {0x09290029,0xd7ef0029,0xe737068e,0x64490030}},	//   رسمي_, يكم_, веч_, dbei
  { {0xa7140010,0xcf93000a,0x6d5a006f,0xa2a1000b}},	//   ымлі, יטד_, štau, _कोल्
  { {0xd5b00029,0x09e6004a,0xb05b007c,0xafdb00cb}},	//   صفة_, _ровн, skäi, tbøk
  { {0x69c300f2,0x7d040df1,0x52ca000b,0x60c00012}},	//   änee, nois, िस्स, ömml
  { {0x64a305e6,0xa87b000a,0xb8d60157,0x62810df2}},	//   рања, _קאמר, जा_, fflo
  { {0x02a60191,0x7d0d0df3,0xca320008,0x64490024}},	//   трим, zlas, ים֙_, abei
  { {0x7d04022d,0xf4840086,0xd48f0355,0xb5ca002b}},	//   kois, _ماشی, _кр_, _توام_
  { {0x7d0400f2,0xf487002b,0x7c2b0091,0x76580061}},	//   jois, _لاهی, žgri, lavy
  { {0xc0e40010,0xfbdf00dd,0x7d040df4,0x7d0d055c}},	//   роўк, _leêr_, dois, vlas
  { {0x7658000c,0x645d0091,0x7f9403ae,0x752b0df5}},	//   navy, ųsit, јарх, _zigz
  { {0x2fcd010b,0x1eea002b,0x6d5c0df6,0x7d0d0df7}},	//   šeg_, روفی_, gsra, tlas
  { {0x8c3b00b8,0x656a002d,0xab950054,0x7b100012}},	//   _maßg, irfh, лабљ, säul
  { {0x5c070063,0xdb580010,0x76580df8,0x7d0d0df9}},	// [12d0] тява, вюх_, kavy, rlas
  { {0xd37b000a,0x19eb0021,0x7d0d0dfa,0x7b100012}},	//   ורמט, وراً_, slas, bäum
  { {0x7d0d0dfb,0x89340015,0x6f020125,0x2486006f}},	//   plas, لعنا, _íoca, _obom_
  { {0x01350053,0xf09f0144,0x71d7004f,0x0000006a}},	//   אָסט_, ndà_, כובד_,
  { {0x97350074,0xc7ab0015,0x2b470033,0xf7850015}},	//   اکرا, بدال_, _шэнг, التَ
  { {0x76580091,0xfc3f0046,0x2ed1000b,0x0000006a}},	//   gavy, _sníh_, _हतोत,
  { {0xceb400f3,0x05540033,0xa5090dfc,0x0000006a}},	//   ייס_, атыя, нека_,
  { {0x2619005d,0x38a40b1e,0xa8a40dfd,0x8a1802ed}},	//   येगी_, _кјуб, _крук, _росс_
  { {0x64490dfe,0xf794008f,0x27e0002d,0xd5bf0024}},	//   rbei, _катэ, úint_, _šāds_
  { {0x64490dff,0x6d5c008c,0x8bba004f,0xf09f03a0}},	//   sbei, ysra, ׂ֖ית, edà_
  { {0xfad6013a,0x27390016,0x62810e00,0x290f0e01}},	//   רותך_, _hèn_, rflo, olga_
  { {0x20c2002d,0x3f6a0e02,0x27390016,0x62810e03}},	//   _cóip_, нимо_, _kèn_, sflo
  { {0xe3650036,0xd496000a,0x7d040e04,0x249f0e05}},	//   _скли, _תכנת_, vois, mdum_
  { {0x249f0084,0xe2960925,0x6d5c0e06,0x8fa3011e}},	//   ldum_, _баш_, tsra, љаре
  { {0x7d04022d,0xf6520008,0xa0a60418,0x6d5c04f8}},	//   tois, מצם_, _байд, usra
  { {0x6d5c0048,0x7b1000b8,0x249f0e07,0x7cda0015}},	//   rsra, räum, ndum_, روذز_
  { {0xcb670175,0x2d850061,0x5336004c,0xdca3005e}},	// [12e0] лате_, çler_, ָנען_, щати
  { {0xda650196,0x66cf003c,0x8f9b0008,0x7d0400f2}},	//   لامي, _søkn, _טיפי, sois
  { {0x38cb002b,0xd256000a,0x98a60a13,0x7d040e08}},	//   کالی_, רשעה_, лиже, pois
  { {0x237f005c,0x28df000b,0x27390016,0x6d5a0073}},	//   ktuj_, पोलि, _bèn_, štas
  { {0xfe360008,0x4b550063,0x76580e09,0x58370127}},	//   ְרֵי_, _въст, tavy, узія_
  { {0x4e7a00b2,0xb8cb005d,0x3b0a0080,0x2ca00020}},	//   גאַצ, _को_, _чего_, ldid_
  { {0x45d409ef,0x2ca0007c,0xf5200033,0x0ec6000b}},	//   ройс, odid_, онкi_, रॉयड
  { {0x2ca00e0a,0x76580007,0x7e09000a,0x734a006b}},	//   ndid_, savy, כִפֶ, нчов_
  { {0x765800df,0xe6460e0b,0x66760002,0xc67600e5}},	//   pavy, _безп, _مدار, _مطاب
  { {0x4b7b0053,0x63ad0057,0x6b7b004c,0xa01b001a}},	//   עטיג, _šanc, ערינ, ffön
  { {0x5ab70053,0xe57a005e,0xf0b5005e,0x7f4401c2}},	//   אליע_, _їзд_, айнь, _atiq
  { {0x853b000a,0x8597000a,0x2ca001c2,0x55bb000a}},	//   _נגדי, _תדאג_, jdid_, _רמאו
  { {0xf09f0251,0x9f35005e,0x2ca00034,0x0000006a}},	//   rdà_, регі, ddid_,
  { {0x539b0008,0x11d60031,0x74130067,0x8c3b0012}},	//   _ניוו, _متعد, _اوها, _maße
  { {0x56370053,0x7f440e0c,0xfd130015,0xfce90015}},	//   ראלע_, _etiq, مجر_, نفسي_
  { {0x2bd9002b,0x361b004f,0x0000006a,0x0000006a}},	//   پارک_, תולד,   ,
  { {0x6d47002e,0xba55009c,0xe4ab000a,0x6d5a0030}},	// [12f0] spja, ивај, עֹלָ, átar
  { {0xb05b00b8,0xcb680002,0x2ca0007c,0x0ab80015}},	//   rkäu, امله_, adid_, ُطلب_
  { {0x6d5a002c,0x3835007a,0xe8590033,0x80aa000b}},	//   štar, анер, ваеш_, _जोडे
  { {0x237f0050,0x5c07006b,0x7a320030,0xda080015}},	//   ytuj_, _бяга, tűtí, ديمه_
  { {0x0a6b0431,0xb05b00f2,0xe72e034e,0xa8780015}},	//   _први_, lkäs, же_, احمر_
  { {0x0f5800a3,0xff58004c,0xa6840033,0xe736098a}},	//   ניום_, נבוך_, йлід, шеш_
  { {0xa564003b,0xb05b0a75,0xb9250015,0x3ebe030a}},	//   مدين, nkäs, _نفسي, ötti_
  { {0x91f50092,0xe795002b,0x38600125,0x3365014d}},	//   hác, _پارک, óirt_, авиг
  { {0x249f0e0d,0xd7fb0a23,0xc603003d,0x68eb0073}},	//   rdum_, _чув_, dzēš_, migd
  { {0x68eb0111,0x237f005c,0xa01b002e,0x6d45002d}},	//   ligd, rtuj_, tfön, _otha
  { {0x25b90087,0x237f002a,0x0477002b,0x897b000a}},	//   _جهاد_, stuj_, _ملاک_, תָ֖ה
  { {0x61ee002d,0x237f0d55,0x68eb0161,0x20560098}},	//   úbla, ptuj_, nigd, штор
  { {0xa01b05d7,0x443f0e0e,0x6d450e0f,0x0000006a}},	//   sfön, mcu_, _atha,
  { {0x71a50033,0x56b5000a,0x50d6002b,0x443f0e10}},	//   _вакз, ׁפָן_, ازگر, lcu_
  { {0x1c3a008f,0xa01b00dc,0x91e205c4,0xf1a8002b}},	//   вязь_, lföl, _моше, _مايه_
  { {0x1c460e11,0x645b0012,0xdddc0091,0x443f0e12}},	//   рнам, naui, perž, ncu_
  { {0xdcb70092,0x2ca00020,0xef1a0080,0x6e460086}},	// [1300] ởng_, rdid_, _ими_, _پنجم
  { {0xc3320008,0x4e1a0015,0xb05b007c,0xe5e50046}},	//   קוב_, _لتجد_, skät, íměř
  { {0x89f50033,0x8c3b0012,0xda650015,0x0f02000b}},	//   бяцц, _saße, صالي, लकीस_
  { {0x270e014e,0x6d3b0135,0x3dfb000a,0x76410e13}},	//   ित्र_, _שײכו, _יליד, _afly
  { {0x40e9000a,0xa01b0030,0x443f0e14,0x60c4002a}},	//   נַעֲ, jföl, dcu_, _moim
  { {0x316b005c,0xa01b0123,0x60c4008c,0x60d60034}},	//   ńczy_, dföl, _loim, _llym
  { {0xd6da0086,0x3f850045,0xb866002b,0x75d3002b}},	//   _یورش_, ălui_, _پازو, ييها
  { {0x399b00b2,0x499b0008,0x3864030d,0x63ad0e15}},	//   _בילד, _בשלב, _udmr_, _šana
  { {0x9696005e,0x86960054,0xf743058c,0xe73a0e16}},	//   _вреш, _вјеч, _мето, _рез_
  { {0xdce7005c,0x78a20e17,0x877b000a,0xe0c8000a}},	//   mują, ldov, _באמי, _אֲ_
  { {0x3a37011f,0xaa370053,0x21780010,0xd5a40086}},	//   ירים_, יטיק_, ыйны_, _دلای
  { {0xd4f50010,0x60d60e18,0x60c40e19,0xd4670e1a}},	//   _лячы, _clym, _coim, _вице_
  { {0xdce7005c,0x77f4000b,0xefb1002b,0x60c40e1b}},	//   nują, _अशोक_, سیدگ, _doim
  { {0x0eeb006d,0xb05b008c,0xa6f8004f,0x0000006a}},	//   тьми_, tkäs, אִֽי,
  { {0xdef8008f,0xeda40185,0xb2bb000a,0x3f820e1c}},	//   рыя_, ошто, _במגר, atku_
  { {0xdce70050,0x60d60026,0x78a20e1d,0x3cf80015}},	//   kują, _glym, jdov, لعقد_
  { {0x30780015,0xd497000a,0x68eb0e1e,0x4b550015}},	// [1310] _ضحية_, סכמת_, vigd, صَار
  { {0x6e95003b,0xdce7005c,0x7ee40029,0x443f00bd}},	//   _الدا, dują, _وكين, zcu_
  { {0x68eb0159,0xa01b0030,0xdb040003,0x443f002a}},	//   tigd, zföl, iviè, ycu_
  { {0xa3c70065,0xcd34009a,0xe708009a,0xdce70535}},	//   _उथल_, _گریب, یتون_, fują
  { {0xdce7005c,0x07a503de,0x443f0e1f,0x3ea1007c}},	//   gują, салн, vcu_, _kaht_
  { {0x443f002a,0x98bc003d,0x67230085,0xcb36000a}},	//   wcu_, īvā_, umnj, _לנשק_
  { {0x3ea10020,0x443f0e20,0xdce70091,0x2d830e21}},	//   _maht_, tcu_, aują, ntje_
  { {0xfdf80e22,0x3f820e23,0xcdf8000a,0x7bcd0003}},	//   ימוש_, ytku_, ימוי_, oyau
  { {0x60c4002f,0xe3e90086,0xdce7005c,0x443f0e24}},	//   _roim, دکان_, cują, rcu_
  { {0x443f0e25,0x65870010,0xa01b0e26,0xe2990054}},	//   scu_, _выдз, rföl, ћан_
  { {0xe3a50086,0x60c40e27,0xd5d40015,0x26c50034}},	//   _گشای, _poim, _وتمث, _iolo_
  { {0x236d018c,0xfd1f0092,0xa01b0e28,0xc9b6000a}},	//   prej_, _nhì_, pföl, צהרת_
  { {0x60c4022d,0x66cf003c,0x78fa0053,0x98a70091}},	//   _voim, _nøkk, רפרו, ūnė_
  { {0xc3320008,0x68fb0e29,0xd336000a,0x3f820e2a}},	//   _זוג_, _ljud, _פרצה_, rtku_
  { {0x60c40e2b,0xdce7005c,0x68e900c0,0x3f820057}},	//   _toim, zują, _omed, stku_
  { {0x6459003e,0xc2120008,0x2fda0115,0xb05b03a4}},	//   _jewi, _מהו_, _موعد_, skär
  { {0x3f9e0048,0x5baa02bf,0x2d830079,0x78a20046}},	// [1320] ātus_, ыкам_, atje_, vdov
  { {0x7e560001,0x68fb0e2c,0xf4120135,0x2bf50033}},	//   _утиц, _ajud, לפן_, іятр
  { {0xfbc90008,0x68fb00c0,0xdce7005c,0x27220092}},	//   עת_, _bjud, wują, _hưng_
  { {0x64590176,0xdce7005c,0x2fdd0064,0x291f0e2d}},	//   _newi, tują, _özgü_, _chua_
  { {0x26c5002c,0x96ea0127,0x907b000a,0x18670588}},	//   _bolo_, лька_, רטני, сачи_
  { {0x8f9b0008,0xdce7005c,0xd7f90036,0x96f8000d}},	//   טיני, rują, шує_, јект_
  { {0xdce7005c,0x6b840e2e,0x6c9a000a,0xc448002b}},	//   sują, ltig, ָשִׂ, لیان_
  { {0xdce7005c,0xd497004a,0x98350033,0x6b840144}},	//   pują, брь_, _дэфі, otig
  { {0x64590176,0xd2500029,0xa5070001,0xd3a30010}},	//   _dewi, ونة_, љења_, прэп
  { {0xdb9b0053,0x6b840e2f,0x68e900bc,0x87f90033}},	//   נסיר, itig, _zmed, _тэст_
  { {0xf202005d,0x6b84059b,0x7abb000a,0xd9fa000b}},	//   _रुख़_, htig, אציו, ्थित_
  { {0x6b8402d2,0x64590e30,0x75d30015,0x1074005e}},	//   ktig, _gewi, _عينا, плюю
  { {0xdfd80063,0x351b000a,0x2d830546,0x272200a1}},	//   бър_, _עודנ, wtje_, _cưng_
  { {0xd9fa000b,0x2d830030,0x27220016,0xa3c70065}},	//   ्थात_, ttje_, _dưng_, ैनर_
  { {0x691802c1,0xa5d8000a,0xbd450015,0xa2e50015}},	//   víen, בַּי, تنزي, _بأنن
  { {0x9d15005e,0x5c07004a,0x2d830e31,0x3ff50015}},	//   ідач, бяза, rtje_, _وكثر
  { {0x6b840e32,0x692c0061,0xfc300015,0x2d830e33}},	// [1330] gtig, _eşek, فحك_, stje_
  { {0x433b0053,0xfaf300e6,0x10140021,0xc911000b}},	//   טעמב, أثر_, _عبيد, ़त्म_
  { {0xfd1f0023,0x753a018b,0x7bcd00e8,0x91f50016}},	//   _thì_, _nutz, syau, hán
  { {0xa8150001,0x26c50e34,0xd7f10015,0x417b004c}},	//   одеш, _solo_, وكا_, רנאב
  { {0x660401e2,0x6c7a0053,0xa08c000a,0x26c50e35}},	//   şikl, _דארפ, רְבִ, _polo_
  { {0x2f5c00a3,0x501c000a,0x0bb6000a,0x1f5c000a}},	//   נדונ, אודו, _ולשם_, נדוא
  { {0x6459005c,0xddd5005c,0x26c504ed,0x291f0e36}},	//   _pewi, lazł, _volo_, _thua_
  { {0xf992000f,0xa3c7000b,0x753a0012,0x6d5a0003}},	//   _קרן_, ैनल_, _dutz, âtai
  { {0xdcfc0024,0x03a50e37,0x26c5016e,0x0000006a}},	//   ntrā, ципо, _tolo_,
  { {0xdddc00dc,0x12870086,0x07f80021,0x765a0079}},	//   zerű, حمدی_, _ارفع_, _gety
  { {0xaade000b,0xb05b008c,0x27220016,0x63a40e38}},	//   फोटक, tkäp, _sưng_, _šint
  { {0xa8790053,0x79850026,0x7b1000b8,0x297a0135}},	//   סאָר, ithw, läut, סטרא
  { {0xa3bb0074,0x94050087,0xc50c004c,0xc7ac000a}},	//   _حاضر_, _بوشه, _גלאָ, ְׁלָ
  { {0x7304005e,0x91f50015,0xa2a1000b,0x63a90e39}},	//   _епіз, _وأثا, _कोच्, mven
  { {0x63a90e3a,0x9db90033,0x6da305a7,0xed5a0e3b}},	//   lven, быту_, мира, роб_
  { {0x161e000b,0x60dd0028,0x63a90e3c,0x4c860033}},	//   येटर_, chsm, oven, ўлав
  { {0xab660036,0x79850026,0x6b8400b8,0x0aea01f3}},	// [1340] ювал, ethw, utig, адай_
  { {0x60230010,0x6b840e3d,0xc9d60040,0xaa16012e}},	//   _ідэа, rtig, يزاب, офеј
  { {0x18a605c4,0x88e6004a,0x6b840e3e,0xa84a0058}},	//   жаем, ожже, stig, للام_
  { {0x7188000a,0x765a02f2,0xe7aa0e3f,0x274a02d9}},	//   מְנַ, _sety, ивел_, ачко_
  { {0x63a90111,0xd90d002b,0xc7960015,0xafad004f}},	//   jven, ایق_, تشاب, ָיוֹ
  { {0x501b0008,0x7d1600f2,0x645d002e,0x2d850144}},	//   בונו, llys, ðsin, àleg_
  { {0xd5470083,0x8c3b00b8,0xa9670c1c,0xa2da000b}},	//   опје_, _maßn, _мира_, _पॄष्
  { {0x63a902de,0x387f0125,0x94aa0e40,0xf3660e41}},	//   fven, _gcur_, ртка_, отон
  { {0x63a90079,0x7d160e42,0x0000006a,0x0000006a}},	//   gven, ilys,   ,
  { {0x0bb70008,0x7d160026,0xc6d80008,0x6f02002d}},	//   קלים_, hlys, _פַּר, _íoch
  { {0x6ebe000b,0xf9a00033,0x7b100012,0xc2b700ce}},	//   शानु, днiм_, läus, ілює_
  { {0x859b000a,0x403501b0,0x63a90e43,0x0000006a}},	//   _כשבו, яемс, bven,
  { {0x63a904f9,0x69180077,0x545300fd,0x4ea7087f}},	//   cven, víel, _цвіт, орва
  { {0x79850026,0xe2970e44,0xf773000a,0xcf270015}},	//   ythw, _мач_, וקש_, ترجي
  { {0x7b1000b8,0x7817000b,0x3ceb0004,0x9980006f}},	//   häus, _तर्क_, аќам_, eďže_
  { {0xdcee0024,0x69c30519,0xdcb80342,0x91040054}},	//   tubā, änem, ощу_, _опје
  { {0x28ab005d,0xa088000a,0xc104002b,0x7b10008c}},	// [1350] _घोषि, _וְתִ, _تويي, jäus
  { {0x42370053,0x1ec40015,0x7e99002b,0x7d160e45}},	//   ַנדל_, _يقيّ, _اندر_, alys
  { {0xdcfc0048,0x39580026,0x0e9a0008,0xf3f90045}},	//   strā, _cwrs_, _השתל, iaţa_
  { {0x2366010b,0x21bb0135,0x79850e46,0x63a90e47}},	//   _ovoj_, יזבא, rthw, yven
  { {0xba77003b,0x7d0d0011,0x4cba000a,0x97d80015}},	//   _واست, moas, _הזרו, يظهر_
  { {0x7d0d0e48,0xbb3a000a,0x63a902b9,0x98aa0046}},	//   loas, _לעשי, vven, _kubě_
  { {0x39580026,0x7b1002ad,0x0000006a,0x0000006a}},	//   _gwrs_, räut,   ,
  { {0x63a9065d,0x5dfc0135,0x7d0d0af6,0xb8b70015}},	//   tven, יפונ, noas, _بإست
  { {0x63a90152,0xf3f90045,0x437500ce,0x69370160}},	//   uven, faţa_, чуйт, _ećet
  { {0x396400f2,0x2cf9000b,0x2366006f,0x63a90e49}},	//   _ässä_, ्कुल_, _dvoj_, rven
  { {0x7d0d00f2,0xe4d70015,0x07080015,0xe4d6002b}},	//   koas, _وتصب, _بيلي_, زویت_
  { {0x2106014e,0x63a900dd,0x361a000a,0x7d0d0045}},	//   रवेश_, pven, _הועד, joas
  { {0xe4560053,0x08760053,0x20550010,0xdfd200e5}},	//   _זינט_, הערט_, ьтэр, ريس_
  { {0x75290e4a,0xb3080015,0xb14502d9,0x63f40058}},	//   lmez, _وغول_, _енкл, _تأمر
  { {0x412a07be,0x471a004f,0xe1f6011e,0x0000006a}},	//   _локо_, מושג, _нгш_,
  { {0x01360008,0xb05b00f2,0x75290061,0x225c0061}},	//   _צרפת_, ljän, nmez, _zevk_
  { {0xfc030e4b,0xceb60058,0xfce302db,0x98a40073}},	// [1360] епто, _فحدث, хото, _gimę_
  { {0x7d1600dd,0x80250015,0xd336000a,0xb05b0123}},	//   slys, _غريم, פרעה_, njän
  { {0xbe3b0008,0x7d160e4c,0xda650015,0x8e57000a}},	//   _לעית, plys, باقي, _מייג_
  { {0x80bf005d,0xcb090135,0xc18c004c,0x7b100012}},	//   षाये, אל_, שטאָ, täus
  { {0xdc3700b2,0xa01b002e,0x20ef0046,0xc7960033}},	//   _מאכט_, rgög, dřil_, яржы
  { {0x65940010,0x66e3017f,0x7b100012,0xa01b001a}},	//   даку, ноча, räus, sgög
  { {0xceb30008,0x39e7006b,0x236605e3,0x7aee02f2}},	//   תיו_, _едро_, _svoj_, _imbt
  { {0x6813005c,0x752900dc,0x98a30a61,0x225c0061}},	//   _będą, gmez, _писе, _sevk_
  { {0xd3b8005e,0x3636006e,0x366a0117,0x0000006a}},	//   ілої_, _فراس, _газо_,
  { {0x28130015,0x51f8005e,0x20050061,0x246c0016}},	//   _أوكس, жною_, şlik_, ớm_
  { {0xd2570033,0x7aee01d7,0x7416002b,0x7a8b004f}},	//   чцы_, _mmbt, _کوشا, זָכַ
  { {0xe53b0008,0x55bb0008,0x09f70008,0x6937016f}},	//   _התאר, _למבו, למים_, _kćer
  { {0x7d0d04f9,0xa3cd005d,0xdfd8006b,0xbff803ca}},	//   voas, रहण_, пър_, зеях_
  { {0x57fb000a,0x3d950e4d,0x93fb000a,0x539b000a}},	//   מלכו, мигр, _פלגי, _לידו
  { {0x629a0e4e,0x7d0d0e4f,0x7e280138,0x0000006a}},	//   meto, toas, зіта_,
  { {0x51fb0008,0x01fb000a,0x7aee0079,0xfc3f016e}},	//   _להוצ, _לפול, _ambt, _baía_
  { {0x7d0d0e50,0xf094000a,0xab940054,0xfc3f0e51}},	// [1370] roas, _טנק_, натљ, _caía_
  { {0x75290046,0x8018012c,0x629a0e52,0xa3cd0065}},	//   zmez, _عزيز_, neto, रहत_
  { {0x629a0e53,0x69da007c,0x7529005a,0x3eb70073}},	//   ieto, _ütel, ymez, četė_
  { {0x3ce00089,0x2c750015,0x629a0e54,0x08d4005e}},	//   chiv_, _تُحس, heto, нція
  { {0xdcfc0011,0xf09f0092,0x629a0e55,0xd366002b}},	//   stră, goài_, keto, _جه_
  { {0x7b100012,0xfb350033,0x501c000a,0x387d0034}},	//   säur, _інвэ, צוגו, sgwr_
  { {0x65920001,0xe5a2005e,0x9479005e,0x20ef0046}},	//   вају, вищи, оспу_, třil_
  { {0x33d50036,0x05b40033,0xd6180015,0x629a007c}},	//   діот, эсіў, أتها_, eeto
  { {0xe7390176,0xb05b00c0,0x63a200dc,0xd299008b}},	//   _grŵp_, tjän, _cson, отні_
  { {0xe2990054,0x290f0e56,0xe7330015,0x2ca9052d}},	//   цао_, loga_, _أصر_, hdad_
  { {0xdb2400dc,0x7f4d0e57,0x91e5006b,0x63a20e58}},	//   ésén, _ataq, фоне, _eson
  { {0x3cf9005d,0x290f0e59,0xa988000a,0x0000006a}},	//   ्कों_, noga_, הָשִ,
  { {0x2ca90123,0x83640015,0x629a0e5a,0x6828004f}},	//   ddad_, _كدول, beto, ּֽרְ
  { {0x2ca90077,0xb05b008c,0x853c0091,0x629a0e5b}},	//   edad_, ljäl, _grės, ceto
  { {0x386d0bcf,0x290f016f,0x9db90010,0x8c4607be}},	//   _oder_, koga_, пыту_, дебе
  { {0xc212000a,0xb05b008c,0xa03a0015,0x2ca90e5c}},	//   _שהה_, njäl, _بأثر_, gdad_
  { {0xcaca0033,0x394d00bc,0x6f660033,0x5aca0e5d}},	// [1380] огае_, _česa_, _ўвоз, олам_
  { {0x89f60e5e,0x63a60e5f,0xab1a0033,0xb05b0123}},	//   وثائ, ækni, іцах_, hjäl
  { {0xdebb0008,0x290f012d,0xbfa30016,0x88860e60}},	//   _ומיל, foga_, hiể, длеж
  { {0x69da00dc,0x38cb0086,0x629a0e61,0x9a25002b}},	//   _ütem, يانی_, zeto, رعلن
  { {0x872a0010,0x98a40046,0x4c9b000a,0xab2a07be}},	//   оўка_, _zimě_, _ובכו, _мома_
  { {0x47330036,0x386d0e62,0x2bbd000b,0x569302d9}},	//   вніс, _eder_, ोहरा, вашт
  { {0xa96a067a,0x69d802de,0x248d0e63,0xb05b0123}},	//   _фиба_, øved, ffem_, fjäl
  { {0x66cf003c,0x98a600bc,0x636a0e64,0xb8660058}},	//   _søkt, omoč_, орог_, _زارو
  { {0xd90d04b6,0x22490061,0x629a0e65,0xa686011e}},	//   _این_, _şaka_, teto, _олад
  { {0xa823002b,0x66290030,0x21540033,0x68e20e66}},	//   _شکنن, áskö, нкоў, lhod
  { {0x02a3008f,0xe3af0086,0xfa77000a,0x386d019f}},	//   трым, هری_, ועית_, _yder_
  { {0x754900dc,0x3d08000b,0xf5060033,0x69c3008c}},	//   őszö, वकों_, _ўздо, änei
  { {0x26cc0e67,0x32d9002b,0x6d480046,0x0443013d}},	//   _kodo_, زدیک_, ídan, _речн
  { {0xe1ef0074,0x7ce30005,0x37d900b2,0xa2b30033}},	//   اسی_, _kõrg, פֿרע, _абшч
  { {0x9f340191,0xdc3a01e2,0xc327003b,0x26cc0e68}},	//   тері, _açık, _تكون_, _modo_
  { {0xe7ab002c,0x26cc04e6,0x0000006a,0x0000006a}},	//   _ďaľš, _lodo_,   ,
  { {0x290f016f,0x2ca90e69,0x68e205ba,0x386d00aa}},	// [1390] voga_, rdad_, dhod, _rder_
  { {0x26cc0e6a,0xcf270002,0x7a540015,0xeafb000b}},	//   _nodo_, _تربي, نضما, ्वेत_
  { {0x7ce30020,0x63a00034,0xb05b008c,0x290f0e6b}},	//   _nõrg, hwmn, yjäl, toga_
  { {0x26de0e6c,0xf8b1009a,0x0000006a,0x0000006a}},	//   _alto_, دکس_,   ,
  { {0x26cc0e6d,0xf7480015,0xcc76000a,0x6c56000a}},	//   _bodo_, وجوه_, _אגרת_, _רישא_
  { {0xf7700087,0xba740015,0x3f7c004c,0xdb0602de}},	//   شاه_, _لافت, קאוס, _arkæ
  { {0x66f2002a,0x66cf00cb,0x48770015,0x9733002b}},	//   ałko, _søks, _يدرس, _یکتا
  { {0x2f160e6e,0xce38000f,0x68e20e6f,0x27e60061}},	//   lægt_, ואות_, chod, bzon_
  { {0xe3b10115,0xf7730115,0x58840033,0x92f500e2}},	//   ارب_, _جاز_, _шыра, ечні
  { {0x16db003b,0xbfa30016,0x8bfa000a,0x6588025d}},	//   _بذرة_, riể, לִיפ, örhö
  { {0x78a90020,0xcb120008,0xb05b04f8,0xb93a000a}},	//   _kaev, רלי_, lkäy, ּׂשכ
  { {0x98b80048,0xe454008f,0x26c701a3,0xe3b10015}},	//   _kurā_, _акцы, ljno_, _مرت_
  { {0x95220074,0x43840029,0xb05b00f2,0x60cd0011}},	//   _حکوم, _للنق, nkäy, _doam
  { {0x78a90020,0x68e20156,0xa2d50015,0xc2c50015}},	//   _laev, zhod, _سيعت, _سيبي
  { {0x27e60014,0x7bcb0012,0x68e20046,0x32da000a}},	//   zzon_, ägun, yhod, _מחסנ
  { {0xc06f0089,0x76930064,0x35a6000b,0x64490e70}},	//   íští, lıyı, _कैफ़, ncei
  { {0x68360064,0x68e20227,0x628100bc,0x91290015}},	// [13a0] _müdü, vhod, oglo, _تسوق_
  { {0x76930061,0x09e60e71,0x62810e72,0x0000006a}},	//   nıyı, нозн, nglo,
  { {0xae5b0008,0x26cc0007,0xe93a00e5,0xd910002b}},	//   _מכיר, _rodo_, سسات_, لیس_
  { {0xa01b01d1,0x3860002f,0x89160029,0x68e20089}},	//   mför, úir_, ربائ, uhod
  { {0xcc3b004c,0x68e20e73,0xa01b0e74,0xcc350033}},	//   _מעכט, rhod, lför, _ахры
  { {0xdddc002a,0x644b019f,0xb5a60a32,0x7ce3007c}},	//   marł, _afgi, ерий, _põrg
  { {0x68e2016f,0xa01b04d4,0xe1e70015,0x26cc00bc}},	//   phod, nför, _إس_, _vodo_
  { {0x7ce30020,0xd37a000d,0x6934002b,0x7c89000a}},	//   _võrg, пчо_, _شکار, ֵאתִ
  { {0x26cc0e75,0x53970033,0xd4670054,0x48e30b9b}},	//   _todo_, евыя_, хиње_, _сотв
  { {0x026a0080,0xd257005e,0xa01b0123,0x7ce3007c}},	//   чший_, нцю_, kför, _tõrg
  { {0xf92a000a,0x6611002b,0x7ce3007c,0x6d48005a}},	//   ּוָּ, _پژوا, _hõre, ídal
  { {0xa01b00c0,0x64490144,0x68360061,0xdddc002a}},	//   dför, ccei, _güdü, karł
  { {0xf8b30008,0xaf370086,0x4e16000b,0x2d9e0061}},	//   אשר_, فرست, _दुबई_, çten_
  { {0x661a00f2,0xdddc0535,0x0000006a,0x0000006a}},	//   _kytk, darł,   ,
  { {0x673a08e0,0x6d5e0026,0x171b0053,0xef1f00dc}},	//   _mitj, _cwpa, פולע, ltük_
  { {0xa1830033,0x51830e76,0xf531004f,0x3e340058}},	//   _сышл, _суша, ֹ֥ל_, افِر
  { {0xb05b00f2,0x9be7005e,0x2f1602de,0x78a9007c}},	// [13b0] hjäk, хівк, tægt_, _raev
  { {0x3f64006b,0x539b004f,0x7c1400ce,0x3e69009a}},	//   _стъб, הימו, удує, _کجکی_
  { {0x6d5e0034,0x78a90072,0x0000006a,0x0000006a}},	//   _gwpa, _paev,   ,
  { {0x6ee2002c,0xf9900015,0xda08006e,0x19b80015}},	//   _vôbe, إبل_, رينه_, عطلة_
  { {0x9814008f,0x7ce30005,0x317e00b8,0x78a90020}},	//   льшч, _võrd, hutz_, _vaev
  { {0xcf940135,0xef1f0030,0x26c700bc,0xbdf8002b}},	//   רטס_, dtük_, ujno_, _آریا_
  { {0xceb4013a,0x27290092,0xb05b00f2,0x6605006b}},	//   טיס_, húng_, skäy, ъпка
  { {0xdb060c77,0x94790cfe,0x673a0079,0xe610002b}},	//   _erkä, фску_, _eitj, حشه_
  { {0x644907cc,0x2c37000a,0x250a002b,0xf506006b}},	//   rcei, עָ֔ם_, بروی_, ънъл_
  { {0x57f40731,0xf767002b,0x80aa000b,0xb05b0012}},	//   _спут, یا_, _जोड़ू, ljäh
  { {0x05740074,0x04950029,0x95570029,0x98d5000b}},	//   _ماند, _للاح, _أخطا, _दवाए
  { {0x3f6a0e77,0x95540015,0xb05b0012,0xa01b0123}},	//   мимо_, _إخلا, njäh, vför
  { {0xa8560008,0xd00f0015,0xefc7004a,0xb05b0012}},	//   כירה_, ْلُ_, влял_, ijäh
  { {0x6b8d00fb,0xe1f10074,0xa01b01d1,0xc7d6000a}},	//   dtag, _پست_, tför, דושי_
  { {0x92580029,0x8d630292,0xdddc002a,0x613e003d}},	//   _أشهر_, ивре, warł, _pūle
  { {0xa01b0e78,0xdddc002a,0xc3390046,0x249f0e79}},	//   rför, tarł, řídá, neum_
  { {0xa01b0c77,0xdca3005e,0x6b8d0e7a,0xcb6706a6}},	// [13c0] sför, шати, gtag, кате_
  { {0xa01b00c0,0x73fa000a,0xed46004a,0x7bc403a0}},	//   pför, וּבו, _иноп, rxiu
  { {0xa01b002e,0xef1f00dc,0xfd120015,0xa967006b}},	//   ngön, ztük_, _نجح_, виха_
  { {0xe8740086,0xb05b0012,0xdddc002a,0x673a001a}},	//   انشگ, gjäh, parł, _sitj
  { {0x2ca00020,0x2729002c,0xe72a002b,0x38cb002b}},	//   meid_, kúnd_, وستو_, بالی_
  { {0xc1780007,0x2ca00e7b,0x46f6006b,0x971301f3}},	//   yrė_, leid_, ъчет, аміц
  { {0x442000df,0x88840086,0x5fa9005d,0xd5630033}},	//   _ši_, _میان, _चैनल, атып
  { {0xef1f00dc,0x2ca00020,0x44200016,0x98b80045}},	//   ttük_, neid_, _ơi_, _dură_
  { {0xccf301c8,0x2b46002d,0x656a002d,0x07a30e7c}},	//   יכה_, íoch_, ssfh, _катн
  { {0x2ca000f6,0x21290e7d,0xef1f0030,0x98b80045}},	//   heid_, _shah_, rtük_, _fură_
  { {0x60f90e7e,0xf1a30063,0x7a7b000a,0xca7b000a}},	//   ення_, арян, וריס, וניט
  { {0x85f7000a,0xdb04008c,0x64a6012e,0x249f0e7f}},	//   _בצבע_, lviä, _јада, ceum_
  { {0x99620089,0x2ca00020,0xfebb0086,0x44200092}},	//   _níže_, deid_, واست_, _ái_
  { {0x2d470e80,0xff040151,0x6b8d09c0,0x83b7004f}},	//   _põe_, аясн, vtag, _שפגע_
  { {0xe29701ca,0x929b004f,0xc0cb00af,0x224e02dc}},	//   _рај_, _חיות, _жупе_, _iffk_
  { {0x3237000a,0x6b8d0e81,0xd5b8003d,0x5c74029f}},	//   _בטון_, ttag, _azāk_, илст
  { {0xfc64006b,0x6e46001a,0xbab90323,0x4c140058}},	// [13d0] ръсн, íubú, нгах_, لبكس
  { {0xbb190029,0x7a40099c,0xab940036,0x6b8d0e82}},	//   رياض_, vští, рифі, rtag
  { {0x99850029,0xac990029,0x6b8d0e83,0x2ca00e84}},	//   الصو, _كندا_, stag, beid_
  { {0xf7710e85,0x98ad0050,0x25b90089,0x60dd0205}},	//   مات_, _mieć_, _čsl_, nksm
  { {0x6d08000a,0xb05b0012,0x60dd0e86,0x7a400046}},	//   _יִשַ, rjäh, iksm, uští
  { {0xd6db0a2c,0x06840036,0x6d450e87,0x6f150077}},	//   ьте_, игін, _kuha, nozc
  { {0x6d450005,0xf3f904f9,0x29880e88,0xa8a70e89}},	//   _juha, maţi_, _исто_, _ирак
  { {0xf3f904f9,0xb9250029,0xe3a90054,0x60dd0079}},	//   laţi_, _إفري, екид_, jksm
  { {0xe7960086,0x42d50010,0xf4950086,0x89340058}},	//   _مالک, гіну, نشکد, _ضعفا
  { {0xdb0403af,0xf3f904f9,0x2fd90176,0x8c1c0008}},	//   rviç, naţi_, dysg_, ווחי
  { {0xf652000a,0x85470033,0xf3f90045,0xd408002b}},	//   _הצב_, _рэзе, iaţi_, فتیم_
  { {0xf1c30089,0x455a0008,0xcea9011f,0x61fc002d}},	//   _alší_, _נכנס, _מי_, úrla
  { {0xe2a80086,0x2ca0007c,0xf536000a,0xf8b60643}},	//   راین_, veid_, _ענני_, אפרי_
  { {0x201e0048,0xf3f90011,0x6d450e8a,0x69ca0012}},	//   āti_, jaţi_, _buha, äfek
  { {0xe2960063,0xf3f90011,0x2ca00e8b,0x7c260e8c}},	//   _сащ_, daţi_, teid_, _szkr
  { {0x61d60008,0x645b0079,0xad2600c3,0x98b80091}},	//   _תוקף_, nbui, ارسو, _kurą_
  { {0xf3f90011,0x2ca00e8d,0xeb2a0e3f,0x8b650015}},	// [13e0] faţi_, reid_, ежал_, لالم
  { {0x2ca00005,0xf3f904f9,0x76410034,0xab77012c}},	//   seid_, gaţi_, _ngly, املا_
  { {0x4229000a,0x499a0033,0x2d9a0123,0x3f820e8e}},	//   תֵּ֣, этая_, _uppe_, luku_
  { {0xa3e3005d,0x7d7b00f3,0x09060033,0xb78a0054}},	//   नना_, _אנטו, ыпен, ељке_
  { {0xda14005d,0x7c260024,0xf3f90011,0x3f820e8f}},	//   _तुरत_, _uzkr, baţi_, nuku_
  { {0xf3f904f9,0x7d0400b8,0xd6d00015,0x3179002a}},	//   caţi_, lnis, تقت_, ńszy_
  { {0x44260d85,0x7d040e90,0xd5b00058,0xdcfc013b}},	//   _szo_, onis, زفة_, hurč
  { {0xd3a60674,0x33740e91,0x7d040e92,0x68f9002a}},	//   гроп, агир, nnis, ciwd
  { {0x98ad005c,0xd70a0254,0xe8d7000a,0x48060969}},	//   _sieć_, _знае_, _עומר_, _спав
  { {0x3f82003f,0x92b600e6,0x33970015,0x96750033}},	//   duku_, احظا, اخية_, _выці
  { {0xe3b20086,0x6f150046,0x7d040e93,0x9b17004f}},	//   _گرا_, vozc, knis, רחיה_
  { {0xf3f904f9,0x2ba5005d,0x3a370008,0xca370008}},	//   zaţi_, _ऑनला, טרים_, טניה_
  { {0x80f40010,0x4426003f,0x6d450e94,0x20ef0046}},	//   спях, _uzo_, _suha, dřit_
  { {0x6d450e95,0xf3f90011,0x02a3006b,0x543b004c}},	//   _puha, xaţi_, _гръм, _נעגא
  { {0xf3f904f9,0x7d040e96,0x78a20e97,0xdbc60012}},	//   vaţi_, fnis, keov, töße
  { {0x4fd50036,0xd9040086,0xfd440033,0x7d040e98}},	//   _вжит, _ری_, сэрн, gnis
  { {0xf3f904f9,0xdbc600b8,0xdb230086,0x5c070033}},	// [13f0] taţi_, röße, موری, уява
  { {0xcf270015,0xf3f90045,0x6d450e99,0x7d040e9a}},	//   _حربي, uaţi_, _tuha, anis
  { {0x7d04018b,0xf3f904f9,0xad27002b,0xe8550015}},	//   bnis, raţi_, _مرحو, لناد
  { {0xf3f904f9,0x78a20134,0x48390029,0xd246002b}},	//   saţi_, geov, نكاح_, _ژن_
  { {0xf3f90011,0x0b8b006b,0x62980057,0x9c28005e}},	//   paţi_, _ясни_, _obvo, _бірж_
  { {0x4b7a0053,0xe7330015,0xd7580058,0x645b0546}},	//   _באשו, حصص_, اجنا_, wbui
  { {0x2d910e9b,0x2d830e9c,0x645b0e9d,0x0000006a}},	//   ntze_, nuje_, tbui,
  { {0x09e1014e,0xe7250016,0x8c3b0012,0x78a20e9e}},	//   पनीय, _dưỡ, _faßt, ceov
  { {0xb4d5005d,0x2d830156,0xe78700d0,0x443900c0}},	//   _सकी_, huje_, _љубо, äs_
  { {0x3ae400c0,0x7d040e9f,0xa3c6000b,0x3f820ea0}},	//   _köpa_, znis, _उपर_, vuku_
  { {0xd5bb005e,0x2d830ea1,0x645b055e,0x90c60ea2}},	//   _яса_, juje_, pbui, абне
  { {0xf530003b,0x8a16000a,0xb1420033,0x96340b1e}},	//   _فإن_, יחתו_, ўнял, _унхц
  { {0x8c3b0012,0xe3a5002b,0x3ae402dc,0x0000006a}},	//   _maßs, _خشای, _löpa_,
  { {0x3f82010b,0xc8e2005d,0x0efa0033,0x602301c6}},	//   ruku_, _खत्म_, тэмы_, ідра
  { {0x20ef0089,0xacf6049d,0x7d040ea3,0x12fa000a}},	//   třit_, ачај, tnis, _שהצב
  { {0x3f820ea4,0x7ce3007c,0x3d28002b,0xfce30432}},	//   puku_, _põra, اتسی_, оосо

  { {0x0b1a0029,0xac050029,0x7d040738,0x5a66004a}},	// [1400] نقرة_, مذكو, rnis, икаб
  { {0xba260010,0x2d830ea5,0x1c39004a,0xca560054}},	//   адзк, buje_, уясь_, ртањ
  { {0x7e7b0008,0xc8660ea6,0x8e7b000a,0x2d830ea7}},	//   _באיז, атли, _בניה, cuje_
  { {0xd7fa0ea8,0x8c960033,0x3ae40123,0x7c960ea9}},	//   кул_, _троі, _döpa_, _троц
  { {0x27e0017e,0x78a20eaa,0xc60e000b,0x4b55006b}},	//   áin_, reov, िथ्य_, _гъст
  { {0xb05b008c,0xd7030248,0xb8820046,0xcfb7004f}},	//   ljät, озчи, _řídk, ילני_
  { {0xafdb0134,0x5f09000b,0x986a0015,0xb7e4000b}},	//   ncør, _सदस्_, _لحذف_, कनहम_
  { {0xd49a00ce,0x3756009a,0x63b90416,0xd9430598}},	//   трк_, _نپرس, _brwn, _фети
  { {0x66760074,0x63b90026,0xa87b000a,0xa5070054}},	//   _ندار, _crwn, _שאמר, јења_
  { {0xeb97000a,0xd5b8003d,0x8c1b004f,0xb1e60058}},	//   סדיר_, _trā_, כופי, لأجه
  { {0x2d8301c9,0x3ce0007c,0xb5ca0058,0x0000006a}},	//   xuje_, kkiv_, _جوام_,
  { {0xd5fb0008,0xb92a005e,0x2d8301df,0x1074005e}},	//   _בפבר, нкiв, vuje_, олюю
  { {0x89370053,0x2d83005c,0x29370053,0x2906008c}},	//   ירטע_, wuje_, יאטן_, inoa_
  { {0xdefb065e,0x539b0008,0xdcef0046,0x2ee5001a}},	//   тым_, _סיוו, ědčt, ólf_
  { {0xcf8e0086,0x2729002d,0x8e380015,0x3ea30030}},	//   وژی_, núna_, لسفر_, rejt_
  { {0x9fe70074,0x2c780036,0x823b000a,0xd23b000a}},	//   _نسخه, ийсь_, _בעוצ, _בגול
  { {0x6f950029,0xdb0f0eab,0x2d830eac,0x0000006a}},	// [1410] _الخض, _arcá, suje_,
  { {0x62880ead,0x5c040033,0xd357000a,0x2d830eae}},	//   ngdo, іята, יימי_, puje_
  { {0xaf340074,0xf9f90029,0x3ce900cb,0xc9870eaf}},	//   _بريت, دفاع_, phav_, рузи
  { {0xb4d5005d,0x2004002a,0x9928005e,0x6fcb0065}},	//   _सके_, źmie_, аюча_, ामपं
  { {0xe72e0010,0xc7a80029,0x97a7004a,0xf0b8004c}},	//   зе_, لدول_, ррел, ילאר_
  { {0x9a84049d,0x0f58000a,0xbae50015,0x2d730085}},	//   _мусл, סיום_, _اكسي, oće_
  { {0x5e78000a,0xf6960015,0xb9e400ce,0x272901d3}},	//   בתון_, صنيع_, _діти, gúna_
  { {0xe9190036,0xccf2000a,0x2d730085,0xd8740058}},	//   _собі_, ּ֛ה_, iće_, _واقب
  { {0x36d50001,0xa8250086,0x33920029,0x368b0eb0}},	//   _лоар, _اکان, كليز, _асен_
  { {0xa2e50004,0x24770016,0x628800cb,0xa979000a}},	//   соод, ểm_, ggdo, ְאָכ
  { {0xd9f7005d,0xa0c6002b,0xd9f9000b,0xddc70046}},	//   ंछित_, ميدو, ्पित_, dajů
  { {0xaac9005d,0xf49400ce,0xa5350138,0x8fa60138}},	//   राडक, _мрію, _унеч, баме
  { {0x2d73016f,0xc4840033,0x10160033,0x34b20015}},	//   eće_, _флік, сьня, _رموز
  { {0x63a9003f,0xd9f9000b,0xfe7a0033,0x441a004f}},	//   mwen, ्पात_, ыёмы_, _גונס
  { {0xdef90010,0x8db50036,0x6d260029,0x6e290046}},	//   рыў_, ості, معرك, řebn
  { {0xa5da004c,0x1c460033,0x6b840eb1,0x6c590054}},	//   אַמי, снам, tuig, ијус_
  { {0x60c40eb2,0xdcfc0024,0xfc2a0033,0xbd46002b}},	// [1420] _inim, gurā, ужак_, _گنجي
  { {0x4bd9004a,0x98a60085,0xb05b07c2,0x0000006a}},	//   шься_, omoć_, sjät,
  { {0xbed70053,0x60d60064,0x35bd000b,0x63a90eb3}},	//   _הויז_, _koym, ्मफ़, hwen
  { {0xe8940191,0xb05b0eb4,0x69c10046,0x5ca60a32}},	//   іаль, ljär, _šlec, _уимб
  { {0xbcb70008,0xb7960001,0xa77302a3,0x316b002a}},	//   _הפכו_, срећ, зліч, ączy_
  { {0x6ffc0024,0xef1f0064,0x8f9b0008,0x63a90177}},	//   mācī, ltür_, ריסי, dwen
  { {0x7f3b0053,0x60c4016f,0x237f002a,0xd9a50015}},	//   נעצו, _onim, eruj_, _وصفً
  { {0xdbdd032c,0x63a90012,0x98bc003d,0x7afe0eb5}},	//   zšír, fwen, īvē_, lipt
  { {0xb7f2005d,0x4bfb004c,0x969609fe,0x6ffc003d}},	//   _आइटम_, ָליס, _греш, nācī
  { {0x77e4000b,0xaa9e0033,0x6eeb04d2,0xf2c609c3}},	//   कनीक_, дзiў, _kübe, ссин
  { {0x5a9b0053,0xba9b01ac,0xef1f0061,0x6d5c0771}},	//   נשטא, נסטי, ktür_, jpra
  { {0x7afe0064,0x692c0011,0xa193017f,0x2a3b004c}},	//   hipt, _aşez, чаюч, טעימ
  { {0x7afe09f0,0x5f94006b,0x351b000a,0xf7c7000a}},	//   kipt, пият, _גואנ, ֶ֔ךָ_
  { {0xff070010,0x60c40201,0x39580eb6,0xd5a60015}},	//   сямн, _enim, _otrs_, وف_
  { {0xd578000a,0x5297000a,0xf297000a,0xab5b0028}},	//   יָּר, _הדוב_, _הכור_, _krüg
  { {0x99860050,0x657c02cd,0x69de00cb,0x6e290046}},	//   łoś_, _århu, dype, řebo
  { {0x8b580029,0x8af90785,0x6d5c0eb7,0x3078004f}},	// [1430] مجلس_, анас_, apra, _התחש_
  { {0xe5090092,0xa9c70036,0x6e990010,0x2d730085}},	//   oặc_, йсек, _твор_, pće_
  { {0x7f3c00b2,0x69670015,0x394a00da,0x96f9002b}},	//   _געזו, صداق, _cubs_, یعتر_
  { {0xad270074,0x3869002e,0x9bc704ab,0x0cab0254}},	//   _درخو, úar_, _лёгк, _стои_
  { {0x89340015,0x78a4007c,0x17c909c3,0xab840004}},	//   أعلا, õiva, ргли_, _нурк
  { {0xab5b00b8,0xe73900a5,0xb579034e,0x8f8c000a}},	//   _prüf, шел_, ащих_, רְאֵ
  { {0xd575005e,0x61040030,0xaedc004f,0x68e201d0}},	//   цуль, lőle, רקוז, bkod
  { {0xe8940010,0x63a900b8,0xd5ae0029,0xd6180015}},	//   _нась, twen, ئفي_, حتها_
  { {0x59e1005d,0x42e90001,0x63a90186,0xd36e0015}},	//   पनकर, имио_, uwen, نهي_
  { {0x63a9018b,0x68e90089,0x60c4016f,0x13020010}},	//   rwen, _hled, _snim, дзьм
  { {0x54550254,0x64c50015,0x68e90eb8,0x63a90012}},	//   _двет, _ويطل, _kled, swen
  { {0x6d5c00bc,0x6112003d,0x0000006a,0x0000006a}},	//   vpra, kāle,   ,
  { {0xb05b0123,0x7fd602a3,0x2b590eb9,0x6fd601f3}},	//   tjär, ціні, _ntsc_, цінц
  { {0x539a0008,0x68e90026,0x68e20eba,0x02440015}},	//   _כינו, _lled, zkod, _فَهَ
  { {0x3d280086,0x82370031,0xc332000a,0x98a40091}},	//   متری_, _ارشا, _חוג_, _gimė_
  { {0xb05b0044,0x70560015,0xab660033,0x6eeb0012}},	//   sjär, _بنظا, жвал, _rübe
  { {0xbf660015,0xcee9002b,0x2a7801d7,0x6d5c0ebb}},	// [1440] _بدعو, _گرين_, _pdrb_, spra
  { {0x8e860015,0x68e90077,0x394a0ebc,0x69de0ebd}},	//   _بلده, _aled, _pubs_, type
  { {0xdcfc0011,0x8c46091c,0x68e20ebe,0xfe9b000a}},	//   gură, _мене, tkod, _דיימ
  { {0x718c0053,0x319a0053,0xab5b00b8,0xc7c6004a}},	//   רװאַ, יבענ, _brüd, жски
  { {0x7d090582,0x6753002b,0xc6900015,0x4c360088}},	//   čest, وخور, ِّت_, _фэнт
  { {0x290d003f,0x68e20ebf,0xdaba0033,0x57b30033}},	//   _ejea_, skod, _тымі_, ьбіт
  { {0xc4480086,0xab5b0020,0xbb4303e7,0xa2c8000b}},	//   میان_, _prüg, _церк, ़ास्
  { {0x1517003b,0x68e90198,0xd2500086,0x88c60015}},	//   يزية_, _gled, کند_, _بتسل
  { {0xdcfc0024,0x93b30033,0x3e570046,0x442202de}},	//   ltrē, дбыц, nětí_, æk_
  { {0x35a60033,0xe3af0015,0xe5a60783,0x87f902ed}},	//   _мазг, ئري_, _мизи, _уэст_
  { {0xd3d70086,0x610400dc,0xdcfc0024,0x6f1c00ea}},	//   مبیا_, zőle, ntrē, dorc
  { {0x6b9600c0,0x361b000a,0x2366002a,0xdcf5002a}},	//   ktyg, _דובד, _twoj_, orzą
  { {0xc49b0008,0xf0440010,0xafe40033,0x6f1c0a25}},	//   _כשאת, дэро, доўл, forc
  { {0x6f1c0085,0x8e840058,0xe29700af,0x0000006a}},	//   gorc, ولُه, _даљ_,
  { {0x52130001,0xccfb0001,0x27320011,0xc27b000a}},	//   _одшт, аћа_, mând_, _כרגי
  { {0x8b670029,0x9f6b0001,0x610400dc,0xc534000a}},	//   قائم, _кроз_, tőle, לָּה_
  { {0x6f1c0188,0x2d680045,0x01340015,0x2bbb0015}},	// [1450] borc, aşe_, _تعود, جازة_
  { {0xf43b013a,0xc3340008,0x27320011,0x3c440015}},	//   שתמש, לוּ_, nând_, ذَلِ
  { {0xdcf5005c,0x68e90ec0,0xfc3f0ec1,0x9dab006b}},	//   erzą, _pled, _país_, _тъпа_
  { {0xaac9005d,0xc237000a,0x3e570046,0x39440144}},	//   राहक, קראו_, bětí_, _cims_
  { {0x99540089,0xdcfc0011,0x69ca0028,0x37ab0481}},	//   _výše_, sură, äfer, ртен_
  { {0x7bda0008,0x68e90026,0xd00c000f,0x501c000a}},	//   _הקשו, _wled, יּוֹ, בודו
  { {0x63a2001c,0xdcf5005c,0x7ce3007c,0xae7c000a}},	//   _apon, arzą, _nõrk, שְׂת
  { {0xe9180036,0x6fcb000b,0x68fb0061,0x2ca90125}},	//   _досі_, ामां, _umud, nead_
  { {0x291d005c,0x4615002b,0xe758005e,0x27320045}},	//   mowa_, _کوار, _миті_, fând_
  { {0x27320011,0x291d005c,0x386d0ec2,0x2ca90ec3}},	//   gând_, lowa_, _heer_, head_
  { {0x42250036,0x386d00f6,0x7d080107,0x6f1c0ec4}},	//   ядов, _keer_, édsk, vorc
  { {0xd59a0008,0x291d0ec5,0x45b6000a,0x659a000a}},	//   _לבעל, nowa_, _מפעל_, _ליעק
  { {0x386d0ec6,0x7ce30020,0x2d830030,0x2ca90ba4}},	//   _meer_, _tõrj, erje_, dead_
  { {0x27320011,0x386d0ec7,0x02450015,0x22590015}},	//   când_, _leer_, _عَبَ, _الغد_
  { {0x291d005c,0x2ca9002d,0x63bb0e5f,0xa9280227}},	//   kowa_, fead_, lvun, ližš
  { {0x27320011,0x317a000a,0x291d005c,0xf0660080}},	//   mâne_, _האקד, jowa_, _экип
  { {0x291d005c,0x2d8300c0,0x61e10ec8,0xa2b2000b}},	// [1460] dowa_, arje_, lyll, _असम्
  { {0xe81f005d,0x8b230080,0x4b23000d,0x6b9600c0}},	//   _बड़ा_, едуе, емув, rtyg
  { {0x6edb013a,0x7edb000a,0x386d0ec9,0x18a60033}},	//   _החיפ, _הקיצ, _beer_, заем
  { {0x27320011,0xdcf5005c,0x3eaa0012,0x291d002a}},	//   zând_, trzą, lebt_, gowa_
  { {0xdcfc0048,0x4cbb0008,0x386d003e,0x9cd7039e}},	//   strē, _הזכו, _deer_, _זוכה_
  { {0x2d980152,0x8f9b039e,0xb4b4000b,0xaf77004c}},	//   otre_, מיני, _छोड़_, לענס_
  { {0x6d460eca,0x27320045,0x291d002a,0xceb3000a}},	//   _kika, vând_, bowa_, גיו_
  { {0x2d980152,0x61e10ec8,0x89eb000a,0xdb04007c}},	//   itre_, dyll, _הַמֵ, hviü
  { {0x27320011,0x6b8402de,0x53e60033,0x6d460ecb}},	//   tând_, nrig, яцка, _mika
  { {0xdb0d03af,0x386d0111,0x248d001c,0x76480007}},	//   rvaç, _zeer_, agem_, _ugdy
  { {0x27320011,0x6b840ecc,0x6d4600f2,0x64a60ecd}},	//   rând_, hrig, _oika, _нажа
  { {0x2fc00176,0x3d16005d,0x7ce30020,0x6d460ece}},	//   _brig_, थकों_, _võrk, _nika
  { {0x27320011,0x613f0024,0x3869002e,0xe424002b}},	//   pând_, _jūli, ðari_, _تکثي
  { {0x6d46022d,0x442600b6,0x6136002e,0xd37b0008}},	//   _aika, _iyo_, jálf, _פרוט
  { {0xe29b000a,0x929b0008,0x06fd0089,0x429b0008}},	//   _השור, _היות, _říká_, _הסוב
  { {0x9075002b,0xe5090016,0x6b840dd3,0x6d460ecf}},	//   _کهکش, hặn_, frig, _cika
  { {0x2d9c01d1,0x0f270036,0x6d460d25,0x2d980ed0}},	// [1470] _även_, _ньом, _dika, atre_
  { {0x61120024,0x7cea099c,0xa3bf005d,0x6d5a0264}},	//   māla, _výra, ुमत_, ítac
  { {0x291d005c,0x752200dc,0xab5b00b8,0x6e9a000a}},	//   towa_, _okoz, _brüc, _ובתח
  { {0xf7710196,0xddde0089,0xc7b10015,0x39950ed1}},	//   نات_, _nepř, َّا_, rås_
  { {0x3f8b0064,0x61120024,0xab5b00b8,0x291d005c}},	//   nucu_, nāla, _drüc, rowa_
  { {0xd246003b,0x386d00f6,0x6d460297,0x291d0ed2}},	//   _لن_, _weer_, _zika, sowa_
  { {0x6721018c,0x5e580053,0x9f440089,0xe7160015}},	//   _vklj, ליגע_, ámé_, بيوت_
  { {0x61e1008c,0x6112003d,0x7d0d0ed3,0x63bb0ed4}},	//   vyll, kāla, nnas, tvun
  { {0x61e10026,0x53c9005e,0x6ef0007c,0xdc8c000a}},	//   wyll, ігом_, _häbe, צְהָ
  { {0x6721010b,0x7d0d0176,0x610400dc,0x61e10ed5}},	//   _uklj, hnas, dőla, tyll
  { {0x7d0d0ed6,0x2d980003,0x63bb0ed7,0x7a88004f}},	//   knas, xtre_, svun, הָרַ
  { {0x63a40011,0x63c80030,0x361a000a,0x61e10ed8}},	//   _ţine, érnö, _וועד, ryll
  { {0x61e10176,0x08760053,0x889a00a3,0x1eaa0015}},	//   syll, וערט_, חברי, ياسي_
  { {0x2d980ed9,0x6d46013c,0xada60eda,0x75290edb}},	//   ttre_, _sika, магл, llez
  { {0x2d980152,0xddc700bd,0x3eaa0012,0x7d0d001a}},	//   utre_, tajš, rebt_, fnas
  { {0x7d0d0ac1,0xd1320002,0x6112003d,0x2d980edc}},	//   gnas, _جمع_, bāla, rtre_
  { {0x83b500b2,0x2d980edd,0x0b460127,0x6136002d}},	// [1480] ופּע_, stre_, днан, tálf
  { {0x6d460ad5,0xbe660002,0xa01b0bc2,0xcaa60015}},	//   _wika, _تهدي, rgöt, بصري
  { {0x6d460048,0x7c26005c,0x9e630033,0x6136001a}},	//   _tika, _wykr, _швэд, rálf
  { {0x18670124,0xfd450010,0x395c0024,0xcb090008}},	//   даци_, _пэўн, īvs_, בל_
  { {0x7d04008c,0xda660040,0x75290085,0xa01b0a88}},	//   miis, _ياسي, dlez, lgör
  { {0x644b0ede,0x64590111,0x6eeb0064,0x752200bd}},	//   _aggi, _afwi, _lübn, _skoz
  { {0xdcf5005c,0x7ae30edf,0xaa57002b,0xe5a30054}},	//   erzę, önte, _آلفا_, вији
  { {0x290201d1,0x75290ee0,0x4254002b,0x3f8b0061}},	//   _öka_, glez, کندر, yucu_
  { {0x38660ee1,0xb7da0015,0xddde0046,0x228600ce}},	//   mbor_, _بوذا_, _vepř, мунг
  { {0x6d5e016f,0x65c6085d,0x75290089,0x51f8005e}},	//   _otpa, _обза, alez, зною_
  { {0xdcf5005c,0x752902c1,0xc4c60015,0xe8df0016}},	//   arzę, blez, _يتصو, _hiền_
  { {0xf5030063,0x6ef00123,0x3f8b0061,0x6112003d}},	//   _изхо, _näbb, tucu_, tāla
  { {0x7ce30005,0xc0e40010,0xe53b0008,0x6d5e0ee2}},	//   _kõrv, тоўк, _ותאר, _atpa
  { {0xe8df0023,0x3f8b0064,0x6112003d,0x0ca7000b}},	//   _miền_, rucu_, rāla, ख़्म
  { {0xdd94008f,0xc3480023,0xe8df0092,0xa01b0123}},	//   кары, _nổi_, _liền_, ggör
  { {0x201e0011,0x30a70292,0x3f8b0061,0x7e99002b}},	//   ştia_, _цркв, pucu_, _کندر_
  { {0xfd44008f,0x7d0d0ee3,0x6ef00012,0x386606c0}},	// [1490] тэрн, rnas, _säbe, dbor_
  { {0x0dcb010f,0x4ac9005d,0x19eb0115,0x7d0d0ee4}},	//   _думи_, राइव, يراً_, snas
  { {0xceb20053,0x212b00a9,0x7d0d001a,0xb5820033}},	//   _גיי_, olch_, pnas, _знiк
  { {0x9e040033,0xb8150099,0xe8df00a1,0xc34800a1}},	//   _шчыл, ндеј, _biền_, _dổi_
  { {0xd139002a,0x7cf10123,0x27e9001a,0x78ab00aa}},	//   mtąd_, _vård, áan_, regv
  { {0x6d580003,0xc1780091,0x38660ee5,0xf6e70138}},	//   _évac, ksė_, abor_, ьцен
  { {0x96b80015,0x38660123,0x27e907d4,0xa954008b}},	//   بانز_, bbor_, šan_, _аксі
  { {0xdb04001a,0xdcf5002a,0x7cf10ee6,0x0000006a}},	//   lvið, trzę, _fåre,
  { {0x613601b2,0x2409004a,0x68e4008c,0xe2990ee7}},	//   nále, янии_, öide, пап_
  { {0xe2990054,0x75290046,0xaad20065,0xe1610138}},	//   чао_, slez, सायक, лямi_
  { {0x91e50342,0xf6470054,0x9939004f,0x3ce90072}},	//   хоне, _цхан, ּתָה, kkav_
  { {0xdcf5002a,0x27320045,0x68f90061,0xa01b0123}},	//   przę, mâna_, _çadı, vgör
  { {0x7d040209,0x290f0ee8,0x13a7002b,0xdb04001a}},	//   viis, inga_, _آنتی_, kvið
  { {0x61360089,0x7ac4000b,0x3cfd000b,0xa01b0123}},	//   dále, राज़ी, रोसे_, tgör
  { {0x7d040209,0x7e530015,0x6da306a6,0xa0a608fc}},	//   tiis, انفص, лира, _зайд
  { {0xe0580086,0x7cea0057,0x8c960033,0x6112003d}},	//   _زیست_, _výro, эргі, mālo
  { {0x7d040044,0xdb04001a,0x249f001a,0xbb4a012c}},	// [14a0] riis, fvið, ifum_, سلان_
  { {0xda650029,0x7d040e95,0xfe42002b,0x6c330015}},	//   نامي, siis, _مکزی, افكا
  { {0xf9690036,0x10ba0008,0xbca60015,0x6112003d}},	//   дрій_, ּזְב, _كمدي, nālo
  { {0xdd2f0089,0xadd7000a,0xc8b60015,0xcb09015b}},	//   pěšn, _נוכח_, عصاب, זל_
  { {0x3c770008,0x569402e1,0x38660ee9,0x387f0034}},	//   _אתכם_, валт, rbor_, _ddur_
  { {0x290f0eea,0xa8240086,0x3f7b004c,0x4991002b}},	//   anga_, _یکشن, לאנס, _چیلر
  { {0x212b0026,0x7e9b000a,0x95970054,0x6b490091}},	//   ylch_, פסקו, етњу_, _užga
  { {0xe8df0023,0x499b000a,0x9553002b,0x9326002b}},	//   _tiền_, _משלב, دخوا, کربن
  { {0x6d3b000a,0x7ce3007c,0x0000006a,0x0000006a}},	//   התקנ, _tõrv,   ,
  { {0x877b0008,0xdb970053,0x13f30080,0xdb060030}},	//   _מאמי, עדיט_, узья, _erkö
  { {0xe6d9002e,0x27e60eeb,0xc1780091,0x61360eec}},	//   _þráð, lyon_, usė_, zále
  { {0x25d7004f,0x28c60065,0xef1f02ad,0x0000006a}},	//   _רואן_, _रोमि, grün_,
  { {0xe8df0023,0xd14a0086,0x6d5a0eed,0x27e6043a}},	//   _hiển_, _کشتن_, ítan, nyon_
  { {0x9f350036,0x26de003f,0x61360057,0x3eba00da}},	//   тегі, _joto_, vále, _capt_
  { {0xb2bb000a,0x26de0eee,0xd72d005e,0x7e7500bc}},	//   _זמור, _moto_, _лiце, razp
  { {0x6b8d0eef,0x61360ef0,0x26de0ef1,0x7cf10ef2}},	//   tuag, tále, _loto_, _sårb
  { {0x3eba0011,0x7d240067,0xfa870054,0x853b000a}},	// [14b0] _fapt_, افقن, ећем, לגלי
  { {0x26de04ed,0x61360046,0x27e609cf,0x3ce900bc}},	//   _noto_, rále, dyon_, skav_
  { {0xab5b018b,0x7b0b0024,0x249f002e,0x69070010}},	//   _grün, kļuv, yfum_, нядз
  { {0xa9540191,0x6c790053,0xdb04002e,0x290f0ef3}},	//   укці, _קאָפ, svið, unga_
  { {0x60cd003f,0xcc76000a,0x9b58006b,0x26de0ef4}},	//   _mnam, _שעשה_, _пият_, _boto_
  { {0x86980063,0xe8df0092,0xd6db0758,0x7ce30020}},	//   етът_, _biển_, яте_, _võru
  { {0x5b140292,0x27e603e4,0x60cd0847,0xa8a70ef5}},	//   _смрт, ayon_, _onam, _прак
  { {0x27e60ef6,0xe8df00a1,0x0000006a,0x0000006a}},	//   byon_, _diển_,   ,
  { {0xf6990124,0x249f0ef7,0x6f07002a,0x26de0ef8}},	//   _овај_, rfum_, kijc, _foto_
  { {0x929d0053,0x4c3c000a,0x6112003d,0x66270015}},	//   _פֿון_, התחב, tālo, _كراك
  { {0xe4e70036,0x9f440046,0xeab2000a,0x0596002b}},	//   _підн, ámí_, בֹר_, _لانگ
  { {0x23b5003b,0xd00a000d,0x67230ef9,0xf494006e}},	//   _لمؤس, деме_, lonj, _مشهد
  { {0x78bb0152,0xe2990345,0x3ae40123,0xa0670054}},	//   _mauv, _жал_, _köpt_, ђара_
  { {0x60cd0efa,0x67230375,0xdb240030,0xe2c8005e}},	//   _enam, nonj, ésün, _плід_
  { {0x8c960010,0x7c960063,0x27e60064,0xc69200a3}},	//   краі, крац, zyon_, יאם_
  { {0xfbe700a7,0xe6d9002e,0xc5f20008,0x7c850054}},	//   _thể_, _þræð, בדל_, луђе
  { {0x3eba003c,0xfeba0015,0x6fb3002b,0x1c460efb}},	// [14c0] _tapt_, _قادت_, _نميا, тнам
  { {0x60cd0dd9,0x0000006a,0x0000006a,0x0000006a}},	//   _znam,   ,   ,
  { {0xd9460efc,0x7c2902de,0xdcee0061,0x26de0efd}},	//   вежи, _øern, şkır, _roto_
  { {0xe786008f,0x8d77000a,0x0906006b,0x480a0923}},	//   вуко, _בגטו_, ъпен, меен_
  { {0x38cb0086,0x67230db2,0xbc1a005e,0x64550046}},	//   ظامی_, fonj, _ціні_, ězil
  { {0xc9860029,0xdb0f001c,0x67230962,0xdcfc003d}},	//   _لشري, _escâ, gonj, ktrī
  { {0x27e60efe,0x66e300d0,0x80b2000b,0xd90d002b}},	//   syon_, роја, ज़ाइ, _کین_
  { {0xef1f00dc,0x44b40180,0x6abc0eff,0x399c0144}},	//   erül_, убис, _harf, mís_
  { {0x26de04af,0x96960036,0xb2c60015,0x399c0f00}},	//   _toto_, _ареш, نغدو, lís_
  { {0x78bb0237,0x6723030d,0xe8df0016,0x26de008c}},	//   _zauv, conj, _tiển_, _uoto_
  { {0x68e0001a,0x399c0f01,0x04960015,0x6abc0f02}},	//   _komd, nís_, _للضح, _marf
  { {0xb97b0008,0x7cf80030,0xe4e301f3,0x7cea001a}},	//   ונטי, _hírf, _вішн, _dýrk
  { {0x399c002d,0x53b6000b,0x68e3016e,0xf8b3000a}},	//   hís_, _अनिश, êndi, בשר_
  { {0x3d9501e8,0x6ee2059d,0x0000006a,0x0000006a}},	//   лигр, _sôbr,   ,
  { {0x5e580191,0xdef8008f,0x7bc6005c,0x9e090029}},	//   тися_, тыя_, _arku, ريرك_
  { {0x853c0091,0x60cd0f03,0x3cf80015,0x8c640555}},	//   _spėj, _unam, نعقد_, итуд
  { {0x6d580152,0x7b740015,0x7b0b003d,0xbc27005e}},	// [14d0] _évan, لطلا, kļut, тєви
  { {0x8c440124,0x539b0008,0x78bb0152,0xe8df0092}},	//   ређе, וימו, _sauv, _miễn_
  { {0x61360014,0xce330086,0x78bb0152,0x69d80bfa}},	//   lála, _خودک, _pauv, øvep
  { {0xfc64010f,0xa2a9000b,0xfc3f0077,0x39150033}},	//   _върн, _जॉन्, _maíz_, ымер
  { {0x61360014,0xd3660074,0x9cd60008,0xab5b0012}},	//   nála, _ده_, _עושה_, _krüm
  { {0x2d910089,0xa5b90001,0x273b0092,0xc724005e}},	//   ouze_, ећих_, iêng_, адій
  { {0x6136002f,0x645b0f04,0xdb1d016e,0x399c030b}},	//   hála, tcui, _ersã, cís_
  { {0x38c200dc,0x91fc0024,0xce38000a,0x6abc0061}},	//   térő_, abāk, כאות_, _zarf
  { {0x07090015,0xd299005e,0xdb04008c,0x645b0f05}},	//   _كيري_, нтні_, rviö, rcui
  { {0xe8df0023,0x61e80176,0xa6f9000a,0x61360f06}},	//   _diễn_, fydl, _אִ֣י, dála
  { {0x394d049c,0x04950115,0xb146068e,0x13a7002b}},	//   _kies_, _ملاح, лнол, رنگی_
  { {0xa6e20084,0xe8d5000a,0x201e0061,0x6d5a0f07}},	//   _öðru, אוֹר_, ştim_, ítam
  { {0x61360f08,0x2d850046,0x80b3000b,0xa78c000a}},	//   gála, álen_, इज़े, ֽאלֹ
  { {0xe8d0005d,0x394d0708,0xe2990f09,0x6d410003}},	//   _सच्च, _lies_, _чак_, ïlan
  { {0x523900b2,0xd3360008,0x82d60008,0x3d28002b}},	//   _אײַנ, _גרסה_, _תוצג_, نتری_
  { {0x399c0251,0xacf50054,0xc212000a,0x6abc0f0a}},	//   vís_, ачуј, _להו_, _sarf
  { {0xdc750010,0x6abc0f0b,0x80d1000b,0x5f2a0004}},	// [14e0] рысь, _parf, धारे, _поим_
  { {0x80a0014e,0x89f6008f,0xa3d4000b,0x7cf10123}},	//   ग्रे, ляец, हमत_, _våra
  { {0x7ce30005,0xcd360029,0x6abc00c0,0xe704002b}},	//   _võrr, _مرحب, _varf, یستی
  { {0x6abc0f0c,0xdb0f0144,0xb86500c3,0xa87600c3}},	//   _warf, _escà, لاهو, اطات
  { {0x62830f0d,0x394d0f0e,0xa9250015,0x98730033}},	//   _odno, _dies_, جعله, сліц
  { {0x3f720024,0xd5b00029,0x7bcb000a,0x394d0b35}},	//   iņu_, قفت_, _אֶלֶ, _eies_
  { {0xfa77000a,0x6a9b000a,0xa6c70015,0xdb230030}},	//   _תעלת_, _רשלנ, طويل_, _óráj
  { {0x2904000c,0xc4480086,0xfc3f02c1,0x62830b90}},	//   _umma_, نیان_, _raíz_, _adno
  { {0xd250003b,0x9cd70008,0xe78a0086,0xc6960015}},	//   ينة_, רופה_, _سپاه_, _مشاع
  { {0x61360014,0x7cf800dc,0xe8df0092,0x3f720024}},	//   vála, _hírd, _viễn_, dņu_
  { {0x6234023e,0xb1150342,0xe6160004,0xf1a301c5}},	//   рену, имош, _сфаќ, брян
  { {0x6136002d,0x361b000a,0xe8df0016,0x62830f0f}},	//   tála, _אובד, _tiễn_, _edno
  { {0x8cbf005d,0xe47b0053,0x29370053,0xe4e90015}},	//   _लोगो, _טראכ, טאטן_, _جعله_
  { {0x4383003b,0xb3bb0008,0xbe650029,0x61360f08}},	//   _الوق, _נמוכ, شهري, rála
  { {0x61360f10,0x6d580152,0xeca7000d,0x9f440089}},	//   sála, _éval, лјан, ámá_
  { {0x55770053,0x61360f11,0x319b000a,0x3eb102ad}},	//   טעלן_, láln, _נבחנ, sezt_
  { {0xe8df00a7,0x1bd400a4,0xab95005e,0xab5b0012}},	// [14f0] _hiện_, ботя, ризі, _trüm
  { {0xe8df0023,0xab940036,0x63bd02de,0x394d0b35}},	//   _kiện_, сифі, æsni, _sies_
  { {0xc333000f,0x127b004c,0x394d0f12,0x28c6000b}},	//   צוע_, גאבע, _pies_, _रोहि
  { {0xd7f10029,0x2fc900dd,0xc052000a,0xdbeb0030}},	//   يكا_, _krag_, ַ֖ד_, lőír
  { {0x61360107,0xbc19000a,0x960d000b,0xdcee0091}},	//   káln, _יוֹש, िप्ट_, erbė
  { {0x2f5c000a,0xb8080015,0x394d0012,0x7bc80643}},	//   עדונ, ديهم_, _wies_, _עֶרֶ
  { {0x8aa40191,0xf7730086,0x45190f13,0x6d4f003f}},	//   _уряд, _گاز_, кция_, _kica
  { {0x7cf80f14,0x2bc9000b,0xed58000a,0xf42904e7}},	//   _vírg, रिपा, נבחר_, койл_
  { {0x54a40029,0x28f80a61,0x61360247,0x6d4f0f15}},	//   صحيف, _сеть_, fáln, _mica
  { {0xe8df0092,0x42550e88,0x03a800e6,0xfbd20008}},	//   _biện_, штит, اديو_, קתי_
  { {0x7cf800dc,0x6b8d0273,0x95570015,0xab5b0061}},	//   _híre, hrag, _إخطا, _brük
  { {0xe8df0023,0x3f720024,0x0fc60036,0xe04601e5}},	//   _diện_, tņu_, аймн, инни
  { {0x61120024,0x613d00dc,0x3f72003d,0x2d850046}},	//   nāli, zélg, uņu_, šlel_
  { {0xdcee0089,0x7cf8002d,0x2fc90f16,0xf1f90015}},	//   ědče, _míre, _drag_, _لعبت_
  { {0x2d9e038d,0x6d4f08c0,0x6b8d0273,0x65c00046}},	//   îte_, _bica, erag, máhá
  { {0x3fe60036,0x6b8d0f17,0x82340015,0xa2cd000b}},	//   _вжив, frag, _ارها, ताक्
  { {0x61360014,0x70b2005d,0xca560004,0xdbc70012}},	// [1500] lálo, ज़ील, атењ, rößt
  { {0xff7b0053,0x0f7b000a,0x7bc40f18,0x3ae8009a}},	//   _שטימ, _שאיב, rviu, دبری_
  { {0x6d4f03af,0x61360f19,0x6b8d0f1a,0x442f0091}},	//   _fica, nálo, arag, _lyg_
  { {0x2c5c005c,0x3ead016f,0xdbdc0f1b,0xf9890018}},	//   _bądź_, đete_, lšíc, اخله_
  { {0xd117000a,0x26350016,0x3a26002a,0x6b8d0f1c}},	//   סקנה_, _áo_, łop_, crag
  { {0x7cf8002f,0x6d440026,0x613d00dc,0xae0b000b}},	//   _díre, lmia, méle, _हेडन_
  { {0xd5b00029,0x613600dc,0x613d0030,0x7e7c01c2}},	//   سفة_, váln, léle, iarp
  { {0x54b80063,0x61360046,0x6112003d,0x7d160f1d}},	//   угия_, dálo, bāli, nnys
  { {0x2bc9005d,0x7e7c0f1e,0x93770033,0x613d0030}},	//   रिया, karp, абыт_, néle
  { {0x41c60010,0xdbdc0227,0x46f4000a,0xa79b000a}},	//   аёма, jšíc, _פֶּן_, _בשמח
  { {0x20d50029,0xdcf60046,0xd250002b,0x2a57000a}},	//   مقدس, ýběr, ينک_, יבין_
  { {0xab5b018b,0xe8df0023,0xb3560086,0x7e6e00c0}},	//   _früh, _viện_, _پیدا_, ebbp
  { {0x7cf10293,0xb4fb000a,0x6d44002a,0x61180033}},	//   _dårl, _בלאר, dmia, рояў_
  { {0x7e7c00c0,0xe8df0092,0x613600dc,0x6b8d0f1f}},	//   garp, _tiện_, láll, vrag
  { {0x13b6014e,0xab5b03ff,0xfff60086,0x433b000a}},	//   _अनुभ, _trük, لکیت_, _שעוב
  { {0x613600dc,0x6b8d0f20,0xccf80054,0x9099006b}},	//   náll, trag, аћу_, _свит_
  { {0x113c0008,0xfbd00015,0xdd2f0046,0x6b8d0f21}},	// [1510] _בתהל, وتك_, _těžb, urag
  { {0xf9c70f22,0xb4e3000b,0x03d7000a,0x7d160034}},	//   ищен, _नक्_, בומם_, anys
  { {0x6d4f0064,0x39580f23,0xdeb6000a,0xba740021}},	//   _tica, _curs_, _הפתח_, زالت
  { {0x61120024,0x58870033,0x39580f24,0x6b8d0f25}},	//   tāli, рыжа, _durs_, prag
  { {0x9cd6000a,0x7d0d0f26,0xa7a90054,0xab8401c5}},	//   _הורה_, mias, укла_, _мурк
  { {0x61360014,0xb882002e,0x7cf8002d,0x61120024}},	//   eáll, _þíni, _víre, rāli
  { {0xeef8000a,0x05680054,0xa5090076,0x02e0000b}},	//   שמור_, ајњи_, лека_, _पकड़न
  { {0x201e0011,0x61360f27,0xd6180015,0x7cf80125}},	//   ştii_, gáll, جتها_, _tíre
  { {0x57f5000d,0xe5040029,0xe3b10015,0x7cf80030}},	//   _упат, تبوي, سرة_, _hírc
  { {0x6d44005c,0xd346002b,0x8c1c000a,0x387d0034}},	//   zmia, مینه_, כוחי, lawr_
  { {0x7e7c002e,0x613d00dc,0x6d4409bf,0x8afa000a}},	//   varp, zéle, ymia, רפתק
  { {0x3f6a0124,0x387d0026,0x7d0d003f,0x1636000a}},	//   лимо_, nawr_, jias, _הנער_
  { {0x320b005c,0x7e7c0f28,0xe536000a,0x88ba004c}},	//   ńcy_, tarp, _פטנט_, נזשי
  { {0x083a0053,0x613d0f29,0x6136001a,0x645d0091}},	//   טערל, véle, málm, žsid
  { {0x51950029,0x527a004c,0x7d0d0f2a,0x412a024f}},	//   _العذ, _ענקא, fias, _йоко_
  { {0x4bda0080,0x1d07000d,0x7d0d0f2b,0xe1f0002b}},	//   льзя_, беси_, gias, _تسه_
  { {0x6136002c,0x4aaa0f2c,0xdbdc0107,0x6d440f2d}},	// [1520] nálm, лкан_, pšíc, rmia
  { {0x613600dc,0xca560054,0x6b8b0030,0xaad2000b}},	//   záll, стањ, ágga, साइक
  { {0x8e570053,0xc8790064,0x387d0026,0x1e57000a}},	//   _לייג_, _beş_, fawr_, _לשיר_
  { {0x27320011,0x3f82005c,0xd943006b,0x7c960c30}},	//   mâni_, osku_, пехи, _уроц
  { {0x2bc9005d,0xccf30008,0xa03a0053,0x02b7000b}},	//   रिणा, _זכר_, װײַז, _असंभ
  { {0xb8ef014e,0xbb4300fd,0x3b0a004a,0xdc37004c}},	//   _वो_, _неяк, _сего_, _לאכט_
  { {0xceb30008,0x61360030,0xa4d80342,0x3e5b004f}},	//   פיה_, táll, идку_, נדקס
  { {0x8a170008,0xdb1d00c0,0x4d7b0053,0xba17002b}},	//   _החלו_, _ersä, ארקע, _ايفا_
  { {0xe73a0083,0x61120024,0x2418054f,0x3f820f2e}},	//   _беа_, nālu, ропы_, jsku_
  { {0x2bc9005d,0x27f90020,0x66e50015,0xd7020033}},	//   रिता, _üsna_, _وألق, _пiса
  { {0xd2500002,0x7d0d01c2,0xe6c50015,0xd6eb000a}},	//   بند_, yias, _بتقي, _עַמָ
  { {0xca370008,0x3a3701e4,0x463b0053,0x613600dc}},	//   מניה_, מרים_, _געבע, lálj
  { {0xdcee0024,0xdb0d001a,0x39460533,0x7d0d0f2f}},	//   arbī, kvað, imos_, vias
  { {0x61360014,0x28cf005d,0x7d0d005c,0x539b000a}},	//   nálj, _सोनि, wias, _עיוו
  { {0xc27b00b2,0x427b0008,0xae45002b,0xdb0f0030}},	//   _גרוי, _גאוג, زپرو, ódít
  { {0xe2170008,0xdb060030,0xdcf5003d,0x0217004f}},	//   _לקוח_, _eskü, muzī, _לחום_
  { {0x212b002c,0xfc330015,0x9962006f,0x61360030}},	// [1530] moch_, سحر_, _ríše_, kálj
  { {0xda670029,0x6e950029,0x39460f30,0x4095002b}},	//   صائي, _بلدا, emos_, _الکر
  { {0xdcfc0024,0xb9b50225,0x48790010,0x99620107}},	//   gurē, تماع, асля_, _píše_
  { {0x9cb50029,0x38580015,0x212b0f31,0x319b015b}},	//   _بمحت, مشهد_, noch_, רבאנ
  { {0x69d8008c,0x7d1d0f32,0xe72e0f33,0x6d5a04b2}},	//   äver, _ijss, де_, ítav
  { {0x613600dc,0x212b0f34,0xd00c000a,0x85b90015}},	//   gálj, hoch_, טּוֹ, لابس_
  { {0x05790029,0x212b002c,0x286b049d,0x13d1000b}},	//   جمعة_, koch_, _брзо_, तम्भ
  { {0xe9190036,0x212b002c,0xfdf8000a,0xf8ae002b}},	//   _тобі_, joch_, מצות_, _لکه_
  { {0x613600dc,0x212b0f35,0x9f4e0046,0x290f0f36}},	//   bálj, doch_, žném_, miga_
  { {0xf6f50074,0x290f0f37,0x13090080,0xdb1d0c77}},	//   _بزرگ, liga_, рной_, _ursä
  { {0xc1060015,0x61460923,0xf7480015,0x0477002b}},	//   قودي, жена, _اللي_, _هلاک_
  { {0xa4f70086,0x290f0f38,0x3f8206cf,0xa2a9021e}},	//   _دکتر_, niga_, tsku_, _जॉर्
  { {0x613600dc,0x3f840107,0xe8d6000a,0x290f007c}},	//   lálk, ému_, קושר_, iiga_
  { {0x7cea002e,0x68f8003d,0x3f820f39,0x236d0085}},	//   _nýrr, īvdi, rsku_, mpej_
  { {0xdd920002,0x6cc60afb,0x91650067,0xd589000a}},	//   ظور_, ойва, _بهبه, יָּ֨
  { {0x613600dc,0x61120024,0x22140010,0x290f01a3}},	//   zálj, tālu, _эфір, jiga_
  { {0x6ef00005,0x290f0f3a,0x2d91002a,0xdd2f0046}},	// [1540] _läbi, diga_, arze_, běžn
  { {0xdcfc0048,0x2d91005c,0x38cb0086,0x60c40d4e}},	//   turē, brze_, یانی_, _haim
  { {0x613600dc,0x40930086,0x60c40f3b,0x6da60015}},	//   válj, _علیر, _kaim, _بمجم
  { {0x290f0020,0x61360f3c,0xc212000a,0x6112003d}},	//   giga_, dálk, והב_, māls
  { {0x39460f3d,0x87ba0080,0xdb040111,0x39400024}},	//   rmos_, рует_, ntië, ķis_
  { {0x6b84002f,0xc58a0080,0x3eb80f3e,0x758a068e}},	//   msig, ащие_, nert_, асив_
  { {0x613600dc,0x290f007c,0x4e8b000a,0x3eb80f3f}},	//   rálj, biga_, שָׂ֣, iert_
  { {0x443d018b,0x3eb800b8,0x60c40f40,0xddd50046}},	//   _bzw_, hert_, _naim, nazš
  { {0x14a6000b,0x212b006f,0x3eb80f41,0xa68605a7}},	//   क्षण, voch_, kert_, _млад
  { {0x61360f42,0x2002005c,0xd25a0001,0xa6f8000a}},	//   lálh, dzki_, шци_, _פִּי
  { {0xd62a0080,0x1a9b0053,0x4a5b0008,0x7ae300f2}},	//   _тоже_, סיטע, ידיו, önti
  { {0x61360014,0x613d002e,0x2d980f43,0xdb1d0144}},	//   nálh, féla, dure_, _essè
  { {0x60c40f44,0x212b0f45,0x3eb80f46,0x2d980ad3}},	//   _daim, roch_, fert_, eure_
  { {0x2d91005c,0x6b840f47,0x212b0f48,0x539b000a}},	//   trze_, dsig, soch_, _כידו
  { {0xfe540010,0x2d850f49,0x41e60484,0x77f8000b}},	//   дкрэ, éle_, _філа, ्छुक_
  { {0x2d83005c,0x01fb0008,0x60c40f4a,0x2d8d013b}},	//   rsje_, _כפול, _gaim, čee_
  { {0x2002005c,0x6b840035,0x3eb80f4b,0x2d470034}},	// [1550] czki_, gsig, bert_, _bŵer_
  { {0xad670029,0xdb040152,0x80a7005d,0x8aa70033}},	//   _واجه, ntiè, ट्रे, ўрад
  { {0x63bb00b8,0xc984005e,0x2ca90012,0xb05b008c}},	//   zwun, дучи, pfad_, ydäl
  { {0x6367002c,0xab5b0012,0x52b7000b,0x7cf80030}},	//   nčný, _brüt, _अस्स, _hírn
  { {0x3f990064,0xb8e3000b,0xd7f80054,0x290f0f4c}},	//   nusu_, _ऍस_, жуј_, riga_
  { {0x290f0f38,0xb579004a,0x61360307,0x47c40033}},	//   siga_, бщих_, tálk, ьбів
  { {0x3f990f4d,0x5e780008,0x7cf80089,0x6367002c}},	//   husu_, חתון_, _mírn, kčný
  { {0xd5ae0029,0x9f4400dc,0xf7bb0086,0x3eb80030}},	//   افي_, ámú_, _پدرش_, zert_
  { {0xb8ff005d,0x13090036,0x48fa0053,0xdc88000a}},	//   ता_, йний_, _פּלא, חְתָ
  { {0xa2050036,0x63bb00b8,0xe29907c1,0x3f990f4e}},	//   зпод, rwun, љан_, dusu_
  { {0xcb1200a3,0x3eb80f4f,0x6136016e,0xd5d40015}},	//   תלי_, vert_, láli, _يتمث
  { {0x443d005c,0x3eb800b8,0x7985003f,0x6b840f50}},	//   _tzw_, wert_, ishw, ysig
  { {0x3eb80f51,0x26c500e8,0xe28e0f52,0x60c40209}},	//   tert_, _kalo_, _па_, _vaim
  { {0x3eb800b8,0x2d980376,0xc2c50015,0x72c4005e}},	//   uert_, ture_, _ريبي, _обіз
  { {0x3eb806f5,0x57b8005d,0x27320011,0x2002005c}},	//   rert_, _इन्ह, mânt_, szki_
  { {0x3eb80f53,0x26c50035,0xab660f54,0x3ea10f55}},	//   sert_, _lalo_, звал, _echt_
  { {0x3f990064,0x613600dc,0xed350010,0x2d980376}},	// [1560] cusu_, válh, фэрэ, sure_
  { {0x2d9802d7,0x6b840e32,0x62810f56,0x613603bc}},	//   pure_, rsig, nalo, dáli
  { {0xc4bd000b,0x3a990033,0x68e90f57,0xd910002b}},	//   ्याओ, ўтую_, _boed, نیس_
  { {0xc7c60080,0xb05b00f2,0x68fb0026,0x68e90335}},	//   зски, ydäm, _clud, _coed
  { {0x68e90026,0x613600dc,0x6d5e003f,0xab5b0012}},	//   _doed, gáli, _hupa, _drüs
  { {0x6d5e0f58,0x8b8b000a,0x62810f59,0x7e7e0f5a}},	//   _kupa, _לָלֶ, jalo, _jepp
  { {0x62810f5b,0x613d0089,0xbb430f5c,0x69da0f5d}},	//   dalo, déln, _черк, _štef
  { {0x68fb0026,0x7cf80089,0x212001a3,0x68e90f5e}},	//   _glud, _míro, _njih_, _goed
  { {0xd4670001,0xe3c30015,0x6d5e0f5f,0x26c5016e}},	//   чиње_, فْيَ, _lupa, _falo_
  { {0x98b800df,0xe3af0196,0xd7fb000a,0x26c50f60}},	//   _kurį_, اري_, _ההמל, _galo_
  { {0x40950015,0xd4d60033,0x6d5e003d,0xb5ca0067}},	//   ولدر, _нідэ, _nupa, _دوام_
  { {0x63a40011,0x93aa0029,0x64a60033,0x6281007c}},	//   _ţinu, _هاتف_, _хада, aalo
  { {0xe5050086,0x6d5e0f61,0xdb040003,0x6367006f}},	//   _تبلي, _aupa, ptiè, rčný
  { {0x628a0134,0x6d5e00e8,0x3f990f62,0x7e7e02b9}},	//   _udfo, _bupa, rusu_, _cepp
  { {0xdd910029,0x271b004c,0x1df801b0,0xadbd0033}},	//   ضوء_, צולײ, перы_, шавi
  { {0xc19b000a,0x65c70046,0xdf58002b,0x291c0f63}},	//   _השהי, léhá, _کشيش_, éval_
  { {0x68e90b7c,0x201e01e2,0xd0080124,0xb05b00f2}},	// [1570] _roed, ştir_, _неће_, hdäk
  { {0x61360f64,0x7cf800dc,0x7e990087,0x3ea1002d}},	//   váli, _hírl, _بندر_, _ucht_
  { {0xed580083,0x68e90079,0x68fb0f65,0x613d0f66}},	//   _ноќ_, _poed, _plud, nélo
  { {0xf9900225,0xd8390033,0x89370015,0x61360f67}},	//   ابل_, опец_, أعطا, táli
  { {0x2b930074,0x68e9016b,0x263c0016,0x6d5e00bc}},	//   _سیاس, _voed, _ảo_, _zupa
  { {0x8f9c00f3,0x68e90079,0x9b45002b,0x45d50923}},	//   מידי, _woed, _آنسو, дцит
  { {0x273204f9,0x26c702c6,0x62810f68,0x3752002b}},	//   vânt_, rdno_, valo, خپوس
  { {0x5dfc000a,0x6281002a,0x6136013f,0x657a0416}},	//   מפונ, walo, páli, _dwth
  { {0xa2a1005d,0xf7940010,0xd794006b,0xf8b2000a}},	//   _खाद्, _патэ, _питъ, _בשן_
  { {0x613600dc,0x21cc0046,0x7bcd0003,0xed640046}},	//   nálv, _běh_, ivau, naží_
  { {0x63a404f9,0x387f00dd,0x613d0030,0x657a0034}},	//   _ţint, _keur_, réln, _gwth
  { {0xdb040077,0x2d8c0046,0x6d5e0f69,0x62810f6a}},	//   rtié, ádem_, _rupa, salo
  { {0x73e40036,0xa5140053,0x6d5e0f6b,0x62810f6c}},	//   _поїз, _אַװג_, _supa, palo
  { {0x387f038d,0x249f0f6d,0x63a90f6e,0xed5a009b}},	//   _leur_, lgum_, mten, жов_
  { {0x63a90f6f,0x613d0030,0xd10a0040,0x6da304bb}},	//   lten, célo, _وقته_, кира
  { {0x249f09f0,0x20560f70,0x417a000a,0x63a90f71}},	//   ngum_, _отпр, _ונקב, oten
  { {0xe8df0023,0x9f860033,0x38c60091,0x0aea01f3}},	// [1580] _chọn_, _ўгод, _jūrų_, одай_
  { {0x6a16002b,0x63a90f72,0x6d5e0f73,0xf1b1000b}},	//   وبار, iten, _tupa, _जहान
  { {0x8ca6005d,0x89f50010,0x6edb000a,0x7edb000a}},	//   _छापो, няцц, _וחיפ, _וקיצ
  { {0x63a90f74,0xa934002b,0xd6cf009a,0xef1f007f}},	//   kten, رباچ, یقن_, nsün_
  { {0x387f0f75,0x4cbb000a,0x38cb002b,0x3f7a004c}},	//   _deur_, _וזכו, تالی_, קאַס
  { {0x6136002e,0xdcfc0007,0xb7d70015,0x2ca0007c}},	//   málu, turė, بوها_, lgid_
  { {0xceb30008,0x613600dc,0x63a90f76,0x28cf000b}},	//   דיו_, lálu, eten, _सोवि
  { {0x2ca00020,0x249f002e,0x61280064,0x89d70029}},	//   ngid_, ggum_, nıld, _توفر_
  { {0x2ca00020,0x7791002b,0x69e30045,0x63a90f77}},	//   igid_, _مینا, ăteş, gten
  { {0x27320045,0xb5da0015,0x574307be,0xf5b60058}},	//   râns_, _وباء_, _ануб, _يصاد
  { {0x61280064,0x546a055f,0x61150f78,0x63a90f79}},	//   kıld, _даем_, едну, aten
  { {0x7bcd0007,0x05770015,0x61360030,0x2fd2002a}},	//   yvau, _آمنة_, zálv, _bryg_
  { {0xfebb0086,0x24f70010,0x40950086,0xa294017f}},	//   ياست_, _іншы_, ولگر, _залі
  { {0x2ca0007c,0x6b96002a,0xc43b000a,0x248402ad}},	//   egid_, dryg, _ותדי, lamm_
  { {0xfcc70001,0x929b0008,0x613600dc,0xd2b7000a}},	//   мљам, _ויות, válv, _חלות_
  { {0x6c550004,0xa2d60065,0x0000006a,0x0000006a}},	//   екбу, बाक्,   ,
  { {0x2bbb0015,0x7bcd008c,0x61360030,0x8aa70719}},	// [1590] غارة_, uvau, gálu, дред
  { {0xab940036,0x7bcd0f7a,0x20dd000b,0x2d850f7b}},	//   тифі, rvau, यावध, áles_
  { {0x387f0152,0x5ee8000a,0x891f004c,0x61360030}},	//   _peur_, _חַרְ, אַר_, rálv
  { {0x6f150064,0xa2150053,0xf77100e6,0xdcf5003d}},	//   lizc, ײַעס_, هات_, irzī
  { {0x32050f7c,0x63a90f7d,0x6d4d0f7e,0x366901eb}},	//   zzly_, xten, mmaa, пало_
  { {0xd2460f7f,0x4f9c0008,0x613600dc,0x6d4d0f80}},	//   _من_, קבוצ, lált, lmaa
  { {0xe613002b,0x6d4d0577,0x38600f81,0xa8a70f82}},	//   خشش_, omaa, žira_, _орак
  { {0x613600dc,0x6d4d0f83,0xc984023e,0xe3b1002b}},	//   nált, nmaa, _јури, هرخ_
  { {0x249f0084,0x6d4d00f2,0x9475002b,0x6f150061}},	//   rgum_, imaa, ودکا, kizc
  { {0xe3c80023,0x63a90f57,0xc2c50015,0x61280061}},	//   _dự_, rten, ريجي, zıld
  { {0x613d00dc,0xe1f10018,0x61280061,0x61360030}},	//   mélj, اسخ_, yıld, kált
  { {0xcea9013a,0xd576000a,0x63a90f84,0x04c80058}},	//   _לי_, _נתנה_, pten, _يولي_
  { {0x251a0053,0x6d4d0234,0x68fa004c,0xdb1d0f85}},	//   _צונא, dmaa, פּטװ, _assí
  { {0x201e0011,0x6d4d0f86,0xf772000a,0x61360030}},	//   ăti_, emaa, רקם_, válu
  { {0xe816005d,0x6561001c,0x61280064,0xc6920053}},	//   _देना_, _julh, tıld, טאם_
  { {0x656103af,0x61360f87,0x6d4d0f88,0xaac6002b}},	//   _mulh, gált, gmaa, کترن
  { {0xf1c90092,0x61280064,0xac0a000d,0x711b000a}},	// [15a0] _hạ_, rıld, чнаа_, _מוקפ
  { {0x6d4d0f89,0xab930015,0x61280061,0xb0ac000b}},	//   amaa, اللغ, sıld, ट्रग
  { {0x61280064,0x613600dc,0x9e7b000a,0x22f6004c}},	//   pıld, bált, _מניפ, עזען_
  { {0xe9730086,0x6d4600f2,0x01fa000a,0xc7ca004a}},	//   اهند, _uhka, הפעל, зыке_
  { {0xf1c90092,0xe73a0419,0xf093000a,0x69c302de}},	//   _lạ_, пед_, רנד_, æner
  { {0x8f9b00b2,0xc6f705d1,0x7bc60f8a,0xe5c608c9}},	//   פיצי, нніх_, _isku, есио
  { {0xe3c800a7,0xd5b7004a,0x64bd000b,0x61360307}},	//   _sự_, есы_, ्यूश, náls
  { {0x35c5005d,0x273b0092,0xaa570015,0x38c8002b}},	//   विज़, hênh_, _ألفا_, _غازی_
  { {0xd90d0074,0xe8b501e2,0x7d0400f2,0x465a0021}},	//   _بین_, lışı, ihis, _فؤاد_
  { {0x55e60036,0x51f80036,0xf1c90092,0x81d40a61}},	//   _позб, дною_, _bạ_, воох
  { {0x7cf80089,0x6136002e,0x9f440089,0x7d040f8b}},	//   _círk, jáls, ámý_, khis
  { {0xe3c80023,0x753b0011,0x7bc60abb,0x78a20522}},	//   _tự_, cluz, _osku, ngov
  { {0x0457003b,0x61360014,0x7d160064,0x656101c2}},	//   _كلمة_, vált, diys, _zulh
  { {0x1ee70074,0x3ea50014,0xe8b50061,0xa29401f3}},	//   روزی_, ült_, kışı, _ракі
  { {0x613d0030,0x61360030,0x6d4d0f8c,0x7bc607c2}},	//   nélk, tált, tmaa, _asku
  { {0x563700b2,0xd9040074,0x23b7005d,0x823b000a}},	//   גאלע_, _طی_, _अहमद, _מעוצ
  { {0x628e005c,0x61360f06,0x78a201a3,0xdb23002b}},	// [15b0] óbow, rált, dgov, هوری
  { {0xadf5008f,0xab180036,0x6d4d0f8d,0xdc45003d}},	//   _апош, нієї_, smaa, mīļo
  { {0xf1c90092,0x6d4d0234,0xceb2000a,0x7aee0030}},	//   _xạ_, pmaa, _דיי_, _dobt
  { {0xf0940053,0x57f50004,0x38c9002b,0x91fc003d}},	//   ָנס_, кпет, بائی_, ecāk
  { {0xdddc0f8e,0x613d0030,0x46a5029b,0xb6a5098b}},	//   parţ, télj, валв, вилл
  { {0x613d0030,0x78a2036d,0x0000006a,0x0000006a}},	//   félk, agov,   ,
  { {0x2bc9005d,0x49c80033,0xd6260054,0xe5e10033}},	//   रिका, _плён_, коше_, рылi_
  { {0x9ddc0008,0x69c70085,0x613d0030,0x3ce9013b}},	//   לקוח, _isje, sélj, njav_
  { {0x3f8b005c,0xf3f10015,0xd4680021,0x443902de}},	//   jscu_, شأة_, رحيم_, æs_
  { {0x69d5005c,0xdcfc0024,0x7790002b,0x42e9005e}},	//   _krze, turī, _ایوا, ємно_
  { {0x3f8b0011,0xb0dd000b,0xc2420342,0x65940f8f}},	//   escu_, यांग, иньк, _баху
  { {0xdddc0085,0xef1f0030,0x7412002b,0xf1c90016}},	//   jarš, ssül_, اویا, _vạ_
  { {0xc95200b2,0xa78c000a,0xc2c50015,0x0000006a}},	//   ימט_, ּאלֹ, _ليشي,
  { {0x78a2010b,0x69c7016f,0x69d5005c,0xe8b50064}},	//   zgov, _osje, _orze, yışı
  { {0x7d160061,0x6e930015,0x386d0f90,0x7d040f91}},	//   tiys, ؤلفا, _ofer_, this
  { {0xad390036,0xa3d5000b,0x7aee0144,0x6136006f}},	//   ечує_, हिप_, _sobt, ráls
  { {0xc0c90054,0xa03a0021,0x7d160f0a,0x5baa02a3}},	// [15c0] _чује_, _تأثر_, riys, ькам_
  { {0x69d5005c,0xe8b50064,0x62830f92,0x7d160727}},	//   _brze, tışı, _jeno, siys
  { {0x7bc6005c,0xf969005e,0xba170015,0xc332015b}},	//   _wsku, ерій_, نيكا_, סוב_
  { {0x69d5005c,0xe8b50064,0xcb09000a,0x2900016e}},	//   _drze, rışı, חל_, óia_
  { {0x69d500b8,0xf74a0015,0xe7b40015,0xdb080125}},	//   _erze, وجته_, امتد, ólót
  { {0x4733042b,0x62830f93,0x7cf10f94,0xe8b5007f}},	//   аніс, _neno, _hårp, pışı
  { {0x27e004f9,0x69d5005c,0xceb30008,0x69d80134}},	//   ţin_, _grze, ייג_, æved
  { {0x23ab0134,0xb8650015,0x2cb20034,0x0000006a}},	//   føj_, _ماكو, nfyd_,
  { {0x7d030011,0x6d3b000a,0x3957000a,0x69d5002a}},	//   _înse, ותקנ, _ישלם_, _zrze
  { {0x6e290064,0x7cf8002d,0xdc370053,0xe6c50015}},	//   şebi, _díri, כאפט_, _متمي
  { {0x26de003e,0xe816005d,0xcb130008,0xba9b0008}},	//   _into_, _देता_, שלת_, וסיי
  { {0x7cf80125,0x51f70174,0xf9460138,0x0000006a}},	//   _fíri, тнюю_, ннiк_,
  { {0x33940f95,0x62830f96,0xb4fb004f,0x0ede0065}},	//   _салё, _feno, _קלדר, मांड
  { {0x2cb20026,0x62830f97,0x80a5000b,0x63a0007c}},	//   efyd_, _geno, _कावे, mumn
  { {0xd7880023,0x82330086,0xb2bb000a,0x6288089f}},	//   hể_, _پروا, _חמור, mado
  { {0x26cc047e,0x3ead0046,0x7e620045,0x62880f98}},	//   _lado_, řet_, _şopt, lado
  { {0xac180001,0x7c840a8c,0x26de0f99,0x613d0030}},	// [15d0] воту_, русе, _onto_, vélh
  { {0x69d50f9a,0x613d0f9b,0x62880f9c,0xdd1c01c0}},	//   _prze, déli, nado, _vášn
  { {0x61280064,0xf9c70063,0x60cd0f9d,0xbd4b0015}},	//   lıla, ъщан, _kaam, _يؤجل_
  { {0xf1b30053,0xa3d5000b,0x19940033,0x60cd05ff}},	//   יסע_, हिम_, раця, _jaam
  { {0x612801e2,0x26cc000c,0x69d5005c,0x6d5d0035}},	//   nıla, _bado_, _wrze, _iisa
  { {0x69d50050,0xdb0f0144,0x6d5d0a38,0x62880f9e}},	//   _trze, _escò, _hisa, jado
  { {0x7cf80341,0x26cc0656,0x62880f9f,0xdb04016e}},	//   _síri, _dado_, dado, stiã
  { {0x25b60086,0x23ab0134,0x45180010,0x6b4b00dc}},	//   اهيد_, tøj_, кцыя_, függ
  { {0x6b8d03af,0xed110023,0x6d5d0fa0,0x62880fa1}},	//   nsag, _đối_, _misa, fado
  { {0x6d5d0407,0x61280064,0xf772000a,0x26cc016e}},	//   _lisa, dıla, _לקמ_, _gado_
  { {0xa1890010,0x3495000d,0x8a16000a,0x62830fa2}},	//   эбна_, _баер, ָ֗יו_, _veno
  { {0xd5fa0053,0x6d5d0fa3,0xd00a0fa4,0xd919000a}},	//   _אפער, _nisa, ееме_, תוֹל
  { {0x61280064,0x80a5000b,0xe2990fa5,0x62880fa6}},	//   gıla, _कारे, _зал_, bado
  { {0x3392003b,0x48160053,0x539a0008,0x6b8d0f47}},	//   _الوز, אַלן_, _ניצו, dsag
  { {0xdef90010,0xb1760016,0x91fc003d,0x6d5d0fa7}},	//   тыў_, _trượ, zbāz, _bisa
  { {0x61280064,0x721a000a,0x6d5d0fa8,0x6b8d001a}},	//   bıla, _רוקח, _cisa, fsag
  { {0x612801e2,0x6b8d0fa9,0xf093000a,0x6d5d0faa}},	// [15e0] cıla, gsag, _הנח_, _disa
  { {0x4e36006e,0x613d0fab,0x09e60fac,0x0dca0088}},	//   _معجز, véli, лозн, _злой_
  { {0x6b8d02f2,0x49ba0015,0x26cc0fad,0x98f60033}},	//   asag, عائد_, _rado_, лядч
  { {0x32360053,0x62880fae,0xa926004a,0xe93a0015}},	//   אטען_, zado, ыдел, رسات_
  { {0x01370053,0x62880faf,0xbcfb0003,0x9b460015}},	//   אָגט_, yado, _siég, _منحو
  { {0x62880341,0x613d0fb0,0x78a90fb1,0xbcfb0003}},	//   xado, réli, _ecev, _piég
  { {0xe1e70074,0x7d0304f9,0x61280064,0xb05b0b1c}},	//   _اس_, _însc, zıla, ndär
  { {0x612801e2,0x443d0176,0x09f70015,0xef1f0030}},	//   yıla, _byw_, _صفقة_, tsük_
  { {0x60cd0005,0x29040fb2,0x62880fb3,0x58f7000a}},	//   _raam, _ilma_, tado, _עצמן_
  { {0x26de003e,0x443d0026,0xc8790064,0x60cd0fb4}},	//   _unto_, _dyw_, _inşa_, _saam
  { {0x22580020,0xba9b0053,0xef1f00dc,0x867b000a}},	//   ärk_, עסטי, ssük_, _נראו
  { {0x612801e2,0x443d0026,0xa0550036,0x6b8d0152}},	//   tıla, _fyw_, ивні, ysag
  { {0xe3af0086,0x33f60002,0xf537000a,0x6b4b0012}},	//   _فرو_, _حساس, _גנאי_, lüge
  { {0x612801e2,0xd5a60029,0x69c5003e,0x6d5d0523}},	//   rıla, يف_, ywhe, _sisa
  { {0xbcfb038d,0x29040064,0x6b4b00b8,0x1317000a}},	//   _liée, _olma_, nüge, _תחול_
  { {0x612801e2,0x563b0053,0x463b0053,0xab5b007c}},	//   pıla, געלײ, געלע, _tsük
  { {0xaae0005d,0x30780029,0x6d5d0fb5,0x5b150fb6}},	// [15f0] नांक, _صحية_, _visa, амат
  { {0xa3d5005d,0x6d5d00e8,0xf1a8000b,0x945d002a}},	//   हित_, _wisa, _कमान, leńc
  { {0x6b8d0fb7,0x929b000a,0xba4702a3,0x6d5d0fb8}},	//   ssag, תיבת, ухай, _tisa
  { {0xd7d5000d,0x317b0053,0x69c5003e,0xc237004c}},	//   ижењ, גראמ, rwhe, נראו_
  { {0x1755005e,0xdb070030,0xdb040fb9,0x97d80058}},	//   авдя, álód, stiá, ُظهر_
  { {0x6b4b00b8,0x443d0026,0xbc1a000a,0x8c1a000a}},	//   füge, _ryw_, _יורש, _יורי
  { {0x5a44008f,0x0000006a,0x0000006a,0x0000006a}},	//   _гэта,   ,   ,
  { {0xd6180029,0xe93b0015,0x2d9e0085,0xe3b9005e}},	//   دتها_, _أسست_, šteg_, вби_
  { {0x76a70029,0xab5b0020,0x320c006f,0x9cd8000a}},	//   _محاك, _psüh, ezdy_, רוחה_
  { {0x57f40001,0x66200046,0x0587008b,0x9814012c}},	//   _упут, ázká, _будм, _طبقا
  { {0xf8c9000b,0xf2e6002b,0x04950015,0x212901d7}},	//   _रसाय, شکوه_, _نلاح, _bjah_
  { {0x33d5042b,0xa3d5000b,0x3a36000a,0xca36000a}},	//   _вікт, हिद_, ירתם_, ינתה_
  { {0x95540087,0xa9360008,0x320c002a,0xa2e50a9d}},	//   _اخلا, שטרה_, azdy_, _волд
  { {0xa8560008,0x394d001c,0xd139002a,0x539a000a}},	//   יירה_, _lhes_, stąp_, _יינו
  { {0xad3a005e,0xff050033,0x3d28002b,0x764e013f}},	//   вчає_, сяўн, هتری_, _úbyt
  { {0x25ed005d,0xc5f20008,0x6446002a,0x6f66012e}},	//   _अपनी_, חדל_, żkie, _квиз
  { {0xed570fba,0x6b4b0012,0xca8606b9,0x113b004f}},	// [1600] рот_, züge, игай, _בתקל
  { {0xbf130015,0x6ffb000a,0x1e960c9a,0x0d860fbb}},	//   _وويب, _ספיג, _трир, _клон
  { {0x7e9b0008,0x09fa0029,0xfe9b01ac,0x0e9b000a}},	//   _בסיו, خفضة_, _ביימ, _בשיל
  { {0x4069000a,0x0000006a,0x0000006a,0x0000006a}},	//   ְיוּ_,   ,   ,
  { {0x67d400d7,0x613d0030,0x6f1c0125,0xf76f0015}},	//   солу, mélt, oirc, واو_
  { {0xd737005e,0x971300e2,0x7cf80fbc,0x945d002a}},	//   апії_, оміц, _víru, zeńc
  { {0x44200011,0x95ca0fbd,0x2abb000a,0x0000006a}},	//   _ţi_, тула_, _שמלא,
  { {0x5e570053,0xc448002b,0x95d7006b,0x6b4b0012}},	//   סיקע_, هیان_, рдът_, rüge
  { {0x6f1c00b8,0xdcef0085,0x889b000a,0x7648002a}},	//   kirc, žeće, _שבמי, _wzdy
  { {0x0bb7000a,0xfbb7000a,0xf7460920,0x326607f9}},	//   סלים_, ספית_, _тезо, штив
  { {0x98af0024,0x8ad9004c,0xd62701c5,0x8afb0447}},	//   logā_, אַרפ, _кофе_, דהיי
  { {0xd5fb0053,0xe58b000a,0x23660091,0x799e0034}},	//   _שפאר, _יָדָ, _tuoj_, irpw
  { {0x69da00bc,0x9f590003,0x72d40515,0x9fe80058}},	//   _štel, lysé_, _голф, لَّم_
  { {0xa2d30029,0x6568003f,0xb3bb000a,0xe7f9000b}},	//   _وينت, _kudh, _סמוכ, ्नता_
  { {0xe2970001,0x51940015,0x6339004c,0x613d0030}},	//   _тај_, _البذ, _געװױ, félt
  { {0x6f1c0125,0x65680fbe,0x8b670015,0xa3ca0065}},	//   airc, _mudh, لائم, _लना_
  { {0xea670001,0x2d58034e,0x395f0144,0x394d0034}},	// [1610] ањен, рить_, _rius_, _rhes_
  { {0x67380085,0x656808cf,0x7cf80030,0x6f1c0fbf}},	//   jovj, _oudh, _bírs, circ
  { {0xc333000a,0xdb060030,0xdbeb0030,0x61280061}},	//   קוע_, émáb, tőór, kıll
  { {0xc7950015,0xa3d6000b,0x18690054,0x7bcb001a}},	//   مشتب, ाटा_, ћали_, ægus
  { {0x2d91005c,0x69ca02de,0x395f0144,0x387d0034}},	//   lsze_, æfer, _vius_, rbwr_
  { {0x16a90661,0x2ca90020,0x099b0015,0x65680fc0}},	//   увки_, lgad_, _لضرب_, _budh
  { {0x2ca90030,0xc5d500e2,0x394d0fc1,0xe8df0016}},	//   ogad_, сіль, _thes_, _nhện_
  { {0x7af500dc,0xb92500e6,0xc98407f7,0x2ca90fc2}},	//   _hozt, _افري, _фури, ngad_
  { {0x291d000c,0xe4c8002b,0x6f1c0061,0x97c40058}},	//   miwa_, شبين_, yirc, _وقفو
  { {0x291d0fc3,0x13060080,0xddde0227,0x5999000a}},	//   liwa_, йный_, _lepš, ְשָׁ
  { {0xdb04001c,0x2d91005c,0xc692000f,0x63b6008c}},	//   stiç, jsze_, _זאב_, _äynn
  { {0x14ca0086,0x291d003f,0xf4d40015,0xb47c005e}},	//   _مهمی_, niwa_, _وتنظ, _акцi
  { {0xc50c00b2,0x613d0030,0xa2d20065,0xb05b005b}},	//   _בלאָ, vélt, _भोक्, seän
  { {0x613d00dc,0x65680fc4,0x84e5000b,0x543a004c}},	//   féls, _yudh, कावट_, _גענא
  { {0x291d000c,0x6b5000c0,0xf2d20053,0x644e002a}},	//   kiwa_, lägg, _מעג_, ębie
  { {0x3c66008f,0x2ca900c0,0x291d003f,0x40960029}},	//   скаг, ggad_, jiwa_, _الظر
  { {0x61280064,0x291d003f,0xc4d2000a,0x1419000a}},	// [1620] nılm, diwa_, הגן_, אוּב
  { {0x2ca90fc5,0xaa8a0015,0x2d91002a,0x1eca004a}},	//   agad_, انام_, bsze_, _слои_
  { {0x8db60036,0x60c603f8,0x7c2f0051,0xeef7004f}},	//   _успі, oekm, _excr, _המיר_
  { {0x718a00b2,0x61280064,0xc9850029,0x3d14000b}},	//   רװײַ, kılm, تشكي, नोशे_
  { {0x31b100dc,0x07a30033,0xc7a309c4,0x67380085}},	//   ház_, зачн, зичк, tovj
  { {0x6d440495,0x09e6006b,0x98af003d,0xf1a80065}},	//   llia, _логн, rogā_, _कमलन
  { {0xfb1b0008,0x6d440fc6,0x291d003f,0x67380b28}},	//   _עולמ, olia, biwa_, rovj
  { {0x539800a4,0xdb04008c,0x5997000a,0x6d440fc7}},	//   авия_, stiä, _לכלב_, nlia
  { {0x6d440fc8,0x6738016f,0x9f6300dc,0x2d850fc9}},	//   ilia, povj, ívül_, ález_
  { {0x656800dc,0x6d440fca,0x91b80004,0x2d91002a}},	//   _tudh, hlia, агот_, ysze_
  { {0xe3af0074,0xf5390089,0x69da00bd,0x6d440fcb}},	//   وری_, boť_, _štej, klia
  { {0xd3e40074,0x4a5b0008,0x613d0030,0xd46a0054}},	//   _وقای, טדיו, véls, _сиде_
  { {0x2d910050,0x6d440fcc,0xb0aa000b,0x34560015}},	//   wsze_, dlia, _कारग, _انشأ
  { {0xa3d5005d,0x291d0fcd,0x31b1006f,0x2d91002a}},	//   हिर_, ziwa_, báz_, tsze_
  { {0xde590036,0x2d850152,0xb05b008c,0x02b7000a}},	//   раві_, èle_, meäm, _הלוך_
  { {0x6d4402d7,0x2d910fce,0x32430015,0xbca50015}},	//   glia, rsze_, _عنيف, تمري
  { {0x2d9100dc,0x6a670029,0x2ca90f38,0x69d802de}},	// [1630] ssze_, مطال, rgad_, æven
  { {0xdb510029,0x2d91005c,0xbb840029,0xaa670cad}},	//   ذَا_, psze_, سلمي, стак
  { {0x291d000c,0x61280064,0xd87900e6,0x7d030011}},	//   tiwa_, zılm, لمات_, _înso
  { {0xff500086,0xe8940036,0x61280064,0x628a00dc}},	//   _يخی_, заць, yılm, _lefo
  { {0x291d0fc3,0x69dc0fcf,0x62980fd0,0x31b10030}},	//   riwa_, _erre, _odvo, záz_
  { {0x7d0d03c0,0x6b5000c0,0x291d0fd1,0x7ac70fd2}},	//   lhas, vägg, siwa_, _усме
  { {0xdb0d002d,0xceb4000f,0x291d003f,0x7d0d0e8b}},	//   ntaí, פיק_, piwa_, ohas
  { {0x612801e2,0x62980fd3,0xa8350054,0x490500c3}},	//   tılm, _advo, _дебљ, _بورق
  { {0xe3b10029,0x628a0fd4,0x13090c71,0xd7740015}},	//   ذرة_, _befo, иний_, _فالع
  { {0x61280064,0xe29900d7,0x56940fd5,0x69ce0fd6}},	//   rılm, јан_, _наут, _ysbe
  { {0x60c60024,0x6d440026,0x90c60146,0x61280064}},	//   tekm, ylia, обне, sılm
  { {0x612801e2,0x320b005c,0xf992000f,0x7bcf0fd7}},	//   pılm, ący_, ורט_, _oscu
  { {0x75290011,0x60c60064,0x6b5004d4,0x63050015}},	//   mnez, rekm, läge, _ووصل
  { {0x26c70f4d,0x6d440026,0xb4c9005d,0xb7da000a}},	//   neno_, wlia, _लघु_, בקשי
  { {0x7bcf0011,0xcce60015,0x75290045,0x6b500fd8}},	//   _ascu, يسري, onez, näge
  { {0xbf65002b,0x26c70fd9,0x62980bf6,0xfce30eaf}},	//   _کديو, heno_, _zdvo, мосо
  { {0x6d440fda,0x62810fdb,0x8c430fdc,0x0c260a31}},	// [1640] rlia, oblo, дете, цман
  { {0x98ad002c,0xcaa60029,0xb0aa005d,0x26c70fdd}},	//   _cieľ_, تصري, _काँग, jeno_
  { {0x26c70fde,0x7bcf089f,0xa113002b,0xd12f002b}},	//   deno_, _escu, _رویت, _سمی_
  { {0x31ba0053,0xdb04002d,0x7d0d0fdf,0xf79a0058}},	//   יזענ, ntiú, chas, لنصب_
  { {0x6fca000b,0xdb040125,0x7aa60015,0x62810fe0}},	//   िबिं, itiú, _وإسل, kblo
  { {0x7d04022d,0x1a5a0015,0x26c70fe1,0x75290fe2}},	//   lkis, _نشأة_, geno_, enez
  { {0xb0aa005d,0x62810fe3,0xe4a60fe4,0x7d04008c}},	//   _कांग, dblo, орпо, okis
  { {0x88860731,0x7d04045a,0xd5d50033,0xef1f0061}},	//   _флаж, nkis, яючы, nsür_
  { {0x26c70ccd,0x394604ff,0xd94303ae,0x7d040fe5}},	//   beno_, mlos_, _цети, ikis
  { {0x8c1b0008,0x7d0d00dc,0x39460fe6,0x62810fe7}},	//   יופי, zhas, llos_, gblo
  { {0xfd4d0092,0xaadb0008,0xb5ca002b,0xa1740033}},	//   ghiệ, בחיר, _خوام_, ягні
  { {0x1074005e,0x39460012,0x62810fe8,0x40350fe9}},	//   млюю, nlos_, ablo, земс
  { {0x645d0091,0x232a0fea,0x68e4008c,0x23780015}},	//   žsir, _коди_, öidy, _امتد_
  { {0xf1a60feb,0x8d770015,0xdb040003,0x98af002a}},	//   _дрин, قارا, quiè, mogą_
  { {0xc27b0053,0x98af0007,0xf27b0008,0x61fc00c0}},	//   _דרוי, logą_, _דרוש, ärld
  { {0xdb04002f,0x459b0053,0x26c706d5,0x7d0400dc}},	//   ctiú, יסלע, zeno_, gkis
  { {0xdb0d002d,0x7d0d0fec,0x39460012,0x3014009b}},	// [1650] staí, rhas, dlos_, _одър
  { {0x657a00dc,0x39460a40,0x61360030,0x7d0d0c6b}},	//   _otth, elos_, dály, shas
  { {0xceb2039e,0x7d0d0fed,0x39460012,0x26c70fee}},	//   _איי_, phas, flos_, veno_
  { {0xcdda00b2,0xed58000d,0x39460fef,0x6b50012d}},	//   _פֿיר, _моќ_, glos_, väge
  { {0x60dc00b2,0x66e5006b,0x69d80123,0x97c7002b}},	//   יקאנ, зола, åver, تتام
  { {0xff7c01ac,0xabfa000a,0x39460ff0,0x8f8c004f}},	//   סטומ, _ההשר, alos_, בְהֵ
  { {0x39460ff1,0x06960015,0x753b002a,0xa5f60054}},	//   blos_, سنية_, touz, зеју_
  { {0x6b5000b8,0x613600dc,0xcdaa0053,0xf8ae002b}},	//   räge, bály, ציפֿ, _مکه_
  { {0x6b500123,0x753b0ff2,0x26c70ff3,0x6b4b0030}},	//   säge, rouz, peno_, nügo
  { {0x753b0089,0x13090139,0x7d0401d3,0x0000006a}},	//   souz, сной_, zkis,
  { {0xcb120008,0x61460ff4,0x753b00b3,0x644e002a}},	//   גלי_, зена, pouz, ębia
  { {0x3d05000b,0x80b8000b,0x62810ff5,0x55ba000a}},	//   रसों_, ेजें, sblo, _למעו
  { {0xb4d7005d,0x7fd5005e,0x8f75017f,0x4427006e}},	//   ायी_, мірі, дусі, _براف
  { {0x3f9e0156,0x3ebe002e,0xe7f3000b,0xad660015}},	//   čtu_, ýtt_, _आपना_, كاره
  { {0x33180086,0xdb040152,0xc27a000f,0x63a90ff6}},	//   _بزند_, quié, _פרקי, luen
  { {0xa01b002e,0x41b20029,0x2571002e,0xc19a000a}},	//   mbön, _أمير, _mál_, _השקי
  { {0x7d040ae5,0x63a90376,0xfbdf016e,0x3f890034}},	// [1660] rkis, nuen, _crê_, _gwau_
  { {0xe816014e,0xa3dc000b,0x6fdb000a,0x60d60ff7}},	//   _देगा_, डित_, _פקיס, _haym
  { {0x4efb000a,0x257100dc,0x7d040061,0x60d60ff8}},	//   _הליג, _nál_, pkis, _kaym
  { {0x63a90273,0xaa570015,0x39460a64,0x57ea0a32}},	//   kuen, سلنا_, ulos_, йдем_
  { {0xe816005d,0x2efa00b8,0xdcf70011,0x39460ff9}},	//   _देखा_, _kopf_, şcăr, rlos_
  { {0xc58a004a,0x7e7a004c,0x4e7a004c,0x60d600da}},	//   бщие_, זאַז, זאַצ, _laym
  { {0x5554002b,0x394609ae,0x7d150030,0x98af0535}},	//   وپتر, plos_, _ügsé, wogą_
  { {0xd3a60036,0x25710089,0x399b0008,0xf9b7000a}},	//   проп, _dál_, _לילד, _מהלך_
  { {0x63a902d7,0x07a3000d,0x94730029,0x07a6006b}},	//   guen, _патн, رديا, _хазн
  { {0xa3ab005d,0x877b000a,0xa318005e,0x957c002a}},	//   गढ़_, _לאמי, іжну_, _prąd
  { {0x867b000a,0xbef8000b,0xbcfb0003,0x645d0091}},	//   _הרבו, ुसैन_, _biél, žsip
  { {0x2906008c,0x212b0ffa,0x63a90ffb,0x60d60ffc}},	//   nkoa_, unch_, buen, _caym
  { {0x63a90467,0x5f94010f,0xdbf10046,0x2f0f0012}},	//   cuen, ният, tříc, _lüge_
  { {0x6b960ffd,0x4173009a,0x2efa01d3,0x0000006a}},	//   dsyg, بایس, _copf_,
  { {0xb2bb0008,0x3cfb005d,0x290600f2,0xa2bb0008}},	//   _המור, ैसले_, kkoa_, _המוט
  { {0x6144000d,0x5cb90033,0x645d001a,0x0000006a}},	//   _пеја, ўлаў_, ýsig,
  { {0xa3d5005d,0x309c000a,0xa3d2000b,0xdb99005e}},	// [1670] हिए_, _השחמ, _हैम_, ювач_
  { {0x2bb80015,0x7bcd0034,0x0000006a,0x0000006a}},	//   ثافة_, rwau,   ,
  { {0x60d60061,0x5d550ffe,0x66f00065,0x79a70138}},	//   _yaym, _окот, चानक_, ярае
  { {0x5fb1000b,0x25e0000b,0x6d88000a,0xad88000a}},	//   _जमाल, किनी_, _מָשְ, _מְשֻ
  { {0x98f40029,0xd7f80054,0x78a40030,0x25710fff}},	//   عثما, зуј_, óiva, _sál_
  { {0xd00c0008,0x85790080,0x257100dc,0xbb840015}},	//   מּוֹ, осит_, _pál_, _سلفي
  { {0x69da018c,0x2002005c,0x28a70033,0xd6ce0015}},	//   _štev, zyki_, _ншаг, شقي_
  { {0xb4d7005d,0x6b4b00b8,0x2907003d,0x644e002a}},	//   ाये_, zügl, īnas_, ębin
  { {0x2be0005d,0x2f0f00b8,0x19580033,0x61280030}},	//   निया, _züge_, _хаты_, nűle
  { {0x68fb0298,0xdddc0007,0x68e9006f,0x7d1a0030}},	//   _houd, varž, _hned, étsz
  { {0x60d61000,0x67231001,0x68fb1002,0xa0a607ec}},	//   _paym, minj, _koud, манд
  { {0x2002005c,0x68fb008c,0x67231003,0x22580052}},	//   tyki_, _joud, linj, ýrka_
  { {0x212200d9,0xe3b3002b,0x68fb1004,0x73090015}},	//   rikh_, _سرش_, _moud, _وقصف_
  { {0x7f190010,0x2002005c,0x68fb1005,0xf7670067}},	//   пісу_, ryki_, _loud, ضا_
  { {0xa3d5005d,0x68e9002c,0xdd1c0057,0x6e43049d}},	//   हिक_, _oned, _vážn, верз
  { {0xdb0d00b8,0x7bc30011,0x68fb014a,0x67230796}},	//   traß, ănun, _noud, hinj
  { {0xe3b900dc,0x67230796,0x2ba5000b,0xab661006}},	// [1680] ntű_, kinj, गंगा, двал
  { {0xbf660015,0x27210046,0x290d0045,0x98af002a}},	//   _تدعو, nčně_, _alea_, mogę_
  { {0x67231007,0x3ebe0020,0x2906008c,0x68fb1008}},	//   dinj, õttu_, tkoa_, _boud
  { {0x6603005c,0x58ba0029,0x07a60010,0x68fb0618}},	//   dynk, تائج_, дадн, _coud
  { {0x4c36008f,0x7b090030,0x2906008c,0x67231009}},	//   _цэнт, ástó, rkoa_, finj
  { {0x8f890008,0xdddc005c,0xa3dc000b,0x75d40015}},	//   פְנֵ, karż, डिस_, فيتا
  { {0xd5af0063,0x66e301ca,0x68fb100a,0x290d100b}},	//   ъс_, тоја, _foud, _flea_
  { {0x88c60029,0x25a00ea5,0x68fb100c,0x25a10046}},	//   _تتسل, čil_, _goud, áhla_
  { {0x644e005c,0x7afc100d,0x6723100e,0x6843100f}},	//   ębio, _kort, binj, _анта
  { {0x68fb0111,0xd7fb000a,0x57fb000a,0xb7d700c3}},	//   _zoud, _והמל, _ולמו, _زوما_
  { {0x2d9e0089,0x36060225,0x7afc0d2d,0x68e90034}},	//   átel_, _تواف, _mort, _yned
  { {0xe5060015,0xd1310021,0x957c002a,0xc5f3000a}},	//   _تبطي, امح_, _trąb, _שדף_
  { {0x7afc00dd,0xd4670054,0x98af002a,0x34bc0065}},	//   _oort, _жице_, gogę_, ्जीद
  { {0x7afc08aa,0xa6f8000a,0x33170015,0x15f20065}},	//   _nort, הִֽי, _يزود_, _अपार_
  { {0xa3d6005d,0x6455005c,0xccfb0001,0x828b000a}},	//   ाटक_, ęzie, оћа_, _וְחֶ
  { {0x6b5000c0,0xa1150086,0x319b000a,0xc19b000a}},	//   väga, _سوخت, _ובהנ, _ושהי
  { {0xdb0d03af,0x6603002a,0x7afc1010,0x7b740015}},	// [1690] ntaç, zynk, _bort, نطلا
  { {0x68fb1011,0x93b7000a,0xdb0d016e,0x68e91012}},	//   _soud, ולמו_, itaç, _sned
  { {0x68fb1013,0x6723044c,0x7afc1014,0x290d00da}},	//   _poud, vinj, _dort, _plea_
  { {0xe7f3000b,0x08d4005e,0x2d830079,0x38350121}},	//   _आपदा_, кція, mpje_, ннер
  { {0x2617005d,0x68fb0152,0x67231015,0x69da01a3}},	//   _भेजी_, _voud, tinj, _štet
  { {0xcaa70115,0xe73300e5,0x6b500123,0x68fb0079}},	//   _تصحي, خصص_, lägn, _woud
  { {0xe81f005d,0x76480026,0x67231016,0xbef8000a}},	//   _मेरा_, _cydy, rinj, וצגו_
  { {0x68e90335,0x61280064,0x76480026,0x67d51017}},	//   _uned, nılt, _dydy, _побу
  { {0x37350010,0x386d1018,0x97250015,0x67231019}},	//   _знаё, _iger_, _كفرو, pinj
  { {0xcb1200b2,0xf7720008,0xfbd20008,0x82350067}},	//   ָלט_, _עקב_, נתי_, فرجا
  { {0x0322008f,0x3f99002e,0xe1260b0c,0x7d0f0030}},	//   удэн, essu_, емни, _olcs
  { {0xa3dc000b,0xf953005e,0x2d9e0046,0xe8df0016}},	//   डिश_, ннiй_, átem_, _khốn_
  { {0x13f40063,0x6d5a0144,0x2bcf000b,0x2d830079}},	//   _изця, ïtam, _सैला, epje_
  { {0x2d9e0085,0x61ee0125,0x7d0f0030,0x98af002a}},	//   štem_, óilí, _alcs, rogę_
  { {0x2f1401d1,0x63bb101a,0x2d8c0152,0xed5a0da4}},	//   _lägg_, ltun, ède_, зов_
  { {0xc5f200b2,0x621a000a,0xbe630015,0x386d0123}},	//   נדן_, _מוצק, اهِي, _nger_
  { {0xe81f000b,0x63bb101b,0x7afc101c,0x5baa02bb}},	// [16a0] _मेला_, ntun, _port, якам_
  { {0x7fd70008,0x63bb101d,0x7d0f0030,0x9b46002b}},	//   _טופס_, itun, _elcs, رناو
  { {0x7afc0746,0xfd4a006b,0xceb7000a,0x60da000a}},	//   _vort, _нзок_, _אפיק_, ּקְנ
  { {0x76480176,0xb17a0053,0x7afc0334,0xa17a004c}},	//   _rydy, לטער, _wort, לטעט
  { {0x39130086,0x6d46101e,0x76480026,0x7afc0541}},	//   دونز, _ikka, _sydy, _tort
  { {0x98c50024,0xcf930008,0x8f9b000a,0xd5b00040}},	//   ītās_, נטו_, ליני, لفت_
  { {0xceb30135,0x49d4000a,0xdb040003,0x60c40085}},	//   טיג_, _בֵּן_, vriè, _obim
  { {0x63bb00b8,0x95c3002b,0x154301ca,0xa3dc0065}},	//   ftun, اييه, лејм, डिल_
  { {0xd4e3005f,0xdb040152,0xc34a0010,0x63bb101f}},	//   ующи, triè, зяне_, gtun
  { {0x0bb70008,0xdb0d001c,0x6b840b63,0x079b000a}},	//   עלים_, rtaç, ipig, _מסמל
  { {0x6d460084,0xdb040152,0xdb0d001c,0x4155029f}},	//   _okka, rriè, staç, квос
  { {0xdb0d016e,0x0577004f,0xf9460138,0x7644007f}},	//   ptaç, _נגדם_, мнiк_, ğiyd
  { {0x389b000a,0xe5050015,0xa01b0030,0x34fb004f}},	//   היכנ, _جبلي, mbök, _מהאד
  { {0x54530191,0x32050089,0xc2c40002,0x6d461020}},	//   _світ, byly_, _شيعي, _akka
  { {0x7c870001,0x1687000a,0x7d250015,0x0dc81021}},	//   еузе, עֲךָ_, نفسن, нути_
  { {0x2d830079,0x2262002a,0x386906c0,0x0000006a}},	//   rpje_, ęskę_, žari_,
  { {0x8aa7087a,0x113c000a,0x6b8402f2,0xfaa70df0}},	// [16b0] еред, _מתהל, gpig, ешен
  { {0x2fc902f2,0x69d51022,0x60dd1023,0x0000006a}},	//   _ipag_, _psze, ldsm,
  { {0xf9930225,0x63bb014f,0xaf340015,0x798e0034}},	//   ابط_, ztun, _حريت, _cwbw
  { {0xd23b0008,0x7d0f00dc,0x2d81002d,0x63bb06ee}},	//   הגבל, _ulcs, _ithe_, ytun
  { {0xb8c9014e,0x69d50050,0x9e670086,0xb09c000a}},	//   _गए_, _wsze, _تاکن, ליאר
  { {0x6d4d0c8d,0x99850015,0xc054000a,0x66b20004}},	//   llaa, _للسو, נזס_, абљу
  { {0x798e0026,0xda090115,0x6d46002e,0x05a9005e}},	//   _gwbw, _غيره_, _ykka, євий_
  { {0x386d0134,0x6d4d1024,0x63bb1025,0x60dd02de}},	//   _uger_, nlaa, ttun, jdsm
  { {0x7d030011,0xdcfc0024,0x63bb04ea,0xe3e9002b}},	//   _însu, nprā, utun, بکان_
  { {0x613d0f87,0x752202b9,0x2d9e0046,0x6b4b0012}},	//   mély, _emoz, átek_, fügi
  { {0x6d4d0005,0x2fc90035,0x63bb1026,0xb05b005b}},	//   klaa, _apag_, stun, keäs
  { {0x6d5a0007,0xd12f0015,0xbcfb016e,0xa4870015}},	//   įtak, ْمَ_, _fiéi, _أجان
  { {0x889a0008,0x2f140bc2,0x1c15000b,0x6b8401cc}},	//   וברי, _läge_, णनफल_, xpig
  { {0xdb04038d,0x656b1027,0xe1f100e6,0x4ed51028}},	//   prié, _high, _نسب_, люст
  { {0x7e230001,0xc1060015,0x14d5000a,0x6d4d008c}},	//   адрж, _لوثي, ֣וּל_, flaa
  { {0x657c00dc,0xc1720008,0x63a91029,0x6d4d102a}},	//   _érhe, _דחה_, oren, glaa
  { {0x656b0041,0x3c660033,0x63a9102b,0x765c0069}},	// [16c0] _migh, ткаг, nren, _úryv
  { {0x656b003e,0x613d00dc,0x0057000a,0x63a9102c}},	//   _ligh, dély, _בשפת_, iren
  { {0x644b00df,0x63a90940,0xdb1d0134,0x6d4d0409}},	//   _lygi, hren, _opsæ, blaa
  { {0x656b003e,0xdcfc0024,0x01fa00a3,0x63a9102d}},	//   _nigh, bprā, ופעל, kren
  { {0xab66005c,0xa7d30015,0x684304ab,0x63a9102e}},	//   _pożą, لتوص, анца, jren
  { {0x501b0008,0xfaa6004a,0x6d440045,0x63a9102f}},	//   וונו, _шаго, loia, dren
  { {0xdb0402c1,0x2be0000b,0x63a91030,0xf5b30015}},	//   stió, निवा, eren, لصيد
  { {0x7d160034,0x7d030045,0x63a91031,0xd37a1032}},	//   nhys, _înst, fren, мчо_
  { {0x63a91033,0xd8770015,0xe4d3002b,0xa7661034}},	//   gren, _شملت_, شتيب, _акад
  { {0x86ea0029,0x656b003e,0x86750010,0x51f80036}},	//   _تعرف_, _eigh, _быцц, еною_
  { {0x656b003e,0x8717000a,0x63a91035,0x64c60015}},	//   _figh, _שקבע_, aren, _ليال
  { {0x9426005f,0x452a006b,0x69130061,0x142603ae}},	//   _имее, _южен_, _içec, _идем
  { {0x6d441036,0x38bd0030,0x60dd1037,0x63a91038}},	//   doia, láró_, rdsm, cren
  { {0x9f60002e,0xf773000a,0xdb250030,0x7d16008c}},	//   ærðu_, יקש_, épül, ehys
  { {0x7e28022a,0xf2d30135,0xce94006b,0x6b500dca}},	//   віта_, _כעס_, расъ, rägl
  { {0x1bd5006b,0x2d580342,0x7d160034,0x2b890058}},	//   лобя, вись_, ghys, فَرٍ_
  { {0xdc55019c,0xfbd00029,0x6d4d0234,0x0000006a}},	// [16d0] увањ, يتك_, rlaa,
  { {0xf1b6005d,0x6d4d0991,0x60080008,0x7b140033}},	//   _अमान, slaa, _יִתְ, адух
  { {0x25780030,0x38bd0030,0x6d4d1039,0x63a9103a}},	//   _nél_, járó_, plaa, zren
  { {0xe0df04ed,0xf9900015,0x63a9103b,0x7d16103c}},	//   ndò_, تبك_, yren, chys
  { {0xfd56103d,0x656b103e,0xa6c90888,0x7d0d103f}},	//   _תשרי_, _righ, елла_, mkas
  { {0x656b1040,0x8c1a000a,0xe8df0016,0x63a91041}},	//   _sigh, _טורי, _phồn_, vren
  { {0x257800dc,0x19940010,0x63a91042,0x85940033}},	//   _cél_, _вася, wren, ашыц
  { {0x25781043,0xaa58005e,0x63a91044,0x693c0085}},	//   _dél_, _рису_, tren, včeg
  { {0xa774005e,0x38351045,0x7d0d1046,0x63a91047}},	//   _влуч, _снар, ikas, uren
  { {0xe1f9005f,0x257800dc,0x63a90901,0xe4560033}},	//   его_, _fél_, rren, ыжы_
  { {0x9afa0008,0x7d0d1048,0x656b1049,0xaaab000b}},	//   תפתח, kkas, _tigh, _चयनक
  { {0x7fb60010,0x63a90376,0x3a36000a,0x656b104a}},	//   лёгі, pren, טרתם_, _uigh
  { {0x7d0d104b,0xc2c50040,0x03a50120,0x6d4400d4}},	//   dkas, _ميشي, _сило, voia
  { {0xa856000a,0xa224002b,0xe4500015,0x54680033}},	//   טירה_, اریه, _بضم_, _раім_
  { {0x7d0d104c,0xdd1d0046,0xdb04016e,0xd7da000b}},	//   fkas, lářs, luiç, _मैनच
  { {0xd24e0015,0xceb8002a,0x9f400144,0x7e7c0085}},	//   _عني_, żę_, _triï_, scrp
  { {0x38bd00dc,0xd1170008,0x6eac005d,0xdb04016e}},	// [16e0] záró_, _תקפה_, _जयपु, nuiç
  { {0x7d0d104d,0x8a3a0080,0xaf0a0029,0x945d005c}},	//   akas, няет_, _أقدم_, leńs
  { {0x88860063,0xdebb000a,0xd884002b,0xb05b0012}},	//   глеж, _אמיל, لهای, nfän
  { {0x7aeb0024,0xb866002b,0xcb09000a,0x58960015}},	//   ēgta, هاشو, הל_, اجاز
  { {0xa3d2005d,0xdd1d0089,0x66f0000b,0x98a30818}},	//   _हैं_, jářs, चालक_, сиче
  { {0x05b40029,0xdd1d0089,0x2af60010,0x1e96000a}},	//   لمتح, dářs, _сямё, אכַל_
  { {0x645d09f0,0xceb3013a,0xe5c60a24,0x0000006a}},	//   ýsin, ציה_, усло,
  { {0x2578001a,0x945d0535,0x61fc02dc,0xd94607f9}},	//   _vél_, jeńs, ärlm, _себи
  { {0x28dd005d,0x46b60002,0xdb04016e,0x945d002a}},	//   _नोटि, _محاس, guiç, deńs
  { {0x9bbb00b2,0x5186104e,0x8bd7000a,0xa3d2000b}},	//   עציפ, лума, נויו_, _हैः_
  { {0xaac6014e,0xd2500074,0x4ac6005d,0x7bc30045}},	//   र्यक, تند_, र्यव, ănui
  { {0xdb04001c,0xd2570010,0xf653000a,0x63e60015}},	//   buiç, ыцы_, _הצע_, _مستك
  { {0xa3b3014e,0xe0df02b9,0x43940937,0xdb0d001a}},	//   जूद_, rdò_, _талс, rtaú
  { {0x1ee7002b,0xdb150030,0x3dda0012,0x7433008b}},	//   دوسی_, öbün, _bspw_, _уніф
  { {0xc27b00b2,0x627b000f,0xa3dc000b,0xbd4500c3}},	//   _ארוי, _אנונ, डिक_, لنسي
  { {0xf1a9014e,0x629a0c0a,0x26de104f,0x2d9e0045}},	//   _कितन, lato, _lato_, âtea_
  { {0x7d0d1050,0x2aab0054,0x7b770040,0x39461051}},	// [16f0] rkas, етео_, اطرا, doos_
  { {0x212b018b,0x6eb2005d,0xc334000a,0x501c000a}},	//   lich_, _जाएँ, ׁוּ_, _רוזו
  { {0x69070010,0x212b002a,0x7d0d1052,0x98751053}},	//   лядз, oich_, pkas, алец
  { {0x629a1054,0x5dfa000a,0x212b0051,0xaa641055}},	//   hato, _ספרנ, nich_, стук
  { {0xdc9a000a,0x6b4b0012,0x98070033,0x18690054}},	//   _שישל, fügt, ыяжд, њали_
  { {0x212b0041,0x945d005c,0x7ceb00c0,0x16a61056}},	//   hich_, zeńs, _förä, авши_
  { {0x212b0050,0x9f440089,0xc68e0015,0x140d000b}},	//   kich_, ímé_, ذِي_, िन्ह_
  { {0xdb04001c,0x212b0156,0x63f50029,0xdd1d0046}},	//   tuiç, jich_, لأخر, tářs
  { {0x26de001c,0x75290024,0x6455002a,0xe459006b}},	//   _fato_, riez, ęzio, ъжи_
  { {0xa1c5008f,0x13090080,0xdb04001c,0x032506f6}},	//   абод, тной_, ruiç, рдон
  { {0xcb140008,0x75291057,0x8505002b,0x27450046}},	//   מלץ_, piez, _پوشن, ríně_
  { {0x9567010f,0x212b005c,0x26de1058,0x757a000a}},	//   _създ, gich_, _zato_, _סטנפ
  { {0x6446007c,0x248d016e,0xd8d6004c,0x4ac6000b}},	//   ükit, mbem_, בורט_, र्डव
  { {0x6d5d003f,0xb05b1059,0x629a06ae,0xfe720058}},	//   _ahsa, pfän, cato, تدح_
  { {0xb05b07fd,0xad6600c3,0x7c960bdb,0xde03105a}},	//   lfäl, لاره, ирац, опри
  { {0x212b032c,0xdb0400f2,0x4c860033,0x3f8d0045}},	//   cich_, ntiö, рлав, ţeua_
  { {0xb05b00b8,0x8b26054f,0x998d0085,0x2fd7002b}},	// [1700] nfäl, адае, _ćeš_, _نويد_
  { {0x305b0008,0x9f9b0008,0x4f9b0008,0x905b000a}},	//   _בדפד, _שסיפ, _שביצ, _בכפת
  { {0xbcfb0003,0xa2bd000b,0x6b50007c,0x26de105b}},	//   _piét, _शान्, nägi, _rato_
  { {0xb05b00c0,0xe7860036,0x497302e1,0x629a105c}},	//   kfäl, ауко, іліс, zato
  { {0xa81a0002,0x18360015,0x26de105d,0x87ba004a}},	//   ختار_, جراح, _pato_, тует_
  { {0xc9860086,0x77910086,0xb5a600a4,0x70d3000b}},	//   _نشري, سیما, арий, _तस्ल
  { {0x96f70015,0x629a105e,0x64590535,0xb05b02ad}},	//   شعور_, vato, _azwi, efäl
  { {0xd943057e,0xbcfb0003,0xb05b0012,0xd4c30033}},	//   _деси, _hiér, ffäl, осьп
  { {0x53970010,0xbcfb00dc,0xaac6005d,0x26de105f}},	//   авыя_, _kiér, र्थक, _tato_
  { {0xe5a6005e,0x68e01060,0x68e2007c,0x212b1061}},	//   _вижи, _hamd, ldod, wich_
  { {0xd25a0063,0x29041062,0xbcfb1063,0x212b1064}},	//   ъци_, _koma_, _miér, tich_
  { {0x64460020,0x2d570061,0xddd4002a,0x629a1065}},	//   ükis, eçen_, łaśn, sato
  { {0x2f1400c0,0xa3dc005d,0xff07005e,0x212b1066}},	//   _säga_, डिओ_, аявн, rich_
  { {0x69dc00bd,0x8cc9000b,0x539b000a,0x23270004}},	//   _osre, ह्नो, _יידו, _кочи_
  { {0x4d27000d,0xa3d2005d,0x2d850384,0x7095006b}},	//   аќаа, हौर_, ële_, _лайф
  { {0x2f140005,0x5c751067,0x6298008c,0x25a10046}},	//   _väga_, слат, _hevo, áhli_
  { {0xa3dc014e,0x68e20176,0x7a870015,0xfc67006b}},	// [1710] डिट_, ddod, لشام, ръвн
  { {0xf1da005d,0x91da000b,0x4ea71068,0xeab30058}},	//   _बनान, _बनाई, _триа, تعر_
  { {0xf8750029,0x3f8b00bd,0xceb2004c,0xbae40058}},	//   مهاج, lpcu_, _ציט_, تكلي
  { {0x32370053,0xc8790064,0xf1a9000b,0x68e01069}},	//   סטאן_, _başa_, _किसन, _camd
  { {0x27e902c1,0x68e00035,0x62980079,0x9814002b}},	//   ían_, _damd, _oevo, يبها
  { {0x62980e25,0xc7240036,0x7bdd106a,0x8724005e}},	//   _nevo, одій, _issu, оміж
  { {0xe7f3005d,0x63a2106b,0x99d40015,0x27e60012}},	//   _आपका_, _avon, _وتفا, avon_
  { {0xce380008,0x68e00026,0x2e38000f,0xd5b8000b}},	//   יאות_, _gamd, ירוש_, _इमरज
  { {0xa3d2005d,0xd7e4005e,0xb8150054,0x248d002a}},	//   हौल_, _міфо, _удај, rbem_
  { {0xf770003b,0xb05b079c,0xd7590015,0xc2c50058}},	//   _قال_, rfäl, _صلات_, حيدي
  { {0x7c3b0084,0xa2aa005d,0x321101c9,0x41b40142}},	//   _þurf, _फ़ार्, ázy_, осят
  { {0x68f9000a,0x80fa0004,0x628e001a,0x89e8000a}},	//   אלֹה, ухот_, ðbor, בַשֵ
  { {0x4385003b,0x63850001,0xc106002b,0x753e0030}},	//   _التق, _угла, لوگي, épze
  { {0x629800f6,0xc692000a,0x68e20b46,0xe299106c}},	//   _gevo, ּאן_, zdod, _сак_
  { {0x321e005c,0xa3b3000b,0x7bdd082d,0x63a209cb}},	//   czty_, जूर_, _assu, _zvon
  { {0x31a301e2,0x6143106d,0x22580030,0x8234012c}},	//   mız_, _неща, ürke_, _برها
  { {0xed570083,0xb47a004c,0x2904106e,0xfc64009a}},	// [1720] сот_, אָבי, _roma_, زخری
  { {0x2904000c,0xda660029,0x7ed50036,0x6281106f}},	//   _soma_, ماضي, _діюч, nclo
  { {0x31a30482,0xe0df0251,0x58860010,0x9d461070}},	//   nız_, clòs_, была, _генд
  { {0xc8b60029,0xc8791071,0xa967006b,0x189a0015}},	//   إصاب, _paşa_, биха_, اضاة_
  { {0xe1e70086,0x68e21072,0x765a002a,0xc79608f0}},	//   _کس_, rdod, _szty, ёрды
  { {0x4733005e,0x07080015,0xa057004c,0x27e61073}},	//   пніс, شيعي_, זױנס_, rvon_
  { {0x76a90036,0x63a2002e,0x69dc016f,0x6d411074}},	//   ртів_, _svon, _usre, élag
  { {0x2561002e,0x76440064,0x31a30061,0x7d061075}},	//   hólf_, şiyo, dız_, _joks
  { {0x7d060007,0x26130092,0x97bd0484,0xa87b000a}},	//   _moks, ạo_, _архi, _תאמר
  { {0x8c1b000a,0x31a30061,0x7d061076,0xf1a90065}},	//   טופי, fız_, _loks, _किशन
  { {0x14ca005f,0x60f90e7e,0x8afb1077,0x2258004a}},	//   _были_, ання_, אליז, рины_
  { {0x54e50015,0x320c002a,0x7d061078,0x05661079}},	//   _وسنق, rydy_, _noks, _увен
  { {0x321e005c,0x657a003f,0x4346005e,0x8556002b}},	//   szty_, _huth, _ледв, _پیکر_
  { {0x543b0053,0x98bd005c,0x421a0015,0x657a044d}},	//   _געדא, mową_, _مزعج_, _kuth
  { {0x91860225,0x98bd005c,0x7d06107a,0x657a0030}},	//   _اجتم, lową_, _boks, _juth
  { {0xf2370008,0x5d55017f,0xdb16008c,0x4035107b}},	//   _לרוץ_, ікат, htyä, _мейс
  { {0xba990036,0x2d5803e7,0x1b7b0015,0x98bd002a}},	// [1730] иває_, сить_, اصرة_, nową_
  { {0x9f53005c,0xc018000a,0xdb040030,0x2dd5107c}},	//   ądów_, _לקחו_, triá, _джор
  { {0xc27b00b2,0xdb0d001a,0x7bc40144,0x0000006a}},	//   ארבי, ptaþ, atiu,
  { {0x76440064,0x98bd005c,0x35c2000b,0xa3b30065}},	//   ğiyl, kową_, _शहज़, जूँ_
  { {0x2b930086,0x9a870010,0x7bc4107d,0x657a0043}},	//   _ریاس, _губл, ctiu, _auth
  { {0x8f9c0053,0xdb160092,0x31a30064,0x98bd005c}},	//   ריגי, huyê, yız_, dową_
  { {0x395f0041,0x7d060064,0x451903fc,0xceb400f3}},	//   _thus_, _yoks, иция_, ליס_
  { {0x2a7b0007,0x6d8c000a,0x69c5107e,0xb385107f}},	//   šybą_, אָזְ, mthe, олил
  { {0x6b8d0111,0x4ac6000b,0x693c00bc,0x69c51080}},	//   npag, र्वव, očen, lthe
  { {0xf1c30089,0xe2990001,0x693c04af,0x6b8d1081}},	//   _naší_, шао_, nčen, ipag
  { {0x3f89013c,0x657a1082,0x69c51083,0xc5d9012c}},	//   _atau_, _guth, nthe, _خواص_
  { {0xe56e0191,0x31a301e2,0x69c51084,0x6b8d0111}},	//   _із_, rız_, ithe, kpag
  { {0x31a30064,0xb05b0012,0x98bd002a,0x69c502f7}},	//   sız_, nfäh, cową_, hthe
  { {0x60cd0020,0x543a004c,0x6b8d0079,0xa01b0030}},	//   _ebam, _דענא, dpag, tbör
  { {0xec9a00d0,0x693c0227,0x6b8d1085,0x69c51086}},	//   итај_, dčen, epag, jthe
  { {0x92580015,0xa01b0400,0x69c5031a,0x7bc41087}},	//   _اشهر_, rbör, dthe, ttiu
  { {0x7d060293,0xc4d2000a,0x4419000a,0xdee61088}},	// [1740] _voks, וגן_, בוּס, _допи
  { {0x78a91089,0xab5b0012,0xca560004,0x1e8301c5}},	//   _adev, _spür, отењ, _ольм
  { {0x6b8d0035,0x69c5108a,0xaac6000b,0xb05b0012}},	//   apag, gthe, र्षक, efäh
  { {0x6b8d108b,0x7bc4108c,0x57ea01b7,0x27ed108d}},	//   bpag, ptiu, идем_, _bren_
  { {0x2ca00db8,0xdb1600f2,0x69c5108e,0x6b500012}},	//   maid_, ttyä, athe, wägu
  { {0x291d00e8,0x2ca0108f,0x69c50012,0x46f6006b}},	//   ahwa_, laid_, bthe, ючет
  { {0xd5b00029,0x27ed1090,0x98bd002a,0x25dd000b}},	//   رفة_, _eren_, wową_, _कैदी_
  { {0x291d000c,0x4ac6005d,0x98bd005c,0xa5070001}},	//   chwa_, र्रव, tową_, жећа_
  { {0xdddc0085,0x27ed02d6,0xfc45004f,0xa7850058}},	//   jbrž, _gren_, ּאתָ_, _فشلو
  { {0xbcfb002d,0x2ca00112,0xa3cb000b,0x98bd002a}},	//   _mhéa, haid_, _लहर_, rową_
  { {0xdcfc0007,0x98bd005c,0x6603000d,0x2ca00020}},	//   sprę, sową_, _опфа, kaid_
  { {0x2ca01091,0x98bd002a,0x612b1092,0x212b00ce}},	//   jaid_, pową_, рцог_, ріон_
  { {0xdb04001c,0xb4b6005d,0xada2002c,0x5f940063}},	//   criç, जली_, _šúpl, мият
  { {0xa3d7005d,0xc7b3000a,0xadbd0033,0x69c51093}},	//   ाबर_, ובש_, лагi, ythe
  { {0xf1c302d5,0x2ca00026,0xe2460086,0xdb0d0003}},	//   _vaší_, faid_, _بخشي, fraî
  { {0xbcfb002d,0xccf80001,0x6b8d0079,0x2ca00034}},	//   _bhéa, оћу_, tpag, gaid_
  { {0xbcfb002f,0x2bb80029,0x0ca80063,0x693c0089}},	// [1750] _chéa, قالة_, ютри_, tčen
  { {0xbcfb002f,0x693c06d5,0x6b8d1094,0xcf92000a}},	//   _dhéa, učen, rpag, _רטי_
  { {0x6b8d0111,0xa2bd000b,0x291d00aa,0x69c80123}},	//   spag, _शास्, thwa_, _ädel
  { {0xbcfb002d,0x69c51095,0xd257000a,0xa2ca000b}},	//   _fhéa, rthe, חשבה_, त्त्
  { {0x6cfa013a,0xacfa000a,0x69c51096,0x3cfa000a}},	//   _הפרס, _ההרכ, sthe, _הפרב
  { {0x291d0f4d,0x5a470010,0xb05b0012,0x6d4d008c}},	//   shwa_, _дэба, rfäh, loaa
  { {0xb05b00b8,0x6ecd000b,0x693c0085,0x7c67002b}},	//   sfäh, द्यु, očel, _داگل
  { {0xd4d90191,0x2e3c01ac,0xdb04016e,0xbe3c000a}},	//   ські_, יגונ, triç, יעות
  { {0x27ed0111,0xe3b10029,0x249f1097,0x98af00d4}},	//   _uren_, ررة_, raum_, angă_
  { {0x6b500123,0xb2250e3f,0x42251098,0x20e800a1}},	//   lägr, змол, здов, _ởi_
  { {0x06760053,0xdb0d02c1,0xc049000a,0x93240015}},	//   _זײער_, ntañ, _עז_, برين
  { {0x6908000a,0xdb0d0234,0x0000006a,0x0000006a}},	//   ַּרְ, kraï,   ,
  { {0x2ca00005,0x24580010,0xa9160053,0x645d0020}},	//   vaid_, _даць_, פֿטס_, üsid
  { {0x656900b8,0xdb1c1099,0x693c0816,0x2d7801c0}},	//   lmeh, özün, ečel, _očet_
  { {0xdb0d0152,0xbcfb002d,0x2ca0109a,0x12fa000a}},	//   traî, _shéa, taid_, _להסב
  { {0x65690012,0x3b86109b,0xf19a000a,0x6d4d02f2}},	//   nmeh, злаг, _פשפש, goaa
  { {0x6569003f,0xe1650002,0x25dd000b,0x1d07109c}},	// [1760] imeh, _تدوي, _कैसी_, чети_
  { {0x6b5000c0,0x98bd002a,0x693c02d8,0x2ca0109d}},	//   vägs, mowę_, ačel, said_
  { {0x1e970008,0x8e7b0008,0x5eeb0008,0x7e7b000a}},	//   _מכיל_, _לניה, _הַכְ, _לאיז
  { {0xbcfb002f,0xfd120015,0xf79a0015,0xa967006b}},	//   _théa, _أجد_, منصب_, пиха_
  { {0xdb0400dd,0x4879005e,0xa7b800fd,0x61e6003d}},	//   nsië, ісця_, ілку_, ākli
  { {0xdbc70020,0x7d04003c,0x96ba02e1,0xb8e3000b}},	//   tööt, ljis, суду_, _एफ़_
  { {0xd5af0010,0xdb0400c0,0xc1da000b,0x7c240045}},	//   эс_, rriä, _बनेग, lzir
  { {0xdce4016f,0x7d160007,0x2a3b000a,0xc4c60015}},	//   kmič, nkys, _העלמ, ستبو
  { {0xdb0d002e,0x59750033,0x9cd70c44,0xd9430317}},	//   otað, _цыру, לוקה_, _чети
  { {0xdb0d002e,0x6569002c,0x98bd005c,0x47d3002b}},	//   ntað, ameh, dowę_, _سيمر
  { {0x8675008f,0x656200e8,0x75960015,0xa2bd000b}},	//   _жыцц, _thoh, _رجاء, _शार्
  { {0x2d570064,0x3a370008,0xaa370135,0x61360046}},	//   rçek_, לרים_, לטיק_, yšle
  { {0x50640124,0xe907000a,0xdb0d001a,0xdb0400aa}},	//   етра, הֶם֙_, ktað, rsiê
  { {0x8d770015,0x7077002b,0x7c2402c6,0x941e0061}},	//   كارا, _کاغذ, dzir, ığıy
  { {0x9757000f,0x9f440046,0x7d04001a,0x7e44007e}},	//   פילו_, ímá_, fjis, ехте
  { {0x91bb0008,0x693c016f,0xd23b000a,0xb23b004f}},	//   _המהי, učel, _לגול, _לעוז
  { {0x7f840029,0xdb0d016e,0x50fa000a,0x6f010030}},	// [1770] _كلين, nuaç, _וִיד, ölcs
  { {0x501c0008,0x7d04109e,0xdb0d0144,0x4424109f}},	//   _לוחו, ajis, rraï, izm_
  { {0xceb200b2,0xdb040152,0x89d90086,0x99d90015}},	//   _ביי_, isiè, توار_, تواء_
  { {0xdb0d002d,0x7c240085,0xa2d3000b,0x79240b9b}},	//   mraí, bzir, _बॉन्, ньчж
  { {0xdb0d02c1,0xa8780029,0xe7a80036,0x66e510a0}},	//   stañ, أحمر_, звіл_, дола
  { {0x8ae40191,0x3ce90020,0xdb0d016e,0x1bfa000a}},	//   _післ, ldav_, duaç, _ולשב
  { {0xdb0d002d,0xcb12000a,0xb865002b,0x45d20099}},	//   nraí, _ילך_, ساچو, војс
  { {0x3ce90020,0x7ae700dc,0xfdf80008,0x838910a1}},	//   ndav_, _hajt, לצות_, обив_
  { {0xdb0d10a2,0x94720086,0x65690a83,0x92b50015}},	//   hraí, نگها, rmeh, وحدا
  { {0x2329005e,0x3f84001a,0x27e00061,0x394f10a3}},	//   іони_, ímum_, çine_, logs_
  { {0xcb120008,0xb2090063,0x461500a2,0x98af0091}},	//   דלי_, ценз_, _توار, angą_
  { {0xcea9013a,0x8fa60190,0xdce406c0,0x0000006a}},	//   _כי_, маме, tmič,
  { {0xbcfb0152,0xd9aa000b,0xdb0d016e,0x25a00085}},	//   _phén, _चट्ट, cuaç, ćile_
  { {0xdb0400dd,0x69d50079,0x7ae710a4,0xdb160003}},	//   rsië, _opze, _najt, puyé
  { {0xdb0d002f,0xdb040079,0x7d1604d1,0xc106006e}},	//   graí, ssië, tkys, _يوتي
  { {0x2f14007c,0xad650021,0xc19a004f,0x1d5500af}},	//   _mägi_, فاقه, _ושקי, еђус
  { {0x3ce6032c,0x4e7a0015,0x5f2a004a,0x394f0f21}},	// [1780] ľov_, _وحدد_, _моим_, dogs_
  { {0xd9100086,0x3ce6002c,0xfe94002b,0xa2d3000b}},	//   گیر_, žov_, _سیرج, _बॉम्
  { {0x4efb000a,0x2f14007c,0xdb0d0125,0x9a6a0015}},	//   _והיו, _nägi_, craí, آمال_
  { {0xdb0d0084,0x693c002c,0xda6500e6,0xd910002b}},	//   stað, mček, رالي, دیر_
  { {0x31da005d,0x98a30b18,0xdb04002d,0x7ae700dc}},	//   _बन्ध, тиче, iriú, _fajt
  { {0x66e30001,0x758a0142,0xc58a006b,0x19ba0015}},	//   воља, осив_, ощие_, _وطأة_
  { {0xf1dd000b,0xd5ba01f3,0x0f37004f,0x0000006a}},	//   _फैलन, іск_, ורסט_,
  { {0xdb0d001c,0x7ae710a5,0xb9060138,0x0000006a}},	//   tuaç, _zajt, _ўзак,
  { {0x63bb003f,0xa7a70004,0x693c0046,0x337410a6}},	//   guun, _окта_, yčej, нгир
  { {0x60c4001c,0x1bfb0053,0x25450024,0x764d0064}},	//   _acim, קליב, vēle_, şaya
  { {0xe13510a7,0xdb0410a8,0x63bb02f2,0xa1590432}},	//   енны, friú, auun, зану_
  { {0xdb040152,0x2d850046,0x26dc10a9,0x0000006a}},	//   ssiè, ílem_, levo_,
  { {0xb5a00001,0x2897000a,0xc1780091,0x78a001d7}},	//   _енcи, ודכן_, tvės_, _memv
  { {0xdb0d10aa,0xd80b004f,0x0000006a,0x0000006a}},	//   traí, חִלָ,   ,
  { {0xdb04002d,0x7ae706e7,0xb2bb000a,0xd2500015}},	//   briú, _rajt, _ומור, _حنث_
  { {0xdb0d0ac5,0x7ae710ab,0x6f1e0079,0x2545003d}},	//   rraí, _sajt, _elpc, pēle_
  { {0x3f67005f,0xbbb90036,0x60dd044d,0xc1790091}},	// [1790] _отоб, ягає_, mesm, svės_
  { {0xbcfb0152,0xc8790011,0x26dc04c6,0xc334000a}},	//   _théo, _iaşi_, jevo_, ׂוּ_
  { {0x7ac40063,0x394f0123,0x26dc10ac,0xb9940015}},	//   ъсте, togs_, devo_, َلْب
  { {0x25f4005d,0x2561001a,0x60dd10ad,0xdb1d0052}},	//   ्मनी_, kóla_, nesm, _ppsó
  { {0x2259002a,0xbcb6000a,0x394f10ae,0x7aca0065}},	//   ęski_, _אפרו_, rogs_, _सॉकॅ
  { {0x5fbc0053,0x8c180015,0x63bb008c,0x257110af}},	//   קצונ, _غيّر_, vuun, _išli_
  { {0x96940036,0x6d480152,0xaa58005e,0x60dd10b0}},	//   тріш, édag, _жиру_, kesm
  { {0x3ea10020,0xfba3000b,0x74150015,0x75d2002b}},	//   _leht_, _ओबाम, فوعا, اييا
  { {0x60dd10b1,0x4ac60065,0x25610052,0x36d510b2}},	//   desm, र्कव, góla_, _поар
  { {0x07f80029,0x68e90026,0x60dd007c,0xa20510b3}},	//   _ترفع_, _haed, eesm, епод
  { {0x68e900d9,0x9f40002d,0xdb04002d,0x63bb0044}},	//   _kaed, _triú_, triú, suun
  { {0x4acf005d,0xaacf005d,0x628a0493,0xd24e002b}},	//   स्तव, स्तक, _effo, حچه_
  { {0x653a0053,0xbcfb006f,0x7c3b10b4,0xb05b0123}},	//   _צענד, _chém, _žurn, dfäs
  { {0x83b6000a,0x63a910b5,0xf767006e,0x6d4110b6}},	//   _נפצע_, msen, طا_, élan
  { {0x523900b2,0x6136003d,0xc332000a,0x81bc003d}},	//   _מײַנ, ašla, _גוג_, nzēl
  { {0x693c006f,0x2167033d,0xfce310b7,0x1d070302}},	//   rček, _пищи_, лосо, неси_
  { {0x63a910b8,0x5bc60015,0xab6610b9,0x113b004f}},	// [17a0] nsen, عترف, евал, _מתקל
  { {0x3ea100b8,0xba260033,0x63a910ba,0x0000006a}},	//   _geht_, ндзк, isen,
  { {0xfe720015,0x63a90012,0x64590034,0x3e36002b}},	//   _حدة_, hsen, _lywi, _سعدآ
  { {0xc7c60229,0x63a910bb,0xb05b0123,0xc9930015}},	//   ески, ksen, mfär, النظ
  { {0x6459003f,0x41a6000b,0x2906008c,0x26dc10ac}},	//   _nywi, _कौनस, rjoa_, tevo_
  { {0x7bcb0008,0xeb910008,0x26dc02c1,0x63a910bc}},	//   _מֶלֶ, _כָל_, uevo_, dsen
  { {0xd9100074,0x68e900d9,0x78a000bd,0xaa460004}},	//   _پیش_, _faed, _temv, _чевл
  { {0x44f4009c,0x63a902de,0x64590034,0x6126001a}},	//   тпис, fsen, _bywi, _hólf
  { {0x645910bd,0x9696005e,0xd4670054,0xdb0d001a}},	//   _cywi, _зреш, ниће_, rtaö
  { {0x6459005c,0x21200049,0x2f14007c,0x2561002a}},	//   _dywi, _alih_, _kägu_, róla_
  { {0x225800fb,0x5ab70053,0x75d30031,0x7d0b0123}},	//   ærk_, עלטע_, _ميلا, ögsk
  { {0x010b0086,0x859b0053,0x2d810012,0xe1670015}},	//   ستجو_, _זשאו, _ruhe_, عددي
  { {0xc8790011,0x64590026,0x63a900dc,0x2d8110be}},	//   _paşi_, _gywi, csen, _suhe_
  { {0xb05b0400,0x2d81008c,0x93fb004f,0x0000006a}},	//   ffär, _puhe_, _מלדי,
  { {0xa01b0014,0x51f30115,0x82d7000a,0x2f14007c}},	//   nböz, _مسير, _נוהג_, _nägu_
  { {0xbcfb0152,0x5d780080,0xd657000a,0xdde30030}},	//   _thém, ейся_, גילת_, érőe
  { {0x7ff70029,0x5c750063,0x3b5500af,0x68e910bf}},	// [17b0] _أسعا, тлат, вкар, _raed
  { {0x291f0125,0x68fb00cb,0x2b14005e,0xb05b0123}},	//   _slua_, _snud, льєр, sfäs
  { {0xc3330008,0x63a910c0,0x68e910c1,0xe945009a}},	//   נוע_, zsen, _paed, پرای
  { {0x5dc8000a,0x63a910c2,0xa3e0000b,0x68e910c3}},	//   _אֶשְ, ysen, दबा_, _qaed
  { {0x34dd005d,0x25710085,0xfc64006b,0xbcf40195}},	//   _मसौद, _ušli_, _бърн, _спящ
  { {0x45d50ea6,0x8f9c000a,0x8c1a0643,0x6126001a}},	//   вцит, לידי, _חושי, _gólf
  { {0xd7580029,0xb8950015,0x6618006f,0x7d0f0030}},	//   رجها_, _للأع, _čaká, _kocs
  { {0xf8a90086,0xdb1c00dc,0xa5f60001,0x63a910c4}},	//   _آگاه_, özön, ђењу_, tsen
  { {0x777a08e0,0x49440010,0x9cd8000a,0x25a00085}},	//   _fitx, _сэрб, תוחה_, ćila_
  { {0x63a910c5,0xfbd2004f,0x82f5009b,0x7bcd10c6}},	//   rsen, סתי_, тчиц, itau
  { {0x6459005c,0x7bcd00f2,0xaac6000b,0x63a910c7}},	//   _wywi, htau, र्टक, ssen
  { {0x05960086,0xe4d70015,0x46580015,0x7bcd0dca}},	//   _شامگ, _ستصب, _أؤكد_, ktau
  { {0x61e10176,0xc7ac000a,0x74290015,0xa023007c}},	//   swll, ּׁלָ, _تكشف_, ööpr
  { {0x81bc0048,0xb4640036,0xb05b00c0,0x539a000a}},	//   izēj, _скіл, tfär, _חיסו
  { {0x2d9e0152,0x6da30063,0xed5a10c8,0x7d0f10c9}},	//   ète_, иира, дов_, _bocs
  { {0x693c10ca,0x7bcd0012,0xb05b038f,0xed4308a0}},	//   lčev, ftau, rfär, ансп
  { {0xed57092d,0xa05a0029,0xb05b0c77,0x3157004c}},	// [17c0] тот_, _تؤثر_, sfär, _שיפן_
  { {0x81bc0024,0x5fbb000a,0x693c0263,0x6d480030}},	//   dzēj, _קצינ, nčev, édab
  { {0x89f50010,0x99f50127,0x18a610cb,0xb05b0012}},	//   ляцц, ляці, ваем, ngän
  { {0xe9950086,0x672110cc,0x9c660015,0xdcfe10cd}},	//   اهنگ, _allj, _لهجو, _kupč
  { {0x2ba9005d,0xc0ad004c,0xb05b0012,0xb7d40015}},	//   _चौपा, ליאָ, hgän, اقتب
  { {0xceb3000a,0xcf93000a,0xa027001a,0xb9960015}},	//   ֑יו_, סטו_, _hröð, _للسب
  { {0x19b90080,0xceb30008,0xe9a30054,0xb5a30033}},	//   _путь_, ביו_, _васп, арый
  { {0x25450024,0x291c0024,0xaa4310ce,0x765a0046}},	//   tēla_, īvas_, _тесл, _vyty
  { {0x98360010,0x288b0086,0x765a005c,0xe6c60015}},	//   _рэві, _آصفی_, _wyty, _لتضي
  { {0xd7640086,0x764d00dc,0x6d58002e,0xd5b20015}},	//   _صنای, ényé, _ívaf, _نفط_
  { {0x69130482,0x3abb0008,0x71e30010,0x7abb000a}},	//   _içer, ומינ, ацяж, וציו
  { {0x5637004c,0x7bcd0091,0xf48310cf,0x254501ec}},	//   _באבע_, ytau, _кушн, pēla_
  { {0xc0580036,0xc9530008,0xa923006f,0x889b000a}},	//   вір_, שמר_, úžia, ובכי
  { {0xdb2301e2,0x21f40029,0x8233002b,0x82360015}},	//   örün, _مكتس, اریا, _لرعا
  { {0xde740015,0x912b0015,0xd37b004f,0xde5800ce}},	//   لدفع, _يسبق_, _קרוט, варі_
  { {0xdb210064,0x7bcd10d0,0x61260125,0xaac6000b}},	//   ştür, ttau, _rólg, र्घक
  { {0x2d580ac7,0x8aa702b0,0x213910d1,0xa134002b}},	// [17d0] тить_, вред, mish_, _خروش
  { {0xdd110048,0xbcfb002d,0x213910d2,0x6e99006b}},	//   _kļūd, _mhéi, lish_, _явор_
  { {0x9f490064,0x6d480152,0x7bcd10d3,0x2019008c}},	//   _araç_, édac, stau, lysi_
  { {0x213910d4,0x5df6000f,0xd23b000a,0xfdf6000a}},	//   nish_, _עזרא_, וגבל, _עצרת_
  { {0x8c670010,0x2ca9007c,0x37ab01e9,0x0000006a}},	//   _штод, maad_, фтен_,
  { {0xcc76000a,0x501c000a,0x36690579,0x81bc003d}},	//   _תעשה_, וודו, нало_, rzēj
  { {0x62860089,0xa493002b,0x4429006f,0x75220046}},	//   ěkol, لیات, _ťa_, _bloz
  { {0xa3e90063,0x04c90029,0xdb0d016e,0x13e9030c}},	//   едиа_, روخي_, fraç, емий_
  { {0xbcfb002f,0xdb0d001c,0x21390705,0x693c0073}},	//   _chéi, graç, dish_, tčev
  { {0x8c440064,0x693c00bc,0x201904b2,0x96f80058}},	//   _öğey, učev, dysi_, _لعمر_
  { {0xbbd0014e,0xc69200a3,0xf7700015,0x46150021}},	//   _सङ्क, _האב_, _ذاك_, _حوار
  { {0xbcfb002f,0xb05b00b8,0xdb0d016e,0xa2d3000b}},	//   _fhéi, rgän, braç, _बॉर्
  { {0xd36e002b,0xf539006f,0xbcfb0125,0x2ca9042f}},	//   تهی_, miť_, _ghéi, daad_
  { {0xf539032c,0x248d044b,0xa856000a,0xc43a000a}},	//   liť_, lcem_, רישה_, _אתני
  { {0x63bb0024,0x693c044c,0x2f140123,0xa1920099}},	//   lrun, očet, _sägs_, _лајч
  { {0xf539002c,0x693c10d5,0x63bb10d6,0x90360067}},	//   niť_, nčet, orun, _مرخص
  { {0xaaba0086,0xa7fd0030,0x6126026a,0x3ce010d7}},	// [17e0] فدار_, _szűn, _cóle, reiv_
  { {0x291d003f,0x7dea0033,0x8b260033,0x63bb10d8}},	//   ekwa_, _змог_, ыдзе, irun
  { {0x63bb018b,0xeb75008f,0xb5ad005e,0x8288000a}},	//   hrun, рытэ, _днiп, דְנֶ
  { {0xb95a003b,0xf539002c,0x6366001a,0x2d9810d9}},	//   رجاء_, jiť_, iðna, mpre_
  { {0xf539032c,0xb8dc005d,0x645d0020,0x6d440d72}},	//   diť_, _आय_, üsil, mnia
  { {0x96b70001,0xceb30008,0x6d4410da,0x75220085}},	//   гућу_, ֖יו_, lnia, _sloz
  { {0x63bb10db,0x25a00085,0x6d4410dc,0x213900da}},	//   erun, ćilo_, onia, yish_
  { {0xdb0d001c,0x3eaa00b8,0xc5f7002b,0xbcfb0125}},	//   traç, habt_, اعوض_, _phéi
  { {0x77920086,0xdb0d016e,0x6d4410dd,0x213910de}},	//   _ایتا, uraç, inia, vish_
  { {0x51f80036,0x2139003e,0x6d4400d9,0x693c00bd}},	//   вною_, wish_, hnia, ačet
  { {0xe3af0074,0xf539002c,0x213910df,0x2d980085}},	//   يری_, biť_, tish_, jpre_
  { {0x63bb00c0,0xbcfb10e0,0x75220085,0x2d9800bc}},	//   brun, _théi, _uloz, dpre_
  { {0x6d44005c,0x29370053,0x613600bd,0x21390b77}},	//   dnia, ראכן_, ošlj, rish_
  { {0xa294078f,0x6d4410e1,0x69dc10e2,0xd370002b}},	//   _такі, enia, _opre, _بهت_
  { {0xde590036,0x6560002d,0x6d440026,0x201f0007}},	//   таві_, olmh, fnia, šui_
  { {0x5c070063,0x865b000a,0x2d870030,0x6d5601d7}},	//   ляза, גדלי, _énem_, goya
  { {0x0b940015,0x69dc10e3,0x2ca910e4,0x2d9800bc}},	// [17f0] مجلد, _apre, raad_, apre_
  { {0xf539032c,0x2ca90035,0x63a2003f,0x543b0053}},	//   ziť_, saad_, _mwon, געמא
  { {0x8f7a000a,0x63bb003d,0xdb0410e5,0x9f7a000a}},	//   _שנתק, zrun, erió, _שנתח
  { {0xf1b30008,0x2ba9000b,0x6d44002a,0xdced00bc}},	//   מסע_, _चौथा, cnia, omač
  { {0xf53905cc,0xe6c50029,0x69dc0003,0x693c006f}},	//   viť_, لتغي, _epre, ečes
  { {0xf7960029,0x645d0020,0x7d0d10e6,0x291d002a}},	//   جنوب_, üsim, ljas, skwa_
  { {0xf539002c,0xff18000a,0xceb405bd,0x7d0d10e7}},	//   tiť_, רקות_, ציק_, ojas
  { {0x7d0d022d,0xb60500dc,0xce38000a,0x63bb10e8}},	//   njas, _aláí, טאות_, trun
  { {0xf5760029,0xf539002c,0x7d1a000a,0xe4510015}},	//   جميع_, riť_, דֵיה, غضب_
  { {0xc6a40083,0xadf7005d,0xe1f90036,0xf539002c}},	//   _грци, ुमान_, вго_, siť_
  { {0x6d440176,0x7d0d0084,0x06840029,0xf539002c}},	//   ynia, kjas, _المُ, piť_
  { {0x54550010,0xba56000a,0x63bb10e9,0xd919000a}},	//   _квет, יסתו_, prun, דוֹל
  { {0x7d0d10ea,0x6d5610eb,0x251a000a,0xc5740015}},	//   djas, voya, _שונא, _اطلع
  { {0x82350086,0xdb040020,0x08760053,0x6d4410ec}},	//   _پرتا, uriü, יערט_, wnia
  { {0x7d0d002e,0x6d44005c,0x442d10ed,0x6d5610ee}},	//   fjas, tnia, lze_, toya
  { {0x69c4000b,0x7aee0049,0x2d980003,0x7d0d001a}},	//   ांसी, _sabt, rpre_, gjas

  { {0x2d9804f9,0x69dc10ef,0x5aca0036,0xeab20002}},	// [1800] spre_, _spre, клам_, قعا_
  { {0x69dc003c,0x6d440472,0x442d10f0,0xb0b6000b}},	//   _ppre, snia, ize_, _आएँग
  { {0x2d850089,0xdebb039e,0x3ebb000a,0xd884002b}},	//   ílet_, _במיל, _בציב, مهای
  { {0x7d0b00c0,0x71d60008,0x9c830264,0xe3a70067}},	//   ögst, יועד_, účtu, _ور_
  { {0x442d0111,0xec470080,0x7c2d002a,0x79950012}},	//   jze_, _взял_, czar, _etzw
  { {0x501b0008,0x69960036,0x442d10f1,0x473300fd}},	//   כונו, _врах, dze_, оніс
  { {0xceb30008,0x98a60036,0xb0b6005d,0x69dc002c}},	//   קיה_, _вибе, _आएंग, _upre
  { {0x75290667,0x98af0045,0xa96a016a,0x628310f2}},	//   ghez, rigă_, _риба_, _agno
  { {0x43060036,0x394610f3,0x46b60015,0x534604bb}},	//   аїна, mnos_, _نحاس, ихоа
  { {0xf36600d0,0xc5d6005e,0x394610f4,0x7d0d10f5}},	//   јтин, _відь, lnos_, zjas
  { {0x7c2d052a,0x7980003f,0x21550033,0x31c3006b}},	//   zzar, _kimw, йкоў, осяв
  { {0x7529000c,0x39460a75,0xd2570033,0x442d0061}},	//   chez, nnos_, рць_, bze_
  { {0x442d0050,0xc0e4008f,0x33940029,0xaac7000b}},	//   cze_, цоўк, _التز, _लालक
  { {0x39460026,0xdced0227,0x6d480003,0xd4670054}},	//   hnos_, rmač, édan, _тиче_
  { {0xeca70e88,0x8d770115,0xa697000a,0x28d7000b}},	//   ијан, لارا, שכלה_, ण्डि
  { {0x427b0008,0x394600dc,0xc27b01ac,0x7c2d10f6}},	//   _באוג, jnos_, _ברוי, tzar
  { {0x29e804f9,0x67da0024,0xfa870001,0x957c005c}},	// [1810] _aşa_, nājā, аћем, _brąz
  { {0x394610f7,0x2bc80004,0x75290030,0xe451000a}},	//   enos_, јуто_, zhez, פֶן_
  { {0x7c2d005c,0x39460026,0x442d10f8,0xd357000a}},	//   szar, fnos_, zze_, סיבי_
  { {0x645d0020,0xa3b3000b,0xbcfb0003,0x394610f9}},	//   üsik, ड़ूँ_, _chét, gnos_
  { {0xb8ef000b,0x6aa70030,0xa91d0085,0x78ab10fa}},	//   _शा_, _tejf, _niže, ragv
  { {0x86980063,0x3946047e,0xa9970015,0xfa55002b}},	//   атът_, anos_, _نشرت, _هرزگ
  { {0x98af0007,0x9f4e00dc,0xc68e0015,0x2d680012}},	//   eigą_, énél_, رِي_, ißen_
  { {0x442d10fb,0x7ae50044,0x0000006a,0x0000006a}},	//   tze_, leht,   ,
  { {0xf794008f,0xc95201e4,0x442d06af,0x67da003d}},	//   _матэ, _זמן_, uze_, gājā
  { {0x442d10fc,0x93440015,0x2d8c0046,0x7ae510fd}},	//   rze_, ْخَم, ídek_, neht
  { {0x442d10fe,0x568c0053,0xdce4005c,0x78a9007c}},	//   sze_, _סטאַ, amię, _keev
  { {0x2d6800b8,0x6136006f,0xf0ba002b,0x3a36000a}},	//   eßen_, ošli, دادش_, מרתם_
  { {0x95540029,0x59c9000b,0xdb04001a,0x69c50012}},	//   _بخلا, ांडर, krið, huhe
  { {0x539a0008,0xa8560008,0x254c0089,0x61260656}},	//   _עיצו, מירה_, měla_, _dóla
  { {0xe1640086,0x69c50020,0x853c0091,0x7e690046}},	//   _وضعی, juhe, _kvėp, řepn
  { {0x91ba0053,0x63a40064,0x61360f28,0x52a7000b}},	//   _עמפי, _çinc, kšli, _ग़ुस
  { {0xdb04001c,0xbcfb0003,0xf3880016,0x9f400052}},	// [1820] nsiç, _rhét, _lợn_, _frið_
  { {0x6ac60015,0x09e6005e,0xf1db000b,0xdb04016e}},	//   إقام, йозн, _बहान, isiç
  { {0x1efb00b2,0x80cf000b,0xd946033d,0x0000006a}},	//   _עלטע, _थामे, бежи,
  { {0x256100dc,0x1d0a10ff,0xe7860a3e,0x984a1100}},	//   bóli_, _семи_, буко, ляла_
  { {0xaab80086,0x39461101,0x87d700c3,0x2ca0007c}},	//   _نگار_, rnos_, مبوس_, mbid_
  { {0xe9aa0086,0x254c0046,0x25a50034,0x2d8200da}},	//   _مدرن_, děla_, _bwll_, _hike_
  { {0x2d82003f,0x9998000a,0x29e80045,0x81bc003d}},	//   _kike_, _כֹּח, _uşa_, nzēt
  { {0x77861102,0x89d70015,0x2ca000aa,0x25a50034}},	//   _глаз, _دوفر_, nbid_, _dwll_
  { {0xccf3000f,0x442200dc,0x4acf000b,0x2d821103}},	//   לכה_, ák_, स्कव, _mike_
  { {0xaaa8005d,0x2d821104,0x26c8002b,0x53340033}},	//   गरिक, _like_, _خطری_, іент
  { {0xd5b90191,0x6126002e,0x71270029,0x23a9005d}},	//   _всі_, _sóla, مرحل, चीबद
  { {0x81bc0048,0x59c9005d,0xc5f30008,0xdfd10115}},	//   dzēt, ांतर, _מדע_, ويج_
  { {0xd8d700b2,0xa2d3005d,0xe3af0015,0xe571004f}},	//   זוכט_, _बॉक्, _كرو_, _חַג_
  { {0x43740074,0x6e940080,0xa7fd00dc,0x2d6800b8}},	//   _بهتر, зиру, _szűk, ußen_
  { {0xe1890092,0x2d821105,0xddc50046,0x9cf500e2}},	//   _hẳn_, _bike_, _vzhů, озві
  { {0x6126002e,0x6136006f,0x614401ca,0x628e00bc}},	//   _tóla, yšli, _неја, žbod
  { {0xdb041106,0x7ae51107,0xdcfe0045,0x67280030}},	// [1830] trið, teht, _supă, _oldj
  { {0x69c5002e,0xbcfb0003,0x9a8701e5,0x78a91108}},	//   tuhe, _chér, суал, _seev
  { {0xceb2000a,0x2ba9000b,0x7ae51109,0xd91b1100}},	//   _קיט_, _चौरा, reht, льд_
  { {0x69c5110a,0x7ae5110b,0x5c07110c,0x0000006a}},	//   ruhe, seht, _ляга,
  { {0xf771040b,0x78a9007c,0x69c5007c,0xb882006f}},	//   وات_, _veev, suhe, _šíri
  { {0x69c500f2,0x25a50026,0x07090015,0xa595110d}},	//   puhe, _pwll_, شيبي_, орищ
  { {0xf592003b,0x1efa00b2,0x78a90020,0x21290049}},	//   ولوج, ילװע, _teev, _olah_
  { {0x1bfd000b,0xb9250015,0x254c0046,0xfd8a004c}},	//   _उछाल_, _بفري, těla_, סטפּ
  { {0x98170074,0x27ed0f01,0x47940058,0xa8a400af}},	//   _ابزا, _usen_, _فجلس, _хрск
  { {0xdb16022d,0x15ab006b,0x247f003d,0x25a50034}},	//   styö, _бъди_, _rāmī_, _twll_
  { {0x81bc0048,0x2129002d,0xeab2000f,0x07080015}},	//   dzēs, _blah_, וֹר_, _ديلي_
  { {0x254c0046,0x7656004f,0x3ce30065,0xcb050065}},	//   pěla_, _ובעד_, ख़ों_, राँड_
  { {0xd24e0086,0x28d1000b,0x7e690046,0xefc7033d}},	//   فنی_, _हानि, řepl, олял_
  { {0x321e0176,0xd5dd000b,0xe299110e,0x040e0016}},	//   byty_, _महाज, _так_, _lýợn
  { {0xad3a0036,0x5fb6000b,0x2d82110f,0x8284002b}},	//   ачає_, _अटकल, _pike_, _عجول
  { {0xc5f20008,0x8d660010,0x4d66022a,0xa00a0015}},	//   ודל_, івае, ікав, _نقبل_
  { {0x25a0016f,0xcb05000b,0x5f760015,0x2ca01110}},	// [1840] ćili_, रांड_, _واخر, rbid_
  { {0x4a9a0033,0x5de61111,0x3a9a0138,0x0000006a}},	//   ртаў_, _джоа, ртаю_,
  { {0xa3a9005d,0x80b1000b,0x6c86002b,0x7f5c0003}},	//   गीत_, _अजमे, _ولدم, morq
  { {0xdd0f0064,0x6d410003,0x61fc0723,0x47d60058}},	//   mışs, élat, årli, قيصر
  { {0xbcfb1112,0x321e002a,0x6bd60015,0x7d061113}},	//   _thér, zyty_, _بتجر, _inks
  { {0xab2a0124,0x3ffb004c,0x27e90144,0x98aa0061}},	//   _тога_, יפנע, çana_, ımın_
  { {0x76a90036,0x386d00dc,0x0f7b000a,0xda650015}},	//   стів_, _ezer_, ברסל, _فافي
  { {0xdb0d001a,0xb603006f,0x1de2000b,0x3d180065}},	//   luað, úšal, _पहनत, _धकों_
  { {0xd90d0086,0xad1b000a,0x25a90085,0xe79e003d}},	//   _حین_, שופר, ćala_, ēlēš
  { {0x63bd00dc,0xd37000e5,0x7bdb000a,0xbb3a000a}},	//   ásna, عهد_, סקיו, יעִי
  { {0x28d1000b,0xd257005e,0x5afb0643,0x92581114}},	//   _हामि, жця_, בליצ, сант_
  { {0x94d40029,0x69c300bd,0x254c0046,0xd4f50033}},	//   _ريتش, šneg, mělo_, _нячы
  { {0xf8b30008,0xb0340080,0xb97b0135,0xdfdb006b}},	//   ושר_, дняш, ינטי, шън_
  { {0x7d0600df,0x25450024,0x543b004c,0x7c29002a}},	//   _anks, vēli_, _דעדא, _żero
  { {0xdef8008f,0x645d007c,0x98af0091,0x61261115}},	//   цыя_, üsiv, aigę_, _gólo
  { {0x25450024,0xe611000a,0x212901d7,0x61260030}},	//   tēli_, עִם_, _ulah_, _jóll
  { {0xac77002b,0xbe870015,0xa91d00bc,0x0000006a}},	// [1850] زارش, _وجدو, _niža,
  { {0x539b009d,0x99d70115,0x78a20057,0xdea1002b}},	//   יימו, قتصا, ebov, _سیری
  { {0x78750030,0x386d1116,0x6f7a004f,0x1a65009a}},	//   küvé, _szer_, _לְטו, سیری_
  { {0xdb0d002d,0xec150015,0xad19000a,0x254c0046}},	//   msaí, _فوجد, _הוֹר, dělo_
  { {0x07a50608,0x186907c1,0xe838005e,0xe8f80033}},	//   чалн, љали_, опці_, ўлі_
  { {0x3707005f,0x8c1a000a,0x2e0b004f,0xb9c70058}},	//   ючев, _הושי, ֹלֵ֣, _وتأه
  { {0xf6250142,0xd5e80015,0x9782002b,0x78a2005a}},	//   ядко, قعين_, ریمه, bbov
  { {0xf5091117,0x395f1118,0x0000006a,0x0000006a}},	//   снил_, _ukus_,   ,
  { {0x97c40015,0xe796002b,0x612601c0,0x7cfa004f}},	//   _يقفو, _فالک, _sólo, זִיק
  { {0x395d003e,0xfbd20008,0x69d70144,0xdb04016e}},	//   lows_, עתי_, otxe, briõ
  { {0xeccb014e,0x644d0007,0x4add000b,0x9975000a}},	//   िलाफ, _žaid, न्यव, ּתָא_
  { {0x8a16000a,0x69d70144,0xe8d5000a,0xa4d5005e}},	//   לחתו_, itxe, הוֹר_, _ході
  { {0x4f960010,0xa3f40036,0x94040015,0xd12f0015}},	//   ярну, _опці, _يومه, امُ_
  { {0x539a0008,0x0735004c,0x2d961119,0x23fa004f}},	//   _היסו, לאָם_, зрас, _להנא
  { {0x78a20057,0x78bb0085,0x6126001a,0xde030342}},	//   ybov, _oduv, _hólm, нпри
  { {0x91ba0008,0xc5f20135,0xc1ba000a,0x621a004c}},	//   _המקי, עדן_, _המקש, _לוצק
  { {0xa08b000a,0xbbe90015,0x50460054,0xe8df0016}},	// [1860] _לְיִ, يركم_, _хепб, _ngựa_
  { {0x3057004f,0xdb5900ce,0x6d41111a,0x0000006a}},	//   _משפך_, оює_, élar,
  { {0x273000a7,0xe9da111b,0xdb0d002d,0x38c8002b}},	//   _hàng_, ске_, csaí, قاشی_
  { {0xd9100086,0x78a20069,0xb05b0123,0x27ff111c}},	//   خیر_, ubov, rgäv, _brun_
  { {0x78a2111d,0x7d7b000a,0xa09b015b,0xdb040125}},	//   rbov, _לנטו, ציסט, isiú
  { {0xb5a6005e,0x28d1000b,0x27300016,0x78a20079}},	//   прий, _हाथि, _màng_, sbov
  { {0xa5d70029,0x27300092,0x18a6005e,0xb9b5006b}},	//   كبير_, _làng_, _навм, _остъ
  { {0x539803fc,0xa5070054,0xd4c30138,0x0000006a}},	//   овия_, зећа_, нсьп,
  { {0xb8e2000b,0x27300016,0xf493006e,0xddde005a}},	//   ूल_, _nàng_, رشيد, _vzpř
  { {0x59d00372,0x798e000c,0xaacc005d,0xa91d0089}},	//   _हमार, _kubw, ालिक, _jižn
  { {0xd7570015,0x20000045,0x877b000a,0x41e6005e}},	//   _علمت_, _arii_, _פאבי, чіпа
  { {0x27300016,0xa91d00bc,0x6366001a,0xe57a0054}},	//   _bàng_, _ližn, iðni, _узе_
  { {0x27300023,0x645d0020,0xc05b0210,0x63ae0046}},	//   _càng_, üsit, сін_, áhně
  { {0x27300092,0x3f85002e,0x7bc40351,0xa91d111e}},	//   _dàng_, ölu_, driu, _nižn
  { {0x7bc40005,0x7af500bd,0xd24f0033,0x62660015}},	//   eriu, _razt, _чц_, _عاتق
  { {0xf5490092,0x859b000a,0xfaf3002b,0xdb0d0125}},	//   hấn_, משלו, کثر_, rsaí
  { {0x70550074,0x2bb80029,0xc1580008,0x6c54067d}},	// [1870] _زندا, كالة_, _משהו_, екту
  { {0x539b000a,0x60dd0028,0x1ac70065,0x2fd40058}},	//   ציבו, lfsm, _लाओथ, _أتيح
  { {0x79a40080,0x2a980015,0x7bc4025a,0xa2cf000b}},	//   ерче, سئلة_, ariu, _दास्
  { {0x7bc400da,0x63740144,0xcdb6004f,0x527b004f}},	//   briu, lànd, _קפרה_, זנבא
  { {0x7bc40251,0x6cfa000a,0x2cfa000a,0x395d111f}},	//   criu, _ופרס, _ולרא, rows_
  { {0x6d4d0079,0xf773012c,0xbae50058,0xe595009a}},	//   lnaa, راش_, _تكسي, وشبخ
  { {0x80bf005d,0x6d4d1120,0xe7560015,0x25a90085}},	//   ्लाइ, onaa, بلوغ_, ćalo_
  { {0x26d80123,0x6d4d1121,0x63bd013f,0x629803f8}},	//   _öron_, nnaa, ásno, _afvo
  { {0x23d4008f,0x47d500e6,0x6d480003,0x63a40061}},	//   нцэр, _زيار, édai, _çinl
  { {0x27300092,0xd7740015,0x69c50012,0x68eb08cf}},	//   _ràng_, _كالع, orhe, legd
  { {0x27300092,0x69c50026,0xa0c60015,0x60dd0012}},	//   _sàng_, nrhe, ويدو, ffsm
  { {0xd7d1014e,0x25450048,0xe7d1014e,0x69c500f2}},	//   _समाच, tēlu_, _समाप, irhe
  { {0x69c500b8,0x644e0061,0x6d4d0079,0x316c003d}},	//   hrhe, şbir, dnaa, ēdz_
  { {0x27300092,0xf1a80086,0xef830033,0x68eb00aa}},	//   _vàng_, _کاوه_, кляп, hegd
  { {0xa3a9000b,0xa91d0085,0x01360015,0x329a004f}},	//   गीर_, _nižo, _يعبد, _ובצד
  { {0x27300092,0x1d07018d,0x65691122,0x6d4d1123}},	//   _tàng_, меси_, nleh, gnaa
  { {0x6b870298,0x5fd2005d,0x7bc40007,0x799c06bd}},	// [1880] _bijg, _तमिल, uriu, _strw
  { {0xdcfd0048,0x6d4d1124,0x63740144,0x65691125}},	//   _visā, anaa, cànd, hleh
  { {0x20050024,0xfe720029,0x2d95006b,0xaadd000b}},	//   ālie_, _جدة_, _пряс, न्धक
  { {0x7bc40011,0x98a6004a,0x68460015,0x41c5000b}},	//   priu, фиде, وَال, _विनस
  { {0xeb9a03de,0x65690046,0x69c51126,0xd765002b}},	//   _фиг_, dleh, arhe, کنوی
  { {0xa037000a,0xf5490016,0x69c30046,0x2259005a}},	//   ואנה_, uấn_, ánec, řsky_
  { {0xa3b0000b,0xf5490016,0x799c002a,0x8cd5000b}},	//   टीन_, rấn_, _utrw, _णामो
  { {0x6ba501d1,0xdce40844,0xb90303de,0x13f4006b}},	//   _åtgä, klič, _изск, езия
  { {0xd8d700b2,0xbcfb0089,0xf8631127,0x7c241128}},	//   _קומט_, _okén, _авто, nyir
  { {0x6126002e,0x521409ef,0xab2b000a,0x657b02f2}},	//   _fólk, едот, ַ֥יִ, amuh
  { {0xa2cf000b,0xdce41129,0x6d4d112a,0x6569112b}},	//   _दार्, elič, ynaa, bleh
  { {0xf3880023,0x4035112c,0x96da0065,0x03a6112d}},	//   _lợi_, еемс, प्रॉ, _жидо
  { {0x28d1005d,0x63740251,0x60dd002e,0xb05b00c0}},	//   _हासि, tànd, rfsm, egär
  { {0x4424005c,0x656000dc,0x741300c3,0x636f01de}},	//   mym_, lomh, _جوها, lønn
  { {0x200d0011,0xf1c5005d,0x1df804ab,0x4424112e}},	//   ţei_, _वियन, меры_, lym_
  { {0xdce4112f,0x91bb000a,0xc445002b,0x69c50046}},	//   blič, _ומהי, _آیین_, vrhe
  { {0x44241130,0x6d4d1131,0x351b000a,0x68eb0030}},	// [1890] nym_, rnaa, קומנ, vegd
  { {0x6d4d016b,0x6560002d,0xa3e6000b,0x65690046}},	//   snaa, homh, _पहन_, zleh
  { {0xf9900015,0x6d4d0079,0x3d29002b,0x2d45003d}},	//   لبن_, pnaa, _فتحی_, uķes_
  { {0x4424002c,0xc27b000f,0x636f00cb,0x99d4006e}},	//   kym_, קראי, jønn, ئتلا
  { {0x0138000a,0x25ac0034,0x7c8407f7,0x6b870079}},	//   וראת_, _awdl_, _ауре, _tijg
  { {0x7d1d0014,0x442400f8,0x28d10065,0x0000006a}},	//   _hoss, dym_, _हावि,
  { {0xdce40198,0xf3880092,0x3cf90020,0xacbb0003}},	//   zlič, _gợi_, _kasv_, _flût
  { {0x7d1d022d,0xa5650086,0xccf2000a,0x657b02f2}},	//   _joss, رگان, ָ֛ה_, umuh
  { {0x13e60080,0xa3a9000b,0xd777012c,0x7d1d1132}},	//   емый_, गीं_, _قاطع, _moss
  { {0x25450024,0x7d1d1133,0x65691134,0xe735004f}},	//   tēls_, _loss, sleh, _אָ֣ז_
  { {0xb979000a,0xcb12039e,0xc049000a,0xf41f007c}},	//   ּנָי, אלי_, _פז_, ääb_
  { {0x7d1d03af,0x442410ec,0xdce410cd,0x0000006a}},	//   _noss, bym_, tlič,
  { {0x4424005c,0xb42700e6,0x44270087,0x75290030}},	//   cym_, _تعاو, _تراف, mkez
  { {0x75290014,0xb05b00c0,0x7bcd007c,0x798900aa}},	//   lkez, tgär, duau, _liew
  { {0xc69205af,0x8db50036,0x6e930002,0xdd920031}},	//   ראל_, ксті, الفا, اور_
  { {0x79890050,0x2d9e0024,0x75290030,0x8e830015}},	//   _niew, īte_, nkez, الِه
  { {0x7ff60029,0x90460086,0x7d1d1135,0x32d9000a}},	// [18a0] _أسبا, _سنده, _doss, ּחֲנ
  { {0x272b003c,0x7c36002a,0x305b004f,0xe8030065}},	//   _sønn_, rzyr, _מדפד, लिना_
  { {0xda660029,0x4424005c,0x3f92003f,0xddde005c}},	//   راطي, zym_, _huyu_, _wypł
  { {0x69c302c1,0x59d2000b,0xd884002b,0x612605a4}},	//   ánea, दंबर, نهای, _bóli
  { {0xa7fd0014,0x9d1b0053,0x75290030,0xeb9701b7}},	//   _szűr, _זוכט, dkez, _пия_
  { {0x57f30001,0xa84700e6,0x254c0089,0x07a30054}},	//   упшт, علوم_, měli_, ћајн
  { {0x44240050,0x38c8002b,0x35f70015,0x0d3a004f}},	//   wym_, _ياری_, فريد_, ּגִב
  { {0x752900dc,0x89db0008,0xc4480086,0x44241136}},	//   gkez, _מחלי, ویان_, tym_
  { {0x8497003b,0x39460f30,0xa806005e,0x636f04d1}},	//   رئيس_, mios_, _язал, rønn
  { {0x656002e9,0xa91d00bd,0x39461137,0x44241138}},	//   somh, _nižj, lios_, rym_
  { {0xa159059c,0x75d60015,0xb2c6002b,0x53c2000b}},	//   дану_, _سيشا, وغگو, _शिवश
  { {0xd2570010,0x31c30010,0xb7f4000b,0x4657004c}},	//   эцы_, ысьв, _इनाम_, _אױבן_
  { {0xc9530008,0xe803005d,0xb803000b,0x5f94024f}},	//   רמר_, लिया_, लियम_, лият
  { {0xdefb0010,0x254c0089,0x539b00a3,0xfdfe000b}},	//   чым_, děli_, _ציוו, ॉमंस_
  { {0x39460007,0x80a2005d,0x7d1d1139,0x12fb0447}},	//   kios_, _क्वे, _poss, _מהגב
  { {0x6366002e,0x9d18113a,0x0000006a,0x0000006a}},	//   rðnu, ност_,   ,
  { {0xdb0d113b,0x7d1d113c,0x3946113d,0x1f75006b}},	// [18b0] nsaç, _voss, dios_, _илия
  { {0xdb0d113e,0x7989002a,0x629a113f,0x3946059d}},	//   trañ, _siew, ncto, eios_
  { {0xa2d8021e,0x394609ae,0xbd79005e,0x629a1140}},	//   _मान्, fios_, _обоє_, icto
  { {0xad270015,0x6d480140,0x61e50012,0x39461141}},	//   _أردو, édat, _ähle, gios_
  { {0x7989003e,0x7c670087,0x2ca91142,0x0000006a}},	//   _view, _ساحل, mbad_,
  { {0xd00c000a,0xd618002b,0x2d8b0077,0xcf940643}},	//   לּוֹ, کتها_, _hice_, אטס_
  { {0x752903c0,0x56920001,0x39461143,0x5b56004f}},	//   tkez, шајт, bios_, _יישב_
  { {0x394606d4,0x6126001a,0xa3b9006e,0x2ca91144}},	//   cios_, _tóli, واخر_, nbad_
  { {0x80a2014e,0x75291145,0xa6f50001,0x442b1146}},	//   _क्षे, rkez, _изаш, ác_
  { {0x3eb3003e,0x69ca001c,0x63740251,0x13020010}},	//   _next_, áfeg, vànc, азьм
  { {0x68fb0458,0x3f920064,0x75290030,0x46150021}},	//   _kaud, _suyu_, pkez, _جوار
  { {0x2eaa014e,0x63740251,0x291f0003,0x68fb1147}},	//   कर्त, tànc, _joua_, _jaud
  { {0x88ba000a,0x20041148,0x68fb1149,0x73c4002b}},	//   וזרי, ími_, _maud, _مينم
  { {0x80a2014e,0x2d8b002d,0x63bb114a,0x6f63004a}},	//   _क्रे, _aice_, msun, ивяз
  { {0x7ed6002b,0x63bb114b,0x2d8b114c,0xc332004f}},	//   _یزدا, lsun, _bice_, _דוג_
  { {0x57d1005d,0x291f0011,0xf2880053,0x254c0089}},	//   _समूह, _noua_, _אָפֿ, těli_
  { {0x69c3002c,0x2d8b114d,0x63bb114e,0xdb0d001a}},	// [18c0] ánen, _dice_, nsun, trað
  { {0x5fb70008,0xffb7000a,0x7e760015,0x63bb114f}},	//   _שהיא_, _שליש_, _لاجئ, isun
  { {0x39460467,0x3ebe002e,0x9046002b,0x9b650015}},	//   tios_, óttu_, _سنگه, اطقه
  { {0x1e570008,0xc7a60fea,0x621a004c,0x63bb1150}},	//   _ישיר_, видк, וועק, ksun
  { {0x68fb0048,0x291f0011,0xf7f30029,0xbb860015}},	//   _daud, _doua_, لسود, _للحي
  { {0x394600df,0x2d8b0011,0xe7e3000b,0xc7a30054}},	//   sios_, _zice_, _गहरा_, шиљк
  { {0x7afc0f04,0x39460c98,0x68fb1151,0xb8960015}},	//   _iart, pios_, _faud, _للزع
  { {0x29dc0467,0x68fb1152,0x80a2000b,0x44f40054}},	//   mía_, _gaud, _क्ले, упис
  { {0xc9550010,0xb86600e5,0x3eb81153,0x1c05000b}},	//   _стры, _شارو, kart_, रियल_
  { {0x68fb0024,0xe44f0015,0xdb0d016e,0xa6c70763}},	//   _zaud, تضى_, rsaç, _алфа_
  { {0x29dc1154,0x63bb05d0,0x0697000a,0xc50a0015}},	//   nía_, asun, _סדאם_, _يتصل_
  { {0x68e20026,0x2d80005c,0x21640286,0x64a61155}},	//   nfod, jmie_, итяг, _рада
  { {0xdb0402c1,0x4fc70063,0xb4ae005d,0x3eb81156}},	//   nsió, ъсна, करी_, fart_
  { {0x63a200b6,0x0ccb005d,0xe803005d,0x2d8b0089}},	//   _iton, िल्म, लिता_, _sice_
  { {0x29dc0077,0xdb041157,0x2e480342,0x3e7c005a}},	//   jía_, mpiè, вято_, váté_
  { {0x29dc02c1,0xeca40054,0x3eb8053a,0xa2d8000b}},	//   día_, ијун, aart_, _माड्
  { {0xfbd00029,0x25a9016f,0x50b80002,0x3eb81158}},	// [18d0] قتل_, ćali_, _شديد_, bart_
  { {0x29dc0467,0xe4e2014e,0x1fa40063,0x79a7000d}},	//   fía_, क्ति_, _тръг, врде
  { {0x29dc0467,0x68e20026,0x99870046,0xdbd10012}},	//   gía_, ffod, ánů_, _füße
  { {0x63a21159,0x08d4005e,0x7c320030,0x7afc115a}},	//   _oton, иція, ókró, _eart
  { {0xb8db014e,0x115a004c,0xdd3a004c,0x7afc115b}},	//   _आज_, עדױע, _נעשכ, _fart
  { {0x29dc0467,0x68e20026,0x7afc0c8c,0xf72b0033}},	//   bía_, afod, _gart, ьцей_
  { {0x29dc0467,0x3a840010,0x69de0111,0x290e002d}},	//   cía_, _вытв, ctpe, ámaí_
  { {0x7afc0012,0x254c002a,0x63bb115c,0x3eb8115d}},	//   _zart, yśle_, tsun, zart_
  { {0xe3b1003b,0xbcfb032c,0x80bf000b,0x7afc0125}},	//   حرب_, _akék, ्लैं, _yart
  { {0x63bb115e,0xdc88000a,0xae13000b,0x2d80002a}},	//   rsun, כְתָ, डमान_, zmie_
  { {0x63bb115f,0xe8df0092,0x2d80002a,0xe4d50067}},	//   ssun, _ngừa_, ymie_, _مقاد
  { {0x34950124,0x7fd6042b,0x3eb81160,0x8fa61161}},	//   _садр, лігі, wart_, ламе
  { {0x67211162,0x251a000a,0xf4870054,0x3eb81163}},	//   _kolj, _רונא, _ружн, tart_
  { {0x08760053,0x083a004c,0x61260030,0xdbd10012}},	//   טערט_, געשל, _rólu, _süße
  { {0xa2d8005d,0xe4f9005d,0x68e20026,0xf3880016}},	//   _मात्, ्यपि_, yfod, _vợt_
  { {0x5c16005f,0x29dc02c1,0xa3b0000b,0xfc3f0077}},	//   льзу, vía_, टीव_, _reír_
  { {0x2d801164,0x3eb81165,0x69c30091,0x7afc1166}},	// [18e0] rmie_, part_, šnel, _part
  { {0x0eaa008f,0x2d80002c,0x29dc1167,0x5f060033}},	//   _якой_, smie_, tía_, _ёзна
  { {0x7afc1168,0x8e76000d,0x18a60457,0x5edb000a}},	//   _vart, _љупч, гаем, _אחיה
  { {0x29dc0467,0x386d01f0,0xc8b60015,0x7afc1169}},	//   ría_, _byer_, اصاب, _wart
  { {0x6d460064,0x68e20026,0x718b0053,0x7afc116a}},	//   _imka, rfod, גװײַ, _tart
  { {0xdb040467,0xa2d8005d,0xbcfb002c,0x29dc116b}},	//   rsió, _माध्, _akéh, pía_
  { {0xf41f022d,0xe9a3008f,0x6721016f,0xa9f8000a}},	//   ään_, _гасп, _dolj, _בִּת
  { {0xb4ae000b,0xaa430238,0x95d7006b,0x186a029f}},	//   करे_, _уесл, удът_, _заби_
  { {0x68e40020,0x14d5000b,0x08f90015,0xd7ca0015}},	//   õidu, _धारण, _جرّب_, _سواه_
  { {0x7982005c,0xeab6000a,0x4b37004c,0x672100bc}},	//   lmow, נִ֥י_, ָרטל_, _golj
  { {0xe693003b,0x06560010,0xf656005e,0xe44f002b}},	//   _المد, _стаў, _стаю, قضی_
  { {0xd59b000a,0x6ed70065,0x759b004f,0x644f016d}},	//   _נבדל, _बाहु, _נידח, úcic
  { {0x236500bc,0xaf37006e,0x2af6000b,0xe4760033}},	//   bolj_, هرست, ीयाँ_, _сужэ
  { {0x88bd0050,0x343b0053,0xde590033,0xb2a60015}},	//   _kośc, _אײדע, вагі_, _صحته
  { {0xd2b70135,0x2bc7000b,0x98bd002a,0xe29b000a}},	//   _גלות_, _लिहा, liwą_, _אשור
  { {0x7982005c,0x88bd002a,0x3169036d,0x23b8000b}},	//   jmow, _mośc, _ukaz_, _इबाद
  { {0x7982002a,0xfaa7005e,0x40ec000a,0x7ff70058}},	// [18f0] dmow, гшен, _נַהֲ, _إسعا
  { {0x20090003,0x69c300bc,0x2d680012,0x9b440015}},	//   _irai_, šnem, ußer_, منقو
  { {0xdb580080,0xeb9f0134,0x7bcb002e,0x12eb000a}},	//   уют_, _grøn_, águb, עַמּ
  { {0x97c50029,0x7bdf0012,0x3f83003d,0x2009116c}},	//   لقصو, ptqu, lmju_, _krai_
  { {0x6721065d,0x27c70080,0xdcef002a,0x9cd6000a}},	//   _polj, ущег, _chcą, _דורה_
  { {0x386d0123,0xd70502ed,0x79820535,0x9a87116d}},	//   _vyer_, рзки, amow, _бубл
  { {0x7bcd0084,0x6721116e,0x236500bd,0xe736006b}},	//   lrau, _volj, volj_, рещ_
  { {0x7bcd0012,0x20090091,0x87d70058,0x64a5116f}},	//   orau, _orai_, _مغطا, јапа
  { {0x36d50860,0x7bcd0435,0x7ce8000a,0x66080012}},	//   _возр, nrau, אַתֶ, _erdk
  { {0x82350029,0x96f800c3,0x2b0e000b,0xb3e80021}},	//   لرجا, _معمر_, साएँ_, اعيل_
  { {0xf7840029,0x88bd005c,0x7bcd00b8,0xc692000a}},	//   _اللَ, _gośc, hrau, _ואב_
  { {0x2b17005d,0x291d003f,0x7bcd1170,0xab66002a}},	//   नाडु_, njwa_, krau, _zażą
  { {0xdfd20015,0x23650085,0x20091171,0xa3a70054}},	//   غيس_, polj_, _crai_, _сјек
  { {0x82a5005f,0x7982005c,0x56b50053,0xe4560053}},	//   _такж, zmow, יפֿן_, _דינט_
  { {0x69c303cd,0x68e908aa,0x7e23012e,0x76000030}},	//   šnej, _obed, одрж, mázá
  { {0xf3880023,0x76000014,0x27ed00ed,0x63a91172}},	//   _hợp_, lázá, _open_, open
  { {0x4d630036,0x0b46070e,0x6a96005e,0xfc031173}},	// [1900] ікув, анан, ареє, опто
  { {0xbd460086,0x3c190010,0x63a90d89,0xb4ab001a}},	//   _چندي, ыўся_, ipen, íþjó
  { {0xe9da1174,0xeb750010,0xa2d8005d,0x27ed0079}},	//   тке_, сытэ, _मास्, _apen_
  { {0x88e6005f,0xa3e6005d,0x7bcd1175,0x853c0091}},	//   ржде, _पहल_, brau, _atėn
  { {0x7982005c,0x76000089,0xa09b000a,0x68430174}},	//   rmow, kázá, דינט, онца
  { {0xceb3000a,0x88bd002a,0x41c5000b,0x68e90061}},	//   ֗יו_, _pośc, _विंस, _ebed
  { {0xceb30008,0xd5b704ab,0xce36015b,0x63a91176}},	//   חיו_, асы_, יאַת_, epen
  { {0x5ca9000a,0x55060004,0x2ca00b95,0xab660535}},	//   ְׁתַ, рчка, ncid_, _ważą
  { {0xad370053,0xa507023e,0x27e9028f,0x07a30004}},	//   ינקס_, рења_, çant_, _матн
  { {0x3d0d000b,0x0000006a,0x0000006a,0x0000006a}},	//   _ढोने_,   ,   ,
  { {0xd2570036,0x2d9e0089,0xfa97000a,0x11d80015}},	//   ицю_, ítel_, ידיש_, دوجة_
  { {0xc05b0010,0xe0d00015,0xf5390046,0x80a2000b}},	//   віг_, وزُ_, chť_, कुले
  { {0xe53b0008,0xc05b0036,0xdb0d0030,0x2294006b}},	//   _בתאר, тін_, őkén, _лиля
  { {0x20090152,0xb4e2000b,0x6d561177,0xf09f0144}},	//   _vrai_, क्रय_, enya, scà_
  { {0xd337000a,0x637b000a,0x7052002b,0xfd1300c3}},	//   _דרגה_, _שנוד, قچیا, يجر_
  { {0x7bcd1178,0xc0cb1179,0x2009117a,0x4c94004a}},	//   trau, _руке_, _trai_, житс
  { {0x2bb80015,0x2d9c0030,0x317c0447,0xe571000a}},	// [1910] لالة_, _éven_, _ברהמ, פַל_
  { {0x7bcd117b,0xfaa70033,0xfb380054,0xda07005e}},	//   rrau, ршан, азуј_, ичеп
  { {0xb8950015,0xcb680067,0xb8b70015,0xceb2000a}},	//   ملاع, جمله_, لإشت, _מיי_
  { {0x637d0291,0x27390003,0x63a9117c,0xd87900c3}},	//   mène, _mène_, ypen, همات_
  { {0x98e40029,0xe6c50015,0xcce6002b,0x63a900da}},	//   تكنو, متغي, _اسپي, xpen
  { {0xf5490092,0xc7c80010,0x57a40010,0x6aa90061}},	//   hất_, рыце_, ішча, _şeff
  { {0x0f380053,0xceb4000a,0x8f38004c,0x7600117d}},	//   שרוט_, קיק_, שאוו_, vázá
  { {0x1e58013a,0xae58000a,0xcdaa004c,0x68e90085}},	//   ישור_, יסוס_, ניפֿ, _ubed
  { {0xe6c70086,0x63a9117e,0x637d0003,0x6b850125}},	//   _نتاي, upen, hène, omhg
  { {0xf5e70191,0x7c2d117f,0x6d4d007c,0x63a90faa}},	//   _відм, iyar, hiaa, rpen
  { {0xa2d8014e,0x7c2d1180,0x22490684,0x2128002b}},	//   _मार्, hyar, упни_, ليدی_
  { {0x04950029,0x645e005c,0xa9fa000a,0x7a88000a}},	//   _الإح, _śpie, נִית, יָרַ
  { {0xd496000a,0x6d4d1181,0x8467009b,0x0000006a}},	//   _הכנת_, diaa, _тъже,
  { {0xe4500029,0xf412000a,0x83640021,0x94740015}},	//   _تضم_, _מפד_, _ودول, _بدما
  { {0x9f4b00dc,0x9d560002,0xc692000a,0x442d1182}},	//   óját_, منست, לאם_, lye_
  { {0xe0da0124,0xad39005e,0xdced05b8,0x6d4d1183}},	//   _сви_, ачує_, rmağ, giaa
  { {0x442d0f4d,0x4f5a0086,0x6d560665,0x443f1184}},	// [1920] nye_, _مجدد_, rnya, nzu_
  { {0x8a3a005f,0x6c330015,0x6c55005e,0x442d0061}},	//   ляет_, أفكا, іттє, iye_
  { {0xd9100086,0xb4f9000b,0xf9920015,0xb2ba004c}},	//   ویس_, ्याय_, سبا_, רמער
  { {0x6d4d0111,0xf969005e,0x442d044d,0xbd46009a}},	//   ciaa, арій_, kye_, _چنگي
  { {0x307a00b2,0x3eba003e,0x29120064,0x2bba0029}},	//   װאַנ, _kept_, ıya_, _حاجة_
  { {0x443f03eb,0x29001185,0xd6cf0015,0x69961186}},	//   dzu_, žia_, فقه_, _грах
  { {0x7abb0008,0xa3b0005d,0xe7f4000b,0x2a350033}},	//   _תצלו, टीई_, _इनका_, _дэтр
  { {0x442d003f,0x7d041187,0x88c50015,0x3e830003}},	//   fye_, ndis, _وتقل, lété_
  { {0xd90d002b,0xfc4a0046,0x389b000a,0x7d041188}},	//   _جین_, blíž_, _תימנ, idis
  { {0x7d04022d,0xdced0263,0xd6d20018,0x87250015}},	//   hdis, vlač, _رقص_, _وعلم
  { {0x36060015,0x443f1189,0x7d0407a3,0x62740058}},	//   _دواف, azu_, kdis, تهدئ
  { {0xd257078f,0xf5490092,0xdced0227,0x78a20057}},	//   сць_, uất_, tlač, ncov
  { {0x443f005c,0xb97b0008,0x5067118a,0x7d04118b}},	//   czu_, טנטי, стна, ddis
  { {0xa8570008,0x88bd005c,0xdd950033,0x6d5a0003}},	//   מיכה_, _nośn, жавы, étan
  { {0x81a60029,0x8d770031,0xb2bb000a,0x6d4d118c}},	//   _احتل, مارا, _גמור, tiaa
  { {0xbd6b0080,0xdced0844,0x78a204b2,0x64400244}},	//   урге_, plač, jcov, ozmi
  { {0x7bd600e8,0x88bd002a,0xfd440033,0x64400012}},	// [1930] guyu, _bośn, чэрн, nzmi
  { {0x64400024,0x7d04118d,0x3ed50040,0xfb84056d}},	//   izmi, adis, _بقدر, пыхн
  { {0x637d0251,0x7c2d0849,0x314b000a,0xa9f50015}},	//   lènc, syar, ְתְּ, تكاث
  { {0x27300023,0x26de0896,0x7c2d118e,0x3915110d}},	//   _hành_, _acto_, pyar, юмер
  { {0x186900d7,0xb901000b,0x98c50061,0x637d0144}},	//   јали_, _दा_, çtır_, nènc
  { {0x442d0061,0x16a6005e,0xe736118f,0x637d0144}},	//   vye_, овши_, жеш_, iènc
  { {0xf77003c4,0x442d00dd,0x656900f2,0x316b002a}},	//   راه_, wye_, toeh, kocz_
  { {0xce380008,0x27300092,0x442d1190,0xb3c903ad}},	//   מאות_, _lành_, tye_, ализ_
  { {0x753b00dc,0x03a80086,0x92f501c6,0xf3590054}},	//   rhuz, یدیو_, очні, ишој_
  { {0x637d0251,0x2d9e0089,0x442d0464,0xa1c51191}},	//   dènc, ítek_, rye_, обод
  { {0x443f005c,0x442d00aa,0x5f1d000b,0x0574002b}},	//   szu_, sye_, मान्_, _کالد
  { {0xd00a000d,0xcea90008,0x394f00b8,0x208a0063}},	//   аеме_, _יי_, nigs_, ийни_
  { {0x41c5005d,0x637d0251,0x27300016,0x28de000b}},	//   _विकस, gènc, _bành_, फ्टि
  { {0xdfcf0029,0x179a0008,0x27300016,0x78bb1192}},	//   ضيف_, יישב, _cành_, _leuv
  { {0x27300092,0x41b50015,0x88bd002a,0xada30033}},	//   _dành_, _بمعر, _rośn, дасл
  { {0x2fcd018c,0x6cd60031,0x0d9904ab,0xa3b0000b}},	//   šega_, تقرا, стры_, टीक_
  { {0x637d0251,0x78a20264,0xb09b000a,0x8b26013e}},	// [1940] cènc, vcov, _דיפר, одае
  { {0x63a4002d,0x636f01f0,0x91ed000b,0x7bd60061}},	//   _éine, møns, _जहाज_, ruyu
  { {0x3e830003,0x09e309c3,0x78bb1193,0x811e0065}},	//   rété_, дохн, _beuv, _बचाओ_
  { {0xcb090008,0x7ed6002b,0x69c31194,0x6440002a}},	//   כל_, _ازکا, ânea, yzmi
  { {0x98a303a9,0xc18d004c,0xbc1a005e,0x38600061}},	//   фиче, אטאָ, _тіні_, çir_
  { {0x78a21195,0x6009000a,0x2cb202de,0x65940b76}},	//   scov, מִצְ, lbyd_, паку
  { {0xa3dc000b,0x78a204b2,0x7bc41196,0x3ecb000a}},	//   तंभ_, pcov, lsiu, שֶׂ֣
  { {0x6abc09f0,0x63740251,0x7bc40091,0x644001f1}},	//   _herf, màni, osiu, tzmi
  { {0x6abc0084,0x7414003b,0x5397008f,0x7bc41197}},	//   _kerf, سودا, овыя_, nsiu
  { {0x7879000a,0x128a006b,0x637d0144,0x27e61198}},	//   _הָעו, ищни_, vènc, mton_
  { {0x29040f4d,0xba9b0008,0xa6a90029,0x9af70008}},	//   _kama_, יסיי, _طالق_, חזיק_
  { {0x2906000c,0x637d0251,0x799c003f,0xe1670015}},	//   ndoa_, tènc, _murw, تدخي
  { {0x74130015,0x2cbf006f,0x41b4002b,0x6abc0827}},	//   _يوما, _ľud_, _کمبر, _oerf
  { {0x637d08e0,0x29040d25,0xfe790089,0x6b400123}},	//   rènc, _lama_, řům_, _högf
  { {0xce940063,0x637d0251,0x31351199,0x27300016}},	//   даръ, sènc, _некр, _vành_
  { {0x5c99044e,0x6abc0125,0x2904119a,0x6e280123}},	//   ская_, _aerf, _nama_, ädba
  { {0xdfdb0063,0x3fc90086,0xdb16008c,0x7af7119b}},	// [1950] _тъй_, _ادبی_, ksyä, text
  { {0x7ff40086,0xf5490092,0x6b40002e,0x501c039e}},	//   _آسيا, hấp_, _lögf, _כוחו
  { {0x78bb038d,0x7bc40020,0x99150010,0x6abc119c}},	//   _peuv, asiu, зьлі, _derf
  { {0x99d40015,0x7af7119d,0x27e6119e,0xbcfb0030}},	//   بتكا, sext, fton_, _ekér
  { {0xd7fb119f,0x78bb0003,0x46a5006b,0x27e611a0}},	//   руе_, _veuv, палв, gton_
  { {0x46a50063,0x3ffc004c,0x63740144,0x1b0b0033}},	//   чакв, יפדע, bàni, _тэмп_
  { {0x6728016f,0x99d40015,0x7f3c004c,0x3eb8004c}},	//   _dodj, _يتفا, שעוו, חלומ_
  { {0x58870010,0x6aa50026,0x6abc00b8,0xe3b9004a}},	//   _дыза, lchf, _zerf, бби_
  { {0x27ff0020,0xf799002b,0xc7c70054,0xc6e701c6}},	//   _usun_, _طناب_, _фсби, _міжп
  { {0xeb9f0134,0x934201c5,0x466b0137,0x60dd11a1}},	//   _esøg_, енье, _крем_, egsm
  { {0xe803014e,0xa2dd005d,0xe1f1002b,0x6aa50012}},	//   लिका_, पलब्, رسد_, ichf
  { {0x69c5003e,0xb6070007,0x2ef80409,0x672302c6}},	//   ishe, rašė, werf_, ljnj
  { {0x88bd005c,0x69c5002d,0xc49a000a,0x4195002b}},	//   _rośl, hshe, _השנת, _کشتز
  { {0x2d9c0014,0x539a0008,0x69c7016f,0x395f00c0}},	//   _évek_, _פיצו, _ovje, _ljus_
  { {0x6b9d018b,0xb2ba01d8,0xa2ba000a,0x877a004c}},	//   _ausg, _המצר, _המצט, מאשי
  { {0xdb0d0061,0x69c511a2,0x2bc7000b,0x27e611a3}},	//   asaü, dshe, _लिखा, yton_
  { {0x7bc40007,0x2cb211a4,0x27e611a5,0xd00f0067}},	// [1960] usiu, rbyd_, xton_, _ملي_
  { {0x7bc404f9,0x4a9a008f,0x63740251,0x799c00e8}},	//   rsiu, стаў_, tàni, _purw
  { {0x7e9b0008,0xceb70008,0x6abc11a6,0x387f11a7}},	//   _לסיו, _מפיק_, _verf, _azur_
  { {0x6abc11a8,0x27e611a9,0x63740144,0xa926004a}},	//   _werf, tton_, ràni, ядел
  { {0x2904016f,0x672811aa,0x510d004c,0x6abc1060}},	//   _vama_, _podj, יהאַ, _terf
  { {0x47330036,0x7d060061,0x27e611ab,0x394d03a0}},	//   нніс, _haks, rton_, _emes_
  { {0x7d060197,0x290411ac,0x27e60ae5,0x8f89000a}},	//   _kaks, _tama_, ston_, קְנֵ
  { {0xda5b0008,0x7d0611ad,0x6b9d11ae,0x27e611af}},	//   _הכלל, _jaks, _yusg, pton_
  { {0xad1b0008,0x69c7016f,0x7d0611b0,0xd45200af}},	//   מוקר, _zvje, _maks, xофф
  { {0x883b013a,0xb7d70029,0x083b000a,0x7d0611b1}},	//   _התמו, _روما_, _העמל, _laks
  { {0x76430050,0x26cc0176,0x6587002e,0xcb13000a}},	//   czny, _iddo_, árhæ, גלת_
  { {0x867b0053,0xf487002b,0x859b004f,0xca7b004f}},	//   _פראו, _کامی, _השאו, מניט
  { {0x60dd11b2,0xcfa7004a,0xdb0d007c,0x0000006a}},	//   rgsm, яшни, tsaü,
  { {0x69c500f2,0x3da711b3,0x81f60015,0x00540015}},	//   yshe, зраб, _فأعط, رَّج
  { {0xdef80010,0x9e140036,0x637b000a,0xadbd0033}},	//   чыя_, ндрі, _הנגד, рабi
  { {0x88bd002a,0x76070046,0x625b004f,0x0000006a}},	//   _pośm, lézá, _לכוה,
  { {0xd11a005d,0x69c7016f,0x0fdb0015,0x73fa000a}},	// [1970] धारण_, _svje, _ابعث_, מּ֑ו
  { {0x648b000a,0x69c3016e,0x0058000a,0x6aa50012}},	//   זְבְ, âneo, _משחת_, uchf
  { {0xf9f90115,0x6aa511b4,0xceb2000a,0x7d0611b5}},	//   تفاع_, rchf, _שיט_, _faks
  { {0xe2930053,0x26cc0026,0x6aa50012,0xe9d00067}},	//   גװע_, _addo_, schf, اغل_
  { {0xfc640063,0x394d00bd,0x68f903e1,0x69c511b6}},	//   _зърн, _vmes_, rewd, sshe
  { {0x8c1a0008,0xb9e7005e,0xe29a0016,0x69c511b7}},	//   _וושי, _ніби, _ngư_, pshe
  { {0x69c7010b,0xba770086,0x945d005c,0xcb12000a}},	//   _uvje, _راست, kańc, _בלם_
  { {0xbe3c0008,0x7643005c,0x98070033,0x27f00046}},	//   מעות, rzny, _нязд, ílný_
  { {0xb4ad005d,0x67d40a6c,0x7643002a,0x387f01c2}},	//   _कभी_, _поту, szny, _uzur_
  { {0xd75b0074,0xc7b2000a,0x81c911b8,0x644d0091}},	//   _اجرا_, _סבב_, огов_, _žais
  { {0xa51d0010,0xb6350015,0x77640144,0xeab2004f}},	//   _вялi, _تفاع, éixe, כֹר_
  { {0x2d9c0030,0x0000006a,0x0000006a,0x0000006a}},	//   _évei_,   ,   ,
  { {0x7d060048,0x307a0029,0x6b4000c0,0x60cd0026}},	//   _raks, تحدة_, _höge, _ddam
  { {0x6d4f11b9,0xf456000f,0x539a000a,0xf412000a}},	//   _amca, _קיסר_, _ויסו, _שפג_
  { {0x2d9e038d,0x4df50191,0x7d0611ba,0x41260015}},	//   ête_, нятт, _paks, _يفتق
  { {0x91ba000a,0xf236002b,0xc1ba000a,0xee37005e}},	//   _ומקי, _تبهک, _ומקש, єнт_
  { {0xed57000d,0x7d0611bb,0x98ad002a,0xaae20065}},	// [1980] фот_, _vaks, _zleć_, _पादक
  { {0x4c830004,0x5aca008b,0xf1c1000b,0x5fd30065}},	//   тлув, ілем_, _शबान, _तितल
  { {0x823a0053,0x63510089,0xfbc9000a,0x63740144}},	//   ֿענצ, měně, שת_, mànt
  { {0x63740144,0x7d0600cb,0x0000006a,0x0000006a}},	//   lànt, _uaks,   ,
  { {0x07fa00e6,0xa09b00a3,0x661d0091,0x1c430033}},	//   تراع_, קיסט, _ąska, _аням
  { {0xd5b00086,0xeb9f02e9,0xf1c0006f,0x6b400012}},	//   هفت_, _prøv_, úšky_, _böge
  { {0x8a030719,0x0000006a,0x0000006a,0x0000006a}},	//   _изре,   ,   ,
  { {0xa9260010,0x3ce00134,0xa5070054,0xdb0d001a}},	//   _ўдал, ngiv_, дећа_, lsað
  { {0x671e005d,0x14180029,0xb366006b,0xa6e600af}},	//   पादक_, سيدة_, дънк, _ожал
  { {0xf7720029,0xdb0d001a,0x8c1b000a,0x6beb004f}},	//   _شاء_, nsað, קויי, חַטַ
  { {0xcad70008,0xd2500029,0x945d005c,0x2fc911bc}},	//   ווית_, انج_, tańc, _svag_
  { {0x914b017f,0x7bcb0030,0xd257055f,0x0000006a}},	//   ічна_, águk, ьцы_,
  { {0xf537000a,0x945d002a,0xf41f008c,0x6b400012}},	//   _קנדי_, rańc, äät_, _zöge
  { {0x637404ed,0x2d8c0079,0x5f94006b,0x6b400052}},	//   tànu, ïden_, кият, _lögb
  { {0xf2060063,0x254c005c,0x22f7000a,0x9f520030}},	//   _цяло, eśli_, _חזון_, óbát_
  { {0x9d180063,0x0000006a,0x0000006a,0x0000006a}},	//   мост_,   ,   ,
  { {0xd0110015,0x63ad0061,0x70550021,0xdb0d001a}},	// [1990] _إلخ_, _çant, _سندا, fsað
  { {0xdb0d001a,0x539b000a,0x6378004f,0xea63009a}},	//   gsað, קיבו, פְּס, نپذی
  { {0x69c802de,0xe9ab009a,0x0000006a,0x0000006a}},	//   _ædel, زدان_,   ,
  { {0xdce40064,0x98f40010,0xd257000a,0xeb9f00cb}},	//   mliğ, вяшч, ושבה_, _brøt_
  { {0xdce40064,0x7ac711bd,0x9cd6000a,0xe89400ce}},	//   lliğ, _осве, _אורה_, ваць
  { {0x80380053,0xd706005e,0xd5e5006b,0x254c0046}},	//   ונדע_, енше_, ежки, měly_
  { {0xd5b1003b,0xdce401e2,0x5ebc000a,0x58d511be}},	//   دفع_, nliğ, חזוק, _повт
  { {0x6b4000b8,0xd61800e6,0xe5f20058,0xa493009a}},	//   _vöge, بتها_, اكيد, نیات
  { {0x6d5a0152,0x47d50115,0x2d9911bf,0x656201d7}},	//   étai, _سيار, _mise_, _djoh
  { {0xdce40064,0x422511c0,0x8c1a000a,0x58840174}},	//   kliğ, едов, פותי, _рыса
  { {0x4ae2005d,0x44390024,0x63a4002d,0x78a402c6}},	//   _पासव, šs_, _éinn, žive
  { {0xa06a0001,0x254c002a,0x64a50004,0x0000006a}},	//   зама_, yśli_, _џала,
  { {0x2c6c0046,0x98a4003d,0x9259002b,0x0000006a}},	//   _kódů_, _jomā_, تشکر_,
  { {0x2d990003,0x254c0046,0xa357006e,0x7f19008b}},	//   _aise_, děly_, _تخصص, місу_
  { {0x72050015,0x975a000a,0x2d9901f6,0x0000006a}},	//   _أوبم, לדשט, _bise_,
  { {0x6283010b,0x2004002e,0xa1c2006b,0x6e930015}},	//   _izno, æmis_, _сбъд, طلقا
  { {0x2601000b,0xbea6058f,0x4f96013d,0x6b400030}},	// [19a0] _वैसी_, _папк, _проу, _rögb
  { {0x539a0008,0x1ae3018d,0x2d9900aa,0x0000006a}},	//   פיעו, лоум, _eise_,
  { {0x533600b2,0xdebb0008,0x5ebb000a,0x3ebb000a}},	//   ענען_, _ממיל, _מזיק, _מציב
  { {0xe1ff0050,0x59760086,0xdb1d00c0,0xdb0d002e}},	//   łów_, رداز, _avsä, ssað
  { {0xdc9b000a,0x6d5611c1,0x69d70144,0x3157004f}},	//   _מיכל, miya, arxe, עינן_
  { {0x2d990011,0x657b01d7,0x56780174,0xd5ba01cf}},	//   _zise_, eluh, мбля_, пси_
  { {0xceb3013a,0xfb1b000a,0x6b6311c2,0xfe79005a}},	//   ניה_, _צולמ, _скра, řův_
  { {0x59760010,0x7afe11c3,0x6d44016e,0x6d5611c4}},	//   _чыгу, lept, nhia, niya
  { {0x75d40074,0xe3af0074,0xa3e70001,0xe3b20029}},	//   ريکا, یری_, едња_, درع_
  { {0xfd1f0023,0xa29401f3,0xdce40061,0x0edc000b}},	//   _nhìn_, капі, yliğ, _बागड
  { {0xf41f0020,0xd25a006b,0xb98a000a,0x2002002a}},	//   äär_, яци_, ּרָ֖, ewki_
  { {0x84660063,0x88bd005c,0x64a30054,0x0446006b}},	//   _пъле, _dośw, _баца, _пеен
  { {0x557700b2,0x2d99003e,0x54330002,0x6d560273}},	//   _װעגן_, _rise_, _مرور, diya
  { {0xf413000a,0xdce40061,0x2d9911c5,0x69de11c6}},	//   _תפס_, tliğ, _sise_, kupe
  { {0xe2130029,0x63a211c7,0xa2bb006f,0xa3dc000b}},	//   _مبيع, _huon, äčše, तूर_
  { {0x63a2000c,0xdce401e2,0x26c100dc,0x6d4411c8}},	//   _kuon, rliğ, óhoz_, ghia
  { {0x63a200f2,0x2d9911c9,0xdce40061,0x539b000a}},	// [19b0] _juon, _vise_, sliğ, ִיאו
  { {0xdce40064,0x2d990495,0x5f950099,0x68e20030}},	//   pliğ, _wise_, _шипт, egod
  { {0x63a2022d,0xda670806,0x70550086,0x6d44002d}},	//   _luon, رائي, _سنگا, bhia
  { {0xacbb0152,0x99d40015,0xf8b1002b,0xe8590033}},	//   _coût, اتلا, شکر_, маеш_
  { {0x63a20035,0xe72e0010,0x7afe0061,0x0c75002b}},	//   _nuon, ае_, bept, _شگرد
  { {0xf72b0010,0x95c50015,0x7d0d11ca,0x7afe11cb}},	//   яцей_, نيته, ldas, cept
  { {0xff18000a,0xae14000b,0xc1790091,0x2d9c0030}},	//   תקות_, डियन_, ntės_, _évet_
  { {0x63a211cc,0xacbb0003,0x7d0d11cd,0x2002002a}},	//   _buon, _goût, ndas, ywki_
  { {0x5964006b,0x7ae10030,0xa822002b,0xe3b10015}},	//   _съра, _ölts, _نکون, جرب_
  { {0x7d0d00f2,0x88bd005c,0xd759002b,0xf647013e}},	//   hdas, _pośw, _غلات_, _пхен
  { {0xcb120008,0x82f40010,0x60c611ce,0x614609dd}},	//   בלי_, учыц, takm, вена
  { {0x7afe00b8,0x81d40010,0x45b6000a,0x26c711cf}},	//   zept, ыцьц, _יפעל_, lano_
  { {0xf99200b2,0x60c60064,0x6283005c,0x69de0fce}},	//   ירט_, rakm, _wzno, zupe
  { {0x7529044c,0xd24e002b,0xb7da000a,0x64490012}},	//   ljez, _ژنو_, וקשי, mzei
  { {0x6d5611d0,0x6d4411d1,0x68e209bf,0xada611d2}},	//   tiya, thia, ygod, табл
  { {0xdcf60091,0x32070012,0x7c36008c,0x26120065}},	//   plyč, _isny_, tyyr, थिती_
  { {0x7afe04f9,0x644900b8,0x753b003f,0x6d440801}},	// [19c0] tept, nzei, ikuz, rhia
  { {0x6d5611d3,0x4e7a0029,0xdb590036,0x60c405d8}},	//   siya, _يحدد_, нює_, _heim
  { {0x3ed900b2,0x3cea005d,0x644900b8,0x5a960418}},	//   _אַרא, _छापे_, hzei, траф
  { {0x6c860029,0x79890335,0xd00f002b,0x394011d4}},	//   _للجم, _chew, _الی_, óis_
  { {0x87e30080,0xacbb0152,0x68e211d5,0x26c711d6}},	//   ающе, _voût, rgod, fano_
  { {0xa77302e1,0xe72f0015,0x75290030,0xd6cf0015}},	//   аліч, قصى_, ejez, ققه_
  { {0x24800048,0x63a204ed,0x2d9c00dc,0x644900b8}},	//   _šim_, _suon, _éves_, ezei
  { {0x644900b8,0xda4b000a,0x26c702f2,0x60c411d7}},	//   fzei, _חֲמָ, aano_, _neim
  { {0xe8d70008,0xd6da002b,0x64490012,0xdced0085}},	//   _שומר_, _يورش_, gzei, slać
  { {0x63a2022d,0x394603af,0xdced016f,0x7d0d00dc}},	//   _vuon, lhos_, plać, zdas
  { {0xf5490092,0x9554002b,0xfb15004c,0x7d0d0061}},	//   hấy_, _یخچا, אַרט_, ydas
  { {0x394603af,0x51870001,0x60c4002d,0x9655006b}},	//   nhos_, ђуна, _ceim, _съуч
  { {0x60c411d8,0xe53b0008,0x14d700a3,0x934611d9}},	//   _deim, _קתדר, _יואל_, _инде
  { {0x533300d7,0xee87004a,0x6b9c0012,0x7f850021}},	//   _вешт, выбо, _nirg, السن
  { {0xa3a8005d,0xc7c80092,0x139b0008,0x02fb00a3}},	//   _खंड_, hố_, _קבוע, _חלומ
  { {0xc1790007,0x6b9c0541,0x90450015,0x6da40004}},	//   rtės_, _airg, _منعه, риѓа
  { {0xc1790007,0x7d0d064e,0xdd9402bf,0x26c711da}},	// [19d0] stės_, rdas, раты, yano_
  { {0x1602005d,0x7cde0011,0x6b9c002d,0xdf390015}},	//   लबार_, tărâ, _cirg, _أكدت_
  { {0x26c711db,0x995c0046,0xb9c40015,0x6b9c11dc}},	//   vano_, líř_, لقلي, _dirg
  { {0x26c70050,0x09e4005e,0x6d5a0324,0xc9840d7a}},	//   wano_, роїн, état, аучи
  { {0x9bc40010,0x386911dd,0x26c711de,0x75290085}},	//   _вёск, çar_, tano_, vjez
  { {0xa03c0008,0x99d70015,0x69d80046,0xade7000b}},	//   ועדפ, _لترا, ávec, _ओमान_
  { {0x78a411df,0xa3a8000b,0x15f50015,0xdb060046}},	//   živa, _खूब_, استح, _utká
  { {0xf3ff11e0,0x2409005f,0x7bcd0024,0x394611e1}},	//   ção_, ении_, osau, chos_
  { {0xc952000a,0xf8ae002b,0xf2a5004a,0xd83b0033}},	//   _המן_, _رکن_, липп, _ўэб_
  { {0x2b1c014e,0x6449018b,0x753b0089,0xe7300115}},	//   नाएँ_, rzei, skuz, _وصل_
  { {0xd4f50010,0x644911e2,0x7ae511e3,0xc1060015}},	//   _бялы, szei, ight, هودي
  { {0xe4cb0086,0x26c50026,0x7bcd11e4,0x6146055f}},	//   _آبان_, _helo_, ksau, уема
  { {0xe5700015,0x44270015,0xfd1f0016,0x25a511e5}},	//   _بطل_, _جراف, _chìm_, _hull_
  { {0xe8e0000b,0x26c500b3,0x8235006e,0x60c411e6}},	//   _पञ्च, _jelo_, _مربا, _weim
  { {0x60c40176,0x200901d7,0xad660015,0x26c50524}},	//   _teim, _esai_, هاره, _melo_
  { {0xc27a0008,0xf1b200a3,0xfcb5005e,0xad650015}},	//   _ארצי, _פסח_, ищую, لاقه
  { {0x7ff60029,0xab6604c2,0x5bc50015,0x4c860033}},	// [19e0] _إسبا, гвал, لتلف, улав
  { {0x909b0008,0x68e9001c,0xcb0a0002,0xaf0601e5}},	//   _אספק, _aced, عيان_, _спол
  { {0x21200089,0x7f3b0053,0x637d0144,0x3f4d003d}},	//   _knih_, _נעטו, gèni, ažus_
  { {0x07a60010,0x6b40002e,0xc7c60a32,0x6b9c002a}},	//   гадн, _gögn, гски, _wirg
  { {0x6b9c0024,0xf7f30015,0xc7af0015,0x7e7e11e7}},	//   _tirg, مسود, كّن_, _hypp
  { {0x26c50844,0x2d8011e8,0x25a511e9,0xfaa311ea}},	//   _celo_, llie_, _bull_, _гаро
  { {0x2120016f,0x26c50796,0xaa46006b,0x394611eb}},	//   _onih_, _delo_, _севл, phos_
  { {0x25a50495,0x61e111ec,0x2956006b,0xba170040}},	//   _dull_, dull, _съгр, _حيفا_
  { {0xb8660029,0xdd040007,0x786611ed,0x778611ee}},	//   _صارو, ūrės, _сказ, _блаз
  { {0x57fb000a,0x25a511ef,0x26c511f0,0x61e111f1}},	//   _אלמו, _full_, _gelo_, full
  { {0x8717000a,0x9f42008c,0x7bcd003d,0xa3e5000b}},	//   _תקבע_, itkä_, zsau, बूब_
  { {0x26c5018c,0xa15911f2,0x64a611f3,0x995c0046}},	//   _zelo_, таму_, _сада, tíř_
  { {0xd0e6014e,0x54360115,0x251b004c,0x61e1008c}},	//   _कारण_, _حرار, _רודא, aull
  { {0xa2940484,0x61e111f4,0x92940515,0x35a90065}},	//   _калі, bull, _калц, _चूड़
  { {0x1df802bf,0x42170015,0x61e111f5,0xc292009a}},	//   леры_, _مزيج_, cull, _دیدب
  { {0x2d8004ba,0x721b000a,0x867b000a,0x7bcd11f6}},	//   glie_, _טווח, גרלו, tsau
  { {0x200900e8,0xfbd00015,0xcb550054,0x5c9908f0}},	// [19f0] _usai_, كتل_, аваћ, ткая_
  { {0x7ae5003e,0x6d5a0003,0x7e2b0033,0x9d55002b}},	//   ught, étar, _зіма_, _چندت
  { {0x2d8011f7,0x7d0e008c,0x7bcd11f8,0x9b680427}},	//   blie_, önsä, ssau, ушта_
  { {0x7bcd0945,0xb815000d,0x48150579,0x6b400123}},	//   psau, идеј, имес, _högl
  { {0x26c503af,0x25a502d7,0xf7710196,0x8cf40033}},	//   _pelo_, _sull_, يات_, _узяц
  { {0x7bda0008,0x25a5043a,0x6eba000b,0x7d0f0030}},	//   _בקשו, _pull_, ्रयु, _hacs
  { {0x6b40018b,0x65c209ef,0x8f38004c,0xd5ae0021}},	//   _mögl, обща, ראוו_, وفو_
  { {0x61e1022d,0x25a50251,0x6b40001a,0xb4df0157}},	//   vull, _vull_, _lögl, तले_
  { {0xa3e5005d,0x2d160053,0x26c505e3,0x7d0f11f9}},	//   बंध_, בֿים_, _telo_, _macs
  { {0x61e111fa,0xe29911fb,0x5f150065,0x25a511fc}},	//   tull, кап_, _फोल्_, _tull_
  { {0xcb1200a3,0xe12611fd,0x61e1008c,0xe4d5009a}},	//   קלט_, амни, uull, _نقاد
  { {0xa3e5000b,0x1168002b,0x2a76000a,0xd343002b}},	//   बंद_, الحی_, יעתך_, _گفتی
  { {0x88ba000a,0x2259002a,0x4fa6006b,0x8fa60133}},	//   כזרי, ńsk_, ригв, раге
  { {0x61e100f2,0x8f76005e,0x90d6002b,0xd0070054}},	//   pull, румі, دآگا, јере_
  { {0x3f840024,0x42790053,0xef170180,0xed5a014d}},	//   ēmu_, _באַג, јмс_, вов_
  { {0xdca3007a,0x205611fe,0x2d8011ff,0x7d060099}},	//   жати, _втор, ulie_, јзаж
  { {0xebe6005e,0x317b0447,0x9c970015,0x717b000a}},	// [1a00] розп, _באקד, لنفط_, _שנפס
  { {0xa03b0008,0x2d8005ed,0x7e7e1200,0x34b30065}},	//   _סעיפ, slie_, _typp, ीरुद
  { {0x6edb0008,0xa3e5005d,0xf1ab000b,0x7edb0c44}},	//   _בחיפ, बूत_, _घूमन, _בקיצ
  { {0xd9460001,0xebe60a13,0xae1b004f,0xcc8a009a}},	//   једи, _комп, _סוככ, _لنجه_
  { {0x4cbb0008,0x88bd005c,0x7d041201,0x98560004}},	//   _בזכו, _pośr, meis, јтеш
  { {0xed59002c,0x57770010,0x7d041202,0x63a40003}},	//   ďže_, абіў_, leis, _éini
  { {0x94d40010,0x76a9005e,0x645d001a,0xe73701ca}},	//   бойц, утів_, úsin, реј_
  { {0x7d04022d,0x9404006e,0xb7da006e,0x0000006a}},	//   neis, موعه, _لورا_,
  { {0xc34a0063,0x95530086,0x6b40002e,0x66e60180}},	//   вяне_, تخوا, _lögm, _воза
  { {0x7982003e,0x16760001,0x7791002b,0x973c0085}},	//   llow, _кћер, _فینا, _biće
  { {0x7d041203,0x32180046,0x6d46008c,0xdbd1001a}},	//   keis, íry_, _olka, _lýðv
  { {0x7d0400f2,0x9257004a,0x9326002b,0xf9a000fd}},	//   jeis, рают_, ارکن, онiм_
  { {0x60d60026,0x5f770029,0x32020089,0x7416002b}},	//   _ddym, لاسر, ňky_, _خوشا
  { {0xc0580036,0x6d461204,0xc43b000a,0xf1a605c0}},	//   рію_, _alka, _בתדי, _крин
  { {0xd378010b,0x7d041205,0x331b000a,0x5d650015}},	//   moć_, feis, _שֵׂע, مُسْ
  { {0x929b013a,0xe29b0008,0x7c870e77,0x25de000b}},	//   _ביות, _בשור, аузе, _गिनी_
  { {0x75220089,0xdfd100e5,0xfaa71206,0x9cc80033}},	// [1a10] _mnoz, _عيد_, ашен, рыса_
  { {0x6d460111,0x78a40263,0xd3781207,0x7982002a}},	//   _elka, živl, noć_, elow
  { {0x3f830263,0xce68004a,0x7e2b0033,0x7d0400d5}},	//   mlju_, _вряд_, _ріпа_, beis
  { {0x97c50029,0xae1a0008,0x49780010,0x7982002a}},	//   مقصو, _עורכ, асіў_, glow
  { {0xb8f20015,0x31790030,0xd3781207,0xf8071208}},	//   سكوب, iosz_, koć_, рчен
  { {0xd2460074,0x907a0053,0xdb230086,0xdc9a000a}},	//   _فن_, נטװי, _بوسی, _תישל
  { {0x5a440010,0xd5e80015,0xeb03000b,0x79821209}},	//   _дэта, لعين_, रजीत_, blow
  { {0x7bdf0a40,0x8938120a,0x0000006a,0x0000006a}},	//   orqu, _кпсс_,   ,
  { {0x14220010,0x4615002b,0x2eb7000b,0x94790033}},	//   здым, _گوار, _अभूत, ыску_
  { {0xf7850015,0x51b90033,0x9353002b,0x7d040b65}},	//   _الطَ, лымя_, تربچ, zeis
  { {0x27e90091,0x0000006a,0x0000006a,0x0000006a}},	//   šinę_,   ,   ,
  { {0x42540010,0x6458005c,0xcea900a3,0xd12f0015}},	//   ітэт, _ściś, _טי_, ّمَ_
  { {0x05740029,0xd91a0053,0xd05a0036,0x4429120b}},	//   _بالد, אורל, урні_, _ça_
  { {0x7d04018b,0x02390087,0x853c0091,0x6e3c02d2}},	//   weis, _مثبت_, _nuėj, tyrb
  { {0x7bdf0251,0xeb9f003c,0x7d04120c,0x7982002a}},	//   erqu, _esøk_, teis, ylow
  { {0x90c60ea6,0x3f830abb,0x4236000a,0x27ff0045}},	//   _убие, alju_, _לנצל_, _opun_
  { {0x3f83016f,0x0bea002b,0x6d580091,0x7d04120d}},	// [1a20] blju_, طفاً_, _įvad, reis
  { {0x7d040c58,0x63bb120e,0x0057000a,0x637d0144}},	//   seis, ipun, _לשפת_, cènt
  { {0xd35a0053,0xe9da1179,0x993a042b,0x88bd002a}},	//   נדעל, уке_, ляду_, _pośp
  { {0xf1b2000a,0x8288000a,0x71d6000a,0xe4470015}},	//   פסד_, בְנֶ, מועד_, _فض_
  { {0x9b8a0067,0x18670054,0x645d006f,0xe73a120f}},	//   _منحل_, баци_, úsil, лед_
  { {0x78250029,0xa09b0008,0xceb30008,0x63bb1210}},	//   تعمل, אינט, ֔יו_, dpun
  { {0xceb300a3,0xd6d90036,0x8f9b0643,0xa96a0785}},	//   היו_, рті_, ניצי, _бива_
  { {0x93b4005e,0xd90e002b,0x63bb026c,0x0000006a}},	//   обиц, _سیت_, fpun,
  { {0x63bb1211,0xe56f0015,0xa5070004,0x0000006a}},	//   gpun, عطى_, сења_,
  { {0xaaba014e,0x51f80036,0x61f80010,0x68fb1212}},	//   ेरिक, аною_, аноў_, _zbud
  { {0x3f83016f,0xdb7b0053,0x62340004,0x4b7b05bd}},	//   vlju_, רניכ, цену, רטיג
  { {0x73e6008f,0x71470080,0x1a9b0053,0x4a9b0053}},	//   _годз, схож, טייע, טייג
  { {0x04960029,0x637d0144,0x31790030,0x7afc0b28}},	//   _الشح, tènt, rosz_, _obrt
  { {0x8504009a,0x0000006a,0x0000006a,0x0000006a}},	//   _دوچن,   ,   ,
  { {0xd5d8000a,0x637d0144,0xd1310015,0xa5d8000a}},	//   יַּש, rènt, _يمت_, יַּי
  { {0x52830029,0x78a40085,0xe16b0015,0x3f8300bc}},	//   _عليك, živj, _حصته_, slju_
  { {0xfd4f0092,0x2bb80015,0x3f830085,0xe7d3003d}},	// [1a30] _khiế, مالة_, plju_, ršūš
  { {0xd5b801ec,0x0000006a,0x0000006a,0x0000006a}},	//   _otā_,   ,   ,
  { {0x27ff1213,0x63bb0012,0x3ce91214,0xc9871215}},	//   _spun_, zpun, pgav_, буди
  { {0x28f9004a,0x6f07002a,0xb9250015,0x6b40001a}},	//   редь_, lejc, تفصي, _lögh
  { {0x6aa90011,0x88c8005e,0x17990088,0x63bb1216}},	//   _şefu, слів_, авды_, xpun
  { {0xfd4f0092,0x68fb002a,0x645d006f,0x6d4d1217}},	//   _nhiế, _wbud, úsim, lhaa
  { {0xc5d50036,0xaa5d00ce,0xf6f6009a,0x0000006a}},	//   ціль, _ревi, تزنگ,
  { {0x63bb1218,0x68fb0085,0xcdaa004c,0x659203ae}},	//   tpun, _ubud, סיפֿ, мају
  { {0x69da01d1,0x14250036,0x63bb00f2,0x1c1c000b}},	//   _åter, ідом, upun, नियल_
  { {0xfd4f00a7,0x27e0002d,0xd6d10086,0x98880008}},	//   _chiế, áine_, _آقا_, _הָעֵ
  { {0x6f070089,0x63bb1219,0x6d48121a,0xf647006b}},	//   dejc, spun, ūdai, _ухан
  { {0xd24e0074,0xdced016f,0x415a005e,0x515a0033}},	//   خچه_, klađ, ршою_, ршоў_
  { {0x297a0053,0x88f6000a,0x6d4d01c2,0x2329121b}},	//   שטרא, חזרו_, dhaa, _воли_
  { {0x6569121c,0x889a00a3,0x289a004c,0x657b0046}},	//   lneh, יברי, יירא, louh
  { {0x41760074,0xbea302bf,0xa3e5000b,0x6d5f01c2}},	//   _وابس, дарк, बूर_, fiqa
  { {0x63a30458,0x6d430011,0x62830035,0xfe43005e}},	//   _hinn, _înal, _iyno, єнто
  { {0x63a30005,0x3c66008f,0x62830026,0x5aca007a}},	// [1a40] _kinn, цкаг, _hyno, илам_
  { {0xbad50010,0x261a000b,0x5db60015,0x61e10034}},	//   зіцы, _मछली_, _وإجر, orll
  { {0x0b170029,0xf8aa0010,0x4e2a006d,0x63a3121d}},	//   تقلة_, авек_, _тонн_, _minn
  { {0x63a3041c,0x6d4d0111,0xb9c5002b,0x98a6121e}},	//   _linn, chaa, ستمه, циде
  { {0x63a3002d,0x38cb0086,0x6569002c,0xd90d002b}},	//   _oinn, شانی_, dneh, دیق_
  { {0x501b0008,0x6d440007,0x1754034e,0x7d160091}},	//   יונו, lkia, явля, ldys
  { {0x63ab0084,0x656900b8,0xdce402c6,0xf62a005e}},	//   _augn, fneh, hnič, ріли_
  { {0x6d4400df,0x63a3002d,0xe96a0a1f,0x65930015}},	//   nkia, _ainn, _табл_, وجير
  { {0xfd4f0092,0x63a300f6,0x6d440007,0x12c6002b}},	//   _phiế, _binn, ikia, يتدپ
  { {0x63a3002f,0xdce4121f,0x7d1600f2,0x5fa5021e}},	//   _cinn, dnič, hdys, _गूगल
  { {0x6d4400f2,0x62830026,0x63a3003e,0xdb0f00dc}},	//   kkia, _cyno, _dinn, ödés
  { {0x63a31220,0x62830026,0x3ce4000b,0x443f02f2}},	//   _einn, _dyno, गलों_, byu_
  { {0xfd4f0023,0x61e10026,0x7d1606bd,0xe0870015}},	//   _thiế, arll, ddys, تجدي
  { {0x6d441221,0x62660021,0x62830034,0x93770015}},	//   ekia, _واثق, _fyno, _وصور_
  { {0xdd950010,0x26cc001c,0xee840010,0x62830034}},	//   завы, _medo_, дыто, _gyno
  { {0x91b70086,0x1bb50010,0x26cc1222,0xdfd10015}},	//   _بطور_, збаў, _ledo_, _كيب_
  { {0x317200dc,0x7127002b,0x6d5f01c2,0x6f071223}},	// [1a50] ézze_, _هرکل, riqa, pejc
  { {0xce950063,0x13bb004c,0x60cd007c,0x656904b2}},	//   _напъ, יזמע, _heam, zneh
  { {0x657b003f,0x60cd013c,0x5f740015,0x7d160091}},	//   youh, _keam, _تاير, bdys
  { {0x644000f2,0x929b000a,0x89a8005e,0x6ee7002b}},	//   kymi, ביבת, іків_, _اسکل
  { {0x88070086,0x6569002c,0xb8070087,0xecb6000a}},	//   تظام, vneh, تباه, _מפרץ_
  { {0xdc3a0008,0x26cc1224,0x4c9a000a,0x2bc4000b}},	//   _העשר, _cedo_, _לברו, _लौटा
  { {0x63a31225,0x65691226,0x8698006b,0x6440001a}},	//   _rinn, tneh, отът_, eymi
  { {0x60cd1227,0xe5050015,0x70b5000b,0x05550033}},	//   _neam, سبعي, ंडोल, ятля
  { {0x3f980176,0xb4bb005d,0x65691228,0x63a3074e}},	//   ymru_, _अभी_, rneh, _pinn
  { {0xaacb014e,0x657b0089,0xe4560033,0xdce40263}},	//   िरिक, souh, яжы_, vnič
  { {0x171a0008,0x6d441229,0x60cd108e,0x656a0125}},	//   _לֵאמ, ykia, _beam, ómhá
  { {0x6d93122a,0xdce40b6c,0x63a3122b,0x216a0923}},	//   nçad, tnič, _winn, сими_
  { {0x82350074,0x6283005c,0xd40b0015,0x10160015}},	//   زرگا, _wyno, _ختام_, أبجد
  { {0x20dc0092,0x61e8122c,0xb3ba000a,0xca6b0033}},	//   ửi_, budl, _המסכ, зiмi
  { {0xdce4052c,0x6146122d,0x9e66002b,0xddde005a}},	//   snič, _нека, ساسن, _vypů
  { {0x6d44122e,0xdce406c0,0x60cd030d,0x2d95122f}},	//   ukia, pnič, _geam, друс
  { {0x2fc90026,0x6fb30015,0x945d002a,0x6d440620}},	// [1a60] _gwag_, _كميا, mańs, rkia
  { {0x8eea0036,0x305b000a,0x3ae8002b,0xa3cd000b}},	//   _умов_, _לדפד, تبری_, षीय_
  { {0x6440005c,0x26cc0f8b,0x2f3b000a,0x7f3b000a}},	//   zymi, _redo_, _הגיד, _העיו
  { {0x4c6a004a,0xc9590033,0x6440005b,0x0000006a}},	//   _гимн_, оўі_, yymi,
  { {0x0c230010,0xad1b0008,0x2d820293,0xa8170015}},	//   _змян, _הוכר, _ikke_, كتور_
  { {0x6d93016e,0x7791002b,0x98a30a32,0xeb97024f}},	//   açad, پیما, хиче, _ния_
  { {0x945d005c,0x78ad0a00,0xb5aa0029,0x8b230063}},	//   kańs, žava, حاتك_, _ядре
  { {0xe5a30001,0x945d005c,0xf9040086,0x64401230}},	//   нији, jańs, _تأسی, tymi
  { {0x945d002a,0x7bd601d7,0xd37a006b,0x60cd1231}},	//   dańs, nsyu, йчо_, _ream
  { {0xcc570008,0xdc8b000a,0x60cd1232,0x23b70015}},	//   פסיק_, מְיָ, _seam, أديب_
  { {0x60cd0005,0xb6bb000a,0x91e30004,0x78a900aa}},	//   _peam, _הצבי, ноќе, _ygev
  { {0xf8cc014e,0x39460007,0x2fd90015,0x945d002a}},	//   ारिय, nkos_, يوجد_, gańs
  { {0xb97b0008,0xb4e8000b,0xc953000a,0x60cd1233}},	//   מנטי, बली_, תמר_, _veam
  { {0xd14b0074,0x9098006b,0xdfa40004,0x0000006a}},	//   _گشتن_, явят_, ејсо,
  { {0xfe700029,0x12fb009d,0x42fb000a,0x945d002a}},	//   هدف_, _להגב, _ההוס, bańs
  { {0x2d58005f,0x6b400084,0xe2130058,0x25bb004f}},	//   пись_, _mögu, _أبوع, מצלמ
  { {0x6b40002e,0x2fc90ad5,0x67280085,0x515c000a}},	// [1a70] _lögu, _uwag_, _ondj, _לכהו
  { {0x2aab0124,0xe451000a,0x7ff40058,0x0000006a}},	//   стао_, כֶב_, _أسيا,
  { {0x7f3c0008,0x442b0092,0x6286005c,0x4efa0008}},	//   _לעזו, ̣c_, ękow, _והתו
  { {0xbcfb02c1,0x67280020,0x2bb5000b,0x8cce000b}},	//   _ejér, _andj, _अंपा, तरणो
  { {0x16a90080,0xe7390ea6,0x6d930341,0xd7fb0937}},	//   овли_, жел_, rçad, суе_
  { {0x945d002a,0x2be2000b,0x07090058,0x2d8911eb}},	//   zańs, _पिता, زيبي_, llae_
  { {0x25a61234,0x7539002a,0x0000006a,0x0000006a}},	//   _biol_, _powz,   ,
  { {0x6b40002e,0xf9930086,0x25de005d,0xe3b91235}},	//   _dögu, _سبز_, _गिरी_, оби_
  { {0x0ebf000b,0x56f50004,0x6ebf000b,0x395f055e}},	//   ्राड, _опаѓ, ्राँ, _imus_
  { {0xaadd005d,0xf8680015,0xc2451236,0x945d0535}},	//   मणिक, _عملي_, днок, wańs
  { {0x77900086,0x945d005c,0x66f2000b,0xc0e60033}},	//   _حیوا, tańs, _घातक_, монк
  { {0x2ec6005d,0x69d8001c,0xb05b00b8,0x6b400123}},	//   वर्त, ávei, rbän, _högt
  { {0x945d002a,0x657c0030,0x660d003d,0x3494012e}},	//   rańs, _írha, žokļ, _зацр
  { {0x1ea90015,0x22680046,0x2d8900aa,0x6265011a}},	//   كافي_, átká_, elae_, _овла
  { {0xdef90010,0x945d005c,0xe8220046,0xb2ba000a}},	//   чыў_, pańs, _měšť, _ומצר
  { {0xa1870063,0xdb24009a,0x0000006a,0x0000006a}},	//   _обща_, کوئی,   ,
  { {0x50db004f,0xad650058,0x3160007f,0x0000006a}},	// [1a80] _וחפצ, رافه, _imiz_,
  { {0x32ba0053,0x5f060010,0x394d1237,0xef94002b}},	//   ַזנד, _ўзна, _ales_, _سیزد
  { {0xceb305af,0x6b520f47,0xe293000a,0x39461238}},	//   _בית_, _lægg, תְּ_, tkos_
  { {0x39460007,0x9cb60086,0x7643005c,0x78ad01a3}},	//   ukos_, _زمست, dyny, žavn
  { {0x6b40002e,0xaac60015,0xeb9a067a,0xaf58000a}},	//   _sögu, _يتسن, _мим_, ּׁ֔ה_
  { {0x394d03af,0xd5ba0178,0x46140029,0x3946121a}},	//   _eles_, оси_, فوتر, skos_
  { {0xda650029,0x394d0546,0x0000006a,0x0000006a}},	//   _كافي, _fles_,   ,
  { {0xb4e8005d,0xe9470086,0xda5b000a,0x14180015}},	//   बले_, _قرقی, _וכלל, كيبة_
  { {0xd90d0086,0x25a61239,0xe7b30058,0xaab20065}},	//   _دین_, _viol_, _لمقد, _जलाक
  { {0x628f005c,0x883b000a,0x25f6000b,0x66290030}},	//   ęcon, _ותמו, _एमपी_, éskö
  { {0x6b4001d1,0xcb130008,0xd25700ce,0x394d0072}},	//   _högs, דלת_, дця_, _yles_
  { {0x041a0015,0x0566123a,0x27e6123b,0x2d47059d}},	//   _ويضع_, _ювен, oron_, _põem_
  { {0x6d4304f9,0x104b0036,0x859b000a,0xd59b000a}},	//   _înai, іями_, _ושאו, _ובאל
  { {0x2bb5000b,0xe1ef002b,0x40340054,0x63bd123c}},	//   _अंबा, دسی_, њерс, ísne
  { {0x3da7008f,0x6b40001a,0x27e6123d,0x637b004f}},	//   драб, _lögs, hron_, _ונגד
  { {0x3f8a0073,0x0000006a,0x0000006a,0x0000006a}},	//   albu_,   ,   ,
  { {0x1eab0029,0x2bbb0015,0x0000006a,0x0000006a}},	// [1a90] _وادي_, تازة_,   ,
  { {0xa3e6014e,0x1b780029,0xbe870015,0x2d8900aa}},	//   _बटन_, وصلة_, _يجدو, slae_
  { {0x27e602c1,0x6b4000dc,0x27e00125,0xab84123e}},	//   eron_, _rögt, áinn_, тутк
  { {0x7e9a000a,0x0e9a000a,0xab5b0061,0x61fa0401}},	//   _מסתו, _משתל, _stüd, ittl
  { {0x7d0d1213,0x76430034,0x31580643,0x78ad0085}},	//   meas, wyny, ויאן_, žavo
  { {0x7d0d123f,0xf7730196,0x764300f2,0xb9c70015}},	//   leas, خاص_, tyny, _يتأه
  { {0x27e61240,0xfbb5000b,0x2bb50065,0xe9b40138}},	//   aron_, _अंडम, _अंडा, _абсь
  { {0x7d0d1241,0x1a68002b,0xd5ae0015,0x46180033}},	//   neas, _تیمی_, حفي_, ьціў_
  { {0xa7750010,0x998500dc,0xf8b200f3,0x98140015}},	//   _злач, _élő_, _תשמ_, _لبلا
  { {0x6b4000c0,0xdb0600dc,0x7d0d0a0a,0x6b5202de}},	//   _högr, _kuká, heas, _vægg
  { {0x59990008,0x26c700bd,0x7d0d00f2,0xa9990008}},	//   ּשָׁ, mbno_, keas, ּבָר
  { {0x361a0008,0xc222002b,0xcf89000a,0x14ca009a}},	//   _מועד, اکوو, _הט_, _فهمی_
  { {0x2d801242,0x61fa003e,0x84470015,0xd24e002b}},	//   voie_, attl, _تخال, لنی_
  { {0xa8560008,0xc43a000a,0x6d4f1243,0xf43a000a}},	//   גישה_, _מתני, _alca, _מתנש
  { {0x236500c0,0x51f50029,0xfd96004a,0xab640061}},	//   milj_, _أستر, ешаю, nmüş
  { {0x65a70030,0xf11a0040,0x7d0d1244,0x27e61245}},	//   _műho, _رغبت_, geas, yron_
  { {0xed570ea6,0x6b520134,0xbf9b00aa,0x7ed6008b}},	// [1aa0] хот_, _læge, rwêr, _пінч
  { {0x78ad0796,0x6c830015,0xf1d3000b,0xdb060030}},	//   žavl, الْم, _दबान, _buká
  { {0xeef7000a,0x9af30015,0x2dda0015,0x2d730085}},	//   _אמיר_, اكمت, _عبدة_, mćen_
  { {0x7d0d0939,0x25f6000b,0x6d930061,0x6a95005e}},	//   ceas, _एमबी_, rçac, трує
  { {0x68460010,0x58830afa,0xe7861246,0x7aeb0030}},	//   энда, лыша, нуко, álté
  { {0xf09300b2,0x7bc41247,0x27e000bd,0xab7a0015}},	//   אנד_, mpiu, šino_, _رمزا_
  { {0x38720011,0xe1e70087,0xd5b10016,0x3687006b}},	//   _ţară_, _حس_, _cú_, нсън_
  { {0x88c50029,0x2601000b,0x76a9005e,0x69dc1248}},	//   _لتكل, _शहरी_, фтів_, _ivre
  { {0x88810074,0xb6030048,0xd7ca0015,0xf8cc000b}},	//   _پیون, āšan, _رواه_, ारीप
  { {0xb7d70029,0x8c1b0008,0x41e6042b,0x7d0d0045}},	//   _أولا_, לופי, німа, zeas
  { {0xf6290029,0xf7770008,0x8b57000a,0xc298005e}},	//   _يسمى_, _טעמי_, גייס_, ькох_
  { {0xb5050015,0x29020123,0x914b00ce,0x0000006a}},	//   _لظهو, _ökad_, їчна_,
  { {0xe53b0008,0x30a70010,0x7d0d0011,0xd4090015}},	//   _מתאר, эров, veas, _يتهم_
  { {0x23780015,0x69dc1249,0x4ea7124a,0x8417004f}},	//   _تمتد_, _ovre, ерба, _נקוב_
  { {0x831b0008,0x3ea5124b,0x7d0d124c,0xa2b7004f}},	//   _מוגז, ält_, teas, _אפוד_
  { {0x2bb5005d,0xdb060069,0x6ab90065,0x6286005a}},	//   _अंदा, _ruká, इड्र, řkos
  { {0xe7cf005d,0x69dc124d,0x61ef002a,0x7d0d124e}},	// [1ab0] _सौंप, _avre, ącle, reas
  { {0x7d0d124f,0x2be2000b,0xfaa5002b,0x61e81250}},	//   seas, _पिरा, نجای, ordl
  { {0x5ee80008,0xdcfd0024,0xdeb6000a,0x7d0d1251}},	//   _אַרְ, _eksā, _בפתח_, peas
  { {0x64c410cd,0x200901d7,0xda080015,0x63aa001a}},	//   nčič, _kpai_, عينه_, _lifn
  { {0x399e0089,0x69dc1252,0xa158000a,0xe89402a3}},	//   _růst_, _evre, עבדה_, гаць
  { {0x3f831253,0x7af5002a,0xe758005e,0xf094004f}},	//   noju_, _uczt, ничі_, ננס_
  { {0xc8f5010f,0xceb4039e,0xbb76000a,0xda05000b}},	//   _извъ, ניק_, _יעשו_, _रहित_
  { {0xab640061,0x69c51254,0xa3ad0065,0x19950138}},	//   rmüş, mphe, कदल_, _рабя
  { {0x290f1255,0x3f831256,0x039501b7,0xad1c004f}},	//   mega_, koju_, кроя, לוהר
  { {0x290f0ab5,0x4225005e,0x38760030,0x71f90058}},	//   lega_, вдов, óerő_, ورجس_
  { {0x2d680064,0x628a0026,0x7bcf0026,0x9b16000a}},	//   iğer_, _cyfo, _lwcu, דחתה_
  { {0x290f018c,0x291d000c,0x50460124,0x628a0176}},	//   nega_, ndwa_, вемб, _dyfo
  { {0xc8da0008,0x30760b1e,0x84440015,0xbf660015}},	//   וקרט, тунс, _مخول, ندسو
  { {0xdf150191,0x5f06006b,0x290f1257,0xe28505ab}},	//   льсь, ъзга, hega_, _илли
  { {0x290f1258,0x628a0026,0x0219005e,0x0000006a}},	//   kega_, _gyfo, _ціль_,
  { {0x290f116e,0x2d680061,0x69ce0034,0x78ad00bc}},	//   jega_, eğer_, _rwbe, žavj
  { {0x290f0005,0xc4d20632,0x8c430080,0x73ac000a}},	// [1ac0] dega_, יגן_, аете, ִיאֵ
  { {0x6009000a,0x7fd7004c,0x290f007c,0x7bc40091}},	//   _נִפְ, _שויס_, eega_, rpiu
  { {0xe8fa008f,0xa9a60063,0xab5b00b8,0xbea60180}},	//   дле_, вижд, _stüc, _јанк
  { {0x290f1259,0x81bc003d,0xadd7000a,0xd7e600e2}},	//   gega_, lvēc, _בוטח_, віко
  { {0xd9430054,0xe7b3012c,0x98130058,0x0000006a}},	//   јечи, لمند, لبوا,
  { {0xbcfb0089,0x6d93125a,0x69d80057,0x290f007c}},	//   _jmén, nçan, áves, aega_
  { {0x6f0301e2,0xceb30008,0xfb1b000a,0x69dc0085}},	//   _önce, סיה_, _קולמ, _uvre
  { {0x38c8002b,0x9418004a,0x15140a32,0xa3dd0065}},	//   _ساری_, ежит_, удия, तओं_
  { {0xa5070001,0x13d30033,0x98a300d8,0x88050015}},	//   тења_, ажыў, _вите, _مظلم
  { {0x5fdc005d,0x2bb5000b,0x4c9b000a,0x926a0004}},	//   _बिजल, _अंसा, ושפע, дрма_
  { {0xe1d80033,0x995e0046,0x973c0085,0x3f83125b}},	//   эдні_, _můž_, _nići, voju_
  { {0xbcfb0152,0x3f83002a,0x27e90b28,0x044a125c}},	//   _amén, woju_, šane_, _опек_
  { {0x3f830095,0x1074005e,0xc0ab0021,0x5064125d}},	//   toju_, илюю, بادل_, атра
  { {0x20e30092,0x643b0053,0x2ebf000b,0x3f830091}},	//   ổi_, _קעגנ, ्रेत, uoju_
  { {0x7e440001,0x6397000a,0x291d002a,0xaed4056d}},	//   ахте, _שדוא_, ydwa_, росш
  { {0xf1a4008f,0xb063008c,0x8d7400c3,0xdce4002a}},	//   _крын, ääss, لاقا, ynią
  { {0x290f125e,0x9da8006b,0x3ae9002b,0xbca40015}},	// [1ad0] vega_, търа_, فبای_, لمفي
  { {0x3b540010,0x93fb0008,0xdca40001,0x207c015b}},	//   акур, ולמי, рађи, _קאזא
  { {0x7c2600b8,0x290f125f,0x2b8f0012,0x2bdf0157}},	//   _erkr, tega_, lück_, _फटका
  { {0xdced00b3,0x98e50015,0x44261260,0xaa580054}},	//   onač, اكشو, _oro_, њицу_
  { {0x69c5003e,0x4426008c,0x290f1261,0x88c800ce}},	//   sphe, _nro_, rega_, тлів_
  { {0x290f1262,0x7784009e,0x6d4d1263,0xdced0085}},	//   sega_, аліз, lkaa, inač
  { {0x6446003c,0x69d80091,0x7d1d1264,0x27fd0034}},	//   økin, šver, _kass, stwn_
  { {0xdb0d0467,0x44260176,0x6d4d1265,0x02bd000b}},	//   mpañ, _bro_, nkaa, ोर्न
  { {0xb4650086,0x7d1d050d,0x6b52001a,0x38600125}},	//   دگاه, _mass, _hæga, úirt_
  { {0xdced016f,0x44261266,0x7d1d1267,0x787a000a}},	//   dnač, _dro_, _lass, _אָבו
  { {0x6d4d022d,0xe6590029,0x44261268,0x216a0515}},	//   kkaa, _ثلاث_, _ero_, еини_
  { {0x44261269,0x7bc10046,0x6d4d126a,0x7d1d126b}},	//   _fro_, _člun, jkaa, _nass
  { {0xd9e0014e,0x656900f2,0x6d9a0026,0x73e50004}},	//   _पट्ट, mieh, nïae, _солз
  { {0x9264002b,0x224c0030,0x6569126c,0x7d1d02f2}},	//   ادیم, ökké_, lieh, _aass
  { {0xd3360008,0xb0630020,0x8db50036,0xfce6126d}},	//   _תרצה_, äärs, исті, лово
  { {0x6d4d0035,0xe6d0000b,0x27e00030,0x8d550004}},	//   gkaa, _सज्ज, áink_, атуч
  { {0x0c26008f,0x5f760086,0x7d1d126e,0xeab20015}},	// [1ae0] ыман, _مادر, _dass, معا_
  { {0x501b0008,0x656900b8,0xac970015,0xc7b90030}},	//   _טופו, hieh, انكا_, _erők_
  { {0xeb970001,0x0e750010,0x4efb0135,0x1efb00f3}},	//   ћих_, _выяў, _אליג, _אליע
  { {0x39400084,0xdce8003d,0xfd120015,0x6f1e0034}},	//   ðis_, ēlēs, _اجد_, _hapc
  { {0x6f1e03c0,0x48e307de,0xf74600f1,0x7d04126f}},	//   _kapc, сочв, ледо, mfis
  { {0x77910086,0xe7370063,0xa773042b,0x8c2b000a}},	//   قیقا, леч_, бліч, _אֵלֵ
  { {0xf6e50010,0x7c241270,0x65690012,0xdced0a30}},	//   рцін, lvir, fieh, znač
  { {0x44261271,0xb7d60015,0x398e0046,0x741400c3}},	//   _pro_, _مقرب, kýsi_, لوبا
  { {0x38560063,0x136a0254,0xc3540054,0x7c241272}},	//   _съвс, ешни_, икиј, nvir
  { {0xbcfb038d,0x07a60124,0xa3e5005d,0x4df6000b}},	//   _amél, _сазн, _फिर_, ुझाई_
  { {0xe135005f,0x6569002c,0xa294022a,0x2294004a}},	//   анны, bieh, рані, риня
  { {0xd257008f,0x51870083,0x6569032c,0x69de0cd9}},	//   уць_, ѓуна, cieh, ispe
  { {0x64460020,0x50670b75,0x44261273,0xa3d40088}},	//   äkid, утна, _uro_, _толч
  { {0x2b8f018b,0xa3f7000a,0x23270054,0x7c241274}},	//   rück_, _עמוק_, _бољи_, dvir
  { {0x41e60010,0xadd50001,0x8d770087,0xb2bb000f}},	//   _сіла, робљ, هارا, _אמור
  { {0x60d60084,0x7c240084,0x6d4d00f2,0x62981275}},	//   _geym, fvir, ukaa, _izvo
  { {0x5c070033,0x1d640015,0x9f4b0046,0x6d4d1276}},	// [1af0] ыява, حدَّ, lucí_, rkaa
  { {0x6569018b,0x7d1d1277,0xda7b0010,0x316b002a}},	//   zieh, _wass, няе_, licz_
  { {0x88d50010,0xda15000d,0x7d1d1278,0xdce4002a}},	//   аўлі, рдењ, _tass, hnię
  { {0xdce40050,0x2a980015,0x316b002a,0x6b9c0012}},	//   knię, ائكة_, nicz_, _ehrg
  { {0x6d930ade,0xdb0d1279,0xe0d2000a,0x69de127a}},	//   nçam, spañ, חֲו_, aspe
  { {0x6d580007,0x5fbc0053,0xb8ec005d,0xd6a90086}},	//   _įvai, עצונ, _श्_, نگام_
  { {0xf8c9038d,0xeef8000a,0x0555006b,0x764a0034}},	//   _créé_, אמור_, ития, gyfy
  { {0x79a4000d,0x15450080,0xdce4002a,0xe6280015}},	//   _груе, реим, fnię, اثون_
  { {0x645b003f,0xc952000a,0xdce4002a,0x69060030}},	//   uzui, _ומן_, gnię, érdő
  { {0x33650a61,0x7bdf06be,0xe787127b,0x65690012}},	//   рвог, isqu, _субо, sieh
  { {0x291f0020,0x069b0015,0x4615012c,0x7d04127c}},	//   _kaua_, _أخذت_, _خوار, yfis
  { {0xc4f80029,0xe4cb0015,0x216a127d,0x20560033}},	//   _معها_, _أبان_, тими_, атгр
  { {0xb4c30372,0xc9160008,0x6d930064,0x68e4002d}},	//   ्री_, בחרת_, rçal, óidi
  { {0x2d8b0089,0x6446008c,0x291f007c,0xab5b0012}},	//   _akce_, äkie, _laua_, _stün
  { {0x6d930251,0x60d6002e,0x7bdf0466,0xbda60015}},	//   pçal, _teym, esqu, لحرو
  { {0x7c2400df,0x27e001a3,0xc27a000a,0xb05b0012}},	//   tvir, šini_, _ברצי, ebäu
  { {0x7d04002e,0xab66127e,0x0d990033,0x6b660004}},	// [1b00] rfis, авал, утры_, акаа
  { {0x3fdb0008,0xd00f0086,0x9e66007a,0x7c24127f}},	//   _שקיב, _کلی_, _ввод, rvir
  { {0x2be2005d,0x399c002d,0xbd8a04c9,0x20020020}},	//   _पिका, híse_, _لندن_, ltki_
  { {0x6d430011,0x929a0008,0x48c30054,0x69de1280}},	//   _înap, דיעת, ољша, rspe
  { {0x27e0002d,0x69de1281,0xdb0f0045,0xdb0d001a}},	//   éin_, sspe, _ducâ, ppað
  { {0xbf360053,0x35e60001,0x69de0123,0x69c30046}},	//   שאַץ_, ацив, pspe, ínec
  { {0x09e3009c,0x4b7b0643,0xe9d7006b,0x65c301ca}},	//   _морн, _סאלו, _вкс_, обја
  { {0x27e90048,0xa5340431,0x399c002d,0x0000006a}},	//   šana_, снич, físe_,
  { {0xc9550010,0x93460029,0xa98b0008,0x61e70030}},	//   _утры, لخدم, _יָמִ, ájln
  { {0x316b08c2,0xc6d8000a,0x9f4b0046,0xd7fb000a}},	//   wicz_, _תַּר, tucí_, _בהמל
  { {0x8ab71282,0x5ab7004c,0xd2500015,0x236b006f}},	//   יליג_, יליע_, سنح_, _žijú_
  { {0x26dc1283,0x8c480061,0x39440091,0xd5af0067}},	//   lavo_, _kağı, _joms_, _قفل_
  { {0xb4d2005d,0x64a6057e,0xca6b005e,0x47f9000a}},	//   वरी_, _тада, дiлi, ְּשׁ
  { {0x6d930527,0x26dc1284,0xe72e0033,0x73c30058}},	//   rçam, navo_, зеi_, _بيوم
  { {0x539b0008,0xc1790007,0x7bc60a6f,0x139b039e}},	//   _שיוו, urės_, _atku, _שבוע
  { {0x06570008,0x39440ad3,0xdd910015,0x7175002b}},	//   בילך_, _noms_, سوء_, _دهبا
  { {0x4bd80015,0x717c000a,0x26dc1285,0x417c004f}},	// [1b10] لبلد_, _שנחס, kavo_, _שנחב
  { {0x7bdf038d,0x26dc1286,0x68fb1287,0x6e96002b}},	//   rsqu, javo_, _scud, _گلپا
  { {0x26dc0007,0x49b80115,0xaab4005e,0x99d40067}},	//   davo_, لاند_, ійці, قتنا
  { {0x8c4801e2,0x58d9005e,0x91bb000a,0xdb0e0f24}},	//   _bağı, уддя_, דמאי, _libè
  { {0xdc3500b4,0xd7fb0010,0x9be4005e,0xd0f8000a}},	//   _האָט_, туе_, _мірк, שמדת_
  { {0x8c4801e2,0x26dc0007,0x6f150077,0x8c1a004f}},	//   _dağı, gavo_, nezc, _גושי
  { {0xcf580008,0x8f9c004c,0x6b5202de,0x60dd1288}},	//   שבות_, דיגי, _mægl, kasm
  { {0x7415003b,0x5e780008,0xb4c3000b,0x2002002a}},	//   موعا, יתון_, ्रे_, ytki_
  { {0x69c7016f,0xb345016e,0x60dd001a,0x26dc1289}},	//   _htje, _noçã, dasm, bavo_
  { {0xda0e005d,0x43740036,0xdc880008,0x61e70030}},	//   _सहमत_, жуют, יְתָ, ájlo
  { {0xe695003b,0x399c0125,0x6f150077,0x0000006a}},	//   _الاد, síse_, dezc,
  { {0xf65201e4,0x8c480064,0xca1a000a,0x04c90021}},	//   _מצב_, _yağı, נֵיכ, _صوتي_
  { {0x98790053,0xa4b6000a,0x657e0030,0xf48703ae}},	//   ראָט, _הלנה_, éphe, _тужн
  { {0x889a000a,0x8f76005e,0x83fd0030,0x20021207}},	//   טברי, сумі, ezőg, rtki_
  { {0x20020668,0x82d6000a,0xdd920015,0x52d6000a}},	//   stki_, _הוצג_, كوس_, _הוצע_
  { {0x26dc1286,0xc2120008,0x5f76002b,0x0000006a}},	//   zavo_, _זהה_, _گابر,
  { {0x0ab60029,0xdca3005e,0x3944128a,0x0000006a}},	// [1b20] محاد, зати, _roms_,
  { {0xef1a0124,0xb05b01d1,0x6721128b,0x39440150}},	//   _смо_, rbät, _nalj, _soms_
  { {0x26dc0007,0x8c480061,0x72da004c,0x4a9a0033}},	//   vavo_, _sağı, רקעג, утаў_
  { {0xb4c30231,0xd910002b,0x9965005e,0x3f8a0046}},	//   ्रो_, بیر_, отіл, lobu_
  { {0xdb0e0d92,0x2be2000b,0x81bc003d,0xa967024f}},	//   _libé, _पिटा, evēl, щица_
  { {0x66e30001,0x501b0008,0xa09b00f3,0x7d16128c}},	//   поља, טונו, ניסט, leys
  { {0x86260010,0x67210a00,0x96f90033,0x6dbc006f}},	//   сьле, _dalj, рэчу_, _očam
  { {0x6d46022d,0x67230796,0xee09000a,0xb4d2000b}},	//   _joka, adnj, ׁמוֹ_, वरे_
  { {0x6d460007,0x3f8a0085,0xfb56000a,0x88bb004f}},	//   _moka, kobu_, ֶׁ֨ר_, _תזמי
  { {0x8c1b013a,0x69c1038d,0x8857000a,0xdb070030}},	//   נויי, _élec, _השמע_, _kijá
  { {0x6d5a0024,0x6d4600dd,0x611508f0,0x3f8a01c0}},	//   ītaj, _ooka, одну, dobu_
  { {0x6721044c,0x32630033,0x27e0128d,0x60dd0091}},	//   _zalj, ятыв, šinu_, uasm
  { {0x7d160064,0xc0580127,0x60dd128e,0xa98b000a}},	//   deys, бір_, rasm, רָיִ
  { {0x93fb0008,0xc058042b,0x2019002a,0x60dd128f}},	//   _עלוי, сію_, rwsi_, sasm
  { {0x6f1502c1,0xde58005e,0x6d461290,0xfe730040}},	//   rezc, барі_, _boka, سدس_
  { {0x2d980015,0x88bd0535,0x2b9408d9,0x0000006a}},	//   مَّد_, _maśc, bäck_,
  { {0x81bc0048,0xc1740008,0x7ff70029,0x6d930291}},	// [1b30] zvēl, _מחק_, _اسعا, nçai
  { {0xfbd00015,0xcaf40015,0x8aa70b1e,0x99d70015}},	//   عتق_, كسمب, бред, متصا
  { {0x83fd0030,0x539b000a,0xdb26002b,0x4f67002b}},	//   mzőe, ניבו, تولی, _ناگف
  { {0x7522002c,0x6dbc0085,0x2bbb0015,0xe8550015}},	//   _naoz, _očaj, _ماسة_, يناد
  { {0x672109e7,0xf745004a,0x17fb0015,0xbcfb0125}},	//   _palj, жело, ارصة_, _nméi
  { {0xec360008,0x81bc003d,0x3fdc000a,0x2c770069}},	//   _ואשר_, tvēl, נקוב, aždé_
  { {0x69c7016f,0x6723016f,0x67211291,0xd5e80015}},	//   _utje, rdnj, _valj, معين_
  { {0x6b52001a,0x672101c2,0x5dcc000a,0x854900af}},	//   _nægj, _walj, אֶזְ, рзив_
  { {0x27e0002f,0xe3b61292,0x6b4000dc,0xb8df005d}},	//   áint_, обы_, _rögz, ूँ_
  { {0x98ad002c,0xd6d80004,0x8c1c05bd,0x43691293}},	//   _hneď_, _гтц_, רוזי, раон_
  { {0x44270086,0x95c40015,0x81bc003d,0xc7b90030}},	//   _گراف, _فيله, lvēj, _erőt_
  { {0xe4350086,0xd05a0033,0x798b0034,0x75220f21}},	//   _وفاد, аргі_, nogw, _gaoz
  { {0x7d1600f2,0x6d461294,0xbf9b016e,0x44270067}},	//   veys, _roka, rtên, _دراف
  { {0xbf9b001c,0x20ea0092,0x83fd00dc,0x6d461295}},	//   stên, ời_, rződ, _soka
  { {0x7d16022d,0x83fd0030,0x6d461296,0x3f8a08c6}},	//   teys, sződ, _poka, robu_
  { {0x3f8a0188,0x83fd0030,0xb05b0123,0x2b940012}},	//   sobu_, pződ, rbär, päck_
  { {0xed57000d,0xceb60029,0x0b461297,0x7f860015}},	// [1b40] цот_, _وحدث, онан, _ولبن
  { {0x6d46002a,0x68e90061,0xdc750033,0xc332004f}},	//   _woka, _aded, чысь, ֽוא_
  { {0x32050041,0x7bcd00f2,0x6d461298,0x7cd60015}},	//   ntly_, apau, _toka, _وتحذ
  { {0xc27a0053,0x6d46008c,0x0000006a,0x0000006a}},	//   ברעי, _uoka,   ,
  { {0x68e90026,0x6dbc002c,0x88160031,0x57a60345}},	//   _dded, _očak, تباط, ошка
  { {0xe3a70029,0x05ea1299,0xf7430054,0xe5c60054}},	//   _زر_, афии_, дељо, осио
  { {0xd6d9129a,0xd5b7005f,0xda0e005d,0x8a030054}},	//   сті_, осы_, _सहित_, _озре
  { {0xceb3000a,0xb5aa0015,0x7c29129b,0xe8f709a0}},	//   ויו_, جاتك_, _šeri, _млс_
  { {0x8d5b0053,0x320500da,0xd37a0fea,0x83fd0030}},	//   יכקי, etly_, ичо_, ezőb
  { {0x46a6008f,0xc7b900dc,0x28130015,0x320500da}},	//   _дазв, _erős_, _توكس, ftly_
  { {0xd3770010,0x7abb000a,0x2b940012,0x7bcd003d}},	//   ўчы_, יציו, räch_, zpau
  { {0x81bc0048,0xa2ae000b,0xdbd20061,0xf653004f}},	//   lvēk, ीशब्, _güçt, _קצף_
  { {0x3205003e,0x0000006a,0x0000006a,0x0000006a}},	//   atly_,   ,   ,
  { {0xdefb008f,0x389b0053,0xdfd00015,0x6d930f85}},	//   шым_, ייכנ, ئيّ_, nçav
  { {0x32050041,0xd250003b,0x6d580091,0x7d6b0004}},	//   ctly_, _سنة_, _įvar, ашав_
  { {0x6ecb014e,0x5cb90010,0xd1310015,0x865b000a}},	//   _त्रु, слаў_, _أمة_, בדלי
  { {0x4c940080,0x351b0008,0x0cab0585,0x0000006a}},	// [1b50] дитс, סומנ, ртви_,
  { {0x7f190086,0x3378000a,0x5b14004a,0x7bcd129c}},	//   _ايدز_, צְּב, ммут, rpau
  { {0x7bcd0780,0xdb0e00dc,0x99870089,0xdb05002d}},	//   spau, óján, ínů_, nmhé
  { {0x7bcd00f2,0x828b000a,0x9b45002b,0x58d4005e}},	//   ppau, בְדֶ, _کنسو, доцт
  { {0xdd3a0008,0x5d3a0008,0x3d3a0008,0x97c40015}},	//   _הערכ, _התרא, _הגרס, وتوم
  { {0x70b7005d,0xfbd2000a,0x9f530003,0x32050046}},	//   ःशुल, _אתך_, écès_, ytly_
  { {0x6446019a,0x0000006a,0x0000006a,0x0000006a}},	//   äkin,   ,   ,
  { {0xea000016,0x9e7c000a,0x6d93016e,0xab5b02ad}},	//   _hiếp_, ינופ, açav, _stüh
  { {0xf3f10029,0xc5680029,0xb7d50087,0x5fb7000b}},	//   رأة_, تحول_, _رقاب, _इंगल
  { {0x6d5a0024,0xe7330015,0xdce40061,0x8c1a000a}},	//   ītai, _تصر_, kniğ, צותי
  { {0x83640015,0x95570015,0x3d0c0065,0x672e0052}},	//   بديل, _وخصا, ड्डे_, _óbja
  { {0xd24e0029,0x3205003e,0xa5c6002e,0x9f4201b2}},	//   انَ_, rtly_, slóð, mské_
  { {0x3205031c,0x9f4201b2,0x659a000a,0x40960033}},	//   stly_, lské_, _פינק, ярот
  { {0x320500da,0x80cc000b,0x657b007c,0x2c190065}},	//   ptly_, _थ्रे, lnuh, _नैइं_
  { {0xd24e0086,0x6da6129d,0x9f420107,0x2bb5000b}},	//   _منو_, зива, nské_, _अंजा
  { {0x3cf6005d,0xf8b90092,0xc6920053,0xad39005e}},	//   इलें_, _ngũ_, גאל_, очує_
  { {0xfbd10029,0x81a50002,0x27e910ca,0x60fb000a}},	// [1b60] َتْ_, _تحول, šanj_, _ההפק
  { {0x8b26008f,0x8b230080,0x0c790010,0xed16002a}},	//   ядзе, ндуе, істы_, _łódź_
  { {0xdebb0008,0x69da0029,0x3ebb0008,0x9f420107}},	//   _למיל, صباح_, _לציב, jské_
  { {0xf9690036,0x9f420107,0xf99200e6,0xa2f9000b}},	//   орій_, dské_, ربا_, ्भुज_
  { {0x18180086,0x28cb000b,0x9f420046,0x3d05000b}},	//   تراک_, ाड़ि, eské_, _हॉटे_
  { {0xbb4a003b,0x38330033,0xcff7000a,0x7bcb129e}},	//   _الآن_, энір, פצצה_, ígue
  { {0x6b52002e,0xf62a005e,0x442f129f,0x4ae10065}},	//   _nægi, сіли_, _arg_, _फ़तव
  { {0xa8240086,0xd90d0086,0xceb3000f,0x4a7b000a}},	//   _يکشن, _نیم_, עיה_, _הרלב
  { {0x9f5912a0,0xdc3a005e,0x6d4412a1,0x0000006a}},	//   ltså_, ицiї_, ijia,
  { {0x325412a2,0x87250015,0xd8770015,0xdb1d016e}},	//   двор, _يعلم, _عملت_, _ausê
  { {0x442f0161,0xc7b3000a,0x27e612a3,0xdb210030}},	//   _erg_, _נבע_, lson_, ötés
  { {0x463b0053,0x55bb01d8,0x3cf6000b,0xa63b000a}},	//   _לעבע, _המאו, इलों_, _לגבר
  { {0x90540010,0xdb0e002d,0xc953000a,0xc05800fd}},	//   евяц, _aibí, גמר_, пір_
  { {0xd3700086,0x68e20026,0x27e60252,0x2327004a}},	//   _جهت_, haod, ison_, _ночи_
  { {0xdd950010,0x639b000a,0x26de12a4,0x539b004f}},	//   давы, _הסגנ, _meto_, _היגו
  { {0x5d99008f,0x127b0053,0x26de0844,0xebd9006b}},	//   ікаў_, _לאוע, _leto_, ждаш_
  { {0xcfe80015,0x7bc00003,0x68e20091,0x9f420046}},	// [1b70] _ففيه_, _émul, daod, zské_
  { {0x7b770029,0x3213005c,0xfaa703e3,0x6d560509}},	//   أطرا, łbyś_, пшен, akya
  { {0x98bf04f9,0x7055002b,0x49d9005e,0x61fa12a5}},	//   _nouă_, _رنگا, іддю_, nutl
  { {0x1a680086,0x9f420107,0x6d5600da,0xdb060012}},	//   سیقی_, vské_, ckya, _zukü
  { {0xea000023,0x7b0200f2,0x7d0d12a6,0xf0b8004f}},	//   _tiếp_, äytö, mfas, פלגר_
  { {0x9f420107,0x7c2d12a7,0xdc3a000a,0xbae50015}},	//   tské_, mvar, _ועשר, _زكري
  { {0xa3df005d,0xe7080115,0xcb12000a,0xe619005e}},	//   धीन_, ستون_, _שלל_, іди_
  { {0x98bf04f9,0xce380008,0x9f420107,0xd4d9022a}},	//   _două_, לאות_, rské_, цькі_
  { {0xbcfb00dc,0x7d1a000a,0xf5920015,0x61fa0012}},	//   _elég, חֵיה, خليج, eutl
  { {0x9f420089,0xa7740010,0xdb1d0123,0x5275005e}},	//   pské_, _злуч, _utsä, думу
  { {0x6d5d0064,0x7c2d007c,0x7d0d12a8,0x4254110d}},	//   _olsa, hvar, kfas, етят
  { {0x6560002d,0x442f0796,0x2d680061,0x7c2d12a9}},	//   chmh, _trg_, nşet_, kvar
  { {0xcfaa00a2,0x995c04b2,0xdb0e006f,0x26c7002a}},	//   قاسم_, níš_, _sibí, ocno_
  { {0x03d60008,0xdfcf00e6,0xb3ba000a,0x671d000b}},	//   _חוסם_, شيف_, _ומסכ, फ़िक_
  { {0xe6070086,0x7d0d00b8,0x490e000b,0x7975002a}},	//   خش_, ffas, ण्डो_, nąws
  { {0xf8a50086,0x78bb003f,0x752912aa,0xada30033}},	//   _مک_, _nguv, ndez, васл
  { {0x9f52002e,0x7125012c,0x75290012,0x9f86005e}},	// [1b80] ðbót_, _سريل, idez, _огид
  { {0x7d0d003f,0x0aea005e,0xda660015,0xeb9f00cb}},	//   afas, ідей_, واضي, _spør_
  { {0x0f5704dc,0x2fc0002d,0xb9060033,0xd94612ab}},	//   _חיים_, _huig_, дзек, межи
  { {0x442d010b,0x3cfa0015,0x27e612ac,0x6f1c12ad}},	//   kve_, _بعدد_, tson_, lerc
  { {0x510d0053,0x48e312ae,0x907b004c,0x8b660067}},	//   מהאַ, точв, ֿטצי, _قاسم
  { {0x64460020,0x61fa0064,0x442d0eed,0xe9da0165}},	//   äkim, yutl, dve_, _мкг_
  { {0x27e612af,0x65940033,0x657e0003,0x442d12b0}},	//   sson_, наку, épho, eve_
  { {0x4d5b004c,0x61fa0061,0x6f1c12b1,0x442d12b2}},	//   ַדיצ, vutl, herc, fve_
  { {0xea000092,0x26de0794,0x15ea000b,0x7c89000a}},	//   _khắp_, _teto_, _टिकर_, ּאתִ
  { {0x6d9312b3,0xc726005e,0x6f1c0077,0x61fa01c2}},	//   nçar, _ідей, jerc, tutl
  { {0x7d0d01e2,0xe3af0029,0x442d12b4,0xf7430658}},	//   yfas, جري_, ave_, _шефо
  { {0x316b005e,0xdb1d0003,0x88bd002a,0x7c2d0091}},	//   ішно_, _eusè, _naśl, yvar
  { {0x232a0098,0xc4560015,0x5fd90065,0x236a0058}},	//   _моди_, _تضاع, _बौखल, _وحتي_
  { {0x69c300dc,0xcddb0001,0x5f450015,0x68e001d7}},	//   ínek, жња_, رنزل, _lemd
  { {0x42fb0008,0x12fb000a,0x02fb000a,0x6e940d22}},	//   _והוס, _והוב, _ולומ, виру
  { {0x672800bd,0x7c2d12b5,0x91870015,0xbcfb12b6}},	//   _ladj, tvar, _تجتم, _amér
  { {0x7d0d00b8,0x25a6002d,0xdd9401b0,0x7c2d12b7}},	// [1b90] rfas, _mhol_, таты, uvar
  { {0x672812b8,0x6f1c12b9,0x38660796,0x1f7412ba}},	//   _nadj, cerc, dzor_, _алья
  { {0xfe350053,0x442d12bb,0x6b52001a,0x644605ff}},	//   _װאָך_, zve_, _nægu, äkij
  { {0xdb1d0152,0x6d9312bc,0x8aa412bd,0x442d12be}},	//   _musé, rças, труд, yve_
  { {0x27e912bf,0xe73912c0,0x8d5a000f,0xf9900015}},	//   éan_, зел_, _זכרי, جبل_
  { {0x25a60014,0x9f590152,0xd822004a,0x394612c1}},	//   _ahol_, fusé_, удши, ajos_
  { {0xe6110074,0x69dc0026,0xdb05002d,0xf7700002}},	//   اشت_, _gwre, nmhí, جان_
  { {0x442d12c2,0x94250549,0x6f1c12c3,0x14250a0b}},	//   tve_, емие, zerc, едим
  { {0x442d038d,0xdb0e00dc,0x752900dc,0x395f0020}},	//   uve_, _hibá, rdez, _ilus_
  { {0x6298020a,0x291d000c,0x7ae501e2,0x13090892}},	//   _byvo, lewa_, naht, чной_
  { {0x06380015,0x9f590003,0xf2e6002b,0x63b812c4}},	//   _يسمع_, cusé_, رکوه_, _divn
  { {0x04c80015,0x99f6000a,0x1a16004c,0x291d0cc1}},	//   _قومي_, עזרה_, ײַטש_, newa_
  { {0xdbd70209,0x394d12c5,0x9359005e,0x25ad12c6}},	//   _jäät, _moes_, _нрку_, mmel_
  { {0x291d003f,0x7ae50049,0x25ad007c,0x75ca002a}},	//   hewa_, jaht, lmel_, _węze
  { {0x291d003f,0x4279004c,0xdbd7007c,0x4252002b}},	//   kewa_, _מאַג, _läät, _منور
  { {0xa0a60033,0x6f1c12c7,0xa00a0015,0x291d002a}},	//   _пайд, serc, _فقبل_, jewa_
  { {0x68e00007,0xdde30024,0xac86071f,0xc4d2000a}},	// [1ba0] _remd, ērša, хгал, טגן_
  { {0xe6250023,0x6b520134,0x395f12c8,0xddce0030}},	//   _đông_, _nægt, _alus_, szbő
  { {0xfce612c9,0x4ae1005d,0x68e000e8,0x6edb000a}},	//   _поно, _फ़रव, _pemd, _מחיפ
  { {0x70770086,0xab5b00b8,0x02b60053,0x394d0034}},	//   _آمیز_, _stüt, גלעך_, _coes_
  { {0x394d0495,0x2d8012ca,0xea000016,0xdc760033}},	//   _does_, mnie_, _thắp_, _чынь
  { {0x2d800dbf,0x395f0020,0x58370010,0x9c0b000a}},	//   lnie_, _elus_, эзія_, _מִלִ
  { {0x56930185,0x69ce0b56,0x394d00da,0x63b80123}},	//   лашт, _utbe, _foes_, _rivn
  { {0x394d00ea,0x291d0375,0x2d8012cb,0xa5340719}},	//   _goes_, cewa_, nnie_, тнич
  { {0x2d8012cc,0x672812cd,0x15130138,0x63b812ce}},	//   inie_, _tadj, удыя, _pivn
  { {0x2129003f,0xd62a067a,0x7c3b12cf,0x2d8012d0}},	//   _saah_, _нозе_, _áure, hnie_
  { {0x7d0601d1,0x6fa7005d,0x74140086,0x2d80005c}},	//   _ocks, _गठबं, روگا, knie_
  { {0xea000023,0x25d90086,0x2d80005c,0x62980107}},	//   _nhập_, _آهنگ_, jnie_, _vyvo
  { {0x2d800050,0xbfab0033,0xa5690015,0xe58b000a}},	//   dnie_, зтве_, _تصلك_, _צָבָ
  { {0x2d800050,0xab640064,0x291d12d1,0x200b0085}},	//   enie_, nlüğ, zewa_, rtci_
  { {0xbe8812d2,0x6e95005e,0x6b52001a,0x7ae501be}},	//   есте_, тиву, _lægs, vaht
  { {0xe29b0008,0x5eb40080,0x929b000a,0x429b000a}},	//   _משור, уйст, _מיות, _מסוב
  { {0x7ae50020,0xacf80010,0xab640061,0xe58b000a}},	// [1bb0] taht, энту_, klüğ, לָמָ
  { {0x2d80005c,0xdbd7008c,0x7c2602de,0x200c0045}},	//   anie_, _räät, _dskr, ădit_
  { {0xf7710086,0x2d80005c,0xdbd700f2,0x395f0493}},	//   یات_, bnie_, _säät, _plus_
  { {0xdbd7022d,0xd879003b,0x2d800050,0x88bd002a}},	//   _päät, ومات_, cnie_, _taśm
  { {0x7ae5022d,0xbcfb0896,0x98e40058,0x49b8009a}},	//   paht, _eléc, اكهو, رامد_
  { {0x291d12d3,0xbcfb0003,0x23a2001a,0x6d4f0061}},	//   sewa_, _fléc, yðja_, _hoca
  { {0x291d000c,0x86980063,0xc9770029,0x7f2c000a}},	//   pewa_, нтът_, _كارث, לֵהֶ
  { {0x1da7005d,0xd5ae0015,0xdb080030,0x395f0fc7}},	//   _कीमत, يفو_, ülöt, _ulus_
  { {0x42d50010,0xe4c80002,0x25ad128a,0xc9840ac9}},	//   кіну, ربين_, rmel_, _сури
  { {0x6b52002e,0x98740010,0x2d80062e,0x8c1c000a}},	//   _hægr, _слуц, znie_, לוחי
  { {0x36d4005f,0x2d800050,0x96ca005d,0x442612d4}},	//   _сохр, ynie_, _स्टॉ, _eso_
  { {0x27e90048,0xf8c1005d,0x27ed12d5,0x29020123}},	//   šanu_, एशिय, _kven_, _ökat_
  { {0x25fd005d,0xd24e0086,0xe588000a,0x2d9212d6}},	//   रूरी_, منی_, _אָסָ, voye_
  { {0x6b52002e,0x2d8007e9,0x3ebe00cb,0xa856004f}},	//   _lægr, wnie_, øtt_, דישה_
  { {0x2d800dbf,0xdee30818,0x1ec70099,0xdd920040}},	//   tnie_, роси, тлси_, لوس_
  { {0x27ed0838,0x6dbc12d7,0x1602000b,0x106a0015}},	//   _oven_, _sčas, रंतर_, _يحظى_
  { {0x9cb30015,0x2d8012d8,0x752b0030,0xd197004f}},	// [1bc0] لمفت, rnie_, _magz, _שכפי_
  { {0xab5b00b8,0x2ca70004,0x998d07c4,0x6b6312d9}},	//   _stür, ткуп_, _češ_, акуа
  { {0x6d4f002f,0xeb970124,0xea000092,0x48e605c4}},	//   _foca, њих_, _thập_, воев
  { {0x81bc0024,0xb8f30015,0xba1700c3,0x0000006a}},	//   ovēr, لكمب, ضيها_,
  { {0xf746019c,0x7c2612da,0x7a130046,0x4c83006b}},	//   кедо, _uskr, větš, _вляв
  { {0x7bd6000c,0x7d0412db,0x0000006a,0x0000006a}},	//   mpyu, lgis,   ,
  { {0x27ed12dc,0xab640064,0x7c240012,0x0f7b000a}},	//   _even_, rlüğ, lwir, ורסל
  { {0xa5070054,0x83fd0030,0x6995005e,0x7d0412dd}},	//   већа_, mzőj, _брух, ngis
  { {0x7c2400b8,0x14180015,0x7d0404d2,0xe4a3005e}},	//   nwir, ريدة_, igis, ирьо
  { {0x442600bd,0xdb05002d,0xa2630092,0x43940004}},	//   _vso_, omhá, _trố, ѓанс
  { {0x7982005c,0xa2660063,0x81bc0024,0xd6390010}},	//   onow, тъпл, evēr, _пяці_
  { {0xd5e90029,0x92570080,0xaaa7000b,0x4273110d}},	//   _أعلن_, тают_, केटक, ргюс
  { {0xf8db000a,0x7645008c,0x442612de,0x7982002a}},	//   וחכמ, ähyv, _uso_, inow
  { {0xc7b40053,0x6ae1000b,0xc7b1000a,0xf8b3000a}},	//   רבֿ_, _फ़ेर, ֶ֑ם_, ישר_
  { {0x7982003e,0x44240026,0xd37812df,0xbcfb0003}},	//   know, lwm_, mić_, _aléa
  { {0x7982005c,0x2d550134,0xd37812df,0x9f590057}},	//   jnow, _nået_, lić_, musí_
  { {0xd0110021,0x3179002a,0x81bd003d,0x7982002a}},	// [1bd0] _الخ_, misz_, svēs, dnow
  { {0xf0e3005d,0x765800f2,0xd37812df,0x20e3000b}},	//   _ख़ुद_, kyvy, nić_, _ख़ुश_
  { {0xdb05002f,0xfdb90758,0x44240034,0x3f830085}},	//   gmhá, _площ_, hwm_, mnju_
  { {0x7982005c,0x317912e0,0xc27b000a,0xbcfb0003}},	//   gnow, nisz_, ורבי, _fléa
  { {0xbcfb002d,0x9f420107,0xbbeb0015,0x97c40015}},	//   _gléa, lská_, _ترجم_, لقنو
  { {0xf094000a,0xd3780085,0x9f590046,0x7982002a}},	//   סנס_, jić_, kusí_, anow
  { {0x2d550134,0xd378016f,0x9f420057,0x95c5002b}},	//   _fået_, dić_, nská_, ديبه
  { {0xc3d90036,0x81bd0024,0xdb1d04af,0x2d550134}},	//   ньої_, zvēr, _musí, _gået_
  { {0x54350074,0xe7050086,0xb8e9005d,0xd37812da}},	//   اربر, _مسای, ोड_, fić_
  { {0x290200c0,0x399c002e,0x6ae1000b,0x82350015}},	//   _ökar_, vísi_, _फ़ोर, هرجا
  { {0x3f83016f,0x3179005c,0x9f420264,0x65620eb3}},	//   dnju_, fisz_, jská_, _floh
  { {0xf530003b,0x44240176,0x74120086,0x3cfd005d}},	//   _وإن_, bwm_, جویا, एलों_
  { {0xa3df005d,0x81bd0024,0xd37812e1,0x61fa12e2}},	//   धीश_, tvēr, bić_, artl
  { {0xd3780050,0x40850001,0x92650015,0x7982002a}},	//   cić_, руџб, _مدعم, znow
  { {0x7982005c,0x81bd0024,0x31790fce,0x51f50015}},	//   ynow, rvēr, bisz_, _إستر
  { {0x3179005c,0x81bd0024,0x127a0053,0x6ae1000b}},	//   cisz_, svēr, _ראקע, _फ़ॉर
  { {0xfafa0015,0xeafa00c3,0x3f830085,0x8c430099}},	// [1be0] فراغ_, فرات_, bnju_, бете
  { {0x7982005c,0x7c2412e3,0x4f26006b,0x83fd0030}},	//   wnow, rwir, _сдоб, ezők
  { {0x7c2412e4,0x6f7b000a,0xe8fa062a,0xed5a0a66}},	//   swir, _רְחו, еле_, _зон_
  { {0xd3780050,0x88e60457,0x329a004c,0xea000016}},	//   zić_, ужде, ײבנד, _chạp_
  { {0xe3c80092,0x7982005c,0x83fd00dc,0x200212e5}},	//   _mực_, rnow, szőj, nuki_
  { {0xe3c80023,0x7982002a,0xdbd2007c,0xfe36000a}},	//   _lực_, snow, _müüt, ָרֵי_
  { {0xd378010b,0x6b6312e6,0x15f30029,0xd6d90036}},	//   vić_, _укра, مسيح, тті_
  { {0x44240176,0xd3780050,0x7bc612e7,0x20020061}},	//   twm_, wić_, _kuku, kuki_
  { {0xe6440064,0x88860001,0xd378016f,0x7bc6055a}},	//   ılığ, _слаж, tić_, _juku
  { {0x3179005c,0x44240026,0x61fa00bc,0x33740a1f}},	//   wisz_, rwm_, trtl, ргор
  { {0x44240026,0xd378016f,0x7bc60201,0x85060087}},	//   swm_, rić_, _luku, _موان
  { {0x6ae1005d,0xe3c80092,0xf1ab0018,0xd37812df}},	//   _फ़्र, _cực_, عاده_, sić_
  { {0xf5930029,0x69c10152,0xd37812e1,0xb4c2000b}},	//   _النج, _élev, pić_, ्डी_
  { {0x31790050,0x9f420057,0x8cba000b,0x1ee7002b}},	//   sisz_, tská_, ्शनो, طوری_
  { {0x31790050,0x5237002b,0x139b000a,0x3f830085}},	//   pisz_, _مسيح_, _רבוע, rnju_
  { {0x9f420057,0xac190054,0x27e001c0,0x7bc612e8}},	//   rská_, кобу_, šiny_, _buku
  { {0x3f83016f,0x7bc6013c,0xbb7501ca,0xab7512e9}},	// [1bf0] pnju_, _cuku, агај, агаш
  { {0x9f420089,0x7bc612ea,0xa3e6000b,0x88bd002a}},	//   pská_, _duku, यीय_, _zaśw
  { {0xb60a0010,0xcb080015,0x75c30030,0x8f9c000a}},	//   _жнiв, ايمن_, _kőze, _איזי
  { {0xdc340227,0x4dda000a,0x2d99007c,0xddc7002a}},	//   _zúča, _שחרו, _ukse_, zyjś
  { {0x83fd0030,0x88c8005e,0xe72e12eb,0xc8af000b}},	//   rzők, улів_, ое_, जेंट
  { {0x6d4d0020,0x2b14005d,0x77840033,0xabfa000a}},	//   ljaa, न्दु_, бліз, _בהשר
  { {0xcf580008,0xf1c90092,0x7bc600b8,0x0f58000a}},	//   רבות_, _mạc_, _zuku, ריום_
  { {0xf1c90023,0xdb1d016e,0x7ae70046,0xdd210046}},	//   _lạc_, _fusã, _hejt, _lůžk
  { {0x68eb0035,0xe3c80016,0x6d4d008c,0x87070040}},	//   magd, _rực_, ijaa, _مبال
  { {0x466b0036,0xdced0064,0x69c7003f,0xdbd2007c}},	//   _прем_, ynağ, _kuje, _rüüt
  { {0x38ba01e2,0x6723065d,0x75d10024,0xdbd20020}},	//   _türü_, menj, _bāze, _süüt
  { {0x27e004f9,0x69c702c1,0xdc34002c,0x68eb0035}},	//   ţine_, _muje, _súča, nagd
  { {0xe3c80023,0xf1c90092,0xfc3f00dc,0x660312ec}},	//   _vực_, _bạc_, _szín_, lunk
  { {0xc4840010,0x8f75005e,0x23ab02de,0x7ae70046}},	//   _улік, бусі, føje_, _nejt
  { {0x7bc61203,0x20020049,0x93940067,0xbcfb0003}},	//   _suku, suki_, _اجنا, _cléo
  { {0x8234002b,0xdbd2007c,0x64460123,0x5f76002b}},	//   _درها, _tüüt, åkig, _چادر

  { {0x68eb00b6,0x5f760002,0x672312ed,0x31570002}},	// [1c00] dagd, _نادر, kenj, _خليج_
  { {0xaae50029,0xdb590036,0x6723060b,0xaaba0086}},	//   مسمو, лює_, jenj, ندار_
  { {0x6723018c,0x66030007,0x4efb009d,0x7ae712ee}},	//   denj, junk, _בהיו, _dejt
  { {0xe3c80023,0xd9100086,0xd7fa0010,0x3f9812ef}},	//   _lựa_, ثیر_, вук_, loru_
  { {0x386012f0,0xd8f7005e,0x7ae70030,0xf9890015}},	//   áir_, рнії_, _fejt, دخله_
  { {0x2b03005d,0xa037000a,0xa773005e,0x672312f1}},	//   _लाएँ_, יאנה_, оліч, genj
  { {0xf62a0036,0xf6e50010,0xfb1b000a,0x25fd000b}},	//   тіли_, сцін, _שולמ, रंगी_
  { {0xa6e90023,0x3f980089,0xb4c2005d,0x8e57000a}},	//   _ngươ, horu_, ्डे_, ייצג_
  { {0x65880089,0x5346006b,0x5398006b,0x06f6002b}},	//   běhn, ахна, лвия_, _نساج
  { {0xdb150014,0x44970080,0x672301a3,0xaaaa000b}},	//   _kizá, рвью_, cenj, _कराक
  { {0x69c10014,0xe3c80092,0x6603005c,0xa15906f6}},	//   _élet, _dựa_, cunk, гану_
  { {0x2c5e0024,0x867b000a,0x506701f3,0x6446014b}},	//   _kādā_, _ברבו, атга, äkis
  { {0x938a0063,0x3d0a000b,0x69c012f2,0x19b7000a}},	//   _иска_, िलने_, _mime, יפטר_
  { {0x69c012f3,0x939300a2,0xc43b000a,0x3f9812f4}},	//   _lime, _وجوا, _שתגי, goru_
  { {0xdef8008f,0x7ae70694,0xa187054f,0x7db70015}},	//   шыя_, _rejt, _выпл, لصرا
  { {0x69c012f5,0x67230b6c,0xb2bb000a,0x7ae70030}},	//   _nime, zenj, _במור, _sejt
  { {0x2ac70001,0x31580008,0x65a500dc,0x7ae702de}},	// [1c10] аљев, _כיהן_, zóho, _pejt
  { {0xa4b70008,0x69c012f6,0x9b880015,0x09f70015}},	//   שלמה_, _aime, لنقل_, لأصد
  { {0xc8790045,0x5e590c30,0xfaf00015,0xd9f90033}},	//   _ieşi_, _синя_, بثق_, унец_
  { {0x4998005e,0xf7f50015,0x2c07000b,0xb4c2000b}},	//   атія_, مستد, िंदू_, ्डो_
  { {0x68eb00b6,0x7ae7002c,0x68270080,0x21380053}},	//   ragd, _tejt, рьез, יטאל_
  { {0x660312f7,0x21cc0046,0x69c700bc,0xa7a901b0}},	//   tunk, _něho_, _tuje, ыкла_
  { {0x6723010b,0x68eb0035,0xd6ce0015,0x69d50012}},	//   renj, pagd, رقي_, _utze
  { {0x9985003b,0xe616008f,0x19940010,0x660312f8}},	//   _الرو, ёды_, _дася, runk
  { {0x681a0048,0x443912f9,0x67d4005e,0x660312fa}},	//   gādā, ís_, _моту, sunk
  { {0xe730003b,0x69c0000c,0xb4e6005d,0x75d50015}},	//   _يصل_, _zime, _बड़ी_, _هيئا
  { {0xcb120008,0x69c100dc,0xb6350002,0xb063008c}},	//   הלי_, _éles, _دفاع, ääns
  { {0x3f980305,0x35b5030c,0x0000006a,0x0000006a}},	//   woru_, _убер,   ,
  { {0x55ba000a,0x3438002b,0xdf76002b,0xbcfb0003}},	//   _עמנו, _پسند_, مدآب, _clém
  { {0x50d8005d,0x20f80092,0xf1cf000b,0x8235002b}},	//   _भ्रष, ọi_, _संपन, _هربا
  { {0xc8790011,0x59b9005d,0x25fd005d,0x03ac000a}},	//   _deşi_, ेदार, रंटी_, _שׁוּ
  { {0x68e9003e,0xbf9b001c,0xc6920135,0x3f9812fb}},	//   _need, quên, פאן_, soru_
  { {0x7d160026,0x7ff60115,0x3f9810d6,0xe0d7004a}},	// [1c20] rfys, _اسبا, poru_, _увы_
  { {0x290d0011,0xaf0609c3,0x69c012fc,0x0000006a}},	//   _acea_, _упол, _sime,
  { {0xcf5701e4,0x0f570053,0xfbc9000a,0x637a004c}},	//   _הבית_, _היים_, תת_, נװעס
  { {0xb4e6005d,0xea000092,0xc7c612fd,0xbd460058}},	//   _बजे_, _nhấp_, бски, _انحي
  { {0x69c00a72,0x68e9055e,0xad37000a,0x8f9a000a}},	//   _vime, _deed, _הנכס_, ְיֶי
  { {0xaa460579,0xc448002b,0x07b70015,0x681a003d}},	//   _легл, ییان_, مهنة_, vādā
  { {0x1b7b0053,0x65880089,0x6b630256,0x68e912fe}},	//   _עטלע, běhl, _экра, _feed
  { {0xea000023,0x2c5e0024,0x32050057,0xb5aa0015}},	//   _chấp_, _tādā_, duly_, داتك_
  { {0x786605ae,0x23b40015,0x3ce90065,0x0000006a}},	//   _указ, يمبس, जरते_,
  { {0x681a0048,0xd7ef0015,0x3f72003d,0xe80d0065}},	//   rādā, _أكل_, iņus_, _समता_
  { {0x6b9b0053,0xcb9b039e,0x62660040,0x75d300c3}},	//   רשיד, רסיט, صادق, _فيلا
  { {0x3abb000a,0xa0b90054,0x31c30033,0xb063008c}},	//   טמינ, игну_, ясьв, ääos
  { {0xf8ba005d,0x91ca000b,0x5436002b,0xdc1d01ec}},	//   ेशिय, _संवै, _درار, kņāt
  { {0x995c0089,0xbed400af,0x98a40073,0x0000006a}},	//   jíž_, зорј, _gamą_,
  { {0xf1c90023,0x15f80008,0x1317000a,0x234b002b}},	//   _hạn_, יִּמ, _החול_, _حسنی_
  { {0x2fc90026,0x9d150033,0x0dc812ff,0x0000006a}},	//   _tuag_, ўдач, сури_,
  { {0x68e91300,0x8fa50015,0x9b450015,0x83fd0030}},	// [1c30] _reed, _ومعه, ينرو, szőv
  { {0x9aab0029,0x68e90100,0xf1c90016,0x7c840099}},	//   هداف_, _seed, _mạn_, чусе
  { {0x6aba001a,0x799900aa,0x9d191301,0x3ea70030}},	//   _útfl, toww, _конт_, _ánt_
  { {0xad270087,0xe919005e,0x8ed8002b,0x49b8006e}},	//   _اردو, роді_, _پذیر_, ماند_
  { {0xf1c90092,0xb4e6005d,0x68e91302,0x98a9006f}},	//   _nạn_, _बड़े_, _veed, ľaď_
  { {0x6d810048,0x7c2f1303,0x45d502b0,0x8c1a0643}},	//   rķau, _iscr, оцит, _דושי
  { {0x68e91304,0x27e0003d,0x5eec000a,0x636d0e51}},	//   _teed, ģina_, אַחְ, _húng
  { {0xf1c900a7,0xf7730074,0x160b014e,0x25b60029}},	//   _bạn_, _کار_, संबर_, يهود_
  { {0xfb57000a,0xf1c90016,0xe4560033,0x6d5a0003}},	//   ֶׁ֛ר_, _cạn_, жжы_, êtai
  { {0x23b20086,0x4374034e,0xf1c90016,0xf8ae002b}},	//   وميس, зуют, _dạn_, _شکن_
  { {0xea000023,0xe1261305,0x0000006a,0x0000006a}},	//   _thấp_, омни,   ,
  { {0x2613001c,0xd1c60010,0x24190afa,0xe4cb0015}},	//   mão_, ўляе_, _воды_, _إبان_
  { {0x2613001c,0x7c2f1306,0x490e0065,0x23750369}},	//   lão_, _nscr, ण्टो_, _واتح
  { {0x7f750010,0x5334004a,0x2613016e,0x88ba000a}},	//   пусц, _нечт, oão_, יזרי
  { {0x3ebe1307,0x2613001c,0x7c2f1308,0x539a000a}},	//   ätt_, não_, _ascr, _דיסו
  { {0x9f42006f,0xd012006e,0x75f00030,0x3cf60065}},	//   nskú_, _قلع_, _hózá, ेलें_
  { {0x3cd90010,0x636d002d,0x8fe60015,0xdca30a6c}},	// [1c40] сьсю_, _cúng, _بأعم, дати
  { {0x8a3a0080,0x8b260010,0x1dd2000b,0xf093000a}},	//   ияет_, юдзе, _दंपत, _קנז_
  { {0x2d9e0003,0x7c2f1309,0xf1c90016,0x2613016e}},	//   îtes_, _escr, _mạo_, jão_
  { {0x2613001c,0xc8790045,0x9f42006f,0x8c4601e1}},	//   dão_, _leşu_, jskú_, _деме
  { {0x6d46130a,0x274a08c9,0x443d02ad,0x9f42016d}},	//   _inka, ичко_, _nrw_, dskú_
  { {0x2613016e,0xdb1d0061,0xd7570015,0xa09b000a}},	//   fão_, _rusç, يلنت_, סיסט
  { {0x2613001c,0xf1c90092,0x6725007c,0x443d0034}},	//   gão_, _sạn_, õhja, _arw_
  { {0x69de00f2,0x5454130b,0xaa77000a,0xa9230054}},	//   mppe, звит, _ותלד_, _одсл
  { {0xf1c90092,0xe947002b,0x68e2130c,0x1867130d}},	//   _bạo_, _ظرفی, mbod, _дати_
  { {0x8c1b0008,0xf1c90016,0x2613016e,0x2d680061}},	//   סויי, _vạn_, bão_, rşey_
  { {0x8b030089,0x2613001c,0xbb3b000a,0x443d0034}},	//   _úřed, cão_, בעיי, _erw_
  { {0xdb1d00b8,0x69de0c0a,0x3cf6000b,0x68e20c0c}},	//   _zusä, ippe, ेलों_, nbod
  { {0xf5770015,0x5067005e,0x2606000b,0x107402ed}},	//   _بمنع_, ітма, सूरी_, дляю
  { {0xf1c90092,0x83fd00dc,0x42560015,0x925a0015}},	//   _gạo_, rzőt, _ونشر, _نشعر_
  { {0xcdd80001,0xd5d8000a,0xa5d805bd,0x9dbb00c3}},	//   жњу_, מַּש, מַּי, لدرز_
  { {0xd6570008,0xdb1c0077,0x31690085,0x7c87130e}},	//   חילת_, _dirí, _ulaz_, оузе
  { {0x2613001c,0x2b58130f,0xfbd00067,0x68e20012}},	// [1c50] zão_, _borc_, نتل_, dbod
  { {0x6a670029,0xfaa71310,0x1aa70054,0x8aa70cab}},	//   يطال, ошен, ојег, оред
  { {0x2613001c,0x539b0008,0x7e2b00ce,0x0000006a}},	//   xão_, סיבו, _тіпа_,
  { {0xdeb6013a,0x49c80010,0x2613016e,0x7e9a000a}},	//   _מפתח_, ілін_, vão_, _לסתו
  { {0x9f42002c,0x9cd60008,0x78270015,0x8ca2000b}},	//   vskú_, _מורה_, تعال, _कुपो
  { {0x261303af,0x6fdc0053,0xd2460029,0x4cba000a}},	//   tão_, סקוס, _كن_, _לזרו
  { {0xa955005e,0x9f42006f,0x4efc000a,0xf993012c}},	//   _екві, tskú_, בלוג, _قبر_
  { {0x261303af,0x7d0d1311,0x7c2d1209,0x361800ce}},	//   rão_, ngas, owar, юцію_
  { {0x261303af,0x9f42006f,0xbcfb0125,0x7c2d1312}},	//   são_, rskú_, _cléi, nwar
  { {0x2613001c,0x31b6000b,0x7c2d01c2,0x0000006a}},	//   pão_, ृद्ध, iwar,
  { {0x636d002d,0xe6100015,0xe2991191,0x7c2d1313}},	//   _rúnd, _لشن_, сан_, hwar
  { {0x661c007c,0x225804d6,0x7c2d1314,0xf8cb0065}},	//   _ärka, ärka_, kwar, िशिय
  { {0xf1c90023,0x645d00b8,0xa4870029,0xd7880092}},	//   _tạo_, äsid, _بجان, iển_
  { {0x442d003f,0x69de00f2,0x54560008,0xe1f10015}},	//   mwe_, yppe, _מסנן_, _كسب_
  { {0xf2d200b2,0x442d00dd,0x68e20495,0x7c2d1315}},	//   _טעג_, lwe_, ybod, ewar
  { {0x7d0d0035,0xfc3f002d,0x3cca0001,0x442d1316}},	//   ggas, _brí_, слао_, owe_
  { {0xed57000d,0x2bba0029,0x7c2d1317,0x2b581318}},	// [1c60] чот_, مائة_, gwar, _porc_
  { {0x103b0008,0xf1c90092,0x2f150030,0x4c83006b}},	//   _פגיע, _lạm_, rúgó_, хлув
  { {0xa9261319,0x7c2d131a,0x2f5b000a,0xaf5b000a}},	//   здел, awar, _הדינ, _הכיכ
  { {0xc7c60e88,0x31b201b2,0xcb09000a,0xd884002b}},	//   пски, báze_, טל_, وهای
  { {0x6d3b0008,0x0734005e,0x68460033,0xe7f5000b}},	//   _התכנ, делю, янда, ुंगा_
  { {0xe3a703c4,0x501b0008,0x656b131b,0x442d0034}},	//   _سر_, מונו, _algh, dwe_
  { {0x442d131c,0xbcfb0125,0x0000006a,0x0000006a}},	//   ewe_, _sléi,   ,
  { {0xb06300f2,0x15130080,0xbcfb0c1b,0x69ce0045}},	//   ääks, едъя, _pléi, _iube
  { {0xe3af002b,0x7ae30030,0xa3e6000b,0x7982002a}},	//   گري_, űnte, यीं_, miow
  { {0x27f70089,0x51f80036,0x2768002b,0x7d0d0030}},	//   ření_, оною_, _بشری_, zgas
  { {0xe3af0015,0x29f8131d,0x2258004a,0x3263006b}},	//   دري_, nča_, цины_, етяв
  { {0x79820050,0x7aee00b8,0xe3b80064,0xc05b005e}},	//   niow, _lebt, smı_, біг_
  { {0xafe40010,0xe53b0008,0x69ce131e,0x8557000a}},	//   ноўл, _לתאר, _lube, _משאב_
  { {0x33940015,0x4fc4131f,0x93fb000a,0x31b20046}},	//   _تلتز, есса, _פלוי, váze_
  { {0xd7880023,0x798b0176,0x69ce0077,0x5337000a}},	//   yển_, yngw, _nube, _מנגן_
  { {0x7c2d07e9,0x8d77002b,0x82330015,0x7d0d01c2}},	//   twar, سازا, _أروا, ugas
  { {0x2d5805cb,0x7982005c,0x5ae70029,0x212b1320}},	// [1c70] чить_, diow, كثاف, mech_
  { {0x7c2d1321,0x31b20046,0x212b1322,0x3c440015}},	//   rwar, ráze_, lech_, عَلِ
  { {0xb9c70086,0x20190020,0xdea10086,0xbdb50001}},	//   ستاه, ltsi_, _شیری, _обој
  { {0x28f80010,0xfc3f1323,0x798b003f,0x212b1324}},	//   зець_, _trí_, ungw, nech_
  { {0xf7700074,0x7e6100c0,0x20191325,0xdd3a000a}},	//   گان_, älpf, ntsi_, _וערכ
  { {0x80a0014e,0xf09400b2,0xa3ab000b,0x201901be}},	//   _ऐडसे, ענס_, _कीं_, itsi_
  { {0xf77004c9,0x442d00dd,0x644602df,0x69ce1326}},	//   دان_, wwe_, åkin, _gube
  { {0x7982005c,0x04590015,0x1a68002b,0xbcfb0030}},	//   ciow, قلعة_, _عینی_, _elév
  { {0x442d0991,0x212b1327,0x200b016f,0xcad5000a}},	//   uwe_, dech_, juci_, ֽוֹת_
  { {0x442d020a,0xf8b20008,0xe1f91328,0x8c1a000a}},	//   rwe_, _ישן_, ого_, קותי
  { {0xc2c5003b,0xf1c90023,0xbb3c0053,0x290f00c0}},	//   بيدي, _tạm_, מעזי, ogga_
  { {0x7bdd0005,0x15f40029,0xd17a0036,0x290f1329}},	//   _otsu, _أسلح, існі_, ngga_
  { {0xbf9b001c,0x3f83132a,0x94ab002b,0x88f6004f}},	//   rrên, fiju_, _اطاق_, וזרו_
  { {0x3f83016f,0x7982002a,0x94ba004f,0x0000006a}},	//   giju_, ziow, _ומנת,
  { {0x7bcf038d,0xddd4002c,0xada60146,0x212b0046}},	//   _aucu, ňažn, давл, bech_
  { {0x7bcf04f9,0xc692000a,0x212b0046,0xd1ba0015}},	//   _bucu, דאל_, cech_, _باتا_
  { {0xeafa0029,0x3f83016f,0x7bc7132b,0x67210844}},	// [1c80] قرات_, biju_, _biju, _oblj
  { {0x3f83132c,0x3c190010,0x09e60361,0x7982002a}},	//   ciju_, яўся_, дожн, wiow
  { {0x639a0053,0x7bc70049,0x539a000a,0xadfa002b}},	//   קסענ, _diju, קיעו, _برخط_
  { {0x7aee132d,0x2d850030,0x257a003d,0xf8aa009f}},	//   _webt, élet_, pūli_, овек_
  { {0x87d70086,0x76410026,0x2089000a,0x38cb002b}},	//   وبوس_, _arly, ּתוֹ_, زانی_
  { {0x212b037f,0xe7b3002b,0x7982002a,0x69ce113f}},	//   zech_, نمند, siow, _tube
  { {0x8b030089,0x7982005c,0xceb3000a,0x09e6005e}},	//   _úřad, piow, ֛יו_, _іоан
  { {0xd8260292,0x3f83132a,0xceb3000a,0x7434006b}},	//   _одби, ziju_, כיו_, ениф
  { {0xf8b2005d,0x212b0089,0x76410026,0xb8660058}},	//   _जरिय, vech_, _erly, _غارو
  { {0xd37003c4,0x212b0026,0x7415002b,0xc21a005e}},	//   اهد_, wech_, روپا, оєм_
  { {0x9f5900dc,0x3f83016f,0x212b132e,0xc56a0015}},	//   pusú_, viju_, tech_, _وحصل_
  { {0xf6530008,0xd7880092,0x73e60010,0x7c260134}},	//   _בצע_, iểm_, _жодз, _opkr
  { {0x3205003e,0x55bb0008,0xc05b0010,0x3f830b6c}},	//   arly_, _ומאו, цін_, tiju_
  { {0xa294008f,0xf4870086,0x200b016f,0x20190020}},	//   _палі, _تامی, ruci_, rtsi_
  { {0x212b0264,0x3f83132f,0x639b000a,0x1dc50015}},	//   pech_, riju_, _וסגנ, فْسِ
  { {0x7bcf0375,0x3f831330,0x81fb000a,0x51fb000a}},	//   _pucu, siju_, _וההז, _וההצ
  { {0x91b80029,0x9f420107,0x3f831331,0xe116004c}},	// [1c90] _تطور_, lský_, piju_, _אַיז_
  { {0xfbab0010,0x3196003d,0x1e350033,0x5fdc000a}},	//   ітай_, rāze_, _зноў, _וחזק
  { {0x09e40036,0x2d8500dc,0x9f420107,0x75221332}},	//   воєн, éles_, nský_, _oboz
  { {0xaadf0372,0x4adf014e,0x39490467,0x1adf005d}},	//   _प्रक, _प्रव, ñas_, _प्रथ
  { {0xba740074,0x9d1a0053,0x636d002d,0x99870030}},	//   _یافت, _צושט, _lúna, ínű_
  { {0xbcfb001c,0xbae50015,0x99d70015,0xe7360fb6}},	//   _elét, _سكري, _يتزا, ееш_
  { {0x6442008c,0x9f420107,0xe619005e,0x99d40015}},	//   _aroi, jský_, їди_, _لتقا
  { {0xe5050015,0x673f002a,0x9f4201c0,0x60cd1333}},	//   ربعي, _żyją, dský_, _ngam
  { {0x6442038d,0x7d1a000a,0xaad3000b,0x442601d7}},	//   _croi, הֵיה, _तलाक, _cpo_
  { {0x64421334,0xf1c90092,0x95cb0010,0x60cd013c}},	//   _droi, _hại_, _дуда_, _agam
  { {0x636d002d,0xdb05002d,0x249b0007,0x80c2000b}},	//   _cúna, lmhó, _žymę_, रेने
  { {0x6d5d1335,0x64420152,0x636d002d,0x25d600f3}},	//   _nosa, _froi, _dúna, _טוען_
  { {0xf1c90092,0xf3e4005e,0x6569038c,0x4f9600f4}},	//   _mại_, _ажіо, mkeh, ерву
  { {0xf1c900a7,0x0dca0029,0x25710089,0x9971005c}},	//   _lại_, كبرى_, _dále_, nął_
  { {0xf8a50086,0x443f1336,0x21cc0046,0x63a10030}},	//   _چک_, lvu_, _běhu_, moln
  { {0xf6520053,0xada30010,0x443f1337,0x27ed1338}},	//   נצן_, гасл, ovu_, _owen_
  { {0xf1ca0092,0x0c260033,0x6d5d1339,0xd910002b}},	// [1ca0] _nại_, эман, _dosa, ییس_
  { {0x909b0008,0x9971005c,0x443f00f2,0xbcfb001a}},	//   _מספק, jął_, ivu_, _slét
  { {0x9f5f00dc,0xa3c0000b,0x27ed0034,0x0906133a}},	//   _órán_, ंगत_, _awen_, епен
  { {0x7e6100c0,0x443f016f,0xf1ca0092,0x7539002a}},	//   älpe, kvu_, _bại_, _nawz
  { {0xe973002b,0x63a1133b,0x18670a0b,0x9f42013f}},	//   دهند, koln, наци_, zský_
  { {0xb907000b,0xfc3f0046,0x78ad007c,0xf1ca0016}},	//   _म्_, _vzít_, üava, _dại_
  { {0x8cba005d,0xe5c603fc,0x443f133c,0x16370015}},	//   ्शको, нсио, evu_, فسية_
  { {0xdb1c0064,0x9f420057,0x6442133d,0x60c90091}},	//   _birç, vský_, _proi, žemi
  { {0x70af005d,0xe4520031,0xed5e0016,0x27ed133e}},	//   _घरेल, اضع_, _đột_, _gwen_
  { {0x2c170053,0xbf9b0152,0x6c7b0135,0x9f420057}},	//   עקיש_, trêm, פריד, tský_
  { {0x443f0048,0xa2940484,0x22940238,0x27ed0012}},	//   avu_, тані, тиня, _zwen_
  { {0x64421334,0x9f40002e,0x9f420264,0x32020057}},	//   _troi, _svið_, rský_, čky_
  { {0x4426003f,0x3866133f,0xb97b000a,0x63a10022}},	//   _upo_, nyor_, לנטי, boln
  { {0xbf9b0152,0x9f420089,0x33980015,0xd437000a}},	//   prêm, pský_, _تنتج_, _נטוי_
  { {0x64470024,0x636d001a,0x6d5d1340,0x673a00bc}},	//   ājie, _kúnn, _posa, _matj
  { {0x9971002a,0x1cbb0058,0x0000006a,0x0000006a}},	//   zął_, كاذب_,   ,
  { {0x6d5d0251,0x91bc0008,0xfbd30087,0xcf270015}},	// [1cb0] _vosa, _צמחי, اتر_, _كردي
  { {0x673a016f,0x5e950015,0x6e950015,0x6569006f}},	//   _natj, _للخط, _للخا, zkeh
  { {0x69c90048,0x6d5d002d,0x539b0008,0x61fa1341}},	//   _piee, _tosa, לימו, nstl
  { {0xbcfb0014,0xd70e000b,0x63a10e8c,0x9cb50015}},	//   _elér, _साउथ_, zoln, _لمجت
  { {0xa3c0005d,0xa3c2000b,0xf1b4000a,0x673a0045}},	//   ंगा_, ्दा_, אסף_, _batj
  { {0xdb05002d,0x21040007,0xbbcd000b,0xd702006b}},	//   rmhó, mčių_, ़दीक, азши
  { {0xab940036,0x63a101b2,0x3f910012,0x38661342}},	//   _сирі, voln, inzu_, ayor_
  { {0xf1ca00a7,0x63a10050,0xd8770015,0x75d1003d}},	//   _tại_, woln, _كاذب, _jāzi
  { {0x210400df,0xe8940036,0x02c9005d,0x656900b8}},	//   nčių_, _бать, रश्न, rkeh
  { {0x21040007,0x443f1343,0x9c18000a,0xf1bf0069}},	//   ičių_, rvu_, תחזק_, emá_
  { {0x77900086,0x443f0209,0xa54b0033,0xc2c50015}},	//   _دیوا, svu_, _нядз_, ضيحي
  { {0x63a100dc,0x46560053,0x63860003,0x21040091}},	//   soln, _בױען_, _pénè, kčių_
  { {0x63a11344,0x78fa000a,0x61e40085,0x04c80015}},	//   poln, ופרו, _čile, _كومي_
  { {0xa2830086,0x25ad1345,0x25bf0045,0x25a00796}},	//   _میخو, llel_, lmul_, čile_
  { {0x539a0008,0xe3c80092,0x21040007,0x394d1346}},	//   _קיצו, _cựu_, ečių_, _ones_
  { {0x395f1347,0x63860003,0x27e00045,0xa5c2001a}},	//   _nous_, _ténè, ţini_, _þótt
  { {0x711b000a,0x91bb000a,0x29d71348,0x203302be}},	// [1cc0] _חופפ, _קמפי, _aça_, _نفيس
  { {0x09ca005d,0x7e6100c0,0x394d1349,0x0e66134a}},	//   िद्य, älpc, _anes_, _акон
  { {0xc3320008,0x395f0781,0xb6d90033,0x0000006a}},	//   שוב_, _bous_, _эмiг,
  { {0x8e97000a,0xa927005e,0x02b6004c,0xfaa30033}},	//   _ידיו_, віше_, דלעך_, шахо
  { {0x2614005d,0x394d0107,0xbcfb0030,0x395f134b}},	//   नूनी_, _dnes_, _ilép, _dous_
  { {0xbf9b038d,0x18670001,0x07080015,0x98730033}},	//   quêt, ђаји_, ريعي_, шліц
  { {0x2bd8005d,0xd6270001,0x6aa300b8,0xbb3b004c}},	//   _भंडा, воје_, ünft, _קעלי
  { {0x2ef801f1,0x395f01c2,0x746a0e4d,0xa5340766}},	//   harf_, _gous_, дров_, унич
  { {0x47c6008f,0xd0e3000b,0xb7d700c3,0x12e6004e}},	//   _абав, _क्षण_, _لوقا_, кінг
  { {0xc445002b,0x63760045,0x27e6134c,0x0000006a}},	//   ایون_, _mâng, mpon_,
  { {0xcb13013a,0xd2570036,0x63760011,0x2ef800b8}},	//   בלת_, вця_, _lâng, darf_
  { {0x25a600b6,0x867b000a,0x21040091,0xf1bf0046}},	//   _ukol_, _קראו, yčių_, umá_
  { {0x69d80046,0xf1bf0794,0x61fa134d,0xe5a30a10}},	//   ívej, rmá_, sstl, _тици
  { {0x2d92003f,0x61fa0012,0x27e602f2,0xbcfb0030}},	//   enye_, pstl, ipon_, _alép
  { {0x3da7000d,0xc333000a,0xa2570015,0x2606000b}},	//   враб, _כוס_, _لشيء_, सूची_
  { {0x463b0053,0xc1150054,0x3ebe001a,0xb1150054}},	//   ועלע, _смиј, ýtta_, _смиш
  { {0xc05b0036,0x0dc8134e,0x511a000a,0x5bb9134f}},	// [1cd0] _цій_, тури_, _אֵינ, елая_
  { {0x395f038d,0x201e0011,0xbb740001,0xbf35006b}},	//   _sous_, ătit_, агуј, _снощ
  { {0x210400df,0xe805005d,0xe8cb005d,0x99d40015}},	//   sčių_, _रिहा_, िश्च, لتنا
  { {0x200b0e63,0xad19000a,0x21040091,0x49b800c3}},	//   orci_, _אוֹר, pčių_, ناند_
  { {0x395f0b7a,0x0904005e,0x6d4f1350,0x25710030}},	//   _vous_, рпін, _inca, _nála_
  { {0xf1ca0092,0x394d0026,0xe7380033,0xa3b2000b}},	//   _hạt_, _wnes_, кеі_, _झील_
  { {0x395f038d,0x63760045,0x25bf0045,0x27e61351}},	//   _tous_, _mând, tmul_, apon_
  { {0x84590083,0x2249016f,0x394d1352,0x2571005a}},	//   ерот_, _čak_, _unes_, _bála_
  { {0xb8e9000b,0x6994004a,0x87270015,0xf1ca0016}},	//   ैश_, _трёх, _لعام, _mạt_
  { {0x69d50064,0x25bf0011,0xf1ca0092,0xb882002c}},	//   _kuze, smul_, _lạt_, číto
  { {0x200b005c,0x751500e5,0x818a0015,0xe28507be}},	//   erci_, _مواض, فندق_, улни
  { {0x9f5e0089,0xdb1d00b8,0x68f90026,0xd00a05b3}},	//   čtí_, _ausü, nawd, неме_
  { {0xe44e0457,0xb4fa000a,0x63640144,0x2ef8001a}},	//   _уж_, _נפסי, _còns, tarf_
  { {0x6d4f1353,0xa856000a,0x32450067,0x7af50046}},	//   _anca, אישה_, _منتف, _nezt
  { {0xa3c2005d,0x27e600bd,0xe80d005d,0x63761354}},	//   ्दर_, zpon_, _समझा_, _sâng
  { {0x7e610123,0xcd36002b,0x0000006a,0x0000006a}},	//   älpa, درآب,   ,
  { {0x1c460010,0xf1a9002b,0x2d9200cb,0x69d51036}},	// [1ce0] ынам, _جاوه_, rnye_, _auze
  { {0x63760011,0xabaa00a2,0x6d4f1355,0x0057000a}},	//   _gând, رهام_, _enca, _עשית_
  { {0xd9461208,0xa96a018d,0x8f1b004f,0x48e6011e}},	//   лежи, нижа_, _אוית, гоев
  { {0xfe370008,0xba170015,0xf1ca0016,0x2258014b}},	//   _ערכי_, طيها_, _gạt_, ärki_
  { {0x58d7005e,0x77610144,0xf3f90045,0xe78606da}},	//   удія_, _bolx, byţi_, луко
  { {0x321e00f2,0x3f8a003f,0xeef6000a,0xfaa61356}},	//   ytty_, nibu_, אמַר_, _баго
  { {0x3687006b,0xd6260015,0xeb9709c2,0x7bcb000a}},	//   лсън_, اعتي, _сир_, _רֶכֶ
  { {0x7bce08c0,0x78b1001a,0x636d0125,0xa8ea0015}},	//   _hibu, ðkvæ, _dúnm, _سعرك_
  { {0xb7160029,0x34940010,0x7bce003f,0xa3c0000b}},	//   _مباش, рапр, _kibu, ंगल_
  { {0x3f8a000c,0x41e60127,0x5c37004c,0xc7d7000a}},	//   jibu_, ліма, נרין_, _עובי_
  { {0x6b7b0053,0x63760011,0x179b000a,0xcb13000a}},	//   גרינ, _rând, _טימב, זלת_
  { {0x844604c9,0xe4e30033,0x257800aa,0x7bce1357}},	//   _مختل, _лішн, _sélf_, _libu
  { {0x200b0003,0x7d160034,0x63761358,0xa98b004f}},	//   urci_, dgys, _pând, תָיִ
  { {0x447b00b2,0x84170008,0xf487002b,0x6266002b}},	//   _אנדע, _עקוב_, _حامی, _مابق
  { {0x63030029,0x63760011,0x6da50015,0xf3c9006e}},	//   _طويل, _vând, لمسم, _شبهه_
  { {0xfbdf0034,0x3d0f000b,0x7d161359,0x0000006a}},	//   _drên_, िलें_, ggys,
  { {0x0fb90054,0x69d5135a,0x2d890d36,0x403500af}},	// [1cf0] _илић_, _suze, riae_, _тепс
  { {0x59d9005d,0x7648135b,0x320c0e63,0x34d10065}},	//   _बंदर, _ordy, ordy_, _हल्द
  { {0x7bce0c61,0x5f74002b,0x539b000a,0x5a35023c}},	//   _dibu, _داير, עיבו, рнет
  { {0xe9ab0086,0xd7880092,0x2d8c0030,0x6d4f135c}},	//   ردان_, iểu_, édet_, _unca
  { {0x68f90050,0x69da0152,0x6cfa0008,0xacfa0447}},	//   rawd, _éten, _בפרס, _בהרכ
  { {0x68f90026,0xf745135d,0x3ead0046,0xa7a9006b}},	//   sawd, реко, řetu_, ъкла_
  { {0x7f3c0053,0x8b9a000a,0x870401c5,0xfaa90040}},	//   געוו, _יבשת, сяче, _شهري_
  { {0x49bb0086,0x05651017,0x24920091,0xca480015}},	//   _سازد_, рвин, _žyma_, _حلفه_
  { {0x320b005c,0x23d40033,0x0000006a,0x0000006a}},	//   ącym_, йцэр,   ,
  { {0x25a0018c,0xb7bd04f9,0xc4280015,0xe3b10015}},	//   čila_, _opţi, اثيل_, غرة_
  { {0x67250020,0x45d507de,0xe299135e,0xbb3a004f}},	//   õhju, _тоес, тан_, דעתי
  { {0x69d8001c,0x798b0026,0x3d0f005d,0xa06a057e}},	//   ívei, nigw, िलों_, вама_
  { {0x671c005d,0x3f8a003f,0x6fa60015,0x85c80015}},	//   _नामक_, tibu_, لإسك, _إِنْ_
  { {0xb4c1005d,0x747a000a,0x92650058,0x0000006a}},	//   ंधी_, _שנסג, _ندعم,
  { {0x3f8a0f4d,0x0fc30191,0xacf607c1,0x7bce0049}},	//   ribu_, ійсн, ичај, _ribu
  { {0x3f8a003f,0x7d160007,0x25710107,0x4aa9000b}},	//   sibu_, ugys, _málo_, _कड़व
  { {0x3b860010,0xbbba0015,0x798b0034,0x9c8704b2}},	// [1d00] алаг, ندئذ_, digw, vočí
  { {0xfbdf00a7,0xdcf60061,0x6ffb0643,0xcb0a002b}},	//   _trên_, ıcın, _שפיג, ئيان_
  { {0x69c20150,0xca560180,0xe8fa06c3,0xb4c10065}},	//   tmoe, штањ, вле_, ंधु_
  { {0xc8ca00e5,0xfd1200c3,0x5ca6012e,0xbbea0058}},	//   نوان_, _بجد_, _вимб, _لرسم_
  { {0xa01b00b8,0xb7d70087,0x97c60c71,0x4813005e}},	//   rzög, لونا_, айде, жміс
  { {0x6e3300dc,0x63760011,0x88c50015,0xe3a70021}},	//   _újbó, _mânc, حتمل, _ذر_
  { {0xd6d90036,0x9c870057,0xb633002b,0x96170015}},	//   уті_, počí, قعيت, لغير_
  { {0x2a3b000a,0x9dd7000a,0xe9a30033,0x342602da}},	//   _בעלמ, סופק_, _дасп, афов
  { {0xa3e70001,0x4d77000a,0xa967135f,0xd49a009b}},	//   адња_, יתקל_, _тита_, ърк_
  { {0xd6f80008,0xa6f8000a,0x93930015,0xf3660a13}},	//   _תִּש, _תִּי, ْجَا, ртин
  { {0x0bb7000f,0xd0d5006b,0x877b000a,0x8506002b}},	//   שלים_, йонъ, _שאבי, _نوان
  { {0xa194008b,0x240a006b,0x51f7055f,0x2187011e}},	//   жаюч, _анди_, шнюю_, рѓов
  { {0x6376001c,0xe0df02b9,0x50640189,0x80a40058}},	//   _cânc, rcò_, отра, ْمُن
  { {0x93fb0008,0x547b0008,0x447b000a,0x1ee7002b}},	//   _ילדי, _שְׁנ, _שְׁא, شوری_
  { {0x63a800fb,0x03bb000a,0xb3bb000a,0x59a6000b}},	//   modn, _שצול, _שמוכ, गकार
  { {0x21290375,0x25780030,0x63a81360,0x22580072}},	//   _ubah_, _féle_, lodn, ärku_
  { {0x91bc0008,0xb478000a,0x8c190015,0x5cb90033}},	// [1d10] _במהי, נָֽי, طيار_, улаў_
  { {0x8ae70191,0x2d8c0152,0x7f840015,0x1f150033}},	//   ріал, éder_, _ولين, _умоў
  { {0x8337004c,0x69da0030,0x1ba80015,0x18f70058}},	//   שאבס_, _étel, جُلٌ_, لأشج
  { {0x63a81361,0x645d0601,0x2bd9002b,0xd257004f}},	//   hodn, äsik, _ماسک_, ישבה_
  { {0x8d5a0008,0x798b0034,0x63a81362,0x0aeb0058}},	//   _עכשי, rigw, kodn, _لرأي_
  { {0xcc3a00b2,0xdc3a00b2,0xf1ca0092,0x778400fd}},	//   _געשט, _געשר, _lạp_, оліз
  { {0x6446002e,0xb9e40036,0x798b003f,0xaac3000b}},	//   ækin, _міти, pigw, वेशक
  { {0xf1ca0092,0x1e98000a,0xd5e80015,0x0000006a}},	//   _nạp_, יכול_, جعون_,
  { {0x7989003f,0x2613005d,0xe8180015,0x47d5006e}},	//   _imew, _धमकी_, _نزلت_, _طيار
  { {0xf7730074,0xc6a70292,0x63a81363,0x32450015}},	//   _بار_, _креи, godn, منخف
  { {0x636d1364,0xc517002b,0x6146029f,0x81ca004a}},	//   _júni, _نبشت, бена, лгов_
  { {0xdb05038f,0x636d0f01,0xf1ca00a1,0x31b90de4}},	//   llhä, _múni, _cạp_, téza_
  { {0x24180010,0x63a806db,0x493a000a,0x001a0033}},	//   _вочы_, bodn, נגשו, ыўны_
  { {0x2bdb014e,0xdee300d8,0x53341365,0x75c30030}},	//   _बढ़ा, зори, _мечт, _tőzs
  { {0xdef90010,0x1d0a0c55,0xfce6005e,0xdb050003}},	//   шыў_, леви_, йово, cohé
  { {0xf1d0021e,0xa19300d7,0x6e930015,0xed460054}},	//   _सूचन, _најч, ألفا, љнап
  { {0xd117000a,0x645d008c,0x442f1366,0x0000006a}},	// [1d20] _הקפה_, äsih, _jpg_,
  { {0xcef60054,0x636d001a,0xdb090015,0x20021367}},	//   _учињ, _búni, لزمه_, mski_
  { {0x6e460074,0xc0a90086,0xbf9b0003,0xeb970054}},	//   _انجم, _مایل_, rrêt, љих_
  { {0x9f490084,0xf8fa0029,0xcd36002b,0xda650015}},	//   _hvað_, اءات_, _اردب, غالي
  { {0x2002060b,0x4f65002b,0xbf9b0003,0x9f49001a}},	//   nski_, _طایف, prêt, _kvað_
  { {0x7c240024,0x39400091,0x38330033,0x07a31368}},	//   mtir, žis_, янір, пачн
  { {0x644b1369,0x8afb01e4,0xbb77000a,0x443d136a}},	//   _argi, _תהלי, _פעלו_, _asw_
  { {0x25a0018c,0xb9960029,0x63a8005c,0x7afe0007}},	//   čilo_, _الرب, wodn, lapt
  { {0x6d440026,0x69c0008c,0xf1ca0016,0x94760015}},	//   idia, _ihme, _rạp_, إدعا
  { {0xc1ea0892,0x2002136b,0xb7db000a,0x28130015}},	//   льме_, dski_, _עקבי, _رومس
  { {0xdb1c0152,0x442f00d9,0xe1351292,0x644b136c}},	//   _chré, _epg_, онны, _ergi
  { {0x5a9b0053,0x1a9b0053,0xdb1c002d,0x68e20ec2}},	//   רשטא, ריטע, _dhré, ncod
  { {0x6d440b7c,0x60e40010,0x55bb000a,0xf08b0015}},	//   ddia, яцэз, _עמדו, ائجه_
  { {0x4034012e,0x7c2404ef,0x6d44136d,0x68e2136e}},	//   џерс, dtir, edia, hcod
  { {0x41e60074,0xdb1c002f,0xf1ca0023,0xa2930036}},	//   _استف, _ghré, _tạp_, _наші
  { {0x7c24002e,0xd0110031,0x6bd70015,0x2002136f}},	//   ftir, _قلب_, متطر, bski_
  { {0xe520005d,0x68e20079,0xa01b0030,0x292f002b}},	// [1d30] _यानि_, dcod, szöb, _ﻫﻴﭻ_
  { {0xda7b0010,0x68e20111,0x24740092,0x7bc50061}},	//   ляе_, ecod, ìm_, umhu
  { {0x7a35003b,0x6d441370,0x7c241371,0x78bb0030}},	//   تفاص, bdia, atir, _szuv
  { {0x621b000a,0xe9d80033,0x7bc50125,0xac191372}},	//   רואק, ёкі_, smhu, _кому_
  { {0xc88b0029,0xe9d00029,0xe8f80127,0xa3b8000b}},	//   دخال_, رغم_, слі_, चता_
  { {0x8cbe000b,0xbae50015,0x6c56000a,0xc018000a}},	//   _शरतो, _ذكري, _וישא_, מקדו_
  { {0xb579005e,0x24740016,0x8579004a,0x65c504d5}},	//   ищих_, èm_, исит_, обка
  { {0x2409071a,0x2002051e,0xe945002b,0x68e202b9}},	//   ании_, yski_, _برآی, ccod
  { {0x75ca0050,0xdb200064,0x9359017c,0xe576005e}},	//   _języ, ütçe, арну_, ізь_
  { {0xdc88000a,0x83891373,0x6d44006f,0x387200cb}},	//   מְתָ, рбов_, zdia, øyre_
  { {0xe6950029,0x24740092,0xcb1204dc,0x6d440026}},	//   _بلاد, àm_, ולי_, ydia
  { {0x2002052c,0xa4f70086,0xf5b70015,0x68fb0003}},	//   tski_, _اکثر_, _اصطد, _jeud
  { {0x84470086,0x443d00b8,0xcfaa0015,0xf4340033}},	//   _دخال, _usw_, لاسم_, _нецэ
  { {0xf767003b,0xe8df0092,0x7d060030,0xdb1c0125}},	//   ذا_, _baịn_, _mérő, _thré
  { {0xfc3f0467,0x64491374,0x6e4307c9,0x20020072}},	//   _así_, lvei, мерз, sski_
  { {0x752902b9,0x20021375,0x64490091,0x68fb0d7c}},	//   nfez, pski_, ovei, _neud
  { {0x6fb60029,0x644907df,0xab660f70,0x7ed601f3}},	// [1d40] _ومعا, nvei, овал, _мінч
  { {0x2fd70074,0xda660015,0x6d441376,0x75e70061}},	//   _گوید_, ياضي, sdia, _kızd
  { {0xcf57000a,0x3946004a,0x8d2a1377,0x7afe1378}},	//   _ובית_, жнег, _конв_, rapt
  { {0x7afe1379,0xdebb000a,0x7c24137a,0xd9d7005e}},	//   sapt, _כמיל, ptir, імії_
  { {0x183600e6,0xade0005d,0x68ed0077,0x68fb137b}},	//   تراح, _खंडन_, ñada, _deud
  { {0xbb560029,0x5c730033,0x69d80030,0x68e2137c}},	//   _بنسب, _ўлёт, íves, scod
  { {0xd95a0001,0x7e7a0053,0x7afc0045,0x6449137d}},	//   _краљ_, יאַז, _iert, evei
  { {0x3196003d,0xdb210030,0x9dd7000a,0x2578137e}},	//   bāzi_, ütöt, חוקק_, _béla_
  { {0x7afc137f,0x644900cb,0x7d7b004f,0x69dc1380}},	//   _kert, gvei, ינקו, _hure
  { {0xe3b20029,0x69dc1381,0xcc57004c,0x1dda000b}},	//   برع_, _kure, קסיק_, भदात
  { {0x64490007,0x3946047e,0x1dbf000b,0x3bbb000a}},	//   avei, odos_, ्षमत, שמיד
  { {0xe1ef0086,0x69dc1382,0x394603b8,0xddcb0091}},	//   کسی_, _mure, ndos_, čiūn
  { {0xf8ca005d,0xe571000a,0x84960015,0xafe40033}},	//   िधिय, _רַב_, _بجائ, моўл
  { {0x7afc0d75,0xb4c8000b,0xa6f8000a,0x25a9036d}},	//   _nert, ोखी_, מִֽי, čale_
  { {0xccfb0001,0x2e480063,0x645d00f2,0xa3de000b}},	//   ића_, оято_, äsiv, _दूत_
  { {0xdd910015,0xc1790091,0xfc3f013f,0x98ca0065}},	//   روء_, rpės_, _psí_, िधाए
  { {0x0bd50029,0xdcef0011,0x7afc1383,0xef67006b}},	// [1d50] سياح, _alcă, _bert, _дъно
  { {0x20191384,0x7afc0aff,0x394600e1,0xdf390015}},	//   musi_, _cert, edos_, _اكدت_
  { {0xea000092,0x64490024,0x69dc0939,0xaae8005e}},	//   _đảo_, zvei, _cure, юєте_
  { {0xe9d8008f,0x3f9106c0,0x69dc1385,0x2019008c}},	//   ікі_, lizu_, _dure, ousi_
  { {0x8d5a0008,0x7afc1386,0x394400da,0x66e51387}},	//   _הכרי, _fert, _dams_, пола
  { {0x69dc0152,0x3946047e,0x37ab00d7,0xa3de000b}},	//   _fure, ados_, штен_, _दूध_
  { {0x7c3901e2,0x2019003f,0xf7700002,0x7bdd0061}},	//   şarı, husi_, خان_, _husu
  { {0x7afc00b8,0x7e9c0053,0x64491388,0x7bdd1389}},	//   _zert, יסוו, tvei, _kusu
  { {0x7bd5000c,0x2019138a,0x6fab000b,0x7529138b}},	//   _kizu, jusi_, चकां, rfez
  { {0x2571002e,0x2019138c,0x43740286,0xcad5000a}},	//   _máli_, dusi_, дуют, ּוֹת_
  { {0xcb1200b2,0xa91d0007,0x7ae50596,0x1ddb000b}},	//   עלט_, _amži, icht, _मूलत
  { {0x291d000c,0x24190080,0xb6ba0008,0xcf890643}},	//   ngwa_, _годы_, _הצעי, _גט_
  { {0x291d003f,0x6281014f,0x04580015,0x2019138d}},	//   igwa_, szlo, _وجهت_, gusi_
  { {0x636d002d,0x03b70015,0x39460091,0x3f9e007c}},	//   _cúnt, _بإصد, zdos_, õtu_
  { {0x272f01e2,0x56b50053,0x3ebe0d17,0xdb1c0064}},	//   mını_, לפֿן_, ått_, _virü
  { {0x69da0152,0x2019138e,0xa0a6138f,0x7afc1390}},	//   _étei, busi_, _найд, _sert
  { {0x7afc1391,0xf539006f,0xdca3032d,0x39441392}},	// [1d60] _pert, ieť_, еати, _rams_
  { {0x272f0064,0xef861393,0x0b8a0015,0xab270054}},	//   nını_, _хлоп, حضري_, зофа_
  { {0x6edb0008,0x81bd0024,0x19ba034e,0x7afc1394}},	//   _לחיפ, ktēl, будь_, _vert
  { {0x7ae51395,0x7afc0940,0xd5b2006b,0x7bdd0045}},	//   acht, _wert, аrни, _fusu
  { {0x7afc0849,0x25ad0409,0xccf3000a,0x2d920061}},	//   _tert, doel_, _רכש_, miye_
  { {0x4cbb0008,0x6d461396,0x272f0061,0x2d920061}},	//   _לזכו, _haka, jını_, liye_
  { {0x272f0064,0x6d461397,0x20190030,0xfaa31398}},	//   dını_, _kaka, zusi_, _заро
  { {0x7ec70014,0x2d920064,0x25ad0026,0x6d461399}},	//   lépé, niye_, goel_, _jaka
  { {0xb4c8000b,0x6d46139a,0x272f0061,0xad37000a}},	//   ोखे_, _maka, fını_, לנקס_
  { {0x6843010f,0xa87b0008,0x4274005e,0x2019139b}},	//   _януа, _האמר, дгос, vusi_
  { {0x2d920064,0x0cb9000b,0xe139005e,0x25ad0546}},	//   kiye_, _आर्म, озні_, boel_
  { {0x6d46139c,0x20190b83,0xf653000a,0x02a30033}},	//   _naka, tusi_, _רצף_, эрым
  { {0x2d920064,0xb0c7005d,0x272f0064,0x645d0201}},	//   diye_, रेंग, bını_, äsit
  { {0x08770053,0x272f0064,0x20190553,0x6442008c}},	//   לעכט_, cını_, rusi_, _isoi
  { {0xae1d005d,0xe3b80064,0xfe540010,0x2d920064}},	//   बंधन_, mlı_, нкрэ, fiye_
  { {0xf1a4008f,0xd2b70008,0x6aba002e,0x929b0008}},	//   _прын, _מלות_, _útfy, _ליות
  { {0xea000023,0x5c9904ab,0xa0080015,0xfce80015}},	// [1d70] _đạo_, цкая_, _فقيل_, سفلي_
  { {0xe3b801e2,0x7ae5059b,0x0bb4034e,0x6d46007c}},	//   nlı_, ucht, ебую, _eaka
  { {0x6d4601e2,0x7ae500b8,0x68ed02c1,0x7bd5139d}},	//   _faka, rcht, ñado, _vizu
  { {0x64420945,0x7ae500b8,0xe3b80064,0xd87900e6}},	//   _osoi, scht, hlı_, يمات_
  { {0xe3b801e2,0x272f0064,0xf7450299,0x25ad03f8}},	//   klı_, yını_, дело, voel_
  { {0x501c000a,0x6d46139e,0x32050247,0xfc5a004f}},	//   מודו, _zaka, ysly_, _וכשמ
  { {0x81bd0048,0xda340010,0x95c50015,0xf9930015}},	//   ttēl, _перы, ويته, _كبر_
  { {0xd11f005d,0x13e9005e,0xdb1c001a,0x1dbf000b}},	//   _भाषण_, омий_, _hirð, ्षित
  { {0x272f0064,0x20090024,0x82f90015,0xe3b80061}},	//   tını_, _nvai_, يردز_, flı_
  { {0xd3890036,0xe2990001,0xb2f40080,0xec38000a}},	//   ійне_, жао_, няющ, לאחר_
  { {0x272f0482,0xda7a00b2,0x32050041,0x9f5900f2}},	//   rını_, ַנשר, usly_, issä_
  { {0x272f01e2,0xc692039e,0x3d07000b,0x645d008c}},	//   sını_, _באב_, षणों_, äsis
  { {0xe3ae008f,0xa01b0014,0x3205003e,0x6d46139f}},	//   _аб_, szön, ssly_, _raka
  { {0xdb1c002d,0x81bd0024,0xdfd20115,0x753b0602}},	//   _phrí, ntēj, ئيس_, leuz
  { {0x1d0a000d,0x2d920064,0x533205e6,0xdd920002}},	//   жеби_, tiye_, _рејт, نوس_
  { {0x9f5900f2,0x0d9a0033,0x24920091,0x656b06cd}},	//   essä_, ітвы_, _žymi_, _jogh
  { {0x2d920064,0xdb07002e,0xad250015,0x81bd003d}},	// [1d80] riye_, _skjá, عرفو, ktēj
  { {0x6d460f4d,0x2d920064,0xdcef003d,0xdb1c0125}},	//   _waka, siye_, ādāt, _thrí
  { {0x2d8013a0,0x753b0111,0x6d4613a1,0x637f06be}},	//   phie_, keuz, _taka, _gêne
  { {0xe3b80064,0x3ebe001a,0x81bd01ec,0x0000006a}},	//   zlı_, ýttu_, etēj,
  { {0xe3b80064,0xd90d0086,0x7d0413a2,0x6d3b000a}},	//   ylı_, صیل_, mais, _ותכנ
  { {0xdc8b0008,0x7d0413a3,0x752202b9,0xf7430054}},	//   _וְלָ, lais, _scoz, вељо
  { {0x68e90026,0x27ed0111,0x2f97000a,0x443f002a}},	//   _ffed, _eten_, וכסן_, ewu_
  { {0xc9660010,0x7d0413a4,0x69950033,0x81bd003d}},	//   _ўвай, nais, _зрух, atēj
  { {0xe3b80064,0xcdb7000a,0x87260004,0x2db7004f}},	//   tlı_, ופקה_, _омаж, ולקן_
  { {0x656b002d,0x7d0413a5,0x3196003d,0x25a90dd9}},	//   _eogh, hais, kāzs_, čala_
  { {0x7d04022d,0x81bd0048,0xe3b801e2,0x656b002f}},	//   kais, stēm, rlı_, _fogh
  { {0x2d9e0014,0xc5f30008,0x7d040604,0xe3b80061}},	//   étel_, _ידע_, jais, slı_
  { {0xe3b80061,0x9f59008c,0x31b90030,0x13f30033}},	//   plı_, yssä_, nézi_, _азія
  { {0x81bd0024,0xc05801c6,0x7879004f,0xe28f009a}},	//   otēk, фію_, פָרו, اذی_
  { {0xd9040074,0xdfd413a6,0x8d770018,0x52830015}},	//   _پی_, торы, وارا, _للوك
  { {0x81a70015,0x5f1b000b,0x7d0413a7,0x9257006e}},	//   _تحتل, _बाक्_, gais, _آشور_
  { {0x4c940080,0xfbdf13a8,0x9f840030,0x3b5513a9}},	// [1d90] витс, _quê_, zöé_, нкар
  { {0x31a40064,0xa3c3000b,0x1bd5004a,0x60c013aa}},	//   mıza_, ्षय_, хозя, ümme
  { {0xc9150124,0xdb1c0084,0xfbd00015,0xb9e4005e}},	//   едећ, _virð, شتك_, вічи
  { {0xae1a000a,0x5e76000a,0x443f002a,0x28f8005e}},	//   _צורכ, _נתרן_, ywu_, дець_
  { {0x656b017e,0x31a401e2,0xa3c3014e,0xf8b10086}},	//   _rogh, nıza_, ्षम_, اکز_
  { {0xf1ca0092,0x656b002d,0xabfa000a,0xdb0704d1}},	//   _dạy_, _sogh, _מהשר, _skjæ
  { {0x81bd0048,0xbbbd005d,0x45d513ab,0x2bd8000b}},	//   rtēj, ्गीक, нцит, _भूटा
  { {0x79820050,0x443f002a,0x81bd003d,0x85940033}},	//   chow, twu_, stēj, кшыц
  { {0x27ed003c,0x81bd0024,0xfbdf13ac,0x753b13ad}},	//   _uten_, ptēj, _grêt_, reuz
  { {0x2d8c0152,0xe3c50015,0xa71402a3,0xca35004f}},	//   édez_, عْدَ, _амфі, ֲנָה_
  { {0x03220010,0x656b002d,0x68e400b3,0xe4d90015}},	//   ыдэн, _togh, žide, _فوات_
  { {0x46380029,0xe4510015,0x31a40061,0x63ba0052}},	//   _تأكد_, _مضت_, fıza_, altn
  { {0x600713ae,0x7bc7008c,0x30760054,0x7d0413af}},	//   нням_, _ohju, хунс, vais
  { {0x0000006a,0x0000006a,0x0000006a,0x0000006a}},	//     ,   ,   ,
  { {0xf77200a3,0x02450015,0x63a60030,0x6da6004a}},	//   נקל_, _أَبَ, ékne, еива
  { {0x3f83007c,0xf1ba000a,0x7bc7007c,0xa3de000b}},	//   ahju_, _מֶ֥ל, _ahju, _दूँ_
  { {0xdee60cf2,0xc19b000a,0xeafa0015,0xdb1e008c}},	// [1da0] _попи, _משקי, كرات_, ympä
  { {0x7d0413b0,0x9b460029,0xdb1c002d,0x2bba0015}},	//   sais, عناو, _bhrá, ساءة_
  { {0x61eb04f9,0xe9da111b,0xc332039e,0xdb1c0057}},	//   _înlă, чке_, רוב_, _chrá
  { {0x307a0053,0xfbdf0152,0xcb09000a,0x2571001a}},	//   ּאַנ, _prêt_, מל_, _máls_
  { {0x75c30030,0xa3de000b,0x75e70061,0x63ba02dc}},	//   _főzz, _दूं_, _rıza, yltn
  { {0x60c4000c,0x38cb0086,0x501b0008,0xdb1c002d}},	//   _mzim, سانی_, פוצו, _fhrá
  { {0xe2870029,0xe60f0015,0xdb1c0125,0x0000006a}},	//   _إذ_, مشي_, _ghrá,
  { {0xe5540099,0x99d60058,0xd6d900ce,0x0000006a}},	//   ткињ, _أقرت, фті_,
  { {0x60c4000c,0x64a30001,0x98a30bb1,0x4614009a}},	//   _nzim, лаћа, _бите, روکر
  { {0xb8f3005d,0x54330029,0x88350033,0x389b004f}},	//   हे_, ارير, _шэсц, _זימנ
  { {0xf656005e,0x26de02f2,0x60c413b1,0x25710030}},	//   _ятаю, _igto_, _azim, _pált_
  { {0x4a9b0053,0x546a0063,0xbcfb0003,0x63760045}},	//   לייג, _наем_, _inég, _mâni
  { {0xc953013a,0x257100dc,0x74130040,0x0000006a}},	//   אמר_, _vált_, _مونا,
  { {0xa3c3014e,0x25a0018c,0x60c40024,0xd5df000b}},	//   ्षण_, čilu_, _dzim, _पूँज
  { {0x9757000a,0xde58005e,0x4377004c,0x83690015}},	//   עילו_, нарі_, _אײגן_, _تصنف_
  { {0x315b0015,0x3eba00cb,0xb2bb000a,0xa2bb000a}},	//   _رجعة_, _dypt_, _ממור, _ממוט
  { {0x2ef5010f,0x321e005c,0x71d8000a,0xdb1c0125}},	// [1db0] _изпр, luty_, _אוהד_, _shrá
  { {0x35b2000b,0x7e610123,0xf3f1000a,0xfaa7005e}},	//   ँकड़, älps, ׁ֣ב_, ншен
  { {0x314b0008,0x321e037f,0xd5df000b,0x9a590021}},	//   ּתְּ, nuty_, _पूंज, بلاط_
  { {0x39780127,0x621b000a,0x201913b2,0x628813b3}},	//   нсію_, לובק, orsi_, izdo
  { {0x6d5d13b4,0xa09c004c,0xad1a000a,0xc19c004f}},	//   _insa, ּיוט, _קושר, השאי
  { {0x2b1e005d,0x39490cd4,0x6d4d13b5,0xb6590a61}},	//   _पाएँ_, žas_, ldaa, дших_
  { {0xfbdf03af,0xe7080115,0xcf58000a,0x7c2d13b6}},	//   _três_, رتون_, תבות_, ltar
  { {0x49040086,0x99d40002,0x0e5c000a,0x6d4d13b7}},	//   _موفق, _متقا, לדוב, ndaa
  { {0x6d4d00f2,0xd6db0004,0x69c9008c,0x200b0085}},	//   idaa, _ете_, _ihee, jsci_
  { {0x69da0152,0x87d70015,0x7c2d13b8,0x3ead0046}},	//   _éter, _أغرا, itar, řety_
  { {0x60c400dc,0x7c2d13b9,0xdce60024,0x6f070a52}},	//   _szim, htar, _lokā, dajc
  { {0x25090086,0x04b5006b,0x7c2d13ba,0xd00a0004}},	//   _آرای_, _исля, ktar, меме_
  { {0x15180029,0xdce6003d,0x21a3004a,0x40330033}},	//   _أزمة_, _nokā, риям, аеўс
  { {0x6d5d13bb,0x6d4d0079,0x7c2d13bc,0xe04303ae}},	//   _ansa, edaa, dtar, јнри
  { {0xee150010,0x657b003f,0xc7b2000a,0xdfcf0015}},	//   льтэ, okuh, יבך_, زيف_
  { {0x40960029,0x6d5d0045,0x6d4d02f2,0xc236000a}},	//   _للعر, _cnsa, gdaa, _ירצו_
  { {0x60c4016f,0x7c2d0a4d,0x1ae60da6,0xcd27006b}},	// [1dc0] _uzim, gtar, возм, ъжте_
  { {0xa3c1005d,0x8ad60029,0x3eba0111,0xa3c3000b}},	//   ंति_, نتائ, _typt_, ्षि_
  { {0x4dd60029,0xab27006b,0x657b05ff,0x442d13bd}},	//   _لتحس, тоха_, kkuh, hte_
  { {0x69c913be,0x442d0362,0x3f980049,0xa91d01c0}},	//   _chee, kte_, liru_, _alžb
  { {0xa3c3014e,0xa3c1005d,0x39130010,0x69db0144}},	//   ्षा_, ंता_, рмір, _diue
  { {0xbb760063,0x18670001,0x69c90111,0x31b90089}},	//   _румъ, таљи_, _ehee, lézt_
  { {0xbf9b0053,0x96270015,0xf6e50033,0x8f9b015b}},	//   ויסש, نكوك_, уцін, ויסי
  { {0x657b13bf,0xe5c60054,0x628813c0,0x442d13c1}},	//   gkuh, њско, vzdo, fte_
  { {0x37e60191,0xa3c0014e,0x75e701e2,0x674500dc}},	//   _розг, ूगल_, _hızl, ítjü
  { {0x61e313c2,0x671c000b,0x637f016e,0x75e70061}},	//   _bunl, _नाटक_, _pêna, _kızl
  { {0xf3630174,0x3f980085,0x7c2d13c3,0x442d05ef}},	//   ртын, diru_, ztar, ate_
  { {0x92930010,0x6446002e,0x6f07005c,0x9695009c}},	//   раюц, ækis, wajc, _сруш
  { {0x5334008f,0x68ed02c1,0x2904003f,0x442d13c4}},	//   _белт, ñadi, _mema_, cte_
  { {0x321e003e,0xdce6003d,0x29040d29,0xf457004f}},	//   puty_, _rokā, _lema_, _שיגר_
  { {0x91e30001,0x7c2d005c,0xcddb0001,0x6f07002a}},	//   _које, wtar, дња_, rajc
  { {0x290413c5,0xed140036,0x672d0085,0x7c2d0624}},	//   _nema_, имсь, đaji, ttar
  { {0xd1b80067,0x3f9813c6,0x7c2d13c7,0x6d4d13c8}},	// [1dd0] _جاوا_, biru_, utar, rdaa
  { {0xd9cb005d,0x2d8200f6,0xbcfb0152,0x257800dc}},	//   िष्ट, _elke_, _poés, _déli_
  { {0x6abc0026,0x7bdc0375,0x442d13c9,0x69c90034}},	//   _cyrf, _diru, zte_, _phee
  { {0x27e400e8,0x7bdc0034,0x6abc0034,0x442d13ca}},	//   _bumn_, _eiru, _dyrf, yte_
  { {0x442d13cb,0x69db0144,0x9d1a000a,0x7bdc13cc}},	//   xte_, _viue, _אורט, _firu
  { {0x69c9003e,0x07090029,0x442d04af,0xb07c004c}},	//   _whee, ريبي_, vte_, ונדז
  { {0xc7940086,0x6abc0026,0xdcf6002a,0x3635002b}},	//   جشنب, _gyrf, łcąc, ارتس
  { {0x05540080,0x58050015,0x6f0513cd,0xa3e7000b}},	//   атья, _مورك, _lehc, _मंद_
  { {0xf1bf13ce,0x77930086,0x65690209,0x33d5005e}},	//   dlá_, _پیغا, rjeh, ліот
  { {0x29040024,0x442d13cf,0xf7700040,0x61e302f2}},	//   _zema_, rte_, _وال_, _punl
  { {0x3f9801a3,0x65690085,0x442d05a9,0x35f513d0}},	//   viru_, pjeh, ste_, _спер
  { {0xeab2000a,0x442d13d1,0xdd110061,0x208a02dd}},	//   מֹר_, pte_, _rüşd, ейми_
  { {0x394d0176,0xa8790053,0x628e002c,0xd0960892}},	//   _maes_, גאָר, úbor, ушны
  { {0x649a00b4,0x749a00b2,0xe7c3000b,0xf1bf013f}},	//   _אינה, _אינפ, षतिप, alá_
  { {0xe1f104b6,0x200000da,0x6fc00012,0xc3320447}},	//   _است_, _wwii_, löck, _לוג_
  { {0x22580134,0x6e930015,0xbda50015,0x9da50015}},	//   ærke_, حلفا, لحقو, لصقه
  { {0x25bf0011,0xe0da0805,0x31600061,0x6abc0034}},	// [1de0] ilul_, _яви_, _iniz_, _syrf
  { {0xdd0401e2,0xbb4a0029,0x69c30003,0x1ee8002b}},	//   ısın, علان_, înen, _جودی_
  { {0xe37a01ac,0x7bdc0a25,0x0f57000a,0x3bd5004a}},	//   ערער, _viru, _עיטם_, рютс
  { {0x7bdc005c,0xfe9b0135,0xdcf70045,0x25780030}},	//   _wiru, _טיימ, ăcăr, _téli_
  { {0x18330015,0x8eda002b,0xd90d002b,0x7bdc13d2}},	//   مروح, _تذکر_, بیق_, _tiru
  { {0xc8080092,0x6fb4000b,0x4733005e,0xf8a90015}},	//   rở_, ंकिं, йніс, خدمه_
  { {0x394d0026,0x290413d3,0x7d0613d4,0xd5b00015}},	//   _faes_, _tema_, _keks, يفت_
  { {0x5e570053,0x81bd0024,0xe5c602bf,0x746a014d}},	//   ריקע_, ntēt, ысло, еров_
  { {0xd90d002b,0x69d80091,0xdb1c0012,0x7d0613d5}},	//   _آیه_, įved, _thrä, _meks
  { {0x883b000a,0x25bf0045,0x38cb002b,0x3437006e}},	//   _אתמו, alul_, _ساقی_, اسيد_
  { {0x0bb7000a,0xfbb7000a,0x877b004c,0x81bd003d}},	//   רלים_, רפית_, _ראבי, ktēt
  { {0x25bf0045,0x6fc0038f,0xd0d5006b,0x216713d6}},	//   clul_, böck, ионъ, утог
  { {0x637613d7,0x05b30015,0xb97b000a,0x637f059d}},	//   _sânu, _امنح, תרכז, _gêno
  { {0x63760011,0xf1bf13d8,0x8233009a,0x7d060073}},	//   _cânt, slá_, جریا, _aeks
  { {0xa3c3014e,0xa3c1005d,0x2dcb0054,0xbed50b1e}},	//   ्षर_, ंतर_, ећан_, ровј
  { {0xbca50029,0x8cf50004,0xe213006e,0xf1bb000a}},	//   لمزي, рзац, _ابوع, _אֶ֖ל
  { {0xcb1b000d,0xd0110086,0xe04b0015,0x63760045}},	// [1df0] еќе_, _بلخ_, _أشبه_, _fânt
  { {0xeb930015,0x3ce6006f,0x75e70061,0xdb23009a}},	//   حظر_, ľova_, _sızm, صوصی
  { {0x9a27002b,0x7d060030,0x7dc70058,0x394d059d}},	//   طعان, _feks, _متحك, _paes_
  { {0x4dfa00b2,0xa9070002,0x99d400a2,0xb9350054}},	//   _שפרא, ابان, متنا, редј
  { {0xd70507d1,0xa1ac004f,0x0000006a,0x0000006a}},	//   азли, עֱבִ,   ,
  { {0x17f80029,0x07a5000d,0x91720016,0xe73913d9}},	//   ارنة_, јакн, rở_, тек_
  { {0x25bf0011,0x6d4f013c,0xe5710015,0x27f800bc}},	//   tlul_, _kaca, قطة_, _črne_
  { {0x6fc00012,0x6d4f13da,0xd5e80015,0x59a90065}},	//   töck, _jaca, دعون_, _कदिर
  { {0xb81c005d,0x64a50010,0x572700e5,0x87270031}},	//   _नियम_, рапа, _مراق, _معام
  { {0x6d4f13db,0xa757006e,0x9cd8004f,0x25bf005a}},	//   _laca, _حضرت, נוזה_, slul_
  { {0x3dc00034,0xa2d00065,0x25bf13dc,0x0000006a}},	//   yliw_, डेल्, plul_,
  { {0x24960074,0x63760045,0x672d0085,0xe29603ca}},	//   انید_, _sânt, đaju, раю_
  { {0x764e002e,0x7d060c2c,0xd00f0015,0xa4d5005e}},	//   _ábyr, _reks, ولَ_, _тоді
  { {0x63760011,0x645913dd,0x7d0613de,0xa856004f}},	//   _dâns, _irwi, _seks, בישה_
  { {0x3ebe002e,0x645c0024,0x2d9613df,0x539a0447}},	//   ætt_, ārie, арас, _ביסו
  { {0x41b30015,0x6459002a,0xed460b1e,0xa19301ca}},	//   _ومور, _krwi, јнап, _мајч
  { {0x81bd0024,0xcaf60029,0x7d0613e0,0x91bb000a}},	// [1e00] rtēt, لساب, _veks, _במקי
  { {0x6e2f00dc,0xb8820089,0x2578001a,0x81bd003d}},	//   önbö, říkl, _hélt_, stēt
  { {0xeb970001,0x3daa0010,0x590a006b,0x81bd003d}},	//   јих_, _акно_, веем_, ptēt
  { {0x32360053,0xc236000a,0x010d004f,0x0000006a}},	//   יטען_, ירעו_, ֲלוּ,
  { {0xa01b00dc,0x6d441358,0x7b010030,0x0000006a}},	//   szöv, meia, éztü,
  { {0x2d80005c,0x207b0053,0xc7a30661,0x9057000a}},	//   lkie_, כאנא, оичк, יבנו_
  { {0xbb3b0008,0x7c2402c1,0xdaba0086,0x7fd70008}},	//   _שעלי, luir, _شهرت_, בוסס_
  { {0x2d80020a,0xdb0713e1,0x94aa0015,0x6d441349}},	//   nkie_, _skjø, َاةِ_, neia
  { {0xb7160086,0x89db000a,0x34940033,0x69c2007c}},	//   _نباش, _יחלי, сапр, mloe
  { {0x6e3e003c,0x69c213e2,0x6d4413e3,0x6459002a}},	//   _oppb, lloe, heia, _drwi
  { {0x0cc3005d,0x2d8013e4,0xcb130008,0xdb1c002d}},	//   _शर्म, kkie_, חלת_, _bhrú
  { {0x25780030,0x067b000a,0x867b000a,0x7c24036d}},	//   _célt_, _שנאל, _שראו, kuir
  { {0x248d005c,0x6d44016e,0x2d80002a,0xdb05039f}},	//   czem_, deia, dkie_, rohú
  { {0xdb0500c0,0x7c24028f,0x6d4f0c98,0x613c02de}},	//   llhö, duir, _saca, _pålæ
  { {0xf2060063,0xa3b3000b,0xbcfb0003,0x4fd4005e}},	//   _тяло, झकर_, _anéa, іжст
  { {0xdb1c002f,0x463b0053,0x69c80024,0xccf80001}},	//   _ghrú, כעלע, _ūden, ићу_
  { {0x65620f1b,0x442413e5,0x69c20026,0x5b150142}},	// [1e10] _mnoh, num_, dloe, ймат
  { {0x6d4f013c,0x3378000a,0x2d80002a,0x6a170015}},	//   _waca, נְּב, akie_, لبصر
  { {0x6d4f002f,0x5a350661,0x7f3c000a,0xddc70030}},	//   _taca, снет, _יעזו, őműv
  { {0xac190036,0x2d8013e6,0xdeb6000a,0x98150015}},	//   _йому_, ckie_, _לפתח_, مبتا
  { {0x765a0050,0x442413e7,0x7d0d13e8,0x7c240045}},	//   _arty, jum_, maas, cuir
  { {0xbb85003b,0x442413e9,0xcc760008,0x4af8004a}},	//   _السي, dum_, _הגשת_, _верю_
  { {0xff18000a,0xe7680015,0x69c213ea,0xe28e011e}},	//   בקות_, شحون_, bloe, _наi_
  { {0x44240084,0x69c20251,0x31b2002c,0xa01b05a5}},	//   fum_, cloe, bázy_, nzös
  { {0x442413eb,0xe3b909dd,0x0000006a,0x0000006a}},	//   gum_, лби_,   ,
  { {0xd774003b,0x8c1a0008,0x248d080c,0x2d80002a}},	//   _والع, נותי, rzem_, zkie_
  { {0x7c240011,0x237800c0,0x248d0eba,0xc049000a}},	//   zuir, örja_, szem_, _רז_
  { {0xa06a0001,0x3d21000b,0x6a96000a,0x0f20000b}},	//   гама_, यलों_, מכתא_, बल्स_
  { {0x442404f9,0xb09a0036,0x645d0134,0x79ba000a}},	//   cum_, утнє_, æsid, רֶיה
  { {0xa0270084,0x644913ec,0x5456000a,0x7d0d007c}},	//   _stöð, mwei, _לסנן_, eaas
  { {0x644900b8,0x2d80005c,0x51f50225,0x0219005e}},	//   lwei, tkie_, _استر, _сіль_
  { {0x7d0d0020,0x752913ed,0xdb05016e,0x7c2413ee}},	//   gaas, ngez, ilhõ, tuir
  { {0x644900b8,0x69c20161,0xf1b3000a,0x2d80044d}},	// [1e20] nwei, vloe, _מסה_, rkie_
  { {0xcb0a0086,0x5f4600a2,0x2d8002ef,0xa01b0030}},	//   ايان_, _اندل, skie_, rzöt
  { {0x7d0d0020,0x644913ef,0x6e3e13f0,0xe8fa13f1}},	//   baas, hwei, _uppb, гле_
  { {0xed5f002c,0x6455003d,0x75290079,0x442413f2}},	//   ážte_, āzij, jgez, yum_
  { {0xa3e7005d,0x7c240dd3,0xccf3000a,0xe80b000b}},	//   _मूल_, quir, _מכר_, _सौदा_
  { {0x64490026,0x31b2006f,0xb7d700c3,0x69c213f3}},	//   dwei, rázy_, مونا_, sloe
  { {0x4424005c,0x7e7a004c,0x4e7a004c,0x64490028}},	//   wum_, טאַז, טאַצ, ewei
  { {0x644900b8,0x9f8400f2,0xba17000a,0x752913f4}},	//   fwei, löä_, _לחלץ_, ggez
  { {0x161a005d,0x7982005c,0xad1b000a,0x8886007e}},	//   _नटवर_, mkow, אופר, _улаж
  { {0xd2140001,0x79820647,0x442413f5,0x4394005e}},	//   омоћ, lkow, rum_, іанс
  { {0xb7d70115,0x3bbb000a,0xd4e6006b,0x442413f6}},	//   _اولا_, רמיד, _люли, sum_
  { {0x79820050,0x44240084,0x656200f2,0xdb1e002d}},	//   nkow, pum_, _unoh, ompó
  { {0x54330086,0xf993000a,0x853b000a,0x7d0d008c}},	//   _فرور, פרש_, _תגדי, vaas
  { {0x1ee7002b,0xc4c50015,0xd5be01ec,0x0000006a}},	//   صوری_, _بتمو, žādo_,
  { {0x7a1c04f9,0x5337000a,0x539b000a,0x877b05bd}},	//   nătă, _לנגן_, _תיוו, נאלי
  { {0xdd94008f,0x63ba13f7,0x32530063,0x71a4049d}},	//   пасы, lotn, _хвър, _најз
  { {0x7982005c,0x2d580a61,0xaae70015,0x6fb50015}},	// [1e30] dkow, щить_, مساو, _ومبا
  { {0x7d0d0020,0x5b1500fd,0x2d9e0140,0xa01b0030}},	//   saas, імет, éter_, szös
  { {0x7d0d00f2,0x644900b8,0x27f800bc,0x7ff4002b}},	//   paas, zwei, _črna_, _وسیا
  { {0xf1c9014e,0x41c9000b,0x4879006b,0x61ea13f8}},	//   रतिन, रतिस, исля_, _mufl
  { {0x63ba13f9,0x18691191,0x7d56000a,0xa3cb000b}},	//   kotn, рали_, _וירד_, लतम_
  { {0x3619005f,0xa09c0053,0xb09c0053,0x7982002a}},	//   ацию_, ניגט, ניגר, akow
  { {0x994d002c,0x75290186,0xff18000a,0x798213fa}},	//   môžu_, tgez, זקות_, bkow
  { {0x0e9c0053,0x644913fb,0x06960015,0x7982002a}},	//   טשול, twei, غنية_, ckow
  { {0x61ea00b8,0xa3e9000d,0xa8180015,0x13e6004a}},	//   _aufl, јдоа_, _هتلر_, омый_
  { {0x290f13fc,0x644913fd,0x1309004a,0x36d50342}},	//   laga_, rwei, шной_, _дозр
  { {0x644913fe,0xd6e80008,0x04f50010,0x59990008}},	//   swei, _הַנָ, _дзею, ֹשָׁ
  { {0x15a8006b,0x290f13ff,0xc5f2004f,0x63a80072}},	//   _лъчи_, naga_, _חדא_, andn
  { {0x2bbe014e,0x43850015,0xafdb00cb,0x63ba1400}},	//   ्तमा, _ولصق, lvøy, botn
  { {0x3e8a0010,0x7982005c,0x79890e18,0xd347002b}},	//   айго_, zkow, _llew, _ایده_
  { {0x7982005c,0xaf99034e,0x290f1401,0xad66006e}},	//   ykow, стях_, kaga_, ياره
  { {0xa3c3005d,0xf652000a,0xa0a61402,0x290f1403}},	//   ्षक_, וצל_, _майд, jaga_
  { {0x0eb6005d,0x9f8400f2,0x8f760033,0x290f1404}},	// [1e40] _आँकड, töä_, _дуні, daga_
  { {0x76411405,0x290f1406,0x7982002a,0x60c40061}},	//   _oply, eaga_, wkow, _iyim
  { {0x79820050,0x7f3b004c,0x798900e7,0x61e4019a}},	//   tkow, _דעיו, _blew, _kiil
  { {0x5f460074,0xd23a0053,0xed5a0f70,0xae57000a}},	//   _انگل, יגעל, _том_, _וסטס_
  { {0x7982005c,0x91720016,0x39461407,0x61e41408}},	//   rkow, iờ_, reos_, _miil
  { {0x7982005c,0x394602c1,0x79890fcd,0x9af60015}},	//   skow, seos_, _elew, _ذكرت
  { {0x394602c1,0x290f0523,0x637f016e,0x7982002a}},	//   peos_, baga_, _gêni, pkow
  { {0x61e400f2,0x63ba06ed,0xd5b00015,0x6d5601f9}},	//   _niil, wotn, عفة_, ndya
  { {0x61ea0011,0x63ba1164,0x236a00d7,0xcb9a000a}},	//   _sufl, totn, ајно_, ֙יִם
  { {0xe72a002b,0xbcfb0030,0x7989002a,0xa78600c3}},	//   _خسرو_, _anél, _zlew, _بشرو
  { {0x32660036,0x63ba1409,0x60cd1116,0xa159140a}},	//   ітов, rotn, _szam, бану_
  { {0x63ba00bd,0x656f00b8,0xe578003d,0x81bd003d}},	//   sotn, öcht, _puķu_, cuēl
  { {0x83f8006b,0x25d70643,0x63ba140b,0x61e4140c}},	//   _уелс_, _וואן_, potn, _diil
  { {0xa2940484,0x60cd00bc,0xbcfb0030,0x9e0700fd}},	//   _налі, _vzam, _enél, жчал
  { {0x290f0035,0x3f83001a,0x61e4140d,0x61f0002a}},	//   yaga_, rkju_, _fiil, ódlą
  { {0xd0110015,0x71f7006e,0x3f830052,0x0000006a}},	//   _كلب_, _بروس_, skju_,
  { {0xe57100b2,0x6ebb005d,0x290f0f38,0x3fa8001a}},	// [1e50] ײַן_, _शुरु, vaga_, ðvuð_
  { {0x7e2b008f,0xddeb0086,0xba740086,0x69c00f28}},	//   _кіма_, _پرده_, ژانت, _akme
  { {0xdced016f,0x8aa7005e,0xfc3f0016,0xdb07001a}},	//   ljač, црад, _axít_, _skjó
  { {0x99810046,0xe81c0065,0xdced0160,0x0000006a}},	//   ruhů_, _निशा_, ojač,
  { {0xa804008f,0x78470015,0x515c000a,0x290f140e}},	//   дзіл, تضام, יכאו, raga_
  { {0x637f016e,0x69c00061,0xa8480015,0x2009140f}},	//   _têni, _ekme, تلهم_, _mwai_
  { {0x6442001c,0xf96b1410,0x91720016,0xaab40015}},	//   _apoi, _край_, hớ_, _قصفت
  { {0xe7950086,0x7641002c,0x04950033,0x64420125}},	//   _کارک, _vply, зроў, _bpoi
  { {0xc952000a,0xdced0085,0xd7f81411,0x0000006a}},	//   _אמן_, jjač, _дух_,
  { {0xe3b10015,0xbb9a000a,0x56670021,0xdced0085}},	//   عرة_, ֶ֑יך, _وداف, djač
  { {0x4b7c00b2,0x61e400f2,0x76410227,0x656f0012}},	//   יאזו, _piil, _uply, öchs
  { {0xe802014e,0x644f0134,0xf656000a,0x7656000a}},	//   रीका_, æcis, _מסעי_, _מבעד_
  { {0xe5c40010,0x7fd60033,0x1168002b,0x61e41412}},	//   _ўсхо, зіві, ملگی_, _viil
  { {0xf7670018,0x2215006b,0x93fa000a,0xe0d7006b}},	//   را_, _ефир, _הלסי, явя_
  { {0x61e4008c,0x63a11413,0x27ed005b,0x0000006a}},	//   _tiil, miln, _luen_,
  { {0xf6520053,0x63a11414,0xdce40085,0x661c02de}},	//   עצן_, liln, njić, _ærke
  { {0x201a0029,0x8b260010,0x27f800bc,0x0c260033}},	// [1e60] _اتبع_, здзе, _črno_, яман
  { {0x645b00f2,0xe7ef000b,0x909b000a,0x63a11415}},	//   ivui, _चढ़ा_, _לספק, niln
  { {0xaac50086,0x3f7b0008,0x0f7b000a,0x8f7b000a}},	//   وتمن, _האיס, _האיב, _הניק
  { {0x290d04f9,0x27ed02c1,0x7e610134,0x657900da}},	//   _ceea_, _buen_, ælpe, _nowh
  { {0xa3cb005d,0xbc19005e,0x4ddb000a,0x7d041416}},	//   लता_, _мірі_, _לחטו, mbis
  { {0x26c50089,0x68ed002c,0x63a100bc,0xbf9b0003}},	//   _bylo_, ľada, jiln, mpêc
  { {0x68ed02d5,0x63a1018c,0x6b630484,0x16370015}},	//   žada, diln, _якра, كسية_
  { {0x442a0010,0xb6080089,0xe944002b,0x63a10012}},	//   бцом_, jišť, _ترسی, eiln
  { {0x2608000b,0xbcfb006f,0xdb050077,0x44f3002b}},	//   _सबकी_, _poéz, cohó, رسيز
  { {0x57fb0008,0x5398005e,0xd7fb000a,0xb8820046}},	//   _ללמו, івня_, _להמל, řísl
  { {0xdb37000a,0xa29401f3,0x9731009a,0x0000006a}},	//   הניח_, фані, _شکوا,
  { {0x6442008c,0xa3e70065,0x7c240160,0x0000006a}},	//   _tpoi, _मूक_, krir,
  { {0x53340080,0xf1b00015,0x7d040085,0x63a11417}},	//   _желт, اءٍ_, dbis, biln
  { {0x44a50015,0x63a11418,0x62811419,0x7d04141a}},	//   _تحمّ, ciln, bylo, ebis
  { {0x433b0008,0xe3b30053,0x733b0008,0xe731000a}},	//   _העוב, _אױס_, _העוס, כֵן_
  { {0x7d040035,0x7c24141b,0x4424141c,0x828b004f}},	//   gbis, frir, orm_, _לְחֶ
  { {0xb6060085,0x7c24141d,0xdfb50054,0x3cb4141e}},	// [1e70] lošć, grir, _обињ, ейтр
  { {0x44240b1b,0x7d0405d0,0x25a00046,0x3b54110c}},	//   irm_, abis, čily_, нкур
  { {0x7c24141f,0xb6060085,0x8f7c000a,0x7d041420}},	//   arir, nošć, _לנזק, bbis
  { {0x99d70015,0x7c870054,0x7c240d29,0x7e08004f}},	//   ستضا, _еуге, brir, _מִשֶ
  { {0x27ed0092,0xf7950010,0xdb1c1421,0x98c70015}},	//   _quen_, мадэ, _chró, أغان
  { {0xf7940010,0xf77100a2,0x777a0251,0xdb23008c}},	//   начэ, ضات_, _cotx, äräa
  { {0x63a11422,0x7d0f0030,0x45d50190,0x44241423}},	//   viln, _kecs, мцит, erm_
  { {0x49750010,0x63a1005c,0x27ed00f2,0xdb050144}},	//   _ўлас, wiln, _tuen_, cohò
  { {0x97250015,0x69c30003,0xe4560033,0x3dc902f2}},	//   _يفرو, îneu, джы_, ilaw_
  { {0x1b7a0053,0x7d0400b8,0x7d0f00dc,0x33990015}},	//   ַטרע, zbis, _lecs, تخبة_
  { {0xcb120008,0x3ce6002c,0x63a11424,0x28d9000b}},	//   כלי_, ľovi_, riln, बेरि
  { {0x7c240084,0xa0a60054,0x6452008c,0x10a603de}},	//   yrir, дамд, äjiä, димн
  { {0xbcfb002c,0xc916000a,0xe4cb0015,0x63a11425}},	//   _inéh, וחרת_, _ابان_, piln
  { {0x7df50007,0x3f8c0264,0x7c241426,0xf8ab00a1}},	//   _sąsa, ódu_, vrir, _đời_
  { {0x7d0f0014,0x25ad0134,0x12fa000a,0xb222001a}},	//   _becs, onel_, _והצב, þætt
  { {0x3cf5014e,0x25ad0220,0x25bf084a,0x61fc0030}},	//   एँगे_, nnel_, noul_, írle
  { {0x7d0400b6,0xa01b00f2,0x070d000b,0xdca31427}},	// [1e80] rbis, lyön, हराव_, вати
  { {0x1c39004a,0x60c00012,0x7c241428,0x7d041429}},	//   яясь_, ümmu, rrir, sbis
  { {0x3dc90026,0x68ed006f,0x41b3002b,0x7d0f01d3}},	//   blaw_, ľadn, _سمیر, _fecs
  { {0xdb1c002d,0xda6500e6,0xd00f002b,0x7c24142a}},	//   _phró, عالي, _حلی_, prir
  { {0xb8f6014e,0xd7ef0029,0x0000006a,0x0000006a}},	//   _हर_, لكن_,   ,
  { {0xa6340036,0x4b55006b,0x25ad0061,0xa01b007f}},	//   енкі, _пъст, enel_, kyön
  { {0x9f8d002e,0x97c50015,0x5ee9000a,0x0000006a}},	//   nþá_, رتهم, הַפְ,
  { {0xba9b000a,0x2b580030,0xa53408b0,0xb6060085}},	//   _וסלי, _harc_, хнич, vošć
  { {0x9326002b,0x31b9006f,0x6b730535,0x0000006a}},	//   وردن, cézy_, _węgł,
  { {0x42740080,0xa87b0008,0xb6060085,0x81bd003d}},	//   егос, _ואמר, tošć, grēn
  { {0xa1590054,0xe2140033,0x51f802a3,0x3218142b}},	//   пану_, эмны, янню_, éry_
  { {0xc4860191,0x21670036,0x5a170053,0x546a0010}},	//   _олек, фтог, וקטן_, _маем_
  { {0xf5770029,0x1074007a,0xc058022a,0xa3e7000b}},	//   _تمنع_, вляю, мір_, _मंच_
  { {0x0efb014e,0xbefb000b,0x88060065,0x42560058}},	//   ्रेस_, ्रेन_, सीएफ़_, _ينشر
  { {0x7d0f0030,0x52730015,0x3dc9055e,0xfebb002b}},	//   _pecs, _لايز, tlaw_, زاست_
  { {0xcdd80001,0xa5d805bd,0xe287009a,0x0000006a}},	//   дњу_, לַּי, _تطهی,
  { {0x2b580034,0x7d020077,0x60c00012,0x5c990138}},	// [1e90] _barc_, ñosa, ümmt, чкая_
  { {0x2bb80015,0x1a8b0015,0xcaa70015,0x5ffc000a}},	//   والة_, يضاً_, وصاي, _והזה
  { {0x7d0f1349,0xb50e000b,0xe9e90058,0x2019142c}},	//   _tecs, सराय_, أفصى_, lssi_
  { {0x68ed002c,0x7d1d0012,0x645c003d,0xdcef003d}},	//   ľado, _udss, ārij, ādēt
  { {0x6cfa0008,0x68ed04af,0x20190604,0xd9160067}},	//   _מפרס, žado, nssi_, ريوش_
  { {0x237c0b28,0x0000006a,0x0000006a,0x0000006a}},	//   _novj_,   ,   ,
  { {0x2bbe005d,0xcf940053,0x199504ab,0x7c2d142d}},	//   ्तरा, כטס_, _завя, luar
  { {0xc867006b,0x6d4d142e,0x0000006a,0x0000006a}},	//   _отзи, neaa,   ,
  { {0x73e5006b,0x7c2d142f,0x25ad02ff,0x25bf0045}},	//   ноиз, nuar, rnel_, roul_
  { {0xe2990001,0x69cb1430,0x182a002b,0x6d4d007c}},	//   зао_, llge, _رقمی_, heaa
  { {0x2019002e,0x6d4d00f2,0x7c2d1431,0x69cb00fc}},	//   essi_, keaa, huar, olge
  { {0x865a000a,0xa3cf000b,0xf652000a,0xe56e0033}},	//   _מדעי, _वीर_, _תצא_, _ёз_
  { {0xbcfb002d,0x656b04ed,0x5576000a,0x1fb60004}},	//   _gnéi, _ingh, _רענן_, есвр
  { {0x69cb00b8,0x7c2d1432,0x6fd50033,0x889a000a}},	//   hlge, duar, вісц, לברי
  { {0x3c430024,0x1eaa0015,0x442d1433,0x20191434}},	//   hīvā_, ساسي_, lue_, assi_
  { {0x52740029,0x7c2d002d,0x29e80061,0x0efb000b}},	//   _جاهز, fuar, _aşan_, ्रॉस_
  { {0x6aa8005d,0x442d0493,0x4339000a,0x7c2d1435}},	// [1ea0] कप्र, nue_, ּעֲב, guar
  { {0x3a060086,0xe0d70010,0xa3c1000b,0x69cb1436}},	//   فکری_, _явы_, ूति_, elge
  { {0x115a000a,0x63760045,0xa9260df0,0x5eeb000a}},	//   ּדְע, _pânz, едел, _מַכְ
  { {0xb17b00c0,0x442d1437,0xbe49002b,0x6d4d0079}},	//   rmåg, kue_, _کشیم_, ceaa
  { {0x637604f9,0xd1170008,0xd90d0086,0x442d003f}},	//   _vânz, תקנה_, زیل_, jue_
  { {0x656b0176,0x501b0008,0xdb07002e,0x7d161438}},	//   _angh, לונו, _skjö, lays
  { {0x442d1439,0x3ce6006f,0xca7a002b,0xa785002b}},	//   eue_, ľovu_, _عمرش_, خشنو
  { {0xfa890010,0x89da0015,0x09e3143a,0x0000006a}},	//   _ўсёй_, _روذر_, _босн,
  { {0x98af0091,0x349401b0,0x442d143b,0x6e2e06a8}},	//   degė_, тапр, gue_, hubb
  { {0x656b0026,0x96960877,0x51f80342,0xdc9b000a}},	//   _engh, _преш, мною_, פסיכ
  { {0xeb970008,0x9473002b,0xbcfb0003,0x7bde0045}},	//   גדיר_, ندیا, _inév, impu
  { {0x7c2d01c2,0x442d143c,0x9c870046,0x6e2e143d}},	//   yuar, bue_, ničí, dubb
  { {0x20190152,0xf1a40010,0xe82a0008,0xe3af002b}},	//   ussi_, урэн, הוָֽ, شری_
  { {0xa3cb000b,0xf1f7002b,0x20190bb5,0xccf90535}},	//   लतः_, بعیت_, rssi_, _żś_
  { {0x6f1500bd,0x656b0026,0x2e480142,0x71f70015}},	//   razc, _yngh, нято_, _كريس_
  { {0x40950029,0x7bde0509,0x99810046,0xdb0e0030}},	//   _للبر, empu, vrhů_, _okbó
  { {0xb81c000b,0x6d4d143e,0xac9400ce,0xab87009b}},	// [1eb0] _निगम_, reaa, гатш, нужк
  { {0xb17b0134,0x6d4d143f,0x69cb0079,0x3df51440}},	//   småd, seaa, wlge, _изос
  { {0x49390010,0x59390010,0x6d4d1441,0x7c2d1442}},	//   дзею_, дзеў_, peaa, suar
  { {0x4ac40029,0x3c430024,0x69cb007c,0xa91d00bc}},	//   ديمق, tīvā_, ulge, _možg
  { {0xe10c00b2,0xdee70086,0x89340015,0x7c2d1443}},	//   פּאָ, _تأکي, اعما, quar
  { {0x9be40010,0xa3cf005d,0xa2c1000b,0x58b80015}},	//   _біск, _वीं_, रॅड्, رانج_
  { {0xead40080,0x9732002b,0xcb12000a,0xcf58000a}},	//   _борь, شکلا, _כלם_, גבות_
  { {0x68fb0034,0xa01b008c,0x442d1444,0x9c87006f}},	//   _ufud, työl, tue_, cičí
  { {0xe432003b,0x0000006a,0x0000006a,0x0000006a}},	//   لفيد,   ,   ,
  { {0x8235002b,0xe71900c3,0x394f1445,0x2d9e0003}},	//   پردا, _آيات_, legs_, étez_
  { {0xbb3c0053,0x36750029,0xfbd20008,0x442d106a}},	//   לעזי, _جهاز, שתי_, sue_
  { {0xe4d90029,0xdb1e1446,0x656b0824,0x0f0a000b}},	//   _قوات_, ropé, _ungh, वर्स_
  { {0x442d1447,0x80d9005e,0x7bde1448,0x0000006a}},	//   que_, еєру_, ympu,
  { {0x6e2e1449,0xdb1c005a,0x0000006a,0x0000006a}},	//   tubb, _okrá,   ,
  { {0x6da60e91,0x62640015,0x7d020077,0x5cf60138}},	//   вива, _مايق, ñoso, вязу
  { {0x3205003e,0x12e80135,0xedc70015,0x3236000a}},	//   mply_, _אַפּ, نِّي_, _סטפן_
  { {0xa91d010b,0x2bf60080,0x5f060063,0x7fda0004}},	// [1ec0] _možd, тябр, _изпа, _офот_
  { {0xaf0a0029,0x6e2e04ed,0x7d160035,0x7e9a0029}},	//   _تقدم_, pubb, says, _ينظر_
  { {0xfeba0015,0xdee603ae,0x0000006a,0x0000006a}},	//   _زادت_, _јони,   ,
  { {0x9975004a,0x637e0046,0xdd050045,0x984a005e}},	//   лучш, _záně, ăsăr, дяка_
  { {0x81bd0024,0xe995002b,0xd7f00058,0xc7ba0138}},	//   frēj, دهنگ, حكت_, мёк_
  { {0xe7180015,0xc66a004a,0xb7d700c3,0xa09b000a}},	//   ريبت_, дшие_, نونا_, וינט
  { {0x98b201e2,0x092a0015,0xcf93000a,0x7d7c000a}},	//   ıyı_, _يسري_, שטו_, ּנ֖ו
  { {0xceb30008,0xd6d9005e,0xaa57002b,0x0466144a}},	//   ייו_, хті_, _جلفا_, втом
  { {0xdb1c0089,0x3205144b,0xa01b005b,0x0000006a}},	//   _zkrá, eply_, työm,
  { {0x32540432,0xe3af0015,0x98750061,0xa91d00bc}},	//   гвор, ْرَ_, lüğe_, _požg
  { {0xc56a0029,0xd6250015,0xc5f6009b,0x66e60766}},	//   _يحصل_, _معني, _рязъ, _рожа
  { {0xfbdf0026,0x316d1279,0x28d9000b,0x75380535}},	//   _apêl_, ñez_, बेकि, óczę
  { {0x90540010,0x60d6002a,0xf206000b,0x71a40033}},	//   авяц, _czym, वीज़_, раўз
  { {0x547b013a,0x9e35056d,0x8233002b,0x3266005e}},	//   _קטגו, легч, دریا, _атив
  { {0x63a8144c,0xdb060046,0xdd950033,0x2bec000b}},	//   midn, ámýc, гавы, _अंजू_
  { {0xf2d30053,0x7bc7144d,0x865b000a,0xa91d0046}},	//   _דעצ_, _skju, ודלי, _kože
  { {0xdb1c0084,0xfbd9023e,0xfaff0024,0xa91d07c4}},	// [1ed0] _skrá, едај_, žīms_, _jože
  { {0xa91d010b,0x8f550191,0xfecb0029,0xe4ab000a}},	//   _može, _свої, _يبدو_, וֹבָ
  { {0x7ac4119f,0x7522122c,0x61ed0eca,0xdb05001a}},	//   асце, _odoz, _kial, nihé
  { {0x629a00dc,0xeb9f02de,0xafdb02de,0xaa6401f3}},	//   izto, _stød_, stød, штук
  { {0xc19c0008,0x61ed003f,0x81bd0024,0x23b4000b}},	//   ושאי, _mial, trēj, ुवाद
  { {0x752202b9,0x89fb0015,0x47c401f3,0xab84013e}},	//   _adoz, _يعزز_, абів, _куск
  { {0x6d5d025c,0x27ec003e,0x3f810089,0x86980063}},	//   _kasa, _didn_, _mohu_, ктът_
  { {0x7bc5003f,0x63a8144e,0x62880e63,0xe459144f}},	//   lohu, eidn, dydo, ежи_
  { {0x629a0024,0x6d5d1450,0x60cd1451,0x0000006a}},	//   ezto, _masa, _nyam,
  { {0x2bd9005d,0x60d6005c,0x6d5d1452,0x490b000b}},	//   _बीमा, _rzym, _lasa, ारको_
  { {0x16380015,0x60d6002a,0xe207002a,0x42541453}},	//   _لسنة_, _szym, _ogół_, атят
  { {0x74b9000d,0x61ed002d,0x320500da,0x6d5d1454}},	//   _пулс_, _cial, rply_, _nasa
  { {0x343900b2,0x7bc50020,0xc9520008,0xb0de000b}},	//   _נײַע, kohu, צמך_, नेंग
  { {0x443f0048,0x947404c9,0x32051455,0xe47a000a}},	//   mtu_, _خدما, pply_, _רָאש
  { {0x443f07e8,0xa2ca005d,0x6288005c,0x629a005c}},	//   ltu_, _सुप्, cydo, czto
  { {0x2d95008f,0x61ed04ed,0x5de61456,0x6d5d00be}},	//   арус, _gial, ужба, _casa
  { {0x2004002d,0x6d5d0849,0x4fb60015,0x443f1457}},	// [1ee0] ímid_, _dasa, _مصدر, ntu_
  { {0x28b7005d,0x7980003f,0xa09b00a3,0x443f1458}},	//   _आख़ि, _somw, _נייט, itu_
  { {0x443f0005,0x092a0080,0x69db002d,0x657b007c}},	//   htu_, ежей_, _bhue, kjuh
  { {0x7d560036,0x644b1459,0xa9c501f3,0x8d56145a}},	//   _стої, _opgi, асік, _сточ
  { {0x657b0020,0xa2ca005d,0x443f06cf,0x8eb3002b}},	//   djuh, _सुन्, jtu_, _نمیش
  { {0xcb760001,0x6d5d145b,0xdb1c145c,0x35f7002b}},	//   _сумњ, _zasa, _skræ, گرود_
  { {0x6d5d01e2,0xbb3b0053,0xa01b00f2,0x569402c8}},	//   _yasa, _רעלי, työk, райт
  { {0x7df50780,0x77920086,0xda4b000a,0x2d82055e}},	//   _sąsk, _گیتا, _אֲמָ, _joke_
  { {0x61ed002f,0x443f0024,0xc50a0086,0x97360087}},	//   _rial, gtu_, وتکل_, _معاص
  { {0xb8930029,0xf20607de,0xdb1e0227,0x61ed145d}},	//   _الكع, лямо, kopí, _sial
  { {0x61ed0375,0xf3630256,0x60cd0375,0xa175008b}},	//   _pial, стын, _syam, агні
  { {0x7bc5000c,0x62880026,0x443f0049,0x7df5002a}},	//   zohu, rydo, btu_, _wąsk
  { {0x7bc5000c,0x629a145e,0x14390086,0xa3cf000b}},	//   yohu, szto, _لينک_, _वीक_
  { {0xd3700029,0x60cd003f,0x98a9005c,0x225802de}},	//   _ذهب_, _vyam, żać_, ærks_
  { {0xcddb0431,0x12fb000a,0x02fb000a,0x6d5d145f}},	//   ења_, _אהוב, _אלומ, _pasa
  { {0x2d5805cb,0x5d55000d,0x3cb5006b,0x7ae10f9c}},	//   лись_, јкат, айбр, _últi
  { {0x7bdc002f,0x6560002d,0xdb070247,0x6d5d1460}},	// [1ef0] _bhru, idmh, šmír, _vasa
  { {0x7bdc002f,0xa01b00f2,0x6d5d0cf9,0x39b10007}},	//   _chru, vyöh, _wasa, mąsi_
  { {0x6440007c,0x443f002a,0x19590033,0xaa550925}},	//   htmi, ztu_, кажы_, рвеш
  { {0x25fb005d,0x4237004c,0x7bc5007c,0x9f600030}},	//   _लंबी_, רנאל_, sohu, örös_
  { {0x998700dc,0xb8fd005d,0x443f0156,0xe8f802e1}},	//   énő_, _डर_, xtu_, улі_
  { {0x16390029,0x8ae702e5,0x6605000d,0xd702005e}},	//   نسبة_, _бібл, апка, озши
  { {0x66240029,0x96750010,0x2d820705,0xdb051461}},	//   مريك, рылі, _yoke_, rnhä
  { {0x7c2d04ed,0xd6ce0029,0x443f1462,0xd5b100e6}},	//   orar, بقى_, ttu_, تفع_
  { {0x9984003b,0x765a1463,0xf992000a,0xed600046}},	//   _القو, _esty, _ורן_, ážit_
  { {0x47340086,0x657b0e95,0xc245000d,0x395f1464}},	//   _هرمز, sjuh, анок, _haus_
  { {0x7d0d00c0,0xe2b50010,0xa229006b,0x6d44028a}},	//   kbas, рспэ, ъжна_, yfia
  { {0x9f490084,0x7c2d1465,0x7df5002a,0x41b30015}},	//   _stað_, krar, _gąsi, ْمَر
  { {0x95c40086,0x6459003f,0x2d8200bc,0x644e0045}},	//   _اينه, _uswi, _roke_, ăbic
  { {0x765a0176,0x23290036,0xc7b20053,0x20040024}},	//   _ysty, _роки_, ַבן_, īmi_
  { {0x442d0014,0xc332004c,0x91fc003d,0xdee61466}},	//   lre_, _ווו_, lvān, рови
  { {0x442d1467,0xb2ba0447,0x7bdc00da,0x7d0d09cf}},	//   ore_, _במצר, _shru, gbas
  { {0x6fd60210,0xed570004,0x6db70085,0x6d441468}},	// [1f00] _вінц, шот_, pćan, rfia
  { {0x8b260036,0xdb23002e,0x442d1469,0x25a90046}},	//   рдже, ærða, ire_, čaly_
  { {0x442d018b,0x2d9e0152,0x49060015,0x29e80061}},	//   hre_, ètes_, لواق, _uşak_
  { {0xdb1c00c0,0x3ebb000a,0x8dfb000a,0x7c2d146a}},	//   _skrä, _יציב, _שהכת, brar
  { {0x442d0134,0xed570063,0x7bdc111f,0x7c2d146b}},	//   jre_, _тоя_, _thru, crar
  { {0x7df51256,0xaa060087,0xa50e000b,0x442d0cbb}},	//   _sąsi, _نظره, सर्च_, dre_
  { {0x6603000d,0x6753002b,0x09e60342,0x1e96000a}},	//   опја, زخور, _вовн, יכַל_
  { {0x395f0007,0xda5b000a,0x6f1c146c,0x1d16000a}},	//   _gaus_, _בכלל, harc, ׁקֶר_
  { {0xd3700015,0x765a002a,0x442d146d,0x9f8d001a}},	//   كهة_, _wsty, gre_, rþú_
  { {0x883b013a,0x46a6010f,0x9378000d,0x6440146e}},	//   _בתמו, _казв, убот_, rtmi
  { {0xd257017f,0x6440146f,0xaf37002b,0x442d1470}},	//   аця_, stmi, یرست, are_
  { {0xa50a061e,0x0446017a,0x442d1471,0x7d0d0012}},	//   _реда_, _ведн, bre_, xbas
  { {0xdcef0048,0x9f84002e,0x6f1c0026,0x98b30024}},	//   ādīt, töð_, farc, _ādīt_
  { {0x7c2d1472,0x6304002b,0x6f1c1473,0xe4510c44}},	//   vrar, _اوغل, garc, _זֶה_
  { {0x63bd00dc,0xfda70054,0xa311006f,0x9f84001a}},	//   ésne, ајам, äčšo, röð_
  { {0x527b0008,0xf27b05af,0xb11503de,0x20040144}},	//   _ינוא, _ירוש, _умиш, ímic_
  { {0xdce600df,0x5ce70036,0x91bc0008,0x2d58007a}},	// [1f10] _mokė, рюва, _שמחי, шить_
  { {0xea670001,0x09bf000b,0xd9bf000b,0x388e003d}},	//   ињен, एक्य, एक्ट, _mērā_
  { {0x442d1474,0x38660012,0x200b00bc,0x41bb000b}},	//   zre_, evor_, lpci_, _उदास
  { {0x442d1475,0xa91d044c,0x7c2d1476,0x75e701d3}},	//   yre_, _boža, prar, _tűzi
  { {0x4dda0008,0x67d5000d,0x5ea4002b,0x9f40030b}},	//   _תחרו, боду, _همیل, _guió_
  { {0xd8740074,0x67470010,0x442d1477,0x2058004c}},	//   تامب, рэдз, vre_, יידל_
  { {0x3618008f,0xaa950029,0xa6c90139,0x06090054}},	//   ацыю_, _الأث, ылка_, ћник_
  { {0xdeb8000a,0x0562006b,0x442d1478,0xceb8004f}},	//   יפוח_, звън, tre_, יפוק_
  { {0x291d00b6,0x3160001c,0x442d1479,0x4990002b}},	//   mawa_, _raiz_, ure_, _زیور
  { {0x316000d9,0x291d13bf,0x442d147a,0x0000006a}},	//   _saiz_, lawa_, rre_,
  { {0x442d0014,0xe6b3002b,0x5999000a,0xa91d147b}},	//   sre_, _بلاگ, ָשָׁ, _zoža
  { {0x291d147c,0x568c0053,0xcf89000f,0x6f1c10ec}},	//   nawa_, _שטאַ, _אט_, warc
  { {0xa4d40036,0xafe6005e,0xe8d5000a,0x6f1c147d}},	//   _доці, йомл, מוֹר_, tarc
  { {0x291d00d9,0xdb1e013f,0xb17b0f94,0xafe601d2}},	//   hawa_, kopá, lmål, согл
  { {0xc7d60008,0x291d147e,0x531a0643,0x7643002a}},	//   מושי_, kawa_, _עוקצ, ntny
  { {0x6dac0061,0x3d12000b,0xada301b0,0x6da3147f}},	//   aşan, ़रें_, пасл, писа
  { {0xdd8f0029,0x291d1480,0x6f1c1481,0xc19b000a}},	// [1f20] روك_, dawa_, parc, _תשפי
  { {0xc910000b,0xa3dd000b,0xc4d20643,0x6dac0045}},	//   ार्म_, _थीम_, לגן_, cşan
  { {0xdb070014,0xa96a0124,0xfaaa002b,0xa92a0033}},	//   ámár, лижа_, دهاي_, гіле_
  { {0x38cb0086,0xa91d0156,0x291d0fd1,0x91f6000a}},	//   گامی_, _poža, gawa_, צמנו_
  { {0x53c7014e,0x25ad002c,0x7643002a,0x38660012}},	//   रकाश, diel_, etny, uvor_
  { {0x38cb0086,0x18530010,0x9b960029,0xbb860029}},	//   دامی_, явіў, _الست, _الآي
  { {0x25ad0384,0x8d5a000a,0x1a78000a,0x291d1482}},	//   fiel_, ָכִי, _דְּמ, bawa_
  { {0xe5c60001,0x25ad002a,0x05760015,0x2d8000aa}},	//   љско, giel_, صاعد, njie_
  { {0x76430273,0x29d30015,0x03f80054,0x79ab000a}},	//   atny, _ريكس, јној_, _עֹלַ
  { {0x388e0048,0x5c5b0632,0x61e60079,0x442a00bc}},	//   _vērā_, נדיק, emkl, čb_
  { {0x3f85002e,0x21790010,0x4b7b0053,0xcb130008}},	//   ölum_, айны_, אטיג, הלת_
  { {0x3d12000b,0xf09f0144,0x7df50091,0xf484002b}},	//   ़रों_, tzà_, _mąst, _واشی
  { {0x7df50007,0x23e6042b,0x200b1483,0xe4d60067}},	//   _ląst, _лікв, upci_, _اتاب
  { {0xa294008f,0xdbf10089,0x291d1484,0x92940254}},	//   _малі, _příl, zawa_, _малц
  { {0x02430015,0xc7b3000a,0x6d8a001a,0x6e940ac9}},	//   _فَوَ, לבש_, _nýas, пиру
  { {0x81bd003d,0x0000006a,0x0000006a,0x0000006a}},	//   grēt,   ,   ,
  { {0x4dd40015,0x75e70030,0x539a004f,0x7dd3007f}},	// [1f30] ستفس, _tűzv, ְי֣ו, nçsi
  { {0x81bd0024,0xdea40086,0xd879002b,0x7a050091}},	//   arēt, _کیفی, یمات_, _lėte
  { {0x9f840020,0xdab900e6,0xcae3000b,0xda080015}},	//   töö_, جهات_, केंड_, ميله_
  { {0x8f550086,0xbae40015,0xd7f10016,0x6ab9000b}},	//   _انگش, سكني, _sĩ_, _आशीर
  { {0xf7700074,0xc9740029,0x291d1485,0xa2ca000b}},	//   کان_, ثالث, rawa_, _सुस्
  { {0xcc76000a,0x501c000a,0x25ad06a8,0x291d1486}},	//   _ועשה_, רוגו, wiel_, sawa_
  { {0x19950010,0xfbd2000a,0xda09000a,0xd7f10016}},	//   _давя, _חתם_, _כִּ֚, _vĩ_
  { {0x91fc0024,0x8429005e,0x6fd202de,0x200901c2}},	//   rvāl, ажив_, ræci, _otai_
  { {0xad1c000a,0x04560015,0x25ad1487,0x76431488}},	//   אוחר, قلية_, riel_, stny
  { {0xe3b10015,0x42251489,0xb17b02cd,0xe795002b}},	//   ظرة_, одов, smål, _بارک
  { {0x09b500b2,0xf4860086,0x25ad148a,0x36040015}},	//   ַפֿט_, مایی, piel_, _فولف
  { {0xe3b80061,0x6a3a000a,0x69cb148b,0x0000006a}},	//   anı_, סגרפ, noge,
  { {0x69cb0026,0x6d5600da,0xb5c8009a,0x61e6148c}},	//   ioge, veya, _اونم_, rmkl
  { {0xaab9005d,0xe3b30021,0x69cb148d,0xa856004f}},	//   _आशंक, _عرش_, hoge, חישה_
  { {0x59c9014e,0x2d8000dd,0xf7720008,0xe819000b}},	//   िकार, tjie_, וקם_, नीता_
  { {0x753b000c,0xed460033,0xa01b008c,0xe62700a1}},	//   nguz, ўнап, työt, _đổ_
  { {0x80e60015,0x81bd003d,0x2bb0002a,0x8c430499}},	// [1f40] _بأغل, arēs, eńca_, мете
  { {0x2d99148e,0xeab20015,0x6d560003,0xab2a02bb}},	//   _else_, وعا_, seya, рожа_
  { {0xe8fa148f,0xa01b008c,0x539a000a,0x386d00cb}},	//   але_, syöt, סיעו, _arer_
  { {0xfd120029,0xcd36002b,0x69cb1490,0x6edb004f}},	//   _تجد_, _بردب, goge, _כחיפ
  { {0xe3b80064,0x7791002b,0x7d041491,0x97c6030c}},	//   ynı_, کیلا, mcis, ойде
  { {0x7c241492,0x7d041493,0xf093000a,0x262a03ae}},	//   msir, lcis, ונד_, ацио_
  { {0x07a3000d,0x41ca005d,0xbf9b0003,0x8f7b000a}},	//   ќајн, रवास, mpêt, ינסק
  { {0x69cb1494,0x38aa002a,0x342603ae,0x7d041495}},	//   coge, tórą_, офов, ncis
  { {0xdb1e0134,0xb866002b,0x7c241496,0xf7560058}},	//   ropæ, _بازو, nsir, _ونرج
  { {0xa3e70001,0x77920086,0xbb3a000a,0x66760021}},	//   одња_, _زیبا, ׁעִי, _ودار
  { {0x8afb1077,0x6b83002e,0x20090824,0x5b57000a}},	//   יליז, öngi, _stai_, חייב_
  { {0xa194022a,0x9633042b,0x7c241497,0x61f70033}},	//   даюч, _ініц, ksir, ўняў_
  { {0xa2ca014e,0xd5e90015,0x2bbf000b,0xd1300015}},	//   _सुर्, _اعلن_, ्वमा, ضمّ_
  { {0xc0580191,0x09b7005d,0x69cb00b8,0xe4e90067}},	//   цію_, _अद्य, zoge, _طعنه_
  { {0xdef40010,0x8d7700e6,0xf3c90029,0x11d70015}},	//   дпры, يارا, _ابنه_, _وتعد
  { {0x7c241498,0x212900e8,0x329b000a,0xe29b000a}},	//   fsir, _udah_, _כבוד, _כשור
  { {0xe5710008,0xdfdb006b,0x7dda0144,0xdb1e008c}},	// [1f50] עַל_, _вън_, aïso, kopä
  { {0x63ba00b8,0x78a2002c,0x7982002a,0xdfab0067}},	//   nntn, dzov, ejow, _خطبه_
  { {0x7c2400df,0x6b51001a,0x69cb1499,0xb955004a}},	//   asir, _aðgæ, toge, звещ
  { {0x4426052c,0xc27b000a,0x7d04149a,0x91fc01ec}},	//   _ovo_, ירבי, ccis, evāk
  { {0x6c790053,0x5d7a000a,0xdb1e007c,0x7d7a000a}},	//   _האָפ, _הארק, fopä, _הנרו
  { {0xbdf80086,0xfc16000a,0xf7940033,0xe7a8005e}},	//   _دریا_, _מקשי_, мачэ, овіл_
  { {0xa2ca000b,0xff18000a,0x29dc0077,0x4426149b}},	//   _सुल्, חקות_, mían_, _avo_
  { {0x7982005c,0x29dc0077,0x386d00cb,0xdebc000a}},	//   cjow, lían_, _trer_, ימול
  { {0x93790029,0xe3b10115,0x7d1d0fb7,0x7d010030}},	//   مصدر_, فرد_, _mess, _záró
  { {0xf8ae0086,0x29dc02c1,0x79890161,0xcc76000a}},	//   _حکم_, nían_, _hoew, פעתה_
  { {0x03220010,0x7d04005c,0xe664004a,0x4426149c}},	//   эдэн, ycis, _отцо, _evo_
  { {0xe6100086,0x7d1d149d,0xc19a005e,0x7c24005b}},	//   _ششم_, _ness, стої_, ysir
  { {0xb4fa0008,0x764b0007,0x34fa000a,0x92b5002b}},	//   _הפני, žnyč, _ההנד, تحکا
  { {0x6dac0061,0x0ef90033,0x8f750033,0x7989149e}},	//   rşam, жэты_, мусі, _loew
  { {0xf7720053,0x29dc02c1,0x2d9602bf,0x7d1d149f}},	//   עקל_, dían_, прас, _bess
  { {0xb8830d05,0x91e30063,0x7c240205,0xa5c6001a}},	//   _klíč, _поще, tsir, mkóð
  { {0xe3190092,0xeafa00e6,0x113b000a,0x7d0414a0}},	// [1f60] _điể, مرات_, _התפל, rcis
  { {0x7d0404a0,0xa01b008c,0xdbf10046,0x29dc0077}},	//   scis, pyör, _přál, gían_
  { {0x4efb0008,0xc3320008,0xafdb0134,0x61e414a1}},	//   _להיו, תוב_, ktøj, _khil
  { {0xfbc90008,0xe9d20015,0x7d010030,0x7c2414a2}},	//   את_, رغا_, _váró, psir
  { {0x29dc02c1,0x61e40125,0xdb1e008c,0xafdb01d0}},	//   bían_, _mhil, topä, dtøj
  { {0x29dc02c1,0x60d600f2,0xc7a314a3,0x07a314a4}},	//   cían_, _myym, ничк, начн
  { {0x4e7a00b2,0x44260084,0xdb1e14a5,0xa3c1000b}},	//   מאַצ, _svo_, ropä, ्कन_
  { {0x2abb0008,0x798900aa,0xcad7000a,0x7abb000a}},	//   _המלא, _goew, _זולת_, _הצלו
  { {0xa5070001,0x86c6002b,0x18a3004a,0x85b70015}},	//   чења_, _کيان, _затм, ثاوس_
  { {0xe44f003b,0x389b0008,0x889b000a,0x6f1e0085}},	//   اضي_, _הימנ, _השמצ, _nepc
  { {0xc444002b,0x7dda0079,0x2bbf0065,0xd57600ce}},	//   سیژن_, eïsm, ्वता, _нудь
  { {0x867b0008,0xd6eb0008,0x4426002e,0xd5fb0008}},	//   _לרבו, _הַדָ, _tvo_, _הפאר
  { {0xa91d0263,0x6ab9000b,0x6d98001a,0xf44001f3}},	//   _božj, _आश्र, _pían, _ролi_
  { {0x64470045,0x7a050091,0x7d1d14a6,0xa91d14a7}},	//   ăjit, _lėta, _sess, _rožm
  { {0x7d1d14a8,0xd3e50086,0x61e4002d,0x29dc02c1}},	//   _pess, _تقوی, _fhil, vían_
  { {0x61e40011,0xb2bb000a,0xfd130015,0xa2bb000a}},	//   _ghil, _למור, عجز_, _למוט
  { {0x6ecd005d,0x7d1d14a9,0xa3d0000b,0x29dc0077}},	// [1f70] _दुरु, _vess, वकप_, tían_
  { {0xa3cc000b,0x7e6102de,0x798914aa,0x7d1d14ab}},	//   लवि_, ælps, _soew, _wess
  { {0x29dc02c1,0xbb840029,0xecf90484,0x7d1d14ac}},	//   rían_, علمي, _менш_, _tess
  { {0x6f1e002a,0xbcfb0030,0x29dc0052,0x0000006a}},	//   _zepc, _lnéz, sían_,
  { {0xa3cc0065,0x0000006a,0x0000006a,0x0000006a}},	//   लवा_,   ,   ,
  { {0xccf2000a,0x35d5000b,0xbc7a000a,0xf77300c3}},	//   _שכך_, _डीज़, _ונשת, عاش_
  { {0xc7c80010,0x6b83002e,0x79890111,0x99d70015}},	//   чыце_, öngu, _toew, _فترا
  { {0x24090080,0x6d4d064e,0x75d50015,0xa2ad000b}},	//   онии_, nfaa, بيعا, ुपस्
  { {0x2900002c,0x25aa002b,0xafdb02de,0xa8340054}},	//   žiac_, تضوی_, rtøj, _петљ
  { {0xdc88000a,0x57b4005e,0x9f530003,0x69d914ad}},	//   לְתָ, _збут, _fixé_, llwe
  { {0x6723065d,0x61e4010c,0x6f1e00bc,0x95cb0763}},	//   manj, _phil, _repc, _луда_
  { {0xa5c60084,0x3d17000b,0x24550015,0x27ff008c}},	//   rkóð, तरों_, _يناس, _kuun_
  { {0xa5c6002e,0xfbbf000b,0x21a3004a,0x27ff007c}},	//   skóð, ्वाम, тиям, _juun_
  { {0x61e4003e,0x82350086,0x98b2005c,0x27ff00f2}},	//   _whil, _قربا, żyć_, _muun_
  { {0x644914ae,0xa01b005b,0x0000006a,0x0000006a}},	//   ltei, syöp,   ,
  { {0xf2d2103d,0x64490024,0x672314af,0x656914b0}},	//   _שעה_, otei, hanj, ndeh
  { {0x6723116e,0xab660010,0xbfc60661,0x1c460010}},	// [1f80] kanj, мвал, _обик, ьнам
  { {0x672314b1,0xd9b8005d,0x8fa6002b,0x7ed600c3}},	//   janj, ेक्ट, _آمده, _يزدا
  { {0x64490c8d,0x236700bd,0x67230a00,0x8f7b000a}},	//   htei, _manj_, danj, _וניק
  { {0x3a3a0f3a,0xaae50018,0xdcfd002a,0x644914b2}},	//   rupp_, رسلو, _posą, ktei
  { {0x26030467,0xdb0e0084,0xdcb90080,0x0d830033}},	//   _año_, þjón, _ещё_, _рлян
  { {0x31bb005d,0xe7040086,0x69d900dd,0x236700bd}},	//   _उद्ध, رستی, alwe, _nanj_
  { {0x88bd005c,0xc34e0016,0x644914b3,0xda630e4d}},	//   _odśw, _bổng_, etei, _иври
  { {0xc34e0092,0x7a8b000a,0x64490012,0xe819000b}},	//   _cổng_, _וָמַ, ftei, _नौका_
  { {0x6e3c0061,0x3f98001a,0x672314b4,0x69d90030}},	//   hurb, kkru_, banj, őbeá
  { {0x6723044c,0xdb050061,0x68fb0045,0x969614b5}},	//   canj, rihç, _zgud, _ореш
  { {0xfb370053,0x644914b6,0xa294017f,0x7d1600aa}},	//   ואיש_, atei, хані, kbys
  { {0x6e3c002e,0x92930010,0x64490012,0x6dac0061}},	//   durb, таюц, btei, ağaz
  { {0x14e2014e,0x2d8b0089,0x3e4800b8,0x64490251}},	//   _परिण, _roce_, eßt_, ctei
  { {0x61ee002c,0x6e3c00da,0x7052002b,0x0000006a}},	//   _ďale, furb, اچيا,
  { {0x518714b7,0x433b000a,0xfbbf000b,0x333b000a}},	//   _жупа, _ועוב, ्वसम, _ותומ
  { {0x6723044c,0x236700bc,0xa2ad0065,0x0000006a}},	//   zanj, _zanj_, ुपर्,
  { {0x2d8b0ede,0xf1bf12c3,0xbb7500af,0xb6010052}},	// [1f90] _voce_, mná_, нгај, _þáve
  { {0x291f0251,0x7f5c0251,0x4fc7017f,0x0076000a}},	//   _seua_, cerq, _іспа, _נתתי_
  { {0x672314b8,0x6449003d,0xc955055f,0xdb1c013f}},	//   vanj, ztei, етлы, _ukrý
  { {0xead8005e,0x67230573,0xf1bf14b9,0xad19000a}},	//   ємці_, wanj, nná_, _מוֹר
  { {0x6723052c,0xd8b800e6,0xe72e022a,0xb9920021}},	//   tanj, ودها_, ле_, طلوب
  { {0xf771003b,0xa3dd005d,0x8c1a000a,0xf7490015}},	//   طات_, _थीं_, _מושי, سلبي_
  { {0xe9190036,0xf6510067,0x291f0144,0x672314ba}},	//   _нові_, ائت_, _teua_, ranj
  { {0x644914bb,0xf1bf0107,0x672314bc,0xd5e80015}},	//   ttei, jná_, sanj, وعين_
  { {0xf1bf0107,0x644914bd,0xe4560033,0x656914be}},	//   dná_, utei, ежы_, rdeh
  { {0x43740036,0x644914bf,0x9cd8000a,0xd2a9004a}},	//   вуют, rtei, ווחה_, зкое_
  { {0xc34e0023,0xfbd20008,0xb345016e,0x236700bc}},	//   _tổng_, רתי_, _acçã, _vanj_
  { {0x0efa0372,0x46580029,0x1a9a0053,0x216a10a0}},	//   ्ड्स_, _تؤكد_, פירע, чими_
  { {0x43950010,0x25bf0011,0x66010020,0x395d14c0}},	//   _падс, mnul_, _hulk, iews_
  { {0xb46405d1,0x2d8f08e9,0xe436000a,0x660114c1}},	//   _шкіл, ögen_, _נרצח_, _kulk
  { {0x6601022d,0xf1bf0227,0x539a000a,0x25bf0045}},	//   _julk, bná_, _מיסו, onul_
  { {0xdd9200e5,0xf1bf0107,0xec160021,0xac0a0004}},	//   دور_, cná_, فورد, знаа_
  { {0x45da00b2,0x81bd0024,0xc5f2000f,0xdca30b5c}},	// [1fa0] פֿלא, ksēj, רדן_, гати
  { {0x7d160176,0xa3c1005d,0x67210607,0x0083005e}},	//   sbys, ्कि_, _nelj, _сльо
  { {0xdb1c005c,0xe7e3000b,0xa91d00bc,0x25bf0046}},	//   _skró, गतना_, _zoži, knul_
  { {0xb8660029,0x6da60036,0x08c6000d,0x621a000a}},	//   فاتو, _чима, нбен, פונק
  { {0xa3c1005d,0x69c30003,0x6721036d,0x3cfb000a}},	//   ्का_, énea, _belj, _מלכנ
  { {0xd7ef003b,0xe66600d0,0xf1bf0107,0x672100bc}},	//   مكن_, етио, zná_, _celj
  { {0xdb1c005c,0xd2cf005d,0xcf930008,0xfbc30080}},	//   _wkró, _सुलझ, רטו_, _сбро
  { {0xceb3000a,0xa96714c2,0x25bf0045,0x660114c3}},	//   טיו_, _писа_, gnul_, _dulk
  { {0xe73a000d,0xf1bf0264,0xb7da0115,0x9f4a0144}},	//   _неа_, vná_, _فورا_, ambé_
  { {0x42740036,0xa857000a,0x25bf0045,0xc4530015}},	//   вгос, _אימה_, anul_, اضيع
  { {0x36360086,0xf1bf099c,0x9bb7000a,0xdc030046}},	//   _سراس, tná_, תהיה_, včíh
  { {0xa91d14c4,0xf484002b,0x672106f2,0xd5b20015}},	//   _poži, _لاتی, _zelj, _حفص_
  { {0x557700b2,0x4fc7006b,0x660114c5,0xf1bf14c6}},	//   _רעדן_, есва, _zulk, rná_
  { {0xe47b00f3,0xf1bf0057,0x54970033,0x533408a0}},	//   _מרדכ, sná_, _явіў_, _рект
  { {0x862b000a,0x7d090015,0xf1bf14b9,0xade7006b}},	//   ּֽלֶ, ِيرِ_, pná_, ецак
  { {0xcdd80001,0xdce60061,0xa91d00bc,0xc2530015}},	//   ењу_, _alkı, _toži, _إخوت
  { {0x41c400e5,0x0000006a,0x0000006a,0x0000006a}},	// [1fb0] _حقيق,   ,   ,
  { {0x09c90065,0xf411004f,0xd9c90065,0x0000006a}},	//   िक्य, ׁ֤ב_, िक्ट,
  { {0x29120061,0x7cea0030,0x672114c7,0x9b440369}},	//   ıyan_, töré, _relj, انمو
  { {0xd2b70008,0x4998005e,0xf8b90015,0xc98408a6}},	//   עלאת_, нтія_, وهاب_, лучи
  { {0x09040036,0x660114c8,0x8934002b,0x395d00da}},	//   упін, _sulk, طعنا, rews_
  { {0xec360008,0xd7f80054,0x660114c9,0xb17b0123}},	//   _באשר_, нуј_, _pulk, llåd
  { {0xbbbf014e,0x36660063,0xb51c005d,0xe5710029}},	//   ्वीक, ващо_, नरूप_, لطة_
  { {0x25bf0045,0xdcfd002a,0x99d70015,0xc654002b}},	//   unul_, _posę, _أتسا, افيک
  { {0x9f5308e0,0x672114ca,0x25bf0011,0x79c80015}},	//   _així_, _telj, rnul_, _أوقف_
  { {0xe2990001,0x660114cb,0xe8740002,0x75c80046}},	//   дао_, _tulk, _حافظ, věze
  { {0xb2f40080,0x52820010,0x25fa000b,0xd5ae002b}},	//   ляющ, агэб, _ऊंची_, صفی_
  { {0x7afa002e,0xe196004a,0x75c80046,0x2d8f0012}},	//   _útte, троэ, těze, ögel_
  { {0xd00f0015,0x2ca90085,0x9596000a,0xd469011e}},	//   يلَ_, jzad_, _שכנו_, _циле_
  { {0x656b017e,0x52850015,0xf70e0016,0xdb1e0061}},	//   _hagh, _للتك, hủng_, üyüy
  { {0x443f0df8,0x7e2301ca,0xb17b01d0,0x645c00d4}},	//   luu_, идрж, flåd, ărie
  { {0x3f85002e,0x91fc003d,0xfce6118a,0xdde90067}},	//   ölur_, rvāt, вобо, فرقه_
  { {0x443f14cc,0x656b14cd,0x6f020045,0xfc030129}},	// [1fc0] nuu_, _magh, _şocu, ипто
  { {0xb17b003c,0x91fc0024,0x656b14ce,0x4e0611b3}},	//   småt, mvār, _lagh, _изоб
  { {0x6a86010f,0x628700f2,0x443f14cf,0xbf9b000a}},	//   ължа, äjoh, huu_, _חייש
  { {0x656b00b6,0x64590177,0x443f14d0,0xceb3000a}},	//   _nagh, _opwi, kuu_, _כית_
  { {0x91fc0024,0xa87a0015,0x443f128b,0xd90d002b}},	//   nvār, بحار_, juu_, سیل_
  { {0x2b58002b,0x98a30054,0x6d4414d1,0x244b01d0}},	//   _سیصد_, риље, lgia, døm_
  { {0xacbb0003,0x6d44007c,0x6eb7000b,0x87250015}},	//   _jeûn, ogia, ोपयु, اعهم
  { {0x7ae300dc,0xb5aa0015,0x6d4414d2,0xd5b7055f}},	//   ünte, باتك_, ngia, ксы_
  { {0x91fc0024,0x80e1000b,0xe7320015,0xa7660054}},	//   jvār, _नरें, _نصا_, _икад
  { {0x96b60054,0x0000006a,0x0000006a,0x0000006a}},	//   _исељ,   ,   ,
  { {0xc7d70008,0xbb3b0008,0x32630063,0x88bd002a}},	//   _יומי_, ועיי, атяв, _teśc
  { {0x69c20026,0xc05b005e,0x0000006a,0x0000006a}},	//   nnoe, міг_,   ,
  { {0x91fc0048,0x20840029,0xe3af002b,0x753d0030}},	//   gvār, للَّ, صری_, ósze
  { {0x644014d3,0xf457000a,0x4fc409c3,0x6d4414d4}},	//   mumi, _סיור_, асса, egia
  { {0x75e50014,0xa3c1005d,0x7c3a0024,0x93fb0135}},	//   lóza, ्कर_, _ātra, _קלוי
  { {0x6d4402d7,0xbd450015,0xfd130015,0xd657000a}},	//   ggia, طنطي, شجر_, כילת_
  { {0x644014d5,0x5c75056d,0x4fc701b0,0x69c202d8}},	// [1fd0] numi, ылат, _асна, dnoe
  { {0x765a0050,0x5b140036,0xbbbf005d,0x6d4400e8}},	//   _opty, имут, ्वेक, agia
  { {0x63af0144,0xc333000a,0x5a350b1e,0x6e950b59}},	//   ècni, שוע_, унет, _сину
  { {0x644014d6,0x09d40010,0x8e1a000a,0x69c20034}},	//   kumi, аціў, _רֵיח, gnoe
  { {0x64400048,0x28f80036,0x5d3a000a,0xf7950033}},	//   jumi, вець_, _אתרא, ладэ
  { {0x60da0053,0x656b002d,0xb6050156,0x8a370015}},	//   ײַנג, _sagh, hláš, _لعرض
  { {0x656b025c,0xc6a70063,0x45d505b3,0x0f58000a}},	//   _pagh, ърди, лцит, דיום_
  { {0x4efc013a,0x443f00f2,0xa91d0085,0xc8790061}},	//   ולוג, tuu_, _požu, _ayşe_
  { {0x644014d7,0xe4320015,0x1994006b,0x656b02b9}},	//   gumi, مفيد, _татя, _vagh
  { {0x8c1a0008,0xa774000d,0xca35000a,0x75c80046}},	//   עותי, _клуч, ְנָה_, tězc
  { {0x6d4414d8,0x8ab6000a,0xb607006b,0xd7df000b}},	//   ygia, ָ֔יו_, _рязк, _पीएच
  { {0xa1360029,0xe5700087,0x443f0209,0x82f40033}},	//   دردش, _وطن_, puu_, шчыц
  { {0x7c2d00c0,0x79ba000a,0x7d0d14d9,0xad9b016e}},	//   jsar, תֶיה, dcas, _miúd
  { {0xafdb00cb,0xe46a001a,0x7c2d14da,0x442d14db}},	//   dtøs, sröð_, dsar, mse_
  { {0x442d14dc,0xfe710015,0xed5a14dd,0x6da600eb}},	//   lse_, يدِ_, нов_, гива
  { {0x69c300dc,0x442d0472,0x6d440091,0x91fd01ec}},	//   énel, ose_, ugia, svār
  { {0x6d4414de,0x442d14df,0x7077012c,0xf1b3004f}},	// [1fe0] rgia, nse_, _مميز_, _לסה_
  { {0x2bba0029,0x6d440304,0x442d14e0,0xd884002b}},	//   راءة_, sgia, ise_, یهای
  { {0x8ad5008f,0xb17b0134,0x442d034d,0x7d0d00da}},	//   аюцц, slåe, hse_, bcas
  { {0x442d14e1,0xafdb003c,0x6dac0064,0xcb090008}},	//   kse_, støt, aşar, לל_
  { {0x64e2005d,0x69c20150,0xe947002b,0x442d14e2}},	//   _परेश, rnoe, ارمی, jse_
  { {0x38cb0074,0x64400024,0x88350033,0x442d0c3e}},	//   رانی_, vumi, рэцц, dse_
  { {0x49940086,0x7f3b0053,0xe2870029,0xaab8005d}},	//   _پیشر, געצו, _اذ_, _आधिक
  { {0x644014e3,0xad9b002d,0xca97000a,0x75e60033}},	//   tumi, _giúd, _גדלי_, ыўле
  { {0xd326087a,0xb9930029,0x48e30608,0xdcef003d}},	//   льни, _القب, _готв, _rocī
  { {0x644014e4,0x533407c1,0x394614e5,0xbb3a000a}},	//   rumi, јент, lgos_, ׂעִי
  { {0x66e60080,0x7c2d0024,0x442d14e6,0x45460031}},	//   _сожа, zsar, ase_, _مناق
  { {0x394614e7,0x644014e8,0x7c2d14e9,0x14ca004a}},	//   ngos_, pumi, ysar, _пыли_
  { {0xc5f3013a,0x6fb50029,0x88bd005c,0x39460007}},	//   _הדף_, لمحا, _leśn, igos_
  { {0xe4fb000a,0x7d0d14ea,0xf413000a,0x1fa70054}},	//   _נפגש, wcas, _הפס_, урмг
  { {0x539b000f,0x7d0d00da,0xee84056d,0x99780091}},	//   _איגו, tcas, быто, nčų_
  { {0x7c870036,0x63ba14eb,0x56b7004c,0xf127005e}},	//   лузе, litn, אפלן_, _сько
  { {0xdfd10029,0x69c30152,0x1bb50033,0x20040144}},	// [1ff0] _ويب_, énem, абаў, ímit_
  { {0x212b14ec,0x8f55005e,0x39460077,0x7c2d14ed}},	//   lach_, _твої, egos_, rsar
  { {0x442d0700,0x6ffa000a,0x7c2d14ee,0xdb080030}},	//   zse_, _שהתפ, ssar, ólás
  { {0x212b14ef,0x32350053,0xa2bb004c,0x442d14f0}},	//   nach_, שטײן_, עמאט, yse_
  { {0x39490048,0x61ed002d,0x63ba14f1,0x672a001a}},	//   ļas_, _mhal, kitn, fafj
  { {0x212b002f,0x442d0020,0xb6590bb9,0x394614f2}},	//   hach_, vse_, вших_, agos_
  { {0x212b14f3,0x16a614f4,0xaa5c005e,0x69ca0003}},	//   kach_, ивши_, _перi, éfec
  { {0x212b005c,0x629a14f5,0x442d14f6,0x61ed14f7}},	//   jach_, dyto, tse_, _nhal
  { {0x212b14f8,0x442d0493,0x291d003f,0x75c1003d}},	//   dach_, use_, mbwa_, nēzi
  { {0x92f50036,0xb8940029,0x442d14f9,0xe3b10015}},	//   ичні, _الْع, rse_, ترب_
  { {0x61ed002d,0xf089000a,0x20190727,0x9bb6000a}},	//   _bhal, _קנ_, epsi_, שהתה_
  { {0xfad6000a,0x61ed02ff,0x63ba0125,0x442d14fa}},	//   יותך_, _chal, aitn, pse_
  { {0xd83e032c,0xc5f20008,0x15f40002,0xad66002b}},	//   _účte_, _ודא_, _اسلح, یاره
  { {0x629a14fb,0x1eaa0015,0x39460077,0x63ba0480}},	//   byto, نازي_, zgos_, citn
  { {0xc7b20008,0x39460007,0x733a0053,0x7db60c55}},	//   קבל_, ygos_, _סעקס, асац
  { {0x3d20014e,0x4ad9005d,0x7bc5001c,0xe1f20087}},	//   बरें_, _बुधव, enhu, _بست_

  { {0x8b260080,0xac0714fc,0x8c4609ac,0x2c0b002b}},	// [2000] идае, инта_, резе, نعلی_
  { {0x109b0008,0xb09b000a,0xafdb0af5,0x207b004c}},	//   _סביב, _סייר, stør, _יאפא
  { {0x7f3b0008,0x32070251,0x34e2005d,0x2f3b000a}},	//   _בעיו, _juny_, _पर्द, _בגיד
  { {0x394600df,0x26de0091,0x8c4614fd,0x0ae90058}},	//   ugos_, _ryto_, _кеме, اركي_
  { {0x8eb30086,0x629a005c,0xadf8000b,0x76430034}},	//   _همیش, zyto, ंगठन_, euny
  { {0x81bd0048,0x57b30036,0x212b1332,0x39460fc9}},	//   lsēt, обіт, zach_, sgos_
  { {0xd7190036,0x212b0034,0x5694110d,0x63ba14fe}},	//   уючі_, yach_, сайт, vitn
  { {0x0d960008,0xe5c6023e,0x28160067,0x81bd003d}},	//   יכֶם_, јско, _نورس, nsēt
  { {0x88bd0050,0x2fd800c0,0xcc56000a,0xf7460054}},	//   _jeśl, korg_, ׁבֵי_, _везо
  { {0x61ed14ff,0x26de0089,0x212b005c,0x629a0007}},	//   _shal, _tyto_, wach_, tyto
  { {0x81bd0024,0xe3af00a2,0x212b1500,0x68e00034}},	//   ksēt, بري_, tach_, _hymd
  { {0x3d20005d,0x629a1501,0x29dc0077,0x869b004f}},	//   बरों_, ryto, mías_, _שיאז
  { {0x67280123,0x7bdc1502,0x29dc0077,0xe53b000a}},	//   _kedj, _okru, lías_, _יתאר
  { {0x644f08e0,0xd83f0107,0x61ed1503,0x212b1504}},	//   àcie, _účet_, _whal, sach_
  { {0x29dc02c1,0x6728044c,0x212b1505,0xaffc005e}},	//   nías_, _medj, pach_, торi
  { {0xdce60024,0x02fb0135,0xaada000b,0x42fb000a}},	//   _sakā, _בלומ, _भड़क, _בהוס
  { {0xdce60024,0x50b80086,0x6be50015,0x9bc90015}},	// [2010] _pakā, _پديد_, مكرم, هورك_
  { {0xa3e6005d,0x69db0595,0x6728100e,0x764301c2}},	//   पति_, _skue, _nedj, yuny
  { {0x7ff400b0,0x6ff40015,0x5a470033,0x68e91506}},	//   _بسيا, _بسيط, рэза, _szed
  { {0x29dc0077,0xc172000a,0x7cd90021,0x6a140138}},	//   días_, ּ֗א_, _موجز_, імчу
  { {0x68e00176,0xa2d8005d,0xa3e6005d,0xf84b004a}},	//   _cymd, _नुस्, पता_, тчей_
  { {0x785a0048,0xe5790026,0x29dc02c1,0x8a170087}},	//   dāvā, glŷn_, fías_, _نظرا
  { {0xf7700225,0x29dc02c1,0x86750033,0xda340033}},	//   بان_, gías_, сылц, _меры
  { {0x9f96002e,0xca480015,0x2fd80079,0x645c0045}},	//   hæð_, _خلفه_, zorg_, ărin
  { {0x24520029,0x69d9005c,0x68e00026,0x320703e1}},	//   كنيس, mowe, _gymd, _suny_
  { {0x29dc0467,0x69d907e9,0x76430509,0x47940015}},	//   bías_, lowe, puny, _وجلس
  { {0xd5750010,0x29dc02c1,0x6b9503a3,0x70b2000b}},	//   _гуль, cías_, _mozg, ीप्ल
  { {0x69d9005c,0x13a7002b,0x35f51507,0x05740040}},	//   nowe, انگی_, _упер, _واند
  { {0xd24e0074,0x2fd8002e,0x14190029,0x200901c2}},	//   ونی_, torg_, _صيغة_, _cuai_
  { {0x443f0b7c,0xf412000a,0x141a000a,0xd8d6000a}},	//   mru_, _צפו_, _עוצב, מורט_
  { {0x69d9005c,0xdee60b0c,0x38ae0030,0xe2150015}},	//   kowe, сови, _köré_, _ابتع
  { {0xdced032c,0x29000007,0x69d9005c,0xd24e0015}},	//   adač, žiai_, jowe, _أني_
  { {0xc5f20053,0x69d91508,0xcc290015,0xd00f0015}},	// [2020] לדל_, dowe, لألم_, _كلي_
  { {0x68e000c0,0x3f9e007c,0x394d1509,0x443f150a}},	//   _rymd, ötud_, _aces_, iru_
  { {0x4906003b,0x1ee8002b,0x443f150b,0x2f97000a}},	//   مواق, _خودی_, hru_, _הכין_
  { {0x70530074,0x5d860029,0x69d9150c,0x443f150d}},	//   _بنیا, _الحل, gowe, kru_
  { {0xa85600d0,0x783a023e,0x2089000a,0x0719000b}},	//   стеј, уџет_, ֹתוֹ_, नुभव_
  { {0x0f7a0053,0x3f7a004c,0x29dc0077,0x75c80046}},	//   ראַב, ראַס, tías_, tězo
  { {0xda650015,0x69d9051e,0x386d068c,0x9f520077}},	//   _وافي, bowe, _eser_, _huyó_
  { {0x76a90036,0x29dc02c1,0x860700e6,0x29040035}},	//   штів_, rías_, حقيق_, _ugma_
  { {0x2bbf000b,0x29dc010d,0x443f150e,0x6b950061}},	//   ्वचा, sías_, gru_, _yozg
  { {0xa3b4005e,0x037a0015,0x212901c2,0x29dc0077}},	//   ібні, احظت_, _seah_, pías_
  { {0x4df8005d,0x22580080,0xe717000a,0xf202000b}},	//   ंगाई_, шины_, _החבר_, _रूख़_
  { {0x8afb000a,0x2001007c,0x443f150f,0xda7b004f}},	//   טליז, _sihi_, bru_, אנטר
  { {0x443f04f9,0x9f96001a,0x0453002b,0xc1b8033d}},	//   cru_, tæð_, _فئود, слях_
  { {0x4fc70080,0x33f60e88,0x69d9005c,0x44261510}},	//   ссма, _учес, zowe, _iwo_
  { {0x6b95005c,0x69d9003f,0xd3570008,0x82330067}},	//   _rozg, yowe, _השוק_, _فريا
  { {0xd1310074,0x64401511,0xbd191512,0x0000006a}},	//   _کمک_, ormi, ржах_,
  { {0xd0110086,0xbbb9005e,0x5bb901b0,0x1dc40015}},	// [2030] _تلخ_, агає_, алая_, سْكِ
  { {0x6ac4014e,0x69d9005c,0x749b000a,0x2cb80015}},	//   वपूर, wowe, אימפ, حافظ_
  { {0x69d91513,0xdd950010,0x64400012,0x0000006a}},	//   towe, _даны, hrmi,
  { {0x88190010,0x195902bf,0xec150015,0x127b004c}},	//   аўку_, рады_, _ووجد, טאבע
  { {0xf09f0251,0x6845017f,0xdd31002a,0x69d91514}},	//   nyà_, інка, _mężo, rowe
  { {0x645c04f9,0x69d91515,0x443f1516,0x67d400ce}},	//   ăril, sowe, vru_, почу
  { {0x86980063,0x753d0030,0xf7700015,0x69d91517}},	//   йтът_, ószo, عاه_, powe
  { {0x443f1518,0xe6280029,0x84590fba,0xe41b004c}},	//   tru_, حثون_, арот_, _אָרגאַ
  { {0xc7c80092,0x2365065d,0xb4650086,0x386d043a}},	//   uốc_, telj_, تگاه, _user_
  { {0x443f1519,0xdb0e001a,0xfe09000b,0xb8df000b}},	//   rru_, _embæ, वदास_, ुप_
  { {0x6d5d04af,0x6440151a,0x01660146,0x32b90015}},	//   _obsa, armi, окно, شددة_
  { {0xc1060015,0x7d020091,0xcf89000a,0xf1bf151b}},	//   توحي, žosi, _בט_, giá_
  { {0x25bf0045,0xb17b0123,0x2365013b,0x0000006a}},	//   miul_, plån, pelj_,
  { {0x25bf0011,0x3cdd005d,0x6d4f151c,0x6d5d079c}},	//   liul_, _खड़े_, _acca, _absa
  { {0x11d60015,0x1d0a07be,0xd3d80015,0x249f0061}},	//   _وتبد, иеви_, _ابنا_, lyum_
  { {0x25bf04f9,0x0c2600d0,0x51f6002b,0xf1bf016e}},	//   niul_, жман, _بستر, ciá_
  { {0x752b0030,0xfce3107f,0x249f151d,0x0000006a}},	// [2040] _megz, дото, nyum_,
  { {0xbfc3004a,0x25bf0045,0xab1a01b0,0x9e660e4b}},	//   _обык, hiul_, рцах_, _двод
  { {0xed5a0083,0xcfa9002b,0x7539002a,0x3dc902f2}},	//   _кон_, _دايم_, _odwz, bnaw_
  { {0xad5a0010,0xe9da1179,0xba17002b,0x010d004f}},	//   _трох_, шке_, زيها_, ְלוּ
  { {0x25bf0011,0x999c00dc,0x515b004f,0x0000006a}},	//   diul_, évő_, שכנו,
  { {0x907b0008,0x207b0053,0x8bd8000a,0x249f151e}},	//   יטני, יאנא, _הַֽח, dyum_
  { {0x645c0045,0xbcfb01d3,0x61e601ec,0x0000006a}},	//   ărim, _ebéd, klkl,
  { {0xdb070084,0x7e9b0053,0x25bf0045,0x25ad151f}},	//   ámör, יסצו, giul_, ghel_
  { {0xf1bf016e,0xa73a002b,0x938a1520,0x88c50058}},	//   viá_, _نثار_, асна_, _فتكل
  { {0x7c290064,0x25ad007c,0xfc5b000a,0x61e60353}},	//   _çere, ahel_, סכימ, elkl
  { {0x25bf1521,0xcb130008,0x86c600e5,0x5b7b000a}},	//   biul_, ולת_, _بيان, בריא
  { {0x4426003e,0x25bf0011,0xb606016f,0x29000007}},	//   _two_, ciul_, rišć, žiau_
  { {0xf1bf002c,0xcf9b0099,0xa0c50015,0x8f0b009b}},	//   riá_, ајв_, سيسو, ихва_
  { {0x43740074,0x3373005e,0x4ea70763,0x02340058}},	//   _رهبر, _огір, орба, _ففتح
  { {0x3ea500dc,0xd13b0033,0xe28f0015,0x98ad0535}},	//   ált_, _кхп_, _لذي_, _ideą_
  { {0x4237000a,0x321e04a9,0x3dc90034,0xdb0d01d3}},	//   _ונהל_, mpty_, unaw_, űkül
  { {0x030e005d,0xc19c0008,0xf19c000a,0x0000006a}},	// [2050] _सलाह_, _כשהי, _כשהש,
  { {0xda7b006b,0x673a02de,0x6ed6000b,0xee870088}},	//   ияе_, _ndtj, _मुकु, _дымо
  { {0xf0b80086,0x9ff80015,0x0000006a,0x0000006a}},	//   _هایش_, _بريء_,   ,
  { {0x7aed003d,0x2ca01522,0x0000006a,0x0000006a}},	//   _ģitā, byid_,   ,
  { {0xb17c0053,0x98f40010,0xdcef0007,0x9cc8004a}},	//   יטאר, мяшч, _įdėk, _дыра_
  { {0x6cfa0008,0x4c9a000a,0xacfa000a,0x7b640e91}},	//   _לפרס, _הבשו, _להרכ, _отсе
  { {0x67ed00dc,0x2d991523,0x25ad1524,0xd7580058}},	//   gúja, _kose_, thel_, تجنا_
  { {0x6d4d1525,0x391501c6,0x2d991526,0x0000006a}},	//   ngaa, _хмар, _jose_,
  { {0x25bf0011,0xd8770086,0x04560029,0x29120061}},	//   riul_, _بازب, كلية_, ıyat_
  { {0x2d990708,0xe7b50067,0xfb96000a,0xbbba000a}},	//   _lose_, _عماد, ִ֣ית_, ֶ֖יך
  { {0x69cb1527,0x95cb0bb9,0x25bf0045,0x91e61528}},	//   onge, _куда_, piul_, зоне
  { {0x2d990398,0xa06a0054,0x69cb0b2d,0x6a96004f}},	//   _nose_, бама_, nnge, לכתא_
  { {0x69cb1529,0x920b000b,0x9554002b,0xd4c70015}},	//   inge, _सूरज_, _آخما, _بغاي
  { {0xa4fa0008,0x69cb0012,0x7bcb0003,0x141a004f}},	//   _פלסט, hnge, égul, _הוסב
  { {0x59db005d,0x6449152a,0xa3b80015,0x395f0003}},	//   यकार, luei, _بانر_, _obus_
  { {0x2d9904ed,0xf2d2000a,0x6d4d152b,0x395f00aa}},	//   _cose_, _רעה_, ggaa, _nbus_
  { {0x6ac4000b,0xe04a002b,0x64490144,0x26110016}},	// [2060] वप्र, _اشعه_, nuei, _láo_
  { {0x6d4d1521,0x395f152c,0xa3cb000b,0x69cb152d}},	//   agaa, _abus_, रचि_, enge
  { {0x4f9b0008,0xbf9b0008,0x9f9b0008,0x2ca00375}},	//   _הביצ, _הייש, _הסיפ, syid_
  { {0x5f46002b,0xd23a004c,0xb5f90033,0xfe37000a}},	//   _بنگل, מגעל, _кнiг, _צרכי_
  { {0x7d7b0008,0x3f9a0024,0x98a3007a,0x51b5004c}},	//   _הנכו, _kopu_, нице, וּװן_
  { {0x26110023,0x64490251,0xdb1e0144,0x69cb0cc6}},	//   _báo_, duei, xipè, ange
  { {0x261100a7,0xdbc70209,0xe5c6006b,0xe7370054}},	//   _cáo_, töös, зспо, чеј_
  { {0x69c300dc,0x9418004a,0xe60f009a,0x7bde152e}},	//   énet, ожит_, دشو_, lopu
  { {0xdce40007,0xc5130015,0x6449152f,0xe4a601f3}},	//   keič, ربيت, guei, ярко
  { {0xdc9b0053,0xb8050015,0x7643002a,0x93930015}},	//   צייל, _قبله, brny, ّجَا
  { {0xf7730008,0xe4d60086,0xd257005e,0x0edb000b}},	//   _רקע_, _کتاب, пця_, _मुंड
  { {0x92570080,0x64490251,0x98a4003d,0xa01b0012}},	//   чают_, buei, _zemā_, nvög
  { {0x6449038d,0x7bde00f2,0xb0340010,0xad9b002d}},	//   cuei, kopu, нняш, _diúl
  { {0x2259005c,0xf43b000a,0x6f15002a,0x34fb000a}},	//   ńska_, _פגומ, uczc, _ההדד
  { {0xdb1e002f,0x735b0008,0x3da70010,0x1ee7002b}},	//   cipé, _הכוח, праб, سوری_
  { {0x91e40001,0x91720016,0xdd170065,0x361b004f}},	//   _поје, rợ_, धुंध_, מולד
  { {0x113c0008,0x9c190029,0x6d4d1530,0x91bc000a}},	// [2070] _התחל, زياء_, rgaa, _למהי
  { {0x2bbb0015,0xbb850015,0x7bde1531,0xfa8b1532}},	//   حارة_, بلطي, gopu, йсей_
  { {0xcb080015,0x2cbf006f,0xdb200030,0x3e350058}},	//   أيمن_, _ľudu_, ótáb, _تفجر
  { {0xc7c80092,0xdb1e00f2,0x69cb1533,0x2d990091}},	//   uốn_, enpä, unge, _uose_
  { {0xe72e005e,0x320e002a,0x6f0c0030,0x26110016}},	//   ке_, _lufy_, _álcá, _sáo_
  { {0xdb230086,0xe93b002b,0x7bde1036,0x66e51534}},	//   _سوری, _گسست_, copu, мола
  { {0xe7300087,0xe919005e,0xff18000a,0x7f3c004c}},	//   اصه_, _мові_, הקות_, זעוו
  { {0x49b80018,0x64491535,0xa5f60054,0xc48507f7}},	//   _فاقد_, tuei, меју_, длик
  { {0xa3b90015,0x87070015,0x2900006f,0xa8980033}},	//   قادر_, _فبال, žiar_, _екту_
  { {0xe2a20023,0x26110016,0xa3b7000b,0xf3c90015}},	//   _thử_, _táo_, घों_, تبعه_
  { {0xd6270002,0xf6550004,0x6dac0061,0xeb92000a}},	//   _رعاي, _цвеќ, aşay, דָר_
  { {0xf8a70015,0x799b042f,0xf652004f,0x7a88004f}},	//   نة_, _jouw, _יצב_, פָתַ
  { {0x29360053,0x7bde003f,0x644911dd,0x85040015}},	//   וארן_, yopu, quei, _كومن
  { {0xb4fa000a,0x03950033,0xa4fa000a,0x34fa000a}},	//   _ופני, _ірля, _ולנט, _והנד
  { {0x5de60010,0x0ef90010,0xdce40091,0xdee313d0}},	//   джва, зэты_, reič, вори
  { {0x69bf005d,0xcd36002b,0x6e930040,0xdd92012c}},	//   लोमी, برآب, خلفا, خور_
  { {0xa5c6002e,0x718b0008,0x5f760115,0x61e41536}},	// [2080] ljóð, _וְיַ, _قادر, _ikil
  { {0x78a2003f,0xafdb00cb,0x4e1a0015,0xfaa61111}},	//   vyov, ktøy, _وتجد_, мазо
  { {0x799b0111,0x7c3a0024,0x9a6a0031,0x7bde1537}},	//   _bouw, _ātru, تمال_, ropu
  { {0xbd460015,0xfbc905bd,0x08c60788,0xc4ad0065}},	//   _تنحي, בת_, мбен, टनाओ
  { {0x69c20034,0xa817002b,0x7bde1538,0x644f0144}},	//   rioe, وتور_, popu, àcil
  { {0x7a0c04f9,0x316b002a,0xa77300e2,0xe3a7012c}},	//   _aşte, zecz_, кліч, _شر_
  { {0x6b9c1539,0x69c20546,0x66e300af,0x0000006a}},	//   _iorg, pioe, коља,
  { {0x2abb000a,0x35f700c3,0x6b9c0030,0x79890034}},	//   _ומלא, وريد_, _horg, _gnew
  { {0x4c9b00b2,0x690b000f,0x236a00d0,0x69c0153a}},	//   ַשטע, _וּבְ, ојно_, _imme
  { {0x889b0008,0xb89b000a,0x6b9c153b,0xf3660788}},	//   _ובמי, _ובמש, _jorg, фтин
  { {0xbcfb002d,0x316b005c,0x6b9c04dd,0x2b16000b}},	//   _mbéa, tecz_, _morg, दुएँ_
  { {0x6b9c10e0,0xc693000a,0xca37000a,0x61f6028a}},	//   _lorg, _שאף_, ונטה_, _chyl
  { {0x6b9c0234,0x9554002b,0xb5fb000a,0xdb1c0030}},	//   _oorg, _يخچا, _ולאכ, _emré
  { {0xe4c70086,0x6b9c153c,0x61e40061,0xa3b7009a}},	//   _تصمی, _norg, _ekil, _ياور_
  { {0xa3cb000b,0xa3bd000b,0xdd9b153d,0x69c0153e}},	//   रचर_, ीचर_, оша_, _omme
  { {0x31c40010,0xc5f8003d,0x0000006a,0x0000006a}},	//   _асьв, _spēj_,   ,
  { {0x6b9c153f,0xfc300015,0x2cfb0065,0x799b0546}},	// [2090] _borg, لحل_, ्शेल_, _rouw
  { {0x21f2002c,0xf092000a,0x5457000a,0xbfd50015}},	//   máha_, _עני_, וסמן_, _سيجع
  { {0xcff6000a,0xafdb00cb,0x656201c0,0x61e40052}},	//   _רצתה_, nrøm, _oboh, _ykil
  { {0x49b80086,0x4efa000a,0x6d4b0125,0x58d50238}},	//   واند_, _מהתו, ógad, ноет
  { {0x6b9c0c0a,0xa9680015,0x9d1a000a,0x2d8b1540}},	//   _forg, ظمهم_, _מורט, _ince_
  { {0xdce401e2,0x79890026,0x6b9c0376,0xafdb00cb}},	//   ldiğ, _wnew, _gorg, ttøy
  { {0x4ae4008f,0x4ad9000b,0xdcfd0091,0x799b0079}},	//   _аўта, _बँटव, _posė, _touw
  { {0xdce40064,0x6b9c1541,0xc6a4006b,0xafdb01de}},	//   ndiğ, _zorg, ърчи, rtøy
  { {0x37c50015,0x9817002b,0x44391542,0x6b9c0a63}},	//   _كيرف, _آبرا, és_, _yorg
  { {0x61e41543,0x56670015,0x57780015,0xf77300c3}},	//   _skil, _يداف, _يصلح_, _جار_
  { {0x2d8b0041,0x98a40011,0x52b80033,0xd794006b}},	//   _once_, _temă_, дыяў_, _шифъ
  { {0x2259005c,0xa91d0091,0xa06a0a3e,0xe29a0016}},	//   ńsko_, _požy, пама_, _ngưu_
  { {0x54a70015,0x2256002b,0xf536000a,0xe6040015}},	//   _تحاف, ولید_, _ננסי_, _شِهَ
  { {0x649a000a,0xc49a000a,0xdff50033,0x3cf5000b}},	//   _מינה, _משנת, вясь, ्धने_
  { {0x645b1544,0x61f61545,0x0000006a,0x0000006a}},	//   ltui, _thyl,   ,
  { {0xb2ba000a,0xc692000a,0x64460091,0x6b9c1546}},	//   _ממצר, נאן_, škie, _sorg
  { {0x8b260010,0xf3900092,0x3c660010,0xdd8f0015}},	// [20a0] едзе, _mảnh_, экаг, حوق_
  { {0xda660029,0x6abd005d,0x645b1547,0x69c30003}},	//   فاصي, ्पूर, itui, ènen
  { {0x6b9c018b,0xfe720086,0x0f57000a,0xff57000a}},	//   _vorg, _صدد_, _איים_, _אביך_
  { {0x317b000a,0xed5f006f,0x645b1548,0xe8fa07f8}},	//   ּ֨אמ, ížte_, ktui, пле_
  { {0xd7e602e1,0x645b0079,0xdb1e1549,0x69230099}},	//   ніко, jtui, lipí, умча
  { {0x7c24154a,0x6b9c064c,0x0000006a,0x0000006a}},	//   mpir, _uorg,   ,
  { {0x61fd0084,0x7c24154b,0x569401e3,0xd9460195}},	//   ymsl, lpir, тайт, _певи
  { {0xf3900023,0x14180029,0xd5b7154c,0xda5b000a}},	//   _cảnh_, ويبة_, есь_, _מכלל
  { {0xdce60024,0xb8860107,0x7c2402f2,0xc9550033}},	//   _nokļ, _blíž, npir, _штры
  { {0x883b000a,0xb8e6000b,0xcc57000a,0x14f30033}},	//   _מתמו, ॉप_, עסיק_, ызыў
  { {0xf8bf09f0,0x0bb70008,0x6283016f,0x645b043c}},	//   _þér_, גלים_, _crno, atui
  { {0x645b00dd,0x65620046,0x0000006a,0x0000006a}},	//   btui, _uboh,   ,
  { {0x53a60010,0xc0ab0015,0xf1c0000b,0xdce40061}},	//   _падб, ساحل_, शोधन, vdiğ
  { {0x32940029,0x7c2400bd,0x44f30010,0x22940015}},	//   _للتأ, dpir, _спіс, _للتس
  { {0xe37b000a,0x777a0016,0x7bc5154d,0x7c24003d}},	//   _מרגר, _matx, vihu, epir
  { {0xf1bb004f,0xa0c50058,0x66f7004f,0xbdf80058}},	//   _מֶ֖ל, _ليعو, תמלא_, فرقا_
  { {0xdce401e2,0xd1640063,0x3b550c1d,0xa0220061}},	// [20b0] rdiğ, _същи, ккар, _şöva
  { {0x657b154e,0xa91d154f,0x69da005a,0x60f80138}},	//   zduh, _inži, _ítej, _яныя_
  { {0xc3330008,0xdcef0045,0x8c440061,0x6abd000b}},	//   רוע_, _bacă, ışar, ्पेर
  { {0x0000006a,0x0000006a,0x0000006a,0x0000006a}},	//     ,   ,   ,
  { {0xed600089,0xf7950033,0x3da40033,0x777a0144}},	//   ížet_, кадэ, _срэб, _batx
  { {0xa08c0008,0xf7710115,0x307c0135,0x98a209b5}},	//   לְוִ, شات_, פאונ, рише
  { {0xd915008f,0x68e9002a,0xcec40046,0x96750033}},	//   _адбы, _wyed, moří_, тылі
  { {0xd6ce0029,0x645b1550,0xdb1e00d4,0x0000006a}},	//   تقى_, ttui, cipâ,
  { {0x75c80089,0x645b008c,0x672c0030,0xa5f60054}},	//   vězt, utui, éljü, њењу_
  { {0x645b1551,0xb464006e,0x4374005e,0xd2a902ed}},	//   rtui, اديه, гуют, дкое_
  { {0xcb12000f,0x645b1552,0xe6950015,0x3f9e001a}},	//   ילי_, stui, _جلاد, ötum_
  { {0xb6d80053,0xcec40046,0x82f40033,0x645b0045}},	//   _אַױט, hoří_, ычыц, ptui
  { {0x98a40007,0x75291553,0xe6040015,0xa93a000a}},	//   _temą_, mbez, _إِنَ, ותרפ
  { {0x64490d75,0x645c0045,0x03a2012e,0x43450c71}},	//   mrei, ărit, _вишо, _рекв
  { {0x64491554,0xd0070bb9,0xed5a10b7,0xdee61098}},	//   lrei, тере_, мов_, тови
  { {0x661c0014,0xb602002e,0x752904de,0x52d60447}},	//   _érke, _þátt, nbez, _בוצע_
  { {0x973c016f,0x64491555,0xff2600a5,0x4d630004}},	// [20c0] _hoće, nrei, _импо, јкув
  { {0x4b230036,0xd00f002b,0x1037004c,0x442f0034}},	//   имув, _گلی_, _שטים_, _mwg_
  { {0xf1c6005d,0x2d9e0152,0x3bd50080,0x64491556}},	//   _लगान, êtes_, уютс, hrei
  { {0x64491557,0xd9180021,0xd00f002b,0xd94603ae}},	//   krei, ريتش_, _دلی_, теди
  { {0x38cb0086,0x5cf50033,0x8e3a002b,0x4614002b}},	//   واهی_, _бяру, _عسگر_, گوبر
  { {0xb17b01d1,0x75291558,0x64491559,0xd885009a}},	//   llåt, ebez, drei, اهوی
  { {0x16370029,0x4b7b0053,0xad9b002d,0x8bd7000a}},	//   نسية_, _קאלו, _siúi, _סולו_
  { {0xfa770008,0xadf8005d,0x55740254,0x6449155a}},	//   _בעלת_, ंगटन_, угит, frei
  { {0x48060010,0xe8ea0086,0xc7c80092,0x6449155b}},	//   _апав, _آرزو_, hối_, grei
  { {0x75c80089,0xafdb02de,0x3cfb000a,0x7529155c}},	//   tězs, msøg, ולפנ, abez
  { {0xafdb02de,0xd3770033,0xf1f6000b,0x75290030}},	//   lsøg, тчы_, ीगढ़_, bbez
  { {0x442f0034,0x673800bc,0xf1a71111,0x6449155d}},	//   _fwg_, lavj, трон, brei
  { {0xe1ff02c1,0xafdb0134,0x1074155e,0x43860015}},	//   rmó_, nsøg, аляю, _للإق
  { {0x9f5308e0,0x26180092,0x533404d7,0xe507004f}},	//   _això_, _kéo_, _сект, _ב֖וֹ_
  { {0x9f340036,0xcec40089,0xde58005e,0x2fcd0085}},	//   ресі, voří_, карі_, đeg_
  { {0x26180016,0x63bd003d,0x2486155f,0x41551560}},	//   _méo_, īsne, _krom_, _свис
  { {0x6abd005d,0x69c30152,0x71d8000a,0x6ce7005e}},	// [20d0] ्प्र, ènem, _שוחד_, тіве
  { {0xdb0700dc,0xafdb0134,0x0bb40010,0x2d9e0003}},	//   _aljá, dsøg, абую, êter_
  { {0xafdb0134,0x4ae40010,0x26180003,0x5c04004a}},	//   esøg, аўца, _néo_, рята
  { {0xdd951561,0xe9190036,0x3eac0723,0xe80f0065}},	//   _самы, ході_, ødte_, ादला_
  { {0xafdb0134,0x39440127,0x91bc000a,0x764a0034}},	//   gsøg, рніг, ומאי, erfy
  { {0xdb0700dc,0x68380046,0xd7f40033,0x26180016}},	//   _eljá, _súdá, азчы, _béo_
  { {0xcf940135,0x37080029,0x64490034,0xfc3f001a}},	//   יטס_, نْهُ_, wrei, _hví_
  { {0xafdb02de,0x64491562,0x24861563,0x69ca01f6}},	//   bsøg, trei, _brom_, éfet
  { {0x752900d9,0x67380085,0x91fd003d,0x04940033}},	//   rbez, bavj, itād, арэў
  { {0x752904de,0x24861564,0x64491565,0xd7e400fd}},	//   sbez, _drom_, rrei, _кіхо
  { {0x35550115,0xd1ca0054,0x02c500fd,0x64491566}},	//   _مناز, елне_, уйно, srei
  { {0x248603c2,0x64460007,0x645c0011,0xe5730015}},	//   _from_, škia, ărir, _خطط_
  { {0x3fc80086,0xf539002c,0xd469012e,0x24861567}},	//   ندسی_, mať_, _чиле_, _grom_
  { {0xf539002c,0x8e7600c2,0x0000006a,0x0000006a}},	//   lať_, лубч,   ,
  { {0xc7c80092,0x213900c7,0x1eaa0369,0x0000006a}},	//   uối_, bash_, راسي_,
  { {0xf539002c,0x25ad1568,0x7db50138,0x21391569}},	//   nať_, nkel_, асуц, cash_
  { {0x3dd20034,0xb17b156a,0x4c860033,0x808a0015}},	// [20e0] rnyw_, rlåt, ылав, _أضعف_
  { {0xb17b00cb,0x9f5e00f2,0xb346016e,0x25ad007c}},	//   slåt, ötä_, moçõ, hkel_
  { {0x53360053,0xf539002c,0x2ca90035,0x7c22002d}},	//   רנען_, kať_, ayad_, íorb
  { {0xe9e50036,0xf539002c,0xafdb02de,0x83fd0030}},	//   аціо, jať_, tsøg, ltőd
  { {0xf539002c,0x07a6156b,0xe894156c,0x3157000a}},	//   dať_, ладн, раль, רינן_
  { {0xafdb00fb,0x50db004c,0x30db004c,0x83fd0030}},	//   rsøg, עקסא, ײַדע, ntőd
  { {0x673800bd,0x1a78000f,0x8a78000a,0x9a78000a}},	//   ravj, _בְּמ, _בָּק, _בָּח
  { {0x442a0124,0x6d5600b6,0xceb3000a,0x2d800252}},	//   нцом_, ngya, מיו_, ndie_
  { {0x6d560035,0xa84a0031,0xa4d4005e,0x61e6156d}},	//   igya, _سلام_, ропі, dokl
  { {0x21f20046,0x610c003d,0x883b000a,0xcc77000a}},	//   sáhl_, _mēlī, _נתבו, נגית_
  { {0xf539006f,0x4422003d,0xb7db004f,0xeb97004f}},	//   bať_, ūk_, _טקמי, אדיר_
  { {0xd9f6005d,0x2486002d,0xf539006f,0x25ad156e}},	//   ेषित_, _trom_, cať_, ckel_
  { {0x33860323,0xe3af002b,0x2d80156f,0x21391570}},	//   _буйв, زری_, ddie_, rash_
  { {0x14d70008,0x2a66005c,0xad9b0125,0x2d801571}},	//   _גודל_, łoby_, _liút, edie_
  { {0xe3370053,0xe2460015,0x8337000a,0xc6d8000a}},	//   _גרופ_, _إختي, _גאוס_, דַּר
  { {0x7c290061,0x6d560030,0x0000006a,0x0000006a}},	//   _çerk, ggya,   ,
  { {0xdfd50010,0xe58b000a,0xade8002b,0xed600046}},	// [20f0] _вопы, עָלָ, افقم_, ížat_
  { {0x6ee7003b,0x91fd0048,0xf539002c,0x6d560a4d}},	//   _مسجل, stād, zať_, agya
  { {0x20d40086,0xfbd00015,0x633b004c,0xc9150054}},	//   _نتیج, ستك_, געבױ, адећ
  { {0xe9ce05d1,0xd257000a,0x5e880015,0x7aee02de}},	//   ік_, רשאה_, _إنَّ_, _dybt
  { {0xf53905cc,0xd5b10023,0x3d3a0008,0xdd3a000a}},	//   vať_, _lúc_, _בגרס, _בערכ
  { {0x22590050,0xdd1c0007,0x8a370015,0x98af0045}},	//   ński_, _iššo, _معرض, eagă_
  { {0x25ad0020,0xf539002c,0xf7700015,0x1a68002b}},	//   tkel_, tať_, ثان_, _میلی_
  { {0x16620010,0xa4451572,0x0000006a,0x0000006a}},	//   івым, анид,   ,
  { {0x9848010f,0xf539002c,0x64461573,0x69cb1574}},	//   _бяха_, rať_, škin, mige
  { {0xf539002c,0xd2650010,0x81bd0024,0x92b50015}},	//   sať_, акой, spēl, لحجا
  { {0x22490063,0x25b000dc,0x8b88039e,0x31a60015}},	//   ъпни_, álló_, אָרֶ, لمدف
  { {0x69cb018b,0x6aba0064,0x61e60007,0x14750015}},	//   nige, _ütfe, uokl, _ناتج
  { {0x6e25002d,0x81bd0024,0x61e61575,0x8fe60015}},	//   _athb, opēj, rokl, لأسم
  { {0x6d4b002d,0x69cb00b8,0xdfd20115,0x94ba000a}},	//   ógan, hige, زيز_, _שמסת
  { {0xa91d04af,0x6da60080,0x5f06006b,0x3f840046}},	//   _každ, аива, рзва, ěmu_
  { {0x32da0008,0x63a31576,0x9f43008c,0x973c0085}},	//   _שחקנ, _honn, eljä_, _moća
  { {0x2d800f75,0x63a31577,0xa91d1578,0xec7a0063}},	// [2100] rdie_, _konn, _mažd, ъпа_
  { {0xeab20029,0x60fb000a,0xaec6005e,0x103b000a}},	//   يعا_, _בהפק, _вбол, _שגיע
  { {0x69cb1579,0xbad50033,0x8f9b000a,0x63a3157a}},	//   fige, біцы, _סיטי, _monn
  { {0x69cb00b8,0x63a30c0b,0x291200cb,0x49ca006b}},	//   gige, _lonn, øya_, ълен_
  { {0x443f005c,0x2089000a,0x38cb002b,0x91fd003d}},	//   jsu_, ָתוֹ_, پانی_, ltāc
  { {0x98a40089,0xc66a0080,0xe72f0015,0x91fd003d}},	//   _země_, вшие_, وصى_, otāc
  { {0x29560063,0x69cb00b8,0xf6570029,0x91fd0024}},	//   _възр, bige, لجيش_, ntāc
  { {0xd378016f,0x18a60036,0xaa5700c3,0x6705000b}},	//   moći_, _кабм, _خلفا_, षेधक_
  { {0x2616014e,0xb0c5005d,0x63a30493,0x98af0045}},	//   _पूरी_, _लेंग, _bonn, ragă_
  { {0x63a30287,0xb8650015,0xe3af0015,0x7982157b}},	//   _conn, _دافو, ِرَ_, ldow
  { {0x6d4604af,0x63a3073e,0x7982002a,0x67ed0030}},	//   _odka, _donn, odow, gúju
  { {0x7c26016f,0xd6cf0029,0x7982157c,0x31c70235}},	//   _otkr, _تقم_, ndow, рсов
  { {0x84630063,0x55bb000a,0xc5f3000a,0x90540033}},	//   _дъще, _במאו, _ודף_, овяц
  { {0x4426025c,0xe3b70010,0xd103000b,0x9257002b}},	//   _ito_, _кліч_, रेषण_, دشیر_
  { {0x639b0008,0xc3fb01d8,0x7c260095,0x33fb000a}},	//   _בסגנ, _שלוש, _atkr, _שהונ
  { {0x7982005c,0x4426066f,0xa91d02c6,0xf531000a}},	//   jdow, _kto_, _kaže, ּ֥ן_
  { {0x61ed0035,0x30a40010,0xdb1e00f2,0x69cb157d}},	// [2110] _ikal, _дрэв, kipä, vige
  { {0x4426000c,0xa91d0007,0x69d80152,0xdb0e00dc}},	//   _mto_, _maže, éven, _elbí
  { {0x69cb157e,0x39150015,0x5fdc000a,0x89370015}},	//   tige, مواز, _בחזק, لعشا
  { {0x8d950029,0x6440157f,0x443f0b90,0x44260ed2}},	//   _الحش, ksmi, ysu_, _oto_
  { {0xfd960008,0x79800026,0x61ed003f,0xbcfb0152}},	//   _הדרך_, _damw, _mkal, _obéi
  { {0x6d580064,0xdb1e0020,0x628a0026,0x7982002a}},	//   ıbaş, gipä, _orfo, adow
  { {0x3f8100d9,0x64420493,0x753b003f,0x5fb8000a}},	//   _mahu_, _avoi, tauz, שהוא_
  { {0x81bd03eb,0xc1c6005d,0xdddc044c,0x63a31580}},	//   spēj, _लगेग, ovrš, _sonn
  { {0x628a0026,0x69c9003f,0x63a31581,0x85c40015}},	//   _arfo, _imee, _ponn, تغوم
  { {0x443f1582,0x63ba1583,0x6395004a,0x61ed1584}},	//   rsu_, ghtn, сшиф, _akal
  { {0x443f0084,0x44260176,0x6d5d002d,0xf77000a2}},	//   ssu_, _eto_, _ocsa, _زال_
  { {0x5999000a,0xc19a005e,0x443f1585,0x63a31586}},	//   אשֹׁ, утої_, psu_, _wonn
  { {0x628a018b,0x95c40029,0x973c016f,0x297a0053}},	//   _erfo, _بينه, _moćn, נטשא
  { {0x7982005c,0x63ba02f7,0x23260ffe,0x63a3008c}},	//   zdow, chtn, _лоши_, _uonn
  { {0xdfcf0196,0x539a000a,0xa91d1587,0x7982002a}},	//   ريف_, _תיצו, _zaže, ydow
  { {0x451900b2,0x3d280086,0xfd95005e,0xe058002b}},	//   רוּװ, شتری_, ошую, _پیست_
  { {0x6da31588,0xada3008a,0x6bda0058,0x8f760138}},	// [2120] чита, чатл, هورس_, _луні
  { {0xa3ca005d,0xdd3c005c,0x2259005c,0x69c9048c}},	//   रोप_, lążk, ńsku_, _amee
  { {0x8e861589,0x0a4a0a61,0xdddc016f,0xad9b002d}},	//   _الجه, узей_, avrš, _dhúb
  { {0xe93a0029,0xe9da0080,0x79821515,0x6d4602de}},	//   اسات_, ыке_, udow, _udka
  { {0x7982005c,0x60000123,0x67ed0030,0x69c80091}},	//   rdow, römf, yújt, _įded
  { {0x98730010,0xd0f7000a,0x207b004c,0xa6660021}},	//   яліц, זמנת_, טאנא, مطبو
  { {0x77910086,0xa91d016f,0x7982020d,0xdb1e0209}},	//   ظیما, _saže, pdow, ripä
  { {0xa91d0007,0xfad70008,0xdb1e0e95,0x6446158a}},	//   _paže, _הולך_, sipä, škim
  { {0x2d82003e,0xd7f20015,0x81bd003d,0x32f70016}},	//   _make_, _فكر_, spēk, _ãy_
  { {0xf8a70086,0xd4e30080,0xa91d016f,0x61ed158b}},	//   _دگمه_, яющи, _važe, _skal
  { {0xc7b30008,0xe2f80036,0x9f8d0089,0xdddc0796}},	//   _צבע_, рені_, uží_, zvrš
  { {0xdb1c002e,0xa1590010,0xad9b002d,0xc2b7005e}},	//   _umræ, шаму_, _mhúc, слює_
  { {0xafdb0bfa,0x673a00f2,0x3f8101d7,0x4426158c}},	//   drør, _ketj, _pahu_, _uto_
  { {0x82330086,0xe8d7000a,0x14d7000a,0x4394135e}},	//   _کروا, מוכר_, _פוגל_, _факс
  { {0x25a60171,0xc7d7000a,0x673a158d,0xe2970099}},	//   _kool_, צולי_, _metj, _гај_
  { {0x463b0053,0xd257000a,0x69d80003,0x2d8204a9}},	//   טעלע, _השהה_, ével, _cake_
  { {0x3f81013c,0x21f90057,0xdb0e0144,0x4c94158e}},	// [2130] _tahu_, lého_, _albà, питс
  { {0x2d87002a,0x75d30045,0x69c9158f,0x673a042f}},	//   śne_, răzi, _smee, _netj
  { {0x21f90107,0x2d82055e,0x68fb0030,0x1df90132}},	//   ného_, _fake_, _szud, _вены_
  { {0xd378016f,0x725b0053,0xad9b002d,0xbc9501ca}},	//   moću_, רכאפ, _dhúc, _дамј
  { {0x21f90107,0x673a1590,0x973c0085,0xe7390477}},	//   hého_, _betj, _voćn, аел_
  { {0x21f90156,0x2d82003f,0x7e8b000a,0x7c2d1139}},	//   kého_, _zake_, ָאֵ֖, mpar
  { {0x2d82000c,0x56920001,0x1f5c004c,0x2f5c000a}},	//   _yake_, дајт, אדוא, אדונ
  { {0x75d50015,0x79a7012e,0x142510b7,0x95c50015}},	//   تيعا, _урге, одим, تيبه
  { {0x57d5000d,0x28f8005e,0x6f000030,0xe3b91591}},	//   _доаѓ, _геть_, _kábí, иби_
  { {0xd874006e,0x87d7006e,0x7c2d1592,0x53c9107f}},	//   _عاقب, _اغرا, ipar, ргом_
  { {0x69d9005c,0x25a6055e,0x27e00125,0xcb8c000a}},	//   onwe, _fool_, éine_, רְחֹ
  { {0x7c2d1593,0x04950015,0x69d90012,0xe60e005e}},	//   kpar, _ولاح, nnwe, _ід_
  { {0xa8790053,0x15180015,0x69d90012,0xdbc6007c}},	//   באָר, _ازمة_, inwe, mööb
  { {0x2d821594,0x44070b44,0x21f901c0,0x442d1595}},	//   _sake_, _учеб, bého_, mpe_
  { {0x2d8200e8,0x442d1596,0xdd92006e,0x7c2d1597}},	//   _pake_, lpe_, ووس_, epar
  { {0x8d660010,0x60000123,0x4d660033,0x91fd003d}},	//   ўвае, döme, ўкав, ltān
  { {0xfaf80048,0x90c3005f,0x7c2d0035,0x71650015}},	// [2140] _šī_, _объе, gpar, _رايك
  { {0x0b4605d1,0x2d820705,0x442d1598,0xe81d000b}},	//   інен, _wake_, ipe_, _पढ़ा_
  { {0x2d821599,0x65b50264,0xafdb00cb,0x60000123}},	//   _take_, _náho, prør, römd
  { {0x673a05d8,0xf2d2004c,0x7c2d00c7,0x65b50046}},	//   _setj, ועב_, bpar, _sáhn
  { {0x7c2d016e,0x65bc0030,0x673a159a,0x661a09bb}},	//   cpar, _jéhe, _petj, _sutk
  { {0xe7930001,0x64460091,0x661a01be,0x1b76002b}},	//   дишњ, škik, _putk, _بدحج
  { {0x442d159b,0x25a60100,0x8f1b000a,0xd6d00015}},	//   epe_, _pool_, בוצת, عقب_
  { {0x21f90264,0x746a009f,0x7a0c0045,0xe46a0004}},	//   vého_, аров_, _oşti, ашол_
  { {0x65b50046,0xc4f70015,0x673a0030,0x276b002b}},	//   _táhn, يعًا_, _tetj, _چشمی_
  { {0x661a159c,0x21f90107,0xa7b8000a,0xccf3000a}},	//   _tutk, tého_, _פֶּת, וכח_
  { {0x74140086,0x85460010,0x4bfb0053,0xe57a0063}},	//   _کوتا, _дэле, שליס, _взе_
  { {0x21f90227,0x41c70033,0xd46a159d,0xda7b000a}},	//   rého_, іёна, _виде_, בנטר
  { {0x55d900b2,0x14c70080,0x3866159e,0xbf67002b}},	//   _פֿענ, _мыши_, ntor_, يدآو
  { {0xa91d0007,0xb4c8000b,0x9f430069,0x3866159f}},	//   _maža, ोपी_, pojí_, itor_
  { {0xa1870010,0x179b000a,0x81f70015,0xdb21001a}},	//   _дыпл, סילב, _وأعط, ótís
  { {0x65b501b2,0xb2bb000a,0x2251006f,0xdb060046}},	//   _náhl, _כמור, ázke_, ímýc
  { {0xf1bf002f,0xa91d0b6c,0xc05b005e,0xab2b0015}},	// [2150] mhá_, _naža, _тій_, لسال_
  { {0x2bbb0029,0x7c2d15a0,0xfe500061,0xfc300015}},	//   جارة_, rpar, üçük_, ضحك_
  { {0xd378005c,0x7a4003d9,0x8f88000a,0xf989002b}},	//   ieć_, _rátá, _וְרֵ, یخچه_
  { {0xa3ca014e,0x4e7a0053,0x12150053,0x7e7a0053}},	//   रोत_, _פארצ, פֿער_, _פארז
  { {0xf1b401e4,0xd8b800e6,0xbd9a000a,0xc87b0004}},	//   וסף_, يدها_, _הסרת, рџе_
  { {0xec360008,0x907c0008,0x00580008,0xa91d121a}},	//   _מאשר_, שְׁפ, קשות_, _daža
  { {0x1f38000a,0xb9350054,0x386615a1,0x9aa502be}},	//   חרור_, _невј, ator_, _عمرو
  { {0x31790050,0x19580033,0xd6780015,0xd5e80015}},	//   jesz_, _масы_, تحها_, يعين_
  { {0xe4510029,0x442d15a2,0x386603b0,0x65690012}},	//   رضة_, upe_, ctor_, rfeh
  { {0x75d30011,0x442d15a3,0x65b50227,0xe4c80015}},	//   văzu, rpe_, _záhl, غبين_
  { {0xa3ca014e,0x656900b8,0xfbd2000a,0x37c40015}},	//   रोध_, pfeh, תתי_, _تيلف
  { {0x216a0a61,0xe8e00092,0x98af005c,0x442d0362}},	//   щими_, uyệt_, wagę_, ppe_
  { {0x251a000a,0x439501e5,0x00da0015,0x40330033}},	//   _הונא, _надс, صبحت_, неўс
  { {0x02450015,0x3cef000b,0x660915a4,0x3f6a0054}},	//   _فَتَ, _आड़े_, lmek, љиво_
  { {0xa3b80002,0x433a000a,0xe3b2004c,0x22590015}},	//   _ظاهر_, _העצב, _אױג_, _العد_
  { {0x31790050,0x6da30001,0x91fd0024,0xd24e0029}},	//   cesz_, ниса, ntāl, _إني_
  { {0x90460029,0x1d070a6c,0x515b000a,0x71d7000a}},	// [2160] _عنده, зети_, _הכפו, _מוקד_
  { {0xab1a0010,0x0e6615a5,0x386600bc,0x660915a6}},	//   сцах_, _екон, vtor_, hmek
  { {0x660915a7,0x38660034,0xdbd9001a,0x8f1b004f}},	//   kmek, wtor_, ræðs, _לוית
  { {0xd378005c,0xa91d0007,0x58860139,0x7e9b000a}},	//   zeć_, _paža, зыка, _הסטו
  { {0x66090020,0x59bd000b,0xd90d002b,0x0395003d}},	//   dmek, ्फ़र, لیف_, _ķīnā_
  { {0xa91d016f,0x386615a8,0x31791022,0x66f40004}},	//   _važa, rtor_, zesz_, мплу
  { {0x3e870046,0x200a0045,0xf1bf006f,0xdce60091}},	//   mítá_, imbi_, yhá_, _pakė
  { {0x0576003b,0x9adb0008,0xd5b00029,0x386615a9}},	//   ساعد, _החלט, ئفة_, ptor_
  { {0x6d4b002d,0xa91d0085,0x83860033,0x83fd0030}},	//   ógai, _kažn, пыне, rtőn
  { {0x88bb0008,0x644f15aa,0x58bb000a,0x6609003d}},	//   _הזמי, ácia, _הממצ, amek
  { {0x2c6615ab,0x217908f0,0xdcfd003d,0x9314009a}},	//   hôd_, ойны_, _masā, بودش
  { {0xf1bf0089,0xdcfd0024,0x5afb000a,0xa91d02c6}},	//   uhá_, _lasā, מליצ, _lažn
  { {0x442004f9,0xbcfb15ac,0xa3b7002b,0x7bce15ad}},	//   _îi_, _océa, زایر_, _ombu
  { {0xad9b15ae,0x7538002a,0xdfdb006b,0xf2e6006b}},	//   _chún, ńczą, съм_, _нюйо
  { {0x33fb0008,0xad9b002d,0x93fb000a,0x4383002b}},	//   _ההגנ, _dhún, _הלגי, _سليق
  { {0x22f70008,0xe4570053,0x9df901c6,0x7bce15af}},	//   _מזון_, _אָנזאָ, інат_, _ambu
  { {0xa91d0007,0x7c15005e,0xc1050015,0x6285001a}},	// [2170] _bažn, ддає, _توظي, _áhor
  { {0xd9b5000b,0x0005002b,0x91fd003d,0x103c000a}},	//   ंस्ट, _تثبی, itām, _הגזע
  { {0xa91d00df,0xfe24056d,0x4a44005e,0x660915b0}},	//   _dažn, _пьян, енєв, ymek
  { {0x6aaa00c0,0x63aa0034,0xc27b000a,0x61ef07ee}},	//   äffa, _lofn, מרבי, nocl
  { {0xdbc700f2,0xc794002b,0x2d9903e6,0x98170058}},	//   töäs, کشنب, _inse_, أبصا
  { {0xbcb60008,0xbcfb002d,0xdc9a0008,0xa69500d7}},	//   _חפשו_, _gcéa, _וישל, дриј
  { {0x660915b1,0xe6640054,0x600c000a,0x25bf00aa}},	//   tmek, етњо, צִדְ, thul_
  { {0x25bf0020,0xafdb00cb,0xa3ca000b,0x7de50091}},	//   uhul_, ruøy, रोस_, bėse
  { {0x91fd03eb,0xed600089,0x660915b2,0x44390006}},	//   rtāl, ížit_, rmek, ès_
  { {0xe3b10029,0x63aa10bd,0xd7c80015,0x9f5e0061}},	//   ئرة_, _cofn, _فوقه_, ötü_
  { {0x66090024,0x2d990079,0x91e60f78,0x0000006a}},	//   pmek, _onse_, доне,
  { {0x44b515b3,0xa91d0007,0x36040058,0xc033005a}},	//   _обес, _mažo, _كولف, ěšné
  { {0xa3ca005d,0x95540058,0x69d801f6,0x0000006a}},	//   रोह_, _أخما, évei,
  { {0x63aa0026,0x2d8900aa,0x200a036d,0x6b8715b4}},	//   _gofn, edae_, umbi_, _najg
  { {0xc332000a,0x248d15b5,0x61ef016e,0x81bd003d}},	//   _יוג_, lvem_, bocl, tpēt
  { {0xbcfb002f,0x2176017f,0xbdda005e,0x0000006a}},	//   _scéa, _цукр, ієві_,
  { {0xdcfd0024,0xa91d016f,0xceb80007,0x3c660033}},	// [2180] _pasā, _pažn, šę_, ькаг
  { {0xaaba0086,0xa08b000a,0x2057000a,0xfd110015}},	//   يدار_, _וְטִ, _קייל_, اجِ_
  { {0xa91d010b,0x4f9b000a,0x9f9b000a,0x8268000a}},	//   _važn, _וביצ, _וסיפ, ּ֣עַ
  { {0xa91d0024,0xed5a002b,0xd99a0015,0xe8fa15b6}},	//   _dažo, _بشدت_, تنصت_, оле_
  { {0x58370033,0x7d7b000a,0xa87a0021,0x6d4415b7}},	//   дзія_, _ונכו, تحار_, maia
  { {0x6283060b,0x98a30001,0x8c43023e,0x95f8000b}},	//   _osno, тиље, _јере, ुष्ट_
  { {0x5a550063,0x6009000a,0x248d016e,0xba2315b8}},	//   _пъту, הִקְ, evem_, _адск
  { {0x77b408e0,0x1dde005d,0x986a0015,0x3949001a}},	//   _màxi, नचित, _وحذف_, óast_
  { {0x186a027c,0xe76600af,0xa01b02ad,0x0000006a}},	//   _фази_, _овап, iwöc,
  { {0xc6760029,0x69c215b9,0x4c9b000a,0x7bde047f}},	//   _يطاب, lhoe, קביו, nnpu
  { {0xcb570008,0x5b570c44,0xc7d7000a,0x6d4415ba}},	//   וסיה_, ושין_, _קובי_, kaia
  { {0xf5930029,0x85060002,0xa1940484,0x22510107}},	//   _للمج, _قوان, ваюч, ázka_
  { {0x4613002b,0x3cfa000b,0x2259002a,0x64b60015}},	//   _شوهر, ्धों_, ąska_, _تحار
  { {0xe3af0015,0xafdb00cb,0x6000008c,0xb4fb000a}},	//   _نرى_, msøk, töma, _ולדר
  { {0xafdb003c,0x05b2000b,0x11d70015,0x3377000a}},	//   lsøk, _जवाब, _يتعد, _חתוך_
  { {0xe3b80064,0xa91d0024,0x41e70015,0x64460091}},	//   lkı_, _ražo, _تستف, škiu
  { {0x8c19002b,0x113c000a,0x51f4002b,0x5bb90174}},	// [2190] سيار_, _ותחל, _جسور, плая_
  { {0x69c20079,0x441b000a,0x2d8900aa,0xe3b80061}},	//   ehoe, קובס, sdae_, nkı_
  { {0x248d0089,0xb17b02d2,0x6fd40015,0x5a350238}},	//   zvem_, pnåd, _جزيئ, хнет
  { {0x7eb6000a,0xd5a60002,0x317c004c,0x69c2042f}},	//   _נהרס_, _صف_, ַרומ, ghoe
  { {0xe3b80064,0xfd56000a,0x99d400c3,0x89d40015}},	//   kkı_, _אשרי_, ختلا, ختلط
  { {0x65bc0003,0xe0b8000a,0xdc3a05bd,0xe79b00c3}},	//   _réha, ולדט_, _מעשר, تخصص_
  { {0xafdb003c,0x6f7a000a,0x0000006a,0x0000006a}},	//   esøk, לְקו,   ,
  { {0xff180008,0x91fd0024,0x34a90054,0x248d0046}},	//   וקות_, stāj, звио_, tvem_
  { {0x600000c0,0xd5e80015,0xf8f40033,0xafdb00cb}},	//   dömn, بعون_, _аптэ, gsøk
  { {0xf7700074,0x6560002f,0xa3ca005d,0x87070015}},	//   _نام_, agmh, रोल_, _قبال
  { {0xeb9215bb,0xe29915bc,0xbb3a000a,0xc6a40004}},	//   אָר_, чан_, העתי, _ирци
  { {0xdb070084,0xcb12000a,0x1df9000b,0x56b6004c}},	//   _hljó, טלי_, ंतोष_, _אפען_
  { {0xb1430010,0xd4c40015,0x60b6002b,0xdb050012}},	//   ынял, _لغوي, رمسئ, chhö
  { {0xe4560053,0x78a400f2,0xa2e5004a,0x8f7502a3}},	//   _ניצט_, äivi, _полд, кусі
  { {0x670f005d,0x69c20026,0x64460007,0xa91d016f}},	//   ाधिक_, yhoe, škit, _pažl
  { {0x62860024,0x752915bd,0x70560015,0xdca615be}},	//   ākot, ncez, _كنعا, наби
  { {0x6b5615bf,0x644915c0,0x998d002a,0x6d4415c1}},	// [21a0] فضائ, nsei, _mień_, raia
  { {0x799b02e8,0xa037000a,0x6d4415c2,0x644915c3}},	//   _anuw, _ראיה_, saia, isei
  { {0x69c215c4,0xc0a90086,0x6d440375,0x2f3b000a}},	//   thoe, _فایل_, paia, _מגיד
  { {0x3940002d,0x644915c5,0x590a006b,0xb2ba000a}},	//   úis_, ksei, пеем_, המער
  { {0x69c20409,0xad1b000f,0xd9170033,0x83fd0030}},	//   rhoe, _מוכר, ньш_, rtőj
  { {0x7aeb0030,0xc7a3011a,0x64490d34,0x798b0034}},	//   élté, личк, dsei, adgw
  { {0x644b0971,0xeb91000a,0x644915c6,0xb60500bf}},	//   _avgi, _דָן_, esei, znáš
  { {0x38cb0086,0xafdb003c,0xa91d00bd,0x7b060024}},	//   _کافی_, tsøk, _lažj, ērtē
  { {0xdb070084,0x91fd0024,0x69c015c7,0xe3b80061}},	//   _fljó, stāk, _ilme, tkı_
  { {0x61e4000c,0xa3ca005d,0xafdb003c,0xe1fb005d}},	//   _ajil, रों_, rsøk, ृष्ण_
  { {0xa1590124,0x26d800c0,0x26c7005c,0xe3b80064}},	//   ману_, _äro_, czno_, rkı_
  { {0xe3b80064,0x644900b8,0xb6bb0008,0xf2c30033}},	//   skı_, bsei, _מצבי, усьн
  { {0xe3b80061,0x64b3006e,0xdfd10015,0xecd0000b}},	//   pkı_, _محور, ليح_, _सेलफ
  { {0x69c000cb,0xdb1e007c,0x30a4005e,0xa01b001a}},	//   _llme, gipü, урюв, fvör
  { {0x02930015,0x65bc0003,0x63b50030,0xb6050046}},	//   _مؤيد, _jého, özne, snáš
  { {0xb7b50016,0x02fb000a,0x7a470046,0x290400c7}},	//   _kịc, _מלומ, _létá, _ozma_
  { {0xf3f90045,0xfc300021,0x6ad90065,0xa01b15c8}},	// [21b0] suţe_, محل_, भप्र, rvös
  { {0xe800000b,0x69c015c9,0x61fd15ca,0x8ae700ce}},	//   _लीला_, _alme, llsl, ніел
  { {0xb7b50092,0x2bb80015,0x8ae7005e,0xdcef003d}},	//   _lịc, راكة_, хіал, _pacē
  { {0x91f60092,0x32370053,0x644900f2,0xdeb6000a}},	//   hún, גטאן_, ysei, _יפתח_
  { {0xf7710015,0xec150015,0x18690004,0x61fd02de}},	//   لاث_, _لوحد, фали_, ilsl
  { {0x2d8b0467,0xa91d0007,0xa6990001,0x64490020}},	//   _hace_, _kažk, дњих_, vsei
  { {0xedcb000a,0x998d002a,0x4ddb004f,0x2f98004f}},	//   ּמִֽ, _pień_, ּח֥ו, תכון_
  { {0x644915cb,0x66240015,0x644f0085,0x442f0c48}},	//   tsei, دروك, šcim, _ptg_
  { {0xd5ae0029,0xe3b10015,0xb4bd000b,0xb9e4005e}},	//   تفي_, لرد_, ीछे_, _сіри
  { {0xb7b50023,0x644915cc,0x98170015,0x2d8b00da}},	//   _dịc, rsei, _أبرا, _lace_
  { {0x1309005f,0xbcfb0003,0x443d15cd,0x9f8f0012}},	//   ьной_, _scél, _www_, _süß_
  { {0x32090092,0x2d8b0077,0x201a02f2,0x9f4a04b2}},	//   _chay_, _nace_, _sipi_, robí_
  { {0xe588000a,0x9f4a0107,0xb05b0012,0x33950015}},	//   _רָעָ, sobí_, nzäh, _للإز
  { {0xdce6006f,0x61fd0052,0x0000006a,0x0000006a}},	//   ámče, alsl,   ,
  { {0x201a003f,0xdb070046,0xb05b02ad,0x2d8b0160}},	//   _vipi_, _bojí, hzäh, _bace_
  { {0xc69201ac,0xa91d003d,0xf652004f,0x0000006a}},	//   סאן_, _dažk, יצל_,
  { {0xdb070089,0xad2500a2,0x11d70015,0x7bd70045}},	// [21c0] _dojí, ارفو, _جوية_, fixu
  { {0x291f02c1,0xdce40024,0xa01b002e,0xf38c0053}},	//   _agua_, ediģ, svör, ּראָ
  { {0x68fb0467,0xcf570008,0x0f570632,0x0b590010}},	//   _ayud, _בבית_, _ביים_, эрты_
  { {0xfbc90008,0xf1bb0016,0x29d50046,0x7a470030}},	//   חת_, _luơn_, sťan_, _sétá
  { {0x07a60010,0x2d80046d,0x764a0034,0xc7c6033d}},	//   кадн, meie_, wsfy, кски
  { {0xc7af0015,0xd7f7006b,0x2d8000cb,0x8ccb000b}},	//   يّن_, кущ_, leie_, _सेटो
  { {0xfaa315ce,0x692615cf,0xbb77000a,0x96340054}},	//   _каро, _амба, _שעלו_, ћниц
  { {0x5e5700b2,0xceb30008,0x96b70001,0xa533006b}},	//   דיקע_, שיה_, ђују_, анъч
  { {0x8a17000a,0x65b50077,0x3957004f,0xe8f700af}},	//   _יחלו_, _náhu, _ששמם_, _алт_
  { {0x2d8004f9,0x65bc0046,0x212001c2,0xa785012c}},	//   heie_, _tého, _agih_, _مشمو
  { {0x2d80020a,0xd7ef0029,0x0bb70008,0xe3af0115}},	//   keie_, _بكل_, דלים_, تري_
  { {0xb6d90053,0x04960029,0x3035004a,0xa5da006e}},	//   _אַנט, _للصح, лемё, _غبار_
  { {0x2d8b0b62,0x3eb8001a,0x0000006a,0x0000006a}},	//   _race_, eyrt_,   ,
  { {0x040d0016,0x403401c5,0xa4b7004f,0x0000006a}},	//   _mườn, рерс, _בלדה_,
  { {0x320900a7,0xa6f8000a,0x0dbb0015,0x040d0016}},	//   _thay_, גִּי, وارث_, _lườn
  { {0x1317000a,0xdddc14a7,0xc536004f,0x0000006a}},	//   _בחול_, avrž, דָ֑ה_,
  { {0x1df80080,0xf3f90045,0xdcf40015,0xe1ff0030}},	// [21d0] теты_, luţa_, لأكب, mló_
  { {0xf0920008,0x1b7b0029,0xad9b002d,0x309a000a}},	//   _פני_, بصرة_, _mhúi, _נשתמ
  { {0xcb680015,0xc9590015,0x2d8b15d0,0x7afc0416}},	//   ضمنه_, فلاش_, _tace_, _cyrt
  { {0xe1ff00dc,0x83fd0030,0xe945002b,0xa91d06c0}},	//   nló_, rtői, ارای, _kaži
  { {0x3da4008f,0x040d0092,0x7c22002d,0x7dda0091}},	//   _трэб, _cườn, íort, rįst
  { {0xa91d00df,0x040d0092,0x1d16000a,0xb05b0012}},	//   _maži, _dườn, _תקשר_, rzäh
  { {0xf770087c,0xb05b0012,0x3619004a,0xa6640015}},	//   تان_, szäh, нцию_, لطيو
  { {0xd5b10092,0xdddc0046,0x394400da,0xb867002b}},	//   _nút_, zvrž, _gems_, _لائو
  { {0x58840010,0xad9b002d,0x4415006b,0xe576056d}},	//   _выха, _chúi, лфот, узы_
  { {0xd7740086,0x39440024,0x69d912d1,0x60001581}},	//   _نامع, _zems_, liwe, tömm
  { {0x614615d1,0xd5b10016,0xd57508f7,0x216a15d2}},	//   лена, _bút_, _буль, нини_
  { {0xcf89000a,0xfa76000a,0x600015d3,0x69d915d4}},	//   _מט_, נערת_, römm, niwe
  { {0xd24e0074,0xe3b30074,0x753b003f,0xe4c80015}},	//   ينی_, _پرش_, mbuz, _لبون_
  { {0xd8da0008,0xe1ff00dc,0x24530086,0x645b0079}},	//   תקשר, aló_, _منچس, mrui
  { {0x3ebe002e,0xa91d0024,0x2eb50080,0x69d9003f}},	//   átt_, _daži, астс, kiwe
  { {0x45b50053,0x0c3a0015,0x01660923,0x3f8c0d7c}},	//   נפּל_, فكرة_, _скио, ždu_
  { {0x69d90026,0x7afc0026,0x672100bc,0xec7a0033}},	// [21e0] diwe, _syrt, _oglj, эпа_
  { {0x8b260805,0x3ea615d5,0xac970058,0x9f86009b}},	//   удже, _биог, دنكا_, _сгод
  { {0x645b002f,0x0309000a,0x9a460015,0x6f4b000a}},	//   hrui, תִּֽ, اضطه, _אֲכַ
  { {0x91fd0024,0x5cf60010,0xb2f60053,0x38cb0086}},	//   stāv, _бягу, אצעס_, کامی_
  { {0x6d46121a,0x7afc0034,0x98560ac9,0xb85600af}},	//   _ieka, _wyrt, утеш, уђењ
  { {0x91fd0048,0xa6340036,0x645b15d6,0xe1ff0030}},	//   ltāt, анкі, drui, zló_
  { {0x6d460375,0xf1c10264,0xf76f00c3,0x645b0079}},	//   _keka, ášky_, ساو_, erui
  { {0x040d0092,0x54540893,0x4e37004c,0x91fd003d}},	//   _tườn, авит, אָזן_, ntāt
  { {0x136a0063,0xd5b10092,0x86070015,0x48e6004a}},	//   ншни_, _rút_, دقيق_, _соав
  { {0xf626005e,0x6d4615d7,0x4274125c,0xd7b80065}},	//   _бджо, _leka, агос, _अविच
  { {0xb345001c,0x2bf70053,0x7c26108a,0x41b50015}},	//   _seçã, רמין_, _lukr, لمدر
  { {0xd257008f,0x645b15d8,0x6d4615d9,0xd5b9004a}},	//   ыць_, brui, _neka, _а́ю_
  { {0x7c2600df,0xf3f90011,0xa91d0007,0x50670010}},	//   _nukr, suţa_, _paži, ытна
  { {0xa3e8005d,0x69d912d1,0x4fc709c3,0xee870033}},	//   _यदि_, ziwe, усма, лыбо
  { {0x4426000c,0xfebb002b,0xe1ff0030,0x6d4615da}},	//   _huo_, راست_, pló_, _beka
  { {0x44260007,0x98c4000b,0x6d4615db,0xc2530015}},	//   _kuo_, वनाए, _ceka, _اخوت
  { {0x44260007,0x8bd50010,0x69d9003f,0x41c40031}},	// [21f0] _juo_, ажац, viwe, _دقيق
  { {0xf1bf0089,0x7c260091,0x69d80003,0x4aeb004a}},	//   lká_, _dukr, èven, ньем_
  { {0x4426022d,0x99350029,0xb9250058,0x3f830160}},	//   _luo_, لفات, لفضي, meju_
  { {0x3ebe0af5,0x89370021,0x19590033,0x6d460009}},	//   øtte_, اعضا, тады_, _geka
  { {0x442600df,0xa9480086,0x3158004c,0x80db000b}},	//   _nuo_, الهٔ_, רידן_, _पेमे
  { {0xfe700086,0x7bd500b8,0x629815dc,0x65b50227}},	//   _بدی_, _umzu, _orvo, _náhr
  { {0xdb05002e,0xf1bf0307,0x6d4615dd,0x0000006a}},	//   rkhó, kká_, _yeka,
  { {0x44260035,0x370a000b,0x645b15de,0x649915df}},	//   _buo_, ाधड़ी_, trui, втор_
  { {0x6298022d,0x05a60080,0x645b14e9,0xf7490015}},	//   _arvo, рвый_, urui, _للذي_
  { {0xe2990124,0x6721016f,0xf7730002,0x60000123}},	//   вао_, _uglj, _دار_, römk
  { {0xd5ae0086,0x8bd6000a,0x11d60015,0xd7c80015}},	//   سفی_, שותו_, لتحد, _حوله_
  { {0x11d6005e,0x3f91003d,0xe63a004f,0xd6d80138}},	//   ріор, edzu_, _יתעכ, _сту_
  { {0x62980111,0x628a15e0,0x55ba000a,0x03a50c9a}},	//   _ervo, _esfo, _שמנו, _вило
  { {0x25ad0020,0x91fd0024,0x88ba0053,0x6d4615e1}},	//   ljel_, tuāc, דזשי, _seka
  { {0xf2330086,0x6d4615e2,0x7c2615e3,0x33da004f}},	//   _ابتک, _peka, _sukr, _בחסד
  { {0xf1bf0156,0x6717005d,0x25bf15e4,0xdee3005e}},	//   cká_, धेयक_, nkul_, іоти
  { {0x8fc50086,0xcce50015,0x0b4608a6,0xec160015}},	// [2200] _گزين, مسكي, инан, لورد
  { {0x91fd15e5,0x1d190a31,0x909b000a,0x7dc3007c}},	//   grāf, уюсь_, _יספק, _võsa
  { {0xa92615e6,0x6d460509,0xaf5b000a,0x2f5b000a}},	//   адел, _teka, _בכיכ, _בדינ
  { {0x25ad0030,0x98bd002a,0x61e615e7,0xa95a0058}},	//   jjel_, zawą_, nnkl, ئجار_
  { {0xdb070089,0x61e60007,0x83fd00dc,0x6d3b0008}},	//   _vojá, inkl, ntős, _בתכנ
  { {0x91fd0048,0xd90d0086,0xf1bf01b2,0x06540015}},	//   ntār, ریل_, zká_, منتح
  { {0x442602d7,0x64420050,0xdb0700dc,0x4b7b000f}},	//   _suo_, _swoi, _tojá, _שאלו
  { {0xafdb06f5,0xbcfb002d,0xd5b7004a,0xd910002b}},	//   nsør, _scéi, исы_, _فیض_
  { {0xa4d40010,0x98bd002a,0xdb1e007c,0x442603f0}},	//   сопі, tawą_, gipö, _quo_
  { {0xa5070001,0xa91d0007,0x61e6093b,0x62980c1a}},	//   шења_, _pažv, enkl, _prvo
  { {0x3f830007,0xa91d0024,0x98bd002a,0x03c30033}},	//   veju_, _dažu, rawą_, ісьм
  { {0x64420050,0x442615e8,0x76bb000a,0x28db000b}},	//   _twoi, _tuo_, _שמאפ, _मेडि
  { {0xdb0e0064,0xe3af0086,0x75d3012c,0x43940148}},	//   _albü, سری_, _بينا, _галс
  { {0xf1bf0f1b,0x63f30015,0xdfdb006b,0x33f30067}},	//   ská_, _وأور, тъм_, _وسوس
  { {0xdeb40174,0x3f8315e9,0x753d0030,0x5337004f}},	//   обры, reju_, űsze, _דנון_
  { {0xd657000a,0x7ae1006f,0x82330040,0xdb1e007c}},	//   יילת_, _žlto, _بروا, nipõ
  { {0x91fd0024,0x4c940731,0x26e2000b,0x7de50091}},	// [2210] stās, оитс, गपुर_, lėsk
  { {0x60c00293,0xde67006b,0x3dc915ea,0x3c440058}},	//   ømme, _къмп, shaw_, تَكِ
  { {0x6e95003b,0x2003044c,0xee870033,0x3a750249}},	//   _الجا, mlji_, _тыпо, слер
  { {0x62860050,0x39150010,0xf9d4005e,0xaa58098b}},	//   łkow, бмер, оцію, рицу_
  { {0x9f510089,0x2259002a,0x1821000b,0xb4e5000b}},	//   hozí_, ąski_, मदेव_, _नशे_
  { {0x6000008c,0x8a370015,0x29d5016d,0x0000006a}},	//   tömi, _نعرض, zťah_,
  { {0x91fd0024,0xc7c80010,0x45d50063,0xcf58000a}},	//   orād, шыце_, йцит, בבות_
  { {0x59f9005f,0x3940002e,0x77bd0251,0x6d4d0b63}},	//   _себя_, ðist_, _mèxi, naaa
  { {0x7bc715eb,0x04560029,0x26c1002c,0x64c50029}},	//   _klju, ملية_, šho_, صيدل
  { {0xb8dd005d,0xd6db0923,0xe7300015,0x6498006b}},	//   ुई_, _ите_, _قصم_, ртър_
  { {0x57fa0053,0xf089000a,0x8b88000a,0xdb1e007c}},	//   _עלעו, _רנ_, בָרֶ, bipõ
  { {0xd3780085,0x930d0061,0xad9b0125,0x91e615ec}},	//   viće_, _ışık, _mhús, соме
  { {0x34ab0029,0xa9fa000a,0x7412002b,0xe3ae1377}},	//   _جداً_, רִית, تویا, _еб_
  { {0x6d4b002e,0xd3780085,0x91fd003d,0x656902f7}},	//   ðgan, tiće_, erād, lgeh
  { {0xada615ed,0x6da615ee,0xe3b0002b,0x72350015}},	//   бавл, бива, _ترن_, _ارتط
  { {0x1d260054,0x656915ef,0xd3780085,0xdb1201f6}},	//   смам, ngeh, riće_, _égér
  { {0x998d005c,0x69d80152,0x20030b28,0xdca31411}},	// [2220] _wieś_, èvem, blji_, пати
  { {0x7f860029,0x91fd0024,0x7dda0089,0xbb4a0087}},	//   _الدن, arād, půso, الان_
  { {0x4a9a0010,0x1617000b,0x5fb7000a,0xb05b0123}},	//   ытаў_, दगार_, _ההיא_, tyäg
  { {0x27e9002d,0x7bc700dc,0xdb1c00c0,0x65690079}},	//   éann_, _elju, _omrö, jgeh
  { {0x28d2021e,0xa8770015,0x63a300aa,0x656915f0}},	//   _देखि, محور_, _onnn, dgeh
  { {0xfaa6008f,0x207b0053,0xf093000a,0xab2702b0}},	//   _лаго, ראסא, פנו_, _гора_
  { {0x656900b8,0x8f9b0008,0x7bde0213,0x2a350010}},	//   fgeh, טיסי, mipu, _мэтр
  { {0x75d40087,0x69cb11b4,0xa9c6002b,0x45b8004a}},	//   تيبا, chge, _ازسو, ргию_
  { {0xc34a15f1,0xe73a0829,0x74140058,0x3437009a}},	//   ляне_, _без_, يوبا, یسید_
  { {0x91fd0024,0x289b004c,0xa91d0091,0xdcef003d}},	//   zrād, _גימא, _važt, _sacī
  { {0xd5af15f2,0x4b7b000a,0xabfb000a,0x628f002a}},	//   _ес_, נאטו, רפיז, łcon
  { {0x31c70080,0x9c830007,0x645d0896,0x92570080}},	//   ссов, ščiu, ásic, щают_
  { {0x7bde15f3,0x107415f4,0xf50600e2,0x83fd0030}},	//   kipu, пляю, _уздо, rtőr
  { {0x6ee70029,0x7de50091,0x93f3005e,0xb4e4000b}},	//   مسأل, mėsi, _епіц, फपी_
  { {0x7de500df,0x43770053,0x91fd0024,0x63770008}},	//   lėsi, _לײגן_, trād, _הגוף_
  { {0x7bcb0024,0x91e40054,0x83fd0030,0x0000006a}},	//   īgum, _ноје, ltőp,
  { {0xcf8e0074,0x7bcb0024,0x30a40033,0x7de50091}},	// [2230] رژی_, ūgum, _ерэв, nėsi
  { {0x2bbb0029,0xdfd10086,0xad9b002d,0x3b5500e2}},	//   دارة_, _آيد_, _chúr, ікер
  { {0xc333013a,0x7bc700bc,0x6d4d02f2,0x387f15f5}},	//   פוף_, _vlju, paaa, _spur_
  { {0x7de50007,0x6b8502ad,0x0000006a,0x0000006a}},	//   kėsi, sehg,   ,
  { {0xa01b00dc,0xfd96000a,0xf865005e,0x27e90077}},	//   dvöz, _ודרך_, івко, éano_
  { {0x7de50007,0x207c0053,0xdb0e0011,0x98480139}},	//   dėsi, טאדא, _dobâ, сяца_
  { {0x5fbc013a,0x3ffc0053,0x656915f6,0x6f4c000a}},	//   רצונ, אפגע, tgeh, אֲחַ
  { {0x95990484,0x59c50015,0xe45915f7,0xa91d003d}},	//   ртку_, _بيرك, ажи_, _dažr
  { {0x656915f8,0x7de50091,0x0000006a,0x0000006a}},	//   rgeh, gėsi,   ,
  { {0xa3d3005d,0x656900b8,0xd7fb13ae,0x61ed041c}},	//   सों_, sgeh, _суб_, _ajal
  { {0xf77004b6,0xd9b5000a,0xcb88000a,0x65690547}},	//   _سال_, ַּ֨ח_, זְרֹ, pgeh
  { {0xb1da0036,0x7de50007,0x216a03e7,0x36050015}},	//   рьох_, bėsi, шими_, _بوصف
  { {0x23b50015,0x98bd002a,0xe3d50015,0xd00a15f9}},	//   _ومؤس, tawę_, _وتتع, иеме_
  { {0xd9b6005d,0x75d3002b,0x69c90079,0xcf250015}},	//   _अक्ट, _بيچا, _llee, كرفي
  { {0x98bd005c,0x61ed002e,0xdb0e0046,0x69c9008c}},	//   rawę_, _fjal, _pobí, _olee
  { {0x61ed0084,0x91fd0024,0xc692039e,0x22510057}},	//   _gjal, nuāl, ואל_, ázku_
  { {0xfc1a0029,0x6b560015,0xd3780085,0x2259002a}},	// [2240] لقرب_, قضائ, lića_, ąsku_
  { {0x6000008c,0x69c915fa,0x6abe0dca,0x73f9004f}},	//   tömu, _alee, typf, בּ֣ו
  { {0xdcff0024,0x69c905d6,0x092a004a,0xd3780085}},	//   īvāk, _blee, ажей_, nića_
  { {0x7ae3002d,0x600000b8,0x9e630033,0x627a004c}},	//   únta, römu, _ўвяд, ינענ
  { {0x91fd0024,0x8b660029,0xe7c5000b,0x9b460015}},	//   duāl, _واسم, वसंप, _ونحو
  { {0xa09b0135,0xb09b004c,0xaa460aed,0x409b000a}},	//   יינט, יינר, _мегл, יבנס
  { {0xeb9100b2,0x69c9003e,0xe666008b,0xc9860015}},	//   _אָן_, _flee, ітко, _وشري
  { {0x35f70086,0xd378016f,0xfad7000a,0x8f1b004f}},	//   يريد_, dića_, _וולך_, סוקת
  { {0x386600c7,0x6b990125,0xb7e615fb,0x9f510030}},	//   quor_, _éagó, _джак, hozá_
  { {0x7de50007,0x249d0026,0x61ed0c8e,0x9f580003}},	//   rėsi, _drwm_, _sjal, boré_
  { {0xc7b30008,0x69c900f2,0x51f905d1,0x2c740034}},	//   _קבע_, _ylee, йною_, häd_
  { {0xc2b7005e,0x7de50073,0x645d0073,0x0000006a}},	//   іляє_, pėsi, šsia,
  { {0xc95301e4,0x80db005d,0x05b30015,0xa50706a6}},	//   ומר_, _पेशे, _تمنح, _деца_
  { {0xa2e60015,0xcf270015,0xd3780085,0x3a2404a9}},	//   _وأثن, ترحي, bića_, _limp_
  { {0xcddb03f1,0x91fd0024,0xc7d7000a,0x80db000b}},	//   ања_, grāc, קולי_, _पेरे
  { {0xd1310015,0xd257004f,0x2904007f,0x61ed0de4}},	//   _ثمة_, _ושהה_, _oyma_, _ujal
  { {0xfc300015,0x8cc40015,0x91bc000a,0xcf270058}},	// [2250] نحل_, وقفه, _כמהי, _وردي
  { {0xaac70074,0xc43b000a,0x69c915fc,0x91fd003d}},	//   يتان, יתמי, _slee, zuāl
  { {0x8ae70191,0xaa950029,0x0af90029,0x93fb000a}},	//   ціал, ثلاث, حفاظ_, סלבי
  { {0x99d40086,0xd8750015,0xbcfb006f,0xfbdf0034}},	//   وتنا, كاتب, _dcér, _gwên_
  { {0xed05002b,0xc7a5006b,0x394f0012,0x1eea002b}},	//   _روسپ, зилк, rags_, _نویی_
  { {0x29040176,0x9f58032c,0x4cba000a,0xe7310067}},	//   _dyma_, toré_, _המשג, رصت_
  { {0x91fd0024,0x6fc2006f,0x28db000b,0xaa5815fd}},	//   tuāl, _dôch, _मेरि, _миру_
  { {0xd378016f,0x61fd0024,0x3694005e,0x212901c2}},	//   vića_, josl, ьшіс, _ngah_
  { {0x478b0080,0x61fd15fe,0x44390003,0xf992004f}},	//   _всем_, dosl, ës_, _ארן_
  { {0x44390024,0x4734002b,0xd3780085,0x0bb6000a}},	//   īs_, _قرمز, tića_, ִ֜ים_
  { {0x443915ff,0x9f4e0089,0xe1fa0010,0x7dca002e}},	//   ūs_, áním_, йго_, _lýsa
  { {0x249d0026,0xd3780085,0x61fd1600,0x41b30058}},	//   _trwm_, rića_, gosl, ّمَر
  { {0x394d1601,0x10160010,0xf8bd000b,0x9f4e0046}},	//   _mees_, зьвя, ्निय, šním_
  { {0x78a60084,0x437500b2,0x394d049c,0xdd920086}},	//   _ákve, _זײַן_, _lees_, کور_
  { {0x443f1602,0xc7b20053,0x6012002e,0xc3320053}},	//   lpu_, ײבן_, væmd, _אוו_
  { {0xc8bd005d,0x82d60008,0xc6920053,0x443f0024}},	//   ्नाट, _מוצג_, עאן_, opu_
  { {0xdd8f0070,0x3c660010,0xc5f2000a,0x69bf000b}},	// [2260] دوق_, якаг, גדן_, _वक़ी
  { {0x909b0008,0xb09b000a,0xa09b000a,0x443f1603}},	//   _פסיק, _פייר, _פייט, ipu_
  { {0x5fbb000a,0x394d00da,0x09e602ed,0x3a2401f9}},	//   _הצינ, _bees_, пожн, _pimp_
  { {0x6fcb0064,0x3236004c,0xf9920015,0xa96a135f}},	//   _tücc, לטען_, عبا_, сида_
  { {0x6d441604,0xc7b8005e,0xdb0e013f,0x18670bb1}},	//   mbia, оґа_, _dobá, зачи_
  { {0x6d440007,0x3f8a0026,0x25b20026,0x3f981605}},	//   lbia, nebu_, _ŵyl_, ndru_
  { {0x3a2404f9,0x63b8099c,0x67530086,0x394d1606}},	//   _timp_, _rovn, رخور, _fees_
  { {0x6fcb0064,0x394d00dd,0xda5b000a,0x86c30015}},	//   _müca, _gees_, _לכלל, عيين
  { {0x6d441607,0x61fd1608,0x6283005a,0x0000006a}},	//   ibia, vosl, _apno,
  { {0x883b0008,0x7de50007,0x8857000a,0x60270003}},	//   _לתמו, lėst, _משמע_, hémè
  { {0xd6c40086,0x443f0340,0x11d90015,0x9473002b}},	//   _تمای, apu_, قودة_, ودیا
  { {0x25a60026,0x7c3a0046,0x92930033,0x3f981609}},	//   _unol_, _čtrn, хаюц, edru_
  { {0x859b000a,0x77bd0144,0x9f580034,0x61fd06ca}},	//   _לשאו, _tèxt, gorï_, rosl
  { {0xb7bd04f9,0x251b000a,0x3f8a01d7,0x6d440034}},	//   _puţi, _הודא, gebu_, ebia
  { {0x6b95052c,0x64400991,0x637b000a,0xd37b000a}},	//   _razg, lpmi, _הנוד, _הרוט
  { {0x463b004c,0x3f9800d4,0x92f200d4,0x0000006a}},	//   מעלע, adru_, ăşăm,
  { {0x7de50007,0x0c390029,0x394d0335,0x515c000a}},	// [2270] dėst, زكاة_, _rees_, _הכחו
  { {0xfe6e0074,0xbca4003b,0x60cf0064,0x394d0100}},	//   دگی_, عملي, ınmı, _sees_
  { {0x6b950064,0x660200dc,0x6d44160a,0x7d06001a}},	//   _vazg, _okok, bbia, _eyks
  { {0x3eac0293,0x248d002a,0xc237000a,0xd8f5002b}},	//   ådte_, ywem_, פרדו_, وزشک
  { {0x315800b2,0x88190010,0x394d007c,0x6d5d0789}},	//   ליאן_, оўку_, _vees_, _idsa
  { {0x394d020a,0x4639004a,0x98a2135f,0x67d41534}},	//   _wees_, очия_, тише, ночу
  { {0x4ac50086,0x6d4f0049,0x9f5e0003,0x1665005e}},	//   _غيرق, _keca, ôté_, євим
  { {0x19940010,0x248d005c,0x8459160b,0x6e3800dc}},	//   _пася, twem_, орот_, _évbe
  { {0x85540086,0x6f090046,0x6d4f160c,0x657b0012}},	//   ریور_, řech, _meca, rfuh
  { {0x798b0034,0x443f160d,0x657b02ad,0x6d4f10b6}},	//   legw, rpu_, sfuh, _leca
  { {0x6d440026,0xd7580029,0x7c2f160e,0xdb68000a}},	//   ybia, _رجلا_, _lucr, הֳרָ
  { {0x798b0026,0x65150029,0x71da0036,0x96fa0008}},	//   negw, _قوائ, ієнт_, _ולעת
  { {0x95540086,0xc4fb0086,0x66090061,0xd3b90033}},	//   _سخنا, _اعضا_, mlek, _мукі_
  { {0x02450015,0x66091123,0x7d060811,0x6d440034}},	//   _قَتَ, llek, _ryks, wbia
  { {0x6d4f0041,0x4427160f,0x3f8a1610,0xe80e000b}},	//   _beca, _iin_, rebu_, ितता_
  { {0x7e610084,0x661b00f2,0x44271611,0x6d4f01c2}},	//   álpa, nmuk, _hin_, _ceca
  { {0x1d070001,0x6d441612,0xfce30076,0x6fd6005e}},	// [2280] дети_, rbia, вото, _жінц
  { {0xabaa0029,0x7d060007,0x8c950033,0xd239000a}},	//   غهام_, _vyks, эрсі, ַגְל
  { {0x6eb5005d,0x1ee80086,0x7d06005c,0x8f8b000a}},	//   _उपयु, _روحی_, _wyks, _וְכֵ
  { {0x44271613,0x58860010,0xfe9b000a,0xc8ca0115}},	//   _lin_, дыка, _ויטמ, يوان_
  { {0xa3cd000b,0x891a002b,0x91fd003d,0x645d14b9}},	//   रसा_, آغاز_, krān, ásil
  { {0x442701e2,0x66091614,0x660209cd,0x945d002a}},	//   _nin_, elek, _skok, zyńc
  { {0xd6d0003b,0x34b8005d,0x442f1615,0x4a4602a3}},	//   طقة_, ेन्द, _aug_, _інав
  { {0xd5b0003b,0x661b02f2,0x7c270079,0x442f1616}},	//   افة_, gmuk, _zijr, _bug_
  { {0xc5f70015,0x7c290030,0x44271617,0x39461618}},	//   بعوض_, _éert, _bin_, mbos_
  { {0x394600df,0xa3d8005d,0xe8d70008,0x442f1619}},	//   lbos_, ठों_, _חומר_, _dug_
  { {0xbcfb161a,0x6609161b,0x4427161c,0xdb9b004f}},	//   _idée, blek, _din_, קסטר
  { {0xf6690029,0x7dc30020,0x4427161d,0x6602003f}},	//   _رحمه_, _tõsi, _ein_, _ukok
  { {0x361b0053,0x4427161e,0x9393002b,0x29f80085}},	//   _וואד, _fin_, رجیا, mčad_
  { {0x250b0086,0x6d4f013c,0x73c40015,0xe4b70033}},	//   _برمی_, _seca, _سيعم, _юліі_
  { {0x442f00b8,0x12b30015,0x33fb000a,0x92b30015}},	//   _zug_, _لإيج, _והגנ, _لحيا
  { {0x4427161f,0xa1870033,0x518701f3,0x7bce1620}},	//   _zin_, _цыкл, _цука, _albu
  { {0x6d4f0024,0x42180015,0x7d080015,0x44271621}},	// [2290] _veca, _تزوج_, ِيقِ_, _yin_
  { {0x2fc700a7,0x44270023,0x660900dc,0x60c00c77}},	//   _ông_, _xin_, zlek, ämme
  { {0x6d4f1622,0x2ef40033,0x38661623,0x61ef1624}},	//   _teca, _азэр, eror_, oncl
  { {0x38660bc8,0xeab00015,0x6d5d02de,0x7bce0030}},	//   fror_, جعك_, _udsa, _elbu
  { {0xdd3a013a,0x52ca000b,0xf1b4000a,0x71d8004c}},	//   _מערכ, ानुस, כסף_, וואד_
  { {0xe6110086,0xa695009c,0xcc76000a,0x96950054}},	//   گشت_, ериј, _אעשה_, ериш
  { {0x44271625,0x6b6800dc,0x77360015,0x66091626}},	//   _rin_, ségü, ركيز_, tlek
  { {0x9f58002c,0xfc3f002d,0xe611002b,0xa87b0015}},	//   vorí_, _tríd_, دشت_, _وحذر_
  { {0x0efc005d,0x66091627,0x661b0d20,0x2d991628}},	//   _एड्स_, rlek, rmuk, _mase_
  { {0xe3b1003b,0x02ca005d,0x78a6002e,0xd8860086}},	//   ارة_, ानून, _ákva, _سهمی
  { {0x03940010,0x8c1c000a,0x1309056d,0x44271629}},	//   трыя, חוזי, яной_, _vin_
  { {0x4427108f,0x442f055e,0x764302f2,0x2d99162a}},	//   _win_, _tug_, mpny, _nase_
  { {0x4427162b,0x2ec8000b,0xb0e0000b,0xe534004a}},	//   _tin_, रन्त, _पेशग, _речь
  { {0xe4560053,0x4427162c,0x3cf3000b,0xe3b0002b}},	//   _טינט_, _uin_, ंपने_, _پره_
  { {0x39460007,0xdb1c0061,0x2d99162d,0x249f001a}},	//   ybos_, üzün, _base_, lvum_
  { {0xdb1c0152,0x2d990376,0x160f000b,0x7dca0247}},	//   _forê, _case_, ातिर_, _výso
  { {0x3dd20176,0x8fa60de5,0xa3e3000b,0x61e6162e}},	// [22a0] rhyw_, _запе, _नगा_, mikl
  { {0xfc3f002f,0x61e6162f,0x395f0011,0x2d99003e}},	//   _dtí_, likl, _adus_, _ease_
  { {0x160f005d,0xb17b00c0,0x319a000a,0x2fc50061}},	//   ातार_, pnåt, ּבְנ, ölge_
  { {0x523a0053,0x61e61630,0x2d991631,0x249f001a}},	//   לײענ, nikl, _gase_, kvum_
  { {0xa9270191,0xb346001c,0x61e60020,0x5837005e}},	//   ніше_, niçõ, iikl, езія_
  { {0x2d990c6d,0x386603b8,0x6d561632,0xc053004f}},	//   _zase_, rror_, laya, נזו_
  { {0x25bd1633,0x61e61634,0xd7570015,0xe5c61635}},	//   _bowl_, kikl, رجوا_, еспо
  { {0x3f9a0048,0xceb3011f,0x3949002e,0x6d561636}},	//   _lapu_, ריה_, ðast_, naya
  { {0x1867000d,0x61e61637,0x76430030,0x53e61638}},	//   _пати_, dikl, apny, ецна
  { {0x3c770008,0x61e60007,0xb3560086,0x66001639}},	//   עתים_, eikl, ریبا_, somk
  { {0xd2570036,0x6600003f,0x61e6048b,0xf77300a3}},	//   нця_, pomk, fikl, _תקע_
  { {0x6d56163a,0xab640064,0x6012002e,0x61e60091}},	//   jaya, ldüğ, væma, gikl
  { {0x7dca04af,0x6d56013c,0x2ca00085,0x2d99163b}},	//   _výsl, daya, jvid_, _rase_
  { {0xb4be005d,0x2ca000c0,0x2005002c,0xab640064}},	//   ीनी_, dvid_, ôli_, ndüğ
  { {0xd3350010,0xdb15163c,0x1ee7002b,0x8337004c}},	//   _рэчы, _pozí, روری_, _טאגס_
  { {0x3253010f,0x6d5600b6,0x3ebe012d,0xb346016e}},	//   _свър, gaya, ätta_, biçõ
  { {0x51fc000a,0xacf8163d,0x2d99163e,0xa91d163f}},	// [22b0] _מההצ, енту_, _vase_, _obža
  { {0x1cb80015,0x3dc90535,0x9f5803a0,0x0000006a}},	//   راقب_, skaw_, corà_,
  { {0x20030007,0x6d561640,0x2d991641,0x83fd0030}},	//   moji_, baya, _tase_, ttőz
  { {0x20030064,0x9a880015,0x645d0030,0xaf4b002b}},	//   loji_, عَنْ_, ásik, _بشکل_
  { {0xcf270086,0x7dda0089,0x83fd00dc,0xe72e0254}},	//   _ترکي, růst, rtőz, ие_
  { {0xa01b002e,0xa09c0053,0xb09c000a,0x08c40033}},	//   stöf, פיוט, פיור, ыбін
  { {0x91fd003d,0x34c9000b,0x60c6006f,0x5ba4009b}},	//   trāl, िन्द, zykm, _сряз
  { {0xb4be000b,0x36180033,0xc485070c,0xa5f600af}},	//   ीनू_, нцыю_, влик, кеју_
  { {0x91a90092,0x61e61642,0x99870091,0x20030de8}},	//   _giả_, vikl, ūnų_, koji_
  { {0x799b003f,0xe4c80029,0x20030007,0xf77000e6}},	//   _hauw, عبين_, joji_, _هام_
  { {0x6d5600b6,0x27e7002e,0xc64b00e6,0xeb92000a}},	//   yaya, minn_, _رجال_, בָר_
  { {0xe3b10086,0x27e71643,0xc692000a,0xb346016e}},	//   ارک_, linn_, _כאב_, tiçõ
  { {0xc9520008,0x32020107,0x69cb0079,0x26c70091}},	//   סמך_, roky_, ikge, lyno_
  { {0x200300bd,0xb346001c,0xa8560008,0x60c6008c}},	//   goji_, riçõ, כישה_, rykm
  { {0x52b20029,0xb346001c,0x26c70007,0x6d560ad4}},	//   _نموذ, siçõ, nyno_, taya
  { {0x799b0111,0xac9a0015,0x753b1644,0x69cb0079}},	//   _nauw, ونزا_, ncuz, jkge
  { {0x27e7002e,0x91fd0024,0x645b0618,0xdcfd0091}},	// [22c0] kinn_, krāj, nsui, _masė
  { {0x201a003b,0xfaa6034e,0x80db000b,0x2055006b}},	//   _تتبع_, казо, _पेटे, _стър
  { {0x81f70086,0x799b00b8,0x6d561645,0x27e7001a}},	//   _سفیر_, _bauw, paya, dinn_
  { {0x5e5700b2,0xd5af0036,0x645b0604,0x186a0004}},	//   _ביטע_, _всi_, ksui, дади_
  { {0x27e7002e,0x61e4003f,0xa1370053,0x76410091}},	//   finn_, _mmil, דאנק_, _atly
  { {0xf0930053,0x27e7074c,0xda660002,0xe6780033}},	//   ינד_, ginn_, _لاري, ейкі_
  { {0x7dc30020,0xab640064,0x656600dc,0x67d30036}},	//   _tõst, rdüğ, ókho, рощу
  { {0x69cb00b8,0x6b9c013c,0x6a97000a,0xd3780085}},	//   ckge, _harg, _בכלא_, mići_
  { {0xb4cc014e,0xb4be014e,0xd467000d,0x6b9c1646}},	//   रने_, ीने_, виње_, _karg
  { {0x674502d5,0x799b005c,0x43940001,0x69c01647}},	//   čují, _zauw, ћанс, _home
  { {0xa3e3005d,0xd6c40086,0xad9b002c,0x6b9c1648}},	//   _नगर_, _حمای, _skúm, _marg
  { {0xdb1c1649,0x6b9c164a,0x386906c0,0x31c702ed}},	//   _coré, _larg, šare_, тсов
  { {0xf993000a,0xdb1c0003,0x5067006b,0xa2630016}},	//   ברר_, _doré, ътна, _huố
  { {0xbcfb002d,0x9f58002c,0x3f85002c,0xa3e1000b}},	//   _ndéa, torá_, ýlu_, नोद_
  { {0x9e070191,0xb062008c,0x3ea5001a,0xe731000a}},	//   вчал, _äänn, ílt_, מֵן_
  { {0xa2630023,0x1dc50015,0xd3780085,0x200300bc}},	//   _muố, دْرِ, dići_, soji_
  { {0x9d1505c4,0x6b9c04dd,0x320902f2,0x91f8004f}},	// [22d0] удач, _barg, _ikay_, _שמחו_
  { {0x6b9c113d,0x6fb50015,0x8bd40033,0xfc3f0077}},	//   _carg, _إمدا, ажуц, _cría_
  { {0x6b9c164b,0x69c00079,0x6fcb0012,0x6562006f}},	//   _darg, _bome, _lück, _odoh
  { {0xceb20053,0x5ee8000a,0x27e70012,0x99d70015}},	//   _היט_, _יַרְ, winn_, ختطا
  { {0x26c70026,0x27e7164c,0xa3c3005d,0x6b9c13e1}},	//   wyno_, tinn_, _एकल_, _farg
  { {0x628a0134,0xa8040033,0xd7f80054,0x480400e2}},	//   _opfo, азіл, куј_, апів
  { {0x27e70b41,0x06540010,0xa2630092,0x645b00da}},	//   rinn_, атыў, _cuố, wsui
  { {0x3f9100b8,0xceb40643,0x27e7164d,0x645b164e}},	//   hezu_, שיק_, sinn_, tsui
  { {0x6b9c0064,0x27e7002e,0xad9b002c,0xc7f90036}},	//   _yarg, pinn_, _akúk, _знає_
  { {0x69c00111,0xb8f7000b,0x61e4164f,0x645b1650}},	//   _zome, ान_, _smil, rsui
  { {0xdb1c001c,0x8bd60008,0x645b1651,0xeb92000a}},	//   _poré, רותו_, ssui, זָר_
  { {0x6627003b,0xc6da00b2,0xcb120008,0x7dca0264}},	//   _شراك, _אַדר, מלי_, _výsk
  { {0xa91d00df,0x89da000a,0x6fcb0012,0x397a004c}},	//   _pažy, תחרי, _küch, עטשנ
  { {0x3a2d0111,0x701901f3,0x68e40125,0xdee60fdc}},	//   _liep_, віст_, úidi, гоги
  { {0xa2630023,0x7dca002e,0xd00f0015,0x2fc5001a}},	//   _xuố, _hýsi, سلف_, ölga_
  { {0xa01b00dc,0x63b50007,0xd3780085,0x7bc30b2d}},	//   gtöb, šanč, vići_, önun
  { {0x6da30063,0xb8860089,0x5baa0418,0x6b9c1652}},	// [22e0] щита, _kníž, нкам_, _parg
  { {0xa01b00f2,0xc0530008,0x69c01653,0x8ad60033}},	//   ttöe, _הזז_, _some, люец
  { {0x77940074,0xc332013a,0x7dca002e,0x69c012d7}},	//   ییرا, צוא_, _lýsi, _pome
  { {0x7db60029,0x9f580251,0x6b9c013c,0xbcfb0077}},	//   _إصدا, forç_, _warg, _idén
  { {0x2d9201e2,0x6fcb00b8,0xd7e6042b,0x1754011b}},	//   meye_, _büch, ліко, авля
  { {0x6fcb018b,0x69c0003e,0xccab04dc,0x0f7a004c}},	//   _rück, _wome, _אֱלֹ, גאַב
  { {0x96f80080,0xa2630092,0xb7650036,0xeab4000a}},	//   ъект_, _quố, ртій, _דִּי_
  { {0x7a8b0008,0xa3d6000b,0xa2a2000b,0x2d920f0a}},	//   _אָמַ, _सतह_, गिस्, neye_
  { {0x7c2e003f,0x08d60010,0xf7461654,0xdb1e007c}},	//   _kibr, _сцвя, _безо, skpä
  { {0x54330029,0x66da004a,0x5fc6000b,0x25af1655}},	//   حرير, _пьер_, रॉमल, _engl_
  { {0x0bb70008,0x2d920064,0x3f91016f,0xe1d9005e}},	//   אלים_, keye_, vezu_, вдні_
  { {0x4a5b000a,0xc2b7005e,0xa565002b,0x6fcb0012}},	//   עדכו, улює_, _ندهن, _züch
  { {0x7c2e002f,0xc0ab00c3,0x3f910085,0x2d921656}},	//   _oibr, راحل_, tezu_, deye_
  { {0x749b000a,0xddc700bc,0xed590091,0x40340427}},	//   _ניופ, dujš, _žž_, серс
  { {0xa6f80008,0x6298016f,0x3f9106f2,0x02a30033}},	//   דִּי, _usvo, rezu_, _грым
  { {0xb886002c,0x7c2e002d,0x6dc4004a,0xb03506b3}},	//   _zníž, _aibr, бсуж, _книш
  { {0xdb6b0036,0x8c250015,0x3a2d0079,0xcb550054}},	// [22f0] ерел_, لفره, _riep_, иваћ
  { {0xcb680054,0x0000006a,0x0000006a,0x0000006a}},	//   лађе_,   ,   ,
  { {0x7f3a000a,0x7959029b,0xbf15002b,0xfa8b0033}},	//   _בעתו, виер_, _خودب, эсай_
  { {0x2d920061,0x0dcb0015,0x442e1657,0xba740058}},	//   ceye_, _أبدى_, _lif_, صامت
  { {0xbcfb0003,0x99840045,0x8d5a000a,0xdcfd003d}},	//   _idéo, _simţ_, _בכרי, _masī
  { {0xdcfd0024,0xf77100e5,0x6d4d0234,0x9058000a}},	//   _lasī, زات_, lbaa, נסוף_
  { {0x45d5066c,0x19950010,0xf6960015,0xd7580021}},	//   ицит, _кавя, لنوع_, اجها_
  { {0xb8860089,0x05a90a61,0x6d4d0161,0xb867002b}},	//   _sníž, твий_, nbaa, _مائو
  { {0xe4560010,0x851f005d,0x9c890036,0x6fcb0012}},	//   ажы_, मेंट_, ерiа, _tüch
  { {0x98170029,0xc4e20010,0x3d1d005d,0x787a000a}},	//   _إبرا, іжэй, _मरने_, _יָבו
  { {0x6d4d00f6,0x6b6000dc,0x7216005e,0x629e1658}},	//   kbaa, lágí, иємц, _špor
  { {0x78a9003c,0x10a603fc,0xb6ba000a,0x07080015}},	//   _krev, аимн, _בצעי, _صيني_
  { {0x21a30080,0x2d920061,0x6d4d0079,0x20d500e2}},	//   циям, veye_, dbaa, бірс
  { {0xf4b6002b,0x64491659,0x7dd800e1,0xfe46165a}},	//   _خشمگ, mpei, _míse, инго
  { {0x2d920064,0xdd9200e6,0xed5a165b,0xdbcf006f}},	//   teye_, يوس_, ков_, bľúb
  { {0x6d4d165c,0x3860044c,0x12fa000a,0x645d0091}},	//   gbaa, širi_, _בהצב, šsiu
  { {0x61fd00dc,0x2d920064,0xef19002a,0x14d5000a}},	// [2300] érle, reye_, ęża_, בוּל_
  { {0x2d92165d,0x8e76009b,0x62810546,0x0000006a}},	//   seye_, _кумч, otlo,
  { {0x7f5c120b,0xfc3f0077,0x75fe003d,0x6d4d0030}},	//   marq, _frío_, līze, bbaa
  { {0x180e005d,0x22510264,0x5a33005e,0x83fd0030}},	//   ित्व_, ázky_, ініт, lsőd
  { {0x913b00b2,0x4c670036,0x27150092,0x38600c1b}},	//   דענק, _киян_, _án_, éir_
  { {0x6f090064,0x2b28002b,0xe6660659,0xcb6a004a}},	//   şece, _مغزی_, атио, _шаге_
  { {0x644900dd,0x442e165e,0xd910002b,0x8c2b000a}},	//   epei, _rif_, _کیش_, _יֵלֵ
  { {0x69d9165f,0x7e61002e,0x7dd8002d,0xbdf6000a}},	//   chwe, álpi, _físe, יֶ֥ה_
  { {0x030b005d,0x6281005c,0x05730015,0x2e3c001a}},	//   _सुबह_, etlo, زايد, _líf_
  { {0x66e60809,0xa87b000a,0x2bfb000b,0x03c61377}},	//   _коза, _באמר, ्वयं_, рсим
  { {0xe7370080,0x442e0003,0xbf67002b,0x69cd007c}},	//   _тех_, _vif_, یدآو, öaeg
  { {0x92570080,0xd3780085,0xb80e0065,0x0000006a}},	//   шают_, viću_, ितकम_,
  { {0x90981660,0x1074007a,0x7dd11661,0x645d0b7e}},	//   авят_, оляю, _såso, ásit
  { {0x9217000b,0xc8840061,0xdbcf006f,0x14db000a}},	//   _धीरज_, mağı_, sľúb, _שַׁמ
  { {0x63bc002e,0x6d4d016b,0xdb230064,0x637b00a3}},	//   örnu, tbaa, ürün, _סנהד
  { {0xcdd80124,0x6d4d00dd,0x629d003d,0x91e40054}},	//   ању_, ubaa, āsot, _моје
  { {0xdce601e2,0xd9040086,0xc8840064,0x7f5c1662}},	// [2310] _bakı, _آی_, nağı_, barq
  { {0x2fe40015,0x2b470033,0x2b580045,0x6d4d1663}},	//   _وكيف, рэаг, _cerc_, sbaa
  { {0xd8b80074,0x4ae40010,0x6d4d0234,0x99350015}},	//   یدها_, оўца, pbaa, مفات
  { {0xf99303c4,0x7dd80089,0x98350033,0x80a4002b}},	//   تبط_, _píse, бэкі, _امین
  { {0xcdb60008,0xa3c8000b,0xaf08002b,0x98a51664}},	//   _הפרה_, ैसा_, _مقیم_, силе
  { {0xec360008,0xe8080033,0x2bc80004,0xf8070004}},	//   _לאשר_, анід_, _кусо_, шчен
  { {0x5a440010,0xb6580033,0x6b600030,0x6f7a000a}},	//   _мэта, ашых_, ságí, רְנו
  { {0x29f800bd,0xeef8000a,0xdce8002a,0x973c0085}},	//   nčal_, ימור_, śląs, _raće
  { {0xdce601e2,0x9f8f0064,0x7c25002d,0xcdb8000f}},	//   _yakı, _güç_, omhr, שפחה_
  { {0x3cff014e,0xa3e1005d,0xe2990001,0x6449043c}},	//   _रखने_, नों_, гао_, rpei
  { {0x11d6003b,0x7c25002d,0x9f5100dc,0x64491665}},	//   متحد, imhr, hozó_, spei
  { {0x9f510014,0x395d0034,0x64491666,0xa0c60058}},	//   kozó_, naws_, ppei, ميجو
  { {0xc8840064,0xd4690175,0xf536000a,0x9f580030}},	//   cağı_, _силе_, _הנני_, morú_
  { {0xd91a0053,0x7dca002e,0xc34b004a,0xa01b008c}},	//   טורל, _lýst, _ряде_, ttöa
  { {0x6fd000c0,0xc332000a,0xdce60061,0x7f5c0d29}},	//   _häck, _צוה_, _rakı, rarq
  { {0x41e50015,0xdce60061,0x6e2402f2,0x14d5000a}},	//   _وسيف, _sakı, umib, ֖וּל_
  { {0x2b5800dc,0x5b3600a2,0x6e2400dc,0x30860015}},	// [2320] _perc_, معار, rmib, _الخف
  { {0x660900dd,0x83fd00dc,0x2f56017c,0x10bb000a}},	//   hoek, lsőb, _утис, _עזיב
  { {0x4e1a0074,0x80250029,0x7dd8002e,0xdce60061}},	//   _متحد_, _بريم, _vísb, _vakı
  { {0xc236000a,0xda650015,0x6012001a,0xaa570015}},	//   צרנו_, زامي, dæmi, صلها_
  { {0xdce60064,0xc7c60404,0x1cba0031,0x260b000b}},	//   _takı, йски, _صاحب_, ावनी_
  { {0x9ad60010,0x711b000a,0x3d1d000b,0x7dca00bf}},	//   _любі, נוספ, _मरते_, _výsu
  { {0x8f9b0008,0xe0df04ed,0x91fd003d,0xceb3000a}},	//   ריצי, zzò_, nsāc, ֜יו_
  { {0xd6d90036,0xc8840064,0x1af70008,0xceb3039e}},	//   шті_, tağı_, _המלל_, ליו_
  { {0xdb1c0251,0x200a1667,0x493b000a,0x288b009a}},	//   _horà, kobi_, _תגמו, _مصلی_
  { {0xfa6a000a,0xe2aa0015,0x91fd003d,0xc8840061}},	//   ְכָּ, هاجن_, ksāc, rağı_
  { {0x51f90036,0x9f5800dc,0x200a00bd,0x91fd0024}},	//   иною_, ború_, dobi_, krāt
  { {0xe45a005e,0x961a0015,0x8637004f,0xc17400ce}},	//   _бжд_, _صغار_, _הראב_, плющ
  { {0xe3af0086,0x91fd003d,0x200a156a,0xddce003d}},	//   ذری_, drāt, fobi_, arbū
  { {0xe47b000a,0xe0df01e0,0x44f30138,0x0000006a}},	//   _ערוכ, rzò_, _эпіс,
  { {0xe2460070,0xd35b011f,0x6fd000b8,0x53e50015}},	//   _اختي, _גדול, _mäch, _بأنف
  { {0x9f5100dc,0x8e15042b,0xbd450015,0x6fd00012}},	//   tozó_, ідац, زنطي, _läch
  { {0x91a90023,0xf1f80074,0x320b005c,0xd1310015}},	// [2330] _giá_, _دعوت_, mocy_, _تمة_
  { {0x66090298,0x6fd000b8,0x44d40092,0x543b0053}},	//   zoek, _näch, ì_, טעמא
  { {0x6fb50074,0xfbd00029,0x3ce00085,0xcb1b0004}},	//   _همکا, رتك_, aziv_, уќа_
  { {0x7dd10134,0x6012002e,0x6fcb0064,0x61ef1668}},	//   _måsk, væmi, _vücu, nicl
  { {0x8934003b,0x718c0008,0x229a0024,0x9ccb04ab}},	//   أعما, רְבַ, _lūk_, _сына_
  { {0x6fd000c0,0xa01b00dc,0x61ef1669,0xd6a90015}},	//   _räck, ztön, hicl, لدعم_
  { {0x9f58002c,0xa01b166a,0x2ca9166b,0xa93d0033}},	//   torú_, ytön, lvad_, _адбi
  { {0xe6190083,0x59f90080,0x3ebe00f2,0x25bf007c}},	//   јди_, _тебя_, ätti_, ujul_
  { {0x4439001c,0x6fd00012,0x7bc7007c,0x38600125}},	//   ês_, _fäch, _koju, áirt_
  { {0x6498010f,0x6609020a,0xa3ba0086,0xf3e50036}},	//   стър_, soek, لاپر_, іжно
  { {0x44d40023,0xdb1c0014,0x2ca9007c,0xdced003d}},	//   à_, _korá, hvad_, edaļ
  { {0x6fd000c0,0x3a7a000a,0x34b50015,0xe4510015}},	//   _täck, סטרד, _وماز, _قضت_
  { {0x3494032d,0xa01b166c,0xe4cb0015,0xdb1c166d}},	//   _нацр, rtön, _حبان_, _morá
  { {0x34b20074,0x2329166e,0x8c420064,0xc2c50015}},	//   _آموز, _коли_, üğme, _ويشي
  { {0xa01b002e,0x443f0152,0x539a0008,0xdced0024}},	//   mtöl, lqu_, _כיסו, adaļ
  { {0xa01b0014,0xaaba0086,0xdd920002,0x657b166f}},	//   ltöl, یدار_, بور_, nguh
  { {0x7dd80089,0xe206000b,0x2f231670,0x38c3003d}},	// [2340] _císa, रवीण_, tégé_, _jūrā_
  { {0xab660036,0x443f1671,0xa01b1288,0xcb6a098b}},	//   івел, iqu_, ntöl, раже_
  { {0x5fb70008,0x2ca90020,0xa01b00dc,0x2f230003}},	//   _והיא_, avad_, itöl, régé_
  { {0x9f99002e,0x6fd00012,0x44d40016,0xc213000a}},	//   láðu_, _säch, ỳ_, ֵ֔ף_
  { {0x91a00023,0x26ce0034,0x58960015,0xe8260342}},	//   _chỉ_, wyfo_, تجاز, офко
  { {0x3cff005d,0x6fcb0064,0x6d4404ed,0x3f981672}},	//   _रखते_, _hücr, lcia, neru_
  { {0xfa671673,0x6d441674,0xdb1c039f,0x0000006a}},	//   _марк_, ocia, _forá,
  { {0x39420005,0xa01b00dc,0x7bc70111,0x29d60015}},	//   _üks_, etöl, _zoju, _بيرس
  { {0x224900bd,0xa01b001a,0xa3c8000b,0x44d40016}},	//   _čaka_, ftöl, ैसल_, ù_
  { {0x657b0035,0x3f98016f,0x69c2049c,0x63a31675}},	//   aguh, jeru_, ljoe, _cann
  { {0x8c1b000a,0x61ef0287,0x764800cb,0x645d0091}},	//   שויי, ticl, _utdy, šsip
  { {0xa01b00f2,0x63a3002d,0x51f80088,0xc4c60058}},	//   ttöo, _eann, жнюю_, _وتشو
  { {0x85f90053,0x44f60086,0x2d8700dc,0x63e60015}},	//   _פּעק, _بساز, őnek_, _وستك
  { {0x80270029,0x63a30335,0xa3ce000b,0x6d440228}},	//   ترجم, _gann, _रवि_, ecia
  { {0xfeb80074,0xbcfb001c,0x9f340036,0x3377000a}},	//   يافت_, _idéi, дері, _ותוך_
  { {0x6560002d,0x7bca002e,0x29d70064,0x7dd801c9}},	//   namh, öfun, _açan_, _písa
  { {0x61ed016f,0xad9b002c,0x6560003f,0x7188000a}},	// [2350] _imal, _skús, iamh, _וְתַ
  { {0xdb1c00dc,0x7dd8002e,0xc052000a,0xcfe80015}},	//   _sorá, _vísa, _רזי_, _وفيه_
  { {0x61ed00bd,0x539b000f,0x3ceb000b,0xdd910015}},	//   _kmal, שיבו, _घेरे_, _كود_
  { {0xfe9a00b2,0x6d4402d7,0x02fb00a3,0x88350033}},	//   _פירמ, ccia, סלאמ, пэкц
  { {0x6d5d0048,0x98f40015,0xa01b008c,0xad27002b}},	//   _iesa, وثها, ytöl, _گرگو
  { {0x6d5d0482,0x6560002d,0xb6590080,0x05a3000b}},	//   _hesa, eamh, бших_, _खोजब
  { {0xba740074,0x69c200dd,0xcf580008,0x6d5d013c}},	//   _يافت, bjoe, חבות_, _kesa
  { {0xfb34008f,0xe7080029,0x9f4300f2,0xa9090015}},	//   _інтэ, غتون_, lijä_, _هيزل_
  { {0xb4d5005d,0xa01b00f2,0x6d5d1676,0x3d19000b}},	//   सने_, ttöl, _mesa, _दरों_
  { {0x33d4005e,0x61ed1677,0x7c3d01d7,0x6d44002a}},	//   діют, _amal, _musr, zcia
  { {0x443f038d,0xa01b002e,0x63a31678,0x3f9806ca}},	//   squ_, rtöl, _vann, veru_
  { {0x63a300f6,0xdb1c0134,0xa01b1679,0x6d5d167a}},	//   _wann, _foræ, stöl, _nesa
  { {0xe4490029,0xe20b002e,0x9f4300f2,0x853a000a}},	//   _التى_, _slóð_, kijä_, _הגני
  { {0xf8a504b6,0xa01b008c,0x60c9007c,0x61ed167b}},	//   _یک_, ltöj, äema, _emal
  { {0x9f990084,0x7c3d00b8,0x6d5d013c,0x443d0a4c}},	//   ráðu_, _ausr, _besa, _huw_
  { {0xa01b00f2,0x6df60029,0x6012002e,0xf1bf001a}},	//   ntöj, أكرا, væmu, nmál_
  { {0xdd8f0029,0x6d5d167c,0x3d28002b,0x6d44167d}},	// [2360] طول_, _desa, زتری_, rcia
  { {0x69db022d,0x6d4404ed,0xac830033,0xe81b000b}},	//   _alue, scia, эгул, _पीला_
  { {0xcf570008,0x7f3b000a,0x2f3b000a,0xdce80061}},	//   _מבית_, _לעיו, _לגיד, ğlıs
  { {0xb23a00b2,0x6d5d167e,0xf3f10092,0x79a30a61}},	//   צענז, _gesa, hị_, ерше
  { {0x2d8200c0,0xf9870015,0x89630015,0x27ec01d7}},	//   _icke_, سنوي_, رُون, _pmdn_
  { {0xf8670015,0x5694167f,0x69db1680,0x68e2002a}},	//   أموي_, дакт, _elue, rzod
  { {0xa6c80015,0x644b0091,0x030b000b,0x91fd003d}},	//   توغل_, _atgi, _सुलह_, krāp
  { {0x75e60010,0xe9a31681,0x8afb000a,0x44b403ae}},	//   яўле, _пасп, _ההלי, дбис
  { {0xdb1c0064,0x3a09002b,0x6560001a,0x9f94008c}},	//   _borç, _بکلی_, ramh, _kää_
  { {0xa01b00f2,0x443d0026,0x65601682,0x61ed1683}},	//   ttöm, _duw_, samh, _smal
  { {0x6b670030,0x39460533,0x656002f2,0x9f9401be}},	//   légí, ocos_, pamh, _mää_
  { {0x1a9b0053,0x39461684,0xd49a012e,0x7ae10030}},	//   זיטע, ncos_, _грк_, _ülte
  { {0x7dd80089,0xdb1c1685,0x38661686,0x6d5d1687}},	//   _písn, _forç, nsor_, _resa
  { {0x925704b6,0x7a230020,0x7e62002a,0xa01b001a}},	//   _کشور_, mõte, _łopa, mtök
  { {0x7c3d1688,0x6d5d1689,0x141b000a,0xa01b008c}},	//   _susr, _pesa, _הוגב, ltök
  { {0x42fb013a,0x12fb000a,0x1317000a,0x52830015}},	//   _להוס, _להוב, _מחול_, _أليك
  { {0x82340015,0x3f81002a,0x4c94168a,0x7dd80046}},	// [2370] _ثروا, _tchu_, нитс, _tísn
  { {0x39460077,0x2d820012,0x69db00aa,0x4ea7107b}},	//   ecos_, _ecke_, _slue, _ерма
  { {0xdb580080,0xdd0c005c,0x69da0007,0xa01b0c8b}},	//   яют_, góło, _įter, htök
  { {0x61fd0084,0xc3330008,0xa5bd0091,0x225800bf}},	//   nnsl, גוע_, amųj, árky_
  { {0xe739067a,0xb90b0015,0x78a6006f,0x1869012f}},	//   оел_, حزام_, _škvr, цали_
  { {0x27c70080,0x945d005c,0x443d0079,0x4cba004f}},	//   ящег, zyńs, _ruw_, _ומשג
  { {0x5692049d,0xa01b008c,0x6446001a,0x25a60125}},	//   вајт, ttöj, íkin, _baol_
  { {0x25a6002d,0xcb34006b,0x443d028a,0x3946168b}},	//   _caol_, _чесъ, _puw_, ccos_
  { {0xf8ae0086,0xf1bf087d,0xdb1c016e,0xa01b001a}},	//   _پکن_, rmál_, _porç, gtök
  { {0xa3e905d1,0xcad5000a,0xa01b008c,0xd7e4005e}},	//   ідна_, ֥וֹת_, stöj, _піхо
  { {0xfbd2000a,0x945d002a,0xf3f10016,0xfc3f0125}},	//   דתי_, tyńs, rị_, _luí_
  { {0x25a60c0b,0x04950015,0xa01b008c,0x67210085}},	//   _gaol_, _يلاح, ltöh, _izlj
  { {0x55ac0053,0x644b02d2,0x395f0ade,0x20b50174}},	//   _ליאַ, _utgi, _meus_, нёрс
  { {0xe820005d,0x7dd8002c,0x94040015,0x67240046}},	//   यतया_, _píso, _كونه, řije
  { {0x7413002b,0x38660030,0x4392012e,0x83fd01d3}},	//   _قوچا, zsor_, _рајс, lsőo
  { {0xe1f20086,0xc6920008,0x38660026,0xfc3f002d}},	//   _جست_, כאל_, ysor_, _buí_
  { {0x39a60780,0xfc3f002d,0xa00a0029,0x9f9400f2}},	// [2380] _jūsų_, _cuí_, _وقبل_, _pää_
  { {0x39a600df,0xafdb0cd8,0x3ebe0123,0x0eba056d}},	//   _mūsų_, spør, ätts_, _думы_
  { {0xbad50010,0xbe660015,0xa5bd0091,0xaf030033}},	//   ніцы, _تهجي, rmųj, _апэл
  { {0xa01b008c,0x38660030,0xcd360058,0x394601ec}},	//   ytök, tsor_, _يرحب, ucos_
  { {0x5fd2005d,0x395f168c,0x9f94008c,0x7e7c001a}},	//   _हवाल, _deus_, _tää_, lurp
  { {0x7a230020,0x77630251,0x25a6002d,0x38c30091}},	//   võte, ganx, _saol_, dūrą_
  { {0xa3b1005d,0x61fd002e,0xdaba0029,0xe7370054}},	//   _ऑफ़_, ynsl, _ظهرت_, мељ_
  { {0x2613001c,0xa01b168d,0x2d80168e,0x746a168f}},	//   dãos_, ttök, ngie_, оров_
  { {0xd49a0036,0x211d000b,0x38c8002b,0xd4060342}},	//   іри_, _नरेश_, _عاری_, дяни
  { {0x9f58002c,0xd3700086,0x628800d6,0xf1bf013f}},	//   torý_, دهد_, ttdo, rmám_
  { {0x2613001c,0xc7b3000f,0xdb1c01f0,0xd4130015}},	//   gãos_, _שבע_, _forå, خبيث
  { {0x22ac0046,0xa01b001a,0x83fd0030,0xf2140058}},	//   _věk_, ptök, lsől, َبَة
  { {0x7dd101d1,0xe4ea0015,0xe4d60015,0x25d70033}},	//   _måst, _بعضه_, _تتاب, _імшы_
  { {0x251b000a,0x7dd10804,0xd6e20535,0x0000006a}},	//   _וודא, _låst, pułą_,
  { {0x2ca00026,0x637b000a,0xdd950033,0xa01b008c}},	//   ewid_, _ונוד, навы, ntöi
  { {0x644f0125,0x442c0079,0x8d7700c3,0x7d770015}},	//   ícig, lmd_, باسا, باسط
  { {0xfc3f1690,0x1cb80015,0x395f1691,0x515c000a}},	// [2390] _quí_, واكب_, _reus_, _וכחו
  { {0x395f122a,0xd83812d7,0x1b7b0015,0xf24a004f}},	//   _seus_, _nič_, تصرة_, ַגְּ
  { {0x0f56000a,0xe1ff0077,0x395f0144,0x442c0079}},	//   _איתם_, onó_, _peus_, imd_
  { {0x3ebe003c,0x2011016f,0xda080015,0x319c004c}},	//   åtte_, lozi_, ويله_, ַבונ
  { {0x7b6715ed,0x3869002d,0x6e2d1692,0x395f0144}},	//   _отве, éar_, mmab, _veus_
  { {0x7b740086,0x907c0053,0x60d8000a,0x307c004c}},	//   _لطفا, קטוי, וודא_, קאונ
  { {0x395f12b3,0xe80e000b,0x260b000b,0x099b0015}},	//   _teus_, ाक़ा_, ावली_, _وضرب_
  { {0x442c0159,0xd5b10115,0xdcef0061,0x38c30091}},	//   emd_, افظ_, _hacı, tūrą_
  { {0x66021693,0x601202de,0x91fd003d,0x973c002a}},	//   _djok, kæmp, rsāl, _zaćm
  { {0xf7480015,0x69d90547,0x8cfa000a,0xa9230091}},	//   _يلقي_, lkwe, לִיח, įžda
  { {0xd24e0074,0xd6d10029,0xb81b000b,0xf486009a}},	//   ینی_, _حقا_, _पीएम_, وایی
  { {0xcf890008,0x7dd80227,0xe1ff0077,0x6aba0030}},	//   _לט_, _písm, gnó_, _átfe
  { {0xea000092,0xa3d509ef,0xb5c8002b,0x764102f2}},	//   hiết_, _подч, _تونم_, _huly
  { {0x201104ed,0x40330010,0x661b0604,0x7e7c1694}},	//   gozi_, леўс, lluk, turp
  { {0x4427018b,0x661b007c,0x9f4a0144,0xdb15006f}},	//   _ihn_, oluk, ribà_, _pozý
  { {0x45b500b2,0x764100e8,0x661b1695,0x6da310ce}},	//   עפּל_, _muly, nluk, лиса
  { {0x91fd0048,0x921700b2,0x0c260a0b,0xfce3008d}},	// [23a0] ksāj, _אַזױ_, еман, гото
  { {0xfc3f002f,0xf093000a,0x44270012,0xa3b5000b}},	//   _arís_, _ענת_, _jhn_, _चोम_
  { {0x2f5b011f,0xdb1c006f,0x76410034,0x9f5802b9}},	//   _מדינ, _horú, _nuly, borò_
  { {0x6a160086,0xceb301d8,0xdb1c006f,0xf8660965}},	//   ربار, _עיר_, _korú, евдо
  { {0x6d3b0008,0x661b0364,0x442c1696,0xba170040}},	//   _מתכנ, dluk, ymd_, ريها_
  { {0xfb560086,0xdc8b000a,0x660200cb,0xc6a60923}},	//   _سپرد, _מְלָ, _sjok, ерии
  { {0x09e60036,0x69960afb,0x8f7b000a,0xd6d00015}},	//   _зовн, _прах, לנסק, شقة_
  { {0x7bce0020,0xe7f2000b,0x76410034,0x69d91697}},	//   _hobu, _अगवा_, _duly, ckwe
  { {0x6d8b000a,0xb4da000b,0x4498005e,0xa01b0bb5}},	//   הָיְ, ठने_, євою_, stöi
  { {0x443801d1,0xb8d4005d,0xa01b00f2,0xb7da0015}},	//   ör_, जट_, ltöv, _عوضا_
  { {0x45e400a7,0x7982005c,0x442c1698,0xc7d7000a}},	//   _đượ, ogow, rmd_, _רובי_
  { {0x7982005c,0xd6db000a,0xd2570033,0xdb0e0123}},	//   ngow, _מחבל, эць_, _inbä
  { {0xd5e90029,0xe3b2002b,0x50670033,0x9f5802b9}},	//   _تعلن_, _مرغ_, этна, vorò_
  { {0x29f8002c,0xa3e4000b,0x6d430046,0x99840046}},	//   očas_, _नति_, ěnam, _nimž_
  { {0x6e9405c4,0xce94006b,0xd7b7004c,0x82b3012c}},	//   лиру, ларъ, עהלט_, _محيط
  { {0x63aa0084,0xfc3f001a,0xdb1c001a,0x6e2d02f2}},	//   _hafn, _asía_, _forú, umab
  { {0x7dd81699,0xdfd10015,0xfd130015,0x6ce7005e}},	// [23b0] _získ, _نية_, اجز_, хіве
  { {0x63aa0084,0xfbd30086,0x661b0061,0x4bfb0015}},	//   _jafn, دتر_, zluk, أعرج_
  { {0xa036013a,0xbb840029,0x9f8f007c,0x29d70061}},	//   _שאתה_, المي, _müü_, _uçak_
  { {0x9f580084,0xdb0e016e,0x91a00016,0xea000016}},	//   lorð_, _robô, _khí_, riết_
  { {0x99140036,0x91fd03e9,0x76410091,0x98a5107c}},	//   льші, esāk, _suly, тиле
  { {0x63aa0084,0x62980150,0x3695007a,0xf094000a}},	//   _nafn, _opvo, вшис, רנס_
  { {0xeb37002b,0xd705006b,0x35a50033,0x67d20004}},	//   _سرسخ, ъзки, вайг, роју
  { {0xceb4103d,0xa8490029,0xf9930002,0xdb15002a}},	//   ריק_, _يلزم_, _حبس_, _wozó
  { {0x7dd8002d,0xf8bf0107,0x661b169a,0x7a040033}},	//   _dísh, _šéf_, rluk, _сярж
  { {0x91aa005d,0x13a7002b,0x7dd80046,0x67240046}},	//   _जोड़े, رنجی_, _písk, řija
  { {0xd6db005f,0xb17b169b,0xf5950015,0x386d169c}},	//   _эта_, rhån, _للاج, _hver_
  { {0x99980024,0xcb12000a,0xa06a0709,0xdb1c006f}},	//   _kurš_, שלט_, мама_, _porú
  { {0x91a00092,0xd1320029,0x95c40015,0x53a50015}},	//   _chí_, شمس_, _حينه, _لمشك
  { {0xa0a30180,0x7982002a,0x9f58001a,0x25ad0013}},	//   јард, zgow, gorð_, ldel_
  { {0x91a00092,0x7982051e,0x7bce0d3a,0x248d169d}},	//   _thì_, ygow, _robu, ltem_
  { {0xc27a000a,0x386d169e,0xbcfb0003,0xb17b0123}},	//   _חרקי, _over_, _adéq, nhål
  { {0xe7f2005d,0x9f58002e,0xf1a90086,0xec16002b}},	// [23c0] _अगला_, borð_, _سايه_, نورد
  { {0xeafa0115,0x80890015,0x73ac000a,0x248d169f}},	//   ورات_, _أضيف_, ּיאֵ, item_
  { {0x386d02d7,0x6f790053,0xaf770053,0xed5a10b7}},	//   _aver_, _אָרג, _בעיס_, _оон_
  { {0xe9da0036,0xe8fa0080,0xc332000f,0xb86600c3}},	//   ьке_, мле_, בוב_, ناتو
  { {0x7bce0007,0xb8940015,0x88e6006b,0x7982002a}},	//   _tobu, التع, ъжде, rgow
  { {0x248d03df,0x481302e1,0xa01b16a0,0x91fd003d}},	//   dtem_, аміс, stöv, tsāk
  { {0x386d003e,0x7c3c008c,0x8c170058,0x3984009a}},	//   _ever_, _iirr, _شيفر_, _میاف
  { {0x63aa002e,0xa01b16a1,0xdbe30003,0x9f8f007c}},	//   _safn, ltöt, _réél, _süü_
  { {0x64420152,0x99870011,0x248d0012,0x5506006b}},	//   _quoi, ţiţi_, gtem_, ъчка
  { {0x3202032c,0x660d0559,0xa857039e,0xa01b16a2}},	//   enky_, čaka, _סיבה_, ntöt
  { {0x5b7b0008,0x51f9017f,0x6b7b000a,0x4b7b05bd}},	//   וריא, енню_, ורינ, וטיג
  { {0x91a00023,0x91a90023,0xcb13011f,0xc4c60015}},	//   _phí_, _khả_, ילת_, _لتتو
  { {0x7cda003d,0x50640511,0x9f8f0061,0x248d16a3}},	//   _jārā, итра, _tüü_, ctem_
  { {0xdb1c0bfa,0x92f60015,0x2005007c,0xa2e60015}},	//   _forø, _لأعض, õli_, _لأبن
  { {0x9f5809f0,0x92940010,0xdef40010,0xc2c300e5}},	//   rorð_, _сайц, апры, _نيوي
  { {0x3253010f,0x9f58001a,0x2251006f,0x61e616a4}},	//   _твър, sorð_, ízke_, chkl
  { {0xbddb1671,0x7c3c16a5,0xcfab0015,0x0000006a}},	// [23d0] _lièg, _birr, _قادم_,
  { {0x9c190029,0x7c840180,0xcb540054,0x8c19006e}},	//   رياء_, јуте, ивућ, ريار_
  { {0x443c00dd,0x248d16a6,0x8ff80015,0xdfd1002b}},	//   _miv_, ztem_, _جرير_, _نيک_
  { {0xe7e5005d,0xe2930053,0xaa580054,0x443c0a3a}},	//   कसभा_, יװע_, тицу_, _liv_
  { {0x248d0089,0xd5b6000b,0x75fe003d,0xfc330067}},	//   xtem_, _अफ़ज, cīzi, _نحس_
  { {0x7784005e,0xba770015,0x6e3d16a7,0x8c440061}},	//   иліз, _لارت, _hisb, üşer
  { {0x2f980008,0xa01b00f2,0xb17b0123,0x56390004}},	//   דכון_, ltös, thål, нџир_
  { {0x0696003b,0xa5650086,0x26c9016f,0x248d16a6}},	//   انية_, اگان, ćao_, ttem_
  { {0xb17b00c0,0xa01b0a75,0x248d16a8,0x04560015}},	//   rhål, ntös, utem_, هلية_
  { {0x7dd8002e,0x20030085,0x03a50054,0xb17b0123}},	//   _vísi, jnji_, ћино, shål
  { {0x17f80029,0x2003060b,0xf6550004,0x7d1d16a9}},	//   _شركة_, dnji_, _свеќ, _lyss
  { {0x64b50002,0xfa96000a,0x95570040,0x6e3d16aa}},	//   _محتر, נדרש_, _شخصا, _nisb
  { {0x69cb0079,0x2004016e,0xe3ae0054,0xd9fa004f}},	//   ijge, émio_, _лб_, תִיך
  { {0x75fe0024,0x443c1639,0xc916000a,0x93bc0045}},	//   vīzi, _giv_, רחשת_, umăt
  { {0xf3f0003b,0x93bc0011,0x6e3d0251,0xe81b000b}},	//   _بأن_, rmăt, _bisb, _पीछा_
  { {0x628111a9,0x63a116ab,0x65690601,0x79890034}},	//   mulo, leln, naeh, _ncew
  { {0x6b560036,0x6e3d16ac,0xa01b008c,0xac460015}},	// [23e0] гтех, _disb, ttöt, ائره
  { {0x3d04005d,0x35c5000b,0xa01b0012,0xfc3f0125}},	//   _रखीं_, वाड़, eröf, _tsín_
  { {0x4a9a0010,0xdce40091,0xa2a9000b,0x61e416ad}},	//   этаў_, maič, टिट्, _klil
  { {0x7cda0048,0x8e7b0053,0xc3320008,0x5f46002b}},	//   _pārā, _אנטה, זוב_, _جنگل
  { {0xd91702e5,0xbddb0152,0x78a900dc,0x62810020}},	//   льш_, _sièg, _csev, hulo
  { {0xf1bf00dc,0xda660115,0xbddb0003,0x76aa011d}},	//   lmát_, _ماري, _pièg, етив_
  { {0x1ae60080,0x998d002c,0x61f60107,0x66730015}},	//   _совм, _sieť_, _omyl, مدير
  { {0xa01b00c0,0x91a90092,0x7bde00c0,0x45d415f7}},	//   ntör, _thả_, lkpu, роис
  { {0xd9100074,0x24490092,0xdce416ae,0x80a4000b}},	//   _بیش_, _cúm_, kaič, _चैले
  { {0x27f80064,0x644f16af,0xb8f8000b,0x289b000a}},	//   _örn_, ícia, ाह_, _אימא
  { {0x2c170053,0xa01b048b,0x92940033,0xfc17004c}},	//   רקיש_, ktör, шанц, רקיי_
  { {0xa01b022d,0xe1350080,0x154616b0,0xf1ab0015}},	//   ytös, инны, _седм, راجه_
  { {0x20030085,0xa01b0030,0x6e3d00bc,0x63a116b1}},	//   tnji_, dtör, _risb, beln
  { {0x7d1d00c0,0x3cff0091,0x53340912,0xdce40091}},	//   _ryss, _žuvo_, _келт, gaič
  { {0x9f350191,0x539b0008,0x62810ff9,0x200301a3}},	//   реві, _ניהו, culo, rnji_
  { {0xa01b1238,0xddd500dc,0x5d5516b2,0x171b004c}},	//   gtör, tsző, ркат, גולע
  { {0x8f550086,0x200310ca,0x316b002a,0x6e3d16b3}},	// [23f0] _پنجش, pnji_, macz_, _visb
  { {0x9f4b00f2,0x2ef5004a,0xb17b0123,0x69c016b4}},	//   äjät_, _взор, skåd, _anme
  { {0xddd500dc,0xa01b00f2,0x61e4008c,0x61f60034}},	//   ssző, stös, _ylil, _ymyl
  { {0x316b005c,0xc333000a,0x19950fea,0x7bde00aa}},	//   nacz_, צוף_, радя, akpu
  { {0xad9b002e,0x42380053,0xa9680029,0xa3e4000b}},	//   _ljúk, אנאל_, امهم_, नसा_
  { {0x38580086,0x2d840061,0x6c7a000a,0x83fd0030}},	//   اشند_, _ömer_, _באשפ, lsőv
  { {0x0f580008,0x65c50080,0x316b002a,0x7bc8000a}},	//   ניהם_, ибка, kacz_, _עֶשֶ
  { {0x04950010,0x660d00bd,0x9f41002c,0xa01b001a}},	//   ароў, čako, _dlhé_, brög
  { {0xa7870087,0x63a116b5,0x5c8b000a,0xdb070046}},	//   _مشاو, teln, ׂרֵ֣, _mají
  { {0x628116b6,0x9cd8000a,0xf7480015,0xb9090157}},	//   tulo, טוחה_, _ملكي_, मन_
  { {0xdce40091,0x212901c2,0x09f5000a,0xeb92000a}},	//   vaič, _azah_, ֹמָם_, חָר_
  { {0xb1da0036,0xdb070089,0x93bc0011,0xb4950001}},	//   тьох_, _nají, umăr, _видљ
  { {0x3d04014e,0x7a230005,0x7dd80089,0x93bc0011}},	//   _रखें_, võtl, _míst, rmăr
  { {0xdff50010,0xa936000a,0x3075004a,0x917a0016}},	//   бясь, יטרה_, щуюс, _mẩu_
  { {0x316b0050,0xb7f8005d,0xa01b025d,0xfe7908f0}},	//   bacz_, ्चतम_, ttör, лёты_
  { {0x61e4003f,0x9046002b,0x0000006a,0x0000006a}},	//   _ulil, _پنده,   ,

  { {0x6c360015,0xdb0502de,0xf1bf16b7,0x75fe003d}},	// [2400] لفرا, ndhæ, rmát_, cīzu
  { {0x8b26008f,0x3ff30015,0xa01b16b8,0x0000006a}},	//   адзе, _وكير, stör,
  { {0xa01b0a55,0x3f7b000a,0x23670030,0x8f7b000a}},	//   ptör, _באיס, _menj_, _בניק
  { {0xf2960053,0x82960053,0xfbc9000a,0x201816b9}},	//   יכער_, ידעס_, ות_, lori_
  { {0xc7c600d0,0xaf360086,0x9f5116ba,0xa8870a32}},	//   иски, _حرکت, lizá_, ийца_
  { {0xdb070089,0x22400020,0x67240046,0x6aba0030}},	//   _zají, _liik_, řijm, _átfo
  { {0xb7650191,0xa5f803c5,0xc14b0016,0xdb0502de}},	//   стій, леку_, _câịp_, edhæ
  { {0x20180026,0xba5700f3,0xd5b7091c,0x4e7b004c}},	//   hori_, _כסלו_, ась_, דאקצ
  { {0xa4f80086,0xad9b002e,0xe97b000a,0xe4e6005e}},	//   دکار_, _sjúk, _שנמש, рійн
  { {0x47aa0029,0x988b000a,0xa2e60015,0x224700da}},	//   _جارٍ_, _יָבֵ, لأجن, _bunk_
  { {0x91fd0048,0x0bb70008,0xa6ca0015,0x28130015}},	//   ksāt, בלים_, _جوال_, _بولس
  { {0x54a60015,0xd49a16bb,0x7dd816bc,0xe0e70033}},	//   _نحتف, _арк_, _míss, аўго
  { {0xf9930008,0x2bc9000b,0xf8c6000b,0x201816bd}},	//   חרר_, रामा, लमिय, fori_
  { {0x7a230005,0xb7f8005d,0x75fe003d,0x224716be}},	//   võtm, ्चिम_, rīzu, _funk_
  { {0x62350254,0x52840015,0xbddb0003,0x7648002a}},	//   _леку, _العك, _nièc, _judy
  { {0xaac70074,0x5d780080,0x433b000a,0x51f40015}},	//   یتان, ийся_, _בעוב, _وسير
  { {0x40950029,0x201816bf,0x61fd16c0,0x7dd8006f}},	// [2410] _الخر, bori_, misl, _ríst
  { {0x61fd15a7,0xdd2f0046,0xf457000a,0x5ba701ca}},	//   lisl, _těžc, יימר_, јраз
  { {0xfb150015,0x2bc9000b,0x2ac70054,0x4c140015}},	//   حواج, राबा, шљав, زبكس
  { {0x12f90053,0x29d70061,0x7bca001a,0x3219097b}},	//   נהײב, _açar_, öfur, nosy_
  { {0xa8a70080,0xf813002b,0x7648002a,0xb9920015}},	//   ррек, يستگ, _audy, سلوب
  { {0x387d0026,0x764816c1,0xf7710031,0x9f580140}},	//   rrwr_, _budy, سات_, tiré_
  { {0x2ca90026,0x3f7a004c,0xdb1c002a,0xf696006e}},	//   lwad_, אָפע, _doró, منوع_
  { {0x61fd16c2,0x2a64006b,0xe70b002b,0x69c90046}},	//   jisl, _фърг, _یتان_, áleč
  { {0x22400020,0x2ca90026,0x224700da,0x9f5816c3}},	//   _riik_, nwad_, _sunk_, siré_
  { {0x91fd0024,0x9f580003,0xa7d40015,0x53c9058e}},	//   ksās, piré_, _وتلص, угом_
  { {0x7a230005,0x22560086,0x201804a1,0xcad5000a}},	//   võtj, یلید_, vori_, צוֹת_
  { {0x515a0010,0x61fd16c4,0x78bb16c5,0x0000006a}},	//   ышоў_, gisl, _kruv,
  { {0x63c20089,0x201812b9,0xca1a000a,0xa01b008c}},	//   ávní, tori_, רֵיכ, ttöp
  { {0x90d5008f,0xe8df0092,0xd91a000f,0xb4e3000b}},	//   іцяч, _ngọn_, רושל, ननी_
  { {0x201811c8,0x4356000a,0x799b002a,0xc2550040}},	//   rori_, _פסקל_, _obuw, _اختت
  { {0xfbdf0092,0x229100dc,0x93bc0011,0xdb1c00b8}},	//   _quên_, mák_, plăc, _vorü
  { {0xbddb038d,0x7bd50064,0x22910f49,0xac0a0004}},	// [2420] _sièc, _bozu, lák_, гнаа_
  { {0xbddb0152,0x6faa0001,0x9f8612ba,0xdb0e0077}},	//   _pièc, _свог_, _угод, _habé
  { {0xfe720196,0x6c330029,0x1c3903e7,0x229116c6}},	//   _عدد_, أفلا, рять_, nák_
  { {0xed5a0063,0xda650015,0xb6350138,0x0000006a}},	//   _щом_, تاكي, _кнiз,
  { {0xdb1c005c,0xcdb70008,0xd7fa16c7,0x0000006a}},	//   _poró, _הפכה_, лук_,
  { {0x229100dc,0xa09b00a3,0xba6a0015,0x613b004c}},	//   kák_, ריסט, _محرك_, אײנס
  { {0xc6770029,0x645b0152,0x22910f49,0xcaa50015}},	//   محيط_, epui, ják_, _وصفي
  { {0xfbc9005d,0x5e570053,0x3ebe00f2,0x442e07cf}},	//   राथम, זיקע_, ätty_, _shf_
  { {0x92a8005c,0x61fd0057,0x7645001a,0x6e2416c8}},	//   _małż, visl, íhyr, ilib
  { {0x61fd0176,0x03f80001,0x13f40036,0x9cd70008}},	//   wisl, рној_, ізня, צויה_
  { {0xdb9b0632,0x17570008,0x8c1b000a,0x0bb7000a}},	//   נסטר, _הסבר_, רויי, זלים_
  { {0xd46a0083,0x92930010,0x60dd00f2,0x19ca000a}},	//   _биде_, чаюц, tysm, אמֹ֑
  { {0x682d002c,0xb08b0033,0x361b000a,0x6115005e}},	//   súde, ыёне_, _גואד, ідгу
  { {0xe507000a,0x229116c9,0x6d4602f2,0x61fd16ca}},	//   _ל֖וֹ_, bák_, _agka, sisl
  { {0x6397013a,0x93fb0008,0xdd9b0063,0xb7db000a}},	//   _הדוא_, _תלוי, лша_, נקלי
  { {0xbcfb00dc,0x7bd50012,0x6e24002a,0xd657004f}},	//   _idéz, _sozu, glib, מילת_
  { {0x8bd504c2,0xe1ff0077,0x83fd0030,0x2d890416}},	// [2430] ожац, mió_, csős, rgae_
  { {0xe1ff16cb,0xab94005e,0x2bc9000b,0x6e2416cc}},	//   lió_, зифі, राधा, alib
  { {0x539b000a,0xe7c7000b,0x9f3500fd,0x0000006a}},	//   ריבו, लासप, _фені,
  { {0xddab01d9,0x3ebe0134,0x99840015,0xe1ff16cd}},	//   _стол_, ætte_, كلمو, nió_
  { {0x229116ce,0x2bc90065,0x0000006a,0x0000006a}},	//   zák_, रादा,   ,
  { {0xa08c000a,0x67d203ae,0xd24600c3,0xe78716cf}},	//   רְאִ, дољу, _ين_, судо
  { {0x99850087,0x501c000a,0xad27002b,0x98140015}},	//   _ولسو, אוגו, _خرگو, أبنا
  { {0x91a90023,0xcb12000a,0x8af8006b,0x7a2a006f}},	//   _nhà_, _חלל_, _унсс_, pýta
  { {0xb4e3005d,0xa50907bc,0xe1ff16d0,0x54c5005e}},	//   नने_, репа_, dió_, ібоб
  { {0xe2910029,0x229100dc,0x22510069,0xdb0e039f}},	//   وذج_, ták_, ízko_, _sabé
  { {0xd1ca0124,0xd5ae0086,0x23290a6c,0xdb150012}},	//   алне_, رفی_, рони_, _unzä
  { {0x36340029,0xbba6000b,0xe1ff16d1,0x229116d2}},	//   _فرنس, _ऑस्क, gió_, rák_
  { {0x20d60010,0xd408002b,0x33f50015,0x6609007c}},	//   цінс, شتیم_, _وستس, mnek
  { {0xc49a000a,0xb14301f3,0x493a000a,0x82f9002b}},	//   _כשנת, ьнял, יגרו, _پرتز_
  { {0x7f430a2c,0xe1ff04f3,0xdb1c002e,0x660916d3}},	//   держ, bió_, _norð, onek
  { {0xe1ff16d4,0x644300b6,0x644b003f,0x660916d5}},	//   ció_, _hini, _kugi, nnek
  { {0x656b0014,0xf5360053,0x644316d6,0x6e240509}},	// [2440] _megh, ַטער_, _kini, rlib
  { {0xdb070014,0x9f58002f,0xdb1c002e,0x60db00b8}},	//   _sajá, oirí_, _borð, äume
  { {0x9d4616d7,0x1619000b,0x661b16d8,0x442516d9}},	//   _менд, दवार_, kouk, ill_
  { {0x18a60036,0x661b00f2,0x6459005c,0xda650015}},	//   жадм, jouk, _otwi, سامي
  { {0x62810012,0x9c87006f,0x9f43001a,0x3ed3002b}},	//   hrlo, rečí, mhjá_, _فقیر
  { {0xdb1c002e,0x644316da,0xb7d70015,0x60bb004c}},	//   _forð, _nini, يونا_, יצנד
  { {0x644b0007,0xdb07001a,0x98a30091,0x8b2316db}},	//   _augi, _snjö, _ąją_, _ждре
  { {0x36330086,0xe1ff0251,0x1af7000a,0x99590045}},	//   وريس, xió_, _ומלל_, râţi_
  { {0x644300b6,0xe1ff02c1,0x644b02b9,0x35f7002b}},	//   _bini, vió_, _cugi, ترود_
  { {0xa2f40036,0xd4970010,0x88bd005c,0x644316dc}},	//   зпоч, іры_, _wyśc, _cini
  { {0xe1ff02c1,0xe3b80064,0x883b000a,0x64430ab0}},	//   tió_, llık_, _כתמו, _dini
  { {0x64430746,0x44250541,0xd5b0002b,0x644b16dd}},	//   _eini, all_, _سفت_, _fugi
  { {0xe1ff02c1,0xe3b80064,0xc0e40010,0x64430738}},	//   rió_, nlık_, доўк, _fini
  { {0xd250003b,0xe1ff08e0,0x93b30036,0xbddb0251}},	//   _كنت_, sió_, _обіц, _cièn
  { {0x2ee5002e,0x637b000a,0x3a2607c4,0x7a31156a}},	//   álf_, _כנגד, klop_, låte
  { {0x628816de,0xc3390089,0xe3b80064,0x667b0008}},	//   mudo, čítá, klık_, יטלק
  { {0x5ce70036,0x61ef002d,0x201a001a,0x7dd80077}},	// [2450] цюва, mhcl, ófið_, _vísp
  { {0xbc680029,0xa2be005d,0x23cd000b,0x63a80030}},	//   تمكن_, षिप्, ़ायद, nedn
  { {0xa3ab000b,0x6600002a,0x628816df,0x441b004f}},	//   ख़त_, kimk, nudo, סובס
  { {0x66000089,0xda78017f,0xd337000a,0xe3b80061}},	//   jimk, іях_, קראה_, flık_
  { {0x998d002c,0x7d250087,0x442516e0,0xed56004c}},	//   _tiež_, _رفسن, yll_, _מברר_
  { {0x27c70080,0x1a5b0029,0x3d3a0008,0x63a816e1}},	//   ющег, _نشرة_, _לגרס, jedn
  { {0xfbd2013a,0xd6a80029,0x6459005c,0xe7760015}},	//   _אתם_, قديم_, _stwi, سميث_
  { {0x2bc9000b,0xb955006b,0x44250034,0x5eec000a}},	//   रावा, _хващ, wll_, יַחְ
  { {0x644316e2,0x99900011,0x973c002a,0x661b16e3}},	//   _pini, ţaţi_, _waćp, rouk
  { {0x76c70015,0x682d006f,0x63a80030,0x442516e4}},	//   _وغال, búda, gedn, ull_
  { {0xf08900f3,0xca35000a,0x9f94008c,0x9f580125}},	//   _תנ_, ּנָה_, _käö_, uirí_
  { {0x644b0020,0x8aa8000a,0x91a90016,0x7a3100cb}},	//   _tugi, חֹשֶ, _phá_, båte
  { {0x628800df,0x64430035,0x7bc716e5,0x63a8016f}},	//   audo, _tini, _onju, bedn
  { {0x3a2600dc,0xdfd20002,0xafe607be,0x628816e6}},	//   zlop_, ريز_, чогл, budo
  { {0xf1bf002f,0x92640031,0x6264002b,0xe3b80061}},	//   mlán_, _قديم, _قايق, zlık_
  { {0x67ef0134,0x32da0008,0x7bc70375,0xed640057}},	//   _højd, _לחצנ, _anju, drží_
  { {0xdca316e7,0x5ca3006b,0x320201c0,0xac8616e8}},	// [2460] нати, нитб, miky_, ягал
  { {0x917a0092,0xa09700a3,0x60fb000a,0x70fb000a}},	//   _hầu_, _צדיק_, _להפק, _להפח
  { {0x6fdb0008,0xca750010,0x3fdb0008,0x9f580144}},	//   _הקיס, дучы, _הקיב, mirà_
  { {0x63a80050,0x8c460080,0x628f005c,0x32020227}},	//   zedn, _неме, ńcow, niky_
  { {0x29120061,0xfc3f001a,0x2bc9000b,0xba170015}},	//   çya_, _asíu_, राशा, أينا_
  { {0xdb0e0467,0xe3b80064,0x7077004c,0xa09b000a}},	//   _habí, rlık_, לײנע_, מינט
  { {0xfbc9014e,0x7a23007c,0xdb0e006f,0x63a80c1a}},	//   रारम, võtv, _kabí, vedn
  { {0x9aeb0008,0xceb30008,0xe3b80064,0x682d002d}},	//   _הַמִ, תיה_, plık_, rúda
  { {0x660016e9,0xb8650058,0x63a816ea,0x0000006a}},	//   rimk, _ياكو, tedn,
  { {0x628816eb,0x13f3004a,0xb05b04d6,0x15130138}},	//   tudo, езья, lväg, эдыя
  { {0x320201c9,0xa75b000f,0xc7b3000a,0xe6c50015}},	//   fiky_, _הדבר, _רבע_, _يتمي
  { {0x917a0023,0xdb0e0089,0x62880134,0x63a80820}},	//   _cầu_, _nabí, rudo, sedn
  { {0x7a230020,0x4fc70063,0x3cf8000b,0x55bb000a}},	//   mõtt, псва, ूपों_, _למאו
  { {0x2d9c00dc,0xa01b00dc,0x853b0008,0x9f580251}},	//   ővel_, ltöz, _הגדי, girà_
  { {0x539b009d,0xb05b00c0,0xa3b5005d,0xf413000f}},	//   _היוו, kväg, _चोट_, _אפס_
  { {0xe3b801e2,0x02450029,0x3ebe002e,0x92b30015}},	//   ldı_, _تَعَ, ætta_, _أحوا
  { {0x61ed00b6,0x67ef0134,0xb0150001,0xfbd907c1}},	// [2470] _ilal, _høje, _омиљ, одај_
  { {0xe3b801e2,0xd6ec000b,0x68e20061,0x9f5801e0}},	//   ndı_, जनाथ_, dyod, cirà_
  { {0x245216ec,0x200316ed,0xbd020079,0x8f9a004f}},	//   _lâm_, miji_, _éénm, _ויתי
  { {0xa9540036,0x200301a3,0x9f5816ee,0xeab00015}},	//   екці, liji_, mirá_, طعم_
  { {0x7a15005c,0x99d40115,0xf990002b,0x38ca002b}},	//   jąte, عتما, ابم_, قاوی_
  { {0x7a230020,0x61ed0026,0x20030a00,0xb8d5005d}},	//   võtu, _llal, niji_, _जन_
  { {0x86790010,0xb6580010,0xdce60024,0xcf58000a}},	//   цёлу_, пшых_, _iekā, הבות_
  { {0xb9c50070,0xe459080e,0xdcfd0061,0x200316ef}},	//   _تقري, ожи_, _hası, hiji_
  { {0xdcfd0064,0xc7470086,0xef19002a,0xf1bf16f0}},	//   _kası, _فضاي, ęży_, tlán_
  { {0x13090080,0x24520092,0x200309de,0xf794004a}},	//   жной_, _dâm_, jiji_, _пауэ
  { {0x442b0024,0x69c9003e,0x32020057,0x200301a3}},	//   ēc_, _knee, tiky_, diji_
  { {0xd6d8005f,0x471a00b2,0x69db0152,0xf1bf16f1}},	//   _эту_, _וועג, _joue, slán_
  { {0x250904b6,0x917a0092,0x32020107,0x0574012c}},	//   _برای_, _cấu_, riky_, _ساند
  { {0xdcfd01e2,0x917a0023,0xdce60048,0x67ef02de}},	//   _nası, _dấu_, _nekā, _føje
  { {0x50430e77,0x43720015,0x9f5816f2,0x69c916f3}},	//   терб, _شهير, rirà_, _onee
  { {0xacb60015,0xed5a005e,0x69db16f4,0x2e150058}},	//   ومزغ, іоз_, _noue, ّبْح
  { {0xdcfd01e2,0x24520092,0x3d280086,0x2003044c}},	// [2480] _bası, _xâm_, ستری_, biji_
  { {0x2003065d,0xcdc90053,0x68e2003f,0x9f580c98}},	//   ciji_, ױך_, vyod, birá_
  { {0x9f580077,0xfaaa002b,0xfc3f0077,0x7a15002a}},	//   cirá_, تهاي_, _asís_, ząte
  { {0xef17008f,0x79a30292,0xe3b80064,0xba170015}},	//   _імя_, врше, zdı_, ويلا_
  { {0x7a230005,0xd6cf0086,0xe3b80064,0xb05b00c0}},	//   võtt, یقه_, ydı_, rväg
  { {0xd0f7000a,0xb05b04d6,0x78ad016e,0x68e209cf}},	//   ומנת_, sväg, çava, ryod
  { {0x7a230020,0x7bdc002d,0x66730015,0x7791002b}},	//   tõtt, _ioru, ندير, ایما
  { {0xc8830064,0x1dd1005d,0x200301a3,0x16370015}},	//   üğü_, हायत, ziji_, وسية_
  { {0xe4520015,0x7bdc16f5,0x9f58016e,0xd6170015}},	//   خضع_, _koru, zirá_, بتوا_
  { {0x88bd005c,0xf1bf0030,0x7792002b,0xdb0e016e}},	//   _myśl, alál_, _شیبا, _gabã
  { {0xe3b80064,0x20030263,0x7a310123,0x7bdc16f6}},	//   rdı_, viji_, låta, _moru
  { {0xd257008f,0x24520023,0x38690045,0xdb1c0123}},	//   ьць_, _tâm_, ţare_, _inrä
  { {0x2003044c,0x60f804ab,0xd5cf0016,0xe63b004f}},	//   tiji_, дняя_, _kềnh_, _ותאכ
  { {0xa2be000b,0xd3b7005e,0xf1bf0030,0x9f5816f7}},	//   षिद्, _олії_, mlám_, tirá_
  { {0xff290015,0x200316f8,0xcddb0054,0xf1bf0030}},	//   سكري_, riji_, оња_, llám_
  { {0x20030263,0x63b80293,0x9f580896,0xdce6003d}},	//   siji_, _havn, rirá_, _sekā
  { {0x229800dc,0x0e440010,0x4174002b,0x200316f9}},	// [2490] lék_, тэрм, _شايس, piji_
  { {0xbcfb00dc,0xfe710086,0x63b80a00,0xfbd30115}},	//   _beér, _مگر_, _javn, ختر_
  { {0xdcfd0064,0xa036000a,0x7bdc16fa,0x629a01be}},	//   _vası, _ראתה_, _doru, ntto
  { {0xf1bf16fb,0xc3330008,0x629a16fc,0x63b80d7e}},	//   klám_, דוע_, itto, _lavn
  { {0x69db16fd,0x8d5a000a,0x186916fe,0x60090091}},	//   _voue, _מכרי, чали_, ažme
  { {0xfe700086,0xdb0716ff,0x229800dc,0x63b80293}},	//   _حدی_, _majú, kék_, _navn
  { {0xd6d1003b,0x26c102d5,0x22980030,0x3a540138}},	//   اقع_, ího_, jék_, _аксё
  { {0x917a0023,0x7bdc0064,0x229800dc,0x99840015}},	//   _mẫu_, _zoru, dék_, _للفو
  { {0xdb07002c,0x7bdc1700,0xc8b40015,0x212901c2}},	//   _najú, _yoru, _لإلغ, _nyah_
  { {0x4423002c,0x76a70015,0xdb0e0030,0xf6e708b0}},	//   ôj_, _يحاك, _habá, _оцен
  { {0x2bb2005d,0xe9ff0092,0xfbd20008,0x21290509}},	//   ीयता, _giản_, אתי_, _ayah_
  { {0xbbdc000b,0xe1f2012c,0x0000006a,0x0000006a}},	//   _मक्क, اسد_,   ,
  { {0x64a5008f,0x04c80015,0xa4390033,0xc4fb0040}},	//   _чала, _يومي_, _езду_, _بعضا_
  { {0xdb0e0123,0x7fd6008b,0x289a000a,0x63b8063b}},	//   _inbö, хімі, הישא, _gavn
  { {0xada60080,0x6da60164,0x71a60033,0xdee60015}},	//   навл, нива, _зайз, رأسي
  { {0x7bdc01e2,0x11d60029,0x25ad0150,0xc1ba0115}},	//   _soru, _ستبد, neel_, _رابط_
  { {0x7bdc1701,0x63a60030,0x0d990088,0x248d1702}},	// [24a0] _poru, őkne, ьтры_, nuem_
  { {0xa09b00b2,0x394d003e,0x1f66017f,0xb09b000a}},	//   _צייט, _ages_, _яком, _צייר
  { {0x88bd0050,0x9b930015,0x25ad1703,0xc1ba000a}},	//   _wyśl, المت, keel_, ּמְש
  { {0x60c41704,0x9f06002b,0xd910002b,0x7077002b}},	//   _krim, _يوکو, لیز_, _تمیز_
  { {0x317b0008,0x25ad0150,0x7ae5008c,0x22980030}},	//   פרסמ, deel_, ayht, zék_
  { {0x207b004c,0xf7930033,0x75fe003d,0x907b000a}},	//   לאנא, гашэ, mūzi, לטני
  { {0x2cb20176,0x63b802c6,0xa96a1705,0xcf93000a}},	//   lwyd_, _ravn, _нива_, אטו_
  { {0x04660010,0x1a9b004c,0x0f37004c,0x7af20061}},	//   нтом, _מילע, ערקט_, ıktı
  { {0x2cb20176,0x248d12b3,0x35c5000b,0x224901c2}},	//   nwyd_, guem_, वाज़, _riak_
  { {0x22980014,0xa87b0008,0x224901d7,0x80c4000b}},	//   ték_, _מאמר, _siak_, िटने
  { {0x2cb20026,0x7dd800dc,0x05661706,0x8497002b}},	//   hwyd_, _dísz, _звен, وئیس_
  { {0x629a1024,0xcb13000a,0x0665002b,0x22980030}},	//   rtto, טלת_, _شامپ, rék_
  { {0xc0cb0001,0xd5af0002,0xa3b40033,0x60c4082d}},	//   чуне_, _دفن_, _аблі, _crim
  { {0x2cb20176,0x14c9009a,0x60c41707,0x629a02ad}},	//   dwyd_, _آهوی_, _drim, ptto
  { {0x443e018b,0xbdc7006b,0x64930dba,0x6e2601d7}},	//   mmt_, нщай, ržiš, _bkkb
  { {0x2cb20176,0x442c1708,0x80be000b,0x52830015}},	//   fwyd_, lld_, शिशे, _إليك
  { {0x2cb20026,0x644a1709,0x7c970029,0x443e170a}},	// [24b0] gwyd_, _kifi, عشرا, omt_
  { {0xf1c0006f,0x0c390015,0xdb15006f,0x6288170b}},	//   čšej_, ذكاة_, _enzý, ordo
  { {0x67ef0134,0xfc300029,0x141b0008,0x443e170c}},	//   _nøja, صحك_, לומב, imt_
  { {0x443e0012,0x2cb20034,0x88bd002a,0x7ae5008c}},	//   hmt_, bwyd_, _wyśm, ryht
  { {0xa17c00b2,0x7ae500f2,0x644a002d,0x67d5170d}},	//   לטאט, syht, _oifi, коду
  { {0x00580008,0x07a50180,0x6e2d0fb7,0x7d00001a}},	//   עשות_, такн, llab, _ýmsa
  { {0x79a7008f,0xf6b20029,0xdb0e0046,0x25ad170e}},	//   _прае, لموج, _tabá, teel_
  { {0x6e2d170f,0x248d0527,0x442c15fc,0xfa37002b}},	//   nlab, tuem_, eld_, _سرزد
  { {0x8cc4014e,0x6e2d1710,0x58840033,0x62881711}},	//   रियो, ilab, _быха, erdo
  { {0xf1bf1712,0x03a50054,0x2c37000a,0x89340015}},	//   blák_, њино, עָ֗ם_, _إعفا
  { {0x6e2d002e,0xe2850063,0xf5e7005e,0x25ad042f}},	//   klab, ълни, _підм, peel_
  { {0x2cb20026,0xe4d50015,0xa5670015,0x644a0034}},	//   ywyd_, _لتتب, _أدان, _eifi
  { {0xa8790053,0x644a003f,0xdd92002b,0x69d90079}},	//   ואָר, _fifi, یوس_, ijwe
  { {0xedca000b,0x9888000a,0xa01b0012,0x6d5d1713}},	//   ाञ्छ, עָרֵ, nröh, _afsa
  { {0x91fd0048,0x7a381714,0xa2d20021,0x5f031715}},	//   mpān, líte, _نيوت, азра
  { {0xa6e90023,0x6e2d1716,0x60c40939,0x65691717}},	//   _trươ, glab, _trim, nbeh
  { {0x7a381718,0x270d000b,0x2cb20034,0x442701d7}},	// [24c0] níte, िपुर_, uwyd_, _kkn_
  { {0x2cb20176,0x6d5d0061,0x6e2d1719,0x2bd2000b}},	//   rwyd_, _efsa, alab, साधा
  { {0x2cb20026,0x6e2d0cf7,0xee3a171a,0xeb97171b}},	//   swyd_, blab, _оно_, тих_
  { {0x65690111,0x58860010,0x99460015,0x066d004c}},	//   jbeh, выка, نَاه, _נאָך_
  { {0x443e002e,0x010d000a,0x4c830033,0x442c171c}},	//   ymt_, ּלוּ, _кляв, yld_
  { {0xc8650029,0x6569002c,0x6b630286,0x6602171d}},	//   اطني, ebeh, _вкра, _smok
  { {0x764b00b6,0x644a04ed,0xa3d5000b,0xc6930015}},	//   _bigy, _rifi, हान_, لشيع
  { {0x442c0111,0x7ae31581,0x644a1610,0x764b0034}},	//   wld_, änte, _sifi, _cigy
  { {0x41d6005d,0x7a3800dc,0xa9260087,0x09e3006b}},	//   धानस, gíte, _شعره, _тотн
  { {0x442c003e,0x6e2d0024,0x52d80036,0x6e24002d}},	//   uld_, zlab, емою_, hoib
  { {0x764b00dc,0x442c171e,0x7a310123,0x3f85171f}},	//   _figy, rld_, kåtl, ólum_
  { {0xda7b000a,0xd0d5009b,0x44270072,0x644a0072}},	//   ונטר, гомъ, _ekn_, _wifi
  { {0x7a15002a,0x61f80033,0x7a38039f,0x0000006a}},	//   kątn, тняў_, cíte,
  { {0xa91d15e9,0x6e951293,0xa294004e,0xe3b8007f}},	//   _udže, лигу, _бакі, alır_
  { {0xdbdc002e,0xd378005c,0x6e2d1720,0xa2e30004}},	//   _ráðl, mać_, tlab, _војд
  { {0xd378005c,0x6e2d0061,0xb6bb015b,0x61e9007c}},	//   lać_, ulab, וצלי, öeld
  { {0x3179005c,0x24f6000a,0x30a40033,0x6e2d1721}},	// [24d0] masz_, כֶ֑ם_, _крэв, rlab
  { {0xd378005c,0x317906e7,0x6e2d0192,0xa50b000a}},	//   nać_, lasz_, slab, וּבִ
  { {0x1622005d,0xe28b0089,0xf09f062b,0x7a3800dc}},	//   मवार_, _účtů_, ltà_, zíte
  { {0xa01b002e,0x4994005e,0x3179002a,0x19590033}},	//   fsög, ишіт, nasz_, хады_
  { {0xd3780050,0x9d14005e,0xf09f1722,0xa3d5000b}},	//   kać_, _вдяч, ntà_, हाम_
  { {0x7a3800dc,0xf807006b,0xd378002a,0xe7390658}},	//   víte, ъчен, jać_, нел_
  { {0xd3780050,0x9f5102c1,0x317912f7,0x6f7a000a}},	//   dać_, lizó_, kasz_, תְנו
  { {0x26c5016f,0xa87b0029,0xcb1200a3,0x3179002a}},	//   _vrlo_, _يحذر_, _הלל_, jasz_
  { {0x75f50089,0x3179005c,0xbddb0003,0x9f510077}},	//   _náze, dasz_, _fièv, nizó_
  { {0xd378005c,0x7a381723,0x68e40201,0x33650033}},	//   gać_, ríte, äide, ывог
  { {0xf09f04ed,0x7a381724,0x420a1725,0xe1f20015}},	//   età_, síte, енно_, مسح_
  { {0x7a3800dc,0xf1bf001c,0xc049004f,0x28c70065}},	//   píte, gdá_, _זז_, लिपि
  { {0x7c250085,0x53a50b76,0xd378002a,0x03a50788}},	//   kohr, _балб, bać_, _било
  { {0x25bd0026,0xd378005c,0x25bf0011,0xe8d6000a}},	//   _hawl_, cać_, ldul_, אושר_
  { {0x93240074,0x539a0008,0x64410012,0x9f96007c}},	//   _پرون, _ניקו, mmli, müük_
  { {0xe1f20074,0x25bf1726,0x66091727,0x20d6005e}},	//   _دست_, ndul_, niek, _біос
  { {0xa3c8005d,0xf09f0144,0x25bd0034,0x6e241728}},	// [24e0] _लोड_, ctà_, _mawl_, roib
  { {0x44250b7c,0x249f002e,0xeb97067a,0x5fba004f}},	//   nol_, itum_, лиу_, _נֶ֥ג
  { {0xb05b01d1,0x6b5900dc,0x66091729,0x7f9b000a}},	//   nvän, _súgó, kiek, _אביז
  { {0xd378005c,0xceb30053,0x644100b8,0x44250f48}},	//   zać_, _פיר_, hmli, hol_
  { {0x4425172a,0xdc750010,0x6609172b,0xbbea0015}},	//   kol_, _высь, diek, _كرسم_
  { {0xa01b002e,0x93bc0011,0xa089000a,0x28b5000b}},	//   rsög, nlăt, דְקִ, _आईरि
  { {0x386600e8,0x6609049c,0x249f002e,0x44250f48}},	//   spor_, fiek, etum_, dol_
  { {0xd3780f9a,0x200a0064,0xb05b00c0,0x66090519}},	//   wać_, hibi_, dvän, giek
  { {0x44250176,0xd378005c,0x200a0064,0xc7960031}},	//   fol_, tać_, kibi_, _مشاب
  { {0x4425172c,0x3a260150,0x3179002a,0xd7570015}},	//   gol_, loop_, wasz_, _ملكت_
  { {0xd378005c,0x16660001,0x3179172d,0x25bf172e}},	//   rać_, _свем, tasz_, bdul_
  { {0xf09f02d7,0x2ca00005,0x91a0005d,0xd378005c}},	//   ttà_, ktid_, ग्लै, sać_
  { {0x3dc00026,0x4425172f,0xd378002a,0xf1bf1730}},	//   ddiw_, bol_, pać_, kláv_
  { {0xc356010f,0xf09f1722,0x44251731,0xb4b2000b}},	//   _съдъ, rtà_, col_, फ़टी_
  { {0xa36f002c,0xf09f1732,0xd35b000a,0x46f4000a}},	//   äčši, stà_, _אדול, בֶּן_
  { {0x8d770015,0x7055002b,0x2cab0045,0x9f510077}},	//   طارا, _پندا, _ppcd_, tizó_
  { {0xdbd20020,0x682d002c,0x80a40086,0x8c570015}},	// [24f0] _füüs, súdi, _همين, ائرا
  { {0x41c3014e,0x320b0876,0x66091733,0x9f510077}},	//   षयवस, licy_, ziek, rizó_
  { {0xddd00064,0x69e70033,0x2bb80015,0x7c251734}},	//   _çeşi, людз, داقة_, rohr
  { {0x320b005c,0x249f002e,0x69d5000b,0x443c007c}},	//   nicy_, ytum_, णाधी, _lhv_
  { {0x2ca00026,0xad19000a,0xaf4b002b,0x25bd1735}},	//   ctid_, _יוֹר, _تشکل_, _rawl_
  { {0x25bd0176,0x6609005c,0xa2650092,0xba770002}},	//   _sawl_, wiek, _buộ, _مارت
  { {0xec36013a,0xa2650023,0x442512f9,0x96b9018f}},	//   _כאשר_, _cuộ, vol_, тулу_
  { {0x3ebe002e,0x249f1736,0x25bf01d7,0x442500a9}},	//   ætti_, ttum_, udul_, wol_
  { {0xfa340086,0xc3d50010,0x25bf1737,0x44251738}},	//   _طرفد, аўны, rdul_, tol_
  { {0x66091739,0x13e60080,0x4425173a,0xa8480015}},	//   siek, имый_, uol_, _ملقم_
  { {0x249f1220,0x7a3800dc,0xddc70007,0x6609173b}},	//   stum_, líta, gpjū, piek
  { {0x44250176,0x249f002e,0xb05b00c0,0x7a880008}},	//   sol_, ptum_, rvän, נָתַ
  { {0xb05b00c0,0xa3d5000b,0x80260015,0x13a7002b}},	//   svän, हाद_, لرسم, _منشی_
  { {0x88bd0050,0xb4fa0008,0x34fa0447,0xb05b0123}},	//   _wyśw, _בפני, _בהנד, mväl
  { {0x645b0467,0x200a173c,0x539a0008,0x245b0092}},	//   lqui, ribi_, _ייסו, _hêm_
  { {0x8e550191,0x4d66008f,0xdd920225,0x78bb00f2}},	//   стрі, ркав, تور_, _osuv
  { {0x93bc0011,0xb05b008c,0x6b560fea,0x7a380030}},	// [2500] plăt, nväl, атех, jíta
  { {0x307b013a,0x907b00b2,0x645b0251,0x2722002c}},	//   _שאינ, _שטיי, iqui, nčné_
  { {0xf1da005d,0xdb15001c,0x78bb0209,0x600b000a}},	//   _बचान, _razã, _asuv, _יִטְ
  { {0x61e400f2,0xc3320008,0xb17b0d2b,0xe9a60010}},	//   _joil, חוב_, lkår, радп
  { {0xdb1c0152,0x61e4002d,0x2722002c,0x98a307be}},	//   _maré, _moil, kčné_, жиче
  { {0x18670001,0xf0930008,0xda660015,0x248d173d}},	//   шаљи_, קנו_, _ناري, drem_
  { {0x5b350010,0x69c1000b,0x8c1b000a,0xdb050012}},	//   _гэту, _रोकी, _סולי, gehä
  { {0x78660036,0x61e4173e,0x68eb02df,0xd8760015}},	//   _вказ, _noil, bygd, _نائب
  { {0x91830023,0x7a38039f,0x248d173f,0x0000006a}},	//   _nếu_, cíta, grem_,
  { {0x320b002a,0xdb1c0144,0xdb150030,0xe8f70054}},	//   wicy_, _parè, _hazá, _тлу_
  { {0x4b7b15bb,0xec370008,0xcb57000a,0x23b7000b}},	//   כטיג, שאיר_, יסיה_, _असरद
  { {0x61e41740,0x69c01741,0x93bc0045,0x2722006f}},	//   _coil, _jame, glăr, ačné_
  { {0xfeb80074,0x245b0176,0x61e4173e,0xd5fb000a}},	//   یافت_, _gêm_, _doil, _בפאר
  { {0x7a310123,0x25ac0091,0xb17b0789,0x9fe80015}},	//   tåtk, ūklė_, gkår, لُّم_
  { {0x69c004f9,0x34b6005d,0x9f350010,0x75f500dc}},	//   _oame, _अनुद, севі, _háza
  { {0xdb0501d1,0x5d551742,0x69c01743,0x78a21744}},	//   nehå, скат, _name, ktov
  { {0x78a2016f,0x69c21745,0xbddb0003,0x7a310123}},	// [2510] jtov, ddoe, _bièr, såtk
  { {0x6fb50087,0x7b670010,0x0a6b0180,0xeb930031}},	//   _امدا, ртае, врди_, تظر_
  { {0xcf92013a,0xd9550015,0x645b0077,0x69c200aa}},	//   _צטט_, مناخ, zqui, fdoe
  { {0x91830092,0xc333000a,0x4279004c,0xb05b008c}},	//   _yếu_, קוף_, ראײג, yväl
  { {0xf0940053,0xf1bf00dc,0xbddb0003,0xa01b0123}},	//   ַנק_, llás_, _fièr, bröt
  { {0xe8f80010,0x645d02c1,0xc864005e,0x68e4007c}},	//   шлі_, ísim, ітчи, äida
  { {0xc6680124,0x7a381746,0x657b0035,0xa3d5000b}},	//   ашње_, mítn, tauh, हास_
  { {0xff180008,0x04950010,0x69c01747,0x95991748}},	//   יקות_, броў, _game, утку_
  { {0x78bb007c,0xdb0504d2,0xadd8000a,0xf992000a}},	//   _usuv, sehä, שוחח_, _מרן_
  { {0x61e41740,0x248d1749,0x69c0174a,0x245b016e}},	//   _soil, rrem_, _zame, _vêm_
  { {0x645b11e0,0x69c0000c,0x7a15005c,0x2722002c}},	//   squi, _yame, jątk, rčné_
  { {0x245b03af,0xcb120008,0x82f40010,0xdb0800dc}},	//   _têm_, ללי_, ючыц, ülés
  { {0x70560029,0x61e40152,0xe6040015,0x45450015}},	//   إنسا, _voil, _بِنَ, _انشق
  { {0x51f60074,0x10160033,0xb1430033,0xe299174b}},	//   _گستر, сьмя, янял, _бак_
  { {0x22950029,0x52850029,0x3376000a,0x61e4174c}},	//   _العس, _البك, _העצם_, _toil
  { {0x51f60074,0x78a20156,0x64590035,0xb17b174d}},	//   _دستر, ytov, _kuwi, skår
  { {0x228301e2,0x5baa0010,0x78a204af,0xf1bf0030}},	// [2520] lık_, лкам_, xtov, rlát_
  { {0x69c0174e,0x6281174f,0xaf9a0fdc,0x0000006a}},	//   _same, oslo, _стих_,
  { {0xcf570008,0xdcef0024,0x22830064,0xc27a004c}},	//   _לבית_, _vecā, nık_, ָרני
  { {0x88860029,0x7db60029,0xf1bf00dc,0x3ebe002e}},	//   مؤتم, _اصدا, llár_, ættu_
  { {0x1754006d,0xc19b000a,0x219b000a,0x78a21750}},	//   овля, רשני, רבנא, utov
  { {0x69c0003f,0x78a2049e,0x2018001a,0x69c203f8}},	//   _wame, rtov, nnri_, sdoe
  { {0x78a21751,0x46670174,0x75f50046,0x69c01752}},	//   stov, брым_, _sáza, _tame
  { {0x9b170008,0x22830064,0xf1bf002d,0x8e7b0053}},	//   _החלה_, dık_, hlár_, אנקה
  { {0x7a380014,0x7a15005c,0xe4e6017f,0x86c6002b}},	//   líto, zątk, сійн, _گيان
  { {0x8cbb013a,0xa41c003d,0x64590034,0x4cbb000a}},	//   נציק, _ādēļ_, _duwi, נזיו
  { {0x02a30142,0x86c600e6,0x7a380030,0xb7d70015}},	//   прям, _ديان, níto, _دولا_
  { {0x224001c2,0x75f51753,0x20181193,0xdd28003d}},	//   _chik_, _táza, enri_, zēšo
  { {0x25b70074,0xb1140010,0x62810844,0x9f41006f}},	//   _دهند_, змяш, aslo, _dlhý_
  { {0x7a3800dc,0xa01b0061,0xb4d40157,0xb05b008c}},	//   kíto, erör, हमी_, lväk
  { {0xa3d5014e,0xa6f80008,0x628112d7,0x0cd1000b}},	//   हार_, בִּי, cslo, सम्म
  { {0xbd890029,0x6463002e,0x7a381754,0xf1bf00dc}},	//   شنطن_, _óvið, díto, rlás_
  { {0xf1d6005d,0xc4b6005d,0xae02000b,0x765a1755}},	// [2530] धारन, _अनोख, रोइन_, _luty
  { {0x3a2d020a,0xf1bf002d,0x41a5000b,0xa01b0123}},	//   _skep_, clár_, ग्रस, rrös
  { {0x1dc4005d,0x765a0007,0x7a381756,0x220b000a}},	//   _लोकत, _nuty, gíto, ְפְּ
  { {0x5ee80008,0xb6460033,0x7a380030,0x60cd1757}},	//   _הַשְ, _кнiж, sítn, _kram
  { {0x7a380089,0x28a7004a,0x22830061,0x7cc7002b}},	//   mítl, сшег, zık_, _ازجم
  { {0x907c0008,0xf7710015,0x22830061,0x26cc0085}},	//   רטגי, ذات_, yık_, _brdo_
  { {0xa3dc000b,0xdc3a000a,0xcf94015b,0x8f8c000a}},	//   डान_, _כעשר, לטס_, רְדֵ
  { {0x7d0909f0,0x26c700bd,0x7aea04d4,0x59f8005e}},	//   _þess, rvno_, äfte, _леся_
  { {0xa3d5014e,0x9475002b,0xe6160033,0xe4560033}},	//   हाल_, زگشا, ўды_, ожы_
  { {0x228301e2,0x981703c4,0x62811758,0xd2a9055f}},	//   tık_, _ابرا, tslo, акое_
  { {0x60cd0482,0xe9ff0092,0x28c7000b,0xcad5000a}},	//   _aram, _nhẫn_, लिवि, קוֹת_
  { {0x64590035,0x75f50264,0x6aa5130f,0xd9f9000b}},	//   _tuwi, _zázn, ithf, ंसित_
  { {0x902a0015,0x01360021,0x24190088,0x7a380030}},	//   لأسف_, تعدد, _коды_, zíto
  { {0x9e660015,0xdd010046,0x3f9e007c,0x60cd1759}},	//   قارن, štěv, ütu_, _dram
  { {0xd3470086,0x60cd0020,0xb6ac000a,0xed5a0004}},	//   _دیده_, _eram, ְׁמֹ, иов_
  { {0x7bd500b8,0xed57000d,0x60cd175a,0xc1ba0021}},	//   _anzu, жот_, _fram, _ضابط_
  { {0xac0a0004,0xa01b0123,0x60db0012,0xdca3144a}},	// [2540] анаа_, rrör, äumt, мати
  { {0x60260191,0x9f6000f2,0xb0690067,0xa01b0123}},	//   _єдна, ärät_, _اصيل_, srör
  { {0x34b6005d,0xda650029,0xb05b00f2,0x75f50069}},	//   _अन्द, كاني, yväk, _názo
  { {0xa3d5005d,0x7bc50a72,0x7a38175b,0x765a002a}},	//   हाँ_, adhu, ríto, _ruty
  { {0x79890176,0x7a380014,0x2db7013a,0x63660089}},	//   _ddew, síto, _ולכן_, nční
  { {0x7a38175c,0xab7a0015,0xa3c8000b,0xdb1c175d}},	//   píto, _خمسا_, _लों_, _harí
  { {0xf1ca014e,0xdb1c001a,0x2d800045,0xb8070021}},	//   ियान, _karí, oaie_, تيوم_
  { {0x95ca0124,0x94aa05e6,0x63660046,0x7b050030}},	//   рука_, атоа_, kční, őttü
  { {0x75fc0014,0xa3d5005d,0xe9ff0092,0x8ccd005d}},	//   _néze, हां_, _hiến_, सियो
  { {0xe9ff0023,0x03f80001,0xe6c60015,0xc34a004a}},	//   _kiến_, сној_, _وتضي, ияне_
  { {0x0bb7000a,0x75d60015,0x01d90015,0xbcfb016e}},	//   חלים_, _ويطا, مودع_, _afél
  { {0xe9ff0092,0x60cd175e,0xf20700ce,0x0000006a}},	//   _miến_, _pram, іяно,
  { {0x845a000d,0x32f50016,0x4fc70783,0x7a38001a}},	//   _трет_, áy_, осва, vítl
  { {0xe9ff0016,0xe4e90015,0x188b000a,0x7a3100cb}},	//   _phẫn_, _دعمه_, סְכּ, lått
  { {0x2263002c,0xa6f8000a,0x6397000a,0xfb00003d}},	//   ľské_, זִּי, _ודוא_, _šūnu_
  { {0x02fb0008,0x442c175f,0xc33300a3,0x2d58034e}},	//   _כלומ, lod_, _קוק_, жить_
  { {0xa80201e2,0x75fc00dc,0xdb1c0533,0x442c1133}},	// [2550] şıyo, _kézb, _darí, ood_
  { {0xe9ff0023,0x442c1760,0xa0080015,0xab94005e}},	//   _biến_, nod_, _وقيل_, дифі
  { {0x20111761,0x64480064,0x7a380030,0x7bc500cb}},	//   mizi_, imdi, mítj, rdhu
  { {0x2486010b,0x7a3800dc,0x6aa50026,0xe9ff0092}},	//   _ovom_, lítj, rthf, _khẩn_
  { {0x8dda0008,0x4dda000a,0x442c1762,0xcdf6000a}},	//   _הקרק, _החרו, kod_, _זמרי_
  { {0x20110482,0xe0df0251,0xe8080036,0x7bd500b8}},	//   nizi_, ixò_, онід_, _unzu
  { {0x96750010,0x501c000a,0xb05b007c,0x442c1763}},	//   чылі, בוגו, sväh, dod_
  { {0x8f1c000a,0xc1da000b,0x39151764,0xe6280058}},	//   יוות, _बचेग, _ембр, يثين_
  { {0x442c0176,0x58840010,0x86c50086,0x79c80029}},	//   fod_, _жыха, زيکن, _بوقف_
  { {0x7305006b,0x20110085,0x442c1765,0x9cd6000a}},	//   зпоз, jizi_, god_, פותה_
  { {0x44390048,0xc6d40029,0x20110db0,0x96f80015}},	//   ēs_, _يتمت, dizi_, _وعمر_
  { {0xdb0e0046,0x2011003d,0xc73a000a,0x5ef10065}},	//   _nabý, eizi_, _התעת, ीनन्_
  { {0x455a011f,0xa01b00b8,0xe9ff0092,0x442c1766}},	//   _הכנס, rsön, _chẩn_, bod_
  { {0x764901e2,0x2011003f,0x7fd506b4,0x22560086}},	//   lmey, gizi_, місі, _کليد_
  { {0xdee60805,0xdb1c1767,0x661b006f,0x6436000a}},	//   чови, _parí, onuk, _צאצא_
  { {0x661b022d,0x764901e2,0xee3a0010,0xe1ff0077}},	//   nnuk, nmey, ёна_, chó_
  { {0xb05b00f2,0x819b0008,0xd3470086,0xc19b000a}},	// [2560] yväi, _הספצ, _دیگه_, _השפי
  { {0x60090007,0x1d19005e,0x2d800003,0x6cd30015}},	//   yžmi, іють_, saie_, عقلا
  { {0xab69003b,0x7a3800dc,0x76490064,0xa01b008c}},	//   تحقق_, sítm, kmey, isöl
  { {0xdb1c001c,0xc8c7000b,0xaa570015,0x8276004c}},	//   _parâ, लिंट, سلها_, פענע_
  { {0xed520086,0x442c0035,0x6448002e,0xdb1c016e}},	//   _سپس_, yod_, ymdi, _barã
  { {0xe9ff0023,0x6d3b0008,0xdb0e0089,0x2609000b}},	//   _tiến_, _לתכנ, _zabý, ़ोसी_
  { {0x2486016f,0xa3d5005d,0x8c431768,0x8cc4000b}},	//   _svom_, हाई_, _чере, रिको
  { {0xceb3013a,0x442c0026,0xc9d40086,0xfb1b000a}},	//   גיה_, wod_, _تمرک, _הולמ
  { {0x38c80074,0x7d041769,0x29020123,0xdb1c016e}},	//   _بازی_, nzis, _åka_, _farã
  { {0xa2f401e5,0x7d00001a,0x6443176a,0xd326030c}},	//   дпоч, _ýmsu, _chni, зьми
  { {0x442c176b,0xe4da002b,0x67a50015,0x6448003d}},	//   rod_, _گوشت_, _تحقق, rmdi
  { {0xd257008f,0xbbc8005d,0x7982003f,0xe3af002b}},	//   яць_, रयुक, naow, پری_
  { {0x442c010b,0x5067176c,0x7a380030,0xf5ab000a}},	//   pod_, ятна, títj, _ה֑וּ
  { {0xe2f80010,0x7d040d55,0x14d7000a,0xc7b4004c}},	//   _мелі_, dzis, _מודל_, ובֿ_
  { {0xc43b0008,0x9f5802b9,0x7a380030,0x5333012e}},	//   _התגי, tirò_, rítj, _пешт
  { {0x753d005c,0x7a3800dc,0x63ba176d,0x2e4b0033}},	//   ższe, sítj, letn, сяго_
  { {0x7d040007,0xdd940010,0x2718000b,0x7a380030}},	// [2570] gzis, эаты, धपुर_, míth
  { {0x7a380f11,0x307c000a,0xf045002b,0x629a16c3}},	//   líth, _האזנ, _تعبی, outo
  { {0xdb1c08e0,0x3f83176e,0xfc300015,0xc175000a}},	//   _carà, maju_, احق_, ֵחַ_
  { {0x7aea00c0,0x63ba00dc,0x7a3800dc,0x39150a61}},	//   äfta, hetn, níth, ммер
  { {0x48ab176f,0x6d580046,0xf1bf0016,0x63ba1770}},	//   стем_, ěvat, goái_, ketn
  { {0xfe700086,0x63ba0263,0x2ca90123,0x629a1771}},	//   _جدی_, jetn, mtad_, kuto
  { {0x76490064,0x67d2000d,0x2ca91772,0x629a1773}},	//   tmey, тоју, ltad_, juto
  { {0x629a1774,0x9b440029,0xceb40008,0x05da000b}},	//   duto, _سنقو, תיק_, भाषब
  { {0x764901e2,0x3f83016f,0xdb170003,0x7a381712}},	//   rmey, kaju_, dexé, díth
  { {0x43740036,0x3f83016f,0x63ba00dc,0xdc8c000a}},	//   нуют, jaju_, getn, צְחָ
  { {0x3f83016f,0x0cba000b,0x47350033,0x7bc71775}},	//   daju_, _उन्म, _ўнес, _maju
  { {0xcf890dab,0x7a3816d2,0x2ca91776,0xa5c6002a}},	//   _כט_, gíth, ktad_, _próż
  { {0xa3c8000b,0xa4d400fd,0xaca30016,0x25ad0123}},	//   _लोक_, _поці, _diịc, mfel_
  { {0x63ba0085,0x2ca90030,0x344b018d,0x3f830085}},	//   cetn, dtad_, _учен_, gaju_
  { {0xe9ff0092,0x67ef0134,0x2bd1000b,0xa5c6002a}},	//   _nhắn_, _højs, _सफ़ा, _wróż
  { {0xee3a02e5,0x2be0000b,0xb22600fd,0xc332000a}},	//   іна_, नाभा, _імпл, _שוה_
  { {0xbc6a0074,0x3f83016f,0x7a380089,0x25ad0012}},	// [2580] زمان_, baju_, sítk, ifel_
  { {0xdb1c0251,0xeafa00e6,0x7b160029,0x3f83016f}},	//   _parà, يرات_, وظائ, caju_
  { {0xdb1c0014,0xe9ff0092,0x3fdb000a,0x7a381309}},	//   _bará, _chắn_, _וקיב, líti
  { {0xdb1c0656,0x63ba1777,0xf99200c3,0xad9b0125}},	//   _cará, zetn, ئبا_, _clúd
  { {0x307a0053,0x395200f2,0x2252006f,0x3c460015}},	//   קאַנ, äys_, ízky_, _يَجِ
  { {0x38cb0086,0x60c4003f,0x7a380030,0x7bc71778}},	//   غانی_, _msim, zíth, _gaju
  { {0xa3c8005d,0xd6d000e5,0xc6a60004,0x97c50015}},	//   _लोग_, اقب_, фрли, عتهم
  { {0xd90e002b,0x3f831779,0xe5a30054,0x6f030061}},	//   _پیت_, zaju_, вићи, _ünce
  { {0xfe37000a,0x91fd003d,0x7a380030,0x63ba177a}},	//   ורקי_, kpār, víth, tetn
  { {0xb05b177b,0xdb1c177c,0x46b60015,0x629a177d}},	//   hwäc, _zará, _يحاس, tuto
  { {0x3f83010b,0x629a00f2,0x63ba177e,0xe2150256}},	//   vaju_, uuto, retn, емны
  { {0x74130086,0x91fd0024,0x629a177f,0xc05b005e}},	//   _یونا, epār, ruto, жів_
  { {0xc5f3013a,0x3f83016f,0x7a381780,0x75d30015}},	//   _בדף_, taju_, ríth, _جينا
  { {0xbbc8014e,0xa01b01d1,0x67ef00fb,0x48f90053}},	//   रयोक, msök, _højr, פּרא
  { {0x60c40356,0xa01b00c0,0x3f831781,0x7a3800dc}},	//   _esim, lsök, raju_, píth
  { {0x7a38002d,0x3f831782,0x2ca91783,0x0000006a}},	//   bíti, saju_, ttad_,
  { {0xe81f005d,0x3f831784,0xa01b0123,0x7a310123}},	// [2590] _बदला_, paju_, nsök, dåtp
  { {0x2c6400c0,0x41dd005d,0x9f4500dc,0x2ca91785}},	//   _död_, यावस, óló_, rtad_
  { {0x386d1786,0x7bc70020,0x25ad0f50,0xdb1c1787}},	//   _ster_, _vaju, yfel_, _pará
  { {0xceb200b2,0xdb260086,0xa01b00c0,0x31bc0053}},	//   _גיט_, رونی, ksök, ַזונ
  { {0x9f58002f,0xdb1c00dc,0x7bc71788,0x58d9005e}},	//   mhrá_, _vará, _taju, яддя_
  { {0x07a20254,0xd0f8000a,0xdc88000a,0x29160015}},	//   гашн, ומדת_, _קְרָ, عقود_
  { {0x49bb0074,0x25ad04f9,0x19950010,0xa01b00c0}},	//   _وارد_, tfel_, _павя, esök
  { {0xcf58011f,0x04c90015,0x6b850049,0x62881789}},	//   ובות_, كوبي_, lahg, dsdo
  { {0x9e4c000a,0xa01b0123,0x8cd2000b,0xad9b001a}},	//   חֲזִ, gsök, ठियो, _klúb
  { {0x7d1a0008,0x25ad00c0,0x13090afa,0xc7470031}},	//   לֵיה, sfel_, зной_, _قضاي
  { {0xa91d00bd,0x6d5d0bfa,0x98140015,0x8bd6000a}},	//   _deže, _ogsa, _شبكا, גותו_
  { {0xb05b008c,0x69cb0599,0xa01b0123,0x60020016}},	//   yvät, ndge, bsök, _môme
  { {0xe9ff0023,0xa01b0030,0x38a90125,0xb05b0c9e}},	//   _nhận_, csök, núr_, dväs
  { {0x2c6400c0,0x64580876,0x68e4014b,0xd9bc000b}},	//   _röd_, _givi, äidi, _ईस्ट
  { {0xa3dc005d,0x7a380030,0x8d760015,0x6e290069}},	//   डार_, mítv, فاءا, čebn
  { {0x91fd0024,0x7a380030,0x6458178a,0x61ed178b}},	//   spār, lítv, _zivi, _goal
  { {0xf6520053,0x60c4003f,0xdd8f00e5,0x908a0015}},	// [25a0] רצן_, _usim, صول_, _عندك_
  { {0x61ed0298,0x75fc00dc,0x26c5178c,0xaec60033}},	//   _zoal, _nézn, _oslo_, _збол
  { {0x8f9b00b2,0xdb1c001c,0x9f7b000a,0x0f7b000a}},	//   _ציטי, _març, _מניח, _מריל
  { {0xa9c50033,0x427a004c,0x75f50030,0xdb0f0046}},	//   ксік, פאנג, _fázi, ádát
  { {0xb05b00c0,0x7a3800dc,0x2be0000b,0x4c67006b}},	//   lvär, kítv, नादा, _пиян_
  { {0xfaa61006,0x3c340123,0x8d76002b,0xa01b0123}},	//   _паго, rävs_, _تاگا, vsök
  { {0x8f9b0053,0x4df4005d,0x6458178d,0xb05b07c2}},	//   ליסי, _इकाई_, _rivi, nvär
  { {0xb5aa0029,0xc1ca005d,0x69e20046,0x28c7000b}},	//   سابك_, ियोग, áteč, लिखि
  { {0x76590176,0x28160015,0xdb1c0006,0x64bc000b}},	//   _diwy, _كورس, _enrô, ्टेश
  { {0xa01b01d1,0x61ed0375,0xc3390046,0xb05b0123}},	//   rsök, _soal, číná, kvär
  { {0xa01b00c0,0xb355002b,0xb05b008c,0x6458178e}},	//   ssök, نیها_, yväs, _vivi
  { {0x2d821007,0x85760015,0x753d002a,0xb05b0123}},	//   _neke_, _أدائ, ższa, dvär
  { {0xf1d6000b,0xb05b0fd8,0xf1a40033,0x60f8004a}},	//   धाजन, evär, ырэн, еняя_
  { {0xdb1c178f,0x7ee702ed,0x0000006a,0x0000006a}},	//   _garç, нцбе,   ,
  { {0x2266002a,0x7a380030,0xc7d7000a,0x61ed1790}},	//   ótką_, lítu, עולי_, _toal
  { {0xe9ff0092,0x433b0008,0xbddb0152,0xbdd50063}},	//   _phận_, _מעוב, _thèm, ъобщ
  { {0x4c941791,0x7d55006b,0x5d5516b2,0x673a001a}},	// [25b0] литс, твах, ткат, _lytj
  { {0xb603002c,0xbd440015,0x5c0402a3,0x9b950058}},	//   čšin, انكي, ляха, ئلات
  { {0xa01b00dc,0xda780010,0xb05b1792,0x62a400bf}},	//   kröz, еяч_, sväs, _úroč
  { {0x61490024,0xe9ff0092,0x8a940015,0xfaf00015}},	//   _tūlī, _thận_, اؤلا, حثك_
  { {0x28f80036,0xf09f0144,0xfd440033,0x69cb1717}},	//   нець_, nuà_, _бэрн, rdge
  { {0xd8b80015,0x307c004c,0x907c004c,0xd9420054}},	//   عدنا_, לאדנ, לטדי, јеши
  { {0xa01b0012,0x38a91793,0x98c10061,0x9782002b}},	//   rsöh, súr_, ısız_, شینه
  { {0xb606016f,0x7ae300f2,0xa91d0085,0x660d006f}},	//   ješć, äntu, _vežb, ďako
  { {0xdb1c0064,0xf1bf002c,0xc5680015,0x0000006a}},	//   _parç, deá_, رحيل_,
  { {0x75f5099c,0x39140010,0xf09f0144,0xd5d10065}},	//   _názv, _смур, duà_, _दोरज
  { {0xfbd20008,0x98140015,0xf7700015,0xb05b0123}},	//   בתי_, _إبقا, _طال_, yvär
  { {0x7a3800dc,0x3f85002e,0x151500a4,0x216a004a}},	//   sítv, ðlun_, _идея, ьими_
  { {0x7a3800dc,0xe44e006b,0xd12f0015,0x73c50015}},	//   pítv, _вж_, ْمُ_, _ليشم
  { {0x35a7005d,0x505902a3,0x889a000a,0xe29901e1}},	//   _गाड़, ешся_, ובשי, _жак_
  { {0x2d821794,0xb05b00c0,0xf772000a,0xc7b2004c}},	//   _peke_, tvär, שקל_, ױבן_
  { {0xf1bf002d,0xc692039e,0xdd920015,0xc1060021}},	//   ceá_, יאל_, شوط_, _لوبي
  { {0xd24f0029,0xb05b00c0,0xa00a0029,0x4d630036}},	// [25c0] _بني_, rvär, _يقبل_, ркув
  { {0x395f017e,0x2d8200dd,0x0e6616b0,0xb05b03a4}},	//   _agus_, _weke_, _икон, svär
  { {0x9ad50036,0xbad50010,0x7a380030,0x2d821795}},	//   люці, ліцы, zítu, _teke_
  { {0x38c8002b,0xd910002b,0xb05b0012,0x20181796}},	//   فاتی_, میز_, nwän, liri_
  { {0x718d004c,0x20180125,0x18671797,0x8b660040}},	//   לװאַ, oiri_, вачи_, _لازم
  { {0xe9ff0023,0x6d461798,0x38330033,0xd7ef0015}},	//   _phản_, _izka, анір, يكن_
  { {0xcac70175,0x86c30040,0x2ca01799,0x2018007c}},	//   _игре_, ليون, luid_, iiri_
  { {0xceb3000a,0x60d60034,0x2018179a,0x66030004}},	//   ׁיו_, _orym, hiri_, ипја
  { {0xe4e60036,0x2018179b,0x2ca0007c,0xb6060085}},	//   тійн, kiri_, nuid_, vešć
  { {0x2018003f,0x33740033,0x2249179c,0xe9ff0016}},	//   jiri_, ыгор, _shak_, _thản_
  { {0xf2c307de,0xd5a4002b,0xb05b0012,0x32fc0016}},	//   асян, _ملای, fwän, ủy_
  { {0x2ca00020,0xdb150057,0x2018001a,0x25bf0045}},	//   kuid_, _nazý, eiri_, ceul_
  { {0x7a3800dc,0x2018179d,0x249f00da,0x64a30033}},	//   líts, firi_, cuum_, _вача
  { {0xdb17001c,0x2ca00111,0xc953000a,0x60d6179e}},	//   nexã, duid_, ימר_, _drym
  { {0x0d670063,0x7a3800dc,0xbe880080,0x6602179f}},	//   възм, níts, ксте_, _klok
  { {0xd3570008,0x4357000a,0x443e17a0,0xa91d17a1}},	//   _בשוק_, _בסול_, llt_, _leža
  { {0x6abb000b,0x201817a2,0x443e17a3,0x60d617a4}},	// [25d0] ईब्र, biri_, olt_, _grym
  { {0x91a00023,0x25bf0011,0x2bbb0015,0xe04b0015}},	//   _thị_, zeul_, بارة_, _تشبه_
  { {0x49750001,0x940b000a,0x61fd0091,0xf813002b}},	//   глес, וּאֵ, oksl, یستگ
  { {0x443e018b,0x5efa0008,0x0a940036,0x7a3800dc}},	//   hlt_, _נפרד, рацю, díts
  { {0x61fd0007,0xa91d002c,0x693417a5,0x5d9a00f3}},	//   iksl, _beža, анцу, _אברה
  { {0x443e00dc,0x660217a6,0x16a9023b,0x0000006a}},	//   jlt_, _alok, евки_,
  { {0x7a380014,0xb6590036,0x099b0015,0x2be0000b}},	//   gíts, нших_, _يضرب_, नारा
  { {0x2018003f,0x36180010,0x443e17a7,0xa01b01d3}},	//   ziri_, кцыю_, elt_, csöv
  { {0x644a002d,0x998f0046,0xd5e80015,0xdce4003d}},	//   _bhfi, logů_, ضعين_, ociā
  { {0xdce40048,0x660217a8,0x249f0020,0x0478002b}},	//   nciā, _elok, ruum_, کلیک_
  { {0x66020084,0xf772000a,0x201817a9,0x7a3817aa}},	//   _flok, _הקב_, viri_, pítt
  { {0x60d6002a,0x660201c2,0x07080015,0x443e17ab}},	//   _prym, _glok, _جيمي_, alt_
  { {0x25e0014e,0x657b064e,0x201816a8,0xca1a000a}},	//   कारी_, mbuh, tiri_, תֵיכ
  { {0x04920029,0x6602005c,0xc3050015,0x23290aed}},	//   _الوح, _zlok, _مبعو, _поли_
  { {0x2018000c,0x7f190127,0xce34002b,0x539a000a}},	//   riri_, віту_, لوسک, _טיסו
  { {0x2ca00020,0x2018003f,0xd6cf0036,0x7c3e0079}},	//   tuid_, siri_, стi_, wlpr
  { {0x271f000b,0xe1f2002b,0x75f50030,0x7a380030}},	// [25e0] यपुर_, _نسک_, _házs, zíts
  { {0x207b0053,0x307b000a,0x6d460046,0xb05b0012}},	//   _ראיא, _ראינ, _vzka, nwäl
  { {0xda65003b,0x657b0035,0x1c39005e,0x99f6005e}},	//   لاني, kbuh, тять_, ляді
  { {0x53360053,0x6e9b0008,0x7e9b0008,0x7a3800dc}},	//   אנען_, _אבטח, _אסטו, víts
  { {0x46140086,0x2ca017ac,0xddc4002a,0x248d08d0}},	//   یوتر, quid_, rmiń, jsem_
  { {0x409b000a,0x3157000a,0xd7e7006b,0x9847006b}},	//   תבסס, אינן_, лмче_, ляща_
  { {0xdcfd0024,0x25e0000b,0x7c2b0324,0x66020d84}},	//   _iesā, काली_, égre, _plok
  { {0x3f8a003f,0x443e059b,0x7a380030,0x657b02f2}},	//   habu_, wlt_, ríts, gbuh
  { {0xa91d0582,0x7a38084c,0x248d00dc,0x7bce17ad}},	//   _teža, síts, gsem_, _kabu
  { {0x78a202d7,0x69c20026,0x03f80001,0x439400d7}},	//   muov, leoe, тној_, јанс
  { {0x8c370008,0x7bce03ac,0x3f85001a,0x248d17ae}},	//   רטיס_, _mabu, ðlum_, asem_
  { {0xcb13000a,0xeac7000a,0x5b57004c,0xdb1c0125}},	//   מלת_, נִי֙_, טשין_, _barú
  { {0x61fd17af,0x78a201e0,0x0000006a,0x0000006a}},	//   rksl, nuov,   ,
  { {0x7bce17b0,0xdcfd003d,0x138a0015,0x3f85001a}},	//   _nabu, _nesā, _أخشى_, úlu_
  { {0xb7db0053,0x68f9002a,0x8ca7000b,0x3219096c}},	//   עקלי, zywd, टूनो, pisy_
  { {0x7bce0035,0x6fde000b,0x78a20bf6,0x518717b1}},	//   _aabu, माउं, kuov, _сука
  { {0x3f8a000c,0x80270086,0x9c39000d,0x69c2169b}},	// [25f0] babu_, _مردم, впат_, deoe
  { {0xa91d002c,0x3f150036,0x26e4005d,0x6e2416ad}},	//   _bežn, _вдос, _कपूर_, anib
  { {0xdb1502c1,0xdce40024,0xd7f10092,0x2bb80015}},	//   _razó, rciā, _rõ_, طالة_
  { {0x2a980015,0xd337000a,0x0d64006b,0xdb150077}},	//   ائلة_, נראה_, _гърм, _sazó
  { {0x417c000a,0x2259013f,0xc4c60015,0x7bce17b2}},	//   תנדב, írky_, _بْ_, _fabu
  { {0xb8cd014e,0xe8f8008f,0xdb1e00dc,0x248d1259}},	//   _कम_, ылі_, zepé, vsem_
  { {0xdd2f0046,0x75fc0030,0xe1ff0030,0xd5e5009b}},	//   věřo, _kézh, kkó_, ижки
  { {0x86450054,0x06b8002b,0x7bce17b3,0x78a20069}},	//   јниж, انيک_, _zabu, buov
  { {0xccf20053,0xdb0500b8,0xf429045f,0x44620088}},	//   ַכט_, gehö, коил_, овыв
  { {0x68f600f2,0xa01b008c,0xddd50030,0x248d17b4}},	//   äyde, isös, iszű, rsem_
  { {0x248d17b5,0xb05b0012,0x657b02f2,0x232917b6}},	//   ssem_, rwäl, pbuh, тони_
  { {0xc1060029,0xa06a17b7,0x3f8a003f,0xf8a70029}},	//   لوجي, кама_, wabu_, ية_
  { {0x3f8a000c,0xa8790053,0x95c40015,0x3eb10012}},	//   tabu_, כאָר, _دينه, etzt_
  { {0x8fa60083,0x7d0d005c,0x661b0a6f,0x15180015}},	//   јаве, dzas, liuk, _حزمة_
  { {0xa2250074,0x3f8a0f58,0x539a000a,0x7bce17b8}},	//   _گروه, rabu_, _סיקו, _rabu
  { {0x3f8a003f,0x75f501c0,0x644117b9,0x661b17ba}},	//   sabu_, _zázr, llli, niuk
  { {0xed5a0083,0xddd500dc,0x42530015,0x7c660015}},	// [2600] тоа_, gszű, _بنير, شاذل
  { {0x9b850029,0x4f960c5b,0x60c90061,0x64410034}},	//   مؤمن, _триу, çeme, nlli
  { {0x4f9b0008,0xbf9b00a3,0x9f9b000a,0xc966042d}},	//   _בביצ, _בייש, _בסיפ, авей
  { {0xe8fa00d8,0xbcfb0030,0x4a730015,0xdca60317}},	//   кле_, _igén, زُهر, _ками
  { {0x18b8008f,0x7d0d005c,0x8d630036,0x7fe90086}},	//   углы_, czas, _євре, _شریف_
  { {0x48130036,0x660905ff,0xa91d0b28,0x9b890067}},	//   оміс, ehek, _težn, _مخفف_
  { {0xddc40024,0x290014c4,0x2cb217bb,0xcf93000a}},	//   rmiņ, šia_, ltyd_, קטה_
  { {0x64410c8d,0xa01b00c0,0x75fc0030,0x2b470061}},	//   elli, nsör, _kézi, ünce_
  { {0x186a0036,0xda5b000a,0xa99b000a,0x2cb200aa}},	//   _рази_, _יכלל, _שבמר, ntyd_
  { {0xe9ff0023,0xf36603f1,0x69080064,0x6609007c}},	//   _phần_, штин, ırdı, ahek
  { {0x7bd900b2,0xa3c5005d,0x32660180,0x5334018d}},	//   אַרק, उज़_, јтов, сент
  { {0xd5b00086,0x6609003f,0x9f58002d,0xe6120015}},	//   _رفت_, chek, bhrú_, _بشئ_
  { {0xba57000a,0xa5650015,0xa91d0046,0x6474004a}},	//   יסטו_, _ادمن, _nežl, _углу
  { {0xe9ff0092,0x33170086,0xfe730031,0xe3af0015}},	//   _thần_, ازید_, قدر_, _قرى_
  { {0x54390053,0xadbd0010,0x229400a2,0x3a260111}},	//   _געװא, навi, _البس, knop_
  { {0x735b000a,0xd35b000a,0x9f34005e,0x2cb200aa}},	//   _בכוח, _בדול, цесі, ftyd_
  { {0xb478000a,0x7c87056d,0x25e7000b,0x7c970015}},	// [2610] רָֽי, рубе, झाती_, ؤشرا
  { {0x60cd166f,0x7d0d002a,0x113c000a,0xab980015}},	//   _isam, rzas, _בתחל, لخمر_
  { {0x9e3507be,0xe0540015,0xdce70061,0x7d0d1116}},	//   _генч, _بخيب, ılıd, szas
  { {0xa2d7005d,0x0000006a,0x0000006a,0x0000006a}},	//   यित्,   ,   ,
  { {0xe9ff0023,0x01fc004c,0xdcfd0045,0x4911000b}},	//   _nhấn_, כפאל, _desă, _देखो_
  { {0x60cd003f,0xed56000a,0x8d5a000a,0xf09f17bc}},	//   _msam, _לברר_, _תכשי, irà_
  { {0xfeca0053,0xaa940477,0x66090db6,0x79a70004}},	//   ָמפּ, _мирч, thek, _врзе
  { {0x9f58002d,0xc48506a6,0x60cd09cb,0x9a840054}},	//   thrú_, блик, _osam, _фурл
  { {0xf795008f,0xe9ff0016,0x6609008c,0x60cd001a}},	//   _газэ, _chấn_, rhek, _nsam
  { {0xf7700029,0xf09f1732,0x22830030,0x840517bd}},	//   _قام_, drà_, tűk_, спож
  { {0x7c220152,0x15b90010,0xd7f817be,0x60cd17bf}},	//   éori, _былы_, _тут_, _asam
  { {0x0000006a,0x0000006a,0x0000006a,0x0000006a}},	//     ,   ,   ,
  { {0x89da0008,0x80260015,0x7bc517c0,0x3123005e}},	//   אחרי, مرسم, kehu, здяг
  { {0x43850029,0x653a0053,0x249f0134,0xa936000a}},	//   _الثق, _גענד, mrum_, מטרה_
  { {0xd138005c,0x60cd17c1,0xf09f1732,0xc2c80021}},	//   łą_, _esam, arà_, _نبيل_
  { {0x629c0024,0xf09f0251,0x8d660033,0x249f17c2}},	//   šroc, brà_, свае, orum_
  { {0x4d4a0001,0xee370010,0x249f00c0,0xf6520135}},	// [2620] упан_, ёну_, nrum_, לצל_
  { {0xf1bf002f,0x2cb200dd,0x249f001a,0x7a150091}},	//   nnán_, rtyd_, irum_, mąty
  { {0x7ed5005e,0x7c2b0140,0xdce4002a,0x249f0061}},	//   _діяч, égra, dcią, hrum_
  { {0xf1bf002d,0x9b960086,0xc3320008,0xdb0700dc}},	//   hnán_, _گلست, הוב_, émár
  { {0xadd7000a,0x5e57004c,0x98a3023c,0x2d8017c3}},	//   _הוכח_, _ליטע_, зиче, mbie_
  { {0xdb1e0014,0x2bb70089,0x4c350033,0xda6600c3}},	//   lepí, _věcí_, _дэст, _هاري
  { {0x2d80005c,0x66740086,0xdb0e00f2,0x1a7800f3}},	//   obie_, زگار, äjän, _כְּמ
  { {0xe5c60892,0x443c002e,0xe9ff0016,0x249f001a}},	//   сско, _skv_, _phấn_, frum_
  { {0x8cdb005d,0xdce4002a,0xb906123a,0x7afe1419}},	//   नियो, bcią, _узак, lypt
  { {0x600b0064,0xf09f04ed,0x94730015,0x75fc0030}},	//   _küme, vrà_, أديا, _nézv
  { {0x61f617c4,0x7c3b05bd,0x60cd008c,0x249f17c5}},	//   _boyl, רגיז, _ssam, arum_
  { {0xf09f17c6,0x64a61006,0x201a02b9,0x44220030}},	//   trà_, _гада, _ampi_, ők_
  { {0x339402bf,0x763b0053,0x44fa002b,0xf09f0144}},	//   _далё, _געאג, _حراج_, urà_
  { {0xf09f02d7,0x3e6e0089,0x61e40026,0xa8ab0008}},	//   rrà_, _být_, _enil, נֹכִ
  { {0x32b70015,0xa3c5000b,0xb698004f,0xe3b0009a}},	//   _هدية_, उजर_, יֹּת, _فرژ_
  { {0x60cd00ec,0xd251002b,0x5eb4004a,0x93250067}},	//   _tsam, _تنب_, яйст, _برهن
  { {0x7bc505c7,0x60cd17c7,0xa2d0000b,0xdfd50033}},	// [2630] tehu, _usam, धिक्, _допы
  { {0x43780008,0xbddb0152,0x7b6702bf,0xdcfd0091}},	//   שְּׁ, _chèr, стае, _nesą
  { {0x2ca00005,0xb9950087,0xeb4b0cfe,0x2d8017c8}},	//   arid_, قلاب, учак_, bbie_
  { {0x314b000a,0x2bc7000b,0x0a580015,0x2ca017c9}},	//   ְתַּ, रजहा, مؤنث_, brid_
  { {0xb05b002c,0x38ca002b,0x75fc0030,0x37891377}},	//   dväz, لاوی_, _jézu, абло_
  { {0x4cba0053,0xbddb0003,0x249f0123,0x86991092}},	//   _דזשו, _thès, vrum_, атит_
  { {0x32090717,0xa3be000b,0xb05b0012,0x05da000b}},	//   _olay_, ुजन_, rwäh, _मोहब
  { {0xb05b00b8,0xf1d9000b,0x46490004,0xa5f60054}},	//   swäh, _बोलन, јзин_, жећу_
  { {0xc7ab0086,0xdb1e0011,0xd8740015,0x37c50015}},	//   _مدال_, cepâ, _فالب, _ويرف
  { {0x320904a7,0x24520002,0x387d0034,0x61f60f0a}},	//   _alay_, ونيس, mpwr_, _soyl
  { {0x2d80005c,0x8c1a000a,0x9735002b,0x249f17ca}},	//   ybie_, שותי, _بکشا, srum_
  { {0xcad60008,0x2d8b0085,0x320917cb,0x8236006e}},	//   קורת_, _nece_, _clay_, ترخا
  { {0xa06a17b7,0x628e00dc,0x05740018,0xf3f10015}},	//   рага_, ábor, _راند, _يأت_
  { {0xee3f002c,0xc4f80015,0xa3d40033,0x602602a3}},	//   _aký_, _دعما_, _ночч, ідва
  { {0x8d760015,0x50431715,0x9e050065,0x72360058}},	//   قاءا, ферб, रसंघ_, _وربط
  { {0xf1bf0030,0xac86027a,0xbcfb0030,0x2ca017cc}},	//   nnál_, жгал, _igéj, trid_
  { {0xee37042b,0x2d800d74,0xbddb0003,0x2d8b0085}},	// [2640] іну_, rbie_, _chèq, _dece_
  { {0x8b260010,0xa91d00bc,0xeaba006b,0x2ca017cd}},	//   одзе, _težj, ийз_, rrid_
  { {0x2d8b04ed,0xf1bf00dc,0x38b20026,0x611c003d}},	//   _fece_, knál_, wâr_, sālī
  { {0xa3d5005d,0x752f005c,0x2d8b0064,0xb2ba004c}},	//   ाएँ_, żczy, _gece_, ימער
  { {0xf1bf0030,0x0000006a,0x0000006a,0x0000006a}},	//   dnál_,   ,   ,
  { {0xec340086,0x2d8b0011,0xd6d000e6,0x3857002b}},	//   _روزگ, _zece_, فقت_, يشود_
  { {0x6fad000b,0x8a0601f3,0x41aa000b,0x5fb2000b}},	//   _जासू, _дзве, _कांस, _जानल
  { {0x1637040b,0x7ae10014,0xd5b7091c,0x93bc0045}},	//   يسية_, _álta, ось_, rnăm
  { {0xa3d5005d,0x442a0001,0x05950086,0xd884002b}},	//   ाएं_, ицом_, سايگ, _رهای
  { {0x22400014,0xb8060067,0x320900da,0x344a0b1e}},	//   _akik_, _ببره, _slay_, јчин_
  { {0xe73a0036,0x320917ce,0x7982002a,0x53f70058}},	//   _теж_, _play_, obow, تريح_
  { {0x601000c0,0x80ac000b,0xb05b0123,0xf1ab00c3}},	//   _jämf, _जमशे, lväx, جاده_
  { {0xd258008f,0xf9930008,0xddcd005c,0x2d8b0045}},	//   юць_, ורר_, ymał, _rece_
  { {0x600b0020,0x2a640a1c,0xb4d6000b,0xb05b0123}},	//   _sümb, _limb_, ाटी_, nväx
  { {0x28d1014e,0xed8b0124,0xd678000a,0x65790003}},	//   _दैनि, исак_, מָּכ, _éché
  { {0xdb1c00b8,0x12770015,0x51f40015,0x9c650015}},	//   _darü, _بحوث_, _يسير, كهرو
  { {0x69c6002e,0x31690030,0x9b6b011e,0xb05b02dc}},	// [2650] _ókey, _igaz_, ашеа_, kväx
  { {0x9f58002e,0x2bb80029,0x9c470010,0x3a3f12b8}},	//   skrá_, قامة_, іхал, _skup_
  { {0xa91d10ca,0x2a6401c2,0x2bac000b,0x78a217cf}},	//   _težk, _bimb_, _चारा, erov
  { {0xbda70015,0x3f910085,0x78a201df,0x25da000b}},	//   _بحدو, lazu_, frov, _खोली_
  { {0xe9d80010,0xcd760053,0xdb15001c,0xdb1c17d0}},	//   ўкі_, _מערק_, _razõ, _baró
  { {0xf7710e85,0x46f50063,0xacfa000a,0x907c000a}},	//   رات_, зчит, _ההשכ, סטוי
  { {0xf1bf0030,0x1ab407d0,0x46a50239,0x78a217d1}},	//   tnál_, _обря, чайв, arov
  { {0xdce4002a,0x78a20787,0xbae40015,0xc4850de9}},	//   ecię, brov, _تكفي, плик
  { {0xdb1c002d,0xe525005e,0xad9b0125,0xf1bf0d46}},	//   _faró, ядип, _clúi, rnál_
  { {0x43740036,0xa91d17d2,0x28c0000b,0xf1bf0030}},	//   муют, _neži, _एहति, snál_
  { {0x7bd517d3,0x3f9e001a,0xf1bf0030,0xe2990054}},	//   _mazu, ótum_, pnál_, љам_
  { {0xdb1c005c,0xcb12000a,0xb6ba000a,0xad9b0125}},	//   _zaró, תלט_, _לצעי, _flúi
  { {0x2bac005d,0xa91d049f,0xad9b0125,0x0ef6000b}},	//   _चाला, _beži, _glúi, ीन्स_
  { {0xdb0500dc,0xd47a0008,0x0478002b,0x3f8c006f}},	//   eghí, _האסל, _بلوک_, údu_
  { {0x25ad17d4,0x7982002a,0x78a2006f,0xd37a000a}},	//   ogel_, ybow, zrov, _פרקט
  { {0x386d00dd,0x12fa000a,0x9f630046,0xe9ff0016}},	//   _ouer_, _להצב, ívám_, _thẹn_
  { {0xed57000d,0x7bd517d5,0x7f7601b0,0x75fc0030}},	// [2660] зот_, _bazu, _нунц, _kézr
  { {0x7bd504f9,0x2137000a,0xef94002b,0x1c430133}},	//   _cazu, _מטפל_, _زیرد, енум
  { {0x6ffb000a,0x7bd50012,0xf1bf0046,0xd910002b}},	//   _הפיג, _dazu, znám_, چیز_
  { {0x38c80086,0xdb1e0144,0xd910002b,0x78a217d6}},	//   قاتی_, repà, نیز_, trov
  { {0xdce4005c,0x2d92003f,0x98730033,0x7bd501c2}},	//   ycię, maye_, еліц, _fazu
  { {0x660b007c,0x7bd50045,0x69dd001a,0x25ad17d7}},	//   _algk, _gazu, _ósen, egel_
  { {0x78a20046,0xb05b0123,0x386d0383,0xdb1c0077}},	//   srov, rväx, _euer_, _varó
  { {0x25ad00dc,0xddcf0011,0x78a20901,0x35b3006b}},	//   ggel_, _micş, prov, ебър
  { {0x0ee9000b,0xb3ea0015,0x85730015,0xb4460033}},	//   _ऑप्स_, معدل_, رديئ, зэнк
  { {0xb8650029,0xd7760015,0xdb1c0003,0x9cd7000a}},	//   _قالو, _رائع, _abré, לופה_
  { {0x0bb70008,0x60c40007,0x2d9d005c,0x877b000a}},	//   הלים_, _apim, ówek_, _האבי
  { {0x60990015,0x0000006a,0x0000006a,0x0000006a}},	//   ينجس_,   ,   ,
  { {0x2d92000c,0x463b0053,0x3f910107,0x5fe7005e}},	//   daye_, _פעדע, tazu_, півж
  { {0x54530036,0xa3e3021e,0xf487002b,0x644f0003}},	//   _звіт, _पोप_, _راهی, ïcit
  { {0x69c0032c,0xb3bb0008,0x645a002e,0x7bc30020}},	//   _obme, _המוכ, mmti, õnum
  { {0xfbd30086,0xc27b0008,0x443e17d8,0x77fa000b}},	//   کتر_, _פרחי, lot_, ्सुक_
  { {0x423801e4,0x1df80080,0x442c17d9,0x2d580a61}},	// [2670] _מנהל_, четы_, ond_, зить_
  { {0x443e0048,0xf09201e4,0x69c00012,0xdde00046}},	//   not_, _שני_, _abme, ětše
  { {0x645a0cdd,0x2d9217da,0xe7f0000b,0x442c17db}},	//   imti, baye_, चाना_, ind_
  { {0x7bd5003f,0x99a80029,0xa2a4005d,0xd337000a}},	//   _wazu, كُمْ_, _किन्, הרבה_
  { {0xddc401e2,0x89370029,0x386d17dc,0x5c740010}},	//   lmiş, أعضا, _quer_, _плят
  { {0xd366003b,0x443e0048,0x7c3e04ed,0xfeb8002b}},	//   _له_, jot_, copr, _بایت_
  { {0xddc40064,0x629c00dc,0x443e17dd,0x6e2d03b0}},	//   nmiş, árol, dot_, onab
  { {0x386d0003,0xceb4004c,0x442c15fc,0x644817de}},	//   _tuer_, גיק_, end_, eldi
  { {0xda340080,0x443e17df,0x629804ed,0x69cb17e0}},	//   _четы, fot_, _avvo, mege
  { {0x04560029,0x2d92003f,0x69cb17e1,0xe4590033}},	//   ولية_, zaye_, lege, ўжо_
  { {0x69d90026,0xdb1c002e,0xd1ca0bb9,0x69cb016b}},	//   odwe, _jarð, олне_, oege
  { {0x7ae300f2,0xddcd003d,0x07080015,0x644817e2}},	//   änty, lmaņ, _عيني_, aldi
  { {0x6e2d0026,0x2004001c,0x69cb0012,0x76490061}},	//   dnab, êmio_, iege, mley
  { {0x94740029,0x764917e3,0xe7f0000b,0x443e17e4}},	//   _أدنا, lley, चाया_, cot_
  { {0x7f43005f,0x42d5005e,0x023a0015,0x7c3e17e5}},	//   верж, _цілу, _وثبت_, vopr
  { {0x6e2d0084,0x764917e6,0x765b0061,0xa3d5000b}},	//   gnab, nley, nmuy, ाएक_
  { {0x40950010,0x3eaa0011,0x60c4003f,0xf55a004c}},	// [2680] _прэт, subt_, _upim, ַדעמ
  { {0x6faa0029,0x600b007c,0x2d920003,0x6d46013f}},	//   _بهدف_, _hümn, saye_, _vyka
  { {0x764901e2,0x600b0020,0x6d46005c,0xe9da0a61}},	//   kley, _kümn, _wyka, жке_
  { {0x69cb17e7,0x443e17e8,0xb9260115,0x6b8e17e9}},	//   gege, zot_, وفاي, _webg
  { {0x442c17ea,0x644317eb,0x644817ec,0x7c3e17ed}},	//   ynd_, _okni, yldi, popr
  { {0xdb1c0084,0xebf4000a,0xd6b4006b,0x93bc0045}},	//   _farð, _אֶֽת_, ейкъ, lnăv
  { {0x6b630010,0x76490064,0x7d0401a0,0xbb460004}},	//   _акра, fley, lyis, _цевк
  { {0xceb3013a,0xf1bf00dc,0x442c0026,0xb05b00b8}},	//   דיה_, rnák_, wnd_, nwär
  { {0x64a3000d,0x26c50020,0x443e17ee,0x2cfb004c}},	//   вања, _eplo_, tot_, ַלטא
  { {0x442c0708,0xb05b0012,0xa2f4004a,0xb902000b}},	//   und_, hwär, епоч, धि_
  { {0xe57a008f,0x442c05f7,0x443e17ef,0xd5af1411}},	//   _дзе_, rnd_, rot_, _ис_
  { {0x7d04022d,0x20ca005d,0x6596002b,0xdddc0046}},	//   kyis, िबंध, _آجار, dprů
  { {0xc1050029,0x443e17f0,0xdb1e007c,0xc5130015}},	//   روسي, pot_, lepä, _لبوت
  { {0xddc40064,0xa294042b,0xdb1e016e,0x7d16002a}},	//   tmiş, _закі, cepç, dzys
  { {0x629500dc,0xd0100015,0xb05b0012,0x69d90034}},	//   ázot, جلّ_, fwär, ydwe
  { {0xddc40064,0xc3330008,0x600b0020,0x7c870001}},	//   rmiş, _שוק_, _gümn, дуже
  { {0xde640063,0x69cb17f1,0xdc550180,0xd904002b}},	// [2690] търп, vege, евањ, _ئی_
  { {0x76490064,0xa4b7000a,0xeb4b004a,0xbc4b0033}},	//   zley, ולמה_, очек_, ічае_
  { {0x76490064,0x764017f2,0xbf150015,0x765b0061}},	//   yley, komy, _أوجب, ymuy
  { {0x7640005c,0xdb1c002e,0xdddd005c,0xf1bf002d}},	//   jomy, _varð, _wisł, nfá_
  { {0x4e160008,0x7d16005c,0xad9b002d,0x5d7a0135}},	//   _נחשב_, czys, _dlút, _מארק
  { {0x78ab1786,0xf807005e,0x69cb17f3,0x628117f4}},	//   rugv, ьчен, sege, yplo
  { {0x76490064,0xba740015,0xcff8000a,0xcb440bb1}},	//   tley, _لاقت, וצגה_, _ахти
  { {0x6ec20065,0x24f500ce,0xad9b059d,0x0000006a}},	//   _लहसु, ечор, _glút,
  { {0x764917e6,0x3e7500c0,0x48770086,0xe7e0021e}},	//   rley, _låt_, _آدرس, _गोवा_
  { {0x62810234,0xdb1e007c,0x5285007e,0xebfa000a}},	//   tplo, bepä, нгоб, ִּים
  { {0x764902f2,0xc7d6000a,0x4a59000a,0x0ece000b}},	//   pley, _רועי_, ּדָו, _हैंड
  { {0xc049000a,0x9635005e,0x7d16002a,0x628117f5}},	//   _הז_, _янец, yzys, rplo
  { {0xa3b7005d,0xe5070015,0x65070015,0x628117f6}},	//   _छाप_, _تباي, _تذاك, splo
  { {0xb4fa000a,0x34fa000a,0x9f9b007c,0x7d04008c}},	//   _מפני, _מהנד, jääk_, vyis
  { {0x84640063,0xe7f0000b,0x92b50015,0xf772000a}},	//   _ръце, चाता_, _أحتا, רקל_
  { {0xee3a0191,0x7d04022d,0x660917f7,0xc6920135}},	//   їна_, tyis, nkek, טאל_
  { {0x4425002d,0x644117f8,0xa3b6000b,0xb05b0012}},	// [26a0] oil_, ooli, ङ्क_, rwär
  { {0x7d160050,0x113b000a,0x644117f9,0x6e24007c}},	//   rzys, _מתפל, noli, siib
  { {0x7d16005c,0xca750010,0xa3b7000b,0x61da000a}},	//   szys, вучы, _छान_, ּקְד
  { {0x6aa3002f,0xf99200e6,0x60970086,0x442517fa}},	//   ánfa, ابا_, _تنیس_, hil_
  { {0x49730010,0x644104c6,0xdb1c0125,0x2fda02f2}},	//   уліс, koli, _ibrí, _kapg_
  { {0xf093000a,0xd7e70054,0x98e30015,0x442517fb}},	//   ננו_, емље_, اكوو, jil_
  { {0x644117fc,0x0cd0000b,0x387f15ca,0x442517fd}},	//   doli, _हनुम, _etur_, dil_
  { {0xcb670010,0xdb1e0020,0x629c0024,0x2abb000a}},	//   _часе_, repä, šrok, _ממלא
  { {0xddde003d,0xdbd7007c,0xdb1e17fe,0x442517ff}},	//   _atpū, _fääs, sepä, fil_
  { {0x64410176,0xdcef0024,0x44251800,0x78660015}},	//   goli, _secī, gil_, _أدرك
  { {0xa3b6005d,0xb05b0012,0xc7b3000a,0x63a7002a}},	//   ङ्ग_, ltäg, _תבע_, ójna
  { {0x4425002f,0xdb210030,0x6441007c,0x1677004f}},	//   ail_, ütés, aoli, _נגדל_
  { {0xc05b0036,0xb5fb000f,0x489b004c,0xc5160067}},	//   зів_, _מלאכ, ּילװ, _ثبات
  { {0x44251801,0x20d60085,0xf1bf0125,0xe0df02b9}},	//   cil_, džić_, sfá_, rvò_
  { {0xdd950010,0x6f640015,0x9f34005e,0x7c25005b}},	//   кавы, ُهُم, гері, vihr
  { {0x629a115b,0x432b000a,0xe7e70065,0x93bc00d4}},	//   msto, _מֵחֲ, _टोना_, rnău
  { {0x629a1802,0x30150010,0x2ba70054,0x61ed1803}},	// [26b0] lsto, _адпр, ејев, _inal
  { {0x600b1804,0xbca40015,0x2bbb0015,0xe7e0000b}},	//   _kümm, املي, ثارة_, _गोला_
  { {0xd0110086,0x25bf00da,0xe9d9002a,0x90340015}},	//   _ملک_, yful_, _paź_, _حريص
  { {0xc27b0008,0x64410fcd,0xdbd70607,0x629a1805}},	//   פרדי, zoli, _sääs, isto
  { {0xfd96013a,0xdbd70c58,0x6441003f,0x2d89003f}},	//   _בדרך_, _pääs, yoli, mbae_
  { {0x25bf003e,0x46a50054,0x2ca90123,0x78a40030}},	//   wful_, вакв, mrad_, áiva
  { {0x25bf003e,0x44251806,0xcf2c000a,0x629a1207}},	//   tful_, vil_, ּֽוֹ, jsto
  { {0x78a4010b,0x44250b90,0xb6580010,0x2ca91807}},	//   šiva, wil_, ншых_, orad_
  { {0x34b20029,0x25bf14e6,0x44251808,0x629a1809}},	//   لميز, rful_, til_, esto
  { {0x2b9c0089,0x13090256,0x64580046,0x6441180a}},	//   mácí_, дной_, _chvi, uoli
  { {0x8bd6000a,0x4425180b,0xa856000a,0x38bb00aa}},	//   דותו_, ril_, _סיעה_, lêr_
  { {0x412a0142,0xe5e50086,0x4425180c,0x644103fe}},	//   домо_, _جزئی, sil_, soli
  { {0x660600dc,0x69db00b8,0x2242180d,0x25b600e6}},	//   ökke, _maue, rokk_, _شهود_
  { {0x2ca9180e,0x6fd50033,0x629a180f,0x69db1810}},	//   drad_, лісц, bsto, _laue
  { {0x539a013a,0xa0671811,0xdb051812,0xf852006f}},	//   _חיצו, тара_, nghä, úžiť_
  { {0xe8df0092,0x3ea5084c,0xf1bf08fa,0x02460058}},	//   _cuịa_, álta_, lián_, _جَبَ
  { {0x8e550036,0x4d660010,0x3b96009c,0x93bc0045}},	// [26c0] утрі, ткав, вјет, mnăr
  { {0x61ed037f,0x3157000a,0xaf0601e8,0xf1bf1813}},	//   _znal, _ביפן_, _апол, nián_
  { {0x69db0ecc,0x93bc0045,0x2ca91814,0x3f98097a}},	//   _baue, onăr, arad_, maru_
  { {0xfaa3008f,0x3c940086,0x2ca91815,0xa2a4000b}},	//   рацо, _میرز, brad_, _किस्
  { {0x69db00b8,0xa9670c45,0xd7fa02db,0x0000006a}},	//   _daue, вица_, дуй_,
  { {0xbcfb0014,0xdb21002c,0x629a1816,0x25da000b}},	//   _egés, štát, ysto, _खोजी_
  { {0x48ee005d,0x99860015,0xfaa60004,0x2ba4003d}},	//   _आपको_, _للأو, _јабо, rīcē_
  { {0x7f3b0008,0x76591817,0x7bdc013c,0x3f981818}},	//   ועצו, _chwy, _haru, haru_
  { {0x26030467,0x78660010,0xb05b008c,0x3f981819}},	//   _años_, _аказ, ltäe, karu_
  { {0xe3af0015,0x7bde181a,0x741400c3,0x629a181b}},	//   يرٍ_, ndpu, اودا, tsto
  { {0x04430004,0x3f98181c,0xb05b008c,0x629a181d}},	//   реќн, daru_, ntäe, usto
  { {0x92930010,0x7bdc015a,0xb0de000b,0xba9b05bd}},	//   шаюц, _laru, मिंग, וסטי
  { {0x63f60015,0x3f980034,0xd0110015,0x629a181e}},	//   _لأغر, faru_, ملح_, ssto
  { {0xc9530008,0x629a181f,0xc05801c6,0x7bdc1820}},	//   שמש_, psto, віс_, _naru
  { {0x5f941821,0xcddb0054,0x7f940088,0x6e94004a}},	//   рист, мња_, расх, ииру
  { {0x61ed06e8,0x4e180021,0xddc4002a,0xee840033}},	//   _unal, نتقد_, elił, рыро
  { {0xe3900023,0x7bdc000c,0x7d55006b,0x68e21822}},	// [26d0] _điề, _baru, увах, jvod
  { {0xdfd10086,0x600b0064,0x69db1823,0x7c14005e}},	//   _ايد_, _mümk, _saue, адує
  { {0xba740115,0x2ca90123,0x7bdc1824,0x8f19000a}},	//   لانت, srad_, _daru, _נוֹת
  { {0xc33301e4,0x601000c0,0xc9870054,0xdb0e0030}},	//   בוע_, _jämn, тужи, _abbó
  { {0x76590176,0x621c0053,0x80d9000b,0xcf27002b}},	//   _rhwy, וואק, मिटे, _سرگي
  { {0x601000c0,0x38bb00dd,0x7bdc1825,0xed580033}},	//   _lämn, rêr_, _garu, _шоў_
  { {0x8cdb005d,0x76590026,0x68e20796,0x5692009c}},	//   निको, _phwy, avod, бајт
  { {0xcf580008,0x601000c0,0x24590003,0xe8e00016}},	//   כבות_, _nämn, ième_, huột_
  { {0x9525002b,0x24590f1c,0x63a7002a,0x58d40248}},	//   دکام, hème_, ójno, _котт
  { {0x87d70031,0xe8550015,0x6b950085,0xa819000a}},	//   _جغرا, _صناد, _jezg, _אֵ֣י
  { {0xcad5000a,0xa22a0a0b,0x76590034,0x3f981826}},	//   נוֹת_, ежна_, _thwy, varu_
  { {0x62480077,0x24590003,0x3f981827,0xa2a40065}},	//   eñor, dème_, waru_, _किर्
  { {0x93bc0045,0xddc4002a,0x9567006b,0x3f981828}},	//   rnăr, ylił, _ръжд, taru_
  { {0x705600e6,0xdd2f0089,0x2a6d0012,0x2249007c}},	//   انسا, měňo, _lieb_, _ekak_
  { {0xdb1c04af,0xada60a61,0x69c20034,0x68e21608}},	//   _obrá, лавл, yfoe, zvod
  { {0x7bdc1829,0x2bc6005d,0x3f98182a,0x1ea90058}},	//   _saru, र्ना, saru_, ضافي_
  { {0xf1bf00dc,0x22980089,0xee370666,0xdd8f0015}},	// [26e0] rnát_, _týká_, унт_, ثوق_
  { {0xb05b00f2,0xd0f7000a,0x00f7000a,0x4d63182b}},	//   ttäe, _עמית_, _עזים_, скув
  { {0x60100012,0x6b950045,0x7bdc182c,0x7fd7000a}},	//   _hämo, _dezg, _varu, _גויס_
  { {0x02b60053,0x7bdc182d,0x6abe0012,0xc9850015}},	//   טלעך_, _waru, rtpf, لشهي
  { {0x984a182e,0xba170015,0xb05b008c,0xa3b30157}},	//   няка_, دينا_, stäe, टला_
  { {0xa09b0135,0xd6d00015,0xa3e3000b,0x6c360015}},	//   גיסט, ققت_, _पोल_, _إفسا
  { {0x394d003e,0x7584002b,0xb05b0123,0x8ad8000a}},	//   _eyes_, لیام, ltäc, _בַּפ
  { {0xa5bd0091,0xa6c70021,0xfa67009b,0x0000006a}},	//   liųj, اويل_, _баск_,
  { {0x27ef0089,0x75fc00dc,0xd3700015,0x99160033}},	//   ální_, _kézz, يهة_, _сьві
  { {0x1cbb0053,0x986a0015,0x9cd7000a,0x224902de}},	//   עמיע, _أحرف_, נויה_, _skak_
  { {0x2bc6005d,0xe9ff0092,0x2bf7000a,0x6354004a}},	//   र्या, _chặn_, אמין_, рвну
  { {0x54e60225,0xa2d5000b,0xdb050012,0xf1bf0046}},	//   _مستق, _बनर्, pfhö, ciál_
  { {0x3d00005d,0x75d300a2,0x6283182f,0x0000006a}},	//   ोनों_, _دينا, _etno,
  { {0x2bc6014e,0x75fc0014,0x60100012,0x24590003}},	//   र्मा, _nézz, _dämo, tème_
  { {0xaed5005e,0xce95006b,0xe1ff0030,0x6b950030}},	//   шовш, рабъ, tmód_, _rezg
  { {0x66020005,0xc1050029,0x24590003,0x52830015}},	//   _jook, _نوعي, rème_, _اليك
  { {0x82340086,0x20010020,0xcd340029,0x2bc6005d}},	// [26f0] _دروا, _tohi_, مركب, र्भा
  { {0x6602003e,0x6fb2005d,0x60cd0035,0x7d0200f2}},	//   _look, _जाएं, _ipam, äosa
  { {0xbcfb0030,0x539b000a,0xdddc0085,0xe1ff0030}},	//   _egép, גיבו, sprš, pmód_
  { {0x5efa000f,0xfde9000b,0x2bc6000b,0xf9900015}},	//   _ספרד, _ऑफिस_, र्बा, كبه_
  { {0xa9350080,0x88c40015,0x6b950061,0x200c0123}},	//   шедш, متول, _tezg, ödig_
  { {0x6010079c,0x807c004c,0x80ad000b,0xa7a600af}},	//   _näml, ענוצ, _जिने, акша_
  { {0xe5710029,0x66021830,0xc9871831,0x87d40138}},	//   يطة_, _book, _бузи, ёўшч
  { {0x7aea00fb,0x46e6006b,0x66021832,0xaa590920}},	//   æfte, рдън_, _cook, _рибу_
  { {0xf1bf0227,0xc7d9006b,0x5dc8000a,0x84590004}},	//   riál_, _имах_, אֶתְ, крот_
  { {0xe4c80029,0x89340015,0x03a50099,0x44d6002a}},	//   ابين_, _اعفا, јино, _dł_
  { {0xfbd20008,0x6602007c,0x9694005e,0xa5d50004}},	//   חתי_, _fook, _гріш, _вжеш
  { {0x016603fc,0x9732002b,0xd1c70033,0x2005001a}},	//   икно, _بکها, алюе_, ölin_
  { {0xe0d7010f,0x998f0007,0xf1bf006f,0xa5090054}},	//   авя_, logų_, ciám_, _јела_
  { {0x8e86004a,0x7f1a009a,0xa06a00af,0x0fd90132}},	//   игге, پيرز_, ђава_, льсы_
  { {0x44d6005c,0x92f60087,0xfd96005e,0x5f03023c}},	//   _zł_, _نفوذ_, ишаю, озра
  { {0xdcfd003d,0xb13a0015,0x98c5000b,0xd1ba0015}},	//   _nesē, _لأخذ_, लझाए, _شابا_
  { {0x4c850029,0x9c2606eb,0x8fa61833,0x0c2609d3}},	// [2700] مؤلف, адад, _капе, аман
  { {0x515b013a,0x309b0008,0xb09b000a,0x7aa60015}},	//   _בכפו, _ששימ, _שייר, لإصل
  { {0xdef9008f,0xf1eb005d,0xfaf60033,0xb05b0123}},	//   _быў_, _जोड़_, шчаю, stäc
  { {0xda65003b,0xb05b00c0,0xa5bd0091,0x6e9b000a}},	//   ماني, ptäc, siųj, _בבטח
  { {0x68e91834,0x6edc000b,0x5cf6004a,0x09360067}},	//   _cred, _पनडु, _тяну, جراج
  { {0xb8ce0372,0xb8fe000b,0xeef6000a,0x2d801835}},	//   _कि_, _तन_, ֹמֵר_, lcie_
  { {0x68e91836,0x8f9b0053,0x3e7c0089,0x2bc6005d}},	//   _ered, דיצי, _jít_, र्णा
  { {0x3e7c0089,0x2d801837,0x95ca0350,0x0d96000a}},	//   _mít_, ncie_, тука_, ׁכֶם_
  { {0x68e91838,0x44271839,0x3e7c0016,0x7e64008c}},	//   _gred, _bmn_, _lít_, imip
  { {0xe3b80064,0x14180015,0x2ca0007c,0x2a78007c}},	//   lnız_, ايدة_, isid_, _kurb_
  { {0x2d80066f,0xa823002b,0xf7460004,0xa01b0030}},	//   kcie_, _بکنن, _тежо, spök
  { {0x2bc6014e,0x2ca00005,0xe4e60036,0x2d80005c}},	//   र्ता, ksid_, _вікн, jcie_
  { {0x60100123,0x25a6183a,0xf8d40065,0xdce401ec}},	//   _täml, _idol_, _धनोप, gaiļ
  { {0x2d80005c,0x629c00dc,0x2ca00020,0xc7b1000a}},	//   ecie_, áros, dsid_, ּ֑ם_
  { {0x93fb0008,0xf09f183b,0x33fb000a,0x442c03b5}},	//   _בלגי, ssà_, _בהגנ, mid_
  { {0xef19005c,0x13170008,0xc104002b,0x02440015}},	//   ąż_, _כחול_, _ژويي, _وَوَ
  { {0x442c0111,0x64480201,0x8264002b,0x25d7000a}},	// [2710] oid_, oodi, _بهين, סומן_
  { {0x442c183c,0x6448183d,0x7e64007c,0x2d80002a}},	//   nid_, nodi, amip, acie_
  { {0x2bc6014e,0x68e9060b,0x2a7800da,0x2ca0007c}},	//   र्धा, _sred, _curb_, asid_
  { {0x68e9183e,0x442c183f,0x644817d1,0x2d801840}},	//   _pred, hid_, hodi, ccie_
  { {0x89a80036,0xb9c40029,0x442c1841,0x48e50bb1}},	//   рків_, تقني, kid_, солв
  { {0xcc760008,0x98f40029,0x6e2d003e,0x9695049d}},	//   _לגשת_, تثما, liab, бриш
  { {0x442c1842,0x2a78002d,0x56920054,0x3e7c0016}},	//   did_, _gurb_, пајт, _xít_
  { {0x0f380008,0x1f38000a,0xdb160125,0x68e9153c}},	//   ירוט_, ירור_, _ócái, _tred
  { {0x2d9904ed,0x68e9060b,0x64480026,0x7d0d1843}},	//   _mese_, _ured, fodi, nyas
  { {0x2d9906f5,0x33f50894,0x442c1844,0xf8ae002b}},	//   _lese_, счис, gid_, _سکه_
  { {0x249f0084,0x8c1a0008,0x2d80005c,0xddc60024}},	//   ssum_, רותי, ycie_, _likš
  { {0xc8790064,0x360400a2,0x2d991845,0x442c1846}},	//   _kuş_, _وولف, _nese_, aid_
  { {0x442c1847,0xd656000a,0xddc60085,0x3e7c0016}},	//   bid_, _פינת_, _nikš, _sít_
  { {0xaf360015,0x644805ef,0x2d80002a,0x7d0d1848}},	//   مرأت, codi, wcie_, dyas
  { {0xa8560008,0x6e2d0493,0xf772000a,0x539a000a}},	//   מישה_, fiab, לקם_, _עסקא
  { {0xf2d20053,0x2ca00020,0xddcd0064,0x82840015}},	//   _זעה_, tsid_, rmaş, _بجول
  { {0x6e360007,0x61eb002d,0x7fd6042b,0x2d801849}},	// [2720] rnyb, _ógla, _ліні, rcie_
  { {0xe0fb0008,0x2ca00020,0xb05b0f7a,0x0ba90015}},	//   _עליל, rsid_, ltän, لامى_
  { {0xd24f0086,0x2ca00020,0x329a004c,0xb6ab005e}},	//   _زنی_, ssid_, ָבנד, _змiн
  { {0x753d005c,0xceb3000a,0x6448184a,0x2d9900aa}},	//   ższy, _ציר_, zodi, _gese_
  { {0x91bb0008,0xdb1e00dc,0x64480064,0xe3b80064}},	//   רמני, lepü, yodi, ygı_
  { {0xf0930008,0x442c184b,0x98a70061,0x0000006a}},	//   לנד_, xid_, şiği_,
  { {0x6448184c,0x07a3049d,0x09e617b6,0xddc4003d}},	//   vodi, чајн, _ловн, rliņ
  { {0x442c184d,0xf1bf00dc,0xd5ba024e,0xcb37004f}},	//   wid_, riák_, уск_, _האלי_
  { {0x38cb0074,0x6934002b,0x14f40033,0x6448184e}},	//   _مالی_, _بکار, ізоў, todi
  { {0x3e4100df,0xccf3000a,0x74140015,0x7982002a}},	//   mėte_, פכת_, زوجا, lcow
  { {0x95ca0191,0xd80b0008,0x442c184f,0x51f9042b}},	//   _була_, _עִמָ, rid_, анню_
  { {0x442c0005,0x661b000c,0x64481850,0xdb1e002a}},	//   sid_, chuk, sodi, lepó
  { {0xc5f30008,0x248600c0,0x2d9902b9,0x442c1851}},	//   _מדף_, _utom_, _rese_, pid_
  { {0x2005002e,0x46dc000b,0x94bb000a,0x5f740015}},	//   ðli_, _मनाह, _עמות, كافر
  { {0x2d9902c1,0x877b039e,0xb4250031,0x59c8000b}},	//   _pese_, ראלי, _بعنو, रभार
  { {0x3e410007,0x7e550036,0xd57a000a,0x8337000a}},	//   kėte_, іває, אָ֑ר, _לאוס_
  { {0x7c970029,0x80a4002b,0x6ad1000b,0x6e2d1852}},	// [2730] إشرا, _فمين, सब्र, riab
  { {0xfbd00086,0x3e410007,0x7d0d117f,0x916d0016}},	//   فتم_, dėte_, ryas, _nổi_
  { {0x7d0d01e2,0xe37b0053,0x6d41005c,0x3ad50087}},	//   syas, ארבר, _ślad, تياز
  { {0x7d0d0064,0xb95505c4,0x9cf50033,0xb2bb004c}},	//   pyas, овещ, _дзмі, רמאר
  { {0xb23c0053,0x3e410091,0x98c70b9b,0x48ab098b}},	//   נעדז, gėte_, ссел, утем_
  { {0x6d5d0024,0xba7700a2,0x31580643,0x18691853}},	//   _izsa, _هارت, ציגן_, шали_
  { {0xb05b022d,0x3619004a,0x6fac000b,0xd6a9002b}},	//   ytän, ицию_, _जयसू, شگام_
  { {0xc485111b,0x34a90001,0x06960015,0x7bd70045}},	//   олик, авио_, آنية_, lexu
  { {0x2bc6014e,0x26de1854,0xe6160036,0xc3d50010}},	//   र्वा, _esto_, ідь_, оўны
  { {0x661b003f,0x9f6000dc,0x799b00aa,0x78a602de}},	//   shuk, űrés_, _heuw, _ækva
  { {0xb05b022d,0xd7f80092,0xe299049d,0x290f1855}},	//   ttän, _khăn_, јам_, lyga_
  { {0xcf890dab,0x04c90029,0x90c60a1f,0xd6e8004f}},	//   _יט_, _نوصي_, обме, _לַנָ
  { {0x89da0008,0x290f0091,0xb05b1856,0xdb150012}},	//   בחרי, nyga_, rtän, _abzü
  { {0xb05b1857,0x853a000a,0x04670054,0xc2c8002b}},	//   stän, _דגני, _утем, جبیل_
  { {0x7982002a,0x7bd71858,0xdee3011a,0x3f6a080e}},	//   ycow, dexu, мори, риво_
  { {0xd5f90053,0xeafa0086,0x224b1859,0xdb1e0030}},	//   ספּר, یرات_, cock_, repü
  { {0xad660074,0xce470033,0x8f76008b,0x3519000a}},	// [2740] زاره, ізуе_, _муні, בוּנ
  { {0x28b8000b,0x6b560f5c,0x7982002a,0xb05b0a64}},	//   उंसि, отех, wcow, ntäl
  { {0x61e400b6,0xfe4607be,0xab770015,0xa3b7000b}},	//   _kail, _мноо, زمنا_, _छाई_
  { {0x3e410007,0xdcfd0007,0x7db60015,0xd7f80016}},	//   tėte_, _nesė, _بصدا, _chăn_
  { {0xc7ba008f,0x8d660036,0x7982002a,0x78a20046}},	//   аёй_, _євге, rcow, usov
  { {0xacd900b2,0x2cb20176,0x3e410007,0x799b0111}},	//   _פֿרי, mryd_, rėte_, _eeuw
  { {0xa01b00f2,0xa714005e,0x28da000b,0x78a2185a}},	//   mpöt, ямкі, _मैरि, ssov
  { {0x78ad010b,0x2bc6000b,0x2bd8000b,0x6b9c185b}},	//   šava, र्रा, ड़वा, _herg
  { {0x6b9c0020,0x80da000b,0x7aee00bc,0xb7d60058}},	//   _kerg, _पैले, _hrbt, _وقرب
  { {0x61f60026,0xa91d0091,0x136a097d,0xdb1c016e}},	//   _anyl, _nežy, ишни_, _acré
  { {0xb4e3014e,0x61e4185c,0x4b7b0053,0x6b9c0939}},	//   कटॉप_, _bail, יטיג, _merg
  { {0x61e412bf,0xe693002b,0x722b033d,0x7bd70030}},	//   _cail, _آلند, рцов_, zexu
  { {0x660f0c77,0x61e4185d,0x2d92185e,0x224b185f}},	//   öcke, _dail, dbye_, rock_
  { {0xf8b3000a,0xa3b7000b,0x104b0121,0x2cb20034}},	//   ושש_, _छाए_, рями_, dryd_
  { {0x9e070036,0x61e41860,0x3ea50030,0xdd9b1797}},	//   очал, _fail, élt_, иша_
  { {0x2cb20026,0x3ead0107,0x61e41861,0x68e00046}},	//   fryd_, čet_, _gail, _osmd
  { {0xc05b0191,0xb05b00f2,0x1cb80029,0x6fb6002b}},	// [2750] _він_, ltäm, قالب_, _کمپا
  { {0x3eb800b8,0xddd6005c,0xeb900021,0xecb80015}},	//   burt_, omyś, نظم_, تطفت_
  { {0xb05b00f2,0x23c2005d,0x6a94005e,0x99f50033}},	//   ntäm, _शानद, дріє, зялі
  { {0x2cb21862,0x6b9c0079,0x600b0061,0xb05b008c}},	//   bryd_, _eerg, _gümr, itäm
  { {0x5dfa000a,0xd9450004,0x7aee0012,0x6b9c1863}},	//   _הפרנ, џели, _erbt, _ferg
  { {0x3abb0074,0xa69500d7,0x28080015,0x6d3a000a}},	//   _پاسخ_, приј, يْنَ_, _הֲלו
  { {0x99d70021,0x8f8c000a,0x4e0f000b,0x1995176c}},	//   _وترا, בְחֵ, _सवाई_, _навя
  { {0xd6ce003b,0x6b850026,0xc6680001,0x7f3c004c}},	//   اقي_, lchg, ошње_, יעוו
  { {0x6d4300b8,0x27f60089,0x61e41864,0x69d91865}},	//   ßnah, ádní_, _rail, mewe
  { {0x94220080,0x61e40376,0x787a000a,0x69d91866}},	//   емье, _sail, _הָאו, lewe
  { {0xef20005c,0x6b8500b8,0xddc4005c,0xc7c40142}},	//   ążki_, ichg, gliś, _юсти
  { {0xb05b01d1,0x61460658,0x2cb20034,0x60100123}},	//   stäl, зема, yryd_, _jämv
  { {0xf9920008,0x69d9055e,0xb05b008c,0x61e41867}},	//   ערך_, iewe, atäm, _vail
  { {0xdff50010,0xb4d7005d,0xe3b30086,0xb05b00f2}},	//   мясь, ाबी_, _آرش_, ltäj
  { {0x63a11868,0x539a000a,0x1287002b,0x26c702c6}},	//   maln, _היצו, _بمبی_, ntno_
  { {0xbc760029,0x2cb21869,0x625d0003,0xb05b008c}},	//   كهرب, tryd_, léon, ntäj
  { {0xee370036,0x5baa0892,0x721b000a,0x91bb000a}},	// [2760] їну_, йкам_, _לוקח, _המפי
  { {0xdce60048,0x26c701a3,0xe572000a,0x63a1186a}},	//   _iekļ, ktno_, גַע_, naln
  { {0x9f97000a,0x0f7b000a,0x3f7b000a,0x69cb0012}},	//   _מדיה_, _לאיב, _לאיס, ffge
  { {0x32090092,0xe8fa0892,0xc27a000a,0xe944002b}},	//   _xoay_, йле_, צרני, ورشی
  { {0x3a3f02ce,0x6b9c0049,0x63a1186b,0xddd6002a}},	//   _djup_, _terg, kaln, zmyś
  { {0xb05b00f2,0xddc4005c,0x3e410007,0x63a10f0d}},	//   ytäm, yliś, mėta_, jaln
  { {0x8c1b013a,0x69d9186c,0xbb4301c5,0xe5c6006b}},	//   _פולי, bewe, _зерк, пспо
  { {0xbb3b01e4,0xd5e20092,0xfecd000a,0xb4d7000b}},	//   _העלי, _khỏ, ׁמוּ, ाबू_
  { {0x3e410091,0xdce6003d,0x27170016,0xa98b000a}},	//   nėta_, _nekļ, ãn_, _הָבִ
  { {0xb05b022d,0x2281001a,0x63a1186d,0x7e7e02dc}},	//   ttäm, _bók_, galn, _oupp
  { {0xe1d90191,0x3160186e,0x61d9006b,0x7e7e007c}},	//   одні_, _aziz_, омня_, _nupp
  { {0xe717103d,0x63a10020,0xb05b00f2,0xa194022a}},	//   _מחבר_, aaln, rtäm, наюч
  { {0xd6250196,0xdb2300dc,0xf1a40010,0xb05b04fc}},	//   _تعلي, _örök, эрэн, stäm
  { {0x3e410007,0x988b000a,0x250b002b,0x225200aa}},	//   dėta_, מָלֵ, _درمی_, _ekyk_
  { {0xdef80010,0xa8570008,0x628a02d2,0x93770015}},	//   пыт_, פילה_, _utfo, _عصور_
  { {0xc3330008,0x433b0008,0xf1bf0030,0x5c9901b0}},	//   _רוק_, _לעוב, giát_, жкая_
  { {0x93bd0053,0x30840015,0xb05b186f,0x30a40033}},	// [2770] _אַלף_, _كليف, ntäk, _прэв
  { {0x9ce40010,0x3138000f,0x9c47005e,0x7055002b}},	//   эцсл, _מנחם_, їхал, _زنجا
  { {0x6b8500b8,0xd7f80092,0x8b670015,0x442e1870}},	//   rchg, _chăm_, سائم, _mmf_
  { {0x69cb00b8,0xeab00029,0x7c2e1447,0xf1bf016e}},	//   ufge, اعل_, _embr, ngá_
  { {0x37e503c5,0x69d9108e,0xba740040,0xf1bf0030}},	//   долг, rewe, رامت, liás_
  { {0x3cfa000a,0x9be400fd,0xacfa000a,0xf8070342}},	//   _ולשנ, _піск, _והשכ, ячен
  { {0xb05b022d,0x63a1018c,0xdb2300f2,0x66e70030}},	//   ttäj, valn, ärän, déká
  { {0x601001d1,0x63a11871,0x672300bc,0xeef8000a}},	//   _hämt, waln, rznj, למור_
  { {0x63a11872,0x26c700bd,0x93fd0010,0x03d9005e}},	//   taln, stno_, аўнi, оєнь_
  { {0xb05b00f2,0x60100123,0x7d02008c,0xd2a9004a}},	//   stäj, _jämt, äosi, окое_
  { {0x56940124,0x2bcf005d,0xeb92000a,0x96f8006b}},	//   _захт, स्या, כָר_, _нефт_
  { {0x63a1013c,0x74f90015,0xf1bf0030,0x600b073f}},	//   saln, _وفاز_, diás_, _sümp
  { {0xa5bd00df,0xe44e042b,0x6908000a,0x7e7e1873}},	//   siųs, _аж_, ִּשְ, _supp
  { {0x2281002e,0xf8b60008,0x3cf1000b,0xe46b004a}},	//   _tók_, ופשי_, ँटने_, _ушел_
  { {0x41c6005d,0x93450d7f,0x0000006a,0x0000006a}},	//   _वापस, _юнке,   ,
  { {0x25bf1874,0xdb080046,0xd5e20016,0xd2b6000a}},	//   ngul_, ílít, _phỏ, _חלקת_
  { {0xed570083,0x71fa002b,0xb5fd00bc,0xf1bf0307}},	// [2780] дот_, _هرکس_, emšk, riát_
  { {0x8d630080,0x660b0134,0x4d630036,0x1fb60010}},	//   твуе, _logk, ткув, _ўспр
  { {0x78a902d7,0xb9e60036,0x5ffb000a,0xfaa30033}},	//   _avev, діли, _והיה, вахо
  { {0xd5e20092,0xfbc9000f,0xd910002b,0xdb1e008c}},	//   _thỏ, ית_, هیز_, kepö
  { {0xd3780085,0xaa050015,0xb86a0054,0x02da000b}},	//   leće_, عظمه, ојке_, _बन्न
  { {0xd7f80023,0x368a0036,0x387f0161,0x7c2e1875}},	//   _thăm_, осин_, _duur_, _umbr
  { {0x8f9b000a,0xd5ba005e,0x7c3e0123,0x20181876}},	//   קיקי, осп_, mnpr, ikri_
  { {0x973c016f,0x8a060010,0xb05b00f2,0xd6d9005e}},	//   _neće, _ўзае, ttäk, яті_
  { {0x47c60124,0xe3ce0023,0x387f00aa,0xf8890015}},	//   _обав, _dựng_, _guur_, _فضلى_
  { {0xb8650015,0x25bf0045,0x7e6601d7,0x7c3e1877}},	//   _كالو, agul_, _lhkp, nnpr
  { {0x0bb7013a,0xe2f80036,0xfbb70008,0xd378016f}},	//   ולים_, чені_, ופית_, jeće_
  { {0xd378010b,0x0000006a,0x0000006a,0x0000006a}},	//   deće_,   ,   ,
  { {0xa3b40033,0x89eb000a,0xc516002b,0xb05b014b}},	//   _зблі, קַטֵ, _تبات, ltäi
  { {0x8ca2005d,0x0000006a,0x0000006a,0x0000006a}},	//   गठनो,   ,   ,
  { {0xadd50001,0x76870064,0xb3bb000a,0x6f640015}},	//   новљ, _kıya, _ומוכ, َهُم
  { {0x645a1878,0xf1d00092,0x601000b8,0x80da000b}},	//   llti, _hạng_, _sämt, _पैके
  { {0x5cb9008f,0x2d58034e,0x443e1879,0x9cc8004a}},	// [2790] ялаў_, дить_, ont_, дыха_
  { {0x2bbb0029,0x443e187a,0xdb26002b,0xdb1e007c}},	//   تارة_, nnt_, کومی, hepõ
  { {0xf1d00023,0x916d0092,0x387f187b,0x443e187c}},	//   _mạng_, _hồi_, _suur_, int_
  { {0x443e00b8,0xdb1c002d,0x32190177,0xddcf0045}},	//   hnt_, _gcrí, nksy_, _dicţ
  { {0x99d40029,0x1bbb00e6,0x7e6d187d,0x625d187e}},	//   ئتما, _واسع_, mmap, véol
  { {0xd3660074,0xb907005d,0x443e0111,0x7e6d0e95}},	//   _مه_, _बन_, jnt_, lmap
  { {0x7ac410b9,0x2aa80888,0xa9c715be,0xb05b0072}},	//   _исте, _отто_, _осак, rtäh
  { {0x645a002e,0xceb40632,0xb05b0020,0x387f00dd}},	//   elti, דיק_, stäh, _tuur_
  { {0x2bcf014e,0xa9540036,0x443e002e,0x79c80031}},	//   स्था, _акті, fnt_, _توقف_
  { {0xd378016f,0x7305049d,0x6932002b,0x5b79000a}},	//   zeće_, епоз, _حکمر, ּרֹא
  { {0xf1d00023,0xdb070046,0x25a40034,0xc6a40a10}},	//   _dạng_, _odjí, baml_, _арчи
  { {0x2bcf014e,0x7afa00dc,0xfb1a0008,0x2ca9007c}},	//   स्ता, _átte, פורמ, ksad_
  { {0xa155010f,0xddc40064,0xd408002b,0x64c40015}},	//   върш, eliş, ستیم_, _لينل
  { {0xdb1c002f,0x6606002e,0x201e002e,0xd437002b}},	//   _scrí, ökkv, óti_, _تعصب
  { {0x141a000a,0x2018001a,0x7d0b0123,0x20730033}},	//   _מוסב, rkri_, ägsn, улёў
  { {0x64b50064,0x42d4005e,0x20180e05,0x41a7009b}},	//   _eğiş, _рішу, skri_, _звън_
  { {0x10160010,0xd3780085,0xfe43187f,0xbc6601b0}},	// [27a0] _зьня, reće_, унто, евак
  { {0xaf9a005f,0xf5360053,0x2482002c,0x9cb30015}},	//   _этих_, ײטער_, íkmi_, املت
  { {0xb4160053,0xe803005d,0xdef90010,0x3f98031f}},	//   עקעס_, लाना_, _жыў_, mbru_
  { {0xda650029,0xe9e50036,0x0f370053,0x3a06002b}},	//   ناني, кціо, _טריט_, رکزی_
  { {0x443e1878,0xc237000a,0x629c0030,0x6e240030}},	//   ynt_, ערנו_, ároz, mhib
  { {0xb05b022d,0x39130033,0x6e240030,0xf6e60b1e}},	//   ttäi, ымір, lhib, ецин
  { {0x8c43087a,0x7d1600f2,0x7bde003f,0xcf930008}},	//   _сере, lyys, mepu, נטה_
  { {0xa7370029,0xa3d2005d,0xceb30008,0x443e1880}},	//   عثور_, ह्न_, איה_, wnt_
  { {0x6846000d,0xdb1c016e,0x288b002b,0x5fb1000b}},	//   _знаа, _ucrâ, _فصلی_, _जयलल
  { {0xb05b022d,0xe8d70008,0x916d1881,0x9c870057}},	//   ltäv, _אומר_, _nối_, lačí
  { {0xa195054f,0xfa6a000a,0x443e0380,0x68e20034}},	//   канч, ּכָּ, rnt_, lwod
  { {0x765b0467,0x68e2005c,0xb05b00f2,0x7bde0012}},	//   cluy, owod, ntäv, hepu
  { {0xf1d00092,0x6e24003f,0x6606001a,0xb05b008c}},	//   _tạng_, dhib, ökku, itäv
  { {0xb05b022d,0x251b0053,0xb803005d,0xe803005d}},	//   htäv, _צוגא, लायम_, लाया_
  { {0x66ab000a,0x6e67006b,0x916d0016,0x7f84012c}},	//   ּ֙לֶ, етаж, _dối_, الفن
  { {0x7e6d02f2,0x735b000a,0x2ca9060a,0x916d0016}},	//   umap, _מכוח, tsad_, _tồi_
  { {0xd90404b6,0x32440029,0xdb1c005c,0x02440015}},	// [27b0] _ای_, _حنيف, _obró, _حَيَ
  { {0x6e240064,0x113c000a,0x8d740015,0xff070033}},	//   ahib, _מתחל, طاقا, _зямн
  { {0x2ca900c0,0xa3d2000b,0x1eab0021,0x7640001a}},	//   ssad_, ह्य_, _عادي_, knmy
  { {0xe975002b,0xddc40045,0x5a35006b,0x6e241882}},	//   نهاد, rmiţ, ънет, chib
  { {0x6010079c,0x2604000b,0xadf40033,0xad270015}},	//   _kämp, वानी_, _спяш, _أرجو
  { {0x7bde04f9,0xec350053,0x764000f2,0xe9680010}},	//   cepu, _יאָר_, enmy, хаіл_
  { {0xb9950015,0x99850015,0x68e2002a,0x765b0061}},	//   _للأب, _للزو, awod, tluy
  { {0x601004b8,0x6447044c,0xc8f5006b,0x24f500ce}},	//   _lämp, čjim, _избъ, вчор
  { {0xe1ff005c,0x200c00dc,0x367200c3,0xa3b902be}},	//   lmów_, ödik_, جهيز, وادر_
  { {0xa934000d,0x2496002b,0x765b001a,0x972702ed}},	//   _сеуш, کنید_, sluy, _пьед
  { {0x2bc6000b,0x916d0016,0x765b0061,0x23c2000b}},	//   र्टा, _rối_, pluy, _शारद
  { {0xc049000a,0x7aea02de,0x7bde002a,0x22161883}},	//   _וז_, æfti, zepu, тфор
  { {0xbcfb0030,0xc2431884,0x0000006a,0x0000006a}},	//   _szén, рняк,   ,
  { {0xc0e307c1,0x73c4002b,0x7d16008c,0x056401f3}},	//   јорк, _ميهم, vyys, _свін
  { {0xada60036,0xb05b00f2,0x6e240410,0x6da612d2}},	//   кавл, ytäv, thib, кива
  { {0x68e20176,0x7bd500b8,0x82d6000a,0xee3a005e}},	//   ywod, _abzu, _יוצג_, єна_
  { {0x916d0023,0x6026008f,0x644100f6,0x6609016f}},	// [27c0] _tối_, _адпа, onli, ijek
  { {0x64411885,0x63a3178c,0xd3780085,0x0c231886}},	//   nnli, _jenn, leća_, амун
  { {0xb05b022d,0x2604005d,0x7d1600f2,0xfa890127}},	//   ttäv, वामी_, syys, есій_
  { {0x644100b8,0x3a20002d,0x2bc6000b,0x63a31887}},	//   hnli, óip_, र्जा, _lenn
  { {0xe3a70086,0x7189000a,0xb05b04f8,0x7bde007c}},	//   _پر_, תְעַ, rtäv, pepu
  { {0x64410111,0x63a300b8,0xb05b0ac8,0xf8630036}},	//   jnli, _nenn, stäv, авчо
  { {0x290004f9,0x45d40010,0xe2870015,0x6f080012}},	//   ţia_, гойс, _خذ_, ädch
  { {0xd378016f,0x661b0035,0xf64f0015,0xb05b0012}},	//   jeća_, gkuk, يئي_, ltät
  { {0x916d0023,0xd378016f,0xb4be005d,0x2bcf000b}},	//   _mỗi_, deća_, ुझे_, स्वा
  { {0x916d0023,0x661b1888,0xa2d4002b,0x2955006b}},	//   _lỗi_, akuk, هيخت, _съср
  { {0x628304f9,0x60100020,0xddc40263,0x8857000a}},	//   _cuno, _rämp, zmiš, _ישמע_
  { {0xd737000a,0x27ec00da,0x44250012,0x63bc001a}},	//   _בטבת_, _hadn_, ahl_, órnb
  { {0xc05b0191,0xb6350053,0x63a31889,0xe1ff002a}},	//   дів_, _גרײס_, _fenn, zmów_
  { {0x63a3188a,0xdfd8006b,0x4425188b,0xe1ff002a}},	//   _genn, къс_, chl_, ymów_
  { {0x64580024,0xe803000b,0x5f740021,0x62830045}},	//   _ikvi, लाता_, لافر, _guno
  { {0x3377013a,0xf3650036,0x63770008,0xfeb80029}},	//   _בתוך_, _стін, _בגוף_, ضافت_
  { {0xde580036,0x3949005c,0x8cf50010,0x0ba7004a}},	// [27d0] таті_, żasz_, ызац, вшем
  { {0x8bb40015,0x61ed188c,0xb05b0012,0xddc40085}},	//   لإما, _haal, ttäu, rmiš
  { {0x41a7005d,0xfe6e0086,0x63a8002c,0x61ed188d}},	//   _ख़ास, تگی_, iadn, _kaal
  { {0xc3330008,0xeab00015,0xa3d9000b,0x63a80057}},	//   סוף_, زعم_, _डॉन_, hadn
  { {0xa9540036,0x3949001c,0x6609016f,0x645801a3}},	//   акці, ças_, vjek, _okvi
  { {0xab940191,0x973c016f,0xd378016f,0xa3d2000b}},	//   _вирі, _seća, zeća_, _हॉल_
  { {0xb05b00f2,0x64410293,0xd6a80067,0x63a3188e}},	//   ltäs, vnli, نديم_, _renn
  { {0xff7c0008,0x7ada0053,0x3a260111,0x24e9009f}},	//   וטומ, _אַמה, chop_, емии_
  { {0xb05b00f2,0x66090020,0x69cc0057,0x63a31042}},	//   ntäs, rjek, ílež, _penn
  { {0xe3b1003b,0x661b022d,0x8d5c0008,0x6609188f}},	//   حرة_, skuk, וכחי, sjek
  { {0xc5d50191,0xbcfb00dc,0x8bd60008,0x63a31890}},	//   _біль, _szél, אותו_, _venn
  { {0x2604005d,0xf5590015,0x7e7d06d1,0x63a31891}},	//   वाणी_, _كلاب_, _nisp, _wenn
  { {0xf484000d,0xb05b008c,0x63a303aa,0x61ed1892}},	//   _кујн, ytät, _tenn, _daal
  { {0xc9520008,0x7e7d002d,0xb7f9000a,0x2bd8000b}},	//   צמם_, _aisp, ׂפָת, ड़छा
  { {0xb05b1893,0x61ed0064,0xa0671179,0xf1bf002d}},	//   kräf, _faal, уара_, mhán_
  { {0xd5e20023,0xc692103d,0x21280086,0x229200a2}},	//   _khó, מאל_, _ليبی_, _اليس
  { {0x4d66070e,0x8b96004a,0x2604000b,0x6d5d00e7}},	// [27e0] укав, греч, वाती_, _cysa
  { {0x309b04dc,0x69c90011,0x2bcf000b,0xab2a0658}},	//   _רשימ, _acee, स्ला, ноза_
  { {0x0af60010,0xdd12003d,0xdc75004a,0x68e91894}},	//   ычаў, _kļūt, рыть, _ased
  { {0xb05b0b14,0x63a800bd,0x1d0a0661,0xa8ea0015}},	//   stät, zadn, _земи_, فعتك_
  { {0xd5e20023,0x09360015,0xd8b70015,0x522d004c}},	//   _nhó, دراج, هدوا_, וואַ
  { {0xdd3b00b2,0xcaa60029,0x3a261895,0xcb760054}},	//   _װעלכ, _مصري, shop_, _бубњ
  { {0xd5e20092,0x63a8017b,0x1706002b,0x5694013e}},	//   _phò, vadn, افعی_, шайт
  { {0xe4e60191,0xa281005c,0x88c60015,0x63a8002a}},	//   гіон, łość_, _متطل, wadn
  { {0x39460001,0xd5e20092,0xe1ff0125,0x7c89004f}},	//   _снаг, _chó, llóg_, ֣אתִ
  { {0xc94b0008,0xf7860015,0xd4d70015,0x656f0046}},	//   _אֲבֹ, _إلاَ, ابيض_, ýcha
  { {0x2604005d,0x61ed0035,0xfc570053,0xb05b00c0}},	//   वादी_, _paal, רביש_, ktär
  { {0xa2270018,0x63a81837,0xa175005e,0x64a60513}},	//   ارده, sadn, игні, _бада
  { {0x7e7d02d7,0x61ed06c2,0x63a80787,0xb5fd10cd}},	//   _risp, _vaal, padn, rmšt
  { {0x3e4100df,0xf1bf002d,0x25a60026,0x439409d7}},	//   mėti_, chán_, _heol_, _такс
  { {0x3e410007,0xb05b00b8,0x61ed049c,0x26b40008}},	//   lėti_, hräg, _taal, יִּם_
  { {0xb05b008c,0x92b3006e,0x387e1896,0x3d950a32}},	//   ttäs, _احوا, _litr_, риар
  { {0x7e7d0048,0x3e410007,0x527c0053,0xc047006e}},	// [27f0] _visp, nėti_, _אנהא, _مخدو
  { {0x25a60026,0xb05b00c0,0x6d5d013f,0x0000006a}},	//   _leol_, dräg, _vysa,
  { {0xb05b1897,0xe803000b,0x9b440015,0x6d5d002a}},	//   stäs, लासा_, منكو, _wysa
  { {0x3e4100df,0x636f00dc,0x2bc7000b,0x98dd0033}},	//   kėti_, lóné, _लावा, дскi
  { {0x9df8004a,0x28f8008b,0x6fd2000b,0xe945002b}},	//   _снят_, лець_, द्वं, جرای
  { {0x3e4100df,0x25a900bd,0x5c070010,0x76b50001}},	//   dėti_, _žal_, _сяма, аљиц
  { {0xe6110015,0xb05b0012,0x7ceb0123,0x2fc70052}},	//   قشة_, präf, _förå, _öngu_
  { {0x25a6002d,0x04c90015,0xe6110067,0xd5e20016}},	//   _ceol_, نوبي_, تشت_, _phó
  { {0xf1bf002f,0xa5f60054,0x25a600e7,0x68e91898}},	//   thán_, рењу_, _deol_, _used
  { {0xa87b0015,0x4423002a,0x24520040,0xb4e5000b}},	//   _أحرر_, ój_, ينيس, _पनी_
  { {0x63bc0084,0xe7840086,0x316900dc,0xca35000a}},	//   órna, _المپ, _azaz_, ֹנָה_
  { {0x3e4100df,0xa4d50036,0xd5751899,0xe803000b}},	//   bėti_, _воді, _куль, लावा_
  { {0xc1e7002b,0x3d01000b,0xd12f0015,0x42550033}},	//   شکيل_, ोहों_, ِمُ_, стэт
  { {0xa06a008f,0xfaf80024,0xe3b9005e,0x0163005e}},	//   тага_, _šīm_, _рбк_, ікро
  { {0x43750053,0xbf650029,0xb05b008c,0x6e36006b}},	//   _דײַן_, مدفو, ttär, ахах
  { {0x644f0152,0x6e030015,0x42530058,0x8d760058}},	//   écif, يِّن, _ونور, لاءا

  { {0x6fd60036,0x62730029,0xa2a1000b,0x1d890015}},	// [2800] _кінц, _بهيئ, कीर्, ائفي_
  { {0xd00f0029,0x5faa000b,0x7ba50015,0xb05b189a}},	//   _يلي_, _क़िल, مصمم, stär
  { {0x5fbb000a,0x8f9b000a,0x394d0730,0x79a6027c}},	//   _בצינ, _שיטי, _axes_, арле
  { {0xb05b00b8,0x79850015,0x3857002b,0x2a6d0046}},	//   träg, مؤهل, یشود_, _cheb_
  { {0xda650029,0x2604000b,0xd794006b,0x6e260061}},	//   حالي, वासी_, билъ, _ilkb
  { {0x25a6002f,0xe917005e,0xc9d4002b,0xb05b008c}},	//   _seol_, роші_, _گمرک, ntäp
  { {0x6f1c0026,0xeab4000a,0x973c0085,0x478902a3}},	//   nyrc, _לִּי_, _većo, усім_
  { {0x6b630036,0xb05b08e9,0x8e97000a,0x998b00d4}},	//   _єкта, präg, בדקו_, ălţa_
  { {0x87da0086,0x6f1c0026,0x7bc3001a,0xd40606b9}},	//   _لباس_, hyrc, ónug, аяни
  { {0x3e4100df,0xf7e90015,0x2604000b,0xe7b30015}},	//   rėti_, _مرمى_, वाही_, _ومقد
  { {0x2338054f,0x8c1b000a,0x3e410091,0x63520046}},	//   упны_, דויי, sėti_, děné
  { {0xd2580036,0x25dd005d,0xd3770010,0x3e410007}},	//   иця_, _कॉपी_, шчы_, pėti_
  { {0x0494003b,0x067b000a,0x6abe0012,0x90a40058}},	//   _التح, _סנדל, hrpf, ْحِم
  { {0x34fb0008,0xd3a3006b,0x04db015b,0x251b0643}},	//   _שהגד, _дръп, _סקול, _בודא
  { {0x6f1c0176,0xfda70001,0x63670063,0xee870010}},	//   gyrc, ијам, _кръг_, рыго
  { {0xe37b000f,0xd37b000a,0x1609000b,0x629a189b}},	//   _ברור, _ברוט, वायर_, mpto
  { {0xb05b00c0,0xcec40089,0x786d016e,0x6abe0012}},	// [2810] träd, teří_, lúve, erpf
  { {0x2bb80029,0x515c000a,0xbca40015,0x0000006a}},	//   لامة_, _בכחו, تمكي,
  { {0x5fdc000f,0x539b000a,0x660200aa,0xb05b0b14}},	//   _יחזק, דיבו, _onok, rräd
  { {0xdb1e001a,0xca8400e2,0xdbd90061,0x497501d2}},	//   efpó, ігій, lçüd, блес
  { {0x8cf40010,0x66ec005d,0x26de16ee,0xd8e703ea}},	//   _дзяц, झिझक_, _apto_, рцеп
  { {0x1d160008,0x3eb1005c,0xb8ff000b,0x07a20a31}},	//   _הקשר_, oszt_, _तह_, пашн
  { {0x6dbb002a,0x87d40015,0x2a7f01c2,0x68420033}},	//   ałał, تغنا, _tiub_, янша
  { {0xee320008,0x656f0107,0xf9900015,0x177a02ed}},	//   ּֽה_, ýcho, _يبق_, у́сь_
  { {0xe459017a,0x0000006a,0x0000006a,0x0000006a}},	//   лжи_,   ,   ,
  { {0x98140087,0x9f4c0f1b,0x84440058,0x0000006a}},	//   _وبلا, ždé_, ْخَل,
  { {0xe7190086,0x6fce000b,0x06850015,0x68fb0069}},	//   _حيات_, _ताबू, _الصُ, _hrud
  { {0xd1ba0015,0x3f91002a,0xcf89015b,0x7a88000a}},	//   دادا_, eczu_, _טט_, יָשַ
  { {0x85050074,0x6f1c0026,0x291d0297,0x2604000b}},	//   _دوشن, wyrc, nywa_, वारी_
  { {0x33950029,0xe3b80064,0xb4fa000a,0xc2c8002b}},	//   _الغز, lkın_, _תפסי, دبیل_
  { {0xd7f10023,0xe3b0002b,0x66f7000b,0x66f9000b}},	//   _mã_, _آره_, ंटिक_, ्मिक_
  { {0xb05b0012,0x0d860612,0x68fb189c,0xe3b8007f}},	//   gräb, слан, _orud, nkın_
  { {0x61e6189d,0xac831884,0x0000006a,0x0000006a}},	// [2820] mekl, згул,   ,
  { {0x21370008,0x442700e8,0x69db0077,0x3b0a0510}},	//   _לטפל_, _jln_, _abue, лезо_
  { {0xfc3f08e0,0xf017000a,0x7017000a,0x63a7002a}},	//   _avís_, _הקיץ_, _החיד_, ójny
  { {0x61e601e2,0x38c80086,0xb346016e,0xddcd0061}},	//   nekl, لاتی_, leçõ, mlaş
  { {0x25ad0176,0x656f002c,0x8d760067,0x68fb189e}},	//   dael_, ýchl, _دادا, _crud
  { {0x5fdb000b,0x7e64189f,0x68fb0c5e,0xab66007c}},	//   म्पल, llip, _drud, gmüü
  { {0xddcd0064,0x2604000b,0x6dbb002a,0xf99f0004}},	//   nlaş, वाली_, słał, _нè_
  { {0x291d005c,0x61e6016f,0x7e9b000a,0x7afc0012}},	//   bywa_, jekl, נספו, _irrt
  { {0xa926005f,0x2bcf005d,0x998f0007,0x68fb18a0}},	//   _удал, स्का, angų_, _grud
  { {0xddcd01e2,0xe3b80064,0xdc89000a,0x52d8005e}},	//   klaş, akın_, סְפָ, амою_
  { {0x5c5b00b2,0x2bf70008,0x57fb000a,0xddcd0061}},	//   רדיק, זמין_, _תלבו, jlaş
  { {0xad9b11e0,0xc0cb0124,0xcb130008,0x5fdb005d}},	//   _anún, луге_, ללת_, म्नल
  { {0x661d00f2,0xe3b20015,0xb5050015,0x7bdc18a1}},	//   öske, _فرغ_, _وظهو, _obru
  { {0xd7f10016,0xddcd0061,0x2229002b,0x70a9000b}},	//   _xã_, flaş, ازگی_, _कबील
  { {0x643b0053,0x543b0053,0x291d005c,0x644f0d92}},	//   _געגנ, _געגא, zywa_, écie
  { {0x61e601e2,0x7e640035,0x645a18a2,0xad670015}},	//   cekl, glip, loti, ماءه
  { {0x42380008,0x9c39000d,0x442c00d9,0x443e18a3}},	// [2830] _לנהל_, апат_, ohd_, oit_
  { {0xf3f10092,0x645a18a4,0x351b000a,0xb346016e}},	//   họn_, noti, אומנ, ceçõ
  { {0x207c0053,0x6008000a,0x443e007c,0x2bb80015}},	//   _גאזא, _הִרְ, iit_, صالة_
  { {0x1df90080,0xa2c0005d,0x31b7005d,0x443e1640}},	//   _темы_, _विन्, _अयोध, hit_
  { {0x89a8005e,0x443e03cf,0x645a18a5,0xc4c60015}},	//   сків_, kit_, koti, _تْ_
  { {0x63aa002e,0xa6950292,0x645a121a,0x443e0a5e}},	//   _nefn, ориј, joti, jit_
  { {0xa3be005d,0x645a18a6,0x9b09000a,0x59c50015}},	//   ेलन_, doti, _דִּ֥, _ويسك
  { {0x7f3c0053,0xbb480029,0xfc3f002d,0xe61918a7}},	//   טעוו, _الفن_, _tvís_, рди_
  { {0x442700e8,0x64480d75,0x68fb003f,0xddcd0061}},	//   _pln_, fndi, _urud, zlaş
  { {0x63aa0176,0xddcd01e2,0x04560029,0xdc8c0008}},	//   _cefn, ylaş, يلية_, נְחָ
  { {0x63aa0176,0x33650029,0x25b90086,0xdb1c002d}},	//   _defn, تهدف, _نهاد_, _scrú
  { {0x64480c60,0x443e0f1f,0x26c718a8,0xd7c9000b}},	//   andi, ait_, muno_, _राँच
  { {0xe3ae18a9,0x61e618aa,0xa5670015,0x625d0003}},	//   _об_, rekl, _ادان, téor
  { {0x63aa1878,0xb97a000a,0x24960015,0xddcd0061}},	//   _gefn, ינרי, _بنود_, tlaş
  { {0xb346016e,0xdb070030,0x61e618ab,0x26c718ac}},	//   reçõ, _fejé, pekl, nuno_
  { {0x22b50048,0x764900f2,0x0e660484,0xb05b079c}},	//   māk_, nney, ікан, träc
  { {0x22b50048,0x22a700dc,0x5baa03e7,0x7c3e18ad}},	// [2840] lāk_, lők_, икам_, tipr
  { {0x27e7003c,0x6e2d02f2,0xa2c0000b,0xebe31797}},	//   jenn_, ahab, _विम्, моуп
  { {0xd24f0086,0xd1490086,0xaaba002b,0x69d90012}},	//   _سنی_, _نشین_, شدار_, ffwe
  { {0xddcd04f9,0x7c3e00df,0xc2cc0053,0x443e18ae}},	//   rmaţ, sipr, רמאָ, zit_
  { {0x3ead010b,0x644818af,0xed57034e,0x7d0b079c}},	//   ćete_, yndi, _мою_, ägst
  { {0x76490064,0x22b5003d,0x26c70017,0xd794006b}},	//   eney, kāk_, funo_, чикъ
  { {0xdcf60064,0x26c702c1,0x443e18b0,0x6009000a}},	//   mayı, guno_, vit_, מִקְ
  { {0xdcf601e2,0xba9b0053,0x22a700dc,0xf6e50010}},	//   layı, _כסלי, dők_, яцін
  { {0xb80a0086,0xa5070001,0x629818b1,0x645a18b2}},	//   _پيام_, жења_, _stvo, toti
  { {0x186a010f,0x68ed18b3,0x644818b4,0x47c303fa}},	//   _тази_, çade, undi, _обув
  { {0x2bcf005d,0x1bfb0053,0x63aa002e,0x22b50024}},	//   स्टा, בליב, _vefn, gāk_
  { {0x443e00d1,0x85060015,0xd3780085,0xa19401c6}},	//   sit_, _ووان, neći_, маюч
  { {0xda7b013a,0x443e18b5,0x3d04000b,0x645a18b6}},	//   ינטר, pit_, रमों_, poti
  { {0x764000df,0xc05b0036,0x22b50024,0xb6020089}},	//   limy, рім_, bāk_, řádk
  { {0x539b0008,0x6e2d18b7,0x5457000a,0xdcf60061}},	//   _דיוו, thab, _וסגן_, dayı
  { {0xd378016f,0x2bdd000b,0x5e450015,0x8d6b0004}},	//   jeći_, न्ना, أَرْ, ајза_
  { {0xd378010b,0x6e2d18b8,0x8d770018,0xacf81155}},	// [2850] deći_, rhab, زارا, онту_
  { {0x1c05005d,0xad9b016e,0x6e240061,0x7640008c}},	//   राइल_, _inúm, akib, himy
  { {0x6e2d0220,0x764018b9,0x27e700cb,0xde5900fd}},	//   phab, kimy, venn_, _гані_
  { {0x69d90012,0x753d0030,0x26c70573,0x7d0b0123}},	//   ufwe, úszk, vuno_, ägss
  { {0xb23c0053,0x22b50024,0x22a700dc,0x01fc0053}},	//   סעדז, zāk_, zők_, יפאל
  { {0x26c70026,0xf80705ae,0xa7fc007f,0x0000006a}},	//   tuno_, ючен, _akıb,
  { {0xdce60024,0xd3780085,0x27e7148c,0x0000006a}},	//   _izkā, beći_, renn_,
  { {0xe7300067,0x68f0008c,0x060918ba,0x22a70030}},	//   خصه_, ähdä, сник_, vők_
  { {0xe4d60029,0xa994002b,0x26c702b9,0x7649082f}},	//   كويت_, _آشفت, suno_, rney
  { {0x22a70014,0x87070029,0x22b50024,0xd707002b}},	//   tők_, _وبال, tāk_, _وظاي
  { {0x2bdd005d,0xa2c0000b,0x17f80015,0x786d006f}},	//   न्या, _विण्, _برقة_, cúva
  { {0x22b50048,0x26f9014e,0x2c6d0264,0x22a70030}},	//   rāk_, ्मीर_, _vždy_, rők_
  { {0x48fe000b,0x85040015,0x22b5003d,0x22a70030}},	//   लियो_, _يومن, sāk_, sők_
  { {0xb4fa0008,0xd8480092,0xd3780085,0xd012006e}},	//   _לפני, họn_, zeći_, رلز_
  { {0x0e6a0029,0x539a000a,0x973c0085,0x644118bb}},	//   مصري_, _פיקו, _peći, mili
  { {0xb2ba0008,0xa2c0005d,0xa2ba0008,0xe1ff18bc}},	//   _המקר, _वित्, _המקט, llón_
  { {0x973c010b,0x6c8600e5,0x3cf6000b,0x718b000a}},	// [2860] _veći, سلام, ँटें_, _לְיַ
  { {0x2242003c,0xe0fb000a,0x644118bd,0x3c630004}},	//   likk_, _פליל, nili, екуг
  { {0xdcf601e2,0xbcfb00dc,0xd378016f,0x62970077}},	//   rayı, _szét, teći_, _éxod
  { {0xf2960053,0xdcf60064,0x644118be,0x224200cb}},	//   לכער_, sayı, hili, nikk_
  { {0xd378016f,0x5dfb000a,0x644118bf,0x76400091}},	//   reći_, _הפכנ, kili, vimy
  { {0xb05b00b8,0xf0930008,0xbad60010,0xd378016f}},	//   hrän, ענו_, _нібы, seći_
  { {0xe9a60036,0x644118c0,0xfe36000a,0x7fd7000a}},	//   _навп, dili, ּרִי_, פוקס_
  { {0xa3d9005d,0x2abb000a,0x44250046,0xd6d9005e}},	//   ड्स_, _למלא, ekl_, юті_
  { {0xdced002c,0x786d002c,0xb05b0012,0xe60f0015}},	//   zbaľ, súva, drän, اشى_
  { {0xa2c0005d,0x988b0008,0x674700dc,0x6edd000b}},	//   _विद्, _הָאֵ, árjá, _पहलु
  { {0x644f038d,0x2242003c,0x079b000a,0xa87b004c}},	//   écia, fikk_, _הסבל, _פאבר
  { {0xb05b01d1,0x7ae100b8,0x224200cb,0xe6170054}},	//   grän, _älte, gikk_, _ндх_
  { {0xe1ff18c1,0xca37000a,0x644118c2,0xd5fb000a}},	//   blón_, לנטה_, bili, _לפאר
  { {0x201a0026,0x104b004a,0x60c00030,0xe1ff0077}},	//   _copi_, сями_, ámma, clón_
  { {0x33db0008,0x629c0107,0x64b50061,0x32b70015}},	//   _החוד, írod, _eşiğ, _فدية_
  { {0x22420030,0x61f600da,0x0000006a,0x0000006a}},	//   cikk_, _gayl,   ,
  { {0x91bc013a,0xc1bc0008,0xbcfb00dc,0xbba8000b}},	// [2870] _המחי, _המחש, _azér, गरूक
  { {0x201a0026,0xa3be000b,0x9f430046,0x7c670015}},	//   _gopi_, ेलि_, lejí_, ساءل
  { {0x99890089,0xf1d4005d,0x682f0293,0x6a94005e}},	//   íkům_, _थामन, _jøde, еріє
  { {0x3a260035,0x682f0134,0xceb2000a,0x4a44005e}},	//   gkop_, _møde, _ביט_, ннєв
  { {0xbcfb0014,0xa3be000b,0xca24004a,0xaa580054}},	//   _ezér, ेला_, эффи, чицу_
  { {0xccf2000a,0x66e518c3,0x644118c4,0xd3780160}},	//   _שכם_, дока, xili, leću_
  { {0x32090064,0x682f063b,0x2d9f007c,0x6441033e}},	//   _onay_, _rødd, _õues_, vili
  { {0x64410b7c,0xdb070089,0xc7440029,0x36350018}},	//   wili, _její, عضوي, برتس
  { {0x28080089,0x3d00000b,0xf8b900c3,0x44250046}},	//   átní_, रिये_, _ذهاب_, tkl_
  { {0xe7b50074,0xd8740015,0xc8c8002b,0xd83b0033}},	//   _آماد, _كالب, _رومن_, _уэб_
  { {0x61f601e2,0x2242003c,0x28080089,0xb05b04d4}},	//   _payl, tikk_, štní_, trän
  { {0xf8d1005d,0x923a0036,0x249f002e,0xd378016f}},	//   _समाय, ічну_, ppum_, jeću_
  { {0x2242003c,0xd378016f,0x64411645,0xb05b0309}},	//   rikk_, deću_, pili, ltäy
  { {0x2242003c,0xdee601c5,0x682f0595,0x682d002a}},	//   sikk_, моги, _føde, eźdz
  { {0x2bcc000b,0x539a000a,0xa06718c5,0x61f618c6}},	//   ालसा, _ויצו, фара_, _tayl
  { {0x74a4000b,0x9f430046,0xc2560015,0x0206004a}},	//   चीकृ, cejí_, _تختت, _цзин
  { {0xdb0e00dd,0x0baa0015,0xdb07006f,0x91bb000a}},	// [2880] _gebê, قاضى_, _dejí, _ומפי
  { {0xe572000a,0x6c330015,0x3299000a,0x682d002a}},	//   דַע_, نفقا, ַבְד, aźdz
  { {0x5f460086,0x3e480011,0xfeba002b,0x2bdd000b}},	//   _آنجل, eşte_, _باخت_, न्धा
  { {0xa2c0014e,0xfaf80048,0xc3320008,0xb9e30036}},	//   _विस्, _šīs_, כוב_, віши
  { {0x0897003b,0xd83a0010,0xc27b000a,0x127b004c}},	//   وضوع_, жэй_, קרני, קאנע
  { {0x0ee2005d,0x9f430089,0x2bdd000b,0xd889002b}},	//   _पहाड, zejí_, न्दा, سخهٔ_
  { {0xd6cf0063,0x66e30180,0x3e480045,0x91ee000b}},	//   ът_, воја, aşte_, ज़ाज_
  { {0x2487002f,0x26c018c7,0xbb3b0008,0x44f40709}},	//   _ainm_, čio_, _ועלי, епис
  { {0x83fc0085,0x05bf000b,0x25af02b9,0x0000006a}},	//   hođe, _एयरब, _degl_,
  { {0x83fc010b,0x224000dc,0xc9850015,0xd3780085}},	//   kođe, _amik_, _أشفي, zeću_
  { {0x97260087,0xd6cf0031,0x430a005e,0x60c602f7}},	//   _تفاو, _نقل_, іхом_, erkm
  { {0x64a6008f,0xc7b8016f,0xd62600e5,0xd251002b}},	//   _жада, _dođe_, _تعطي, انح_
  { {0x7c2e18c8,0x067b000a,0x867b000a,0xdce7003d}},	//   _olbr, _ונאל, _וראו, ālīb
  { {0x9f430089,0x656f00b8,0x34f30033,0xf1bf0030}},	//   sejí_, üche, _шпіё, ehát_
  { {0x83fc016f,0xddc4002a,0x5f94125c,0x60c618c9}},	//   gođe, dnił, тист, arkm
  { {0x41e702e5,0xddc4002a,0xe731000a,0x5c9908f0}},	//   _ціка, enił, נֵם_, зкая_
  { {0xee840010,0x5c7502a7,0xd3780085,0x7bde0012}},	// [2890] тыро, елат, reću_, ffpu
  { {0x78a204af,0x83fc016f,0x4fc70010,0x9f4c0227}},	//   dpov, bođe, _ўспа, ždá_
  { {0xf993002b,0xb5fd18ca,0x7cf80030,0x63ae002a}},	//   نبش_, loše, túrá, óbny
  { {0xd37b0053,0x9f7a000a,0x2cc40061,0x8c490061}},	//   קראט, _מנתח, ürdü_, _başö
  { {0xb5fd016f,0x5d850115,0x682f04d1,0x442e00da}},	//   noše, _سلسل, _rødb, _olf_
  { {0x46f50142,0x2c05000b,0xe8f80033,0xb05b008c}},	//   ечит, राओं_, ьлі_, ttäy
  { {0xa2c0000b,0x7b64004a,0x7bc8000a,0x78a2036d}},	//   _विष्, _атте, _קֶשֶ, apov
  { {0x7af50030,0x2c740123,0xb5fd0085,0x442e18cb}},	//   _iszt, räde_, koše, _alf_
  { {0xa4d60001,0xa8a7017f,0x74150015,0x98f40015}},	//   едњу_, _ірак, فوظا, _لثلا
  { {0xa2c0005d,0x7af5005c,0x25a20064,0xccf2000a}},	//   _विश्, _kszt, ıkla_, נכי_
  { {0xe5e10010,0x4374005e,0xcad5000a,0xc6d40015}},	//   _былi_, куют, עוֹת_, _لتنت
  { {0x83fc016f,0x349518a7,0xe6040015,0xc7b80085}},	//   vođe, _задр, _لِمَ, _vođe_
  { {0x65940124,0xddc4002a,0x45b6000a,0x660b18cc}},	//   _рачу, ynił, _נפסל_, _ingk
  { {0x7af500dc,0x7bc3002e,0x3f980045,0x251a000a}},	//   _oszt, ónul, ucru_, _מונא
  { {0xe4560053,0xbcfb00dc,0x4375004c,0x9e760054}},	//   _איסט_, _szép, _אײַן_, ећај
  { {0x2612005d,0xcfaa002b,0x83fc0085,0xddc4002a}},	//   थायी_, _کاظم_, rođe, wnił
  { {0x7af500dc,0x61e402f2,0x20130052,0x0000006a}},	// [28a0] _aszt, _ibil, ýnið_,
  { {0x3ec50064,0x4d6318cd,0xa7fc0061,0x6b560248}},	//   üstü_, укув, _akın, нтех
  { {0x4fd700b2,0x7fd700b2,0x660b00e8,0xe7c9000b}},	//   _אויב_, _אויס_, _ongk, _राजप
  { {0x5e460015,0xf2d2015b,0x6e9b000a,0x6ad00065}},	//   _أَحْ, רעא_, _מבטח, _हमीर
  { {0x61e4000c,0x7af500dc,0x67d4049d,0x186a05f8}},	//   _mbil, _eszt, волу, пади_
  { {0xd6d00029,0x25dd005d,0xc173000a,0xa2c0000b}},	//   لقت_, क्सी_, אחד_, _विल्
  { {0x67b70029,0xad9b002e,0xcc870015,0x97a5005e}},	//   راوح_, _snúi, _أنّه_, тріл
  { {0xdb1c002d,0x89a50015,0x95d7006b,0x61e4007f}},	//   _ndré, _لإكم, едът_, _nbil
  { {0xb17b00c0,0x54540254,0xda650015,0x1c05000b}},	//   neåt, квит, _شافي, राचल_
  { {0xccf3013a,0x660b0375,0x61e418ce,0x88bb000a}},	//   רכז_, _engk, _abil, _מזמי
  { {0xf2e50011,0x22590088,0x6fd7000b,0xdb0e0077}},	//   ţând_, дины_, _बाबू, _bebé
  { {0x5ab700b4,0xb05b008c,0xd5d60015,0xf2c30033}},	//   עלכע_, rräm, _ستؤث, ысьн
  { {0x656f002c,0x64a30484,0xf3f5002b,0xa3f402a3}},	//   ýcht, _бача, رتیک, _аплі
  { {0xdb0700dc,0xf537000a,0x7a330061,0xb5fd1587}},	//   _lejá, _אנדי_, _içte, roše
  { {0xc0ab0074,0x63bc002e,0x3ca9000b,0x15f4000b}},	//   _کابل_, órnu, _चौड़ा, _आसार_
  { {0x27ee0034,0x290418cf,0xfe7300c3,0x7f840058}},	//   hefn_, _orma_, ادس_, طلقن
  { {0xcbc70086,0xebc70001,0xf1bf0089,0x627c000a}},	// [28b0] فزاي, ељен, nkám_, _צנחנ
  { {0x69c00ad3,0x61e418d0,0x09bb000b,0x61fd18d1}},	//   _adme, _zbil, ॉल्य, ldsl
  { {0x19f90033,0xdb070030,0x61e80030,0x49d9005e}},	//   дэль_, _bejá, ődle, ддею_
  { {0xff16000a,0xb05b0123,0x68ed1702,0x61fd18d2}},	//   _סקרת_, kräk, çado, ndsl
  { {0xd3660074,0x7e6d0048,0x99d40067,0xdb070077}},	//   _چه_, mlap, اتما, _dejá
  { {0xd3660074,0xab950001,0x7e6d18d3,0x7bd5005c}},	//   _نه_, _јављ, llap, _uczu
  { {0x316c0050,0x8f9c0053,0xcc540063,0x57a40033}},	//   ędzi_, ליגי, _свръ, ушча
  { {0x7e6d00dc,0x59d8005d,0xda09002b,0x87040021}},	//   nlap, _डायर, _تيره_, ابول
  { {0xe895008f,0x9f4a0251,0x25dd000b,0xe65d0061}},	//   _разь, rebé_, क्षी_, çtığ
  { {0xe3b10015,0xdb05001a,0xe29903ae,0xdb0e0030}},	//   جرة_, dahú, мао_, _sebé
  { {0xe1bf005d,0x26dc0264,0xe8d1000b,0xe6c70067}},	//   ्लंघ, ctvo_, _समुच, _ستاي
  { {0xa69600a3,0xd24f0015,0xa116002b,0x7e6d003d}},	//   _סכנה_, ْنَ_, پوست, jlap
  { {0x463a00b2,0x7e6d0024,0x60dd02de,0x85b8002b}},	//   _קענע, dlap, gtsm, _سانس_
  { {0x25dd005d,0xd0120031,0x91a2000b,0x7536004c}},	//   क्री_, جلس_, _क्रै, _באנד_
  { {0x998f0007,0x023a0029,0x60dd0c0d,0x61e418d4}},	//   nigų_, _يثبت_, atsm, _tbil
  { {0xa7fc0064,0xc6920135,0xe8d1000b,0x61e40b28}},	//   _akıl, שאן_, _समूच, _ubil
  { {0x0d860a13,0x6a7818d5,0xa05a0058,0x3e5a005a}},	// [28c0] тлан, nífe, _يؤخر_, jďte_
  { {0x6faa0029,0xe0b700a3,0xd9ba000b,0x2bdd000b}},	//   _تهدف_, _שליט_, उण्ट, न्ला
  { {0xe9da0080,0x3daa0080,0xb5fd002c,0xcb0a0115}},	//   дке_, _окно_, alši, بيان_
  { {0x831a0053,0x1e97000a,0xceb80091,0x98a608b0}},	//   וועז, _שככל_, šęs_, виде
  { {0x6c860029,0xb7b50092,0x314d000a,0xd197000a}},	//   _للحم, _vọn, ּתוּ, דכני_
  { {0x69dd0123,0x913b000a,0x18740174,0xf1bf00bf}},	//   _ösen, וענק, ыгля, vkám_
  { {0xddcd0011,0x27ee0026,0xcf93000a,0xb9960015}},	//   noaş, refn_, סטה_, _للزب
  { {0xceb30008,0xe1ff0030,0x1af7000a,0xd49a012e}},	//   ביה_, rlók_, _במלל_, мро_
  { {0x29040011,0x5e570053,0x26dc0198,0xb8e50029}},	//   _urma_, כיקע_, stvo_, _مثله
  { {0xa84a012c,0x7d7b000a,0x98760099,0x7e6d01ec}},	//   _غلام_, ונפו, _рубљ, zlap
  { {0x0bb70008,0xd7760029,0xfbd3000a,0x1db2000b}},	//   כלים_, _شائع, בתת_, जरात
  { {0xd7d2005d,0xbddb0003,0x64430061,0x27e90085}},	//   _साँच, _amèn, _emni, đane_
  { {0x61fd0dec,0x68e90045,0x61ef18d6,0x59d70065}},	//   rdsl, _xped, recl, ण्टर
  { {0xa4b7000a,0xa3b6000b,0xb5fd003d,0xdb05001a}},	//   _ילדה_, _ज़ि_, moša, rahú
  { {0x6f24005e,0xf487002b,0xb5fd003d,0x5333006b}},	//   аєте, _شاهی, loša, _вещт
  { {0x6443005c,0x2d8f0134,0xfda40001,0x1317000a}},	//   _zmni, øge_, ијум, _יחול_
  { {0x3d0d014e,0xb5fd0048,0xe7d2000b,0x23b6000b}},	// [28d0] समें_, noša, _सांप, _आजाद
  { {0x7e6d0780,0xd0f800f3,0x9b27029b,0x644818d7}},	//   slap, _יצחק_, кфел, nidi
  { {0x68e918d8,0xe945002b,0xfbd00015,0xe0df02b9}},	//   _sped, گرای, غتك_, ltò_
  { {0xb5fd0024,0xe1ff07e6,0x6e360107,0x2cbe0091}},	//   koša, ndó_, chyb, _žydų_
  { {0x89a80036,0xb5fd0024,0xe0df04ed,0xbe3a000a}},	//   тків_, joša, ntò_, _נעשת
  { {0xb5fd0048,0x29c30092,0x3e5a0227,0x6e2d02ad}},	//   doša, ựa_, rďte_, lkab
  { {0x3669005f,0x644818d9,0x48ef000b,0x501c000a}},	//   нако_, didi, _इनको_, ווגו
  { {0xd5b10029,0x83fc016f,0xc7b8016f,0xd90f002b}},	//   حفظ_, vođa, _vođa_, _ویا_
  { {0x9f4300f2,0xb5fd0024,0x229a0024,0x5a440010}},	//   lejä_, goša, _rīka_, _тэра
  { {0xb05b0012,0xe5760033,0x644818da,0x5f9402ed}},	//   bräi, ызы_, gidi, ти́т
  { {0x84580063,0x96fb0029,0x6e2d0064,0xdddd006f}},	//   ърът_, _تعذر_, kkab, _zisť
  { {0x82360086,0xb5fd0024,0x83fc0085,0x98a00091}},	//   اردا, boša, rođa, šią_
  { {0x78f90053,0x69da0053,0x3c360134,0x7d090085}},	//   עפֿו, ײַכו, _hæve_, _šesn
  { {0x9f43022d,0xddc401cb,0xc1bf000b,0x6305002b}},	//   kejä_, dliš, ्लॉग, _موتل
  { {0x752900dc,0x3ebe002e,0xd5b7000b,0x0eb90033}},	//   lyez, étt_, _इजाज, куты_
  { {0x6e2d0035,0x661b0849,0xb17b0293,0xdd8f0015}},	//   gkab, njuk, reår, كوف_
  { {0x7529000c,0x753b00b8,0xab640064,0xddc40963}},	// [28e0] nyez, nzuz, zcüğ, gliš
  { {0x1c0e005d,0x661b0e95,0xbc6a0002,0x6e2d18db}},	//   साइल_, hjuk, رمان_, akab
  { {0x49ca18dc,0xbf9b004c,0x27e00030,0x9f8b007c}},	//   елен_, _ריטש, őink_, _söök_
  { {0xb05b0123,0xddc400bc,0x644818dd,0x6e2d18de}},	//   tsäg, bliš, zidi, ckab
  { {0x28f80a2c,0xad9b002c,0x627c005c,0x644802e8}},	//   тель_, _vnút, _głoś, yidi
  { {0xe1ff0030,0xb5fd18df,0x7d040ef2,0x8c4600af}},	//   rlói_, voša, mvis, _сеге
  { {0xfaa30180,0x627c002a,0xa3d7000b,0xeed6000a}},	//   _гасо, _złoś, िलन_, אֵ֥ת_
  { {0xb5fd0048,0x64480176,0xceb30008,0xb05b0123}},	//   toša, widi, זיה_, psäg
  { {0x25b9002e,0x752900dc,0x7d0418e0,0x97c60040}},	//   ðsla_, gyez, nvis, _متضم
  { {0x2a660035,0xb5fd18e1,0x5c37004c,0x64480234}},	//   loob_, roša, ָרטן_, uidi
  { {0xd793003b,0x7d04022d,0x3ce00020,0xb5fd0340}},	//   _المخ, hvis, htiv_, soša
  { {0xb5fd18e2,0xe0df04ed,0x5b57004c,0xd3770033}},	//   lošn, ttò_, רשטן_, ычы_
  { {0xc5f3013a,0xa2c0005d,0xf1bf0030,0x7feb005e}},	//   _לדף_, _विक्, nkái_, нєва_
  { {0xe0df04ed,0x7d0418e3,0xe1ff002a,0x4fc70033}},	//   rtò_, dvis, ylów_, ысма
  { {0xf8d1014e,0x9f340036,0xd9040086,0xe0df04ed}},	//   _सम्प, бері, _کی_, stò_
  { {0x7bca002e,0x7d0402de,0x9f43008c,0x21360003}},	//   ófun, fvis, vejä_, êché_
  { {0x5bcb0001,0xdb0e02c1,0x786d002c,0x7c970021}},	// [28f0] ећег_, _debí, súvi, اشرا
  { {0xad9b0f64,0x9f4300f2,0x212b0d55,0x6e2d18e4}},	//   _saúd, tejä_, mych_, skab
  { {0x8f9a000a,0x1a65002b,0x9aa40015,0xddc407c4}},	//   _ביתי, لیسی_, مملو, sliš
  { {0x58b90015,0x9f43008c,0xb05b0123,0x98a90085}},	//   ناتج_, rejä_, gräv, šač_
  { {0x212b18e5,0x3ce00011,0xab950036,0xba740015}},	//   nych_, ctiv_, _вигі, حالت
  { {0x63ba016f,0x9f4300f2,0xdb05002d,0x15e2000b}},	//   jatn, pejä_, lbhí, क्सर_
  { {0xdb580036,0x75d50086,0xc7c40080,0x63ba18e6}},	//   _бют_, ليغا, ссчи, datn
  { {0x212b002c,0xd5ae0015,0x9f4a016e,0x645800bc}},	//   kych_, وفى_, lebã_, _ajvi
  { {0x680b0048,0xe3b10086,0xe4d6002b,0x67d50054}},	//   _pēdē, يرد_, لويت_, _возу
  { {0x212b00f8,0x13090080,0xe2e5005e,0x661b156a}},	//   dych_, вной_, ажоп, sjuk
  { {0x9f4c002c,0x8bd6000a,0x35f518e7,0xb05b0012}},	//   ždú_, בותו_, _впер, nräu
  { {0xcad60008,0x7d0400f2,0x224b0f8b,0x2ca90079}},	//   סורת_, yvis, gick_, kpad_
  { {0x63ba0049,0x23dd000b,0x8505002b,0x6d4b001a}},	//   batn, _मापद, _خوشن, úgal
  { {0x645d038d,0x82360086,0x98a0016f,0x7d0418e8}},	//   ésid, ارگا, šić_, vvis
  { {0x683f0007,0x6fd7000b,0xdfcf0015,0x20040046}},	//   _išdė, _बारू, ظيف_, ěmi_
  { {0x31260063,0xb21b02de,0x02460015,0x212b18e9}},	//   _вдиг, lmæn, _خَبَ, bych_
  { {0x212b0050,0xb21b0134,0x1c4618ea,0xcd27005e}},	// [2900] cych_, omæn, анам, ажте_
  { {0x69db0467,0x629e0656,0x6e46002b,0x6abe0012}},	//   _acue, _époc, _چندم, tspf
  { {0x23dd005d,0xb5fd0024,0x0b460004,0x68fb1703}},	//   _मानद, jošo, јнен, _asud
  { {0xd3560008,0x3ebe002e,0x7d040db2,0x7e9b000a}},	//   ביעי_, áttu_, pvis, _שסכו
  { {0x9f580251,0x7d030010,0xb5fd18eb,0x656f0012}},	//   ldrà_, _дзяж, tošn, üchl
  { {0xd90d0086,0xb05b00b8,0x6d3b000a,0x6826001a}},	//   عیل_, bräu, _יתכנ, _aðdr
  { {0x212b0050,0x63ba18ec,0x9f580251,0xb05b0c77}},	//   zych_, vatn, ndrà_, mrät
  { {0x7bc3002e,0x27e9016f,0x88c60029,0x8afb000a}},	//   ónuv, đana_, _نتطل, _בהלי
  { {0x8e370053,0x15e2000b,0xb4260015,0x2bdd000b}},	//   ינקא_, क्षर_, لعدو, न्का
  { {0x3cf9005d,0x224b1650,0xb05b0400,0x25ad18ed}},	//   _उनसे_, wick_, nrät, abel_
  { {0x212b0f9a,0x8bd70053,0x3c77000a,0xd37a006b}},	//   wych_, סוטו_, שתים_, ъчи_
  { {0x212b0d55,0x63ba18ee,0x058601e1,0x722b02ed}},	//   tych_, satn, _кулм, тцов_
  { {0x92580063,0x361b000a,0x224b037e,0x32050046}},	//   раят_, _שודד, rick_, ěly_
  { {0x50670124,0x212b18ef,0x104b03e7,0x44a30021}},	//   ртма, rych_, тями_, _بموق
  { {0xe2970083,0xc0580191,0x6716005d,0x447b0008}},	//   _кај_, рія_, थमिक_, _שנוע
  { {0xbbaf000b,0x7147004a,0x2ca918f0,0x63b800cb}},	//   टर्क, _вхож, tpad_, _hevn
  { {0xdb05002f,0xb5fd18f1,0xfd100015,0x52840015}},	// [2910] rbhí, došl, وجك_, _بليك
  { {0x0ba70010,0x63b8003c,0xb05b0b14,0x9c380054}},	//   ршам, _jevn, träu, апут_
  { {0xdb1500dc,0xb9950015,0xddc4002a,0x68e218f2}},	//   _kezé, ملاب, nniś, etod
  { {0xdb05007c,0xb05b0012,0x2ca918f3,0x3a2418f4}},	//   mahü, rräu, ppad_, _comp_
  { {0xfe00005d,0x4e16000a,0x49b8002b,0x7c320030}},	//   _लोटस_, _החרב_, شاند_, ákró
  { {0xb5fd0024,0xfaa70036,0x7bdc002d,0x63b818f5}},	//   tošo, _вшан, _gcru, _nevn
  { {0x26c118f6,0x7bc3002e,0xab040020,0xad9b016e}},	//   ého_, ónuu, _ööpä, _gaúc
  { {0xa2c00372,0x9f5802c1,0xcf58011f,0x26c90085}},	//   _विज्, ndrá_, יבות_, čao_
  { {0xdb0701b2,0x68fb10af,0x25ad18f7,0xd3b900ce}},	//   _nejú, _usud, rbel_, луні_
  { {0xc6e70191,0x62980947,0xe1ff0030,0x200101d7}},	//   _відп, _buvo, klós_, _nahi_
  { {0xd6db0124,0xe3650142,0x5b3a000a,0xa349012e}},	//   _шта_, скни, ָׂרו, узна_
  { {0xf5950029,0xe1f20029,0xb21b02de,0x61e60012}},	//   _الإج, أسد_, smæn, ufkl
  { {0x5fdc000b,0x659a000a,0xb148002b,0x661d001a}},	//   _बादल, _עיסק, شیدم_, ösku
  { {0xf66a0084,0x05740086,0xa8790053,0x22920086}},	//   phæð_, _بامد, טאָר, _کليس
  { {0x20010717,0xdb1c0227,0xae5a005e,0xb05b186f}},	//   _dahi_, _odrá, грає_, vrät
  { {0xb05b0012,0x7bc70390,0xdd920015,0x63b80046}},	//   tsäc, _adju, سوط_, _zevn
  { {0x629800b8,0xa3de000b,0xe1ff0030,0xb05b0400}},	// [2920] _zuvo, _णाम_, alós_, trät
  { {0xddcd005c,0xd37e0085,0xb05b03c1,0x0429000a}},	//   gnał, šćem_, rsäc, נֵּֽ
  { {0x5f0608fe,0x31ba000a,0xbb4a006e,0x6286063b}},	//   _узна, ָזְנ, دلان_, omko
  { {0xb05b0bc2,0x5f17000a,0xddcd002a,0x68e218f8}},	//   srät, _החטא_, anał, ttod
  { {0xb05b00c0,0xa3d7021e,0xa9540033,0xb5fd0f81}},	//   prät, िला_, ўклі, rošl
  { {0xd6da0036,0x6c360086,0x2c0e000b,0x2906008c}},	//   гти_, _افسا, साओं_, rvoa_
  { {0x87060010,0xfe1c000b,0xdc37004c,0xb21b001a}},	//   сяле, _पचास_, _פאלט_, fmæl
  { {0xb05b008c,0xf1bf0030,0x8b57015b,0x60c406c0}},	//   isäa, nkát_, _הילס_, _ovim
  { {0x27330023,0x63b80264,0x5a17000a,0x07da002b}},	//   ạn_, _pevn, _פקמן_, _مذاب_
  { {0x2937000a,0x96ba125d,0xdb1c0247,0x224918f9}},	//   _האמן_, _буду_, _zdrá, _smak_
  { {0xe6960029,0x3618002b,0xd5af18fa,0x8c1b000a}},	//   _الصد, _پراگ_, _нс_, אויי
  { {0xe717000a,0xddcd002a,0xdb05007c,0x0000006a}},	//   _לחבר_, znał, vahü,
  { {0xdb1500dc,0x067b0053,0x85760015,0xcfa7005e}},	//   _vezé, _ענדל, _ادائ, йшви
  { {0x23480086,0xf1db005d,0xa0550036,0x6e95000d}},	//   _پستی_, _भावन, івві, живу
  { {0xadbd008f,0x9f340036,0x2001007c,0x4477000a}},	//   кавi, пері, _vahi_, _העגל_
  { {0x66020005,0xd357000a,0x44e2001a,0xe1ff0030}},	//   _jaok, _לשוק_, oð_, rlós_
  { {0x61ed0035,0x99860046,0x61440054,0x200118fb}},	// [2930] _ibal, ehož_, _нећа, _tahi_
  { {0x44e20084,0xb6060085,0x2bb80015,0x0000006a}},	//   ið_, lašć, مامة_,
  { {0xaab5005e,0xf24b000a,0xf1bf0030,0x999906f3}},	//   ійді, ְגְּ, bkát_, акет_
  { {0xb05b08e9,0x8f88000a,0x3c2f0061,0x497518fc}},	//   präs, _לְרֵ, _sıvı_, олес
  { {0x7bc30084,0x61ed000c,0xa9690001,0x69d90028}},	//   ónus, _mbal, јила_, rgwe
  { {0xbcfb0152,0xdb050125,0x1d16000a,0x16a90974}},	//   _exéc, abhá, _וקשר_, авки_
  { {0x44e20084,0xaaa9000a,0x682f0595,0xe7390818}},	//   eð_, _כֹּ֖, _jødi, рей_
  { {0xe7f5005d,0xf6250036,0x562901b7,0x644a18fd}},	//   _इसका_, ідпо, ржим_, _amfi
  { {0x845918fe,0xb5fd01a3,0xb21b18ff,0x44e2001a}},	//   ирот_, lošk, rmæl, gð_
  { {0x61ed1900,0xf1bf0030,0x94790004,0xb21b001a}},	//   _abal, zkát_, јсиу_, smæl
  { {0x44e20084,0xfbd20008,0x60c4016f,0x3860002d}},	//   að_, ותי_, _svim, éire_
  { {0xe5ef008c,0x75150015,0xbf13000b,0x3c3602de}},	//   äkää, _وواض, डमैन_, _nævn_
  { {0x644f0152,0x629e0003,0x62861901,0xe44e03ca}},	//   écis, _épon, rmko, _жж_
  { {0x389a000a,0xfc3f0046,0xdfd200c3,0x22591902}},	//   יישנ, _stín_, بيس_, ansk_
  { {0x02460015,0xbea30033,0x44271903,0xb5fd0085}},	//   _وَتَ, даск, _ion_, jošk
  { {0x44271904,0x78a90089,0x6d05000b,0xb13a0015}},	//   _hon_, _otev, रिंग_, _نأخذ_
  { {0xec4a005f,0xdb9a0001,0x9c260254,0xb1e50015}},	// [2940] азал_, атељ_, одад, _رأيه
  { {0x44271905,0x73f9000a,0x1bba0015,0x2004003d}},	//   _jon_, יּ֣ו, شائع_, ēmis_
  { {0x44271906,0x290d08b2,0x7c27002a,0x1ae3006b}},	//   _mon_, _area_, _dojr, дохм
  { {0x38c80086,0xb05b03c1,0x6097009a,0xddcd0535}},	//   ماتی_, nsän, _دنیس_, gnań
  { {0xb05b008c,0x290d1907,0x61eb0061,0xa88a033d}},	//   isän, _crea_, _ögle, айда_
  { {0xb8f2005d,0x764b0026,0x44271908,0x38cb002b}},	//   _वि_, _amgy, _non_, شاهی_
  { {0xab2a001e,0xd6d00029,0x3e480045,0xe9a6005e}},	//   _това_, رقة_, eşti_, _мавп
  { {0x4427002f,0xcf930008,0xd4b80731,0x2e37004c}},	//   _aon_, וטו_, блиц_, ַריש_
  { {0xe4e60191,0x44271909,0xa5d70015,0x290d0045}},	//   ційн, _bon_, زبير_, _grea_
  { {0x44e20084,0x4427190a,0x4438190b,0x61ed190c}},	//   rð_, _con_, ór_, _sbal
  { {0xd2510086,0xe2f80036,0x78830089,0x4427190d}},	//   فند_, щені_, _důvě, _don_
  { {0x92580080,0xe665005e,0x9f450046,0x4427190e}},	//   жают_, _етіо, ýlí_, _eon_
  { {0xc2180191,0x85560086,0xa633005e,0x2167005e}},	//   ією_, _بخاط, _інші, ютог
  { {0x9f4c0107,0xddcd002a,0xdb1e016e,0xd48f008b}},	//   ždý_, znań, rapê, _ір_
  { {0x764b0176,0xa5c3005c,0x645a0125,0xb6060085}},	//   _ymgy, spół, mnti, pašć
  { {0x5d990033,0x4d990323,0x4427190f,0x7e761910}},	//   скаў_, скаю_, _zon_, glyp
  { {0xe04b0074,0x443e007c,0x9f510046,0x2d8f1911}},	// [2950] _نشده_, oht_, mezí_, äge_
  { {0x645a1912,0xddcd0045,0xfbab0151,0xae14000b}},	//   nnti, flaţ, ртай_, डाउन_
  { {0x2bb80029,0xdefb0010,0x645a1913,0x6ffa000a}},	//   زالة_, _тып_, inti, _ההתפ
  { {0xf9c70191,0x7b64010f,0x290d04f9,0xb5fd116e}},	//   іщен, фтуе, _prea_, rošk
  { {0xf99003c4,0xae1a000a,0xc27c000a,0x07a507be}},	//   نبه_, _הורכ, בראי, палн
  { {0x290d0011,0x09340029,0x7c3e1914,0xb05b008c}},	//   _vrea_, برمج, chpr, isäo
  { {0xc9f70015,0x2b57002b,0x443e0125,0x09f70015}},	//   _وسرع, _بیاد_, dht_, _وأرد
  { {0x682f169b,0x443e0a83,0x44271915,0x1f5c000a}},	//   _nødv, eht_, _son_, ידוא
  { {0xc6480015,0x98170015,0xd7e7005e,0xb05b0123}},	//   تجول_, _وبطا, _міжо, vsän
  { {0x443e1916,0xfb96000a,0xf7730015,0x0000006a}},	//   ght_, ּ֣ית_, _قاض_,
  { {0x44270bcf,0xdb0e00b8,0xa8220086,0x2509002b}},	//   _von_, _gebä, _سکون, _گرای_
  { {0x98cf005d,0x44271917,0xf8cf005d,0xfc3f0bd7}},	//   _हटाए, _won_, _हटाय, _stíl_
  { {0xb5fd0024,0x44271918,0x263f002a,0x443e0125}},	//   joši, _ton_, głoś_, bht_
  { {0x443e1919,0xb5fd003d,0x25bd0034,0x1fa7006b}},	//   cht_, doši, _hewl_, зкри_
  { {0xa8560008,0x765b0061,0x7d0b01d0,0x0000006a}},	//   לישה_, onuy, ægsn,
  { {0x9f4b0014,0x23760021,0x6446003d,0x925703ae}},	//   áját_, _عميد_, īkie, _најт_
  { {0x229a0024,0xd257000a,0xdb1c016e,0x61db000a}},	// [2960] _rīki_, _משקה_, _gerê, _הקפד
  { {0xdb1e00dc,0x4176002b,0x9046002b,0xddc40045}},	//   lapé, _واکس, _رنجه, foiţ
  { {0xb05b022d,0x4f9b0008,0xbf9b0008,0x1c390036}},	//   isäl, _לביצ, _לייש, цять_
  { {0x62870046,0x0136004f,0x7d290052,0x0000006a}},	//   ňkov, ּרַת_, ðssó,
  { {0x645a191a,0x6284002d,0xddcd0045,0x5d7501b0}},	//   ynti, _mhio, slaţ, _журф
  { {0x7b0100f2,0x6296003f,0xa157000a,0x7d7b000a}},	//   äytä, _liyo, הבנה_, _לנכו
  { {0xb17b0bfa,0x8f9b00a3,0x6e360091,0x765b001a}},	//   mgåe, זיצי, okyb, fnuy
  { {0x6e360007,0x6d440012,0xcf93000a,0x629609cf}},	//   nkyb, ozia, עטה_, _niyo
  { {0xa4f80086,0x6d44191b,0x38cb002b,0x0000006a}},	//   تکار_, nzia, _هالی_,
  { {0x644f0152,0x6e24003f,0x533410a1,0x443e007c}},	//   écip, hjib, деот, uht_
  { {0xddcd02d5,0xe41a002c,0x6296191c,0x60c6007c}},	//   hlaš, _kľúč, _biyo, eskm
  { {0xa77b0053,0x46a30010,0x4b7b000a,0x25b7002b}},	//   _פראפ, _чацв, מאיו, _فهمد_
  { {0x61f80010,0x6296117f,0x051a002b,0xe57a00ce}},	//   чняў_, _diyo, _ديشب_, _узд_
  { {0xc953013a,0x6d440050,0xc05b0484,0xc6c6004f}},	//   תמש_, dzia, сім_, ּהּ֙_
  { {0x6284002d,0xb17b0134,0x0877004c,0x9f5a191d}},	//   _fhio, dgåe, פעלט_, _papá_
  { {0x3377013a,0xb5fd0024,0x735b000a,0xddc40045}},	//   _מתוך_, toši, _לכוח, voiţ
  { {0x7e6d0011,0xddcd0198,0xdb1c0144,0xb5fd0091}},	// [2970] roap, glaš, _herè, uoši
  { {0x6e24003f,0x00bc000a,0xb5fd191e,0xcf270015}},	//   ajib, _המזמ, roši, _فرجي
  { {0x3cf9005d,0x69c20026,0x539b00f3,0x0af90015}},	//   _उनके_, faoe, ציאו, تفاظ_
  { {0xddcd00bd,0xbdf90015,0x7bde02f2,0x99d40067}},	//   blaš, _بفحص_, agpu, فتها
  { {0x8c3b018b,0x99840089,0x88c8005e,0x23dd000b}},	//   _auße, _domů_, злів_, _मालद
  { {0xe8f80010,0x7d0d01d3,0x27e102ad,0x682f174d}},	//   ялі_, mvas, ühn_, _nødt
  { {0xca7700e6,0x7d0d191f,0x2619000b,0xba770015}},	//   _فارغ, lvas, भाली_, _فارت
  { {0xff180008,0x443c1920,0x765b0061,0x34a90054}},	//   לקות_, _alv_, unuy, овио_
  { {0x3a840010,0x58d404e0,0x89340015,0x3ce9060a}},	//   _чырв, _потт, _كعكا, ntav_
  { {0x23c60046,0x3ce90085,0x42c902d9,0x5fdc0065}},	//   víjí_, itav_, огон_, _बाइल
  { {0xb05b00c0,0x3ce90020,0x7d0d0e95,0x6284002d}},	//   rsäl, htav_, hvas, _phio
  { {0xc7b80085,0x0555006b,0xdb1c02de,0x76400034}},	//   _dođu_, _отля, _udrå, chmy
  { {0x66090064,0x95c8005e,0xdb1e0cf7,0x320c0046}},	//   mdek, _хліб_, rapé, ědy_
  { {0x6d44002c,0xdfd20015,0xddcd0085,0x749a000a}},	//   vzia, ضير_, vlaš, _ויספ
  { {0x6284002f,0xdee31921,0x66091922,0xada60033}},	//   _thio, кори, odek, дабл
  { {0x9e750054,0xb2ba000a,0x1e750004,0x2ca600e1}},	//   ећуј, _ומקר, еѓус, íodo_
  { {0x15e2005d,0x99840046,0xdd8f00c3,0xfc2a1923}},	// [2980] क्टर_, _romů_, لوف_, ожак_
  { {0x660900f2,0x6d441924,0x6441001a,0x26c7036d}},	//   hdek, rzia, nhli, ksno_
  { {0xf09301d8,0xdb1c0030,0x7d0909cb,0x501b000a}},	//   _שנת_, _keré, _šest, _וויו
  { {0xa2d5005d,0xddcd0024,0x2a600020,0xceb3000f}},	//   _भिन्, plaš, õib_, _שיר_
  { {0x08fa0021,0x8dfb000a,0xdb1c0030,0xb5fd003d}},	//   تراب_, _והכת, _meré, nošu
  { {0x6bd60015,0x645d0003,0xcee9002b,0x76aa0e60}},	//   _تتحر, ésil, _برین_, отив_
  { {0x8c3b00b8,0xda660058,0x98690058,0x0000006a}},	//   _fußb, _قاري, أحنف_,
  { {0xd5b00029,0x44250134,0x6674002b,0xba260033}},	//   دفة_, ejl_, رگار, _ўдак
  { {0x69c00048,0x7d1b0251,0x3494006b,0x5e77000a}},	//   _ieme, _àust, наир, ותקן_
  { {0xd90d0086,0xd4670001,0x682f0293,0x69c01925}},	//   _دیه_, миње_, _døds, _heme
  { {0x69c00d25,0x988b000a,0x734a030c,0xbbd705bd}},	//   _keme, _וָאֵ, ючив_, וויץ_
  { {0x9f58002c,0x06b10089,0x682f0293,0x6fdc000b}},	//   ceré_, žící_, _føds, _बाउं
  { {0x229a0048,0x656f00b8,0x69c00d25,0x7bce005c}},	//   _rīku_, ücht, _meme, _odbu
  { {0x6441018b,0xd0840080,0x69c01714,0xdb1500dc}},	//   chli, выси, _leme, _lezá
  { {0x32670063,0xfe73012c,0x33db000a,0x0000006a}},	//   _отив, ندر_, _וחוד,
  { {0xe5080023,0x27e9016f,0xbddb18b3,0xdb150057}},	//   _kỷ_, đani_, _amèr, _nezá
  { {0xa2da005d,0x61fd1926,0xdd030024,0x91bc000a}},	// [2990] पूर्, mesl, _ārēj, _ומחי
  { {0x66090064,0x54780008,0xb05b00f2,0xb5fd1927}},	//   zdek, פְּנ, isäk, lošt
  { {0xdb1500dc,0xf214000b,0xde190015,0x7d0d1928}},	//   _bezá, _तोड़_, _فقدت_, svas
  { {0xfe3500b2,0x69c01929,0xdb050003,0x61fd192a}},	//   _נאָך_, _ceme, nché, nesl
  { {0xda080086,0xe8ee0080,0xadd60008,0x61fd192b}},	//   بينه_, ыл_, _אורח_, iesl
  { {0x0138000a,0x6bd40015,0xb5fd0046,0x66e502db}},	//   ורדת_, _لتفر, hošt, еока
  { {0x9f580089,0x3ea10020,0x6609016b,0xbbcb000b}},	//   teré_, _juht_, tdek, ाणीक
  { {0x06540010,0x85570086,0x69c0192c,0xf1db000b}},	//   ктыў, ویار_, _geme, _भागन
  { {0x6441192d,0x61fd192e,0x6609151d,0x0000006a}},	//   thli, desl, rdek,
  { {0x03250083,0xe3b10029,0x60dd0020,0x26dc0007}},	//   едон, درة_, dusm, buvo_
  { {0x35b5192f,0x69cc0089,0x979a004c,0x69c01930}},	//   _збер, ůlež, _זשעק, _yeme
  { {0xcb1200b2,0x61fd0384,0x68340251,0xb5fd0024}},	//   אלט_, gesl, _ràdi, tošu
  { {0x25b90084,0x7bc50035,0xddc40089,0xb6340015}},	//   ðslu_, kahu, tliž, _جعلت
  { {0xf8b20008,0x14d6000a,0xd0120021,0x7bc51931}},	//   רשם_, _נוצל_, دلس_, jahu
  { {0x5e96003b,0x3a3f0064,0x63050029,0xf772004c}},	//   فلسط, _olup_, _أوبل, ָקן_
  { {0xf1bf0030,0xd356000a,0x61fd1932,0x929a004f}},	//   lján_, _ריקי_, cesl, _ציפת
  { {0xc692103d,0xd7e0005d,0x8fa6017f,0x6bd6002b}},	// [29a0] ראן_, _नालच, _папе, فتار
  { {0x69c01933,0xf1bf0030,0x539a000a,0xec770920}},	//   _seme, nján_, ִינו, епу_
  { {0x69c0064e,0x4fbb0008,0x5f460015,0xcb0a0015}},	//   _peme, _מציא, _أنجل, ثيان_
  { {0xf38c0053,0xfbc9000a,0x0f570643,0xda6600c3}},	//   קראָ, מת_, _טיים_, راضي
  { {0xa3cf005d,0xd83a0010,0x2610005d,0xbd9b0135}},	//   षणा_, зэй_, _दोषी_, _מסכת
  { {0xdb1e00dc,0x916d0092,0x26dc1934,0x394602c1}},	//   lapí, _hội_, tuvo_, rzos_
  { {0x8c1b00b2,0x316c0050,0x28d2000b,0xcc77000a}},	//   _צולי, ędzy_, _सिवि, _נעלה_
  { {0xe5c6004a,0xb21b02de,0xddd10091,0xdb1e006f}},	//   хско, mlæg, _įgūd, napí
  { {0xb21b02de,0xb5fd0085,0x0595009a,0x61fd007f}},	//   llæg, vošt, پايگ, vesl
  { {0xb05b00c0,0x60dd007c,0x43941935,0x7c2e1936}},	//   rsäk, vusm, капс, _jobr
  { {0xb21b0134,0x229a0024,0xe1ff002d,0x61fd1937}},	//   nlæg, _rīks_, nnóg_, tesl
  { {0x916d0023,0xe5080023,0xe5a30054,0x60dd1938}},	//   _nội_, _tỷ_, _бици, tusm
  { {0x7bc5003f,0x3ea10020,0xe5080092,0xdb051939}},	//   yahu, _suht_, _uỷ_, rché
  { {0x7c2e193a,0x251b000a,0xa3a9000b,0x61fd193b}},	//   _nobr, _מודא, गुआ_, sesl
  { {0xddc4005c,0x60dd007c,0x2240193c,0xfc3f0030}},	//   bliż, susm, _flik_, _ktív_
  { {0xb21b193d,0x82370015,0xb05b008c,0x442e0c8f}},	//   dlæg, _سرعا, isäi, _hof_
  { {0x3d1b005d,0x3a2d0177,0x7bc5193e,0x6c750054}},	// [29b0] नमें_, _roep_, tahu, влађ
  { {0xddeb04b6,0xac19005e,0x5d840015,0x6f03016e}},	//   _کرده_, ьозу_, الكل, _ânco
  { {0xfb190015,0x220b000a,0xbb190015,0x7c2e193f}},	//   بقاع_, ּפְּ, بياض_, _dobr
  { {0x7bc504af,0xf2d30053,0x5ee8000a,0x442e1940}},	//   sahu, רעף_, _אַשְ, _lof_
  { {0x7c95003b,0x7bc50035,0xb21b0134,0xbddb0251}},	//   _للحص, pahu, lmæs, _elèc
  { {0xbddb0152,0x46f50036,0x25a9002a,0x28d2000b}},	//   _flèc, вчит, _żal_, _सिरि
  { {0x1c0a005d,0xddcd005c,0xe7080015,0xaa59107f}},	//   _होटल_, miał, فتين_, _живу_
  { {0x60cd016f,0xb05b00f2,0x7c2e0264,0xa8020061}},	//   _ovam, ssäh, _zobr, çıra
  { {0xe1ff00dc,0x93fd0010,0x98f400e5,0xe81e000b}},	//   deó_, оўнi, _مثلا, पाशा_
  { {0xddcd005c,0x442e0026,0xcad5000a,0x22401941}},	//   niał, _cof_, ֣וֹת_, _slik_
  { {0x22400050,0xf1c30023,0x60cd1942,0xb21b02de}},	//   _plik_, _trở_, _avam, klæd
  { {0x6b9a002e,0xe6040015,0x3552009a,0xe3b1009a}},	//   _útge, _مِمَ, انیز, درک_
  { {0xf1bf0014,0xdd010089,0x4103006b,0x45b6000a}},	//   pján_, čtět, азяв, _ספסל_
  { {0x65940124,0xd4790053,0x442e0034,0x2a7d0034}},	//   _сачу, _קאַל, _gof_, hlwb_
  { {0xf456000a,0x83f60054,0xd466029f,0xbfc31943}},	//   _שיצר_, _рејс_, _шише_, рбск
  { {0xb17b00c0,0x8d760015,0x7c2e0ec1,0x224000cb}},	//   mgån, ناءا, _sobr, _ulik_
  { {0x660b00b6,0xb17b00c0,0xdca303ad,0xed571944}},	// [29c0] _magk, lgån, иати, вот_
  { {0x2137015b,0x660b02dc,0x30760132,0x0000006a}},	//   _סטיל_, _lagk, _шуйс,
  { {0x9f4800f2,0xfaa30033,0xb17b0123,0x8b9612ba}},	//   ähän_, аахо, ngån, трач
  { {0xb21b0084,0x660b0035,0x7c2e0034,0x5d860015}},	//   rlæg, _nagk, _wobr, _للجل
  { {0xb21b0134,0xd94603ad,0xda650021,0xddcd002a}},	//   slæg, ъеди, دالي, biał
  { {0xddcd005c,0x987302e5,0x2b4d0046,0xf770009a}},	//   ciał, аліц, _řece_, یاژ_
  { {0x44200023,0x97c50015,0x7d040012,0x97240015}},	//   _đi_, اتهم, lwis, افعو
  { {0x2619000b,0xf76f0015,0xb17b0123,0x6b830359}},	//   भागी_, غاو_, dgån, ünge
  { {0x2ca6017e,0x57ea000d,0x25f3000b,0xdb1c1945}},	//   íodh_, _одам_, ्ज़ी_, _merí
  { {0x93b40033,0xa9750054,0xd83800b3,0x6a7809ae}},	//   ыбоц, _сусј, _biče_, rífu
  { {0x7bdb000a,0xdb150012,0x66270061,0x7d0401f1}},	//   וקיו, _gezä, ürkç, hwis
  { {0xddcd005c,0x7d04003f,0xb21b1946,0x7e0c000b}},	//   ział, kwis, emær, हयोग_
  { {0x7642003f,0xa4d40036,0xa9bb000a,0x6a78001a}},	//   _iloy, _солі, וזכר, lífs
  { {0xb21b1946,0x6697004c,0xf993015b,0x1074005e}},	//   gmær, _נאַרײ, ירר_, иляю
  { {0xf8c80092,0x7d040313,0x925b0015,0xadd50054}},	//   hứ_, ewis, _يشعر_, ловљ
  { {0x63970008,0x12870086,0xddcd005c,0x6d0e000b}},	//   _בדוא_, _جمعی_, wiał, सिंग_
  { {0xd90404b6,0xebc70124,0x2d580a2c,0xb21b0134}},	// [29d0] _بی_, вљен, вить_, smæs
  { {0x5fb7000b,0x6bd40067,0x61f60046,0x76421947}},	//   _अभिल, لتمر, _zbyl, _lloy
  { {0xddcd005c,0xc174002b,0x8c3b0012,0x98b8003d}},	//   riał, _مدیت, _fußn, _ārā_
  { {0x629e0152,0xddcd005c,0x7f3a000a,0x22591948}},	//   _épou, siał, _נערו, nisk_
  { {0x4dda013a,0xbd6b0001,0xddcd002a,0xdb1c1949}},	//   _אחרו, _црне_, piał, _cerâ
  { {0x07090015,0xb7d90015,0xd366009a,0xd7c902be}},	//   فيتي_, روعا_, _هه_, روبه_
  { {0x660b025c,0x06f50015,0xf0940643,0xd7e4005e}},	//   _pagk, استج, בנס_, річо
  { {0x9f9c0008,0xceb40008,0xdb0700dc,0xf509194a}},	//   וסופ, ביק_, _bejö, енил_
  { {0xd919000a,0x614a0003,0xb05b0012,0xddcd002a}},	//   _אוּל, _mêlé, lsäu, miań
  { {0x2c1c000b,0x9cd6000a,0xb17b0123,0x7d7c000a}},	//   नाएं_, נותה_, tgån, ונחו
  { {0xc7350087,0x7d04194b,0x8c1a000a,0x9234004c}},	//   _حفاظ, zwis, גותי, אָרט_
  { {0x7d04005c,0xb17b00c0,0x41b6004a,0x98bd002a}},	//   ywis, rgån, ысот, azwą_
  { {0x1c03000b,0x7fd600e2,0x6fd600ce,0x5155194c}},	//   रजाल_, ліві, лівц, атру
  { {0xdb1c02c1,0xd838044c,0xf1e8000b,0x8f760033}},	//   _serí, _tiče_, ट्ज़_, губі
  { {0x9e66002b,0xdb1c194d,0x2259194e,0x7f860058}},	//   هارن, _perí, bisk_, الأن
  { {0x22590050,0x25ad194f,0xb21b02de,0x11e6004a}},	//   cisk_, ncel_, smær, _сжим
  { {0xb21b02de,0xdb1c1950,0xc1060015,0xddcd002a}},	// [29e0] pmær, _verí, _صودي, diań
  { {0x5f760086,0x629e0251,0xdb1e0125,0x7d041951}},	//   _ماجر, _èpoc, eapá, rwis
  { {0x41b8000b,0xe9da1952,0x7d040012,0x28c6000b}},	//   _आभास, еке_, swis, रीनि
  { {0x539a000a,0xfe42002b,0xe9e5005e,0x38c8002b}},	//   גיעו, _اکسی, иціо, ناتی_
  { {0x91bb000a,0x27150016,0x9f581953,0x64430030}},	//   גמני, _h́nh_, lerà_, _olni
  { {0xdcfd0048,0xf5390046,0xe89400e2,0x0000006a}},	//   _uzsā, dyť_, шаль,
  { {0xf1ba0023,0xeab401e4,0xcc870015,0xbb460004}},	//   _đơn_, _כִּי_, _إنّه_, _севк
  { {0xfb1b0008,0x7e640a54,0x963416e7,0xb05b0400}},	//   _אולמ, nnip, рниц, lsät
  { {0xc9660010,0x3d17000b,0x9f5802b9,0x6a6b000a}},	//   _свай, निये_, herà_, _טֻמְ
  { {0x54540661,0x2259005c,0x68e20a6d,0xc4f70015}},	//   рвот, wisk_, muod, اعيا_
  { {0xd5e20023,0x5c5b0053,0xb05b00f2,0xb8930029}},	//   _chọ, תדיק, isät, _اللع
  { {0xbb3b0053,0x3eb800bc,0x9f581953,0x64430091}},	//   געטי, dprt_, derà_, _elni
  { {0xf1bf00dc,0x27150092,0x25f3000b,0x7c3e00cb}},	//   lják_, _ánh_, ्जरी_, kkpr
  { {0x33940010,0xd40a0015,0x61e602f2,0x22591590}},	//   _калё, _ستتم_, agkl, sisk_
  { {0x33170029,0x343b0053,0x645a1954,0xa6f8000a}},	//   _مزيد_, _אײגע, miti, כִּי
  { {0x442c00c0,0x9757000a,0xc333000a,0x68e20091}},	//   ljd_, אילו_, _לוצ_, kuod
  { {0x26c10014,0x5d990010,0x644800f2,0xdc550292}},	// [29f0] ához_, ткаў_, ohdi, авањ
  { {0x68e20007,0xddcd005c,0x40ec000a,0xe7e0000b}},	//   duod, wiań, _נַחֲ, _नागप
  { {0xcb550124,0x442c0111,0x443e1955,0xdb0e00b8}},	//   јвећ, ijd_, ikt_, _gebü
  { {0xdb1c03af,0xf1bf00dc,0x99a80029,0x20031956}},	//   _serã, dják_, هُمْ_, leji_
  { {0x443e002e,0x89a80036,0xfc3f002d,0x645a1957}},	//   kkt_, уків_, _dtír_, kiti
  { {0xccf20008,0x443e0111,0xd8b80015,0x3158015b}},	//   _וכך_, jkt_, ادنا_, ניגן_
  { {0xaa950036,0xf1bf00dc,0xfc3f02c1,0xdb1c001c}},	//   _вивч, gják_, _guía_, _verã
  { {0xe6c40029,0xceb400f3,0x443e1958,0xcf58000a}},	//   حتوي, זיק_, ekt_, טבות_
  { {0xdb1c001c,0x7bc70375,0x69cb1959,0xdcef003d}},	//   _terã, _keju, mage, _izcē
  { {0x4d7c0053,0x6448002d,0xf539002c,0x8cdd000b}},	//   ערזע, ghdi, ryť_, _पिनो
  { {0x9f58195a,0x628d0125,0x200305ca,0xcc56000a}},	//   xerà_, _bhao, deji_, שבתי_
  { {0x7bc70048,0x443e0111,0x38ab0134,0x9f5804ed}},	//   _leju, akt_, _kør_, verà_
  { {0x628d002f,0x9f58195b,0x645a195c,0x38ab00cb}},	//   _dhao, derá_, biti, _jør_
  { {0x443e195d,0x7649002e,0x645a195e,0x6d4d0079}},	//   ckt_, lhey, citi, dzaa
  { {0x94740029,0x68e20007,0xe516000b,0x0e560054}},	//   _ادنا, zuod, तिथि_, ађар
  { {0x628d002d,0x9f5802b9,0xd24f0015,0xdb1c006f}},	//   _ghao, rerà_, _ينو_, _nerá
  { {0x527b0008,0xb05b03a4,0x6486002e,0x127b004c}},	// [2a00] _בנקא, tsät, iðin, _באקע
  { {0xdb1c002d,0xb05b0012,0x9c230054,0xbab60015}},	//   _aerá, usät, одуд, لمطب
  { {0x49ca0080,0xb05b0c77,0x3fdb000a,0x9f58195f}},	//   влен_, rsät, _בקיב, berá_
  { {0x4e030010,0x38ab169b,0xb05b0f3a,0x9f580656}},	//   _дзюб, _bør_, ssät, cerá_
  { {0xb05b00c0,0x39400ab3,0x6448008c,0xd9d7005e}},	//   psät, áis_, yhdi, рмії_
  { {0xf1bf0014,0x2c1c005d,0x68e20007,0x26dc0085}},	//   tják_, नाओं_, ruod, trvo_
  { {0x68e200f2,0x39400007,0x45d40010,0x7d160089}},	//   suod, šis_, бойс, lvys
  { {0xd6260029,0x2619005d,0xb6e30010,0x96b700e6}},	//   شعبي, _मोदी_, цюшк, جاوز_
  { {0x38ab00fb,0x37e60080,0x645a1960,0x04660973}},	//   _gør_, _возг, titi, итом
  { {0x628d002f,0x9f58002c,0x443e003d,0xf1bf0030}},	//   _shao, zerá_, ukt_, pják_
  { {0xcc3b0053,0xfbd3000a,0x7414002b,0xa87b000a}},	//   דעיט, חתת_, لوکا, _יאמר
  { {0xa75b0008,0x443e1961,0x7ae30144,0x6f09002a}},	//   _בדבר, skt_, ànti, łeck
  { {0xc05b0191,0x9f58001c,0xdcef0024,0x51870010}},	//   вів_, verá_, ādīs, руна
  { {0xc05b0036,0xdb1e0251,0x02a606fe,0x853b000a}},	//   тім_, capç, _крим, _בגדי
  { {0xa2e3000d,0xdb1e0020,0x628d002d,0x44f00291}},	//   _дојд, napä, _thao, là_
  { {0x2003003f,0x7bc7064e,0x98bd005c,0xb05b00f2}},	//   seji_, _seju, azwę_, tsäs
  { {0x629f0152,0x2ba70001,0xdb1e0020,0xdb050264}},	// [2a10] _époq, ајев, hapä, dchá
  { {0x44f002d7,0xdb1c02c1,0x6d4d0111,0x6e2d0079}},	//   ià_, _será, rzaa, sjab
  { {0x44f00092,0x2bb9005d,0xb05b1581,0x38ab13e1}},	//   hà_, इडबा, ssäs, _sør_
  { {0xceb200b4,0xc212000a,0x7d0b02de,0xe0df01e0}},	//   _מיט_, ּ֔א_, ægss, orò_
  { {0xe9d80010,0xdb1c0fc9,0x79800034,0x78eb004a}},	//   ркі_, _verá, _cymw, тьев_
  { {0xfd96000a,0x44f00144,0x1bb800c3,0xb0b8000a}},	//   _לדרך_, dà_, _نافع_, ספוס_
  { {0xb9e70036,0xdb051962,0x69cb1963,0x87040015}},	//   _візи, rbhó, page, قبيل
  { {0x62560007,0x683d0251,0x99d40015,0x38ab0013}},	//   ršok, _mèdi, _وتقا, _tør_
  { {0x64860084,0xf8070036,0x79800026,0x49040015}},	//   rðin, _вчен, _gymw, _ووفق
  { {0x04450054,0xddcd00bc,0x76950091,0x61ed1964}},	//   сеон, jlaž, _ašyt, _acal
  { {0x9f580251,0xe0df1732,0x60c41965,0xddcd18b1}},	//   merç_, erò_, _swim, dlaž
  { {0x44f00144,0x78a11966,0x7d16008c,0x0000006a}},	//   bà_, _hilv, yvys,
  { {0xf6740029,0x44f00251,0x78a91967,0x25bf142d}},	//   _بالخ, cà_, _juev, mbul_
  { {0xf992000a,0xf3f10015,0x78a90077,0xb97a004f}},	//   פרם_, _رأت_, _muev, רנשי
  { {0x7ae50020,0x61ed00f2,0xf1bf00dc,0x3e860015}},	//   juht, ällö, bbá_, مشرف
  { {0xf8a504b6,0x60db0007,0x25bf1968,0x6ca60015}},	//   _يک_, šuma, nbul_, مصطل
  { {0x78a90467,0x64410024,0x925a002b,0xc692000a}},	// [2a20] _nuev, okli, _لشکر_, לאל_
  { {0xdd8f00e6,0x64411969,0x3157000a,0x8b9601b7}},	//   رول_, nkli, _ליפן_, бреч
  { {0xb09b0008,0x3ad30015,0x25bf01c2,0x6441196a}},	//   _תייר, كيلز, kbul_, ikli
  { {0x0dba0029,0xd9100086,0xdb1e0020,0xdb050046}},	//   _حادث_, ویز_, vapä, uchá
  { {0x78a9010d,0x44f00144,0x807a000a,0x9e630033}},	//   _cuev, xà_, ְנֶצ, _хвяд
  { {0x78a10048,0xb900005d,0x76590034,0xaad1000b}},	//   _cilv, _थि_, _amwy, _हिचक
  { {0x61b8000b,0xbbc4000b,0x1ae318c3,0x5694012a}},	//   _आभूष, षरीक, _норм, оакт
  { {0x44f002d7,0x44b40191,0xbb3b0053,0xc8e0005d}},	//   tà_, обис, _געלי, _निपट
  { {0xb4260015,0xdb1c196b,0x78a9196c,0x9f5a0030}},	//   معدو, _berç, _guev, _kapó_
  { {0x25bf0064,0x44f0196d,0x64410035,0x9f5a0251}},	//   abul_, rà_, gkli, _japó_
  { {0xcc7b00b2,0xe2f80036,0x78730015,0x95c6002b}},	//   רװיר, шені_, _عُما, _هياه
  { {0x644100dd,0x3ea2005c,0x78a10111,0xe0df04ed}},	//   akli, _nikt_, _zilv, trò_
  { {0xdb1c00f2,0xf5960029,0xd516002b,0x867b0643}},	//   _herä, _الشج, _دباغ, _גראו
  { {0xdb1c196e,0x61ed005c,0x6441196f,0xe0df02b9}},	//   _gerç, _wcal, ckli, rrò_
  { {0x76590026,0xc058042b,0xc6d8000f,0xb3f7000a}},	//   _ymwy, сія_, יַּר, _המוח_
  { {0x74bf000b,0x8de50058,0x2fdf00d4,0x0000006a}},	//   लीकृ, تكره, şug_,
  { {0x7c35002c,0xdd9401b0,0x3ea20795,0xdb1c0061}},	// [2a30] _pozr, заты, _dikt_, _yerç
  { {0x4d98044e,0x3ea2003d,0x25bf01c2,0xbc3b009a}},	//   скую_, _eikt_, zbul_, دسرا_
  { {0xfbd00029,0x29d50029,0xdc300091,0x5f95029f}},	//   عتك_, قياس, ažįs, _финт
  { {0x64410024,0x78a11970,0x7ae50a94,0xdd2b0030}},	//   zkli, _silv, ruht, sőűr
  { {0xbcfb001c,0x7ae50044,0x49c801f3,0x7c871971}},	//   _exér, suht, слін_, _гуве
  { {0xdb1c01d1,0xdd31005c,0xd0f8000a,0x8aa71972}},	//   _berä, zęśc, צמות_, _град
  { {0x20131973,0xf6d5005e,0x8ca20065,0x6e38013b}},	//   _maxi_, ціля, _कूटो, žabš
  { {0xe892006f,0x44f90033,0x56920099,0x625601c0}},	//   ĺňať_, ахоў_, мајт, lšov
  { {0x78a1075b,0x89370086,0xe9d9005c,0x58050015}},	//   _tilv, _اعزا, _idź_, _وورك
  { {0x99480029,0xf9900029,0xa9880008,0x64411974}},	//   _الكل_, _سبق_, _הָעִ, ukli
  { {0xdb1c00b8,0xc5d50036,0xb21b0134,0x8bd6000a}},	//   _gerä, _діль, rlæn, חותו_
  { {0x99f90053,0x625a004a,0x64411975,0x28e00065}},	//   ױפֿפ, ррор_, skli, _निमि
  { {0xdb1c168c,0x99f6000a,0xa2d5000b,0x7a88000a}},	//   _terç, חזרה_, _भिक्, מָשַ
  { {0x224900d9,0xf8b2000a,0x2d8200aa,0x3ea20795}},	//   _elak_, ושך_, _ryke_, _sikt_
  { {0x03250036,0x82860015,0x4fa3006b,0x6b830012}},	//   _єдин, _وجعل, дирв, üngl
  { {0x3f8403eb,0xdcf7005d,0xedf4002b,0x1e8600e2}},	//   āmu_, ुबंध_, ثيرگ, ілам
  { {0x62730029,0x3ea200c0,0x0d9a056d,0xdbca0248}},	// [2a40] _تهيئ, _vikt_, ртвы_, игад_
  { {0x39420020,0x62861976,0xc8e0000b,0x6b660248}},	//   _üksi_, llko, _निबट, окза
  { {0x0b460010,0x3ea20024,0x6da600ff,0xe7ed000b}},	//   ўнен, _tikt_, _мина, च्छा_
  { {0xaac50015,0x66fc003d,0xf9861977,0x99460058}},	//   ستمن, nākš, огео, يَاه
  { {0xa3e9000b,0xf1bf0030,0x62861978,0x082a1979}},	//   यला_, mját_, ilko, ицки_
  { {0xdb1c00f2,0xf1bf00dc,0x410b000a,0x9f58008c}},	//   _perä, lját_, שִׁ֣, perä_
  { {0x27e001e2,0xf7930010,0x38c8002b,0xa09b000a}},	//   ğin_, машэ, _گازی_, ביסט
  { {0xdb1c00b8,0x67f4002e,0x27e0062c,0x8f9b000a}},	//   _verä, fþjó, şin_, סיקי
  { {0xd40603ad,0xe46a0004,0x746a0e1a,0x69c2197a}},	//   ояни, ишол_, иров_, mboe
  { {0xb3540805,0x68e20026,0xdb1c00f2,0x6abe00cb}},	//   зкош, mrod, _terä, oppf
  { {0xf1bf00dc,0x68e4002d,0x22490150,0x28c6000b}},	//   kját_, áidf, _plak_, रीरि
  { {0x64a6197b,0x68e2197c,0x22440015,0x69c2197d}},	//   _дада, orod, ِنَّ, nboe
  { {0x1a9b00b2,0xf1bf00dc,0xba9b04dc,0x2beb021e}},	//   ייטע, dját_, יסטי, _चालू_
  { {0xadee005d,0x7414002b,0x68e20030,0x6286197e}},	//   ङ्घन_, _روبا, irod, alko
  { {0xd83800bd,0x6fbf000b,0x69c216f3,0xce95006b}},	//   _moč_, ्रबं, kboe, завъ
  { {0xf1bf00dc,0x68e20205,0xd019002a,0xe731000a}},	//   gját_, krod, śń_, עֵם_
  { {0x5d550549,0xa3ae005d,0xfbab034e,0xdfa70015}},	// [2a50] чкат, _कला_, атей_, _وحدي
  { {0xf1bf00dc,0x68e2197f,0xd83800bc,0x4c940a32}},	//   aját_, drod, _noč_, диус
  { {0xb5fd0f81,0x30a40033,0x68e21980,0x625601c0}},	//   liše, _ўрыв, erod, ršov
  { {0xc33300b2,0x5a350063,0x69c20111,0x539b000a}},	//   ווע_, янет, gboe, ביבו
  { {0x2ca30298,0x68e2005c,0x62560107,0x4054002b}},	//   _tijd_, grod, pšov, _رئیس
  { {0xdb150030,0x96f90015,0xe1ff0030,0xd7fb0189}},	//   _kezü, معبر_, liód_, руд_
  { {0x44290023,0x3ffc00b2,0xb6590080,0x17f80015}},	//   _đa_, יפגע, йших_, ترنة_
  { {0x67f4002e,0x68e21981,0x05b90015,0xdb050012}},	//   tþjó, brod, حدثت_, rchä
  { {0xdb05018b,0xc68e0015,0x66fc003d,0x7d0d1982}},	//   schä, دِي_, vākš, nwas
  { {0x67f4002e,0x87270015,0x7d0d02f2,0x28e00065}},	//   rþjó, _وعام, iwas, _निति
  { {0x58840010,0x67f4002e,0x59cf000b,0x2bfd000b}},	//   _цыта, sþjó, _हजार, र्यू_
  { {0xdb120014,0x6286003d,0x83fc0085,0x41e50015}},	//   égév, ulko, viđe, وسُف
  { {0x271c0023,0xa5670086,0xf221000b,0xd24f0015}},	//   _ảnh_, _بدان, याज़_, انُ_
  { {0x66fc0024,0xdb1500b8,0x94ba000a,0xa879004c}},	//   sākš, _bezü, _המסת, מאָר
  { {0xa2d20015,0x44271983,0xf1bf0030,0x7d0d1984}},	//   _كيوت, _inn_, tját_, ewas
  { {0xdd920029,0xd24f0015,0x68e2002a,0x66091985}},	//   فوز_, _منى_, yrod, neek
  { {0x59cf000b,0xf1bf0030,0x16c80065,0xad250058}},	// [2a60] _हज़र, rját_, _रब्ब, وركو
  { {0x66091986,0x4c830345,0x515b000a,0xac830c71}},	//   heek, елув, _לכפו, егул
  { {0x103b0008,0xf1bf00dc,0x291f003f,0xda6f006b}},	//   _הגיע, pját_, _arua_, ея_
  { {0x200a0064,0xdca61987,0x7d0d003f,0x20181988}},	//   lebi_, _нами, bwas, ldri_
  { {0xb05b0020,0x68e20007,0x69c20159,0x7d0d0026}},	//   späe, urod, rboe, cwas
  { {0xb17b003c,0x2af60033,0xd8230054,0x764b0034}},	//   mgåt, _нябё, едљи, _algy
  { {0x20180024,0xa91d099c,0xa09b0135,0xbbba000b}},	//   idri_, _vyža, זיסט, ेरीक
  { {0x4427002f,0x54b803ad,0xe4e6005e,0x46a30054}},	//   _ann_, огия_, піон, најв
  { {0x7bce064e,0x88c50015,0x48e30289,0xb17b00cb}},	//   _kebu, _يتكل, _потв, ngåt
  { {0x88bb000a,0x986a0015,0x200a0085,0xb5fd06c0}},	//   _לזמי, _احرف_, jebi_, više
  { {0x67bb0008,0x77bb000a,0xf3660342,0x2018001a}},	//   _המבק, _המבח, ятин, ddri_
  { {0x7d0d005c,0x44271989,0x9f58006f,0xf1bf0030}},	//   ywas, _enn_, berú_, ejár_
  { {0x867b000a,0xba57004c,0xda7b000a,0x067b000a}},	//   _פרדו, לסטו_, מנטר, _פנדל
  { {0xc0580010,0xd59b0008,0xb5fd0796,0x859b000a}},	//   піс_, _הבדל, riše, _השדו
  { {0x33fb009d,0x8c3b00b8,0xa3e9000b,0x93fb000a}},	//   _להגנ, _mußt, यलर_, _הלוי
  { {0x7d0d0035,0xb5fd0796,0xf3130015,0x1eea002b}},	//   twas, piše, _أبوظ, توفی_
  { {0x62560007,0x200a0064,0xa6970008,0x41c3000b}},	// [2a70] ršot, bebi_, לכלה_, _व्यस
  { {0x7c140036,0xfbab0033,0x5458000a,0xdb070030}},	//   ндує, стай_, קֳּד, _ifjú
  { {0x2bb80029,0x6ffa000a,0x99d70015,0x7bdc0034}},	//   سالة_, _והתפ, كتشا, _ddru
  { {0xa3dc005d,0xfd1f0092,0x43770053,0x2cb90015}},	//   तृत_, _trì_, הײבן_, _وُجد_
  { {0x9f5102c1,0x28a7004a,0x6609007c,0xf9900021}},	//   pezó_, чшег, veek, هبه_
  { {0x7bce059b,0x6fbf000b,0x7e6d0030,0x6609198a}},	//   _gebu, ्रिं, lnap, week
  { {0xe7360063,0x6d400020,0xac94198b,0x6609198c}},	//   дещ_, _ümar, _чарш, teek
  { {0x7bdc198d,0x7e6d030f,0x61fd0079,0xddc40045}},	//   _zdru, nnap, jfsl, mniţ
  { {0x6fbf005d,0x7cde0011,0x7e6d198e,0x66090161}},	//   ्रां, părţ, inap, reek
  { {0x68e4002f,0xcc3a0053,0x61fd002e,0x7e6d198f}},	//   áide, ַערט, efsl, hnap
  { {0x420a02c8,0xfbd2000a,0x8c1c000a,0xc7b2000a}},	//   онно_, כתי_, מוזי, _סבא_
  { {0x1fc60372,0xd9ff005d,0xc049000a,0xf7480015}},	//   वर्ड, ोजित_, _דז_, _علني_
  { {0xd4350029,0x113a0033,0x7e6d1990,0x241908f0}},	//   _يعتب, цяны_, dnap, _моды_
  { {0xe800000b,0x24180033,0x2bb2000b,0x859a000a}},	//   ल्पा_, _ночы_, _जलधा, _ושנו
  { {0x7bce1991,0xa28a0015,0x92660015,0x10a30296}},	//   _rebu, _وضعك_, _يدعم, тирн
  { {0x7bdc01cb,0x7bce013c,0x200a1992,0x67210085}},	//   _sdru, _sebu, sebi_, _mrlj
  { {0xd59a004c,0x6aae1993,0x6abc1994,0x0000006a}},	// [2a80] ַבעל, _subf, _strf,
  { {0x7e6d0035,0x1daa000b,0xfce30c02,0xb17b02dc}},	//   anap, _कलकत, тофо, rgåt
  { {0x28e0000b,0x5f76002b,0x4fd7000a,0xddc6004a}},	//   _निहि, _زادر, _קוטב_, _обни
  { {0x533600b2,0x1bf0000b,0xb9b4002b,0x7bce1995}},	//   ונען_, _चावल_, رمتع, _webu
  { {0x644f0024,0x7c490030,0xd8b70015,0x7bce1996}},	//   īcij, ásró, ودوا_, _tebu
  { {0x7bdc016f,0x8884002b,0xdb240045,0xa157000a}},	//   _udru, ریان, ăsân, ובנה_
  { {0xba0a0015,0x62840091,0x68e40125,0x61fd00aa}},	//   _وترك_, _okio, áidb, yfsl
  { {0x44200440,0x8c3b0012,0x151401b7,0x7c3c16c8}},	//   _şi_, _wußt, едия, _horr
  { {0x6d440375,0x7c3c1997,0xd6770015,0xf3f10016}},	//   nyia, _korr, بحوا_, hịu_
  { {0x03f80001,0xdb1c01f0,0x62840573,0x798d002a}},	//   чној_, _berø, _akio, żawc
  { {0x8c1b000a,0x17790033,0x7c3c1998,0xe7d5002b}},	//   קוטי, _есць_, _morr, _سمنگ
  { {0x68ed0780,0x75460063,0x1fb7000b,0x63ad1999}},	//   žodž, _онез, अड्ड, _şant
  { {0x61f4002c,0xa19400e2,0x61fd199a,0x7c3c0547}},	//   _želá, каюч, rfsl, _oorr
  { {0x7c3c199b,0x20840015,0x30840015,0x0000006a}},	//   _norr, َلَّ, َلَف,
  { {0x9f5f0064,0xe3b80064,0x75220057,0xa3b70015}},	//   _ürün_, mcı_, _hroz, _غاور_
  { {0x7e6d003f,0xd717000a,0x60380061,0x91690016}},	//   unap, וחלט_, _aşmı, _lửa_
  { {0x7c3c0c07,0x28e0000b,0x8d770067,0xb1b9002a}},	// [2a90] _borr, _निषि, ذارا, ążąc
  { {0xe3b80064,0x2ca7199c,0x7c3c1103,0x6f050016}},	//   ncı_, önd_, _corr, _tphc
  { {0x7c3c0335,0x30780015,0x660200bc,0x443c199d}},	//   _dorr, _تحية_, _obok, _mov_
  { {0x60cd199e,0xddeb0086,0xddc40011,0x7a390010}},	//   _kwam, _برده_, rniţ, япер_
  { {0xa8030064,0xb90b00a2,0xc27c000a,0xf8b1002b}},	//   _çıkt, تزام_, חראי, اکر_
  { {0x91690092,0x60cd003f,0x68eb0159,0x6e3d0034}},	//   _cửa_, _mwam, rugd, _hosb
  { {0xddc400bd,0x98bf0064,0x394915ff,0x1ab40010}},	//   lniš, ırım_, šas_, _абся
  { {0xf7700031,0xddc40085,0x83fc0085,0x7c3c199f}},	//   جاه_, oniš, viđa, _zorr
  { {0xc8f40063,0x22920046,0x6e3d00c7,0xd7fb0a15}},	//   _изтъ, jáka_, _mosb, _муж_
  { {0xe1ff002a,0xe5760033,0xf8b2000a,0x87070015}},	//   onów_, эзы_, _עשב_, _يبال
  { {0x13a70086,0x63ad19a0,0xc169000a,0xddc400bc}},	//   بندی_, _şans, _פח_, hniš
  { {0xf0890008,0x23bf000b,0x28c6000b,0x64480061}},	//   _הנ_, _श्रद, रीकि, akdi
  { {0x321e0089,0xc56b0040,0xddc402d8,0x752219a1}},	//   ěty_, _بحال_, jniš, _groz
  { {0x653a0053,0x661b19a2,0xddc402c6,0x853a000a}},	//   _מענד, lduk, dniš, _מגני
  { {0x7522095b,0xc2c80115,0xc7b2000a,0x6e3d0079}},	//   _zroz, _قبيل_, רבל_, _bosb
  { {0x82360074,0x6e3d19a3,0x6aa9002a,0xb05b008c}},	//   _سربا, _cosb, _nief, isäy
  { {0x6e3d0026,0x33f90008,0xb05b008c,0x1d0702b0}},	// [2aa0] _dosb, ּהֲנ, mpän, нети_
  { {0xe0fb0008,0x31570053,0x661b008c,0x7e6405ff}},	//   _צליל, _ניין_, hduk, siip
  { {0x4ff70053,0x7c3c19a4,0x916900a1,0x7d1b005a}},	//   _אזיע_, _vorr, _rửa_, _šust
  { {0x91690023,0x7ae3002f,0xddc4018c,0x78a800c0}},	//   _sửa_, ánta, bniš, _sidv
  { {0xe3b80061,0x5f76002b,0xc98319a5,0xe1ff002a}},	//   ycı_, _زاگر, луши, anów_
  { {0xa9670029,0x98a312bd,0x260a0016,0xb5fd19a6}},	//   عموم_, гиче, _ẹo_, viša
  { {0x09e60191,0xda660015,0x75220046,0xe3b80061}},	//   _повн, _كاري, _sroz, vcı_
  { {0xceb30008,0x8afb000a,0x752219a7,0xe8fa0004}},	//   ניח_, _מהלי, _proz, _нлб_
  { {0xc8ca0018,0x7d1b016e,0xe4740054,0x78a80804}},	//   _روان_, _áust, клињ, _tidv
  { {0x201a0014,0x07a613ae,0x78250029,0x7b070030}},	//   _napi_, _зазн, _لعمل, _írtá
  { {0x60cd19a8,0xddc40844,0xb5fd0091,0xe3b80061}},	//   _swam, zniš, siša, rcı_
  { {0xd3770010,0xb5fd0fd0,0x752219a9,0xe606008c}},	//   эчы_, lišn, _troz, äsää
  { {0x865b000a,0x44f90144,0x2619000b,0x1ee7002b}},	//   _צדדי, cè_, _मोटी_, کوزی_
  { {0xddc40263,0xc56900e5,0x20cd044c,0xe1ff002a}},	//   vniš, _تحمل_, rži_, ynów_
  { {0x141b0008,0x6e3d00dd,0x4ee40033,0xadd50054}},	//   _מוגב, _posb, літз, ковљ
  { {0xddc40844,0x6d1c000b,0x9f6001d3,0x0000006a}},	//   tniš, निंग_, árát_,
  { {0x22ac0089,0x7db40015,0xc27c000a,0x6aa919aa}},	// [2ab0] _věku_, اصفا, _מרהי, _rief
  { {0x31580053,0xddc40844,0xb05b008c,0xb5fd0085}},	//   _ריזן_, rniš, ysäy, jišn
  { {0xb5fd19ab,0xcfb60008,0x99f50010,0xd07400a2}},	//   dišn, _בלתי_, вялі, _حديث
  { {0xee21005e,0xe1ff002a,0xddc4036d,0x314b000a}},	//   _темi_, rnów_, pniš, ּתַּ
  { {0x9dd60053,0xdfa7002b,0x9be7005e,0x62640030}},	//   _בורק_, _تحکي, _півк, dőol
  { {0x6bd40115,0xddeb002b,0x7ae2003d,0x6486001a}},	//   _متفر, _برگه_, ņota, iðis
  { {0x6aa900b8,0xe3b10086,0x39460035,0x79c90115}},	//   _tief, یرد_, ayos_, _يوسف_
  { {0x6b8302ad,0x44f903a0,0xdb1e03a0,0x0000006a}},	//   üngu, tè_, aapó,
  { {0x44f90251,0xe4d6002b,0xf495004a,0x04950033}},	//   uè_, نويت_, крою, кроў
  { {0x764910d0,0xe5040015,0x661b19ac,0x032502ed}},	//   skey, ابيي, sduk, вдон
  { {0x35f50010,0x201a0375,0x95d9004a,0x6b8c000a}},	//   _апер, _rapi_, _ждет_, ּאכֵ
  { {0x201a00e8,0x216a0758,0xcb12000a,0xe1f20015}},	//   _sapi_, дими_, בלט_, جسد_
  { {0x2124002d,0x89da000a,0x6fd6005e,0xe535006b}},	//   ímh_, וחרי, ківц, _шедь
  { {0x0596002b,0x3a3f19ad,0x8548005e,0xdcee003d}},	//   _شانگ, _loup_, _язів_, ūdīg
  { {0xfc3f0f14,0xe1ff0077,0x201a0072,0xb05b005b}},	//   _luís_, mión_, _vapi_, ppän
  { {0x201a003f,0x33760008,0x2ee5001a,0xe1ff19ae}},	//   _wapi_, _בעצם_, álfa_, lión_
  { {0x201a013c,0x70560015,0x84ac000a,0xbea319af}},	// [2ac0] _tapi_, _لنظا, ִיאִ, ратк
  { {0xe1ff02c1,0x8b260010,0xe572000a,0xec7700ce}},	//   nión_, кдзе, בַע_, впу_
  { {0x8fa605e6,0xb5fd0085,0xfeba002b,0x539a0c44}},	//   _јане, višn, _تاخت_, ֵינו
  { {0xc332013a,0x3a3f19b0,0xaae50015,0x2fd80144}},	//   יוב_, _coup_, اسلو, larg_
  { {0xdb1e002e,0x3ea019b1,0x63bc0030,0xc7b80085}},	//   tapó, mmit_, űrni, _lađe_
  { {0xdb1c0014,0xb7d80029,0x515b0008,0xfbc30004}},	//   _kerü, روبا_, וכנו, _вбро
  { {0x8c1b0008,0xe704002b,0xc7b80085,0x16660015}},	//   _קולי, استی, _nađe_, َابَ
  { {0xdb1c00dc,0x96b70054,0xeb9719b2,0xb21b0052}},	//   _merü, њују_, _рис_, nlæt
  { {0xb5fd01a3,0xca750033,0x2292001a,0x3ea00771}},	//   mišl, _суры, tákn_, imit_
  { {0xe1ff19b3,0x9f580077,0xbd9b000a,0x62640030}},	//   gión_, neró_, וספת, sőol
  { {0x9f580089,0x225200dd,0x07a60660,0x25bd0034}},	//   terý_, _blyk_, _ражн, _ffwl_
  { {0xacbb0152,0xdb1c19b4,0xb5da0015,0x26da0046}},	//   _brûl, _heró, _آباء_, ápou_
  { {0xb1140033,0xc5f3000a,0xb5fd0046,0x7c2e0079}},	//   амяш, _כדף_, rnšt, _onbr
  { {0xe1ff0782,0xdb1c19b5,0x5453009e,0x6486002e}},	//   ción_, _berü, _квіт, rðis
  { {0xeeab0036,0xc058005e,0x9f580077,0x9f66001a}},	//   дтак_, тія_, deró_, óuðu_
  { {0x645d0024,0x02a404ab,0x7c2e19b6,0x6dc4004a}},	//   īsie, _крым, _anbr, исуж
  { {0xa5c2002a,0x645d003d,0xb5fd006f,0xcc990099}},	// [2ad0] łówk, ūsie, dišl, евац_
  { {0x3ea019b7,0xfc190015,0x3a3f00da,0x7ae319b8}},	//   amit_, عقاب_, _soup_, ánto
  { {0x3ea010df,0xdb1c0012,0xdb14001a,0xaab40015}},	//   bmit_, _gerü, ðaði, لإنش
  { {0x3ce900bd,0xd7f80011,0xd357000a,0xb21b02de}},	//   prav_, _acă_, כיבי_, mlæs
  { {0x8bb70015,0x09e4005e,0xa3c4000b,0x99d4002b}},	//   _لإزا, роін, ौरा_, شتنا
  { {0xe1ff02c1,0x20110ee0,0xf813002b,0x46f5004a}},	//   xión_, nezi_, شستگ, гчит
  { {0xef120008,0x27e90064,0x2011003f,0xead4124a}},	//   ֶּה_, ğan_, iezi_, _вось
  { {0x27e901e2,0x20110045,0x2bcb000b,0xab8400af}},	//   şan_, hezi_, िरका, _ђурк
  { {0x2a64010f,0x06960029,0xa565002b,0x20110aa5}},	//   _търг, دنية_, دگان, kezi_
  { {0x69d919b9,0x98170087,0x98a40054,0x20110030}},	//   lawe, _جبرا, _виђе, jezi_
  { {0x3ea000f2,0x7bd519ba,0xf2a6029b,0x201119bb}},	//   ymit_, _mezu, лиоп, dezi_
  { {0xe1ff0467,0xb21b0134,0x69d919bc,0xddd60069}},	//   sión_, dlæs, nawe, chyň
  { {0x6486002e,0xd5ae0087,0x4a5a000a,0xa616000a}},	//   rðir, _عفو_, תדרו, _תקנד_
  { {0xdb05002d,0x8936004c,0x9f5802b9,0x69d919bd}},	//   nchó, ארשע_, derò_, hawe
  { {0x2d8f00b8,0x2eb50a61,0x53320004,0x63050015}},	//   ügen_, истс, _гејт, _إوبل
  { {0x229900dc,0x69d919be,0xdb1c0012,0x7e550033}},	//   téke_, jawe, _verü, атуц
  { {0xed5719bf,0x7bd519c0,0x9f580077,0xb21b001a}},	// [2ae0] гот_, _bezu, teró_, rlæt
  { {0xdb1c0014,0x09cc005d,0xd9cc005d,0x3ea00024}},	//   _terü, ार्य, ार्ट, smit_
  { {0x272301e2,0x5f460029,0x8cb0000b,0x60db003d}},	//   _nın_, _إنجل, _अंको, šumt
  { {0x248519c1,0x9f410077,0x7ae2003d,0xdb210030}},	//   holm_, _echó_, ņoto, ötár
  { {0xc7ba0010,0x1ae0000b,0x9f58010d,0xb5fd19c2}},	//   нёй_, _पटकथ, peró_, rišl
  { {0xd9430124,0xddcd005c,0x98730484,0x9d2b000a}},	//   сељи, chał, бліц, _אֵלִ
  { {0xc8e0005d,0x7d160026,0xa634005e,0x69d90647}},	//   _निकट, lwys, инкі, bawe
  { {0x60c4001c,0x58d60015,0x20110045,0xdb05002a}},	//   _otim, _ميرذ, zezi_, achó
  { {0x29560063,0x7d1619c3,0x89db000a,0xb21b01f0}},	//   _съвр, nwys, _רחמי, klær
  { {0xb7b50092,0x3cfb0053,0xebd6000a,0xe6440061}},	//   _hạn, עלינ, נֵ֥י_, ılış
  { {0x2259004a,0x60c40091,0x7d160034,0x5c370447}},	//   вины_, _atim, hwys, אטיב_
  { {0xe4520074,0x2011000c,0x6681002b,0x88c70046}},	//   _گفتگ, wezi_, _ویول, směš
  { {0x61e40176,0xb7b50023,0x8cb0000b,0xa4d401f3}},	//   _ddil, _mạn, _अंगो, _толі
  { {0x61e401e2,0xf593003b,0x7d1600aa,0x60c40125}},	//   _edil, _الهج, dwys, _dtim
  { {0xa91d002c,0x69d9003f,0x03bb000a,0x7d1600aa}},	//   _vyži, yawe, _אצול, ewys
  { {0x02fb000a,0x2449001a,0x1c02000b,0x7d1619c4}},	//   _נלחמ, _rúmi_, र्सल_, fwys
  { {0xdb0500b8,0xe6d1000b,0x2beb0004,0x320902f2}},	// [2af0] schü, _सब्ज, еќен_, _ibay_
  { {0x6bd40029,0x69d91480,0x2bb80015,0x319c000a}},	//   متمر, wawe, هامة_, _אבחנ
  { {0x9f35005e,0x547b004c,0x7bd50085,0x69d919c5}},	//   _тені, עטבו, _vezu, tawe
  { {0x5fbf005d,0x7f3a0053,0xb7b50092,0x7d160026}},	//   ्रकल, _סערו, _cạn, bwys
  { {0xb7b50023,0x80a40086,0x8dda000a,0xe0df02b9}},	//   _dạn, _خمین, _בקרק, nsò_
  { {0xb3460064,0xe800005d,0x628619c6,0xa9680058}},	//   _kaçı, ल्ला_, zoko, دمهم_
  { {0xe739087a,0x91690092,0xa3e8000b,0x628619c7}},	//   тей_, _lừa_, यणन_, yoko
  { {0x8aa419c8,0xb5fd1573,0x24520003,0xb3460061}},	//   _груд, mišk, _râma_, _maçı
  { {0xf1c80089,0xb5fd158a,0x2c6f002a,0xe611002b}},	//   ndář_, lišk, ażde_, مشک_
  { {0xb4650973,0x4465110c,0x62860535,0x0000006a}},	//   ркол, рвов, woko,
  { {0xe29a0001,0x8c1a0008,0xb5fd158a,0x21290509}},	//   као_, דותי, nišk, _arah_
  { {0xe126004a,0x69ac000b,0x7d160034,0xf77000c3}},	//   амми, ुँची, ywys, _عال_
  { {0x8a160008,0x2d8f00b8,0x9548002b,0xd5a3002b}},	//   בחרו_, ügel_, _مشوق_, _الشی
  { {0x9f580084,0x455a0008,0xb5fd0007,0x7019042b}},	//   ferð_, _בכנס, kišk, ліст_
  { {0x9f580084,0xb5fd19c9,0xfec30015,0x8fa60a68}},	//   gerð_, višj, قيَّ, раве
  { {0x201e0007,0x25bf064e,0xb5fd00f0,0x20d6005e}},	//   žti_, ncul_, dišk, _кіос
  { {0xbc660010,0xb21b003c,0xedd30015,0x00e30033}},	// [2b00] авак, plær, زيلد, _джын
  { {0x7d16020a,0xb5fd158a,0x6f660121,0x644319ca}},	//   rwys, fišk, _ввоз, _joni
  { {0xb5fd0007,0xe9da12d2,0x7d1600aa,0x644319cb}},	//   gišk, вке_, swys, _moni
  { {0x539a000a,0x536c004c,0x62870085,0xa92619cc}},	//   דיעו, עכאַ, čkog, идел
  { {0xb5fd0007,0x8277004c,0xd3780085,0x2ba7000b}},	//   aišk, סענע_, maće_, केबा
  { {0xdb1c002e,0xb5fd1573,0x1c02000b,0x8cd6000b}},	//   _ferð, bišk, र्शल_, मीणो
  { {0xdb1c0084,0xd6d703be,0xa089000a,0x475a006b}},	//   _gerð, аты_, נְנִ, ърдя_
  { {0xddcd19cd,0x960a0010,0x963419ce,0xcb37000a}},	//   mnaţ, тэка_, сниц, _דאלי_
  { {0xd90e0086,0xe9440086,0xc9660033,0x9537006b}},	//   _آیت_, _ارزی, _твай, изът_
  { {0xddcd0011,0x656f002d,0xc34a006b,0x644319cf}},	//   onaţ, úcha, вяме_, _coni
  { {0x0bb7013a,0x6f090050,0x84330036,0xfbb7000a}},	//   ילים_, łecz, інює, יפית_
  { {0xe717000a,0x9f58001a,0xf50600f4,0x32671208}},	//   _כחבר_, verð_, _вздо, ртов
  { {0xdfdb010f,0xc6930008,0x50f40342,0x644319d0}},	//   къв_, _ואף_, озят, _foni
  { {0xd48f0036,0x91690092,0x92030024,0x64a30033}},	//   _єр_, _vừa_, _šādo, _дача
  { {0xaf340086,0xb05b00f2,0xe0df062b,0x749b000a}},	//   يرفت, npäi, ssò_, _שיופ
  { {0xb5fd1573,0x9757000a,0x433b000a,0x443e0123}},	//   višk, בילו_, _יעוב, ljt_
  { {0x8bb70029,0xdbd1002e,0x656d002c,0x212900bd}},	// [2b10] لإضا, _býðu, _ľahk, _urah_
  { {0xb5fd00df,0xa8020061,0x3138004f,0x60640058}},	//   tišk, çıla, _כרחך_, _وهيل
  { {0xf2d300b2,0x2d87005c,0x2b470045,0x307c000a}},	//   ַעס_, łne_, ânc_, _באזנ
  { {0xdb1c09f0,0xb5fd19d1,0xd9990015,0xd337000a}},	//   _verð, rišk, هنات_, ירבה_
  { {0xb5fd0007,0xfe36000a,0xf1b4000a,0x91f8000a}},	//   sišk, _הארך_, קסס_, שמדו_
  { {0x893406e4,0x31580053,0x1ed8002b,0xe1ff0030}},	//   تعما, סיגן_, _حبیب_, fiók_
  { {0x9b45002b,0xe1ff0030,0xd7f806f6,0x4faa000a}},	//   _انزو, giók_, руч_, ְׁפְ
  { {0x645a0e95,0xceb4000a,0x7e6d19d2,0xd706004a}},	//   ehti, חיק_, niap, ёные_
  { {0x644319d3,0xd5490080,0x6d4d013c,0x25bf0045}},	//   _poni, уппе_, nyaa, rcul_
  { {0x645a19d4,0x628d003f,0x25bf19d5,0x7996002a}},	//   ghti, _akao, scul_, żywc
  { {0xd795003b,0xe1ff00dc,0xf1a900a3,0xf7850015}},	//   _الاخ, ciók_, _נס_, _الضَ
  { {0xc04919d6,0x443e0085,0x425600c9,0xb5fd0091}},	//   _אז_, ajt_, стот, kiši
  { {0xa979004c,0xd3780085,0x644319d7,0x7e6d19d8}},	//   ראָכ, vaće_, _toni, diap
  { {0x46130086,0x645a19d9,0x10a6107f,0x305500af}},	//   _دوچر, chti, сигн, ођст
  { {0x8c3b0012,0x7d0f0030,0xd3780085,0xddc400d4}},	//   _fußz, _apcs, taće_, ghiş
  { {0x3392002b,0x92650015,0x7e6d19da,0x0000006a}},	//   _عليز, _وديم, giap,
  { {0x80b2000b,0xe1ff0030,0xd3780085,0x6da319db}},	// [2b20] _इंटे, ziók_, raće_, зита
  { {0x3ce019dc,0x8f76004e,0x0000006a,0x0000006a}},	//   rsiv_, _гумі,   ,
  { {0xeafa0086,0x6d4d013c,0x60a50015,0xeab20015}},	//   طرات_, ayaa, _بإيق, سعا_
  { {0xeb970a2c,0xddcd0011,0xaa65005e,0x99dd006f}},	//   щих_, rnaţ, отік, _poňa
  { {0x2d840152,0x645a00f2,0xdd920002,0x799b002a}},	//   _âme_, yhti, _روس_, _czuw
  { {0x98730033,0xa91d0091,0xb9000065,0x99dd016d}},	//   пліц, _ryžt, _दब_, _voňa
  { {0x39520007,0xf743000d,0x23db000b,0x7bdb000a}},	//   šys_, зејо, _मज़द, _תקלו
  { {0xceb30008,0xdb1c00c0,0xbb77000a,0xddcd0085}},	//   היה_, _berö, _העלו_, onaš
  { {0xb05b00f2,0x645d0024,0xca37000a,0xf7ea0015}},	//   späi, īsin, _פנמה_, _مرضى_
  { {0x14b7003b,0xb05b00f2,0xb8960029,0x7bde015a}},	//   حديث_, ppäi, _الطع, napu
  { {0x53980036,0x9f450064,0xe21502bf,0xe9ff0016}},	//   рвня_, ülü_, омны, _xoắn_
  { {0x91690092,0x4b7b01ac,0x68e219dd,0xf36302bf}},	//   _nữa_, ראטו, osod, ятын
  { {0xc05b0036,0x5a9b0053,0x65960086,0x60d60026}},	//   гів_, טשטא, _اجار, _cwym
  { {0xd3ba0036,0xdb1c001a,0x7d0400d5,0x60d60034}},	//   _суді_, _afrí, dtis, _dwym
  { {0x7e6d01c2,0x91690016,0xe3b80061,0x6fda0065}},	//   tiap, _bữa_, ndım_, _बजरं
  { {0x33770008,0x6377000a,0x798d002a,0x7d0419de}},	//   _לתוך_, _לגוף_, żawi, ftis
  { {0x1dc40015,0x7d040030,0x60d60034,0xfe700015}},	// [2b30] سْلِ, gtis, _gwym, ردف_
  { {0x7e6d0375,0x859b000a,0xdb5b0033,0xb5fd19df}},	//   siap, רשמו, люе_, riši
  { {0xfb150015,0xd011002b,0x6d4d01c2,0x68e20034}},	//   تواج, _فلک_, syaa, esod
  { {0x02fb0053,0xb5fd02c6,0x7bde008c,0xdd910058}},	//   רלאמ, piši, aapu, _يود_
  { {0xe9d8008f,0x645802c1,0xab620064,0x127c0053}},	//   скі_, _olvi, _çünk, נאדע
  { {0x40ec000a,0xe9d9002a,0x68290030,0xa6c90fb6}},	//   אַהֲ, _weź_, ködő, алка_
  { {0x70b5005d,0xdc9a000a,0xf742006b,0x07a21305}},	//   ंदुल, _כישל, дещо, машн
  { {0x245b038d,0x7996005c,0xb6580010,0xdb1c0026}},	//   _même_, żywa, йшых_, _ffrâ
  { {0x69db0026,0xe1ff06e7,0x6f1b002a,0xe4590719}},	//   _ieue, ciói_, łuch, ижи_
  { {0xdb1c00b8,0xad27008b,0x3cdb000b,0x1309056d}},	//   _verö, рвiс, खीये_, аной_
  { {0x37c40015,0xe1ff002a,0x60d6002a,0xd6390033}},	//   _رينف, niów_, _swym, _вялі_
  { {0x7de60014,0xdb1c0064,0x7d0419e0,0xa3b5000b}},	//   _késő, _terö, ytis, _झलक_
  { {0xef1f002a,0x7bde19e1,0x98bd002a,0x69db0144}},	//   óżne_, yapu, tywę_, _meue
  { {0x9f580152,0x68e4002d,0x88ba004c,0x7ae2003d}},	//   lgré_, áidi, יזשי, ņoti
  { {0xe29a19e2,0xc0590010,0x1eaa0015,0xdb1c016e}},	//   _как_, сіў_, لاري_, _jerô
  { {0x69db018b,0x4e060010,0xe1ff005c,0x7d040ae5}},	//   _neue, ўзаб, diów_, ttis
  { {0xe0d2003b,0x76590026,0x02030010,0x0eb6000b}},	// [2b40] _غزة_, _mlwy, _ўзьн, _आंकड
  { {0x76590176,0x7c960010,0xe058002b,0xe3b80061}},	//   _llwy, ірац, _ایست_, ydım_
  { {0xda660036,0x3bd50080,0x9f060031,0x4dd60015}},	//   овжи, яютс, _بوجو, _وتحس
  { {0x201819e3,0x7ff60086,0x7ae30045,0x386e0034}},	//   leri_, _اسکا, ânta, wifr_
  { {0xcaa50029,0xb9930015,0x7bde015a,0x69db0144}},	//   أصلي, ولمب, papu, _deue
  { {0x752900dc,0xab2a18a7,0x76590034,0x68ed0030}},	//   dvez, _кога_, _alwy, áada
  { {0xf8bf0298,0x76590026,0x69db19e4,0x752900dc}},	//   _één_, _blwy, _feue, evez
  { {0xe3b801e2,0x76590026,0x7bdc19e5,0x9f450003}},	//   rdım_, _clwy, _heru, ûlé_
  { {0x20180064,0x7bdc0375,0x28160015,0xdb21008c}},	//   keri_, _keru, _وورس, ätös
  { {0x94760029,0xb05b00f2,0x07a60033,0x97360015}},	//   تدعا, npät, _дазн, _وعاص
  { {0x76590176,0x42550029,0xdb0500b8,0x7bdc013c}},	//   _flwy, كندر, schö, _meru
  { {0xbddb0152,0x75290844,0x644100d9,0x76590034}},	//   _poèm, bvez, ajli, _glwy
  { {0x290600f2,0xe3b80064,0x85760015,0xddcd0046}},	//   ntoa_, ndık_, _بدائ, chař
  { {0x20180375,0xe3af002b,0x6fd9002a,0x3a2419e6}},	//   geri_, عری_, dźcó, _lamp_
  { {0xcddb0180,0xff040256,0x2906008c,0x6abc01c2}},	//   иња_, мятн, htoa_, _nurf
  { {0x7bdc19e7,0xb5fd0091,0x0000006a,0x0000006a}},	//   _aeru, sišv,   ,
  { {0x8cf50010,0x7bdc19e8,0x201819e9,0xdcfd003d}},	// [2b50] язац, _beru, beri_, _izsī
  { {0x7bdc0011,0x20180011,0xb5fd06cf,0x69db027d}},	//   _ceru, ceri_, lišt, _seue
  { {0x20010e18,0x2906008c,0x7bdc19ea,0x6abc01f9}},	//   _ichi_, etoa_, _deru, _curf
  { {0xd9590010,0xe1ff005c,0x6abc059b,0x3a2407fc}},	//   йшлі_, riów_, _durf, _camp_
  { {0xcfab0086,0x3ea90197,0xd91b004a,0x69db0144}},	//   _حاکم_, mmat_, рье_, _veue
  { {0xd8220080,0x3ea919eb,0xeafb002b,0xb5fd00bc}},	//   едши, lmat_, _پرست_, hišt
  { {0xf6510029,0x7bc5002d,0x76590034,0x7d190061}},	//   فئة_, mchu, _plwy, şası
  { {0xe9df09f0,0x3a240026,0x38c90086,0xb5fd19ec}},	//   _þú_, _gamp_, _هائی_, jišt
  { {0x5a340010,0x1a680086,0x20010011,0xb5fd06cf}},	//   _ўнут, _بینی_, _ochi_, dišt
  { {0x2001000c,0x75290014,0xfdb8000b,0x3ea90049}},	//   _nchi_, rvez, _अल्फ, hmat_
  { {0x7bc500b8,0xa4480015,0x8bd6000a,0xb4640015}},	//   ichu, تشيك_, הותו_, بديه
  { {0x7bc5002d,0xb05b002c,0xc243005e,0x95c40015}},	//   hchu, zpät, енюк, _قيمه
  { {0x55ba0008,0x3ea900d9,0x2ef80012,0xd3780085}},	//   _המנו, dmat_, wurf_, raća_
  { {0x394000f2,0x70560015,0xd00a0054,0x9fc70054}},	//   äisi_, أنسا, љеве_, згра_
  { {0x43750053,0x602f0007,0xe800000b,0xe456004c}},	//   _מײַן_, dėmė, ल्टा_, _מיסט_
  { {0x75f60061,0x7bdc06a2,0xf1bf19ed,0xe3b80061}},	//   müzü, _seru, ldán_, ydık_
  { {0x0d9a0010,0x8d660010,0x51fb0008,0xdd920115}},	// [2b60] ствы_, чвае, _ההפצ, روط_
  { {0x7bc5002d,0xee3f006f,0x8fa608f7,0xf1bf0030}},	//   gchu, _chýb_, _напе, ndán_
  { {0xddc4005c,0x68ed00dc,0x501b000a,0x6f0c0045}},	//   oniż, áadn, _פוטו, încă
  { {0x82d60053,0x290600f2,0xda650031,0x7bc5002a}},	//   פונג_, ttoa_, واني, achu
  { {0xba290015,0xb05b008c,0x7bdc19ee,0xd7e6005e}},	//   تسلم_, mpär, _teru, пійо
  { {0x6e2600b6,0x7c5a0029,0x290600f2,0xd90d0086}},	//   _hakb, _السر_, rtoa_, شیم_
  { {0x2906022d,0xdc370053,0xc66a0080,0xdb830b1e}},	//   stoa_, _צאלט_, йшие_, _згри
  { {0xb8660086,0x6e26005c,0xe6630036,0x4b7b0008}},	//   _کارو, _jakb, етьо, _האלו
  { {0xc7b60015,0x6e3b000a,0x6e2619ef,0xa7b60099}},	//   _فصاع, מתקד, _makb, _есеј
  { {0x6e2619f0,0x2913009a,0x224901f9,0x8386066a}},	//   _lakb, _سومآ, _soak_, зыме
  { {0xb5fd04c6,0xe9ff0016,0xb05b0072,0x68ec0073}},	//   tišt, _hoạn_, kpär, žodį
  { {0x76bb0008,0x6e2601c2,0x22440015,0x54e60058}},	//   _המאפ, _nakb, ّنَّ, _فستق
  { {0xb5fd010b,0x321919f1,0x9f51001a,0x61fd19f2}},	//   rišt, resy_, _íbúa_, rgsl
  { {0xb97b000a,0xf0440138,0xa2ca04c5,0x0000006a}},	//   מרכז, нэсо, _луиз_,
  { {0x9f340036,0xb5fd0089,0xe9ff0092,0x987b0053}},	//   нері, pišt, _loạn_, צאלט
  { {0x5f94059c,0x5eb4086e,0x7bc50034,0x644a086c}},	//   хист, ейст, wchu, _hofi
  { {0x628f002c,0x998f002a,0x8e740015,0x3ea919f3}},	// [2b70] moco, zegł_, رافض, rmat_
  { {0x7bc519f4,0xe5530030,0xb05b0a64,0x5ba702b0}},	//   uchu, éséé, rpäs, през
  { {0xe7a50024,0x7bc519f5,0xe1ff0030,0x7b670f82}},	//   ādīš, rchu, ogó_, чтае
  { {0xe1ff19f6,0x7bc519f7,0x68ed00dc,0xd1080086}},	//   ciót_, schu, áado, _بقیه_
  { {0xa9540191,0x5a340033,0x08c4005e,0x9a880015}},	//   нкці, энцт, ебін, أَنْ_
  { {0xf7700074,0x60cd003f,0x644a0026,0x75f60061}},	//   گاه_, _mtam, _nofi, yüzü
  { {0xab950036,0xe1ff0537,0x572400e6,0xe7080015}},	//   _циві, chóg_, فريق, كتين_
  { {0x60cd00f2,0xb8820030,0xf7700021,0x2a7f1839}},	//   _otam, áírj, داه_, _ujub_
  { {0x68e4002f,0xd5e80015,0xa3f50033,0x80b9000b}},	//   áidt, سعين_, мянш, _एंगे
  { {0x644a0176,0x61ed19f8,0xd928000a,0xe1ff0030}},	//   _cofi, _adal, _מֵעָ, ziót_
  { {0x5884008f,0x60cd0064,0x442b0046,0x67210085}},	//   _чыта, _atam, ěc_, _uslj
  { {0x442b002a,0xd7f80045,0xaad50065,0xb5fd016d}},	//   śc_, _umăr_, डीएक, rišs
  { {0x98a40011,0x61ed0026,0x2bfe005d,0xb1430342}},	//   _urmă_, _ddal, _लालू_, внял
  { {0x644a0026,0x94ba000a,0xf3f5002b,0x7c270e1f}},	//   _gofi, _ומסת, _آتشک, _najr
  { {0x92e8003b,0xcec40089,0x28dd000b,0xdee6005e}},	//   _فريق_, daří_, नीति, ьови
  { {0x93240015,0x644a0bbd,0xed5a0fea,0x442719f9}},	//   _أرون, _zofi, ооб_, _han_
  { {0xfce3005f,0x3cf5005d,0x312302bf,0x6e260079}},	// [2b80] кото, एंगे_, _адыг, _vakb
  { {0xb05b0020,0x61ed1837,0x2ca7070c,0x442719fa}},	//   spär, _zdal, дкуп_, _jan_
  { {0x661b00f2,0xe9ff0092,0x20570008,0xe1ff19fb}},	//   keuk, _soạn_, _חייל_, ciós_
  { {0xe1ff005c,0x92080024,0x442719fc,0x6298016e}},	//   chód_, _frāž, _lan_, _êxod
  { {0x09360015,0x09e308ad,0xddc40091,0x5886055f}},	//   براج, точн, snių, мыка
  { {0xd9430054,0x7afa0123,0x442719fd,0xe1ff19fe}},	//   тељи, _åtto, _nan_, zgó_
  { {0xc7b00015,0xe73702d9,0x644a19ff,0x17f70058}},	//   دّث_, деј_, _rofi, ذروة_
  { {0x442715d8,0x7c27002a,0x68e40125,0x764b0034}},	//   _aan_, _zajr, áids, _cogy
  { {0xd7cf005d,0x44271a00,0xc6a3006b,0x644a0045}},	//   _स्वच, _ban_, ърши, _pofi
  { {0x44270388,0x628f002a,0xddd6006f,0xb7160058}},	//   _can_, woco, skyň, _يباش
  { {0x4427013c,0x67bb000a,0xd3700015,0x77bb000a}},	//   _dan_, _ומבק, اهج_, _ומבח
  { {0x92580080,0x4427002d,0x926b005e,0xc7b80085}},	//   дают_, _ean_, ірна_, _nađi_
  { {0x84460029,0x44271a01,0xe1ff19b8,0x628f1a02}},	//   _يختل, _fan_, rgó_, roco
  { {0xa3df014e,0x44271a03,0xd4c50015,0x628f1a04}},	//   तरण_, _gan_, _أغني, soco
  { {0x764b00e8,0x626b0089,0xc7b1000a,0x33fb000a}},	//   _yogy, dřov, ָ֑ם_, _והונ
  { {0x2cb8002d,0x6db50baf,0x61ed1a05,0xe1ff0144}},	//   _aird_, ейбу, _udal, riós_
  { {0xce940063,0x2cb81a06,0xddcd002a,0x60cd1a07}},	// [2b90] татъ, _bird_, tkał, _utam
  { {0x82350086,0x69c90079,0x22990030,0x2ee50052}},	//   _آرژا, _sfee, déki_, álfs_
  { {0xe945002b,0x5fbe000b,0x64940144,0x68e91a08}},	//   کرای, ्डरल, làis, _sved
  { {0xdb0e00dc,0xdd910086,0x539b000a,0xddcd002a}},	//   áján, _موج_, חיבו, skał
  { {0xcce7003b,0xe6ed002c,0xcdf6000a,0x6bd70058}},	//   _تسجي, _väčš, _אמרי_, _يتسر
  { {0xa1580008,0x07a505b1,0xc7a5030c,0xf1bf013f}},	//   ובדה_, налн, нилк, ddám_
  { {0x44271a09,0x2bae005d,0xf7730018,0x3eb90546}},	//   _ran_, झेदा, خاش_, _kist_
  { {0x19950010,0x2d99008c,0x44271a0a,0x3eb9087b}},	//   _забя, _kyse_, _san_, _jist_
  { {0xe5790080,0x68e90107,0xeab00031,0x442711a3}},	//   язи_, _uved, _ضعف_, _pan_
  { {0x9cd6000a,0x3eb91a0b,0xe3b1002b,0x285b0015}},	//   עותה_, _list_, ُرد_, _بؤرة_
  { {0x87070086,0x44271a0c,0xe29a1a0d,0xd6c3002b}},	//   _زبال, _van_, зан_, _شمشی
  { {0x44271a0e,0x23780030,0x3eb91a0f,0x0000006a}},	//   _wan_, úrja_, _nist_,
  { {0xdb1c00c0,0xc19a005e,0x35f8002b,0x44271a10}},	//   _ifrå, ятої_, _زرند_, _tan_
  { {0x3204002a,0xf8a70015,0xd576004f,0xa52400ce}},	//   żmy_, طة_, _אתנה_, _шмід
  { {0x68ed00dc,0x322900f2,0x3eb900b8,0x66c70061}},	//   áadj, ötyä_, _bist_, _yıka
  { {0x6cd60015,0xf772004c,0x3eb9082b,0x0000006a}},	//   فقرا, אקל_, _cist_,
  { {0x626b0089,0x127b004c,0x63a6002a,0xc27b000a}},	// [2ba0] třov, _מאקע, ękne, _מרקי
  { {0x4f261a11,0xf2e6002b,0x3eb90079,0x61e61a12}},	//   _здоб, _تکیه_, _eist_, lakl
  { {0x5fdb0008,0x80890029,0x2be1000b,0xeed6000a}},	//   _מחיק, _تضيف_, _फ़रा, _אֵ֚ת_
  { {0x2cb80bcf,0xb346001c,0xc332000f,0x88e609ef}},	//   _wird_, laçõ, טוב_, ежде
  { {0xa3df005d,0x9269004c,0x626b005a,0x0000006a}},	//   तरा_, ובאַ_, přov,
  { {0xeee70074,0x317b0053,0x20c60092,0xb346001c}},	//   _تغیی, האנד, _môi_, naçõ
  { {0x20c60092,0xf09300a3,0xcb94002b,0x8ba3004a}},	//   _lôi_, אנג_, _شهرک, _бирж
  { {0x95ca0572,0x35460245,0x963404d7,0x0000006a}},	//   чука_, ехов, тниц,
  { {0xd4060036,0xea77000a,0xddcd0045,0x06e0000b}},	//   няни, _נגמר_, liaţ, _गौरव_
  { {0x5454066c,0xdbdf001a,0x62870085,0xf1bf0046}},	//   твот, níði, čkom, rdám_
  { {0xd2510087,0xd706005e,0x66c70061,0xddcd0045}},	//   لند_, _їзди, _tıka, niaţ
  { {0xa75b0008,0x20c60016,0x375b000a,0x78ba0030}},	//   _מדבר, _bôi_, _מכבד, _hitv
  { {0xf1bf00dc,0xf44001f3,0x20c60016,0x3eb91a13}},	//   ldák_, _волi_, _côi_, _rist_
  { {0xb346001c,0x853b0008,0x200517f7,0x3eb902d2}},	//   gaçõ, _מגדי, üli_, _sist_
  { {0xddcd002a,0xdb210061,0x61f40123,0x833300c3}},	//   ykań, ötür, ådlö, _مريض
  { {0x61e60064,0xddcd0011,0x439b000a,0x639b000a}},	//   cakl, diaţ, _מבוג, _מסונ
  { {0x442c0176,0x3f9e002e,0x3eb90293,0xdfd1002b}},	// [2bb0] odd_, ýtur_, _vist_, _پيج_
  { {0xb346001c,0x2bbb0029,0x3eb90111,0x7e640061}},	//   caçõ, ساطة_, _wist_, ahip
  { {0x442c1878,0x2d9900dd,0x73a9000a,0x6e950015}},	//   idd_, _wyse_, ֵינֵ, _للدا
  { {0x7d090045,0xbdf9006e,0x7e641a14,0x78ba0073}},	//   _ţesu, _تفحص_, chip, _aitv
  { {0x6e3d00b8,0x88c80036,0x7afe1a15,0x9cb50015}},	//   _insb, елів_, aupt, _لمحت
  { {0xa3bc005d,0x645a0079,0x61e61a16,0x6eaf0065}},	//   _अलग_, jkti, zakl, ंगवु
  { {0xddcd0011,0xba770015,0x7d0d1a17,0x61e6007f}},	//   ciaţ, _كارت, ltas, yakl
  { {0x442c0176,0xb346001c,0x7f3c0053,0x99d70021}},	//   edd_, zaçõ, לעוו, _سترا
  { {0x0568000d,0xc4850142,0x2c6400c0,0xe8e00016}},	//   ејќи_, клик, _född_, _đệm_
  { {0xcdaa0053,0x69d90012,0x7d0d118c,0x629d1a18}},	//   ויפֿ, lbwe, itas, elso
  { {0xb904005d,0xb346001c,0x7d0d1a19,0x20c60016}},	//   भी_, vaçõ, htas, _sôi_
  { {0x27e7002f,0x442c1a1a,0x45d505c4,0x7d0d1a1b}},	//   lann_, add_, _родс, ktas
  { {0xb346001c,0x320c005c,0x68ed00dc,0x69d900b8}},	//   taçõ, ędy_, áadh, ibwe
  { {0x7d0d00fb,0x27e7002f,0xdfd20029,0xc7ce0092}},	//   dtas, nann_, شير_, hống_
  { {0xb34603af,0x24960029,0x5f06006b,0xa284002b}},	//   raçõ, _جنود_, ъзва, _میدو
  { {0x20c600a7,0xdbc90020,0xb346001c,0x7996002a}},	//   _tôi_, _mõõd, saçõ, żywi
  { {0x27e7002e,0xb346016e,0xdbdf001a,0xf1bf0030}},	// [2bc0] kann_, paçõ, tíði, zdák_
  { {0xbc630010,0x7e641a1c,0x61e41a1d,0xe3b80061}},	//   авук, ship, _heil, mdır_
  { {0xe3b80064,0xbddb0291,0x78ba001a,0xdbdf001a}},	//   ldır_, _poèt, _ritv, ríði
  { {0xddcd0011,0x6da60029,0x60c4003f,0x53360053}},	//   riaţ, _لمجم, _kuim, כנען_
  { {0x442c0b7c,0xe3b80064,0x61e41a1e,0x27e70123}},	//   ydd_, ndır_, _meil, fann_
  { {0x27e71a1f,0xcee90086,0xddcd0011,0x60c4003f}},	//   gann_, _ترین_, piaţ, _muim
  { {0xa7fc0064,0x60c4002d,0x91830092,0x9c17000a}},	//   _alıc, _luim, iếp_, _שחלק_
  { {0xdb1c002f,0x442c0176,0x61e41a20,0xb7bc003d}},	//   _ngré, wdd_, _neil, _maģi
  { {0x60c40007,0x0906049d,0x7e9b000a,0xd3780085}},	//   _nuim, _шпан, וסקו, maći_
  { {0x27e7002d,0xdb1c0152,0x78ba00f6,0xe56f0015}},	//   cann_, _agré, _uitv, غطي_
  { {0x442c0176,0x7d0d00dc,0xa2b50063,0x61e41a21}},	//   rdd_, ztas, лбоч, _beil
  { {0xd378016f,0x7d0d0671,0x442a00bc,0x61e4124e}},	//   naći_, ytas, žb_, _ceil
  { {0x60c4002d,0x4613002b,0x83f80004,0x25a00125}},	//   _cuim, _خونر, _зелс_, _áil_
  { {0x2bfe014e,0xa2ca000b,0x250b002b,0x60c40547}},	//   _लागू_, _संप्, _زرهی_, _duim
  { {0x61e41a22,0x260f000b,0xa0740033,0xcebb0054}},	//   _feil, थ्वी_, рыўш, дља_
  { {0x01650015,0x68ed0085,0x7d0d1a23,0x60c40077}},	//   _مُعَ, šadi, ttas, _fuim
  { {0x7d0d1a24,0x60c41306,0xf1c40069,0x6e2d1a25}},	// [2bd0] utas, _guim, ášť_, rdab
  { {0x7d0d1a26,0x61e4059b,0xbbdd000b,0x3f840061}},	//   rtas, _zeil, यरेक, ğmur_
  { {0xddc6005c,0xda350010,0xbae40015,0xd9f915b8}},	//   _dokł, лежы, لكلي, енец_
  { {0x27e700b8,0x99d40002,0xa2ca000b,0x6a94005e}},	//   wann_, لتها, _संन्, аріє
  { {0xe9d8008f,0xee3f002c,0xf1bf0125,0x6ce40033}},	//   ткі_, _iný_, meád_, _вісе
  { {0x27e7002d,0x6ac50015,0xd70905ab,0x66e502ed}},	//   uann_, _مقسم, енке_, гока
  { {0xe3b80064,0xd7ee0029,0xd8740115,0x9b890015}},	//   zdır_, سكي_, جانب, _أنزل_
  { {0xddcd0048,0xe3b80064,0x68f60091,0x98e50015}},	//   skaņ, ydır_, šyda, _مكرو
  { {0x27e7002e,0xa5d9002b,0x765b0061,0x66240015}},	//   pann_, وبکر_, rkuy, شريك
  { {0x656900b8,0x60c40161,0x61e41a27,0xbbe1000b}},	//   rzeh, _ruim, _seil, _फ़ोक
  { {0x656900dc,0x60c41a28,0xbbe1000b,0x8704013e}},	//   szeh, _suim, _फ़ैक, _вяче
  { {0xa75a004c,0xeb92000a,0x52860015,0x216a02ed}},	//   _אדער, מָר_, الحك, еими_
  { {0x4a5a0008,0x61e41a29,0x60c41a2a,0xdd0001ec}},	//   גדרו, _veil, _quim, ītīg
  { {0xe3b801e2,0x04590015,0x61e41a2b,0x99dd0046}},	//   rdır_, _سلعة_, _weil, _koňs
  { {0x9975005c,0x61e41a2c,0xc29a004a,0x6f630004}},	//   nęło_, _teil, _птиц_, бврз
  { {0xa2060e4d,0x6fd4000b,0xd356000a,0x7afa0804}},	//   _спид, _ब्रू, _תיקי_, _åtti
  { {0x0eb9044e,0x66c70064,0xddc6005c,0x4c8616b0}},	// [2be0] туры_, _sıkl, _pokł, глав
  { {0x91bb000a,0xdde3003d,0x5d130058,0x0000006a}},	//   _אמפי, ārša, إِلا,
  { {0x9975002a,0xaae60015,0xfaa61a2d,0x26c5026a}},	//   jęło_, اسطو, гажо, _nulo_
  { {0x2cb00007,0x6f790008,0x1efb0053,0x3ce8021e}},	//   _žodį_, _יְרו, _אלטע, _चौथे_
  { {0xf9920029,0x127b0053,0x08f70015,0xed5700eb}},	//   حبا_, עאנע, هروب_, _боя_
  { {0x66c70482,0xb7ca0015,0x3ea01a2e,0xa92804b2}},	//   _tıkl, ربتك_, llit_, južš
  { {0x3c630342,0x5c730033,0xcb6a0b1e,0x6b661a2f}},	//   _укрг, _улёт, _џабе_, _сква
  { {0x7c2e1a30,0x44f4058f,0x26c502f2,0x3ea001f9}},	//   _habr, апис, _dulo_, nlit_
  { {0x5e570053,0xca750010,0x3e7f00f2,0xdebb004c}},	//   טיקע_, _туры, lätä_, עמפל
  { {0xd91b0053,0x24520011,0xa98b000f,0x6fd4000b}},	//   _אומל, _câmp_, _אָבִ, _ब्लू
  { {0x68ed00dc,0x36060031,0x5c97004c,0x66c70061}},	//   áadv, _مواف, רכיע_, _yıkm
  { {0x21b50191,0x0bb70008,0xa295022a,0x4b37004c}},	//   ийня, טלים_, рамі, ארטל_
  { {0x667b0053,0x463b0053,0xe6930015,0x067b015b}},	//   _אטאק, _רעדע, _الند, _אנאל
  { {0x3e670020,0x3e7f008c,0x53340129,0x7c2e1a31}},	//   _mõte_, kätä_, _вект, _nabr
  { {0xdb1c0026,0x316b005c,0xe7f7000b,0x23270054}},	//   _sgrî, szcz_, ीलता_, _боји_
  { {0x442e0026,0xf777004c,0x3ea01a32,0xddcd1a33}},	//   _haf_, אעלי_, glit_, snaž
  { {0x3cee014e,0x9f430089,0xdbdf002e,0x21290509}},	// [2bf0] ेंगे_, mají_, _bíðu, _usah_
  { {0x9f430089,0x8c440001,0x93bc0045,0x3ea01547}},	//   lají_, беђе, bdăt, alit_
  { {0xbb840029,0xb9c50015,0xb09c004c,0xfbd00021}},	//   ملكي, لقضي, _איזר, ستل_
  { {0x9f430089,0xda670021,0xe37b004c,0x3ea01a34}},	//   nají_, دائي, עראר, clit_
  { {0xd7c9002b,0x3208000a,0x7c2e1a35,0xba22005e}},	//   نوشه_, א֖וּ_, _fabr, ідшк
  { {0x9f430089,0x3cfa000a,0xfd96000a,0x2c14000b}},	//   hají_, _בלשנ, _כדרך_, न्दू_
  { {0x36690cb9,0x9f430089,0x00580008,0xf7710070}},	//   како_, kají_, רשות_, غات_
  { {0xbb84003b,0x7ae30011,0x7c2e06ca,0x0000006a}},	//   _الفي, ântu, _zabr,
  { {0x9f430089,0x4975006b,0xa4d60054,0x98b90099}},	//   dají_, _тлас, адњу_, _алат_
  { {0x99540001,0x26c5008c,0x94050015,0x5d48000a}},	//   _укуц, _tulo_, جوده, רָהּ_
  { {0x53a5000d,0xa564002b,0x52aa0054,0x3ea0008c}},	//   ранб, لدین, квом_, ylit_
  { {0xcb120008,0x67b80115,0x673c0030,0x2c6402dc}},	//   חלט_, _صالح_, _árja, _möda_
  { {0x9405002b,0x4103006b,0x8352002b,0xd3780085}},	//   _نوشه, озяв, مپیا, daću_
  { {0x05a80036,0xb4fa0008,0xad9b002d,0x14190015}},	//   _свій_, _יפני, _gcúi, _شيعة_
  { {0xdee60a6c,0x9e760054,0x3f9e001a,0xd47a000a}},	//   роби, аћај, ætu_, _באסל
  { {0xdbdf0084,0x6e2f0016,0xdb1c0034,0x7c2e1a36}},	//   _síðu, _cacb, _sgrï, _sabr

  { {0x3ea00084,0x6bd60029,0x7c2e1a37,0x9cb60015}},	// [2c00] rlit_, لتار, _pabr, لمرت
  { {0xa7fc01e2,0x6286006f,0x113b000a,0x3ea01a38}},	//   _alın, lnko, _יתפל, slit_
  { {0xf1a9002b,0x6ffb000a,0x62870d70,0x3ea01a39}},	//   _لایه_, _בפיג, čkov, plit_
  { {0x3e7f00f2,0x2c6400c0,0xcdaa002b,0xeb971a3a}},	//   rätä_, _döda_, _لهجه_, ших_
  { {0x3e7f022d,0x93bc0011,0xa3e8000b,0x67d40004}},	//   sätä_, ndăr, बरम_, болу
  { {0x7d041a3b,0x987302e1,0x6e241a3c,0x2c640123}},	//   muis, оліц, leib, _föda_
  { {0x8c1b0008,0xe0b70008,0x7d041024,0xd6cf0342}},	//   _שולי, בלסט_, luis, ют_
  { {0x95d70063,0x89d70015,0x442e1a3d,0x98560535}},	//   адът_, _نوفر_, _saf_, dłą_
  { {0x9f430089,0x78b1002e,0x68ed0030,0xf9fb000a}},	//   vají_, ákvæ, áadt, _שהממ
  { {0xb8060074,0xb7960001,0x6e2400b8,0x442e01c2}},	//   _خبره, _крећ, heib, _qaf_
  { {0x9f430089,0x1c0b000b,0x63a6002a,0x43941a3e}},	//   tají_, स्टल_, ękno, санс
  { {0x877b000a,0x7d041a3f,0x62860595,0x6e240030}},	//   _באבי, kuis, gnko, jeib
  { {0x61f60026,0x5ab70053,0x4fc700a4,0x7d041986}},	//   _ddyl, ילטע_, исва, juis
  { {0x7d041a40,0x251b000a,0x0377002b,0xdb1c00be}},	//   duis, _סווא, احیت_, _agrí
  { {0xf0b40036,0x1df904ab,0xf7d7000a,0x6aa2001a}},	//   ійсь, левы_, שולש_, klof
  { {0x2c6400c0,0xdce60064,0xcdd80054,0x539b000a}},	//   _röda_, _aykı, ињу_, _שיהו
  { {0xd9040086,0xa2ca005d,0xebc70001,0xd5b3000a}},	// [2c10] _تی_, _सूत्, аљен, ַׁע_
  { {0x38a9006f,0x8bd80bbb,0xc19c004f,0x2292005a}},	//   kúra_, имус_, _בשחי, dáky_
  { {0xeb090029,0x7d04008c,0xca15006b,0x6e950920}},	//   اقصى_, auis, йджъ, _гину
  { {0xe8f5003b,0x7d041a41,0x3a98005e,0x6f010144}},	//   مستخ, buis, атію_, àlcu
  { {0x3cfe005d,0xa9c40033,0x4238004c,0xb9270da4}},	//   _लिये_, ісцк, ינאל_, рфей
  { {0xed56000a,0x5c040033,0xf1bf0030,0x17150015}},	//   _הבשר_, _мяса, ldás_, مذبح
  { {0xe7080029,0x9aa5002b,0x6286002a,0xda3508f0}},	//   لتين_, _همسو, ynko, _левы
  { {0xcb120008,0x7c251a42,0x0f58000a,0x0a940033}},	//   _מלל_, lehr, שיהם_, _дасю
  { {0x95550015,0xd8420046,0x959908f0,0xaa5800af}},	//   إخبا, áčí_, ытку_, _титу_
  { {0xb465005f,0x8af9000a,0x6e240012,0xe80e000b}},	//   скол, ְהָי, zeib, _साया_
  { {0x8c1a0008,0x36d4005e,0x60d61a43,0x6e240030}},	//   אותי, _дохр, _stym, yeib
  { {0x9980002c,0xca7a004c,0xd24f0015,0x62861a44}},	//   žiť_, ָנשט, ّنَ_, unko
  { {0xf6520008,0x7c2500b8,0x9856002a,0xd5480040}},	//   _מצא_, kehr, słą_, _نجوم_
  { {0x75360053,0x7d0400f2,0x200c0020,0x660910cc}},	//   _לאנד_, vuis, üdi_, lgek
  { {0x64430b41,0x78a30024,0x8fa6070e,0x74120002}},	//   _inni, ilnv, саве, _رويا
  { {0xa3df000b,0x7d041a45,0x22f605bd,0x44251a46}},	//   तरक_, tuis, _הזקן_, lel_
  { {0x75290111,0x6e2405c7,0x3daa0054,0x628700bc}},	// [2c20] nwez, reib, укао_, čkot
  { {0x8b260010,0x31370135,0xa3ab000b,0x7c250012}},	//   йдзе, _פנים_, _खरा_, gehr
  { {0x291f00f2,0x00bb000a,0xb9c60021,0xdb24002b}},	//   _apua_, _תמימ, مقاي, توای
  { {0xa2ca014e,0x201800c0,0x44251a47,0x7d041a48}},	//   _संस्, lfri_, hel_, puis
  { {0x6443022d,0x2baa005d,0x66090161,0x44251a49}},	//   _onni, _करवा, dgek, kel_
  { {0xd90d0086,0x38a9163c,0x91bb000a,0xeb9a1a4a}},	//   ئیل_, túra_, אמני, _биг_
  { {0xfaa60010,0xbad50010,0xf1bf1a4b,0x8ad8000a}},	//   _гаво, _міты, ndár_, _כַּפ
  { {0xa6c700e6,0x64431042,0x14f80054,0x44251a4c}},	//   حويل_, _anni, анић_, eel_
  { {0xc9660010,0x4d7b0053,0x89661a4d,0x96170015}},	//   _увай, ָריע, _укаж, صغير_
  { {0xe8d70008,0x442502b3,0x68f30046,0xa2f402dd}},	//   _לומר_, gel_, ředí, опоч
  { {0xd3d70029,0x4c9b000a,0xd7960015,0xd7ef0015}},	//   حبًا_, רביו, _الضخ, _سكن_
  { {0x44250176,0x46690036,0x64430b84,0xf2c30033}},	//   ael_, _крім_, _enni, ясьн
  { {0xf4d70015,0x44251a4e,0x0000006a,0x0000006a}},	//   _هونغ_, bel_,   ,
  { {0x27ee002e,0x23480086,0xe3af002b,0xe81b000b}},	//   nafn_, _نسبی_, ظری_, प्पा_
  { {0x447b0008,0xd6f80008,0xa6f8000a,0xd47b000a}},	//   _תנוע, יִּש, יִּי, _תאול
  { {0x7c2500b8,0x63be0046,0x8e150033,0x6287111e}},	//   wehr, ězně, ўдац, čkos
  { {0xdc550124,0x463b0053,0xcbc70015,0xd0110015}},	// [2c30] овањ, נעמע, مزاي, _قلة_
  { {0xba3d0046,0x61ef1a4f,0xddc6005a,0x8cf40138}},	//   _lhůt, lacl, _mokř, язуц
  { {0x212b0176,0x50d40086,0x99d90015,0xdfd2002b}},	//   lwch_, _وزیر, لواء_, _تيپ_
  { {0x44251a50,0x19eb0015,0x639b000a,0xe81b000b}},	//   zel_, اراً_, נסאנ, प्ना_
  { {0x212b0176,0xa2bc0053,0x44250700,0xa3e8000b}},	//   nwch_, אמאט, yel_, बरा_
  { {0xb17c000a,0x37090015,0x27ee0034,0x212b0034}},	//   נטגר, لْتُ_, gafn_, iwch_
  { {0xb8d0005d,0x2bdf005d,0x212b0026,0x44251a51}},	//   _टी_, _प्या, hwch_, vel_
  { {0x0f7c000a,0x5eec000a,0x44251a52,0xba740015}},	//   טרול, רַגְ, wel_, _فاقت
  { {0x200a0026,0x20180034,0x44251a53,0x4900000b}},	//   ygbi_, yfri_, tel_, _रियो_
  { {0x212b0176,0x75290111,0x24960086,0x660902f7}},	//   dwch_, rwez, ينيد_, sgek
  { {0x224a000d,0x212b0026,0x44251a54,0xb76712ae}},	//   апни_, ewch_, rel_, _утай
  { {0xd6ab0070,0x44251a55,0xc049000a,0x212b0034}},	//   _صدام_, sel_, _בז_, fwch_
  { {0x212b0176,0xa4f70086,0xc5e8000a,0x14750015}},	//   gwch_, _اکبر_, _הַצֹ, _واتج
  { {0x6443002e,0x73c40015,0x316c002a,0xd00a0054}},	//   _unni, _فيهم, ądz_, јеве_
  { {0x1fb5106d,0xe81b000b,0xdfcf0015,0xae7a062f}},	//   зстр, प्या_, ضيق_, асах_
  { {0x212b0026,0x00ca08a6,0x35d1000b,0x201800d6}},	//   bwch_, _клик_, _हलफ़, sfri_
  { {0x63a30176,0xf1bf002d,0x80e60015,0x212b0034}},	// [2c40] _hynn, leán_, _بأعل, cwch_
  { {0x63a30084,0x0c230080,0x3e670020,0xf1b90089}},	//   _kynn, ммун, _võta_, ýše_
  { {0xd138005c,0x5b2600a2,0x49ca1a56,0xeafa0021}},	//   łąd_, تفال, ален_, شرات_
  { {0x09e3000d,0x7e6d1a57,0x63a30bc8,0xb1cd000a}},	//   доцн, chap, _mynn, ְמוֹ
  { {0xe80e000b,0xb5fd006f,0xba1700c3,0x67d415df}},	//   _सादा_, chši, تينا_, полу
  { {0x6e360007,0x88c50015,0xd7f00015,0xd8b70015}},	//   ldyb, ستهل, ركب_, يدوا_
  { {0xc053000a,0x466a0783,0x7e64005b,0x0000006a}},	//   וזג_, ирим_, okip,
  { {0xf1bf002d,0x27ee002e,0x7791002b,0xddc40045}},	//   deán_, safn_, رینا, chiţ
  { {0xceb3011f,0x7d161a58,0x7e641a59,0xad1a004f}},	//   ויה_, ntys, ikip, ׁוֵר
  { {0xc8660029,0x63a30026,0x7d7b000a,0xf71a0033}},	//   _بطري, _bynn, ינפו, _віды_
  { {0x63a30176,0xe3b80064,0xfbd3000a,0x7e64008c}},	//   _cynn, ldız_, ותת_, kkip
  { {0x212b0026,0x63a30026,0x63b50057,0x45460015}},	//   twch_, _dynn, ýzna, _وناق
  { {0xa2ca000b,0x61ef0110,0x212b0034,0xc6b7000a}},	//   _सूर्, racl, uwch_, _והאי_
  { {0x212b0176,0x74130002,0x14180015,0x4543002b}},	//   rwch_, _يونا, _طيبة_, _آنوق
  { {0x63a30176,0x212b0176,0x9f340036,0xb6d8000a}},	//   _gynn, swch_, мері, מַּט
  { {0x97570008,0xa195017f,0x64581a5a,0x12780015}},	//   חילו_, _найч, _hovi, _وحيث_
  { {0x7e6d1a5b,0xd01b006b,0x5bcb0054,0x9856002a}},	// [2c50] rhap, _кфн_, аћег_, słę_
  { {0x2ba70001,0x61ed1a5c,0x7e641a5d,0x6e360091}},	//   ојев, _heal, akip, adyb
  { {0xf42900f2,0x30940015,0x998f0030,0x629d1a5e}},	//   lmää_, _تشيس, vegő_, ooso
  { {0x3ae70026,0x60cd003f,0x61ed003e,0x13b7004c}},	//   rŵp_, _kuam, _jeal, קהאל_
  { {0x61ed17ce,0xd92b006b,0x6d4b0123,0x67210160}},	//   _meal, рцел_, ågad, _splj
  { {0x60dc000a,0x64581a5f,0x629d1a60,0x8d5a000a}},	//   סקונ, _novi, hoso, _הכשי
  { {0x915e0092,0xb5fd0024,0xf42900f2,0xad9b002d}},	//   oặc_, ekša, hmää_, _gcúr
  { {0xdb1c00dc,0x99d40015,0x7c35165d,0x63a31200}},	//   _ugrá, _يتقا, _hazr, _rynn
  { {0x65600026,0x629d1a61,0x4585004a,0x2806013f}},	//   gymh, doso, ягив, ávné_
  { {0xf1bf002d,0xb9240015,0x33d4005e,0x1309004a}},	//   teán_, _تفكي, міют, бной_
  { {0x61ed002d,0x07080029,0x6b56000a,0x13a7002b}},	//   _beal, _ويكي_, ִישׁ_, تندی_
  { {0x61ed002f,0xf1bf002f,0x7d160c4d,0xd575005e}},	//   _ceal, reán_, ytys, _нуль
  { {0xf8cb005d,0xf1bf002d,0x61ed1a62,0x66060030}},	//   ादिय, seán_, _deal, ókke
  { {0x653a00b2,0x63a31a63,0xc952000a,0x7c35172e}},	//   _לענד, _tynn, תמך_, _nazr
  { {0xdfcf0018,0x61ed0c0b,0xe432002b,0xbf650015}},	//   ايف_, _feal, _سفيد, ودفو
  { {0xee3a0001,0x64460024,0xe81b000b,0x61ed0921}},	//   љна_, ēkie, प्ता_, _geal
  { {0xf1bf002f,0xd00a03ae,0xc6920643,0x7e641a64}},	// [2c60] neál_, _лепе_, גאן_, rkip
  { {0x7e641a65,0x61ed1a66,0x7d161a67,0x76590034}},	//   skip, _zeal, rtys, _lowy
  { {0x8b260036,0x6d4b00c0,0xe805021e,0x7d161a68}},	//   ядже, ägar, _राजा_, stys
  { {0x76590050,0x0ae90029,0x2bbd000b,0x9f5f01d3}},	//   _nowy, تركي_, ्ख़ा, _árán_
  { {0x9056000a,0x63a6002a,0x28f80033,0x98a60e4d}},	//   ּסֶף_, ękni, цель_, пиде
  { {0x26cc02c1,0xb8f4000b,0x28f7004a,0x68e90034}},	//   _pudo_, _सं_, чешь_, _dwed
  { {0xe1ff005c,0x629d0b63,0x765900e7,0xa8170040}},	//   chów_, yoso, _bowy, ستور_
  { {0xfaa30191,0x7d041a69,0x9b17000a,0xf429008c}},	//   _засо, oris, _מחלה_, ymää_
  { {0x68e90026,0xb5fd003d,0xf64f0015,0xa3e8000b}},	//   _gwed, ukša, ائى_, बरल_
  { {0x26cc03af,0xd4d70029,0x61ed1a6a,0xb21b02de}},	//   _tudo_, أبيض_, _seal, nnæv
  { {0x61ed0005,0xa3b6005d,0xe61a061d,0x229503ad}},	//   _peal, चें_, _где_, диня
  { {0xd3770010,0xe707002b,0x7d041a6b,0xb6d30058}},	//   ячы_, _رسمی, kris, _أقنع
  { {0xe5340080,0xc0e40010,0xf1bf002d,0x104b006b}},	//   _цель, ноўк, ceál_, бяви_
  { {0x61e001e2,0x61ed003e,0x55bb0008,0x629d00f2}},	//   ımla, _weal, _המדו, soso
  { {0xda0d005d,0xf42900f2,0x7c3502c6,0x60c5007c}},	//   _हालत_, smää_, _razr, _vihm
  { {0xe0df02b9,0x7c350085,0x7d041a6c,0x816b0cb0}},	//   ppò_, _sazr, fris, _гроб_
  { {0x81fc0008,0xaffd0036,0x2249002c,0x82340040}},	// [2c70] _ההחז, _копi, _inak_, _سريا
  { {0xdfd10029,0xfbd00015,0x0000006a,0x0000006a}},	//   _جيد_, هتم_,   ,
  { {0xaac703c4,0xde590036,0x68e91a6d,0x7d041a6e}},	//   ستان, _дані_, _swed, aris
  { {0x7d18002f,0x68e90035,0x7d041a6f,0x5ee8000a}},	//   éasá, _pwed, bris, _מַשְ
  { {0x3ea90123,0x17c90e77,0xd91b0088,0xe8f801f3}},	//   mlat_, огли_, сье_, злі_
  { {0x01380008,0xc7a50036,0x49b80018,0x07a51a0d}},	//   פרות_, милк, ساند_, малн
  { {0x76590d72,0xe80e000b,0xb8f4000b,0xdce4002a}},	//   _powy, _सारा_, _सू_, dzię
  { {0xd8770074,0x645c01d1,0xb5fd00bd,0x5692009c}},	//   _کارب, örin, akšn, кајт
  { {0x58050015,0xa525005e,0xdb1c0123,0xb8150099}},	//   _يورك, ємод, _egrä, _одај
  { {0x22490375,0x3ea9008c,0x383500fd,0xe01f000b}},	//   _anak_, hlat_, _інер, म्मद_
  { {0x8bd6000a,0xc1ea0015,0x3ea91a70,0xa22a1a71}},	//   וותו_, يّده_, klat_, ожна_
  { {0x1dbf005d,0x03940010,0x179a000a,0x38b20045}},	//   ्शात, эрыя, _ויעב, râre_
  { {0x66c70061,0xb148002b,0x13a7002b,0x3ea91a72}},	//   _fıkr, سیدم_, تنگی_, dlat_
  { {0x63850124,0x55ba000a,0x3ea90123,0x22491a73}},	//   _огла, _ומנו, elat_, _enak_
  { {0xe29f0084,0xd3350010,0x7545005c,0x82860029}},	//   boð_, _цэлы, łrzę, _يجعل
  { {0x0eaa0010,0xecea024f,0xe058002b,0x7d041a74}},	//   ікай_, ждал_, _کیست_, tris
  { {0x32d30023,0xd12f0086,0xb21b02de,0xbea30c6e}},	// [2c80] _hãy_, _نمي_, tnæv, татк
  { {0x7d041a75,0x6c4a0015,0x25a2007c,0x2249088b}},	//   rris, غلاف_, ükli_, _znak_
  { {0x7d041a76,0x3ea91a77,0x7c650058,0xbad60138}},	//   sris, blat_, راكل, фізы
  { {0x3ea90251,0x7d040376,0x20d4007c,0x2a660085}},	//   clat_, pris, _käi_, ukob_
  { {0xaac50086,0xbdfb0086,0x20d40607,0x2bdf000b}},	//   رتمن, _برپا_, _jäi_, _प्वा
  { {0xd6da1a78,0xe8940033,0x9cb6002b,0x3ea01a79}},	//   оти_, эаль, _آمست, loit_
  { {0xf793008f,0x3ea008cf,0x80d50065,0x45d402ed}},	//   кашэ, ooit_, _यूने, нойс
  { {0xa3c3005d,0xdce4002a,0xf729005e,0xdb1c0123}},	//   ्शन_, wzię, яцій_, _vgrä
  { {0x64c8000b,0xd40602ed,0x20d40072,0x0000006a}},	//   रदेश, мяни, _näi_,
  { {0x986a0015,0x2db7000a,0xc3540004,0x33860033}},	//   _بحرف_, ולפן_, екој, думв
  { {0xd37a062d,0xe29f001a,0x88c50015,0x68e20416}},	//   ючи_, toð_, _ستكل, lpod
  { {0x57250086,0x32d30092,0x68e21a7a,0x056612ff}},	//   _سرمق, _dãy_, opod, _овен
  { {0xa2ca005d,0xf1ab0086,0x76bb0008,0xddcd006f}},	//   _संक्, تاده_, _ומאפ, tiaž
  { {0x104b0036,0x9f43002c,0x33940010,0xdbf30061}},	//   цями_, majú_, _палё, _işçi
  { {0x9f43002c,0xc058022a,0x442c1a7b,0x32d30016}},	//   lajú_, фія_, med_, _gãy_
  { {0x92580029,0x02fb000a,0x442c1a7c,0xd737000a}},	//   _يشير_, _ולהמ, led_, וטלת_
  { {0xdfd510a7,0x865b0008,0x9f43002c,0x442c1a7d}},	// [2c90] _попы, קדמי, najú_, oed_
  { {0xb5fd0048,0x442c1a7e,0x3ea91a7f,0x2919003d}},	//   ekšl, ned_, slat_, _īsa_
  { {0x9f43006f,0x1ae4005e,0x68e21a80,0x442c1a81}},	//   hajú_, воєм, epod, ied_
  { {0x2bdf0372,0xfbdf014e,0x9f43002c,0x3a750010}},	//   _प्रा, _प्रम, kajú_, элер
  { {0x26de04ed,0x4dda0008,0x442c1a82,0xd82504e0}},	//   _atto_, _מחרו, ked_, едли
  { {0x9f43002c,0x442c1a83,0x961d003d,0xf84b004a}},	//   dajú_, jed_, diņa, ючей_
  { {0xa2ca005d,0x442c1a84,0xb6a50511,0xc7a2006d}},	//   _संग्, ded_, никл, лишк
  { {0xbb480086,0xee320008,0x442c1a85,0x628f0079}},	//   _تلفن_, ָֽה_, eed_, jnco
  { {0x660600dc,0x9989005c,0x79a70e88,0x442c0335}},	//   ókka, żał_, _црве, fed_
  { {0xa2ca014e,0xe451003b,0x442c1a86,0x57270015}},	//   _संख्, اضة_, ged_, _يراق
  { {0xae0f005d,0xcc56000a,0xe2860c96,0xfe0f000b}},	//   िलान_, תבתי_, елни, िलास_
  { {0x644a1a87,0xa3c0000b,0x442c007c,0x9f43006f}},	//   _enfi, ूख़_, aed_, bajú_
  { {0x3e6e002e,0x442c1a88,0xd36e002b,0x764b0030}},	//   _nýta_, bed_, لهی_, _ingy
  { {0x442c1a89,0xa06a0010,0xa8790053,0xa2ca021e}},	//   ced_, чага_, לאָר, _सूक्
  { {0x6e2d002d,0x53320004,0x3ea01a8a,0x7f1901c6}},	//   feab, _бејт, toit_, міту_
  { {0x7d0d003f,0xb13a0015,0xddcd002a,0xd7f10016}},	//   fuas, _فأخذ_, ciaż, _lẽ_
  { {0x3ea01a8b,0x8cca0015,0x62861a8c,0x98a40091}},	// [2ca0] roit_, سواق_, miko, _esmę_
  { {0xc19b0008,0x69db0077,0x628609cb,0xbca60067}},	//   _משפי, _afue, liko, رماي
  { {0x9f43002c,0x961d0024,0xb5fd0024,0xe1ff002d}},	//   zajú_, ziņa, ekšm, mhór_
  { {0x649c0064,0x442c07e9,0x6e2d00da,0xfce615d5}},	//   _içiş, zed_, ceab, _помо
  { {0x442c003e,0x3cd50010,0x58d7005e,0x6286008c}},	//   yed_, _аўст, едія_, iiko
  { {0x442c003e,0x9f43002c,0x62860e95,0xddcd002a}},	//   xed_, vajú_, hiko, cjał
  { {0x442c003e,0xe66600d7,0xa09b000a,0xab090015}},	//   ved_, етпо, היסט, _يتفق_
  { {0x442c0495,0x9f43002c,0x961d003d,0xdb1f0030}},	//   wed_, tajú_, tiņa, _óvár
  { {0xdb1c002d,0x442c1a8d,0x35b4006b,0x39460033}},	//   _ngrú, ted_, ъбир, _янаг
  { {0x998000df,0x7d7b0008,0x9f43002c,0x47d30015}},	//   žių_, פניו, rajú_, _ميكر
  { {0x442c1a8e,0x9989006f,0x62861a8f,0xe56f002b}},	//   red_, ľať_, fiko, لطی_
  { {0x62860005,0x9989002c,0x442c1a90,0xf1a7056d}},	//   giko, žať_, sed_, ергн
  { {0x442c0abe,0x60f80088,0x2c6f002a,0x93aa002b}},	//   ped_, нняя_, ażdy_, _کاشف_
  { {0xc0580484,0x62861a91,0x644a00da,0x7d0d008c}},	//   ніс_, aiko, _unfi, vuas
  { {0xcf9800d0,0x2f28006b,0x533410b7,0x6e2d1a92}},	//   ејт_, нюто_, _рейт, teab
  { {0xad9b0125,0xb21b1a93,0x3e6e006f,0xce580033}},	//   _ndúc, rnæs, _pýta_, насц_
  { {0x8d740015,0xbbeb0015,0x6e2d1a94,0x1bd50a66}},	// [2cb0] هاكا, كرام_, reab, возя
  { {0xf8b80092,0x9c380054,0x6e2d1a95,0x38a90030}},	//   _nhĩ_, нпут_, seab, púri_
  { {0x749b0008,0x39441a96,0x307c000a,0x68fb0085}},	//   לימפ, _arms_, _מאזנ, _svud
  { {0xd7f100a7,0x636b00dc,0xa9350015,0xbae40015}},	//   _sẽ_, lönö, َّاب, اكني
  { {0xb5fd0091,0x26da013f,0x5fd50065,0x7d0d01e0}},	//   ukšm, ípon_, _दलाल, quas
  { {0x717c000a,0x62861a97,0xf1b4000a,0x0f8b004f}},	//   הנדס, ziko, נסס_, ּאֵ֑
  { {0xa695009c,0xd874002b,0x63aa0034,0x39441a98}},	//   криј, دانب, _nyfn, _erms_
  { {0x99d40015,0x8aa400e2,0x6edc00bc,0x62861059}},	//   _متكا, _бруд, _učbe, xiko
  { {0x58d50036,0xf9930018,0xa2cb000b,0x62861a99}},	//   _розт, _صبر_, _संज्, viko
  { {0x44651a9a,0x58d40a21,0x290f007c,0xb9c40015}},	//   твов, _софт, muga_, _صقلي
  { {0xe3b9008f,0x63aa0176,0xfbd20008,0xe29a0770}},	//   ьбо_, _cyfn, יתי_, дан_
  { {0x63ae0061,0x63aa0034,0xf987012c,0x2485007c}},	//   übna, _dyfn, لب_, silm_
  { {0xa56400e6,0x290f0020,0x0fda004a,0x867a000a}},	//   _مدون, nuga_, дьбы_, _קרנו
  { {0x291d0fcd,0x62861a9b,0x5576000a,0x0000006a}},	//   itwa_, siko, _בענן_,
  { {0x63aa0026,0x290f199c,0x8fa60254,0x93440015}},	//   _gyfn, huga_, таве, _مخيم
  { {0x290f0020,0x7bdc04ed,0xf2d20008,0xe3b00067}},	//   kuga_, _sfru, _דעה_, _اره_
  { {0xc5f200a3,0x6284002a,0x290f007c,0x7e230054}},	// [2cc0] ידן_, _imio, juga_, јдуж
  { {0x20040007,0xad650015,0x6aca000b,0xf0ba002b}},	//   ėmis_, دافه, िद्र, _تابش_
  { {0x753c003d,0xbb4a0058,0x78a3005b,0x9a250138}},	//   ārzi, بلان_, donv, сiяй_
  { {0x290f1a9c,0xf98a0015,0xc986012b,0x9f97004f}},	//   fuga_, وناي_, кули, _ידיה_
  { {0xf9920015,0x290f007c,0x89330015,0x645c01be}},	//   جبا_, guga_, لعوا, örik
  { {0x7afc016f,0xa7fc0064,0x6aa20020,0x4813005e}},	//   _tvrt, _alır, soof, иміс
  { {0x7c3c002f,0xba0a0015,0x291d01d7,0xe72f0015}},	//   _iarr, _يترك_, atwa_, قصي_
  { {0xcf93000a,0xc6a6006b,0xaac50015,0x96341a9d}},	//   יטו_, ърли, _متقن, униц
  { {0x291d005c,0x08c60010,0xdd110061,0xe60f002b}},	//   ctwa_, _абан, _müşe, زشي_
  { {0xccf3000a,0x38cb002b,0x3e67007c,0xdb0e0045}},	//   סכת_, _قالی_, _võti_, _izbâ
  { {0xd2510074,0x64a30083,0x18770008,0x961d0024}},	//   مند_, раќа, _שעבר_, ciņo
  { {0xa77b01ac,0x2179004a,0x8717000a,0xf5060033}},	//   _קראפ, еймы_, _יקבע_, _аздо
  { {0x95530074,0xaf340086,0x3437002b,0x51840054}},	//   _نخوا, یرفت, رسید_, аура
  { {0x3e7506f5,0x8cd6000b,0x2584003d,0xa3d312ae}},	//   _måte_, _बढ़ो, rīlī_, _кошч
  { {0x6d4617e3,0x54330031,0x66020247,0x1ee7009a}},	//   _arka, _ضرور, _kdok, ئوری_
  { {0x3cfe005d,0x443e1a9e,0x636b0030,0x443c1a9f}},	//   _लिखे_, ldt_, sönö, _hav_
  { {0x961d0048,0x5cb90010,0xdd110064,0x7c3c1aa0}},	// [2cd0] ziņo, елаў_, _düşe, _barr
  { {0x1a650086,0x443c1aa1,0x443e1aa2,0xcfab002b}},	//   گیری_, _jav_, ndt_, _يادم_
  { {0x44e20023,0x6d4600b8,0x6ec70029,0x7c3c1aa3}},	//   hư_, _erka, _لتحق, _darr
  { {0x7c3c002f,0x99840007,0x290f1aa4,0x8f88000a}},	//   _earr, _namų_, tuga_, _יְרֵ
  { {0xc27c00f3,0xe8df0016,0xb9250067,0x1a040033}},	//   וראי, _trọn_, افتي, рпім
  { {0x443c03eb,0xfc640063,0xad1a0008,0x443e0111}},	//   _nav_, _късн, _אושר, jdt_
  { {0x291d005c,0x290f0020,0x46f40010,0xa4f7002b}},	//   stwa_, suga_, ачыт, چکتر_
  { {0x443e0111,0xc1e3021e,0x9f5e0003,0x6d460123}},	//   edt_, _क्लब_, ûté_, _yrka
  { {0xfeca0053,0x7e6d1238,0x2614000b,0x6e3d02f2}},	//   עמפּ, ikap, _धारी_, _masb
  { {0x649d0251,0x38a9006f,0x49740033,0x7e6d008c}},	//   nèix, túru_, _тлус, hkap
  { {0xf7700086,0x46150087,0x7e6d1aa5,0xc169000a}},	//   _وام_, _موار, kkap, _צח_
  { {0xe0c900b2,0x32ba0029,0x6d03000b,0x443e0079}},	//   _זײ_, عددة_, _लिंग_, adt_
  { {0x321e005c,0x7e6d1aa6,0x51f7009a,0x0000006a}},	//   ęty_, dkap, دسپر,
  { {0x85b80086,0xdfd200e6,0x66020227,0x7e6d0030}},	//   _شانس_, صير_, _zdok, ekap
  { {0x141a000a,0x6569008c,0x1e960db7,0x44271aa7}},	//   _נוקב, lyeh, грар, _ibn_
  { {0xd7f10023,0x93bc0045,0x9e750054,0x6da6004a}},	//   _dõi_, sfăc, аћуј, гиба
  { {0x261b005d,0xbda50029,0x614616d7,0x12a90015}},	// [2ce0] _यानी_, لحكو, _сепа, _جدوى_
  { {0x31570008,0x7e6d0019,0x7e761aa8,0xc157000a}},	//   _עיין_, akap, shyp, _עשיו_
  { {0x8e86068e,0x9cb30015,0x629d0003,0xaa460004}},	//   _бгне, حملت, érog, лежл
  { {0x7c3c1042,0x998d002a,0x26da006f,0x6d460085}},	//   _warr, _oceń_, ípom_, _trka
  { {0x7c3c1aa9,0x99550061,0x58860174,0x0d83024e}},	//   _tarr, rüşe_, лыка, _глян
  { {0x8d4b0008,0x219b004c,0x61f61aaa,0x98a30f82}},	//   _אֲלֵ, עבסא, _leyl, биче
  { {0xc7af02bf,0x7fd700a3,0x2bc3000b,0x87260021}},	//   сё_, נוקס_, वेदा, اعتم
  { {0x9b930029,0x443c1aab,0x657b0012,0xfaa61aac}},	//   _الفت, _sav_, fzuh, _сабо
  { {0x6d441aad,0x443c0007,0x44271aae,0xb355002b}},	//   nvia, _pav_, _bbn_, ییها_
  { {0xd5c0005d,0xe8d70008,0x443e0079,0x7414012c}},	//   शेषज, _עובר_, udt_, جودا
  { {0x443e0a9c,0xd8770015,0xfc57004c,0x61f61aaf}},	//   rdt_, _حملت_, אביש_, _beyl
  { {0x673a0085,0x71750015,0x479b000a,0x61f61ab0}},	//   _istj, لهجا, _איבס, _ceyl
  { {0x6d44002c,0x61f80010,0x9f510057,0xc50a0015}},	//   jvia, ыняў_, razí_, _أتصل_
  { {0x60d60064,0x14180015,0xc05b01f3,0x6d44006f}},	//   _duym, _شيبة_, хім_, dvia
  { {0xb4c2005d,0xb4c0005d,0xcebb0001,0x5ea50029}},	//   ्दी_, ंगी_, еља_, لمسل
  { {0xe80e005d,0x38bb00dd,0x539b000a,0x4ea71ab1}},	//   _साझा_, mêre_, _ריהו, урга
  { {0x38bb00dd,0x6abb0026,0x5d550254,0x6e3d00aa}},	// [2cf0] lêre_, _rhuf, шкат, _vasb
  { {0x673a0020,0xd01100e6,0x9ed9017a,0x7e6d1ab2}},	//   _ostj, _بلد_, _имот_, skap
  { {0x649d0251,0x38bb00dd,0xca15006b,0x600c000a}},	//   rèix, nêre_, иджъ, _נִזְ
  { {0x99d40067,0x8bc40088,0xbddb0144,0xe74d0030}},	//   متها, ссуд, _enèr, _kéöü
  { {0xc27c00b2,0x8dfa0008,0x527c0053,0xe9d80010}},	//   ערדי, _שהשת, ענדא, укі_
  { {0x1bd4058f,0x8d48000a,0xa9661ab3,0x00f8004f}},	//   _горя, _עֲרֵ, риша_, נמוך_
  { {0x4af60086,0xdc9a000a,0x4c9a000a,0x1a65002b}},	//   _نکند_, _יישל, _יבשו, _پیشی_
  { {0x0f580008,0xe1ff002a,0x442701d7,0x9a871ab4}},	//   ריהם_, mków_, _sbn_, _сугл
  { {0xd4550036,0x7d0d08f5,0xb4c2000b,0x4d57000a}},	//   атнь, nras, ्दू_, רֹ֔ן_
  { {0x7c25002d,0x032500d0,0xddc40007,0x657b0012}},	//   nfhr, адон, nkiš, rzuh
  { {0xe1ff0050,0x96550063,0x3a3f1404,0xee3f006f}},	//   nków_, _вълч, _kaup_, _akým_
  { {0x216a0036,0x6d440007,0x7c25002d,0x61461ab5}},	//   вими_, yvia, hfhr, аема
  { {0xe2971ab6,0xc568006e,0x34951161,0x7d0d1ab7}},	//   рая_, _محول_, _кадр, jras
  { {0xd4660124,0xb4fa0008,0xe5c40010,0x38bb00dd}},	//   _више_, _ספצי, _усхо, bêre_
  { {0x6ec60015,0x6f630004,0x1eaa0015,0x7d0d1ab8}},	//   لترق, оврз, ناري_, eras
  { {0x539a0e22,0xe1ff005c,0x7afa002e,0x29000007}},	//   _ביצו, dków_, _ætti, šiai_
  { {0xf6520008,0x4c860010,0xac860219,0x1cba0015}},	// [2d00] חצן_, алав, агал, نائب_
  { {0xe0fb013a,0xd12f0086,0x70770086,0xf7f2002a}},	//   _שליל, _کمی_, _ناپذ, ężką_
  { {0xdddd0014,0x0ca900a2,0x2abc0077,0x64411ab9}},	//   _első, اطقي_, híbe_, idli
  { {0x6da60036,0x8b650029,0xf38c004c,0x7d0d1aba}},	//   _вима, حاكم, עראָ, bras
  { {0x2900001c,0x9f430077,0xed430033,0xe1ff002a}},	//   éia_, bajó_, _дняп, aków_
  { {0x20181abb,0x3eb200f2,0xf1b90264,0x3706007a}},	//   ngri_, llyt_, ýši_, ачив
  { {0x26cf02f2,0x64411abc,0x27170015,0xe1ff002a}},	//   _bigo_, ddli, لآية_, cków_
  { {0xeb970191,0x644100b8,0xbb3b0008,0x2240013c}},	//   _тис_, edli, _בעלי, _naik_
  { {0xd5b70a7f,0xd9460054,0xb9290015,0x7a460030}},	//   ись_, _њези, _مثلك_, gétő
  { {0xb4c0005d,0x91690092,0xb4c2005d,0x38bb00dd}},	//   ंगे_, _lựa_, ्दे_, têre_
  { {0x3e7500c0,0x36060029,0x2240013c,0x0ec6000b}},	//   _låta_, _نواف, _baik_, लगाड
  { {0x92940010,0x7ae10030,0x38bb00aa,0x39461abd}},	//   жаюц, _élte, rêre_, ovos_
  { {0x867b0008,0x265b000a,0xe1ff002a,0x7416002b}},	//   _בראו, _שכדא, zków_, _نوشا
  { {0x27fc0cd8,0xe1ff005c,0x3946016e,0x7d0d0363}},	//   navn_, yków_, ivos_, vras
  { {0x06fd0089,0x94bb000a,0xa857000a,0x43370015}},	//   žívá_, _שמות, סילה_, _نسيج_
  { {0x2295002b,0xf777000a,0x41e7005e,0x7d01001a}},	//   _دلبس, בעלי_, _тіка, járý
  { {0x7d0d1abe,0x91690092,0xb2bc000a,0xdb1c002a}},	// [2d10] uras, _dựa_, _במהר, _ogró
  { {0xe1ff005c,0x7ae90046,0x7d0d1abf,0x61fd1ac0}},	//   tków_, _četb, rras, lasl
  { {0x309a0008,0x99d50029,0x2a641ac1,0x9e350004}},	//   _תשתמ, مقات, _bomb_, _ленч
  { {0x7e550086,0xde590484,0x7d0d1ac2,0x8f36000a}},	//   _انحص, _самі_, pras, _פארו_
  { {0x39490467,0x0dcb000d,0xe1ff005c,0xf9900002}},	//   ías_, _јуни_, sków_, وبه_
  { {0xf8a80010,0xb4c0000b,0x49b80067,0x229200bc}},	//   авік_, ंगो_, جامد_, mške_
  { {0xb21b001a,0x6d40001a,0x61fd1ac3,0xf7490015}},	//   mhæf, _ámar, kasl, البي_
  { {0x2f980008,0x2a6400dc,0x7d1b0012,0x61fd003d}},	//   יכון_, _gomb_, _äuss, jasl
  { {0x88070225,0x4975070e,0xa3c9000b,0x99850015}},	//   _نظام, _улас, लेन_, _الذو
  { {0x2abc002d,0x981700a2,0xedb6000a,0x998f0046}},	//   ríbe_, _خبرا, מִית_, legů_
  { {0x69cb005d,0x9f580003,0x64411ac4,0xa25b016e}},	//   _तृती, paré_, rdli, rmôn
  { {0x6f150467,0x27211ac5,0x290f1ac6,0x625a1ac7}},	//   duzc, món_, orga_, урор_
  { {0x2935004c,0x51170033,0x27211ac8,0xe5090015}},	//   זאָן_, боўю_, lón_, _إيتو_
  { {0x05a8005e,0x672300bc,0x6f0804b2,0xd5b40015}},	//   _твій_, otnj, ádco, _بإمع
  { {0xb21b0134,0x8456000a,0xe456000a,0xdee603a8}},	//   dhæf, _לבסס_, _ליסט_, соби
  { {0xbda60015,0xd1320015,0x39460091,0xdc10000b}},	//   محذو, _فمع_, yvos_, ाल्ड_
  { {0xee370001,0x9b8a002b,0xed571ac9,0x272119b8}},	// [2d20] љну_, گنال_, бот_, hón_
  { {0xa3ab000b,0xcc090015,0x4f960004,0xb17b02dc}},	//   कअप_, لزمن_, _грму, rbåt
  { {0x5f4600a2,0xf1a9002b,0x27211aca,0x4b260004}},	//   _انجل, _مایه_, jón_, смев
  { {0x82d60053,0xef22005c,0x2010002a,0x3ea900c7}},	//   צונג_, ążę_, łnią_, coat_
  { {0x186a09ac,0x1958055f,0x3946008c,0xe9f70138}},	//   лади_, ралы_, uvos_, сніі_
  { {0xa9670054,0x2a6400da,0xfce31acb,0x27211acc}},	//   сиља_, _womb_, _хоро, fón_
  { {0xcc77000a,0xa3c9000b,0x39460091,0x61fd0f0a}},	//   _פעלה_, लेम_, svos_, yasl
  { {0x3e6e0046,0x1efb004c,0xddcd002a,0x6e361acd}},	//   _býti_, אלקע, jjaś, neyb
  { {0x61fd0014,0x9992005c,0xb5fd0024,0xe9440086}},	//   vasl, żył_, ekšs, _برزی
  { {0xd6d20806,0xb8650029,0xe56f0015,0x7d7b000a}},	//   _فقط_, _والو, عطي_, טנפו
  { {0xd5b2002b,0x2259004a,0x27211ace,0x61fd1acf}},	//   _کفش_, аины_, cón_, tasl
  { {0x41e40010,0xb5fd0007,0x0bb70008,0x9757000a}},	//   зіра, ukšt, מלים_, _ליבו_
  { {0x61fd02c6,0xb5fd0091,0x64a61883,0x645c1ad0}},	//   rasl, rkšt, _лада, öris
  { {0x2d801ad1,0x8cd3005d,0x7d160061,0x351b000a}},	//   dzie_, _भूगो, duys, _עוונ
  { {0x61e40176,0x7e6600c0,0x4fc40758,0x61fd1ad2}},	//   _ffil, _bokp, зста, pasl
  { {0x63970008,0xa195006b,0x5f941ad3,0x9e090015}},	//   _לדוא_, _майч, чист, شيطك_
  { {0x272102c1,0x81170086,0x2d58006d,0x3ea900da}},	// [2d30] zón_, _اذعا, бить_, roat_
  { {0xaae70029,0xebc70001,0xc4d3000a,0xfc300015}},	//   مسؤو, бљен, פגע_, فحم_
  { {0xb21b002e,0xb5fd0796,0xdb510015,0x7b350015}},	//   rhæf, ljše, بَا_, تفاؤ
  { {0xdb1f002e,0xf1bd005d,0xb21b001a,0x6f0116ee}},	//   _ávís, _ईरान, shæf, álcu
  { {0xae1a00b2,0xb5fd10ca,0x89370015,0x290f1ad4}},	//   _דורכ, njše, إعصا, urga_
  { {0x27211ad5,0x0c750086,0x07390029,0xd118000a}},	//   tón_, _بگرد, لسبب_, מקדה_
  { {0xe7080021,0xddcd002a,0x2d9c0061,0xe1ff1ad6}},	//   متين_, yjaś, şvet_, kaó_
  { {0xb5fd0024,0x272107ea,0xf509125c,0x628f0160}},	//   ekšr, rón_, анил_, jico
  { {0x628f1ad7,0x27210077,0x58870174,0x6499016a}},	//   dico, són_, _лыжа, итор_
  { {0x73050191,0x917a0092,0x32090064,0x6aab1ad8}},	//   опоз, hập_, _aday_, logf
  { {0x8c1a0008,0xe3b10029,0x628f0a40,0x07080015}},	//   בותי, برة_, fico, _هيلي_
  { {0x628f0656,0xc2c60015,0xd1ca0054,0xd575187f}},	//   gico, تيجي, илне_, _муль
  { {0xd5480115,0xf494002b,0x3cde000b,0x26da006f}},	//   _هجوم_, _کشند, _कंधे_, ípov_
  { {0xd01200e6,0x201e007c,0x5552009a,0x661b0072}},	//   بلس_, üti_, _آپور, lguk
  { {0xe81c000b,0x644302b9,0x661b007c,0x52860015}},	//   _नासा_, _iani, oguk, _ولتك
  { {0xee3a00d7,0x661b1ad9,0x38b20045,0x644315db}},	//   јна_, nguk, râri_, _hani
  { {0x644303ac,0x7fd6009e,0xa3c3005d,0x3c660033}},	// [2d40] _kani, _міні, ्शक_, окаг
  { {0x2d80002c,0x64431ada,0xfcb600ce,0xab2a01e9}},	//   rzie_, _jani, іщаю, иоза_
  { {0x6a860da6,0x4a46006d,0xdddd002a,0xe9da058e}},	//   олжа, жнев, _dosł, аке_
  { {0x9c870089,0x539a0008,0xe5670015,0xddc60091}},	//   _počá, ביעו, _قط_, _jokū
  { {0xdb070089,0x09360015,0xef19002a,0x79360015}},	//   _vyjá, تراج, ąże_, تعاط
  { {0xc1730008,0xd90d0086,0x64431adb,0x36d41adc}},	//   וחד_, ایل_, _nani, покр
  { {0xe3a70074,0x8b2303f1,0x09e60036,0x394d02c1}},	//   _آر_, _одре, _мовн, _eres_
  { {0xba1a0015,0x7d041add,0x7ae10030,0x628f1ade}},	//   _خيرا_, osis, _élta, xico
  { {0xd90d0086,0x9f58002c,0xe4c6004a,0xfa890033}},	//   _مین_, darí_, жённ, _усёй_
  { {0x64431adf,0xf878000a,0x67560015,0x628f002a}},	//   _cani, _פְּל, _وخار, wico
  { {0x7bdb000a,0x628f1ae0,0xd4970033,0x1cbb000a}},	//   יקיו, tico, ўры_, שמיע
  { {0xd377008f,0x7d041ae1,0xdb2100dc,0x95ca0709}},	//   ючы_, ksis, étét, _кула_
  { {0x66d50007,0x7d040024,0x64431ae2,0x628f1ae3}},	//   _iška, jsis, _fani, rico
  { {0x644309a9,0xdfd80063,0x66001ae4,0x628f1ae5}},	//   _gani, жът_, lamk, sico
  { {0x628f0a40,0x4e8b006b,0xdddd002a,0xd47b000a}},	//   pico, ащам_, _rosł, _דאגל
  { {0x7d04000c,0x637b000a,0x64431ae6,0x66001ae7}},	//   fsis, _כנוד, _zani, namk
  { {0xd9040074,0x7d0400b6,0xdddd005c,0x9d150036}},	// [2d50] _جی_, gsis, _posł, ядач
  { {0xfc330029,0x14d70008,0x660000d9,0xa0680001}},	//   بحر_, קובל_, hamk, _мања_
  { {0x66000375,0x68e9179f,0x5a350004,0x44e00016}},	//   kamk, _sted, знет, _lò_
  { {0xc1750008,0xcf92004c,0x5e590015,0xeaf80015}},	//   ּחַ_, _טטי_, _الحس_, تركت_
  { {0x9e5a0008,0xd2b80008,0x6aab02de,0x63a6002a}},	//   _הכרט, קלדת_, rogf, ękny
  { {0x68e9002c,0x3e7c0089,0xf8680015,0x48ab0054}},	//   _vted, _víte_, يمني_, штем_
  { {0xf77104c9,0x68e9005c,0xdb230086,0xa08c039e}},	//   عات_, _wted, _توزی, יְהִ
  { {0x394d1ae8,0x44e00092,0x05650142,0x4f9c000a}},	//   _tres_, _bò_, звин, יבוצ
  { {0x79820050,0xceb4000f,0x64431ae9,0x7545005e}},	//   czow, ויק_, _pani, їноз
  { {0x44e00092,0xd8770002,0x629d0a8b,0x4877002b}},	//   _dò_, _بارب, éron, _بدرس
  { {0xf1a900b4,0x229200df,0x03220010,0x11d6005e}},	//   _עס_, eška_, ндэн, зігр
  { {0x67ba0008,0x64431438,0xe29a1aea,0x47340015}},	//   _המעק, _wani, сам_, _تركز
  { {0x2bb8005d,0xa7fc0064,0x44e00016,0x64431aeb}},	//   _अर्थ, _alıy, _gò_, _tani
  { {0x7ae904c6,0xf09f0144,0x22590091,0xd1c70033}},	//   _četn, dràs_, _čekų_, яляе_
  { {0x6e2f001c,0x7982002a,0x6d4f1aec,0x1fb5144a}},	//   _bbcb, zzow, _arca, дстр
  { {0x3e6e0084,0xc7b20008,0xae59005e,0x7d041aed}},	//   _nýtt_, גבל_, орує_, tsis
  { {0xed570345,0x621b000a,0x0d860054,0x721b000a}},	// [2d60] пот_, _הופק, члан, _הופח
  { {0xe0580086,0x14d6000a,0x7d041aee,0xb564000a}},	//   _بیست_, פועל_, rsis, וֹעַ_
  { {0x6fdb000a,0x3fdb000a,0x7d0402b3,0x8ad60067}},	//   _לקיס, _לקיב, ssis, ستائ
  { {0xf09f0144,0xa176000a,0xfaa31aef,0x7aa3005e}},	//   bràs_, ּעַד_, нахо, нихз
  { {0xda650015,0x9f580144,0xadd7000a,0x0000006a}},	//   بالي, larà_, _מוכח_,
  { {0x91bb0008,0x7982005c,0xf7720115,0xe6b4002a}},	//   זמני, rzow, فاع_, łużą
  { {0xa3ab005d,0x7982005c,0x9f580251,0xbf360053}},	//   _कुल_, szow, narà_, לאַץ_
  { {0x8b9b0008,0x9aeb000a,0x45d4027a,0x09e60054}},	//   _הבלת, _לַמִ, мойс, _хоан
  { {0xa3c9000b,0xfaa30eaf,0x66001af0,0x89eb004f}},	//   लेस_, _чато, ramk, _הַבֵ
  { {0xd2510086,0x628d002d,0x660000b8,0x9cd60008}},	//   چند_, _smao, samk, הוִה_
  { {0xd2510074,0x4adc000b,0xe215004a,0x66000030}},	//   نند_, यदिव, ммны, pamk
  { {0x9f580251,0x11d90029,0xa75b0008,0x26db000a}},	//   darà_, توحة_, _לדבר, _הקאמ
  { {0xc05b0036,0x32540010,0x75d30015,0xeab1000a}},	//   бів_, хвяр, _كيما, דֹם_
  { {0x82f7002b,0xa3c9000b,0x4ee7005e,0x229202d8}},	//   _کروز_, लेह_, зіаз, rška_
  { {0xb5fd065d,0x9f580251,0x64480026,0x64581af1}},	//   ljša, garà_, mddi, _invi
  { {0x02a4008f,0x877b0053,0x290600f2,0x539b000a}},	//   _прым, זאלי, ksoa_, _ליוו
  { {0xfeb80086,0xb5fd00bd,0x2d58007a,0x98cc000b}},	// [2d70] سافت_, njša, пить_, ाषाए
  { {0x26de00dd,0xebc70001,0x7c970015,0x9f580144}},	//   _outo_, пљен, أشرا, barà_
  { {0x9f580251,0x64480026,0x2003003f,0x4b550015}},	//   carà_, iddi, maji_, بَار
  { {0x39350010,0x629d00cb,0x20030696,0x6d4b02dc}},	//   дэкс, nnso, laji_, ågas
  { {0xe9ab002b,0x26de06aa,0x6d4f0045,0xf773002b}},	//   حدان_, _auto_, _urca, کاش_
  { {0x2003003f,0x629d1915,0x89a8005e,0x9f5816ee}},	//   naji_, hnso, чків_, lará_
  { {0x61e600c0,0x97280015,0xf048000a,0x60df01c2}},	//   yckl, كثيف_, לָה֙_, _luqm
  { {0xa3c2005d,0x644806f1,0x9f580c98,0xcf58000a}},	//   ्धन_, eddi, nará_, לבות_
  { {0x64481af2,0x6d4d1af3,0x20030d06,0x9f4c0125}},	//   fddi, nvaa, kaji_, údú_
  { {0x1309004a,0x6d4d14e9,0x629d1af4,0x9f58059d}},	//   оной_, ivaa, enso, hará_
  { {0x3e7c002e,0x9f580251,0xf799002b,0x26de1349}},	//   _líta_, xarà_, _بناب_, _guto_
  { {0x9f581af5,0x6d4d007c,0x7ae90046,0x645818c4}},	//   varà_, kvaa, _četl, _envi
  { {0x6f15005c,0x9f580656,0x51550681,0x0000006a}},	//   erzc, dará_, нтру,
  { {0x9f580251,0x629d1af6,0xe588000a,0x200301d7}},	//   tarà_, anso, _מָצָ, gaji_
  { {0xa3c9000b,0xd00f0015,0x7e6401d7,0xe7270040}},	//   लेश_, ؤلف_, tjip, خص_
  { {0x9f581af7,0x76490064,0x229200bc,0x12fa000a}},	//   rarà_, ndey, mško_, _והקב
  { {0x82360074,0xdb0e0089,0x9f580251,0xb2290015}},	// [2d80] _فرکا, _vybí, sarà_, _رأيك_
  { {0x28e1005d,0xfbd20115,0x7649008c,0x66d500bc}},	//   _पढ़ि, نتا_, hdey, _oško
  { {0xab270eb0,0x6d4d1af8,0x0ae90015,0x69c0002a}},	//   доха_, avaa, كرني_, _szme
  { {0x99dd099c,0x9f580656,0x2906008c,0x4dd60015}},	//   _daňo, cará_, tsoa_, _يتحس
  { {0x64480b7c,0xda650015,0xa9670076,0x48e30033}},	//   yddi, عامي, мица_, вочв
  { {0x76590026,0x68fb005c,0xd7ef0015,0x3ead1af9}},	//   _anwy, _dwud, لكه_, čete_
  { {0x2906001c,0x8a060001,0x7bdc02f2,0xba1a002b}},	//   ssoa_, _озве, _igru, _ويسا_
  { {0x2003000c,0xc9560080,0xf429008c,0xf76f0058}},	//   zaji_, _отзы, ylää_, شاى_
  { {0xceb30008,0x6f1c1afa,0x69c018e1,0x66d50091}},	//   כיה_, hurc, _uzme, _eško
  { {0xb4b8005d,0x26de01b2,0x9f580c98,0x3d16000b}},	//   चते_, _tuto_, zará_, _फटने_
  { {0x629d1afb,0x64481afc,0xd62a1afd,0xb7db000a}},	//   tnso, rddi, _може_, _וקבי
  { {0x6f1c018b,0x9f5800e1,0x38a9006f,0x7d161afe}},	//   durc, xará_, dúry_, krys
  { {0x20030f4d,0x44f30010,0x75291aff,0x104b0b08}},	//   taji_, _апіс, ctez, ояви_
  { {0x656f00b8,0x55bb000a,0x27170016,0x7bdc01d7}},	//   äche, _ומדו, ũng_, _ngru
  { {0xf4130008,0xa2950010,0xd0d40063,0xe2ab0029}},	//   _ספק_, _пакі, торъ, _وابن_
  { {0x6d4d0111,0x4ea4017a,0x5e58004a,0xb2a70015}},	//   tvaa, вруа, мися_, _تحته
  { {0xf1a40010,0x9f580656,0xdd9404ab,0x81fc000a}},	// [2d90] _арэн, rará_, ваты, _והחז
  { {0x3156013a,0x9f580a40,0x76490061,0x6d4d1b00}},	//   _ניתן_, sará_, zdey, rvaa
  { {0xda15000d,0xbae40015,0x752900bc,0xdee700c3}},	//   едењ, نكلي, ztez, _تأخي
  { {0x8f1a000a,0x28c4000b,0x2249007c,0x1dbe000b}},	//   _צורת, _लीबि, _jaak_, ्धशत
  { {0x22491786,0xeab00029,0x99d400e6,0xcd2b0015}},	//   _maak_, جعل_, نتها, _بسجن_
  { {0x9178000a,0xacfa004f,0x212b01f9,0x0000006a}},	//   ועדף_, _מהשכ, itch_,
  { {0x7afc0176,0x20010020,0xcb690015,0x3ce5000b}},	//   _gwrt, _mehi_, _عمره_, _झंडे_
  { {0x752904ed,0x06091b01,0x26c61553,0x7bdc09bb}},	//   ttez, чник_, _choo_, _zgru
  { {0xf5480023,0x78f80015,0x76490061,0x3915012c}},	//   _cụ_, _يعكس_, rdey, _سواز
  { {0xf5480023,0x2db80008,0x75291b02,0x3365168f}},	//   _dụ_, ולחן_, rtez, евог
  { {0xa3c9005d,0xe8d60008,0xe66700a4,0x872700c3}},	//   लें_, _נוער_, _отдо, _زعام
  { {0xbbdc005d,0x75290045,0xfbd2000a,0x229207c4}},	//   _बल्क, ptez, טתי_, rško_
  { {0x0000006a,0x0000006a,0x0000006a,0x0000006a}},	//     ,   ,   ,
  { {0x38a9006f,0x7d1600aa,0x2a6d1b03,0xa855000a}},	//   túry_, vrys, _loeb_, ׂיָה_
  { {0xc7b200b2,0x2baf005d,0x7e561b04,0xb416000a}},	//   ָבן_, _जुला, нтац, _טקסס_
  { {0x9f5c09f0,0x291d0f4d,0x683301e2,0xb21b02de}},	//   _því_, kuwa_, lıdı, lhæn
  { {0xafe605f8,0xe3b80061,0xec7a01c5,0xd10a0040}},	// [2da0] _попл, ngın_, ппа_, _عقده_
  { {0xcf460010,0x68330064,0xb21b0134,0x22490111}},	//   _зной, nıdı, nhæn, _zaak_
  { {0x6bd70015,0xe803000b,0x66c50030,0x3ce5000b}},	//   فوكس_, _रज़ा_, iókb, _झूठे_
  { {0xdceb0064,0xb90604ab,0x68e00034,0x49ca004a}},	//   _çiğn, ездк, _pumd, плен_
  { {0xe2970053,0x38c8002b,0xf9920015,0x09ca0065}},	//   עכנט_, واتی_, دبا_, िधेय
  { {0x6d461b05,0x49730010,0xd90d002b,0x3ea01b06}},	//   _iska, ыліс, زیم_, lnit_
  { {0x501b0008,0xbcb70008,0x66c50030,0x7c3e0e90}},	//   לוסו, _נפלו_, zóke, mepr
  { {0x3ea01897,0x3944007c,0x8b0b000a,0xa5341b07}},	//   nnit_, _tsms_, _מִמֵ, внич
  { {0x224900dd,0xb21b0134,0xfe370008,0x3e7c0046}},	//   _raak_, fhæn, גרפי_, _líto_
  { {0xf5480023,0x224912c5,0xa9230091,0x3ea01b08}},	//   _vụ_, _saak_, ėžta, hnit_
  { {0xd7640086,0x7c3e090f,0x2c1e0065,0x9c0b004f}},	//   _جنای, iepr, _पाईं_, הִכִ
  { {0xd62a0080,0xf5480092,0x877b000a,0x270c0046}},	//   _ходе_, _tụ_, _מאבי, měn_
  { {0x22490298,0xc05b0036,0x63860152,0x399b004c}},	//   _vaak_, пів_, _béné, ִילד
  { {0x68330061,0x3ea01b09,0xa3ab000b,0xc1740058}},	//   cıdı, enit_, _कुक_, ادَت
  { {0x270c0089,0x9f340036,0xa8570008,0x2249016b}},	//   něn_, лері, עילה_, _taak_
  { {0x62670031,0x644a1b0a,0x03bb000a,0xceb80054}},	//   _سابق, _hafi, _מצול, ељу_
  { {0x5ff50063,0x443e0161,0x61ed0123,0x644a1b0b}},	// [2db0] _изпу, oet_, _ifal, _kafi
  { {0x6386038d,0x319c000a,0x8d740015,0xe81c000b}},	//   _géné, _מבחנ, دافا, _नागा_
  { {0x443e0298,0xa3c2005d,0xf24b000a,0xe3b80061}},	//   iet_, ्धि_, ּגְּ, zgın_
  { {0xd9990029,0xe3b80064,0x443e1b0c,0x291d02f2}},	//   ونات_, ygın_, het_, tuwa_
  { {0x61ed003f,0x443e1b0d,0x7c3e0007,0x68330061}},	//   _mfal, ket_, bepr, yıdı
  { {0x1d160008,0x443e1b0e,0xa3c2000b,0x98f40015}},	//   _בקשר_, jet_, ्धा_, اثنا
  { {0x1ab50010,0x61ed0026,0xd8b80087,0x8aa7005e}},	//   _абвя, _ofal, ردها_, _зрад
  { {0x2f5c0053,0x443e1b0f,0xead40033,0x0000006a}},	//   לדונ, eet_, _бось,
  { {0xe5710029,0x443e1b10,0x2e380008,0x1662004a}},	//   شطة_, fet_, תרחש_, рвым
  { {0xf9900086,0x5d48000a,0x3ea00046,0xb8e7000b}},	//   _طبق_, תָהּ_, znit_, ैग_
  { {0x68330064,0x644a1b11,0x53a50658,0x03a51b12}},	//   rıdı, _dafi, танб, тино
  { {0x7c3e1b13,0x68330064,0x8bd6000a,0x63860003}},	//   zepr, sıdı, כותו_, _séné
  { {0x63860152,0x3ea00089,0x443e1b14,0xe56e0c30}},	//   _péné, vnit_, bet_, _тз_
  { {0x61ed0176,0x659a004c,0x61430054,0x443e1b15}},	//   _efal, _קיסק, јера, cet_
  { {0xc003009c,0x63860003,0x3ea00046,0xdee609fd}},	//   рпск, _véné, tnit_, тоби
  { {0x6d460cd4,0xd336000a,0x644a1b16,0xb5fd01ec}},	//   _pska, _ירצה_, _zafi, ekšz
  { {0x7c3e1b17,0xf1bf0034,0x63860003,0x1d07118f}},	// [2dc0] tepr, ffáu_, _téné, кети_
  { {0x91770008,0x711b0053,0x764b0035,0x3ea01b18}},	//   _סעיף_, _קויפ, _lagy, snit_
  { {0x6d460050,0x290d1b19,0xbb860029,0xa3d1000b}},	//   _wska, _avea_, خلاي, वधि_
  { {0x443e1b1a,0x7c3e1b1b,0x270c0046,0xc332000a}},	//   zet_, sepr, věn_, שוא_
  { {0x443e1b1c,0x99340015,0x7c3e1b1d,0x6d461b1e}},	//   yet_, افتت, pepr, _uska
  { {0x443e11bc,0x3cfb000b,0xfd5f0016,0x270c0046}},	//   xet_, _लौटे_, huyệ, těn_
  { {0xfb16002b,0x644a1b1f,0xdc37004c,0xb09b004c}},	//   _جوزج, _rafi, _שאלט_, ויסר
  { {0x6d44005c,0x443e1b20,0x99dd006f,0x6e241b21}},	//   owia, wet_, _naňh, ngib
  { {0x48e60191,0x7ae9016f,0x644a0026,0x6602007c}},	//   _розв, _četi, _pafi, _veok
  { {0x54530080,0x443e1b22,0x442702b9,0x61ed1b23}},	//   авьт, uet_, _ccn_, _sfal
  { {0x6602022d,0xbc1b0053,0x8c1b103d,0x443e1b24}},	//   _teok, וויש, וויי, ret_
  { {0x92580080,0x443e1b25,0x644a0573,0xb5ca006e}},	//   вают_, set_, _wafi, _قوام_
  { {0x644a1b26,0x443e1b27,0xc0970015,0x3e750123}},	//   _tafi, pet_, نجست, _mått_
  { {0x8438003b,0x649a005e,0x1c1e000b,0x66c50030}},	//   _أكثر_, _ютер_, _पागल_, móka
  { {0x66c500dc,0x138a0015,0xe208002a,0xaab20065}},	//   lóka, _تخشى_, _stół_, जवाक
  { {0x645d0048,0x2ebf005d,0x3e7500c0,0x61ed003f}},	//   ēsie, ्षेत, _nått_, _ufal
  { {0x518702e5,0x3f8a0046,0xaed4005e,0x5d550174}},	// [2dd0] _шука, azbu_, ротш, ыкат
  { {0x1acb005d,0xfdc3000b,0x20c4008c,0x66c50030}},	//   िष्ठ, _शरीफ, löin_, ióka
  { {0xdfd10086,0x764000f2,0xf413000a,0x6d44002a}},	//   _ديد_, kemy, שפע_, awia
  { {0xc3330008,0xdcf70015,0xcf56000a,0xb21b02de}},	//   יוע_, _لأسب, _עברת_, skæf
  { {0x66ea005c,0xae1a000a,0x0d64006b,0x202a001a}},	//   _ręka, _אורכ, _кърм, _ýtið_
  { {0x66d50007,0xfaf3002b,0xbae50015,0xb4ac000b}},	//   _iški, _نثر_, _مكسي, कको_
  { {0x9f5100dc,0xe7080031,0x3e751b28,0x4c340033}},	//   mazó_, نتين_, _fått_, _тэўт
  { {0x3e750971,0x3fdc000a,0x7d0d01be,0x9f510077}},	//   _gått_, וקוב, osas, lazó_
  { {0xdd1201e2,0x95550021,0xdb1c0030,0x764b0091}},	//   _müşt, اخبا, _izrá, _vagy
  { {0x7c250026,0x229200bd,0x9b15000a,0x04c90015}},	//   nghr, mški_, ְחָה_, عودي_
  { {0x6d44002a,0xc759003d,0x22920085,0xe29a04bb}},	//   zwia, šībā, lški_, еан_
  { {0x09b50053,0x95550115,0xc04900f3,0xcb36000a}},	//   ָפֿט_, _مختا, _מז_, נארי_
  { {0xd5bb008f,0x44270016,0x96080033,0x9f580003}},	//   _ўсе_, _tcn_, _рэха_, mbré_
  { {0x351a0053,0xd378005c,0xc4840484,0xf8c3000b}},	//   _נוצנ, być_, _клік, षतिय
  { {0xa3c9005d,0xe29a07d5,0x8cb9000b,0x6fb6002b}},	//   लेख_, _пак_, ्तनो, امزا
  { {0x539a000a,0x6d44002a,0x26dd01d7,0xdd920040}},	//   _ריקו, twia, _jiwo_, موز_
  { {0x7d0d00b6,0x6284000c,0x6c1a0029,0xdd120064}},	// [2de0] gsas, _ilio, فتاح_, _düşt
  { {0x7640005c,0x6d44005c,0x64411b29,0x50460054}},	//   zemy, rwia, neli, _сеоб
  { {0xe47a0053,0x44e9002d,0x61e900bd,0x9f580125}},	//   ערעכ, _lú_, žele, harú_
  { {0xa3ab005d,0xaaba0086,0x4df50010,0x644109e7}},	//   _कुछ_, ردار_, _вярт, heli
  { {0x44e90084,0xd378005c,0xf2d3000a,0xa9960015}},	//   _nú_, zyć_, צעד_, دشات
  { {0x7ae9016f,0x200a0035,0x64411b2a,0x62840034}},	//   _četv, nabi_, jeli, _llio
  { {0xeef60008,0x3179005c,0xd6da1b2b,0x64410e84}},	//   אמֶר_, zysz_, нти_, deli
  { {0x66c500dc,0x9b930015,0xf60a002b,0x224200cb}},	//   tóka, _طلقت, رتبه_, jekk_
  { {0x49ca0124,0x44e91b2c,0x64411b2d,0xd49a1a9d}},	//   _члан_, _cú_, feli, ерн_
  { {0xb8ea005d,0x27f701b2,0x66e60329,0x62841b2e}},	//   ोष_, čení_, _божа, _alio
  { {0x44e9002c,0xa8570008,0xd7ef0015,0x7d0d0030}},	//   _eú_, _תיבה_, _ركن_, zsas
  { {0x66c500dc,0x35fa0029,0x74140086,0x8ccb005d}},	//   lókn, _أراد_, دوگا, _तीनो
  { {0x85760015,0xd378002a,0x44e91b2f,0xca970643}},	//   _حدائ, syć_, _gú_, רדכי_
  { {0x64411b30,0x224d0c6d,0x230a0015,0x657d0013}},	//   celi, žek_, _كتبي_, øshe
  { {0x447b00b2,0x1ee70086,0xdfd50139,0xc6c6000a}},	//   _אנגע, اوری_, ровы, ָהּ֙_
  { {0x7d0d0209,0x2005002a,0xe3130067,0xf313006e}},	//   tsas, źli_, _ابوب, _ابوظ
  { {0x320b003e,0xe21400e5,0x7d0d01be,0x629d0003}},	// [2df0] macy_, _طبيع, usas, érou
  { {0x2dd80015,0x7d0d1b31,0x320b051e,0x859b004f}},	//   طبقة_, rsas, lacy_, גשמו
  { {0x628400f2,0x66d50007,0x7d0d1b32,0x7c250125}},	//   _ylio, _iškv, ssas, rghr
  { {0xd3570008,0x639b0053,0xa3c9000b,0x6fb6002b}},	//   טיבי_, עסאנ, लेट_, _خمپا
  { {0x44250026,0x19580010,0x64411b33,0xdfd1002b}},	//   ygl_, лацы_, yeli, _ديگ_
  { {0x7e6d0020,0xfc670063,0x99d40002,0xa3e0000b}},	//   ljap, _съмн, حتما, _थलग_
  { {0x44e91b34,0xb5fd00bd,0xe0b8004c,0x26dd002a}},	//   _sú_, ljši, אלגט_, _piwo_
  { {0x7f3c0053,0x7be30064,0x3dc6002a,0x320b002a}},	//   געהו, ştuğ, żowe_, jacy_
  { {0xc68e0029,0x26c30024,0xb5fd00bd,0xe8df0092}},	//   بِي_, ējo_, njši, _trốn_
  { {0x9984003b,0x98db0029,0x62841b35,0x44e90016}},	//   _الكو, _أبرز_, _slio, _vú_
  { {0x46150074,0xc1690008,0x200a00bd,0xebd7000a}},	//   _نوار, _קח_, vabi_, נֵ֖י_
  { {0x44e9017e,0xc5d50191,0xa5f90001,0x320b1b36}},	//   _tú_, _кіль, _реду_, gacy_
  { {0x273100a7,0x200a0035,0xa3c9005d,0x224213e1}},	//   _hơn_, tabi_, लेज_, rekk_
  { {0xe3b00074,0x0574002b,0x251a004f,0x0000006a}},	//   _کره_, _دامد, _יונא,
  { {0xb4c3005d,0x200a0582,0x441a0053,0x67230849}},	//   ्षी_, rabi_, _סוקס, nunj
  { {0x6284000c,0x66c50f87,0x200a1b37,0x320b00da}},	//   _ulio, ióko, sabi_, cacy_
  { {0xb2bb009d,0x6146000d,0xee370001,0xa2bb000a}},	// [2e00] _במקר, _тепа, јну_, _במקט
  { {0xcc870010,0x3e7c0046,0xfbc60850,0x6723088a}},	//   абуе_, _míti_, абзо, kunj
  { {0x0b460956,0x66ea002a,0x69c901c2,0x6723088a}},	//   рнен, _ręko, _azee, junj
  { {0x533600b2,0xb4c1005d,0xba170015,0xd336000a}},	//   ינען_, ंतु_, ليما_, ירעה_
  { {0x656f00b8,0x66c500dc,0xd9540015,0xe6da001a}},	//   ächl, tókn, إنتخ, ðsíð
  { {0xfb260086,0x57f30cb9,0x98b70010,0xf7720015}},	//   _پرسپ, општ, аліт_, قاع_
  { {0x61e401d1,0xa7b81292,0x27310092,0x67630015}},	//   _ogil, ылку_, _cơn_, قُول
  { {0x66c5002e,0x2baf000b,0x45440015,0xfaa61b38}},	//   sókn, _जुटा, منعق, _табо
  { {0xd5b00015,0x54b8006b,0xe5c6004a,0x8aab000a}},	//   ثفة_, лгия_, шско, _סֹלֶ
  { {0x14180029,0x6723016f,0x4438001a,0x8433005e}},	//   ديدة_, bunj, ýr_, оньє
  { {0x94730015,0x88bb000a,0xe8d7000a,0x988b000a}},	//   تديا, _יזמי, _כומר_, _בָאֵ
  { {0x9f610003,0x442a002a,0x079b000a,0x48fd0065}},	//   _épée_, żb_, _בסבל, रीको_
  { {0xe298008f,0x32540010,0xe6930087,0x320b1b39}},	//   раў_, цвяр, _بلند, racy_
  { {0x40350054,0x61e41b3a,0xdfa703ae,0x653b05bd}},	//   љевс, _egil, ајбо, _סעוד
  { {0xddc40048,0xcebb0001,0xddc6005c,0x7ed70015}},	//   ndiņ, вља_, _nakł, لزرا
  { {0x33db0008,0x6e64005e,0xdc0f000b,0x6d58003d}},	//   _בחוד, отуж, ाण्ड_, āvan
  { {0x629d1b3b,0x66c50030,0x7e6d019a,0xbbaf0065}},	// [2e10] miso, zóko, rjap, _जुड़क
  { {0xfd4d00a7,0xc1bc0008,0x91bc0008,0xc4f7000a}},	//   _khoả, _במחש, _במחי, יזמי_
  { {0x629d0f21,0xf092004f,0xa4b7004f,0x9b440058}},	//   oiso, _זני_, סלבה_, ينكو
  { {0x6723003f,0x69c000dd,0x6a94005e,0x6d4b001a}},	//   vunj, _byme, оріє, ægas
  { {0x69c00176,0x27310092,0xaa560015,0xe9470674}},	//   _cyme, _sơn_, صلوا_, рхео
  { {0x6c850029,0xd0f8000a,0x00f8000a,0x66c50030}},	//   _السم, סמות_, סמוך_, tóko
  { {0x3e7c0089,0xd7ee0015,0x28120015,0x46150015}},	//   _síti_, ركي_, سويس, موغر
  { {0x9aa50074,0x7ae00007,0x629d003f,0xc6680054}},	//   _امرو, _gimt, jiso, ишње_
  { {0xddc60050,0x69c00176,0xddc40046,0x8e98000a}},	//   _zakł, _gyme, ojiš, ידהו_
  { {0xd874003b,0x61e40026,0x67231b3c,0xe8740015}},	//   _والب, _sgil, punj, _والظ
  { {0xe3b10029,0x58ba004c,0xf1d0000b,0xdb1c1b3d}},	//   ثرة_, _עמעצ, _सृजन, _pyré
  { {0xeb3a004c,0x216a030c,0x0598002b,0x2292006f}},	//   נערש, гими_, امیک_, yšku_
  { {0x68e10293,0xe2970088,0x68e90012,0xe5a50054}},	//   _kild, сая_, _jued, _ћили
  { {0x629d1b3e,0xa4d4005e,0x0379002b,0xd466006b}},	//   aiso, _дочі, _محبت_, _гише_
  { {0xf1bf00dc,0xe3b3002b,0x1168002b,0x1eaa0015}},	//   lgál_, _برش_, _چلبی_, هاري_
  { {0x681b0048,0x673c00f2,0xc8790045,0x3376000a}},	//   lādē, _ärje, _duşi_, _לעצם_
  { {0x7ae00007,0xe1ff002a,0x7afb0045,0x22920046}},	// [2e20] _rimt, ejów_, _ăuta, ušku_
  { {0xcb6a0001,0xad250021,0x31570643,0x22920085}},	//   лазе_, ترفو, _פיין_, ršku_
  { {0x60db0008,0xb5fd00bd,0xfcb5005e,0x69c01b3f}},	//   _תקינ, ljšu, іщую, _syme
  { {0x7f3b0053,0x68e10026,0xddc40046,0xacea0015}},	//   _געטו, _aild, ajiš, _مرسل_
  { {0x39130036,0x1e57000a,0x68e11b40,0xb5fd00bc}},	//   змір, _השכר_, _bild, njšu
  { {0x96f80010,0xbcfb002e,0x69c00264,0x68e90034}},	//   аект_, _bréf, _vyme, _dued
  { {0xd6d0003b,0xbb860029,0xb21b0134,0x68e10064}},	//   وقت_, _الأي, mhæv, _dild
  { {0xdd08002c,0x994c002c,0x567800a4,0x7ae00091}},	//   _môže, môže_, рбия_, _uimt
  { {0xc9aa008f,0xd5ba0afa,0xb9960015,0x09f70015}},	//   _свае_, ыск_, _الذب, _طفلة_
  { {0x68e10084,0x629d0026,0x07a600e2,0x046608ad}},	//   _gild, wiso, _лазн, стим
  { {0x66c500dc,0x8cbb004c,0x629d0d97,0xa5bd0091}},	//   iókj, רציק, tiso, ngųj
  { {0xc8790045,0xe1d9005e,0xa50a008a,0x25a90160}},	//   _ruşi_, идні_, _беда_, _žale_
  { {0x75d60086,0xc50a0015,0xe1ff1b41,0x25ab006f}},	//   _ايشا, _إتصل_, rbó_, čilú_
  { {0xfd4d0092,0xcff4006b,0xc8790045,0x94d30058}},	//   _thoả, зпръ, _puşi_, _فينش
  { {0xe7f0005d,0xe4370008,0x66d50007,0xd437000a}},	//   _चलना_, _הרוח_, _iškr, _הרוק_
  { {0x6e940809,0xc333004c,0x9df91b42,0x82a401ca}},	//   пису, _זוק_, рнат_, _најж
  { {0xcc990124,0xe29f0084,0xa3c2000b,0xa0c50015}},	// [2e30] авац_, mið_, ्धक_, _ويعو
  { {0xe29f0084,0x6bd70015,0x68e90077,0x5c74005e}},	//   lið_, متضر, _rued, плут
  { {0xa0360008,0xe80c005d,0x41b50086,0xda7b042b}},	//   _ואתה_, _सज़ा_, _دمکر, ляд_
  { {0x68e90782,0x66f10048,0xe29f002e,0x02c9005d}},	//   _pued, _nāka, nið_, रतिभ
  { {0x68e11b43,0x8e56000a,0xa925005e,0xa9690848}},	//   _pild, _וירג_, ідкл, рила_
  { {0xaf340074,0xbcfb0152,0xddeb0086,0x0138000f}},	//   _بریت, _préf, _جرگه_, צרות_
  { {0xe29f0084,0x907c0053,0x3ea91b44,0xf7710115}},	//   kið_, רטוי, onat_, ظات_
  { {0x68e90026,0x3ea91b45,0xb4c3000b,0x68e10b9d}},	//   _tued, nnat_, ्ष्_, _wild
  { {0x394d003e,0x30e30053,0x68e10595,0xe29f001a}},	//   _uses_, _שריפֿ, _tild, dið_
  { {0x9f88002e,0xa4d60054,0xe29f001a,0xf494005e}},	//   kóða_, одњу_, eið_, зрюю
  { {0xe29f0084,0x681b0024,0x9f88002e,0xbcfb0003}},	//   fið_, rādē, jóða_, _frég
  { {0xe29f0084,0xcb120008,0x6d4f1b46,0x6d5d1b47}},	//   gið_, ולט_, _osca, _orsa
  { {0xd1760010,0xbbc6000b,0x3ea91b48,0xa50915f7}},	//   цыны, _वर्क, dnat_, _тела_
  { {0xcfaa0029,0x74f60015,0x39400061,0x3e7c001a}},	//   لازم_, _بفوز_, çisi_, _lítt_
  { {0xe4d20015,0x78a40125,0xf6680030,0xc4d2004f}},	//   _تقود, éivi, _áüés_, _חגג_
  { {0xd5f90053,0x3ea90251,0xc332000a,0xd13200c3}},	//   שפּר, gnat_, _חוה_, _قمع_
  { {0x660b0014,0x648d002d,0x3ce30111,0x61f600c0}},	// [2e40] _megk, _cúig, _bijv_, _ifyl
  { {0x8521005d,0xa7fc0064,0x660b00dc,0x6d5d00bc}},	//   _मिनट_, _anın, _legk, _drsa
  { {0x9b460015,0x9b1a002b,0x6d5d07fd,0x6d4f03b8}},	//   تناو, شتاز_, _ersa, _esca
  { {0xfaa3090a,0x0000006a,0x0000006a,0x0000006a}},	//   махо,   ,   ,
  { {0x82d70053,0xda650015,0xbcfb1b49,0x3ea0019a}},	//   קונג_, ثالي, _créd, miit_
  { {0x3ea01b4a,0x66f10024,0x66c50030,0x100a0065}},	//   liit_, _sāka, lókh, वरिश_
  { {0x8cb9000b,0xa3de000b,0x0000006a,0x0000006a}},	//   ्तरो, _दृढ_,   ,
  { {0xbcfb04aa,0xda660021,0x7bce0045,0x9f580077}},	//   _fréd, _باسي, _izbu, laró_
  { {0x94aa000d,0x95d70063,0x95ca01f3,0x66c50030}},	//   итоа_, одът_, шука_, iókh
  { {0x3ea91b4b,0x3ead01a3,0x7a40001a,0x7afe00cb}},	//   znat_, četi_, _fátæ, oppt
  { {0xe29f0084,0xadfc000b,0xa3cf000b,0x5c5b000a}},	//   tið_, ौरान_, _शरण_, בדיק
  { {0x55660058,0x0000006a,0x0000006a,0x0000006a}},	//   _وهاك,   ,   ,
  { {0xe29f09f0,0x3ea910d5,0x7feb005e,0x3ea0007c}},	//   rið_, vnat_, иєва_, diit_
  { {0xe29f002e,0xf8ca005d,0x648d002d,0xc4c60015}},	//   sið_, ितिय, _cúid, _بتصو
  { {0xc0580191,0xa6f80008,0xd6f80008,0x3f850057}},	//   ція_, מִּי, מִּש, álu_
  { {0x82f70086,0x442c0111,0xce680036,0xe29800d7}},	//   _بروز_, lgd_, оруд_, _мај_
  { {0x6fbb005d,0xa1150015,0x98ca000b,0x2d58004a}},	// [2e50] _शुरू, _عودت, िताए, оить_
  { {0xebc70001,0x4d9802bf,0x64481b4c,0x442c1b4d}},	//   ољен, цкую_, nedi, ngd_
  { {0xaa4b005e,0x442c0079,0x64480079,0x3ea90123}},	//   иїде_, igd_, iedi, pnat_
  { {0x2011010b,0xbcfb1b4e,0x64481b4f,0x4fd6004f}},	//   lazi_, _préd, hedi, _מותב_
  { {0x6d5d00b8,0xca740029,0xd5a60015,0x6f15002a}},	//   _ursa, بالغ, _أف_, lszc
  { {0xbcfb038d,0x6448010b,0x4d7a000a,0x4dda000a}},	//   _crée, jedi, _הרשע, _לחרו
  { {0x6d4d0111,0x6f150e8c,0x64481b50,0x6e2d02b9}},	//   lwaa, nszc, dedi, ogab
  { {0x7a16002a,0x442c0079,0x915e0016,0x64481b51}},	//   rętó, egd_, hắc_, eedi
  { {0x6e2d1b52,0x20111b53,0xa5f60054,0x6d4d06a8}},	//   igab, kazi_, чењу_, nwaa
  { {0xa3cf000b,0xe3b10015,0x442c0123,0x660b1b54}},	//   _शरद_, فرج_, ggd_, _wegk
  { {0xe7f0005d,0x9cd8000a,0xe3b90054,0x6f15002a}},	//   _चलता_, חוזה_, сбн_, jszc
  { {0x442c0159,0x6d4d1b55,0x32020046,0x998f0030}},	//   agd_, kwaa, ubky_, legű_
  { {0x6f150050,0x64640011,0x3634002b,0x20d6005e}},	//   eszc, _ştiţ, _آرمس, зівс
  { {0xb4fa0008,0x455a0008,0x64481355,0xd576000a}},	//   _הפסי, _לכנס, cedi, _מתנה_
  { {0x6e2d00b8,0x66c50030,0x43040015,0x5f06106c}},	//   fgab, tókh, _قذيف, язва
  { {0xa7fc0064,0xc332000a,0x531a000a,0xa206004a}},	//   _anıl, _נוח_, _הוקצ, _эпид
  { {0x6d4d0409,0xa0a60004,0xb4f9004c,0xb21b001a}},	// [2e60] gwaa, _наид, מפּי, rhæt
  { {0x3137013a,0xddcb0064,0x66f10024,0xb21b002e}},	//   _צריך_, şişl, _nāko, shæt
  { {0x307b013a,0x807b0008,0x395f0509,0x907b000a}},	//   _האינ, _הניצ, _arus_, _הטיי
  { {0x28c4000b,0xe9da004a,0x31600061,0xce4a0054}},	//   _लीजि, бке_, _kriz_, _узме_
  { {0xb9e30036,0x628600f2,0xda65002b,0x9f580077}},	//   ніши, ikko, ظامي, paró_
  { {0xcee9002b,0x9cb6002b,0x6aab06cd,0x7d161b56}},	//   _درین_, _رمزت, angf, msys
  { {0xa7370029,0x7bce0085,0xe3a70015,0x27171b57}},	//   كثير_, _uzbu, _أر_, găn_
  { {0xd90d0086,0x64480026,0xcb37000a,0x98ac0061}},	//   _چین_, wedi, _מאלי_, ılıp_
  { {0x644801e2,0xe4c604f7,0x7d161b58,0x34941886}},	//   tedi, зённ, nsys, дапр
  { {0x7ce90007,0x6f15005c,0xc917000a,0x0d97000a}},	//   _užre, yszc, _מחמת_, פכים_
  { {0x442c0079,0x6d4d0079,0x57fb000a,0x64481b59}},	//   rgd_, zwaa, _הלבו, redi
  { {0x64481b5a,0xa25b0152,0x20110297,0x75d60015}},	//   sedi, plôm, wazi_, _فيضا
  { {0xd6270036,0x644805fe,0x6f15002a,0xecbe000b}},	//   _хоче_, pedi, wszc, ्ताफ
  { {0xf993000a,0x44f20034,0xe3af002b,0xe4d7002b}},	//   גרש_, _iâ_, ئری_, _فونت_
  { {0x543b00b2,0x643b0008,0x2fc50134,0x201102c6}},	//   _לעגא, _העונ, ælg_, razi_
  { {0x6d4d0079,0x6f15002a,0x998f0030,0xef540033}},	//   twaa, rszc, zegű_, эксь
  { {0x50670033,0xa7fc0061,0x2005001a,0x6e2d1b5b}},	// [2e70] _етна, _anım, ðlis_, rgab
  { {0x6e2d00b8,0x6d4d09f2,0x787d0152,0x44f20034}},	//   sgab, rwaa, _lèvr, _mâ_
  { {0x29000011,0x1a65002b,0x3e7c0046,0x6e2d003d}},	//   ţial_, ویسی_, _vítr_, pgab
  { {0xfbd0003b,0x6723018c,0x66f10048,0x7aee0251}},	//   اتك_, vrnj, _sāko, _dubt
  { {0x9e5a000a,0x5c070033,0x224b02f7,0x6d4d01c2}},	//   _וכרט, _нява, ieck_, qwaa
  { {0xccf20008,0xba770086,0xe73100c3,0xbcfb0a8b}},	//   _בכך_, _کاست, نصب_, _tréb
  { {0xe7391028,0xe7fe000b,0x0000006a,0x0000006a}},	//   цей_, _उभरा_,   ,
  { {0x05650080,0x61e90263,0xbcfb1b5c,0x3694004a}},	//   двин, želj, _gréc, ешьс
  { {0xb345001c,0x06960029,0x648d002d,0x395f0213}},	//   _opçã, بنية_, _núic, _urus_
  { {0x628d01be,0x1827002b,0x99d40015,0x44310061}},	//   _alao, _رقصی_, _ستقا, üz_
  { {0xdc380053,0x8c1a000a,0x620a0015,0x96070015}},	//   לאזט_, חותי, يْدِ_, _فبإم
  { {0xd29a0036,0x78a300f2,0x11d60036,0xa6c90015}},	//   ітні_, linv, дігр, _بوصل_
  { {0x6286022d,0x7529047e,0x22150033,0x5a16004f}},	//   rkko, quez, эфэр, וקרן_
  { {0x62860005,0xc0e3005e,0xc4db0054,0xa988000a}},	//   skko, кояк, _уђе_, פָרִ
  { {0x93fa000a,0x33920015,0xf486002b,0xae7a004a}},	//   _ולצי, _للوز, _زاوی, осах_
  { {0xee3a008f,0x92b6003b,0x628d002d,0xdd920086}},	//   ўна_, _تحتا, _glao, نوز_
  { {0xc237000a,0x7aee0d67,0x6da30b27,0xec7a01e1}},	// [2e80] _חאפז_, _subt, вита, опа_
  { {0x7982003f,0x70770015,0xe588000a,0x02f9000a}},	//   vyow, _يميز_, הָעָ, ַלְמ
  { {0xbcfb038d,0xbb4a0067,0x9f1a0015,0x5ed60015}},	//   _préc, تلان_, _بآخر_, _يتجز
  { {0x8b65003b,0x49ca0579,0x1e831b5d,0x1e260058}},	//   عالم, олен_, _алюм, _تفحّ
  { {0xd9100086,0x7d03006b,0x28ca0065,0x7bc70052}},	//   ایط_, _изяж, ितलि, _eyju
  { {0xa967004a,0x787d1b5e,0x91bb004f,0xd197004f}},	//   ьича_, _sèvr, חמני, וכני_
  { {0x93bc0045,0x212b002a,0x0000006a,0x0000006a}},	//   ngăt, zuch_,   ,
  { {0xdb0e005c,0x8f1b000a,0x8b9b000a,0x96341b5f}},	//   _wybó, קופת, _ובלת, хниц
  { {0xfaa30001,0x61e91b60,0xd44a00ce,0x08c60138}},	//   _рато, želk, оянд_, _жбан
  { {0x54540010,0xe97b000a,0x27f70015,0x224b0012}},	//   хвот, _ונמש, _يفقد_, weck_
  { {0xd2510031,0x7d0b0030,0x224b0012,0x0000006a}},	//   هند_, ágsz, teck_,
  { {0x6d460134,0x68e81b61,0x45460015,0x212b0012}},	//   _opka, _hidd, _يناق, tuch_
  { {0x656f00b8,0x93bc0011,0x224b1b62,0xddc60046}},	//   ächt, egăt, reck_, _takř
  { {0x557700b2,0x212b020d,0x68e81b63,0x0000006a}},	//   _קעגן_, ruch_, _jidd,
  { {0x212b00b8,0x23730087,0x6d460cd4,0x889b000a}},	//   such_, _لايح, _apka, קבלי
  { {0x68e81b64,0x64581b65,0x443e1b66,0x65621b67}},	//   _lidd, _havi, lft_, _kroh
  { {0x61ed0020,0x7bca00b8,0xb11900c3,0x64581b68}},	// [2e90] _igal, üfun, _عقدا_, _kavi
  { {0xbcfb038d,0x443e00b8,0x61fa0089,0xe1d80010}},	//   _créa, nft_, ětle, _ідэі_
  { {0x661d00df,0xbcfb002f,0x9be40010,0x443e1b69}},	//   ųski, _dréa, віцк, ift_
  { {0x80ad000b,0xc212000a,0x69dd01c0,0x64581b6a}},	//   ँचवे, ָ֔א_, _úsek, _lavi
  { {0x1e960008,0xbcfb002d,0xdb1c0107,0x68e81b6b}},	//   _נכשל_, _fréa, _vyrá, _bidd
  { {0xbcfb002f,0x443e0111,0x68e80064,0xa75501b7}},	//   _gréa, jft_, _cidd, етищ
  { {0x68e80176,0xf094011f,0x69c600cb,0x78a31b6c}},	//   _didd, כנס_, _øken, rinv
  { {0x68e80026,0x443e1b6d,0xca24004a,0x8cb9000b}},	//   _eidd, eft_, _аффи, ्तको
  { {0x443e1b6e,0x68e81b6f,0xb95b0015,0x64581b70}},	//   fft_, _fidd, _بجزء_, _bavi
  { {0xe1fa014e,0x656200b8,0x64581b71,0x61ed1b72}},	//   ूर्ण_, _droh, _cavi, _agal
  { {0x53c90036,0x7ae90007,0xf1a9000a,0xe3b10015}},	//   ягом_, _kiet, _פס_, طرد_
  { {0xb6070010,0x7e7d0024,0x656f00b8,0x7afa0030}},	//   _цяжк, _nosp, ächs, _étte
  { {0x1a9a004c,0xdce70046,0xe569006b,0x7ae91b73}},	//   פישע, áměs, _хилд_, _miet
  { {0x7ae91b74,0x64581137,0x61ed1b75,0x66060061}},	//   _liet, _gavi, _egal, ıkke
  { {0xb4cb005d,0xf8b20008,0xa3bb0015,0x3ff30058}},	//   लती_, אשם_, _باشر_, اكفر
  { {0x139a0008,0x733a0053,0xf7720135,0x539a000a}},	//   _מבצע, _זעקס, נקן_, _מיצו
  { {0xbcfb1b76,0x6439000a,0x753b1b77,0x7e7d1b78}},	// [2ea0] _préa, ּעֲנ, ntuz, _dosp
  { {0xe0d204c9,0x6ab8005d,0x765900ea,0x8f76005e}},	//   _حزب_, इक्र, _lawy, _зумі
  { {0xa09b0053,0xcb090036,0x7ae90303,0x1037000a}},	//   _זייט, дхід_, _biet, _אטים_
  { {0xc3320008,0x7ae9003d,0x7e7d1b79,0x2282001a}},	//   רוא_, _ciet, _gosp, _tóku_
  { {0x6443005c,0x9e630010,0xaa570029,0x443e002e}},	//   _obni, _свяд, علها_, yft_
  { {0x7d041b7a,0x0000006a,0x0000006a,0x0000006a}},	//   mpis,   ,   ,
  { {0x7ce90007,0x64581b7b,0x5694006b,0x8c43006b}},	//   _užra, _ravi, какт, _щере
  { {0xddcd016f,0x95080029,0xd6d70802,0xbb3b0008}},	//   ljaš, وقعك_, нты_, _מעלי
  { {0x7ae30161,0x1fdd000b,0xb4cb000b,0xddcd07c4}},	//   ïnte, _मण्ड, लतू_, ojaš
  { {0xd91b013a,0x64a30001,0x443e00b8,0xb7960001}},	//   _מומל, лања, uft_, _прећ
  { {0xa2950036,0x443e1b7c,0x229509ef,0xf5ea006b}},	//   вані, rft_, виня, _емел_
  { {0xda10014e,0x645806e8,0xcb8b000a,0x65621b7d}},	//   ारित_, _wavi, לְכֹ, _troh
  { {0xd2510074,0x5187008f,0x1a9b0053,0xba9b0008}},	//   هنگ_, хуна, ליטע, לסטי
  { {0xb4fb000a,0xc0e40033,0x7e7d1b7e,0x7659002a}},	//   _צפוי, лоўк, _sosp, _zawy
  { {0x6e6702b6,0xf487002b,0x9e96002b,0xd904002b}},	//   нтаж, _ثانی, چاقچ, _گی_
  { {0x66c50030,0xc7d7000a,0x61ed1b7f,0xddcf0535}},	//   lókr, תולי_, _ugal, _racł
  { {0xd9040086,0xac271b80,0xdd94054f,0x7ae91b81}},	// [2eb0] _دی_, ефек, гаты, _riet
  { {0xd140005c,0x22b60024,0x7ae91b82,0xda67002b}},	//   żący_, māka_, _siet, کائي
  { {0x22b60024,0x7ae91b83,0xf413004c,0x7d041b84}},	//   lāka_, _piet, רפע_, apis
  { {0xe9f8005e,0xc333004f,0x0000006a,0x0000006a}},	//   енці_, טוע_,   ,
  { {0x273a0111,0xe8f80484,0x7ae91b85,0xddcf002a}},	//   eën_, елі_, _viet, _wacł
  { {0x5c14002b,0x7ae9002a,0x49b80067,0x2ca5001a}},	//   _مظفر, _wiet, راند_, _öld_
  { {0x648d002e,0x6b8300c0,0x98140087,0x7ae91b86}},	//   _búin, ängd, ابها, _tiet
  { {0xdddd0048,0x0f580008,0x22b60024,0xb9250015}},	//   _nosū, תיהם_, kāka_, _لفري
  { {0x648d002f,0x765b0d40,0xf505009b,0x0000006a}},	//   _dúin, rduy, ъзпо,
  { {0xb4cb005d,0x23750015,0x99d40015,0xa5440015}},	//   लते_, ناجح, _إتفا, اضيو
  { {0xdc88000a,0xb767005e,0x648d0125,0x6c56000a}},	//   גְרָ, _ятай, _fúin, דיתא_
  { {0x3dc6002a,0xddcd06f2,0x7d041b87,0x0000006a}},	//   żowi_, zjaš, ypis,
  { {0xe2971b88,0x66090801,0x22b6003d,0x5bbe0065}},	//   тая_, mbek, gāka_, _ऍड्व
  { {0xbcfb0003,0xdb080030,0xd00f0015,0x93bc0045}},	//   _prén, őlép, يلُ_, rgăr
  { {0xc0590010,0x12aa0029,0x3f8c0107,0xd7f100a1}},	//   хіў_, _يدعى_, ádu_, _lão_
  { {0xe3e80053,0x7d04016f,0x601f0061,0xbcfb1b89}},	//   _אַפֿ, tpis, _açmı, _créo
  { {0x1ea90029,0x7bd504ed,0xf1de000b,0xee37006b}},	// [2ec0] رافي_, _azzu, नेशन, ънт_
  { {0x0cbe014e,0x7d040049,0x9cb30015,0x2a6d0247}},	//   ्तेम, rpis, لمقت, _aneb_
  { {0x91f6000b,0x26df0091,0x20181b8a,0x64410012}},	//   _इलाज_, kmuo_, mari_, ifli
  { {0xca750010,0xba290029,0xfa890127,0x8b23004a}},	//   лучы, فسهم_, нсій_, рдце
  { {0xdb0e00c0,0xf1bf0030,0x26df0091,0x5c34002b}},	//   _nybö, lgár_, dmuo_, _مکاز
  { {0x66d50007,0xd90d0086,0xfc030fe4,0xc19b000a}},	//   _išky, سیم_, _впро, ושני
  { {0xf0930008,0x22b60024,0x20180251,0xe757005e}},	//   שנו_, zāka_, iari_, вищі_
  { {0x3eb21b8b,0x6b8307fd,0x20181b8c,0xdb1c002a}},	//   nnyt_, änge, hari_, _wzró
  { {0xd9460124,0xa3e4005d,0x20181b8d,0x15130033}},	//   _јези, पेन_, kari_, адыя
  { {0x3eb200f2,0xb8f6021e,0x98e60015,0x93780004}},	//   hnyt_, सत_, _شكاو, ебот_
  { {0x53340010,0x66091b8e,0x20181b8f,0xdddd0091}},	//   ыент, bbek, dari_, _posū
  { {0x22b60024,0x558a0661,0x268a0015,0x20131b90}},	//   tāka_, _обем_, _تخطي_, _sexi_
  { {0x20180705,0x2499003d,0x75291b91,0x1677004f}},	//   fari_, ūsma_, crez, _שגדל_
  { {0x9f35042b,0x22b6003d,0x3d16000b,0xf3661797}},	//   легі, rāka_, _पौधे_, _атин
  { {0x22b60024,0xbcfb0003,0x6437004c,0x645d003d}},	//   sāka_, _préo, _סאהא_, ēsit
  { {0x2018166f,0xceb80054,0x5eb40ef5,0x26c41b92}},	//   aari_, вљу_, айст, nomo_
  { {0x2018000c,0x3f9e001a,0xd2b8000a,0xd578000a}},	// [2ed0] bari_, útur_, _שלחת_, עָֽר
  { {0x6609003f,0x653b0008,0x8c590015,0x20181b93}},	//   zbek, ועמד, علاء_, cari_
  { {0x6ce4005e,0x26c41b94,0x7529036d,0x0000006a}},	//   ріте, komo_, zrez,
  { {0x3e040063,0xddcd0089,0xc3330008,0x6e950015}},	//   _вярв, zdař, שוף_, _إلحا
  { {0xe29c000a,0x26c41b95,0xf9900040,0x6b830123}},	//   ושאר, domo_, يبه_, ängb
  { {0x08c4017f,0x7c870785,0x99d400e5,0x475903fc}},	//   абін, _руме, جتما, ерия_
  { {0xf6510029,0x46a50063,0x648d002d,0x2bc80912}},	//   مئة_, лакв, _dúil, _ауто_
  { {0x75291b96,0x8579000d,0xc6190002,0x3ea9127a}},	//   trez, есот_, رتبط_, niat_
  { {0xd4151561,0x20180508,0x59b7005d,0x66091b97}},	//   льны, yari_, _आखिर, rbek
  { {0x1309005f,0x478b0063,0x75291b98,0xf992000a}},	//   нной_, _осем_, rrez, _הרמ_
  { {0x3eb2022d,0xe4c80029,0xb6350015,0x26cd0077}},	//   ynyt_, خبين_, _مفاع, pleo_
  { {0xbcfb0152,0xfbd20008,0x26c41b99,0x75291b9a}},	//   _prél, מתי_, como_, prez
  { {0xe56e0124,0x04450b75,0x3ea91b9b,0x361a000a}},	//   _уз_, _белн, diat_, _נוסד
  { {0x03190015,0x291f0573,0x291d01d7,0xbcfb0003}},	//   _كتبت_, _mvua_, iswa_, _crém
  { {0xb4c1000b,0x73c50015,0xc4d2000a,0x20181b9c}},	//   ूती_, _حيثم, _הגג_, rari_
  { {0x20181b9d,0xc332000a,0xe3b00067,0x22b6003d}},	//   sari_, _הוה_, _بره_, māko_
  { {0x8d661292,0x22b60024,0xc5f2000a,0xa3e7000b}},	// [2ee0] ывае, lāko_, מדן_, _मृत_
  { {0x26c4003f,0x219b00a3,0xc19b000a,0xbcfb0247}},	//   zomo_, _נביא, _נשיי, _grém
  { {0x26c4000c,0x0c370029,0x22b60024,0x4b261179}},	//   yomo_, اكمة_, nāko_, умев
  { {0x3ea91b9e,0x648d0125,0x7e5600af,0x0000006a}},	//   ciat_, _súil, _стоц,
  { {0x22920046,0x38140033,0xc237000a,0x38c8002b}},	//   ušky_, амлё, ראנז_, پاشی_
  { {0x61d70008,0x7bf8000a,0x6e360091,0xdca600af}},	//   נוסף_, _יִֽה, lgyb, _саги
  { {0x38cb0086,0x37a7006b,0x26c41b9f,0x57460058}},	//   راهی_, лтън_, tomo_, اختف
  { {0x7f3b0053,0x212b0026,0x21200263,0xa7fc0061}},	//   געקו, yrch_, _ovih_, _anıt
  { {0x18360002,0x3f8a01b2,0x7afb00bc,0x7826006e}},	//   _مراح, hybu_, _čuti, _معضل
  { {0x4438018b,0xb9930029,0xb80a0029,0x26c4003f}},	//   ür_, _الكب, _أيام_, somo_
  { {0xf8b3000a,0xa3d40033,0x22b6003d,0x212b0034}},	//   _פשע_, ронч, gāko_, wrch_
  { {0x92580080,0x7ae211b6,0xc7d7004f,0x623502ed}},	//   гают_, nmot, _גובי_, шему
  { {0x3ea908e0,0x212b00b8,0xd6df002a,0xa5070054}},	//   viat_, urch_, ółem_, _беча_
  { {0xe3a40086,0x3ea9005c,0x22b60024,0x6d560026}},	//   _پشتی, wiat_, bāko_, dwya
  { {0x92950010,0x7ae200c0,0xd7b8000a,0x22b6003d}},	//   _вайц, kmot, דֶּך, cāko_
  { {0x5e580191,0x6db5027a,0x201e001a,0x25a90085}},	//   лися_, айбу, ótir_, _žali_
  { {0xfc67006b,0x3ea91ba0,0x7c15005e,0x7ae21ba1}},	// [2ef0] лъжн, riat_, идає, dmot
  { {0xb8820046,0x25d7000a,0x3ea91ba2,0x6e360030}},	//   říjm, רומן_, siat_, agyb
  { {0x75eb0014,0x6ffa000a,0x50b80015,0xef67006b}},	//   _közü, _בהתפ, _حديد_, _съпо
  { {0xeaae0036,0x4e79004c,0x3f7a004c,0x628f0079}},	//   ій_, _סאָצ, _סארס, nkco
  { {0xfe360053,0xd9440029,0x224900e8,0x89370015}},	//   _דארך_, مئوي, _mbak_, اعصا
  { {0xf77100e6,0x98e40015,0xd705006b,0xe0fc000a}},	//   قاب_, مكنو, азки, עלול
  { {0x1038004c,0xdd0e0061,0x66f1003d,0xa7fc0061}},	//   אטום_, _kışl, _nākt, _anıs
  { {0x31690050,0xa3de0089,0x22b60024,0xada6006f}},	//   _oraz_, _běží_, vāko_, slúž
  { {0x98750036,0xef19002a,0x60c70dd2,0x3a7404bb}},	//   _клац, ąży_, kojm, _ултр
  { {0x66f10048,0x26130092,0x22b60024,0x25db000b}},	//   _sāku, ảo_, tāko_, खेगी_
  { {0x2120010b,0xe3b10029,0x798b0026,0x29000045}},	//   _svih_, ترة_, lygw, ţiat_
  { {0x91e618dc,0x61fa0046,0x22b6003d,0x95550015}},	//   ионе, ětlo, rāko_, _نختا
  { {0x6f05002d,0x661b00f2,0x51ba01b0,0x15f40058}},	//   _athc, mauk, тыня_, _اسمح
  { {0x859a0008,0x7ae212b8,0x661b1ba3,0xf8a70015}},	//   _בשנו, zmot, lauk, زة_
  { {0x44fb020a,0x23760086,0xafe60248,0xa0670054}},	//   _hê_, _نمود_, ровл, јаса_
  { {0x44fb0023,0x75eb0064,0xddd60033,0xeef50033}},	//   _kê_, _gözü, аўзэ, сярэ
  { {0xdd0e0064,0x6e361ba4,0x20d6008b,0x8d63005e}},	// [2f00] _dışl, rgyb, _вінс, овте
  { {0x6e360026,0x44fb1ba5,0x61db000a,0x6d560034}},	//   sgyb, _mê_, _בקפד, rwya
  { {0x907b0008,0x66f10024,0x394d00da,0x44fb1ba6}},	//   _סטטי, _māks, _apes_, _lê_
  { {0x6b8300c0,0x4fbb00f3,0x7bce0227,0x661b1ba7}},	//   änga, _יציא, _vybu, jauk
  { {0x09b0005d,0x7bce005c,0x88e60457,0xb9570015}},	//   जपेय, _wybu, ажде, لجوء_
  { {0x9915008f,0x66f1003d,0xe8380033,0x7ae21ba8}},	//   сьці, _nāks, упкі_, smot
  { {0x7c470030,0xa09b000a,0x7ae2055e,0x78aa1ba9}},	//   ésrő, כיסט, pmot, rifv
  { {0x44fb1baa,0x3546170d,0x661b1bab,0x628402b9}},	//   _bê_, ахов, gauk, _noio
  { {0x66f10024,0x245b0007,0xa5070004,0x0000006a}},	//   _sākt, kšmė_, аења_,
  { {0x44fb1bac,0x75eb0061,0x07a607c3,0xa818000a}},	//   _dê_, _sözü, _казн, _תֵּי
  { {0x2bf70008,0x8c1b0008,0x57fb0135,0x9cd7000a}},	//   ימין_, כויי, _סלאו, שויה_
  { {0x1546005e,0x7a410030,0x661b01d7,0x5b7b000a}},	//   _ведм, mátó, cauk, דרטא
  { {0x628f0079,0xddd6002a,0xe1ff010d,0x7a410030}},	//   rkco, ndyń, rcó_, látó
  { {0xd59b000a,0x160e000b,0xe1ff1bad,0x351b004f}},	//   _שֹׁכ, सरकर_, scó_, _יודנ
  { {0x3169005c,0xe3af0029,0x60c7002c,0x4ea719bf}},	//   _wraz_, _يرى_, rojm, араа
  { {0x3169016e,0xf1a70e3f,0xf239009b,0x0000006a}},	//   _traz_, _врон, _спиш_,
  { {0x7c070015,0xd657000a,0x44fb0016,0x0000006a}},	// [2f10] لباك, סימת_, _xê_,
  { {0x70550074,0xcc740124,0xb0350054,0xfc330015}},	//   _اندا, огућ, _унош, تحر_
  { {0x07f20053,0x6a170015,0x6ec70015,0x9f580046}},	//   _װאָס_, لبشر, _نتحق, obrý_
  { {0x99d90029,0x539b000a,0xdfd1009a,0x660201ec}},	//   هواء_, כיבו, _ويک_, _nfok
  { {0x661b09e2,0x644a002a,0xc238004f,0xfaa80058}},	//   vauk, _obfi, שרדו_, جهني_
  { {0x88c80191,0x31580053,0xfc670063,0x78470010}},	//   алів_, יידן_, _тъмн, рэдж
  { {0xbb850029,0xab950029,0x44fb00dd,0x661b00f2}},	//   _الزي, _الأغ, _sê_, tauk
  { {0x66f10024,0xcfb80008,0xe7080015,0xbcfb0003}},	//   _sāks, ילוי_, جتون_, _préh
  { {0x05680083,0x6aa9003f,0x661b1bae,0xa3e40231}},	//   ајќи_, _imef, rauk, पेस_
  { {0x661b0048,0x88550008,0x44fb1baf,0xc8240015}},	//   sauk, _לֹ֣א_, _vê_, _وفقً
  { {0x97a70010,0x661b00f2,0x44fb0026,0xe6430061}},	//   _трал, pauk, _wê_, şmış
  { {0xc7b20008,0xf0890643,0x92b60015,0x44fb1bb0}},	//   _צבא_, _אנ_, إحدا, _tê_
  { {0xd6c60074,0xe3b10086,0x3076005e,0xf505004a}},	//   _امنی, ترک_, бувс, _узло
  { {0xbcfb002d,0xb97a0008,0xa06a0001,0x03a8002b}},	//   _gréi, אנשי, ћава_, ادیو_
  { {0x141a0008,0xdfd200e5,0xf852006f,0x8416000a}},	//   _עוקב, سير_, ážiť_, _הקצב_
  { {0xb21b0134,0xed5a1bb1,0xee37070c,0xbea30b27}},	//   skær, лоб_, йнс_, паск
  { {0x6cd60029,0xf1a90086,0xa2c5000b,0x6b831bb2}},	// [2f20] مقرا, _پايه_, रवर्, ängn
  { {0x8db50036,0xcc290029,0x317b000a,0x4c830190}},	//   істі, لأمم_, _ערימ, плув
  { {0x6d5d1bb3,0x0b461310,0xeb2a011e,0x0000006a}},	//   _essa, снен, ужел_,
  { {0x2f5b0008,0xc332000f,0x8aa5005e,0x0136000a}},	//   _עדכנ, לוב_, орід, ֶרֶת_
  { {0x823b0053,0xda650070,0x44270160,0x0000006a}},	//   רענצ, تالي, _odn_,
  { {0x3cf1002c,0x6c860029,0x515b000a,0x7189000a}},	//   ľovú_, _الآم, טכנו, יְצַ
  { {0x6d441bb4,0xb8ff000b,0x9f580077,0xeb9a07be}},	//   ltia, _धी_, mbró_, _сив_
  { {0xddcd0064,0x7e641bb5,0x22af0046,0xfbb7000a}},	//   ndaş, ndip, křka_, _הפלת_
  { {0x7a4100dc,0x6d441a0e,0x661d001a,0x8aab004f}},	//   sátó, ntia, ðska, _עֹלֶ
  { {0x6d44002d,0x0000006a,0x0000006a,0x0000006a}},	//   itia,   ,   ,
  { {0x6c7b004c,0x6d440fec,0x0ec8000b,0x0000006a}},	//   אריד, htia, लवाड,
  { {0x51870004,0x6d441bb6,0x8bd7004f,0xc56a0058}},	//   буга, ktia, מויו_, _محتل_
  { {0xe298008f,0xbcfb002d,0xd7f10016,0x75221bb7}},	//   саў_, _tréi, _rãi_, _uvoz
  { {0x7ff40015,0x201a01d7,0x139402ed,0x0000006a}},	//   كسفا, _cepi_, _милю,
  { {0x6d440375,0xfebb0040,0x5f9400c2,0x7ce90073}},	//   etia, هارت_, пирт, _užri
  { {0xb3b7000a,0xbd450015,0xda0a0065,0x0000006a}},	//   _לפוג_, ينزي, हुमत_,
  { {0x98ba000b,0x5ed40058,0x0000006a,0x0000006a}},	// [2f30] ेवाए, ستفز,   ,
  { {0xd0110015,0x9f550b1e,0x5478004f,0x0000006a}},	//   _تلد_, _двоч, סְּנ,
  { {0x6d441bb8,0xd9f90e91,0x9b5907be,0xf3f1004f}},	//   atia, анец_, риет_, ֵ֣ב_
  { {0x4ee40010,0x70550086,0x6d4402f2,0x0000006a}},	//   _ніяз, _انگا, btia,
  { {0xa9240036,0x2004002a,0xec150015,0x27330016}},	//   зділ, śmie_, _ووحد, ọng_
  { {0x20030050,0x1869000d,0xd70909b5,0x2bd9002b}},	//   ncji_, раки_, анке_, _نازک_
  { {0x9b090008,0x7d0d0cbb,0xcb34006b,0x32020046}},	//   _כִּ֥, lpas, _неръ, ycky_
  { {0x6aa9003f,0x44271bb9,0xdd09006f,0x7d0d1bba}},	//   _umef, _sdn_, _môžt, opas
  { {0x20030050,0x9479059c,0x7d0d1bbb,0x64480012}},	//   kcji_, асну_, npas, ffdi
  { {0x8d5c0008,0x22b6003d,0x395f1bbc,0xf349029f}},	//   רכזי, māki_, _isus_, апол_
  { {0xc169000a,0x22b6003d,0xf8b2000a,0x68fb008c}},	//   _שח_, lāki_, _קשב_, _huud
  { {0x68fb0201,0xaac9000b,0x7d0d01d7,0x28ca000b}},	//   _kuud, िकिक, kpas, ाकथि
  { {0xa1930010,0x28a6000b,0x68fb05ff,0x76490034}},	//   даўч, कोवि, _juud, mfey
  { {0x68fb0005,0xa06a008f,0xc5f2000a,0x60260033}},	//   _muud, шага_, _חדד_, ўдва
  { {0x6b8304d4,0x63050015,0x7d0d1bbd,0x65691bbe}},	//   ängl, _بوبل, epas, lveh
  { {0x61f602e9,0x27330092,0x6d441bbf,0x2003002a}},	//   _ugyl, ạng_, ttia, acji_
  { {0x7d0d00b6,0x64960011,0xf6520053,0x201a0375}},	// [2f40] gpas, _mâin, וצן_, _tepi_
  { {0xd00a0001,0x6d441bc0,0x76490034,0x0c2601c6}},	//   _њене_, rtia, hfey, імен
  { {0x5f460015,0x395f007c,0x09fa0015,0x7d0d1bc1}},	//   _بنجل, _asus_, لفضة_, apas
  { {0x298a058f,0x5aca056d,0x6fdb000a,0xd910002b}},	//   исло_, шлем_, _כקיס, فیر_
  { {0xc9830080,0x187406b4,0x76490026,0xacea0015}},	//   дущи, згля, dfey, _نرسل_
  { {0xf72a0080,0xbcfb1a87,0x96f8006b,0x7bca0061}},	//   аций_, _prév, бект_, üfus
  { {0x7bdc0024,0xab271bc2,0x907b000a,0xdce40091}},	//   _uzru, _мора_, יטסי, nvič
  { {0x76490026,0x64960045,0x22b6003d,0xc66a098b}},	//   gfey, _câin, bāki_, ршке_
  { {0x2003005c,0x7e9b0135,0xc9aa0033,0x26d8003d}},	//   ycji_, יסקו, _твае_, ēro_
  { {0x60c2002f,0x39460095,0x7afc1bc3,0xbcfb1bc4}},	//   _íomh, mtos_, _kurt, _trév
  { {0xa3e4014e,0xc606008f,0x4bfb000a,0x7bfb004c}},	//   पें_, _дзей, יליס, יפיצ
  { {0x9294008f,0xa75b000a,0x39461bc5,0x69c600cb}},	//   даюц, _כדבר, otos_, _økes
  { {0x50670661,0x7d02002d,0x39461bc6,0xdb07001a}},	//   отва, íosl, ntos_, _ólög
  { {0x27330092,0x39461bc7,0xf8ca000b,0xc0cb1bc8}},	//   ụng_, itos_, ाकिय, руме_
  { {0xa2950010,0xeeab0c53,0xe437000a,0x2003002a}},	//   _накі, атак_, _ורוח_, rcji_
  { {0xc3330008,0x539b0008,0x7d0d1bc9,0x9df90608}},	//   _חוק_, _כיוו, tpas, снат_
  { {0x3ebe002e,0x2003005c,0x80e70015,0x39461756}},	// [2f50] étta_, pcji_, _وأخل, jtos_
  { {0xc0580036,0x68fb0604,0x7afc1bca,0x5c070033}},	//   _дію_, _ruud, _burt, іяза
  { {0x68fb1bcb,0x7afc02d0,0x7d0d1bcc,0xdce4013f}},	//   _suud, _curt, spas, cvič
  { {0x68fb0005,0xaa490033,0x67380085,0x7d0d1bcd}},	//   _puud, ёпла_, duvj, ppas
  { {0xa9691bce,0x4e7a000f,0xbcfb0140,0xd9980015}},	//   сила_, _הארצ, _crét, يخها_
  { {0xe9d8008f,0x22b60024,0x7afc14e6,0x61fa0089}},	//   цкі_, rāki_, _furt, ětli
  { {0x661d002e,0x28ca000b,0x8cba000b,0x9b24005e}},	//   ðsko, ाक़ि, ्वरो, _офтл
  { {0xbcfb0084,0xba770070,0x5fbc039e,0xf5590015}},	//   _frét, _باست, יצונ, ملعب_
  { {0x39461bcf,0xe611002b,0x76490034,0xd789002b}},	//   ctos_, وشک_, rfey, شنکو_
  { {0x7afc0061,0x76490034,0x65691985,0x23c60065}},	//   _yurt, sfey, rveh, रअंद
  { {0x69c600cb,0x69b10065,0x35f500af,0x0000006a}},	//   _øker, _आइडी, _епер,
  { {0x0000006a,0x0000006a,0x0000006a,0x0000006a}},	//     ,   ,   ,
  { {0xc5fa000a,0x101601f3,0xe5090015,0x15fa000a}},	//   _הפנט, зьбя, _ايتو_, _ההנע
  { {0xd0070080,0x2ec4000b,0x648d0125,0x53a50891}},	//   зере_, वक्त, _cúit, _налб
  { {0xc0590010,0x394600dc,0xd496000a,0x141a000a}},	//   ціў_, ztos_, _מכסת_, _הוצב
  { {0x39460007,0x531a004c,0x21391bd0,0xe2a90040}},	//   ytos_, _פופצ, bush_, _واين_
  { {0xa2b70008,0xf539002c,0x39461243,0x7afc00de}},	// [2f60] _מפקד_, nuť_, xtos_, _surt
  { {0x7afc1bd1,0x6cd60015,0xe1ff0077,0xc1730643}},	//   _purt, أقطا, ndón_, _נחת_
  { {0xbcfb0152,0x6ffb000a,0xef94002b,0xd55300e2}},	//   _brés, _להיפ, _غیرد, _хvіі
  { {0xbcfb0152,0xdb230046,0xd196000a,0x8b650015}},	//   _prét, írán, ּכַי_, ظالم
  { {0x2bac000b,0x90a5002b,0x38c8002b,0x64960003}},	//   _टेरा, _رحیم, ياتی_, _bâil
  { {0x7afc0472,0xcfb6000a,0x4ddb000a,0x22b6003d}},	//   _turt, ּלֵי_, _לחכו, māku_
  { {0x22b60024,0xfbc3042b,0x58030015,0x76aa006b}},	//   lāku_, _збро, رويك, йтив_
  { {0xdb1c005c,0x8bd70135,0x3bbb000a,0xbddb0781}},	//   _wyró, _זולו_, _המלד, _ibèr
  { {0xc9860029,0x22b6003d,0xf7f600c3,0x0000006a}},	//   _عشري, nāku_, _فساد,
  { {0x7c3e1bd2,0x0000006a,0x0000006a,0x0000006a}},	//   ngpr,   ,   ,
  { {0x2ee90034,0x62351797,0x0000006a,0x0000006a}},	//   ymaf_, мену,   ,
  { {0x22b60024,0x0bb7000f,0x648d001a,0x46a301f3}},	//   kāku_, ללים_, _búis, _пахв
  { {0x5bb9005d,0x648d002d,0xa6e20052,0x0000006a}},	//   _आश्व, _cúis, æðuh,
  { {0x212d02d5,0xa3b40036,0x22b6003d,0x21391bd3}},	//   šeho_, _облі, dāku_, rush_
  { {0x645a1bd4,0xa9230091,0x4fc4027c,0xc05800ce}},	//   meti, ėžia, еста, чія_
  { {0x7c3e00dc,0x645a1bd5,0x443e1bd6,0x9ed901c6}},	//   egpr, leti, lgt_, імат_
  { {0x648d002d,0x98dc000b,0x4dd70067,0x443e0079}},	// [2f70] _gúis, यताए, سترس, ogt_
  { {0x6728010b,0xa2c5005d,0x3ea00035,0x645a1bd7}},	//   _ovdj, रवक्, ahit_, neti
  { {0xbcfb038d,0x9e150036,0xdc1d005d,0x6008000a}},	//   _prés, _одні, _फ़ीड_, _מִרְ
  { {0xd9990029,0xd3660086,0x22b60024,0x9b180067}},	//   ينات_, _یه_, bāku_, ستمز_
  { {0xd9140010,0x645a1bd8,0xbd6b0004,0xbcfb0030}},	//   едчы, keti, _урне_, _erér
  { {0x443e0111,0xddcd002a,0x645a1bd9,0x7d7a004f}},	//   jgt_, reań, jeti, _ונשו
  { {0xbcfb0152,0xe8480015,0xf6510015,0x645a1bda}},	//   _trés, سجون_, نئة_, deti
  { {0x22b60024,0x443e1bdb,0xf5090a32,0x645a1bdc}},	//   nākt_, egt_, онил_, eeti
  { {0xdddd0050,0x64a50033,0x69c600cb,0x28080046}},	//   _hasł, дапа, _økep, étní_
  { {0x648d002d,0x443e05d7,0x27e00046,0x34a9005e}},	//   _rúis, ggt_, řina_, івно_
  { {0x9c870089,0xd6ce0086,0x22b60024,0xe1ff0077}},	//   _začá, طقی_, zāku_, rdón_
  { {0xd5ae0086,0x443e172b,0xe5690015,0xe2970c6e}},	//   افی_, agt_, _ومضى_, даю_
  { {0x92930010,0x648d002d,0x36340015,0xf42901c5}},	//   таўц, _dúir, _أرمس, _долл_
  { {0x22b6003d,0xb4fa000a,0x9f4e0247,0x8936000a}},	//   vāku_, _ופסי, žník_, ורשע_
  { {0x7e660035,0xdddd002a,0x9e76002b,0x94d20058}},	//   _pakp, _nasł, وهست, _جيوش
  { {0x22b60024,0x648d002d,0x5336000a,0xdee30888}},	//   tāku_, _túis, _חנקן_, воси
  { {0x0d9a0010,0x2499003d,0x7e6600aa,0xed460033}},	// [2f80] цтвы_, ūsmu_, _vakp, ьнап
  { {0x22b60024,0x80a60086,0x01370135,0x61fa0089}},	//   rāku_, _آمدن, _קרית_, ětlu
  { {0x307b0008,0x807b000a,0x6fe70003,0x7e6602f2}},	//   _ואינ, _וניצ, récé, _takp
  { {0x22b60024,0xeb97004a,0xe9da0724,0x62861bdd}},	//   māks_, ьих_, оке_, njko
  { {0xbcfb0152,0x645a0064,0x22b60024,0xa95a0021}},	//   _fréq, yeti, lāks_, تجار_
  { {0xf2bb000b,0x6e240030,0xb7bc003d,0x96f815d2}},	//   _उद्घ, laib, _leģe, пект_
  { {0x22b60024,0x645a1bde,0x36d40df0,0x8c4310ff}},	//   nāks_, veti, нокр, _шере
  { {0x98a6002a,0x7bc10091,0xda660015,0xebe31bdf}},	//   kroć_, _žlug, _غازي, _росп
  { {0xdddd005c,0xe4c6004a,0xbed7000a,0x645a1be0}},	//   _zasł, дённ, ווקז_, teti
  { {0x7d7b0c44,0x28130015,0x84e70015,0x443e02f7}},	//   קניו, _لوكس, وفيق_, ugt_
  { {0xb21b0134,0x6e240035,0x5c37000a,0x57fb000a}},	//   bjæl, kaib, ורין_, _ולבו
  { {0x6b830a83,0x07b70015,0x87250015,0xdddd006f}},	//   ängi, _تهمة_, _أعلم, _hosť
  { {0x65960225,0x7c2e016f,0x20f9005d,0x22b60024}},	//   _تجار, _odbr, ंदेश_, vākt_
  { {0xe3af04b6,0x61f8008f,0xf993000f,0xe5050015}},	//   اری_, ьняў_, דרש_, _أبني
  { {0xdfd80063,0xdfd40010,0x22b60024,0x643b000a}},	//   дът_, воры, gāks_, _ועונ
  { {0xd5e2000b,0x656d06c0,0x98a60535,0x6e2401d3}},	//   _पराज, _šahi, broć_, gaib
  { {0xdd910015,0xbcfb0003,0x5d550033,0x7c87004a}},	// [2f90] دوء_, _crép, экат, муже
  { {0x22b615e5,0x61e00064,0xfc300015,0x40950015}},	//   sākt_, ümle, لحم_, _ألدر
  { {0x290d0045,0x9f45008c,0x5a350719,0x6ee70015}},	//   _stea_, älä_, енет, _يسجل
  { {0x6aa20026,0xdf58002b,0xe7f4000b,0x9dab006b}},	//   ghof, _کشیش_, ेखना_, _дъга_
  { {0x49b80074,0xd5a60015,0xb908009a,0x5a440138}},	//   واهد_, _إف_, وزوم_, тэха
  { {0xd62202e1,0x2bbe000b,0xad1a004f,0x2bd00065}},	//   _цiка, ्थशा, _מושר, _तुवा
  { {0xe739034e,0x46f5007a,0x8a370015,0x87240015}},	//   чей_, нчит, _يعرض, نعيم
  { {0x05650124,0x6aa2003f,0x32c40064,0x61fb0085}},	//   евин, chof, kıya_, žulj
  { {0x5a440010,0x22b60024,0xe5710002,0x5eec000a}},	//   _шэра, zāks_, اطب_, חַזְ
  { {0xd87400c3,0x28150015,0xb21b02de,0x6e240030}},	//   _لامب, _أواس, sjæl, zaib
  { {0x889a0008,0x5435002b,0x8c1a000a,0xd808000a}},	//   _צבעי, ورگر, הותי, _חִנָ
  { {0x753b003f,0xc0490008,0x3ce6000b,0x22b6003d}},	//   puuz, _לז_, _जीने_, vāks_
  { {0x3495008f,0xbddb0152,0xaa3a000a,0xb7bc003d}},	//   _падр, _scèn, התרח, _veģe
  { {0x22b60024,0x7c250012,0x09b6000a,0x55b80058}},	//   tāks_, jahr, תפשט_, _تطمح_
  { {0xdfd20002,0x8fa60033,0x6e240030,0x6609003d}},	//   ايز_, хаве, taib, ocek
  { {0xbcfb0152,0xc7b2000a,0x22b6003d,0x66091be1}},	//   _prép, אבל_, rāks_, ncek
  { {0xed570083,0x7c25018b,0xee37008f,0xc50c0053}},	// [2fa0] нот_, fahr, энт_, ַלאָ
  { {0x64411be2,0x6e240030,0x44251be3,0x0000006a}},	//   ngli, saib, nal_,
  { {0x64411a41,0x20181be4,0x44251be5,0x2c0b009a}},	//   igli, mbri_, ial_, سعلی_
  { {0xca750010,0x2ebd000b,0xa3e4000b,0xbcfb0003}},	//   кучы, ्कृत, पेट_, _trép
  { {0x8dfb000a,0xe9800033,0x4dd60015,0x44251be6}},	//   _מהכת, ралi_, _ستحس, kal_
  { {0x7c2e0134,0x6cd60029,0x44251be7,0x6ac9000b}},	//   _udbr, _أقسا, jal_, िकॉर
  { {0x59dc005d,0xf0930008,0x67d30036,0x4bd50033}},	//   _बरकर, רנו_, лошу, _аўту
  { {0x7b060024,0x2f5b000a,0x7640001a,0x32c40061}},	//   ēstā, פדפנ, ugmy, yıya_
  { {0x44251be8,0xfaa31377,0x95d7006b,0x35b3006b}},	//   fal_, _сато, ндът_, лбър
  { {0x18280074,0x64411be9,0x44251960,0x33740e77}},	//   _آقای_, ggli, gal_, вгор
  { {0x5c370053,0x3d17000b,0x4736002b,0x9781002b}},	//   ערטן_, _पढ़ने_, _سراز, _نیوه
  { {0x3bbb000f,0x3dc6002a,0xc7b3000a,0x7c250046}},	//   למיד, żowy_, _גבע_, zahr
  { {0x44250faa,0x644e0072,0x7ebb005b,0x0000006a}},	//   bal_, õbis, häpä,
  { {0x32c40064,0x44251bea,0x442e143c,0x656601d0}},	//   rıya_, cal_, _udf_, ækhu
  { {0x7ea30005,0xd4670001,0xd4330029,0xdfd50256}},	//   _lõpe, _чије_, _صعوب, товы
  { {0x2ebd014e,0x7c2500b8,0x33db0008,0x32c40061}},	//   ्केत, wahr, _מחוד, pıya_
  { {0x661d09f0,0x2d58005f,0xa2ce005d,0xe1670015}},	// [2fb0] ðski, нить_, सवर्, _أدبي
  { {0x6ac9005d,0x2d870085,0x91bc000a,0xc60d0065}},	//   िक्र, ćne_, _ממחי, _सभ्य_
  { {0x212b04de,0xc052004c,0xf09f0144,0x3ed50058}},	//   lsch_, _דזי_, spàs_, _لقدر
  { {0xc3330008,0xc5fe0024,0x44251beb,0x3a98005e}},	//   רוף_, šējo_, zal_, нтію_
  { {0x212b1bec,0x44251bed,0x7e7d1bee,0x18691bef}},	//   nsch_, yal_, _insp, дали_
  { {0xf8ae0086,0x6d4d0035,0x212b020d,0xa3c0000b}},	//   يکل_, mtaa, isch_, ंपा_
  { {0x2bb80029,0x23cf005d,0xf892000d,0x6d4d1bf0}},	//   _كافة_, _सुंद, рајќ, ltaa
  { {0xcb12011f,0x7e6d0d25,0x6b8310cc,0x57a40033}},	//   _כלל_, ndap, ängu, ышча
  { {0x6441018b,0x66091bf1,0x6d4d0fb4,0xc68e0015}},	//   tgli, rcek, ntaa, تِي_
  { {0xd90d0074,0x13090afa,0xa3c30046,0x6d4d1bf2}},	//   _هیچ_, мной_, ráží_, itaa
  { {0x6d4d00f2,0x291a002a,0x64411bf3,0x61e41945}},	//   htaa, ązań_, rgli, _szil
  { {0xddc404f9,0x64410026,0x6d4d143e,0x44251bf4}},	//   ndiţ, sgli, ktaa, sal_
  { {0x7afb0014,0xa696000a,0x06380015,0x44250d29}},	//   _miut, _שכנה_, _أسمع_, pal_
  { {0xe3b901e5,0x016300d0,0x43850015,0x7e7d1914}},	//   _обл_, јкро, _للتق, _ansp
  { {0x03a20036,0x6d4d16f3,0xf767002b,0x213901f9}},	//   _вищо, etaa, جا_, arsh_
  { {0x41b60029,0xcf250029,0x6d4d00aa,0x7ae900cb}},	//   _لمعر, طرفي, ftaa, _nhet
  { {0x6cd6003b,0x6d4d0035,0xf1aa000b,0x6df30015}},	// [2fc0] نقرا, gtaa, _चेचन, لكفا
  { {0x7afb02d7,0xdd8f0087,0x7e6d1bf5,0xeb9a011e}},	//   _aiut, غول_, adap, миз_
  { {0x0a4a008f,0x109b000a,0x8fa61bf6,0xcb09005e}},	//   дзей_, _חביב, _ране, ехід_
  { {0x7afb08e0,0x78a11bf7,0x7ae91bf8,0xb5fd0091}},	//   _ciut, _allv, _chet, nešd
  { {0xd954003b,0x7ceb00b8,0xa8ea0015,0xaa43005e}},	//   انتخ, dürf, وعتك_, речл
  { {0xf7720031,0x5dcb000a,0x7ae30079,0xe8f7005e}},	//   لاع_, _חֶלְ, ïntr, вніч_
  { {0x6b8304d4,0xd7ef027a,0xcc57004f,0x8a061bf9}},	//   ängt, ру_, _שבלי_, _азбе
  { {0xe6cc005d,0x3ce6000b,0x3ae8002b,0x7ae91bfa}},	//   ावेज, _जीते_, _سبزی_, _ghet
  { {0xceb3013a,0x27e51bfb,0x7d16008c,0x7bdc1bfc}},	//   ייה_, _ezln_, npys, _hyru
  { {0xb8650074,0xb4cc005d,0x68fa0150,0x3a2400da}},	//   _مامو, लवे_, _uitd, _hemp_
  { {0xa295009e,0x83fc016f,0xcc3b0053,0x387e0011}},	//   гані, jeđe, ועיט, _intr_
  { {0x26c00007,0xfbd3000a,0x9731002b,0x212b1bfd}},	//   čios_, יתת_, _اکوا, tsch_
  { {0xe298008f,0x2904003f,0xe534054f,0x212b0012}},	//   таў_, _juma_, _сель, usch_
  { {0x2ebd005d,0x03b60015,0x64a303ae,0x212b1bfe}},	//   ्क्त, _لإعد, _ваља, rsch_
  { {0x9f050029,0x29040035,0xff0403ad,0x3e070033}},	//   اورو, _luma_, иятн, вязв
  { {0x6d4d022d,0x9757000a,0xb3f7000a,0xde58005e}},	//   ttaa, כילו_, _במוח_, касі_
  { {0x2904001c,0x7e6d0375,0x7afb1bff,0x629d0091}},	// [2fd0] _numa_, rdap, _riut, ūros
  { {0x6d4d1c00,0x7cd9002b,0xba74002b,0x629d1c01}},	//   rtaa, رواز_, یانت, lkso
  { {0x3f790053,0x50b80806,0x81f90086,0x7afb1c02}},	//   _װאָס, _جديد_, _تفکر_, _piut
  { {0x4ae40010,0xda090015,0x010b000a,0x629d1c03}},	//   аўча, ريته_, ֵלֶּ, nkso
  { {0x7d020125,0x4a720015,0xd90f002b,0x3fc9002b}},	//   íost, صُور, زیا_, _زدگی_
  { {0xe8f80036,0x98e50029,0x7ae9003e,0x6845042b}},	//   влі_, دكتو, _whet, унка
  { {0x00580008,0x22490064,0x67550040,0x644f0030}},	//   דשות_, _ocak_, اختر, őcik
  { {0xdb24017e,0xd7560074,0x387e0003,0x629d0079}},	//   _úsái, اليت_, _entr_, jkso
  { {0x59b7000b,0xb5fd0085,0x3ebe001a,0xddc402d8}},	//   _अधिर, ješe, étti_, odiš
  { {0x82360086,0x20010092,0xb5fd0237,0xa87b0015}},	//   گردا, _nghi_, deše, _تحرر_
  { {0x94750074,0xe1ff002a,0x98af0045,0x97150033}},	//   ندگا, ndów_, argă_, _смец
  { {0xcad50008,0x7ceb0012,0xaad3000b,0x82360015}},	//   רוֹת_, bürg, तविक, دردا
  { {0xc5fe003d,0x661b0cc4,0xd468002b,0xe1ff0030}},	//   ģēto_, mbuk, رحیم_, deód_
  { {0x55ba0008,0x3f980034,0x629d1c04,0xb5fd003d}},	//   _אמנו, tyru_, akso, rešd
  { {0xf8b20008,0xb4c1005d,0x3f9e0f1b,0x2d8f04d4}},	//   משך_, ्की_, átu_, ägen_
  { {0x7ee30015,0x629d1c05,0xc7b2004f,0x0000006a}},	//   مكّن, ckso, צבן_,
  { {0x83fc010b,0xad66002b,0x3f9e1c06,0xc6920643}},	// [2fe0] ređe, دازه, štu_, זאן_
  { {0xf066092d,0x0c2301b7,0x7bdc04c3,0x0000006a}},	//   _скоп, ймун, _pyru,
  { {0xddd4005c,0x1ec600a2,0x5cf5005e,0xb09b000a}},	//   _łańc, _مقدّ, ряту, _ניטר
  { {0x75240064,0xba45005e,0xd910002b,0x094a0419}},	//   _çizg, ихій, قیر_, ечки_
  { {0x82d700b2,0x38a20084,0x5f760086,0x7bdc002a}},	//   נונג_, _aðra_, _شاگر, _wyru
  { {0x4b260031,0x38c8002b,0x3157004c,0x753b1129}},	//   _معرف, خاصی_, ריסן_, druz
  { {0xd6d00086,0x3a24052a,0x8cdb000a,0x69c50012}},	//   يقت_, _temp_, _נחלת, ßher
  { {0x2904000c,0x6b8300c0,0x661b1c07,0x758a011d}},	//   _tuma_, ånge, gbuk, есов_
  { {0xc0b30023,0x7d061c08,0x9876003d,0xdddd005a}},	//   gười_, _juks, aļās_, _basř
  { {0xd563010f,0xd498005e,0x895b000a,0x63541293}},	//   стъп, ткої_, _אדמת, авоу
  { {0x2ee00064,0x9cd7000a,0x389b000a,0x289b000a}},	//   klif_, רויה_, _ריבנ, _ריבא
  { {0x52a70029,0x2bf7000a,0xd1310015,0x7ceb080d}},	//   اصدق, טמין_, يمج_, pürg
  { {0xc05b0191,0x629d02e9,0xe1ff002a,0x34560015}},	//   нів_, rkso, zdów_, _منشأ
  { {0xf484002b,0xe58b000a,0xc1040015,0xe1ff002a}},	//   _خاصی, _רָאָ, صوفي, ydów_
  { {0x28970053,0x93770015,0x94230054,0x7d061c09}},	//   נדלן_, _مصير_, _умје, _auks
  { {0x7d061c0a,0xc333000a,0x6e20007c,0xe37b000a}},	//   _buks, _הוק_, _õmbl, _טרור
  { {0x40350b75,0xb5fd00bc,0x75240061,0x9df90190}},	// [2ff0] _кепс, peše, _çizd, тнат_
  { {0xadf41c0b,0xf1b4000a,0x90e70058,0x7ceb007f}},	//   спуш, _לספ_, _حسبن, küre
  { {0x60fa0008,0x70fa0008,0x7ae30045,0x0a150040}},	//   _שהתק, _שהתח, înto, لواح
  { {0x19b9008f,0x660200dd,0x7ceb136c,0xc333000a}},	//   куль_, _ngok, würd, מוע_
  { {0xe1ff005c,0x645804e2,0x3ea901b3,0xe969004a}},	//   rdów_, _obvi, mhat_, талл_
  { {0x3ea900dc,0x7c871bc8,0xd9160015,0xe708002b}},	//   lhat_, _суме, جيوش_, گتون_
  { {0x07a51c0c,0xc7a5006b,0xe0fc000a,0x2bc801ca}},	//   райн, рийк, גלגל, _буто_
  { {0x753b1c0d,0x661b0035,0xe708002b,0x19950033}},	//   truz, ubuk, دتون_, _кабя
  { {0xca480086,0xd5b10029,0x661b0849,0x3ea901d7}},	//   _حلقه_, تفظ_, rbuk, ihat_
  { {0xb4c1005d,0xb9940029,0x753b08c7,0xd8770058}},	//   ्के_, _الْب, rruz, _حارب
  { {0x987a004c,0xe2860718,0xa3ea0157,0x7c270085}},	//   _שרעק, ални, _मरण_, _mejr
  { {0x25b60086,0x8bd60008,0x7c2702de,0x6d5d1c0e}},	//   اهید_, יותו_, _lejr, _opsa
  { {0xcad60008,0x3ea900dc,0xfad6000a,0x8aa8000a}},	//   שורת_, dhat_, שורך_, רֹתֶ
  { {0x7c270089,0x3ea900e8,0xa06a0001,0xe5a212fd}},	//   _nejr, ehat_, њава_, _фиши
  { {0x6d5d1203,0x7d061c0f,0x4e2a0004,0x44271c10}},	//   _apsa, _suks, ковн_, _ien_
  { {0xed5a07c1,0x44271c11,0x7d06007c,0xbea303ae}},	//   коб_, _hen_, _puks, оаск

  { {0x1d070063,0xbe130015,0x8e070248,0x25ad1c12}},	// [3000] иети_, توقع, рнув_, nzel_
  { {0x44270089,0x3ea90035,0x75240064,0x4c83000d}},	//   _jen_, ahat_, _çize, олув
  { {0x5b360015,0xef94002b,0x80a6002b,0x9c590033}},	//   شعار, _ایزد, _ممکن, ышту_
  { {0x4427002c,0x3ea91c13,0xbbe90015,0x9281004c}},	//   _len_, chat_, اركم_, אָבן_
  { {0xfe37000a,0x2d8f02de,0x7c2702de,0x3ebe001a}},	//   _דרכי_, øget_, _fejr, éttu_
  { {0xd7f10023,0xddcd0011,0x7ceb03ba,0xb4c1000b}},	//   _hãy_, leaş, türe, ्को_
  { {0xf7270010,0x6d440045,0x07a303ae,0x569400fd}},	//   ацый_, luia, жајн, йакт
  { {0x27330092,0x3ea001a0,0x25f2000b,0x2916002b}},	//   ịnh_, nkit_, ँधली_, _نورآ
  { {0x74c60063,0x35f3006b,0x7ae20030,0xaa3b000a}},	//   ищож, опър, mlot, _שתמח
  { {0x3ea900dc,0xed570008,0xd91b000a,0xf7d60033}},	//   zhat_, סביר_, _סובל, _кіеў
  { {0x5c790053,0xdc89000a,0xcc770447,0x44271c14}},	//   אָרױ, רְפָ, בעיה_, _den_
  { {0x44271c15,0x96070080,0x96fa00e5,0xf79b000a}},	//   _een_, _кэша_, _شعار_, _שבאמ
  { {0x20d70015,0x3ea90030,0x24580033,0x44271c16}},	//   لتسج, vhat_, _баль_, _fen_
  { {0x3be6005d,0x3ea9003e,0x859b000a,0xe44f0015}},	//   _करूँ_, what_, _בשדו, _قضى_
  { {0x3ea900dc,0x442c0032,0x43430180,0x447b000a}},	//   that_, mad_, _дејв, _שְׂא
  { {0x93fb0053,0x92b40015,0x23fb000a,0x03c50484}},	//   _בלוי, _وحيا, _בפומ, _усім
  { {0xfd130015,0xbc070342,0x27330016,0x8d7700c3}},	// [3010] تجز_, ачей, ạnh_, جازا
  { {0xb5fd00c5,0x7cf00012,0x6db70061,0x442c1c17}},	//   neša, härf, _ağaç, nad_
  { {0x7c270134,0x25ad00dc,0x442c002d,0xcb550001}},	//   _vejr, zzel_, iad_, свећ
  { {0xbad80036,0x7ceb00b8,0xbb840015,0x89350015}},	//   афії_, fürc, تلمي, معتا
  { {0x98dd0010,0x6d440045,0x9e76000a,0x99670681}},	//   нскi, cuia, _פגשה_, ртел
  { {0x442c0005,0xb5fd016f,0x25ad00bd,0xf7710015}},	//   jad_, ješa, vzel_, كاب_
  { {0x442c1c18,0xccf20008,0xb5fd016f,0x9bc90015}},	//   dad_, _מכך_, deša, _صورك_
  { {0x4427022d,0xead40c1d,0x6e2d1c19,0x442c1c1a}},	//   _sen_, _дось, naab, ead_
  { {0xddc6018c,0x442c1c1b,0x44271c1c,0xdb24001a}},	//   _kakš, fad_, _pen_, ásöl
  { {0x4d7a004c,0xd4690054,0x442c1c1d,0x8578006b}},	//   אָטא, ћине_, gad_, рсът_
  { {0xa22a0080,0x17fb0029,0x6e2d166f,0x25ad06e7}},	//   лжна_, _شرطة_, kaab, szel_
  { {0xddc61c1e,0x64480079,0xf6740015,0x44271c1f}},	//   _lakš, agdi, _وانخ, _wen_
  { {0x44271c20,0x76490061,0x83fc0085,0x6e2d007c}},	//   _ten_, mgey, ređa, daab
  { {0x7cf00020,0x76490064,0x7e20000b,0x03a90015}},	//   märg, lgey, बर्ग_, _مدعو_
  { {0x13a7002b,0x3be6000b,0x34920b1e,0x8fa3123e}},	//   _خنثی_, _करेँ_, _хајр, паре
  { {0x539a0008,0x42260457,0xc2c60015,0x6e2d02f2}},	//   _תיקו, _удив, _ديبي, gaab
  { {0x3ea000f2,0x7e640007,0x7d26002b,0x51850004}},	// [3020] rkit_, reip, صفان, _дуќа
  { {0x7ae2002a,0x6d440045,0x3ea005ff,0x6e2d02f2}},	//   wlot, ruia, skit_, aaab
  { {0xd24f0086,0x2d8f0134,0xf8c80092,0xe1ff0251}},	//   _غنی_, øger_, hức_, bdós_
  { {0x6b8300c0,0x1a2a006b,0x7ae2008c,0x442c1c21}},	//   ånga, ужди_, ulot, zad_
  { {0x442c00b6,0xb9560124,0x7cf00020,0x67010053}},	//   yad_, стећ, järg, _נאָענ
  { {0x307a00b2,0x7ae21c22,0x7ea30020,0xa157000a}},	//   ראַנ, slot, _lõpl, מבנה_
  { {0x442c1c23,0x07370015,0xa7370015,0x628400da}},	//   vad_, مسيب_, مثير_, _onio
  { {0x7cf00123,0xe6660a96,0xf66a002b,0x442c1c24}},	//   färg, стко, احثه_, wad_
  { {0x142a005e,0xf517002b,0xb21b0789,0x442c1c25}},	//   ліно_, یتیش_, kjær, tad_
  { {0x62841755,0x442c0c43,0xe46a0883,0xe76a0058}},	//   _anio, uad_, ушил_, _محصن_
  { {0x442c1c26,0x38ab01f0,0x629601d7,0x7cf00012}},	//   rad_, _sørg_, _boyo, märd
  { {0x75d30086,0x6284002d,0xd62705b3,0x5b7b004c}},	//   _کيها, _cnio, _гоце_, ארטא
  { {0x914b0010,0xb5fd06d5,0xa3b8000b,0x6284002a}},	//   ычна_, lešn, _घेर_, _dnio
  { {0x224d005c,0x39460007,0xf537000a,0xb504000b}},	//   żek_, iuos_, _פטור_, रदीप_
  { {0xdbf10089,0xe4570053,0x4ea70010,0xc7b1000a}},	//   _přím, _ליגט_, браа, ֵ֑ל_
  { {0x9e150033,0x39460091,0xf814002a,0xdc210065}},	//   ідзі, kuos_, ężyć_, यर्ड_
  { {0x5cb90010,0x6e940784,0xce94006b,0x4238000a}},	// [3030] алаў_, читу, чатъ, _הנחל_
  { {0xa3cc005d,0x38ab0134,0x8c590015,0x3946047e}},	//   _रखा_, _køre_, ؤلاء_, duos_
  { {0x6296000c,0xce95010f,0x4af90086,0x395f0011}},	//   _yoyo, _данъ, لکرد_, _spus_
  { {0xdb0800dc,0xc17f0091,0xaa5909c2,0xe37b004f}},	//   álás, _įėjo_, риду_, טרבר
  { {0xc7b8016f,0xddc600bd,0x7cf000c0,0x394602c1}},	//   _među_, _takš, färd, guos_
  { {0x7cf01c27,0x88c8005e,0x3158000a,0xe7870046}},	//   gärd, блів_, ציון_, _váží
  { {0x7ea3007c,0xa09c000a,0x309c000a,0x76490052}},	//   _lõpm, ריוט, רשומ, tgey
  { {0x66f20180,0x78a8001a,0x06090561,0x9aa50021}},	//   мпју, _eldv, шник_, _بمرو
  { {0xf993003b,0x5fdb005d,0x1a680086,0x4585005e}},	//   _عبر_, _मुसल, _دینی_, ігов
  { {0xb9c40015,0x65690012,0x62960618,0x7cf00012}},	//   _عقلي, rweh, _soyo, rärg
  { {0x61ed0717,0xd808000a,0x626618dc,0x97a71884}},	//   _azal, _הִנָ, овна, _урал
  { {0xe7300029,0x4dfb000b,0xc7d6004c,0x7cf00012}},	//   _أصل_, ्शाई_, _וועי_, märe
  { {0x62960152,0x7cf01c28,0xaada004f,0xe4c8009a}},	//   _voyo, läre, שחרר, شبین_
  { {0x6284005c,0x2ee2005d,0x6aa90026,0xa3b90086}},	//   _wnio, पत्त, _llef, _پاتر_
  { {0x38ab00fb,0x2bd9005d,0xdfd200e6,0x9e960001}},	//   _gøre_, _बुला, ذير_, ошаљ
  { {0xf77201ac,0x628402e7,0xb5fd1c29,0x0000006a}},	//   וקל_, _unio, nešo,
  { {0xe5f60053,0x216a005e,0xe1ff0077,0x85f6004c}},	// [3040] ַזער_, _типи_, león_, ַמעס_
  { {0x61e40064,0x9046002b,0x39460091,0xa2a8000b}},	//   _iyil, _بنده, vuos_, फ़ोर्
  { {0xbcfb038d,0x7cf00f37,0x643a0053,0x60dc0045}},	//   _spéc, värd, שעענ, morm
  { {0xae5a005e,0x60dc1c2a,0x5ad30015,0x39461c2b}},	//   _троє_, lorm, وْلا, tuos_
  { {0xbcfb0030,0x7cf00dca,0x60dc1c2c,0xe8fa0515}},	//   _csés, tärd, oorm, алд_
  { {0x2d540020,0xbefa0024,0x7cf00bc2,0x98a303ad}},	//   mäe_, žģīt, färe, миче
  { {0xf09300b4,0xfaa60010,0xb8650029,0xe72f0029}},	//   ונג_, _даво, ثانو, نصي_
  { {0xc6f80054,0x60dc0852,0x963405c8,0x6aa90034}},	//   љних_, horm, чниц, _glef
  { {0xe60f0015,0x0ae90015,0xb7bc003d,0x0000006a}},	//   خشى_, _طرفي_, _meģi,
  { {0x7cf00c77,0xd49a0080,0xddcd0011,0x59c0000b}},	//   lärb, рри_, ldaţ, _शेयर
  { {0x6c7b000a,0x64b30015,0x64a30004,0x37c60067}},	//   בריד, بحير, фаќа, _بياف
  { {0x2bbd005d,0xddcd0011,0x51870054,0x442a0535}},	//   ्पता, ndaţ, оуга, źb_
  { {0x8afb004c,0xad9b0030,0x865b000a,0x75d60015}},	//   יפטק, _egúj, _כדאי, _بيشا
  { {0x6ab7021e,0x04580015,0xf8bc000b,0x61ed013f}},	//   _आग्र, _طلبة_, ्चिय, _vzal
  { {0x09b7005d,0xcebb0001,0x7880006f,0x8cae000b}},	//   _अध्य, аља_, _závä, ंघनो
  { {0x9d15017d,0x02940015,0x32b80015,0x645a0ffa}},	//   здач, _يؤيد, _ودية_, lfti
  { {0x5fdb000b,0xf8bc000b,0x61ed1c2d,0xe29c004f}},	// [3050] _मुरल, ्चाय, _uzal, _כשהר
  { {0xe5710008,0x645a00b8,0xb5fd0046,0x351b000a}},	//   עַן_, nfti, dešl, יומנ
  { {0xc052000a,0x7cf00012,0x6bd90058,0xf1c8005a}},	//   _אזי_, färb, حواس_, rbář_
  { {0x8f880008,0x59750033,0x7cf00b1f,0x9fbf005a}},	//   _וְשֵ, зыку, väre, nčím_
  { {0xa9240191,0x0dc8000d,0xaa560015,0xddeb002b}},	//   дділ, _дури_, سلوا_, _خرده_
  { {0x645a0111,0x27950956,0x61e00012,0x5dfa000a}},	//   jfti, зшир, ümli, _לפרנ
  { {0x24890016,0x4ac50058,0x0000006a,0x0000006a}},	//   _đam_, _فيسق,   ,
  { {0x32090023,0xfbd2000f,0x5b340067,0x7cf00012}},	//   _ngay_, _נתן_, _زعفر, räre
  { {0x645a0313,0x47d5002b,0xf5560015,0x60dc1c2e}},	//   ffti, _کيار, كليب_, yorm
  { {0xe7190086,0xd7770015,0x870702db,0x7ceb02ad}},	//   _هيئت_, _واضع, _дяде, zürn
  { {0x64980063,0x3a2d04d0,0xf7480029,0x65620aa2}},	//   ютър_, _keep_, _ولكي_, _epoh
  { {0x216a006b,0x3a2d1c2f,0x6d41003d,0x60dc0e9d}},	//   бими_, _jeep_, _ālan, worm
  { {0xb7bc0048,0x2905000c,0x15b80033,0x6aaa03f8}},	//   _reģi, _kila_, _мышы_, ëffi
  { {0x2d540020,0xf9920008,0x3ce5000b,0x60dc008c}},	//   väe_, תרך_, कतों_, uorm
  { {0xd00f0031,0xf412000a,0xa3de0046,0x657b001a}},	//   الف_, _אפו_, _těší_, lvuh
  { {0x539a013a,0x60dc0152,0xf7720053,0xfe0a0015}},	//   _ליצו, sorm, עקן_, صغرى_
  { {0x60dc025c,0xa1130015,0xdb0d006f,0x3519000a}},	// [3060] porm, _كويت, ľkým, מוּנ
  { {0x29050035,0xf8a50086,0x3157000f,0x317b000a}},	//   _nila_, _شک_, _ציין_, _פרימ
  { {0x309b0008,0xda0a0029,0xa09b01ac,0x409b000a}},	//   _השימ, مياه_, _הייט, _הביס
  { {0x7ceb1c30,0xaae60015,0xed5a070c,0xfbf70058}},	//   büro, أسطو, _лом_, سّنة_
  { {0x3a2d003e,0xb8660029,0xbefa000b,0xddcd0045}},	//   _deep_, كاثو, ्दीन_, rdaţ
  { {0x7ceb0064,0xbab6002b,0xec34002b,0x63a10123}},	//   nürl, _کمرب, _زورگ, kyln
  { {0x38cb0086,0x7c2e003d,0x56941c31,0x290516ad}},	//   حانی_, _iebr, дайт, _dila_
  { {0xbb3b000a,0x8cb6000b,0x7c2e1c32,0x6d441c33}},	//   _לעלי, ोचको, _hebr, oria
  { {0x9c8300bd,0x7ceb0012,0x6d440125,0x29051c34}},	//   ščet, kürl, nria, _fila_
  { {0x6d440fc6,0x73381c35,0x2937000a,0xc9850015}},	//   iria, озор_, _מאמן_, _تشفي
  { {0x99560024,0xe2f90036,0xe8d7000a,0x7ceb0061}},	//   kļūt_, жені_, _צובר_, dürl
  { {0x6d440007,0xa3bd000b,0x2905003d,0x6f06002a}},	//   kria, _इधर_, _zila_, _nikc
  { {0xc50a003b,0x867b013a,0x51870124,0xa2ae005d}},	//   _اتصل_, _לראו, чуна, ुफ़्
  { {0x7ceb0064,0xd5fb0008,0x45fb000a,0x7c2e0a25}},	//   gürl, _הפדר, _ההדג, _nebr
  { {0x71270086,0x4477000a,0x6d441c36,0x9f350033}},	//   _کربل, _מעגל_, eria, ьеві
  { {0x6e2400b6,0xdce4016f,0x442e1c37,0xa2e40004}},	//   gbib, dviđ, _hef_, _појд
  { {0xcc990001,0x1df8054f,0x6d441c38,0x5c99055f}},	// [3070] овац_, зеты_, gria, окая_
  { {0xd0110087,0x6e2402f2,0x7055002b,0xff070033}},	//   _جلد_, abib, _کنگا, _нямн
  { {0xf0920008,0xdced016f,0x7c2e1c39,0x3a2d0158}},	//   _סנט_, hvać, _debr, _peep_
  { {0x29051c3a,0x8f36015b,0xddcd0085,0xdef80033}},	//   _sila_, _קארו_, adaš, _ныя_
  { {0x4e7a000a,0x6d441c3b,0x8e96000a,0x2ee90034}},	//   _וארצ, cria, _חדרו_, mlaf_
  { {0x21780008,0xe9d80010,0x7c2e1c3c,0x2ee90304}},	//   פתור_, чкі_, _gebr, llaf_
  { {0x6b830134,0xf77100e6,0xb8f5000b,0x1bd4005e}},	//   ængd, ئات_, _हद_, _зоря
  { {0xaa580124,0x7c2e1c3d,0x753d0030,0x7c250125}},	//   _нису_, _zebr, ászo, lbhr
  { {0x29051c3e,0x6e2f0061,0xa85503de,0xdcf6006f}},	//   _tila_, _mecb, _окач, zvyč
  { {0xb5fd0263,0x03a5033d,0x5c9a004c,0x2ee90012}},	//   lešk, диоо, ַשרײ, hlaf_
  { {0xa91d06d5,0x9405002b,0x657b014b,0xd6db1c3f}},	//   _drže, بوده, svuh, _лтд_
  { {0x7d070298,0x7c25002d,0xb5fd1c40,0x7ceb0061}},	//   _lijs, hbhr, nešk, dürm
  { {0x27e001e2,0x7ceb136c,0x3f570003,0x4a5a004f}},	//   ğine_, türl, eçu_, חדרו
  { {0x1dd8014e,0x6d44138e,0x2329005e,0x442e001a}},	//   _भुगत, vria, _доки_, _gef_
  { {0x7c2e08e0,0x91030b1a,0x6d440026,0x7ceb0064}},	//   _rebr, тпре, wria, rürl
  { {0xb5fd0085,0x21a60015,0x7c2e1c41,0x6d441c42}},	//   ješk, _يمثّ, _sebr, tria
  { {0xed570083,0x44250026,0x7d070111,0x828b000a}},	// [3080] мот_, obl_, _bijs, _וְיֶ
  { {0x1c390010,0x6d441c43,0x60970015,0x10a60788}},	//   зяць_, rria, _ينيس_, _цион
  { {0x7cf001d1,0x660b00cb,0xbb860058,0x0000006a}},	//   gära, _oggk, بلاي,
  { {0xcf93000a,0x5e460015,0xb9c60015,0x7c250125}},	//   _סטר_, _تَحْ, وقاي, abhr
  { {0xe7c3005d,0x7c2e0064,0x2d8f0123,0x26cd0085}},	//   _वेबप, _tebr, äget_, dneo_
  { {0xab2a0063,0xfbd9000b,0x18b80033,0xf8680015}},	//   _мога_, _बुकम, яглы_, سمعي_
  { {0x4733002b,0x8c4303ae,0xfc031c44,0xb5fd00bc}},	//   نريز, _јесе, _апро, bešk
  { {0x6b8300fb,0xda660086,0x2007002c,0x442e0d0c}},	//   ænge, _تاسي, _únie_, _sef_
  { {0xfcaa000a,0xb4460033,0xa91d0160,0x0000006a}},	//   ַיֹּ, мэнк, _prže,
  { {0xa99b000a,0x75240061,0x83fc0085,0x999b004f}},	//   _ובמר, _çizm, leđi, _ובמט
  { {0xf7720029,0x7eb1003c,0x442e002e,0x867a0033}},	//   _جاء_, _håpe, _vef_, _мёду_
  { {0x87b7004c,0x4b37000a,0x57b7000a,0xe5c61a9d}},	//   _קלאס_, ורטל_, _קלאב_, _осло
  { {0xa91d0a05,0x7ceb0012,0x41e40033,0x26c41296}},	//   _trže, würm, віра, mimo_
  { {0x394603af,0x26c40a00,0x3d1c005d,0x7ceb18b8}},	//   iros_, limo_, _पढ़ें_, türm
  { {0x7d070079,0xe8ee0033,0x4fc40e37,0x7d0f01d0}},	//   _rijs, ылi_, вста, _sucs
  { {0x3f570152,0x26c41c45,0x39461c46,0x3f8102c6}},	//   rçu_, nimo_, kros_, _vrhu_
  { {0x2fdf005c,0x9b950086,0xf1a70036,0xb5fd10ca}},	// [3090] ług_, کلات, _ірин, vešk
  { {0x3f810227,0xebc70054,0x2295002b,0x3959003d}},	//   _trhu_, мљен, _آلکس, _īss_
  { {0x26c400df,0xeb090029,0x7c25002d,0x38ab0134}},	//   kimo_, أقصى_, rbhr, _børn_
  { {0x26c400df,0x7d070111,0x6ffa000a,0x93fb000a}},	//   jimo_, _wijs, _מהתפ, קלאי
  { {0xae1a0008,0xe1ff00dc,0x44250026,0xe9ce1c47}},	//   _מורכ, deók_, ybl_, ук_
  { {0x7cf01c48,0x99d40086,0x7b670063,0x8c250067}},	//   pära, ختما, _отбе, _سفره
  { {0xc8780061,0x9aa50015,0xb5fd00bc,0xddcf0045}},	//   _dağ_, _كمسو, pešk, _facţ
  { {0x39461c49,0x26c40007,0x44250026,0x3ea90d9c}},	//   bros_, gimo_, wbl_, nkat_
  { {0x2f1502ce,0x6d4d1c4a,0x26cd1c4b,0xf5051c4c}},	//   _låg_, nuaa, rneo_, нзио
  { {0xb5fd00df,0x7e6d002d,0xd8380085,0x03251c4d}},	//   neši, heap, _poče_, ндон
  { {0xc2c60029,0xf1c5005d,0x3ea90064,0x13e90080}},	//   فيدي, _लेबन, kkat_, ямой_
  { {0x7cf000c0,0xc5d5017f,0xeb92004c,0x06840015}},	//   järn, _піль, אָש_, _للمُ
  { {0x91360010,0x7e6d0011,0xc8780061,0xeab2000a}},	//   эхні, deap, _yağ_, רֹת_
  { {0x0ef8005d,0x6d4d0020,0xb5fd016f,0x859a000a}},	//   ंग्स_, duaa, ješi, _משנו
  { {0x7ea30005,0x645c0251,0xb5fd1c4e,0xf7670040}},	//   _lõpu, òrie, deši, دا_
  { {0x7eaa0057,0x3ea91c4f,0x7cf00123,0x67230085}},	//   _výpo, gkat_, gärn, ipnj
  { {0xac86176c,0xfd4a0033,0x4d4a0033,0xe0d2002b}},	// [30a0] нгал, язак_, япан_, _مزد_
  { {0x3946001c,0x5ce60015,0x3ea91c50,0x26c40b28}},	//   vros_, ركال, akat_, zimo_
  { {0x9057000a,0x1fb50010,0x2d8f079c,0x2057000a}},	//   _אביו_, _асяр, äger_, _אייל_
  { {0x394606d4,0x3ea900c0,0xc8780064,0x26c40e57}},	//   tros_, ckat_, _sağ_, ximo_
  { {0xf539002c,0x83fc016f,0x26c41c51,0x7bc10046}},	//   jsť_, ređi, vimo_, _žlut
  { {0x20070251,0x7eb1003c,0xfce6005e,0x672d0085}},	//   _únic_, _våpe, _чого, ćajn
  { {0xf539002c,0x7ceb0030,0x37061c52,0xcb67098b}},	//   esť_, zürk, нчив, _паре_
  { {0x2b470089,0xcf930008,0xc8ca002b,0x2d801c53}},	//   ánce_, רטה_, _کوئن_, ovie_
  { {0xceb30008,0x2d80001c,0x26c409d4,0xdce4002a}},	//   טיה_, nvie_, rimo_, awią
  { {0x26c41c54,0xed570008,0x22400509,0x493b000a}},	//   simo_, עביר_, _adik_, _מגמו
  { {0xf539006f,0xd6cf1c55,0x26c41c56,0x1cb7000a}},	//   asť_, _бт_, pimo_, גליל_
  { {0x5fdb000b,0x7ae21c57,0x7ceb1c58,0x0000006a}},	//   _मुगल, noot, türk,
  { {0x64a61c59,0x2f1502ce,0xe79a0046,0xeac7000a}},	//   _пада, _såg_, věří, תִי֙_
  { {0x251b00a3,0xf4d70015,0x35f301c6,0x7ae2185e}},	//   _צווא, _كونغ_, _спір, hoot
  { {0x30a40063,0xdfd40010,0x7e6d0011,0x3ea91c5a}},	//   уряв, горы, teap, tkat_
  { {0x9f470046,0x6d4d1928,0x3ea91c5b,0x2f150123}},	//   _ání_, tuaa, ukat_, _våg_
  { {0xdce4005c,0x628d003f,0x6c550080,0xfd130031}},	// [30b0] zwią, _inao, ккау, اجر_
  { {0x3ea91c5c,0x8c440054,0x2f150123,0xdcf90058}},	//   skat_, леђе, _tåg_, ذفات_
  { {0x6e3600b6,0x50d40029,0x6d4d0209,0xe1ff0030}},	//   bayb, _حزير, suaa, deói_
  { {0x9f960008,0xd337000a,0xf8a9000b,0x7ae2005b}},	//   _סדרה_, תראה_, कस्प, goot
  { {0xf2d40053,0xa3de0089,0x8e36000a,0x7e9a0c44}},	//   װעס_, _věří_, _שנשא_, _חסרו
  { {0xf7710002,0xf74505c1,0x91bc000a,0x67550015}},	//   لاب_, веко, המדי, نخبر
  { {0xa91d065d,0xc052000a,0x2c16000b,0x501c000a}},	//   _drža, ׁ֖ה_, दुओं_, לוגו
  { {0x6a140015,0x0565004a,0x67230160,0xddc40073}},	//   _مبكر, ввин, rpnj, leiš
  { {0x68270010,0xe9d30015,0x5eec004f,0xa92b0138}},	//   _зьез, _صغر_, הַזְ, _хібе_
  { {0xb4bd005d,0x94760086,0x27e00045,0xc48202bb}},	//   ीचे_, ندپا, şina_, альк
  { {0x8c1a000a,0x68e31c5d,0x2d80006f,0x21200160}},	//   וותי, mond, zvie_, _stih_
  { {0xa6c90015,0x83fc0085,0xd24f0015,0xe9c70015}},	//   _توصل_, jeđu, ينٍ_, لغ_
  { {0x6a3a0008,0xe3b80064,0x645c0251,0x7cf00123}},	//   וגרפ, azı_, òric, färl
  { {0x64a21c5e,0x68e31c5f,0x753b0061,0xc948000a}},	//   _ваша, nond, msuz, עֲרֹ
  { {0xafe6006d,0x753b0061,0xe2b60033,0x661b0061}},	//   товл, lsuz, _аспэ, ocuk
  { {0x661b0375,0xd0070054,0xee3a0004,0x2d80006f}},	//   ncuk, ђете_, ќна_, tvie_
  { {0xe0da023e,0x68e31c60,0x753b0061,0x71730015}},	// [30c0] _ови_, kond, nsuz, _نهيا
  { {0x3137013a,0x2d801c61,0x0137000a,0x69b70065}},	//   _שנים_, rvie_, _שרית_, ्छनी
  { {0xda7a006b,0x7ae21c62,0x83fc0085,0x0b170015}},	//   дял_, toot, beđu, نقلة_
  { {0xbb430080,0x0a6700d7,0xad260015,0xeafa0015}},	//   рецк, врши_, _لرسو, ذرات_
  { {0xb1cd000a,0x39130015,0xfaa30004,0x7ae21126}},	//   ּמוֹ, لونز, јачо, root
  { {0x91bb0008,0xf863005e,0xc173000a,0x75240061}},	//   ומני, ивчо, יחד_, _çizi
  { {0xb8ea005d,0x98a30001,0xa9070015,0x97240015}},	//   _लग_, рије, خيول_, دفعو
  { {0x7ceb0012,0x97c50015,0xfaa31c63,0x44200046}},	//   fürw, دتهم, _касо, _ři_
  { {0x09061c64,0x4a5b000a,0xa91d00bc,0xbad50033}},	//   _апан, _קדמו, _trža, _сіры
  { {0x68e304a0,0x7cf00123,0x3957000a,0x3d1a0065}},	//   cond, kärm, _בשמם_, _बढने_
  { {0xc4c6002b,0x7cf00123,0xd7ea0033,0x61f61c65}},	//   فتگو, värl, _ўмее_, _azyl
  { {0xeb3b0053,0x66e3033f,0xc6a3023e,0xd7ef0015}},	//   ועטש, _коха, _врши, _بكم_
  { {0xc05b0036,0x61f6005c,0xe5720087,0xc6490015}},	//   мів_, _czyl, _خطا_, _أجمل_
  { {0x38d4000a,0x0000006a,0x0000006a,0x0000006a}},	//   אֵֽל_,   ,   ,
  { {0x290c1c66,0x40340892,0x92b70002,0x3f850046}},	//   _mida_, ресс, _لحظا, ílu_
  { {0x628d000c,0x68e30111,0x877b000f,0xc7d7000a}},	//   _unao, zond, ואלי, דולי_
  { {0x83fc016f,0xbdf50054,0x68e30f0a,0x0000006a}},	// [30d0] ređu, упај, yond,
  { {0x6adb014e,0x20750010,0xb5fd016f,0x7cf00012}},	//   यक्र, _слоў, mešt, bärm
  { {0x68e30298,0xfbd00029,0xddc40007,0x3ed50015}},	//   vond, يتم_, reiš, _مقدر
  { {0x19f90010,0x6aa01c67,0x68e308cf,0x7b640c02}},	//   нэль_, _comf, wond, ртфе
  { {0x4a440036,0xb5fd0007,0x6d4b0125,0x68e31c68}},	//   рнів, nešt, ágad, tond
  { {0x68e3003f,0xab2b0015,0x63a802de,0x3c3c0046}},	//   uond, _يسأل_, kydn, ráví_
  { {0xdce4005c,0x57a40001,0xf09400a3,0x68e31c69}},	//   jwię, ишћа, ינס_, rond
  { {0x7cf00c8d,0xf7700087,0x68e31c6a,0x0f58000a}},	//   järj, تاه_, sond, דיהם_
  { {0xb5fd016f,0xceb40008,0x68e30936,0xdce4002a}},	//   ješt, ייק_, pond, ewię
  { {0xd928000a,0xbcfb0125,0x753b0061,0x998d0046}},	//   _יֵעָ, _bpéi, rsuz, _kdež_
  { {0x645c0144,0x7e7d0045,0x61f6002a,0x7cf00123}},	//   òria, _oasp, _szyl, färj
  { {0x7e7d03cd,0xe29a155e,0x92b60015,0x290c0085}},	//   _nasp, хам_, احدا, _zida_
  { {0x45450029,0xa2b5000b,0x7cf00012,0xd347002b}},	//   _إنتق, ॉफ़्, wärm, ریکه_
  { {0xdddd0050,0xf0d50010,0x653a004c,0x43850015}},	//   _obsł, аўсю, _טענד, _ملتق
  { {0x644600df,0x7afb0020,0x61ed0064,0xbf160015}},	//   ėkit, _ohut, _eyal, اورب
  { {0x7ea30020,0xc7b2000a,0x2eb50033,0xcf250015}},	//   _sõpr, זבל_, асус, شرفي
  { {0xde350010,0x6e930015,0x7c3508c1,0x6aa01c6b}},	// [30e0] рэсь, حلقا, _bezr, _romf
  { {0x7e7d002d,0x7cf01c6c,0x71bb0008,0xddc60107}},	//   _easp, märk, _נציג, _takž
  { {0x0b460036,0x5f760002,0x290c17df,0xa0c6002b}},	//   унен, _صادر, _rida_, _ليکو
  { {0xbae50191,0x290c02ce,0xe9da0175,0x8e760054}},	//   ацій, _sida_, нке_, _суоч
  { {0x5a330036,0x9e630010,0x79c60010,0x4a750010}},	//   сніт, _увяд, ыйдз, рыхт
  { {0xf7720115,0xa91d1c6d,0xf9870015,0x7e7d1c6e}},	//   ماع_, _tržn, انوي_, _zasp
  { {0x69dc0050,0xdb780008,0xab781c6f,0xf6e60254}},	//   _śred, _בְּש, _בְּי, лцин
  { {0x7afb002f,0x644300dc,0x1ab8000b,0xd6d70138}},	//   _ghut, _adni, _आतिथ, лты_
  { {0x45d40e88,0xbcfb002d,0x7e64001a,0x290c1c70}},	//   ропс, _spéi, ifip, _tida_
  { {0xb5fd010b,0x7ea30005,0xb8650087,0x63a801f0}},	//   vešt, _lõpp, _نامو, tydn
  { {0x8726004a,0x44f700c3,0x0000006a,0x0000006a}},	//   _смеж, دريج_,   ,
  { {0x171b000a,0x8bd7000a,0x41b50015,0x6443035f}},	//   _נודע, רוטו_, لمجر, _edni
  { {0x7e7d1c71,0xf4860afb,0x0595002b,0xe4d3002b}},	//   _rasp, _буйн, _ناوگ, شتیب
  { {0xe9ce0033,0xe1ff0030,0x7e7d003d,0x89eb000a}},	//   ўкi_, deót_, _sasp, גַלֵ
  { {0x7e7d0780,0x9f35005e,0x1847000a,0x80b6000b}},	//   _pasp, ребі, נְךָ_, _उतरे
  { {0x4ea40124,0xc3330008,0x2ea7002b,0x61ed00aa}},	//   бруа, _פופ_, دپری_, _tyal
  { {0xdd940080,0x7afb0026,0x8d77002b,0x7e7d1c72}},	// [30f0] баты, _rhut, دازا, _vasp
  { {0x7afb1350,0x27e00046,0xae01000b,0x91bc000a}},	//   _shut, řiny_, लेषन_, _רמזי
  { {0xda15000d,0xf092000a,0x7f950054,0xbb750054}},	//   адењ, _וני_, _танх, ргеј
  { {0xa3c30089,0x8f9a0135,0xc175000a,0x1b180033}},	//   náší_, _סירי, ֹחַ_, ужцы_
  { {0xd90f002b,0x4af9002b,0xae01000b,0x1a68002b}},	//   سیا_, _یکصد_, लेशन_, طیلی_
  { {0x07a5010f,0x6b8300c0,0xe8f80210,0xa7850015}},	//   иалн, ångs, глі_, لشعو
  { {0x78a10467,0x00580008,0xe6110015,0x96b50054}},	//   _volv, אשות_, يشة_, исиљ
  { {0x46a505c4,0x0f7c000a,0x78a11747,0xb925002b}},	//   раив, תאהב, _wolv, _نفري
  { {0x6d4d1024,0xe919005e,0x6f0f1c73,0x96c40065}},	//   nraa, _розі_, _micc, िफ़ॉ
  { {0x98f70029,0x629d0089,0xa5f60001,0x99d40031}},	//   _إثرا, ejso, шењу_, _اتفا
  { {0xf799002b,0xd3b9005e,0x7ceb0061,0x6c56004f}},	//   _جناب_, тупі_, lürs, ביתא_
  { {0x8b080089,0xd7c80086,0x7cf0079c,0x7989002a}},	//   mořá, _حومه_, tärk, _krew
  { {0x80e60015,0x7ceb0061,0x6d4d1b8e,0xa4d5005e}},	//   لأسل, nürs, jraa, _коді
  { {0x55ba000a,0x6e2d01c2,0x6d4d1c74,0x2a7f0012}},	//   _במנו, ebab, draa, _laub_
  { {0x93880015,0x6f0f02b9,0x2d8f0123,0x6d4d16f3}},	//   _مضيق_, _bicc, ågen_, eraa
  { {0xddc60050,0x6e2d00b6,0x6f0f1c75,0xad260058}},	//   _takż, gbab, _cicc, لرطو
  { {0x3da70063,0xdd920015,0x6281003d,0xbd46002b}},	// [3100] акто_, غوط_, ēlot, شناي
  { {0x6e2d0035,0x8c4601e5,0x913b000a,0x51fb000a}},	//   abab, реже, _שעיק, _בהפצ
  { {0x1ec60015,0x6ecc0061,0xb09b000a,0x8f7602a3}},	//   _نقدّ, aşba, _סיטר, _тупі
  { {0x8b230036,0x79891c76,0x6fdb000a,0x5b13008b}},	//   ідче, _brew, _יקיס, іміт
  { {0x7cf00012,0xb8660015,0x39401c77,0x79891c78}},	//   häri, لاثو, éis_, _crew
  { {0x798910ec,0x4b260015,0x89d70015,0x7cf0008c}},	//   _drew, _نعرف, جوهر_, käri
  { {0xd90d0074,0x27680086,0x6a96005e,0xd6da1b2b}},	//   ریم_, اشتی_, _крає, кти_
  { {0xa5340036,0x2f1c00dc,0xa9260142,0x4b7b0c44}},	//   бнич, _míg_, _вдал, _באלו
  { {0x6f0401b5,0x9f600003,0x7989145d,0x387e002a}},	//   imic, érêt_, _grew, _tatr_
  { {0xd40609ef,0xf8aa000b,0xc977000a,0xcc56000a}},	//   ияни, _कविय, _דגמי_, ׁבִי_
  { {0xdddd0024,0x6f04044c,0x4c3b000a,0x58bb000a}},	//   _pasū, kmic, כתיב, _שמבצ
  { {0x20cd00df,0x3ad1002a,0xd62a05ab,0x26c602f2}},	//   džia_, tąpi_, _роде_, _umoo_
  { {0x6f0f1132,0x6f040d98,0x914b006b,0xd1380004}},	//   _ricc, dmic, ъчна_, ихр_
  { {0x6d4d049c,0x14f30010,0x3d1a000b,0xf1a4005e}},	//   vraa, _дзіў, _बढ़े_, ірян
  { {0x3ec70010,0x13a90086,0x6f0f1c79,0x34fb000a}},	//   асаб, _منوی_, _picc, _שהוד
  { {0x5eb40229,0xa2d50015,0xceb80054,0xd8380046}},	//   ойст, _ديبت, аљу_, _leč_
  { {0xe7ed005d,0xf1a40010,0x6e2d1c7a,0x5d350015}},	// [3110] _चुना_, _дрэн, rbab, صفائ
  { {0xa3cb000b,0x9f41008c,0x0c390015,0x4cb801b0}},	//   _रेड_, _pyhä_, اكاة_, алую_
  { {0x6d4d1c7b,0xdfd10015,0xbb180058,0x0000006a}},	//   sraa, _ريح_, لزنا_,
  { {0x6e9506e4,0x38b90152,0x6d4d0150,0x7e28005e}},	//   _الحا, _mère_, praa, _віра_
  { {0xa9c7000d,0xd8380085,0x200c0046,0xaa580054}},	//   јсек, _beč_, ždit_, ричу_
  { {0x1d160008,0x7ceb0064,0xa3b6000b,0x08c402a3}},	//   _לקשר_, rürs, छना_, обін
  { {0x47380010,0x6e460030,0xe0b8000a,0x0000006a}},	//   ачыў_, _átbö, שלוט_,
  { {0x1a68002b,0x24890061,0x7cf01c7c,0x0682006b}},	//   _نیمی_, _şam_, väri, згън
  { {0xe5710029,0xdb120030,0xe6c40058,0x0000006a}},	//   سطة_, ögöt, تتوي,
  { {0x8b080089,0x7cf01341,0x6f040816,0x67d51c7d}},	//   pořá, täri, zmic, _лозу
  { {0x130a0080,0xc209000a,0x752904ef,0x0000006a}},	//   лной_, _נה_, spez,
  { {0xfbd20008,0x870400ce,0x7cf00072,0x0000006a}},	//   לתי_, _дяче, räri,
  { {0xd4690e88,0x86c40002,0xdce70046,0x2d8f0123}},	//   _биле_, _بينن, íměs, ågel_
  { {0xd7f10092,0x7cf01c7e,0xf3c8002b,0x602307d1}},	//   _kỹ_, päri, ابیه_, здра
  { {0xf4120008,0xe436000a,0x38b90003,0x7f1a0058}},	//   _צפה_, _הרצח_, _gère_, ايرز_
  { {0x1604005d,0xd7f10092,0x93240002,0xe3b0002b}},	//   शेवर_, _mỹ_, _برون, _تره_
  { {0xddea0074,0xd2570008,0xbea305fc,0xa3cb000b}},	// [3120] ارزه_, _השפה_, чатк, _रेत_
  { {0xc5f20135,0xc19b000a,0xdd8f0021,0xeb9a0880}},	//   לדן_, _עשיי, عول_, лиз_
  { {0x7f86003b,0x9f5e00f2,0xd8380d98,0xdb4f0015}},	//   _الجن, ätä_, _reč_, َّم_
  { {0xd8380089,0x93bc0011,0x7cf01c7f,0x60ce0073}},	//   _seč_, mbăt, järv, libm
  { {0xe838005e,0x2fd7002b,0x0000006a,0x0000006a}},	//   аплі_, _نوید_,   ,
  { {0x3ea704f9,0x48e30063,0x49730010,0x52a5000b}},	//   _într_, почв, яліс, _ऑक्स
  { {0xd8380e6d,0xf1bf0014,0x07a300d7,0x6d5611ac}},	//   _več_, zzá_, зајн, luya
  { {0xc6f80001,0xa6aa00a2,0xcf93000a,0x7c3e0980}},	//   јних_, طابق_, לטו_, lapr
  { {0x54b801b7,0xe8fa0e16,0xe9da1c80,0x0000006a}},	//   игия_, _бла_, _ска_,
  { {0x38b9038d,0xb8660087,0x44380f45,0xdd7b000a}},	//   _père_, _دارو, úr_, נטיל
  { {0xd2510074,0x7e76002e,0x25bf0045,0x7aed0045}},	//   وند_, keyp, azul_, _întî
  { {0x6d5600b6,0x3f85002e,0x7bdb000a,0xddcd0045}},	//   kuya, ælum_, רקטו, neaţ
  { {0x9c83018c,0x68ea0111,0x7cf000b8,0x41e70010}},	//   ščit, oofd, läru, сіна
  { {0x9a290016,0x661d006f,0xdb0d006f,0x5577000a}},	//   _mươi_, ľske, ľkém, _לעדן_
  { {0xbcfb038d,0xaab8005d,0x443e1ba0,0x2d8b0263}},	//   _opér, _आतंक, mat_, _srce_
  { {0xff07022a,0x62670015,0x38ab0723,0x443e1c81}},	//   сягн, _طابق, _hørt_, lat_
  { {0xf2d40053,0x443e00da,0x9c390054,0x38ab02de}},	// [3130] _מעק_, oat_, ипат_, _kørt_
  { {0x6ef30064,0x251b000a,0x645a1c82,0x7055006e}},	//   içbi, טומא, ngti, _بندا
  { {0x443e0011,0x645a02de,0xea191977,0x0000006a}},	//   iat_, igti, ажеш_,
  { {0x6008000a,0x443e1c83,0xda65005e,0x7c3e0535}},	//   _לִרְ, hat_, івли, aapr
  { {0xd9450080,0x443e1c84,0xddcd002a,0x7cf01c85}},	//   цели, kat_, ndaż, värv
  { {0x0f8b000a,0xdcb10016,0xa7a91c86,0x6b82002a}},	//   ָאֵ֑, _ổ_, икла_, łoga
  { {0x3eb9002e,0x905c000a,0xccf2039e,0x443e1c87}},	//   _klst_, אכות, _חכם_, dat_
  { {0x443e06f8,0x224901d7,0x854909c2,0xf6510015}},	//   eat_, _ndak_, азив_, ذئب_
  { {0x443e1c88,0x3940001a,0x93bc0045,0x05760058}},	//   fat_, áist_, zbăt, قمية_
  { {0xe4c50191,0x20cd00df,0x25ad0064,0xf20c000b}},	//   ійни, džio_, ryel_, सेफ़_
  { {0x7cf000f2,0xf3f10015,0x7aeb0079,0xdc8c000a}},	//   märt, بأة_, oogt, רְחָ
  { {0xae09005d,0xf770012c,0x645a1c89,0x7cf00dca}},	//   वधान_, _سام_, agti, lärt
  { {0x06980029,0x3f450024,0x443e1c8a,0x672d0085}},	//   _دخلت_, eķu_, bat_, ćaju
  { {0xbf02005d,0x6b6c0024,0x443e1c8b,0x85050015}},	//   लग्न_, lēgš, cat_, _بوتن
  { {0x6d4b002d,0xa35d0033,0xbe3a005e,0xc2c60015}},	//   ágan, _рэлi, ичаї_, _ويتي
  { {0x93bc0011,0xb1e60015,0xddd60033,0xa91d0091}},	//   rbăt, _وأظه, оўзэ, _erži
  { {0x6296025c,0x27e001e2,0xe0da0121,0xed5a1c8c}},	// [3140] _inyo, ğini_, _ввп_, роз_
  { {0x93bc04f9,0x62860005,0x6284003f,0x27e01c8d}},	//   mbăr, ldko, _haio, şini_
  { {0x6f660015,0x7aeb0030,0x7c3e13dd,0xbea60b27}},	//   _بهجم, fogt, rapr, _данк
  { {0x6d560003,0x443e1c8e,0xed5a01dc,0xd83800bc}},	//   puya, zat_, _ком_, _točk_
  { {0x628403af,0x6296000c,0x7c3e1c46,0x88e609ef}},	//   _maio, _mnyo, papr, ожде
  { {0xf1b30008,0xc8660036,0xed43017f,0x443e1b9e}},	//   וסד_, ітли, _інсп, xat_
  { {0x501b013a,0x38cb0086,0x9949005c,0x6d441c8f}},	//   בוצו, جانی_, góły_, lsia
  { {0x356a008f,0xd83800bd,0x7c3c1c90,0x2907003f}},	//   арон_, _moči_, _herr, amna_
  { {0x443e1c91,0x7c3c1c92,0xd83800bc,0xa8030030}},	//   tat_, _kerr, _loči_, óűrl
  { {0xc9d50086,0x6296043a,0x6d441c93,0x7c3c1c94}},	//   _عملک, _anyo, isia, _jerr
  { {0x6d4400d9,0x5f1a000b,0x3c77000a,0xe853002b}},	//   hsia, _मूल्_, חתים_, _زنند
  { {0x6b830134,0x672d016f,0x6d44137f,0x2007006f}},	//   ængi, ćajt, ksia, _únii_
  { {0x56d90053,0xd251002b,0xc4c60015,0x443e0337}},	//   _פֿעד, ونگ_, _وتتو, pat_
  { {0x84380029,0x6e241c95,0xc953000a,0x3e750016}},	//   _اكثر_, ecib, ומש_, _ất_
  { {0x22560089,0x6d460b56,0xa2e70015,0x92f70015}},	//   ácké_, _avka, _وأبن, _وأعض
  { {0x3f450024,0x1ee70086,0x443c1c96,0x6284059d}},	//   rķu_, آوری_, _hev_, _gaio
  { {0x54fe005d,0xa91d1c97,0x8d770015,0x7d55006b}},	// [3150] _उठाए_, _trži, غارا, явах
  { {0xf1a40010,0x443c0820,0x80a40015,0x7c3c1c98}},	//   _ірын, _jev_, _يمين, _cerr
  { {0x69c20111,0x7aeb00dd,0x307a000a,0xa088000a}},	//   ezoe, togt, _האתנ, _וְרִ
  { {0x0f7a00b2,0x70550086,0x7cf00b1c,0x539b05bd}},	//   _פארב, _بنگا, färs, יסבא
  { {0x99d40086,0x7c3c1c99,0x6b8e0012,0xfc330015}},	//   وتها, _ferr, _erbg, _يحس_
  { {0x017c0008,0x88c80036,0x917c000a,0x817c000a}},	//   שָׁל, олів_, שְׁח, שְׁק
  { {0xe739005f,0xdb230086,0xda35054f,0x1b780015}},	//   щей_, _آوری, _невы, _وصفة_
  { {0x7c3c0359,0x66de003d,0x7d1d1c9a,0x7c251c9b}},	//   _zerr, tīka, _kuss, lchr
  { {0x7cf000f2,0xa43d022a,0x765b0061,0xf1bf0030}},	//   märr, льнi, rguy, ibás_
  { {0x6aa90111,0x7d1d1c9c,0x20cd0247,0x64990de9}},	//   _hoef, _muss, užil_, стир_
  { {0xa3b90029,0xec36000a,0x6e3d042f,0x6d441c9d}},	//   صادر_, האתר_, _oesb, zsia
  { {0xe0c90053,0x6d441c9e,0x7c250125,0xd7fa000a}},	//   _גײ_, ysia, hchr, _ההעל
  { {0x361a0135,0xa5f80054,0x443c134b,0xa022007c}},	//   _הונד, _децу_, _fev_, _öökl
  { {0x54680010,0xa06a0001,0xd5d40015,0x93bc0045}},	//   _маім_, љава_, _تتمث, rbăr
  { {0xdfd2003b,0x7d1d1c9f,0x7e6f1ca0,0xdff5005e}},	//   رير_, _auss, _bbcp, дять
  { {0x6d440005,0x7d150048,0xd00f0029,0x7b030020}},	//   tsia, _aizs, طلق_, nõud
  { {0x6d441ca1,0xee370010,0xb2bb000a,0x81460015}},	// [3160] usia, янт_, _למקר, _عندن
  { {0xfb1a0015,0xcea9004c,0x22421ca2,0x6d440faa}},	//   مقطع_, װי_, lakk_, rsia
  { {0x7d1d0152,0x6441003f,0x207b01ac,0x6d441ca3}},	//   _euss, iali, _פאטא, ssia
  { {0x7b030020,0x64411ca4,0x69c20079,0x6b82002a}},	//   jõud, hali, tzoe, łogo
  { {0x44270026,0x64411ca5,0x7d1d01f1,0x7c3c1ca6}},	//   _ofn_, kali, _guss, _terr
  { {0x69c20298,0x64411ca7,0x6f1e1981,0x2d821ca8}},	//   rzoe, jali, _kupc, _iske_
  { {0xf093013a,0xa3cb005d,0x69c20111,0x443c1ca9}},	//   תנו_, _रेल_, szoe, _rev_
  { {0x2608005d,0x7bdb000a,0x443c003d,0x4427001a}},	//   ाइली_, _הקלו, _sev_, _afn_
  { {0x7ae31714,0x7eb80046,0x64411caa,0xa3e40065}},	//   énte, _lípo, fali, _भुज_
  { {0xe56f0029,0xa9bb000a,0xd49a045f,0x64411cab}},	//   اطي_, _הזמר, сри_, gali
  { {0x99840007,0xa2790432,0x38ab00cb,0x988b000a}},	//   _temų_, обну_, _tørr_, _לָאֵ
  { {0x32670080,0x64411cac,0xabfb000a,0x9258004a}},	//   чтов, aali, מהיר, пают_
  { {0x443c0024,0x644114cd,0x7c251cad,0xc1eb0033}},	//   _tev_, bali, ychr, сьне_
  { {0x64a3008f,0xf1b00015,0x20cd0046,0x39461cae}},	//   _пача, اءَ_, mžik_, isos_
  { {0xb4fb0008,0x34fb039e,0xcebb0054,0xd36f005e}},	//   _הפגי, _ההגד, бља_, _яч_
  { {0x33db000a,0xdd950033,0xf2070033,0x67270030}},	//   _לחוד, мабы, _няпо, _éjje
  { {0x7b030020,0x9d1500fd,0x7693002a,0x3d170065}},	// [3170] nõue, ддач, _użył, _भूखे_
  { {0x91bc0008,0xc1bc0008,0xad9b0077,0xa41c0065}},	//   _למחי, _למחש, _azúc, नशिप_
  { {0x7d1500dc,0xab950021,0x7d1d0012,0xd437000a}},	//   _vizs, بلاغ, _wuss, פטאי_
  { {0xc3330008,0x7c2517e7,0x7d1d00f6,0xf8ae0086}},	//   תוף_, schr, _tuss, یکل_
  { {0x7b03007c,0x64411caf,0x6934008b,0xa924005e}},	//   jõue, yali, енчу, еділ
  { {0xec290029,0x4dd40015,0x6d9a000a,0x7c8400af}},	//   _ذكرى_, _ستُس, _ובשפ, _пусе
  { {0x238c0089,0x64411cb0,0x7cf00123,0x98a2024f}},	//   _něj_, vali, pärr, тище
  { {0xa5620086,0x2007006f,0x64411cb1,0x57a40138}},	//   چگون, _úniu_, wali, эшча
  { {0xc6480029,0xa5620086,0x26c30007,0x15090015}},	//   سجيل_, نگون, ėjo_, يْبٍ_
  { {0x98db0015,0xf3490663,0xa91d1cb2,0x64411cb3}},	//   _ابرز_, опол_, _držt, uali
  { {0x61f6008c,0x96eb004a,0x64411cb4,0x0000006a}},	//   _syyl, _льда_, rali,
  { {0xc0490dab,0x216a0080,0x80d0005d,0x35b50511}},	//   _כז_, оими_, डोने, _обер
  { {0xf6520008,0x21a30080,0xa1930033,0x64411cb5}},	//   _יצא_, виям, ваўч, pali
  { {0x3cf9005d,0x6ada0065,0x0000006a,0x0000006a}},	//   ्गों_, _भद्र,   ,
  { {0x291f0020,0x93bc0045,0x65690980,0x2496002b}},	//   _luua_, ncăl, lteh, _زنيد_
  { {0x61f600f2,0x0000006a,0x0000006a,0x0000006a}},	//   _tyyl,   ,   ,
  { {0x8d660010,0x4d660033,0xdd9200c3,0xad650015}},	// [3180] ьвае, ькав, خوذ_, فاله
  { {0x315700b2,0xec7707f8,0x718b004f,0x0000006a}},	//   _קיין_, мпу_, _וְטַ,
  { {0x309b0008,0xa09b0008,0xb09b000a,0x9a860888}},	//   _ושימ, _וייט, _וייר, дулл
  { {0x212001c2,0xa3d40065,0x2b4700d4,0x0000006a}},	//   _kuih_, _सेफ_, ânca_,
  { {0x397a04c9,0x59370010,0x39460007,0xa3d4000b}},	//   تصاد_, дзіў_, usos_, _सेन_
  { {0x7f5c0003,0xf77200c3,0x3a261cb6,0x39460583}},	//   ourq, ناع_, scop_, rsos_
  { {0x39460e2c,0xd7ef0a61,0xdce40263,0x8b230033}},	//   ssos_, ту_, ntič, _адсе
  { {0x38c80086,0x66de0024,0x2d801cb7,0x66e30004}},	//   _کاری_, rīko, owie_, која
  { {0xe5c60080,0xe4e60036,0x656900dc,0x786609ef}},	//   ьско, дінн, gteh, _оказ
  { {0x80d0000b,0xdce41c97,0x0000006a,0x0000006a}},	//   डोमे, ktič,   ,
  { {0xe2f90210,0x2ca7007c,0xb865012c,0x03c70033}},	//   зені_, öndi_, _سالو, дыяй_
  { {0x9294008f,0xe6930029,0x7b03007c,0xb7d70015}},	//   ваюц, _للمد, põue, _توما_
  { {0xf5b60074,0x54a60029,0xf1b90227,0x4255002b}},	//   _تصاد, _يحتف, áš_, ونگر
  { {0xfd4f0092,0x2d80005c,0xb75a0016,0x45fb000a}},	//   _triế, dwie_, _ngừơ, _והדג
  { {0xc5880023,0x46b2000b,0xf203000b,0x73c30015}},	//   _hồ_, _जवाह, रेज़_, _ليوم
  { {0x38690085,0xe502000b,0xe731000a,0x0000006a}},	//   đari_, _रीति_, רֵם_,
  { {0x7cf00dca,0x2d801cb8,0x0000006a,0x0000006a}},	// [3190] tärp, gwie_,   ,
  { {0xc5880016,0x387c0160,0x0000006a,0x0000006a}},	//   _mồ_, jevr_,   ,
  { {0xf42900f2,0x66de0024,0xc5880092,0x50d400e5}},	//   lkää_, tīkl, _lồ_, _جزير
  { {0x527c0053,0x0dcb0e41,0x60d51cb9,0xca490058}},	//   ַנוא, _дуги_, lizm, سلته_
  { {0x5e560135,0x39490c24,0x6f0d0ccc,0x0000006a}},	//   _אירע_, éas_, mmac,
  { {0x80a2005d,0xb066008c,0xbd02006f,0x6b8302de}},	//   खाये, _ikää, žéro, ængs
  { {0x66020014,0x7ceb00b8,0xb8920015,0xaa670674}},	//   _azok, kürz, طليع, _отак
  { {0x291f0020,0xc5880092,0xe70800e6,0x9733002b}},	//   _tuua_, _bồ_, وتين_, _یکبا
  { {0x98751155,0xe576004a,0x93bc0045,0x7888003d}},	//   _плац, езы_, scăl, _būvē
  { {0x6f0d00b8,0xcdf8000a,0x8c19000a,0xdce70091}},	//   hmac, ומחי_, ּוֹי, ėmėt
  { {0xccf20008,0x2d80005c,0x93450010,0x6f0d1cba}},	//   רכי_, zwie_, энне, kmac
  { {0x87b60053,0x127a0015,0xe7b6004c,0x60d51253}},	//   _אלעס_, أحدث_, _אהער_, eizm
  { {0x463a00b2,0x30760036,0xa484002b,0xf1bf0125}},	//   _זענע, нувс, رجین, scán_
  { {0x73e5010f,0x30750080,0x672100f2,0x6f0d1cbb}},	//   _полз, кусс, _kulj, emac
  { {0xf852002c,0xf8ad0092,0x7fd5005e,0xe3b30015}},	//   ížiť_, _đợi_, віті, _جرش_
  { {0x2d80005c,0x67210abb,0xdea1002b,0x386501d7}},	//   twie_, _mulj, لیپی, _lclr_
  { {0x82770053,0xdce41cbc,0xf3890016,0x0ef90033}},	// [31a0] _טעקע_, stič, _hả_, фэры_
  { {0x6c860029,0x9f8602e5,0x2d80002a,0xef8601b7}},	//   علام, _згод, rwie_, _злоп
  { {0x103b0008,0x9b8a0015,0x6e460fbd,0x26df0085}},	//   _מגיע, ثنال_, _пенз, knuo_
  { {0xceb60015,0x6da60aed,0xcf93000a,0xca0a0923}},	//   _أحدث, _зима, _עטר_, пнеж_
  { {0xd6d00086,0x7ae30077,0xda650058,0x2d8f0ee6}},	//   یقت_, énta, ضاني, åget_
  { {0x98a30df0,0xc5880016,0x6c36012c,0x67210160}},	//   личе, _rồ_, _سفرا, _bulj
  { {0x660200dc,0xfce30fe4,0x7c3f0030,0x0000006a}},	//   _szok, _соро, özrő,
  { {0x6721016f,0xeb97000a,0x26df0085,0x6f7b004f}},	//   _dulj, _אדלר_, gnuo_, לְחו
  { {0xfcaa004f,0x0000006a,0x0000006a,0x0000006a}},	//   ִיֹּ,   ,   ,
  { {0x07a6008f,0x6d4b00dc,0x7ceb0012,0x6f0d1cbd}},	//   _пазн, ágai, würz, zmac
  { {0xf3890023,0x6f0d06bd,0x92591cbe,0x7ceb0012}},	//   _cả_, ymac, мант_, türz
  { {0xf7730008,0x9f5e006f,0xf429008c,0x51870054}},	//   _תקף_, ätý_, tkää_, нуга
  { {0x3d1f000b,0xc1b80b9b,0x60d51cbf,0x7b030072}},	//   _बढें_, елях_, tizm, nõua
  { {0x13f40063,0x645c016e,0x859b004f,0xddc60535}},	//   _изля, órid, _משדו, _odkł
  { {0xcebb0054,0x6f0d1cc0,0xaf070cfe,0x60d51cc1}},	//   пља_, tmac, ечак, rizm
  { {0x7982002a,0x1dc50015,0xb2a70015,0x33fb004f}},	//   kwow, نْزِ, _سحبه, _מהונ
  { {0x9883002c,0x75220007,0x6f0d1cc2,0x752b000a}},	// [31b0] víľu_, _juoz, rmac, ּֽמַ
  { {0x658f0030,0x9c8200bc,0xf531000a,0x7e660012}},	//   lőhö, ščne, ׁ֥ב_, _eckp
  { {0xc4d300b2,0xf3890016,0x1cb80015,0x9c640058}},	//   נגע_, _xả_, راكب_, اهمو
  { {0x59d2000b,0x0a150015,0x2d8f02de,0xd35b004f}},	//   _देहर, نواح, åges_, לדבל
  { {0x672100f2,0x41b3000b,0x3ea9003d,0xd91b004a}},	//   _sulj, ुनिस, mjat_, чье_
  { {0x9dd60008,0xdb230086,0xed56000a,0x67211cc3}},	//   _יורק_, _موسی, _בבשר_, _pulj
  { {0xfecb0008,0x07a50afb,0x2ca7001a,0xc7a5006b}},	//   ּמִּ, тайн, öndu_, тийк
  { {0x3ea91cc4,0xf3890016,0x59d20065,0xcf94004f}},	//   njat_, _rả_, _देवर, רטק_
  { {0xceb40632,0x3ea9008c,0xf509033d,0x39151cc5}},	//   טיק_, ijat_, мнил_, _амар
  { {0x66e80046,0x3ea901be,0x26df0085,0x394d01f9}},	//   věke, hjat_, snuo_, _ives_
  { {0xa3cb005d,0xed600046,0x0000006a,0x0000006a}},	//   _रेख_, ěžit_,   ,
  { {0xe2970418,0x07080015,0xf3890016,0x6d5f00aa}},	//   ваю_, _كيلي_, _vả_, kuqa
  { {0xcb1200b2,0x20d60191,0xf486002b,0xd12f0015}},	//   ילט_, вівс, رایی, يمَ_
  { {0xf3890023,0x09b6000a,0x3e7c0016,0x0000006a}},	//   _tả_, דפשט_, _ật_,
  { {0xddca005c,0x10a312fd,0x5043009b,0x64431cc6}},	//   łoży, ширн, ресб, _ieni
  { {0x20cd0007,0x7982005c,0x236a0046,0xdc34006f}},	//   džiu_, ywow, žijí_, rúčk
  { {0xe0d20086,0xfc320029,0xa7fc0061,0x64431cc7}},	// [31c0] _نزد_, لحا_, _acıl, _keni
  { {0x3ea900f2,0x64431cc8,0xccc30033,0x8e0700ce}},	//   ajat_, _jeni, абуй, тнув_
  { {0x2d8f0134,0x90e50087,0xaa46029f,0x539a000a}},	//   åger_, _حسين, веел, ֽינו
  { {0x7982005c,0x6249000a,0xdb210030,0xda77006b}},	//   twow, ֲנוּ_, átás, вяш_
  { {0x3eab0227,0xf2d3004c,0xfe37000a,0x64430773}},	//   žitá_, סעד_, _ברכי_, _oeni
  { {0x7982005c,0x658f0030,0xfce619cc,0x0000006a}},	//   rwow, zőhö, _рого,
  { {0xcc77000a,0xc8b50033,0xf6e61cc9,0x36d406da}},	//   _שעלה_, ысцы, кцин, локр
  { {0xd6d7044e,0x88bd002a,0x7b03007c,0x9633006b}},	//   кты_, _puśc, lõun, анъц
  { {0xb5a30010,0xc9661301,0xa96a012c,0x64431cca}},	//   арэй, _швай, _زمام_, _beni
  { {0xe7ed005d,0x7ae2005c,0xd90e0086,0x89f50033}},	//   _चुका_, lnot, _بیت_, _сясц
  { {0x9f4f0064,0x644314a0,0xfc5b000a,0x645c0144}},	//   ünüz_, _deni, וכימ, òriq
  { {0xa1590010,0x41e70127,0x6443016b,0xf7490015}},	//   наму_, віга, _eeni, _أجله_
  { {0xb3560074,0x64431ccb,0x7ae21ccc,0x0000006a}},	//   ریکا_, _feni, inot,
  { {0x64431ccd,0x33940021,0x7ae20125,0x3cec000b}},	//   _geni, _ملتز, hnot, जकों_
  { {0x3ea90acf,0x251b00a3,0x351b000a,0xdfd8006b}},	//   tjat_, _קווא, _קוונ, вът_
  { {0xaf340086,0xff070036,0x6e22006f,0x3ea9003d}},	//   شرفت, тягн, žobn, ujat_
  { {0x644301e2,0x7d1c002e,0x7ae20107,0x3ea91897}},	// [31d0] _yeni, _birs, dnot, rjat_
  { {0x3e530023,0xdcf90029,0x64481915,0x27e90045}},	//   ệt_, رفات_, nadi, şani_
  { {0xaa950036,0xd5d9005d,0xfc3000e6,0x51f4002b}},	//   лижч, _बेनज, تحق_, _مسیر
  { {0x2bc2000b,0x628f1cce,0x64481ccf,0x7ae21cd0}},	//   वैधा, ndco, hadi, gnot
  { {0x7d1c003e,0x79a70063,0xd5a60087,0x628d0e95}},	//   _firs, ърже, _اف_, _maao
  { {0x7ae2022d,0x961d0024,0x91bc0008,0x7c341cd1}},	//   anot, ieņe, ומדי, _верх
  { {0xccf20008,0x9848005e,0xab8402a3,0x6d4d1cd2}},	//   _לכך_, тяча_, _кутк, lsaa
  { {0xb5fd0024,0x645d0007,0x6e2d1689,0x6d4b0091}},	//   egša, ėsim, ncab, šgau
  { {0x6d4d014a,0xceb4004c,0x6f1d1cd3,0x64481cd4}},	//   nsaa, שיפ_, _misc, fadi
  { {0xf7700086,0xa7870015,0x6f1d1cd5,0x15090015}},	//   _ژان_, _لشؤو, _lisc, عْدٍ_
  { {0x64431cd6,0x628f0079,0x47350e4d,0x69cb0012}},	//   _veni, fdco, _снес, lzge
  { {0x6443018b,0x68ed002d,0x6d4d1cd7,0x64480bb5}},	//   _weni, éadf, ksaa, aadi
  { {0x6448000c,0x644316d1,0x645c047e,0x2d87002a}},	//   badi, _teni, óric, łnej_
  { {0x6f1d002f,0xd6d9005c,0x6d4d00dd,0xa3d4000b}},	//   _aisc, lił_, dsaa, _सेव_
  { {0xd36e0029,0x6f1d1cd8,0x68e30e05,0x1fb51cd9}},	//   _فهو_, _bisc, innd, астр
  { {0xdfcf0029,0xd6d9005c,0x6d4d00dd,0x1eaa0015}},	//   سيق_, nił_, fsaa, رازي_
  { {0xed570083,0xd83e0091,0x91db000b,0xddcd0061}},	// [31e0] лот_, ščia_, _पेपै, rgaş
  { {0x20cd0089,0x621b000a,0xcc8a0015,0x6f1d1cda}},	//   užit_, _אופק, عناه_, _eisc
  { {0x7d1c1cdb,0xad9b0077,0x7ae21cdc,0x6d4d1cdd}},	//   _virs, _ayúd, tnot, asaa
  { {0x6d260029,0xeafa0087,0x7ae21cde,0x2c0b002b}},	//   _معسك, ررات_, unot, رعلی_
  { {0x99dd002c,0x7ae21cdf,0x2d840003,0x42db004c}},	//   _peňa, rnot, _ème_, עקנע
  { {0xc173000a,0x2cb100bc,0x7ae21ce0,0x6f1d0012}},	//   צחו_, _gozd_, snot, _zisc
  { {0x64481ce1,0x9cd7039e,0xf76f0015,0xd6d9002a}},	//   vadi, _עולה_, كاي_, fił_
  { {0x65aa0001,0xe6661ce2,0xb60500bc,0x64480017}},	//   етог_, утко, _oišč, wadi
  { {0xceb3000f,0x7b06003d,0x64481ce3,0x35b3006b}},	//   מיה_, ārtē, tadi, йбър
  { {0x3a09002b,0x297b004c,0xb97b000a,0x24180088}},	//   _شکنی_, _אטמא, _אנמי, копы_
  { {0xd6d9005c,0x442e0012,0x64481ce4,0xf7720015}},	//   bił_, _vff_, radi, _داء_
  { {0xd6d9005c,0xfbd3000a,0xe215004a,0x7b03007c}},	//   cił_, מתת_, имны, jõul
  { {0x59c4005d,0x291e013c,0x1677000a,0x914b0033}},	//   वनिर, _kita_, _תגדל_, эчна_
  { {0x361b000a,0xf1c200bc,0x43940923,0x6b6901ec}},	//   _נוגד, dišč_, _вакс, lūgš
  { {0x14d71ce5,0x889b0053,0x291e1ce6,0x226a008c}},	//   _גוגל_, עבלי, _mita_, ätkö_
  { {0x1e35008f,0xc7d7000a,0x63b5006f,0x6d4d1ce7}},	//   рнаў, אולי_, äzne, tsaa
  { {0xe9050023,0x2d580a61,0x63ba02de,0x6f1d1139}},	// [31f0] _lượ, лить_, lytn, _visc
  { {0x0f350086,0xd6d9005c,0xc174000a,0x5fd6000b}},	//   _نکرد, ził_, _החץ_, _डेवल
  { {0x6f1d020d,0x711a039e,0x6d4d0044,0xbc0703ad}},	//   _tisc, _שותפ, ssaa, учай
  { {0x7b740029,0x6f1d002d,0x4fd60008,0xdb12002e}},	//   إطلا, _uisc, _כותב_, ægðu
  { {0x18691ce8,0x291e1ce9,0x0000006a,0x0000006a}},	//   вали_, _bita_,   ,
  { {0xd6d9005c,0x63ba0227,0x28d0000b,0x2d990077}},	//   wił_, kytn, थोलि, _irse_
  { {0xa3d4000b,0xab89000a,0x7cf0008c,0x291e1cea}},	//   _सेल_, _בָּ֖, järy, _dita_
  { {0x47d200e6,0x2b5c0046,0xe9050016,0x0f58000a}},	//   غيير, ávce_, _dượ, איהם_
  { {0x7afb0375,0xd6ce0015,0xe4810033,0xa6e20033}},	//   _ikut, بقي_, ошнi_, ўжыл
  { {0xd6d9005c,0xa5090001,0x14c7002b,0x67d5070c}},	//   sił_, ђена_, اهدی_, _козу
  { {0xd6d9005c,0x645c1ceb,0x889a000a,0xf1a9000a}},	//   pił_, ória, _שבעי, _קס_
  { {0x95d90080,0x8c1a0008,0x291e1cec,0xe610002b}},	//   _идет_, כותי, _zita_, _کشم_
  { {0x2611005d,0x64a51ced,0x66ba000a,0x3e86002b}},	//   देशी_, _вала, _שמנה, یشرف
  { {0x7ae9016f,0x6575002c,0x455a000a,0x6ac2000b}},	//   _ljet, ľahč, _יכנס, _शत्र
  { {0x61ed0aff,0x224b1cee,0x7afb1cef,0x2d9900d4}},	//   _exal, back_, _okut, _arse_
  { {0xf1c200bd,0x5de60254,0xc7b2000a,0xcf250015}},	//   tišč_, ажба, חבל_, صرفي
  { {0xf8c5005d,0xfe43005e,0x42fb000a,0x3d28002b}},	// [3200] वसाय, інфо, _שהפס, اتری_
  { {0x3b960001,0xc19b0008,0xe50b000b,0x8b960fea}},	//   ијет, _ישפי, _सीमि_, иреч
  { {0x60dc0035,0x0b1a0015,0x2d8b02b9,0x0c790033}},	//   mirm, نقطة_, _esce_, ысты_
  { {0x291e1cf0,0x60dc0061,0x7eb80052,0x0000006a}},	//   _sita_, lirm, _pípu,
  { {0xed570063,0x7ae90085,0x63ba002a,0x60dc0125}},	//   _коя_, _djet, zytn, oirm
  { {0xd8f70191,0xf7540029,0xd7fa0010,0x2a660026}},	//   анії_, منتج, куй_, sgob_
  { {0x291e1cf1,0x60dc007c,0x69d60065,0x0000006a}},	//   _vita_, iirm, _मेरी,
  { {0x7eb80014,0xe9050092,0x60dc00b8,0x6009000a}},	//   _típu, _vượ, hirm, נִסְ
  { {0x7c290064,0x96b70001,0xe4a61cf2,0x74a601ca}},	//   _şeri, рују_, арно, ајне
  { {0xe9050092,0x291e0045,0xcd77004c,0x7cf0008c}},	//   _tượ, _uita_, סעיק_, täry
  { {0x224b003e,0x15170015,0x92951cf3,0x60dc1cf4}},	//   tack_, جزية_, банц, dirm
  { {0x81c30024,0x56930036,0xb7db0008,0x2b470045}},	//   ņēmi, _маєт, _בקבי, ânci_
  { {0xd5340086,0x20b4000b,0x86f5002b,0xddcd0045}},	//   _افتخ, ुसंध, _اينچ, ifaţ
  { {0xd59b0008,0x55bb0008,0x33980021,0x66e1003d}},	//   _שבגל, _במדו, _منتج_, vēki
  { {0x23271cf5,0xd43700b2,0x61140036,0x5457000a}},	//   _који_, _דרוק_, ідсу, _כסגן_
  { {0x443e0012,0x877b004f,0x33fb004f,0x0000006a}},	//   lbt_, כאלי, _שההנ,
  { {0x5d990010,0x32090061,0xfd470033,0x6bd9009a}},	// [3210] ыкаў_, _uzay_, рэбн, گواس_
  { {0xf537000a,0x81fc000a,0x7afb1cf6,0xc172000a}},	//   ינמי_, _בהחז, _skut, _צחי_
  { {0x443e018b,0xbb840015,0x3b67009b,0x68f80160}},	//   ibt_, يلكي, ръзв, dovd
  { {0x8f9a0008,0x4ae40033,0xedd5002b,0x66e80046}},	//   _עירי, оўча, _هيجد, děko
  { {0xe9f80036,0x7ae91cf7,0x9f5e008c,0xa825002b}},	//   анці_, _vjet, ätö_, مکان
  { {0x6728022d,0xe8f802e5,0x3158000a,0x224900da}},	//   _budj, алі_, שיגן_, _leak_
  { {0xe7680029,0x7b030020,0x90580008,0xa3c8000b}},	//   لحين_, nõuk, בסוף_, लैम_
  { {0x7afb0297,0x443e1cf8,0x7ae900bc,0x645c001a}},	//   _ukut, ebt_, _ujet, órin
  { {0x2eaa0053,0xb93405e6,0x25a90015,0x9984012c}},	//   רשפּ, _метј, ادعي_, _ولفو
  { {0x442302de,0x7b2c0061,0xc8b40015,0x0000006a}},	//   øj_, _oğul, _وإلغ,
  { {0x83a80029,0x60dc0064,0xdc88000f,0x80ab000b}},	//   لاَّ_, virm, בְרָ, ञाने
  { {0x1b7a0053,0x21290509,0x8bd6000a,0x4b7a004c}},	//   נטרע, _buah_, מותו_, נטרג
  { {0xd36e0086,0x443e00c0,0xe3b10086,0x60dc1cf9}},	//   وهی_, bbt_, زرگ_, tirm
  { {0xf5560015,0x25c90061,0x2d9e0046,0x505900ce}},	//   _الوب_, ıtlı_, _čte_, ишся_
  { {0xf4d40015,0xbea60658,0x60dc001a,0x66de1cfa}},	//   _بتنظ, бавк, rirm, cīks
  { {0x93bc0045,0x42560015,0xc2460734,0xee260138}},	//   rcăt, _انظر, _уник, смап
  { {0x62861cfb,0x93bc0045,0x60dc1cfc,0xecea0033}},	// [3220] meko, scăt, pirm, гдал_
  { {0x3086003b,0x6c4a0015,0x20860015,0x0ffa0015}},	//   _الدف, الاف_, _الدّ, _معجب_
  { {0x2029002c,0x62860161,0x93bc0045,0x05d9000b}},	//   átiť_, oeko, lcăr, _बेसब
  { {0xc332000a,0xda660015,0x0a160015,0x24851cfd}},	//   פוד_, صاصي, موضح, helm_
  { {0x38cb0074,0x6f0400b8,0x6728016f,0x59d2005d}},	//   گانی_, mlic, _sudj, _देखर
  { {0x62860e95,0x99470015,0x6f041cfe,0x7c2900d4}},	//   heko, حلول_, llic, _şerv
  { {0x38cb0086,0x35d0005d,0x62860544,0xa09b000f}},	//   دانی_, _तेज़, keko, טיסט
  { {0x6f04018b,0x62861cff,0x9f5f0003,0x25700144}},	//   nlic, jeko, érée_, tàl_
  { {0x7abb000a,0xd943070c,0x44a60015,0x6f041d00}},	//   _עצמו, _нети, محدّ, ilic
  { {0x67280014,0xa4d40036,0x6f041d01,0x443e00b8}},	//   _tudj, іоні, hlic, ubt_
  { {0x2249003e,0x443e00b8,0x6f041d02,0x3cfb00a3}},	//   _peak_, rbt_, klic, רלינ
  { {0xd5a40086,0xbc1b0053,0x8c1b0008,0xe2f90036}},	//   _ولای, טויש, טויי, ремі_
  { {0xc05b0191,0x6f041d03,0x7ae30077,0x316b004a}},	//   лів_, dlic, énti, ышно_
  { {0xf6170008,0x2249003e,0x241801b0,0x44f300e2}},	//   _החדש_, _weak_, _колы_, _епіс
  { {0xc1040029,0xf4870086,0x6f041d04,0xcfa4049d}},	//   سوفي, _دانی, flic, пшти
  { {0x6f041d05,0x212900d9,0x644a1d06,0xceb80054}},	//   glic, _tuah_, _hefi, бљу_
  { {0x5274002b,0x569b0643,0x226401c0,0x6b9c1d07}},	// [3230] _رايز, נימצ, šské_, _arrg
  { {0xf537000a,0xddd00045,0x0ba7004a,0x6f161d08}},	//   צטבר_, ţeşt, йшем, amyc
  { {0x9be40010,0xbab5004a,0xd47b004c,0xebd90004}},	//   піцк, жёлы, ראבל, јдеш_
  { {0x220b000a,0x99991528,0x539b000a,0x644a082b}},	//   ְפַּ, икет_, טיבו, _lefi
  { {0x64580796,0xd8251d09,0xda7801c5,0x7af900da}},	//   _odvi, одли, сях_, rowt
  { {0x4759010f,0x6286005c,0x98a20254,0x5f74002b}},	//   ария_, zeko, дише, _بایر
  { {0xe739005f,0x7af9005c,0x98f40015,0x16a90189}},	//   шей_, powt, أثنا, ивки_
  { {0x2ee90026,0x8579000d,0xb9e70036,0x64581d0a}},	//   nnaf_, асот_, _лізи, _advi
  { {0xfe380008,0xb883002c,0x644a1d0b,0x785b003d}},	//   זרחי_, _príč, _befi, tāvē
  { {0xd87700a2,0x189b0015,0x6f041d0c,0x644a0034}},	//   _دارب, _حضرة_, zlic, _cefi
  { {0xc2090008,0xdce4016f,0xdc88000a,0x87270015}},	//   _סה_, stić, זְרָ, _طعام
  { {0x7e7d1d0d,0xf987006e,0x70b4000b,0x24851d0e}},	//   _nbsp, وب_, ुस्ल, selm_
  { {0x412a138f,0xe4d50015,0x3495030e,0x961d003d}},	//   рого_, _وتتب, _мадр, meņo
  { {0x93bc0011,0x7e7d00b8,0xa06a00d7,0x644a1d0f}},	//   rcăr, _absp, јава_, _gefi
  { {0x68e4002f,0x6f041d10,0x93bc0011,0x62860020}},	//   éidi, tlic, scăr, peko
  { {0x7523018b,0x64411804,0xf412000a,0x32d20091}},	//   _hinz, lbli, _קפה_, ršys_
  { {0x6f0404ec,0x5d6a006d,0x64411d11,0xd257000a}},	// [3240] rlic, ризм_, obli, _ושפה_
  { {0x7c650029,0xdb9a0001,0x2ee90150,0x25ad0cb4}},	//   كامل, итељ_, anaf_, ixel_
  { {0xda6f054f,0xbb86002b,0x307b000a,0x6f0405ef}},	//   мя_, تلاي, _דאינ, plic
  { {0xbae5005e,0x59db000b,0x63ae0012,0x261a000b}},	//   пцій, _मेहर, äbni, मेडी_
  { {0x2d8f02de,0xa25b0003,0x8d760015,0x67221d12}},	//   æget_, mhôt, _باجا, _rioj
  { {0x58d7005e,0x76590034,0xd794006b,0xc19b000a}},	//   одія_, _adwy, зикъ, ישני
  { {0x68ed002d,0x764b0293,0xc6900015,0xc7a30004}},	//   éada, _begy, ِّب_, дијк
  { {0x38600064,0xab2702e1,0x35b41d13,0x64410012}},	//   şir_, _фота_, збир, ebli
  { {0x2cb80005,0x2db70053,0x76590026,0x1539002b}},	//   _kord_, ַלטן_, _ddwy, یزیک_
  { {0x79b7000a,0x752311f0,0x7d7b000a,0x98c6002b}},	//   _ולמד_, _cinz, סניו, _بغرن
  { {0x644a002e,0xa295042b,0x44270273,0x2295005e}},	//   _vefi, пані, _dgn_, пиня
  { {0x7523018b,0x2cb81915,0xf1a70121,0x64411d14}},	//   _einz, _lord_, оргн, abli
  { {0x644102d7,0x867b0008,0x66de0024,0x752301e0}},	//   bbli, _כראו, lūko, _finz
  { {0x645800fb,0x2cb81d15,0x752301f9,0x0000006a}},	//   _udvi, _nord_, _ginz,
  { {0x645d0007,0x0f1b0015,0x76590034,0xaabc000b}},	//   ėsit, لغرب_, _ydwy, ्घाक
  { {0xd3570008,0xd4090015,0x44270079,0xe1ff0030}},	//   _ויהי_, _اتهم_, _zgn_, ngók_
  { {0x61550029,0x2cb81d16,0x0000006a,0x0000006a}},	// [3250] _عندئ, _bord_,   ,
  { {0x2cb800da,0xd53b000a,0x0000006a,0x0000006a}},	//   _cord_, יתמט,   ,
  { {0xd0f8000b,0x23ca000b,0xfbab0033,0x5e470058}},	//   ंकरण_, ानिद, штай_, _وضحك
  { {0x6ffa0008,0xbad8005e,0x99d7006e,0x5ffa004f}},	//   _להתפ, офії_, يتشا, _להתה
  { {0x64410026,0xd94514fc,0xe9a80015,0xe8ee15ee}},	//   ybli, чели, قدون_, ел_
  { {0x3eb91139,0x68270033,0x7e6d007c,0x8fab000a}},	//   _host_, цьдз, lgap, ֹסֵ֔
  { {0x8ae70036,0x1866006b,0xad9b0030,0x3eb91d17}},	//   _діал, чащи_, _ezút, _kost_
  { {0x7e6d1d18,0xc98705a7,0xa7fc007f,0x0000006a}},	//   ngap, _музи, _acıs,
  { {0x9555003b,0x26df00df,0x3eb91d19,0x05760015}},	//   أخبا, riuo_, _most_, كمية_
  { {0x3eb9003e,0xe7330029,0xd4690054,0x64411d1a}},	//   _lost_, _قصص_, љине_, ubli
  { {0xf7700029,0x93e90029,0x3eb90111,0x2cbc004c}},	//   _لان_, صفحك_, _oost_, ימזײ
  { {0xf7700015,0xc7b2000a,0x977a000a,0x29070a88}},	//   _جاك_, _רבא_, _לרעה, llna_
  { {0x27310092,0x59bd005d,0x2611000b,0x64560030}},	//   _hán_, ्निर, देखी_, égió
  { {0x859a013a,0x659a0632,0x9742016f,0xf8a70029}},	//   _לשנו, _לינק, šćen, رة_
  { {0x3eb90026,0x656900f2,0x27310b7e,0x8fa30658}},	//   _bost_, lueh, _ján_, наре
  { {0xa3d4005d,0xd35a000a,0x27311d1b,0x7e6d1d1c}},	//   _सेट_, _הדקל, _mán_, ggap
  { {0x2731002d,0x62960035,0x4d660210,0x8d660033}},	// [3260] _lán_, _iayo, якав, явае
  { {0xdd8f0029,0x7e6d0035,0xeb760010,0x629611ac}},	//   طوم_, agap, зыдэ, _hayo
  { {0x3eb90440,0x629600b6,0x00bb000a,0x8a460015}},	//   _fost_, _kayo, _המימ, كَان
  { {0x656900f2,0x2cb8014c,0x2fc501f0,0x600b000a}},	//   kueh, _word_, ølge_, _לִכְ
  { {0x7e9b0008,0x62961d1d,0xe8940839,0x0e9b0c44}},	//   _הסכו, _mayo, даль, _השכל
  { {0x27311d1e,0xddc4005c,0x2907002e,0x7aeb02f2}},	//   _bán_, raiń, glna_, angt
  { {0xd6da05cb,0x27310092,0xf093000a,0xaa461d1f}},	//   йти_, _cán_, גנו_, _невл
  { {0x987800bd,0x6d560064,0x27311d20,0x2d840003}},	//   _išči_, osya, _dán_, _âmes_
  { {0xa4d400fd,0xe5c601b0,0x7ae21d21,0x99360015}},	//   допі, яско, miot, _رفضت
  { {0x29570008,0xa4d80036,0x62960035,0x38c80086}},	//   _מסמך_, ідну_, _aayo, _باری_
  { {0xd91b0135,0xb80a0115,0x78a8193d,0xe853002b}},	//   _פובל, _ايام_, _indv, _سنند
  { {0xddc40048,0xf6d6002b,0x7ae21d22,0x0000006a}},	//   maiņ, _عزاد, niot,
  { {0x64a61d23,0xc6b7000a,0x65940033,0x78ba013f}},	//   _нада, _מהאי_, _цалу, _kotv
  { {0x760b00b2,0xc8be000b,0x65930004,0xe1ff0030}},	//   _פּאַ, ्सिट, _чашу, ngói_
  { {0xd4970008,0x747b0008,0x447b0008,0xd47b0008}},	//   _זכות_, _הנוג, _הנוע, _האול
  { {0x62961d24,0x660f00b8,0x93930015,0x7b03007c}},	//   _gayo, ückg, _أجوا, nõut
  { {0xa2aa005d,0x5cb90033,0x8d740015,0x41550033}},	// [3270] टार्, олаў_, فالا, _ўвос
  { {0xb0350195,0xddc401ec,0x78ba1d25,0x0000006a}},	//   _юнош, kaiņ, _notv,
  { {0x316c005c,0x6296003f,0xdb0e0227,0xdab90033}},	//   ądze_, _yayo, ždýc, жылі_
  { {0x5a340010,0xc333000a,0xd337000a,0xbb840015}},	//   енцт, גוף_, פרדה_, علني
  { {0x6e9a000a,0x27310016,0x98f50033,0xfe9a004f}},	//   _וברח, _sán_, мякч, _וירמ
  { {0x48790036,0x27310264,0xc7450015,0xf771006e}},	//   ісля_, _pán_, وضعي, ناب_
  { {0x261a005d,0x97a70033,0x77360015,0x905c000a}},	//   मेसी_, ярдл, وكوز_, זכות
  { {0xe5590001,0x2907002e,0x27310016,0x7ae20363}},	//   ојој_, slna_, _ván_, ciot
  { {0x78270225,0x62961d26,0xfaff003d,0xf8af002b}},	//   _فعال, _rayo, ļūda_, _مکث_
  { {0x27310092,0x61e2002e,0x99840058,0x6abb005a}},	//   _tán_, _þoli, _سلمو, _houf
  { {0xc7470086,0xd8740015,0x68e31d27,0xa2aa000b}},	//   _رضاي, _سالب, mind, टाल्
  { {0xd7fa0008,0x57fa000a,0x91e60658,0xe1ff002a}},	//   _והעל, _ולעו, доме, ngów_
  { {0xdc0a000b,0xba56000a,0x64b50015,0x9557002b}},	//   _वर्ड_, וסרו_, _يحتر, _رخشا
  { {0xf9920008,0x361a000a,0x68e31d28,0x7ae21d29}},	//   דרך_, _וונד, nind, ziot
  { {0x7b030020,0xc43a000a,0x629602f2,0x1eaa0040}},	//   nõus, _ותצי, _tayo, ياري_
  { {0x7c2913cc,0x8236012c,0x68e31d2a,0xe3a6009a}},	//   _şerp, _غربا, hind, _آشوی
  { {0xcce60015,0xad9b0030,0x68e317ab,0x7ae21d2b}},	// [3280] وسطي, _szúr, kind, viot
  { {0x3cfa014e,0xdd8f0029,0x69c2003f,0x6aa90034}},	//   ्तें_, ؤول_, vyoe, _anef
  { {0xb4fa0053,0xa08b0008,0xcdc9000a,0x6abb1d2c}},	//   קלער, _וְכִ, סך_, _bouf
  { {0xc3320008,0xbad50033,0xda650021,0x78ba013f}},	//   דוא_, нічы, فاهي, _sotv
  { {0x6abb0089,0x68e31d2d,0x78ba06ca,0x7ae21d2e}},	//   _douf, find, _potv, riot
  { {0xb0a7000b,0x68e31d2f,0xe1ff002a,0x98a3029f}},	//   खाएग, gind, agów_, киче
  { {0xa089000a,0x7ae2008c,0x98a30054,0xf76f0040}},	//   לְקִ, piot, тије, لاي_
  { {0xddc4003d,0x6abb16c3,0x656d006f,0x501b000a}},	//   raiņ, _gouf, _ťaha, חוצו
  { {0x048a0054,0x8466006b,0x68e31d30,0x2bc60065}},	//   ољни_, мъне, bind, लनका
  { {0x78a81d31,0x68e31d32,0x6abb0046,0x442a02de}},	//   _undv, cind, _zouf, øb_
  { {0x97c60015,0x6d4b0030,0xe7a80065,0x0000006a}},	//   _تقاو, ágaz, _कपटप,
  { {0xeb910008,0x28be000b,0x65870123,0xe56f0061}},	//   נָי_, ्सवि, örhå, ağış
  { {0xf4930086,0x05d30015,0xf2040033,0xa227009a}},	//   رشید, _لزوج, вяро, برده
  { {0x3cfa014e,0x660f00b8,0x64c40015,0xe1ff0535}},	//   ्तों_, ücke, _سيعل, zgów_
  { {0xcebb0001,0x34fb000f,0xb4fb000a,0x8503002b}},	//   оља_, _והגד, _ולגר, _جوون
  { {0xa2d50015,0x68e31d33,0x3383009b,0x0000006a}},	//   _سيخت, zind, _рушв,
  { {0x68e30064,0x33180015,0x9d151d34,0xfbd0009a}},	// [3290] yind, _تزود_, едач, یتم_
  { {0x6abb0152,0xee3f002c,0x2bbb0015,0x7f95005e}},	//   _souf, _iným_, ياضة_, _заох
  { {0xa2d6005d,0xf092000a,0x6abb002a,0x68e31d35}},	//   मोक्, _גני_, _pouf, vind
  { {0x68e31d36,0x0000006a,0x0000006a,0x0000006a}},	//   wind,   ,   ,
  { {0x19580010,0x66e80046,0xe1ff002a,0x13ca000b}},	//   дачы_, něku, rgów_, ानुभ
  { {0x7b030020,0x68e31d37,0x279507f7,0x35d90065}},	//   tõus, uind, ешир, _बेग़
  { {0x98a40011,0x68e31d38,0x6abb0003,0x961d003d}},	//   _sumă_, rind, _touf, meņi
  { {0x68e31d39,0x7705002b,0x19950033,0xf5b5030c}},	//   sind, رژان, _пабя, есою
  { {0x68e30278,0xa7fc0061,0x35d90065,0x0000006a}},	//   pind, _adıd, _बेख़,
  { {0x9742016f,0x39141d3a,0x38d5004f,0x0000006a}},	//   šćan, _амур, _אֵ֣ל_,
  { {0x28ac005d,0xf8680029,0xb8d3005d,0xd7740015}},	//   चारि, _زمني_, टा_, _لانع
  { {0xdce401e2,0x59c4000b,0x63bc0123,0xe29a127b}},	//   ktiğ, वनचर, ärna, чам_
  { {0x26cf0091,0xa2d6000b,0x25e6000b,0xcb12000a}},	//   _ilgo_, मोग्, _जेपी_, טלט_
  { {0xb5fd0024,0x55ba000a,0x657b001a,0xb5c80067}},	//   ugšu, _ממנו, mtuh, _توهم_
  { {0x3f16000d,0xe4c800c3,0x60c1001a,0x99dd005a}},	//   еќат, _زبون_, ölma, _keňs
  { {0x11680086,0x394d00da,0x23760015,0x0000006a}},	//   _قلبی_, _owes_, _أميد_,
  { {0x7c3b0061,0x657b1482,0x0000006a,0x0000006a}},	// [32a0] _şura, ntuh,   ,
  { {0xe0da0054,0xe189002b,0x51fb004f,0x8c960138}},	//   _хво_, _آئين_, _מהפצ, эрбі
  { {0xa037004c,0x539a000a,0x0b461d3b,0x7bc50034}},	//   _ראטה_, ּינו, хнен, gyhu
  { {0x657b0035,0x7f3b000a,0x29050061,0x68e10034}},	//   ktuh, _מעטו, _akla_, _amld
  { {0x19940c1d,0x28ac000b,0x28be000b,0x62840125}},	//   таля, चालि, ्सलि, _mbio
  { {0xd90d0086,0x26cf0656,0xdcf604b2,0x6d441d3c}},	//   قیق_, _algo_, otyč, mpia
  { {0x56941c31,0x67630015,0x66de1cfa,0x0000006a}},	//   вайт, هُول, lūki,
  { {0xd6d7005f,0x20d40020,0x4733002b,0xe704002b}},	//   еть_, _häid_, دروز, خستی
  { {0x16370015,0xa9671d3d,0x20d4007c,0x8886080e}},	//   رسية_, _пита_, _käid_, _плаж
  { {0x6d440007,0x20d4007c,0x2c36000a,0x06130033}},	//   ipia, _jäid_, עָ֥ם_, ыдыю
  { {0xe2f90036,0x02cc005d,0x9cd7000a,0x13f40138}},	//   дені_, ासंभ, גויה_, тзня
  { {0x92940010,0x7bcb000a,0xa1590033,0x660f02ad}},	//   гаюц, לֶכֶ, маму_, ückc
  { {0xe2980010,0x6eba000b,0xc218005e,0x76bb004f}},	//   хаў_, _एकजु, еєр_, _ממאפ
  { {0x2ec9014e,0xd7e60029,0xe58b0008,0x6abd0065}},	//   रस्त, لك_, _זָהָ, _ऍक्र
  { {0x316c002a,0x439403ca,0x649b004f,0x749b004f}},	//   ądza_, _райс, _מסגד, _זיופ
  { {0xdce40064,0xdb0d0061,0x3e890015,0x33970058}},	//   ttiğ, üküm, بَرَ_, _أخوة_
  { {0x8d770015,0x60f9006b,0x6c750054,0x12fc000a}},	// [32b0] عارا, _ония_, клађ, _מההב
  { {0x6284005c,0x0cbd000b,0x629d1d3e,0x628f1d3f}},	//   _zbio, ोसेम, ldso, leco
  { {0xdce40061,0x6d440034,0x0000006a,0x0000006a}},	//   stiğ, apia,   ,
  { {0x7b2c0064,0xe04b0086,0x629d1d40,0x290500bf}},	//   _ağus, _بشکه_, ndso, _skla_
  { {0x80270086,0x629d0409,0x7bc51d41,0x6f0d1d42}},	//   _ترکم, idso, syhu, mlac
  { {0x01380008,0x31380008,0x6f0d1d43,0x2d4f002a}},	//   ערות_, ערוך_, llac, mże_
  { {0xe7760015,0x628f01c2,0x6f0d1d44,0x2d4f002a}},	//   نموث_, keco, olac, lże_
  { {0x2d4f005c,0x9585006b,0x25790144,0x46a5004a}},	//   oże_, влие, tèl_, таив
  { {0x98a40007,0x629d0026,0x8883002b,0x7af80030}},	//   _sumą_, ddso, _میشن, évte
  { {0x6f0d1d45,0x35b8000b,0xe8df0016,0x657b1d46}},	//   hlac, ेनज़, _meịo_, rtuh
  { {0x657b00b6,0x69d90012,0xe7b500c3,0x6f0d1d47}},	//   stuh, lzwe, _جماد, klac
  { {0x2d4f0050,0x64481d48,0x628f1d49,0x6d44002a}},	//   kże_, abdi, geco, ypia
  { {0x4a5a000a,0x2d4f002a,0x69d902f7,0x95c50058}},	//   ודרו, jże_, nzwe, _جيشه
  { {0x442e0012,0x0086006b,0x6143168f,0x4103006b}},	//   _ggf_, ълго, рера, изяв
  { {0x6d440176,0xb4bf005d,0x6d5d02d2,0xb4cd000b}},	//   wpia, ीसी_, _avsa, रसी_
  { {0x43740180,0x6f0d1d4a,0x673c0030,0x6284002a}},	//   _сушт, glac, _érje, _ubio
  { {0xed570083,0x531b0008,0xf6520053,0x71590010}},	// [32c0] кот_, _קופצ, יצן_, _прэс_
  { {0x6f0d002d,0xa3c8000b,0x3157015b,0x6606007c}},	//   alac, लैक_, _שיין_, ükki
  { {0xd8380085,0x961d003d,0x6f0d1d4b,0xef1a067a}},	//   _jače_, meņu, blac, _омо_
  { {0x6d441d4c,0x0ba90015,0x0ea9000b,0xd946171a}},	//   ppia, عالى_, _चोपड, веди
  { {0xda650029,0xd910002b,0x394000aa,0xc237000a}},	//   طاني, میر_, ëis_, דרנו_
  { {0x7b2c0011,0x656900b8,0x8c4301e5,0xf8ac0065}},	//   _eşua, dreh, _вере, चाइय
  { {0x20d40020,0xba6a0015,0x4c9b000a,0xc7b00015}},	//   _käib_, _يحرك_, _קבלו, صّة_
  { {0x2ef20034,0x2508009a,0x8574009b,0x6f041d4d}},	//   nnyf_, کربی_, глих, noic
  { {0x656900dc,0x628f0024,0xceb3000a,0x35b3006b}},	//   greh, veco, שיח_, ибър
  { {0xdce41d4e,0x63bc0123,0x6f041d4f,0x39461d50}},	//   krič, ärno, hoic, mpos_
  { {0xd4970802,0x65690358,0xe8d7000a,0x64481d51}},	//   тры_, areh, _שובר_, rbdi
  { {0x290e0026,0x20d4007c,0xa3c8000b,0x6f041d52}},	//   llfa_, _näib_, लैग_, joic
  { {0xf5770029,0x394600dd,0x6f0d0085,0x629d1d53}},	//   _لمنع_, npos_, vlac, rdso
  { {0x394602c1,0xa2c7000b,0x6f0d1892,0x2127009a}},	//   ipos_, ासङ्, wlac, ئيسی_
  { {0x4fc40c20,0x27380030,0x628f0028,0x1ee7009a}},	//   аста, _jén_, peco, نوسی_
  { {0xb2750080,0xb3b7000a,0xc2750054,0x479b015b}},	//   _слиш, _יפוג_, _слиј, וילס
  { {0x1e340010,0x27381d54,0xa2f800f3,0x9df9006b}},	// [32d0] рнуў, _lén_, _שמחה_, хнат_
  { {0x6f0d1d55,0x2605000b,0xbbeb0058,0x0000006a}},	//   slac, _हँसी_, ورام_,
  { {0x6f0d0376,0x27380016,0x2fd90015,0xde59008b}},	//   plac, _nén_, _أوجد_, _пані_
  { {0x69d9018b,0x99f50033,0xfb840033,0xbcfb0030}},	//   tzwe, лялі, рыфн, _svéd
  { {0xff160008,0xaa580054,0x6eda000a,0x99850021}},	//   _תקרת_, тичу_, _נחשפ, التو
  { {0xd914008f,0x69d900b8,0xa2aa0231,0x6fba000b}},	//   адчы, rzwe, _जोन्, _उपमं
  { {0x2738002f,0xeafb0029,0x69d90012,0x38690061}},	//   _cén_, _قررت_, szwe, ğar_
  { {0x65690014,0x394600dd,0x38691d56,0x27380125}},	//   treh, bpos_, şar_, _dén_
  { {0x7989005c,0x27380111,0x28a4000b,0xcc75000a}},	//   _upew, _eén_, _गोवि, ְעֹה_
  { {0xdced002c,0xb4cd000b,0xd8380085,0x6f041d57}},	//   hvaľ, रसे_, _pače_, zoic
  { {0x9cd6000a,0x889a000a,0xd794006b,0x42ea0137}},	//   רותה_, _רבעי, _вихъ, емно_
  { {0x216a0191,0x6d41065d,0x1635006b,0xc7b2000a}},	//   ними_, _član, _седя, _לבב_
  { {0x20d6005e,0x09b5004c,0x5155005e,0xa155006b}},	//   гівс, נפֿט_, итру, иърш
  { {0x19b60008,0x6f04005c,0xb4470010,0xe588000a}},	//   אפשר_, woic, _рэдк, _יָצָ
  { {0x2d9904ed,0x70530029,0xf456000f,0xb4fa000a}},	//   _asse_, إنفا, _עיקר_, _אפסי
  { {0x0000006a,0x0000006a,0x0000006a,0x0000006a}},	//     ,   ,   ,
  { {0xdb1e0030,0x6f041d58,0x290e0034,0xb2d30058}},	// [32e0] _évéb, roic, ylfa_, _دييغ
  { {0xdce4116e,0xc173000a,0xec77004a,0x0d0a0058}},	//   prič, _פחת_, лпу_, رقاً_
  { {0x2d991d59,0xa09b0053,0xf4560053,0x160a000b}},	//   _esse_, _װיכט, ריער_, _हुनर_
  { {0xdd120024,0xf8be000b,0xcf93000a,0x3946042c}},	//   _kļūs, ्स्प, _פטר_, tpos_
  { {0xaa570115,0x8277004c,0x9f06002b,0x08540342}},	//   الها_, רענע_, _لوگو, авлю
  { {0x307a0053,0xddab000a,0xfce60004,0x2259002a}},	//   גאַנ, _אֱלָ, _сого, zask_
  { {0xa3e2000b,0xf72a033d,0xb8ec000b,0xada3006f}},	//   _नें_, нций_, _लव_, ajúč
  { {0xe29f002e,0x96340a0b,0x3d18000b,0x8f57004c}},	//   koða_, шниц, _बीते_, אסקא_
  { {0x2d800298,0xb5a30033,0xb5fd003d,0x34940033}},	//   ntie_, брэй, ugšp, аапр
  { {0x7d7b0135,0x3ea007d2,0xcd97000a,0xd4540054}},	//   עריג, hdit_, נדית_, шкоћ
  { {0xd25100b0,0xb8f8005d,0x8cd9005d,0xa9230107}},	//   يند_, ास_, फोटो, ížen
  { {0x57fb0008,0x2d801bc9,0x25a61d5a,0x0000006a}},	//   _אלבו, ktie_, _trol_,
  { {0xc693000a,0x98a4002a,0xc56a0015,0x22590091}},	//   _לאף_, _sumę_, _أحصل_, rask_
  { {0x659b000a,0x759b000a,0x3ea01d5b,0x63bc04d1}},	//   _ניוק, _נסוג, edit_, ørns
  { {0xde59005e,0xdfd8006b,0xd3a30033,0xf457015b}},	//   каві_, гът_, _грып, _גיור_
  { {0x3ea00177,0xe29f001a,0x4916000b,0xf3f10016}},	//   gdit_, boða_, _पीसो_, oạn_
  { {0xdc550292,0x7d250029,0x2d80003d,0x3e880058}},	// [32f0] ивањ, لفرن, gtie_, طَلَ_
  { {0x28a4005d,0x3ea00046,0x443e1d5c,0x645a1d5d}},	//   _गोलि, adit_, nct_, nati
  { {0x5a351a56,0x40ec000a,0xbb95006b,0x2d801d5e}},	//   анет, _רַחֲ, раещ, atie_
  { {0xf991012c,0x645a1d5f,0x0000006a,0x0000006a}},	//   قبت_, hati,   ,
  { {0x2d800298,0x9e5a0008,0x50b80086,0xb23c004c}},	//   ctie_, _בכרט, _شدید_, געדז
  { {0x20d40020,0x3158000a,0xb4c3000b,0x645a1d60}},	//   _käia_, ניון_, _एके_, jati
  { {0x98540036,0x57e70033,0xf094000a,0x645a1d61}},	//   стіш, ыўдз, מנס_, dati
  { {0x16a9005f,0x443e0011,0xb4cd000b,0x645a1d62}},	//   твии_, ect_, रस्_, eati
  { {0x63410048,0x0576003b,0xba190029,0xceb4000a}},	//   _mēne, لمية_, _شيئا_, מיק_
  { {0x7aeb1d63,0xc4820802,0x2ed2005d,0xd8740115}},	//   ligt, ольк, _सत्त, _هامب
  { {0x86c50074,0x23160036,0xc2c60029,0x69cb0757}},	//   _پيشن, иємс, ليدي, lyge
  { {0x645a0f7a,0x67ba000a,0x7aeb15f6,0x2d80006f}},	//   aati, _במעק, nigt, ytie_
  { {0x98a5003d,0x645a1d64,0xa91d0073,0x0000006a}},	//   _zilā_, bati, _apži,
  { {0x03a50191,0x645a0f43,0x04450004,0x443e1d65}},	//   _вико, cati, _текн, cct_
  { {0xb21b00fb,0xd00a0054,0xd8380085,0x8fa602d9}},	//   lfæl, теве_, _jača_, јабе
  { {0xe519005d,0x2d80052a,0x59c5000b,0x3ea01d66}},	//   _नीति_, ttie_, वहार, udit_
  { {0xee371d67,0x3ea01d68,0x5f03008b,0x2907055c}},	// [3300] рну_, rdit_, ізуа, kona_
  { {0x2d8011c3,0x515b000a,0x8f7601f3,0xfbd200c3}},	//   rtie_, _שכיו, _кумі, يتا_
  { {0xa7fc01e2,0xda7a006b,0x2d801d69,0x29071d6a}},	//   _adın, вял_, stie_, dona_
  { {0x645a0041,0x2d801d6b,0x0a67006b,0xcb670033}},	//   zati, ptie_, арши_, раце_
  { {0x660f00b8,0x645a1d6c,0xdce4003d,0xbebb00aa}},	//   ückl, yati, ariā, _viët
  { {0xc173000a,0xd9180015,0x29071d6d,0x7aeb0091}},	//   קחו_, ديتش_, gona_, aigt
  { {0xe0b70053,0x0306000b,0x38cb002b,0x645a1d6e}},	//   ילסט_, रवाह_, خانی_, vati
  { {0x656600dc,0x645a1640,0x69cb02de,0xbebb08cf}},	//   ákho, wati, byge, _hiër
  { {0xcdf6000a,0x645a1d6f,0x29071d70,0xd94307ec}},	//   ימֵי_, tati, bona_, _мети
  { {0xe7ff000b,0x29071d71,0x961d01ec,0x7bde0487}},	//   _ऊँचा_, cona_, teņr, ozpu
  { {0x9f450064,0x5c37000a,0x2259004a,0x8c37004c}},	//   çlü_, ירין_, лины_, יטיס_
  { {0x6d46016f,0xf5ea0080,0x7982002a,0x12e7005e}},	//   _otka, _имел_, otow, ріог
  { {0xc05b0191,0x79820050,0x645a0705,0xd251002b}},	//   ків_, ntow, pati, ينگ_
  { {0x41e8006b,0x7aeb0073,0x0000006a,0x0000006a}},	//   рфюм_, zigt,   ,
  { {0x64580048,0x6d460048,0x251b0053,0x66d5001a}},	//   _ievi, _atka, _שווא, _háka
  { {0x79820050,0x2907171d,0x63040015,0xc7d7000a}},	//   ktow, zona_, _ووول, בולי_
  { {0xa697000a,0x12fc000a,0x8d7400c3,0x7982051e}},	// [3310] סכמה_, _שהחב, قالا, jtow
  { {0x4095003b,0x2ba70001,0x7c59002b,0xa115002b}},	//   _الدر, ијев, الار_, _دوخت
  { {0xd0080083,0x7aeb00b8,0xbca40029,0xd5a6002b}},	//   _веќе_, tigt, تملي, _کف_
  { {0x69cb01d1,0x68e80026,0x290c0035,0x7982002a}},	//   tyge, _amdd, _akda_, ftow
  { {0x99d40086,0x7aeb00dd,0xceb60008,0x8f1a000a}},	//   يتها, rigt, _הפרק_, _תורת
  { {0xa3c8005d,0xe9d80010,0x7aeb1d72,0x64581d73}},	//   ोना_, шкі_, sigt, _nevi
  { {0x7982005c,0x47580010,0x29071d74,0xdb210030}},	//   atow, арыя_, rona_, ítós
  { {0x20d4022d,0x0f58000a,0xbbb5000b,0xdbdd0030}},	//   _näin_, ביהם_, ूहीक, jáép
  { {0x27380092,0x799b005c,0x7ae91d75,0x64581d76}},	//   _lĩnh_, _usuw, _imet, _bevi
  { {0xa91d0007,0x04b50080,0x99d40015,0x6aa00045}},	//   _apžv, ссия, _بتفا, _zamf
  { {0xd4c4003b,0xd6db0001,0x7ae90844,0x28150067}},	//   تغيي, _итд_, _kmet, _اواس
  { {0x9bb6000a,0x98a50045,0x95950054,0x78a11d77}},	//   צהרה_, _filă_, _гркљ, _halv
  { {0x68e80176,0x454504c9,0x64a51d78,0xb607006d}},	//   _ymdd, _انتق, _гала, _тяжк
  { {0x6458020a,0x05b80086,0xdddd005c,0x66de0024}},	//   _gevi, _خدمت_, _odsł, lūkp
  { {0x66d504af,0xc0e30010,0x7982002a,0x7ae91d79}},	//   _záka, чорк, ztow, _omet
  { {0x7982005c,0x44240015,0x6441158f,0xdee30973}},	//   ytow, _ظروف, lcli, поси
  { {0x3c660033,0x64410045,0xcc360058,0x31860058}},	// [3320] йкаг, ocli, مراع, _الخِ
  { {0x7ae90cda,0x7afb1d7a,0xcce50015,0x6aa01d7b}},	//   _amet, _ajut, يسلي, _samf
  { {0x6120002e,0x2fd00011,0xe4520008,0xa0c6002b}},	//   tölf, ângă_, לֶף_, _نيکو
  { {0x76590b7c,0xdbd00107,0xbae5005e,0xd37a004c}},	//   _newy, _užív, оцій, טרעט
  { {0xc2cd004c,0x6d461d7c,0xe3a7002b,0x98c6008b}},	//   כמאָ, _utka, _کر_, йскл
  { {0x79820050,0x66d500dc,0xa7860015,0xdc750033}},	//   rtow, _ráka, مشبو, _мысь
  { {0xf0930008,0x765900dd,0x79821d7d,0x645808a2}},	//   פנה_, _bewy, stow, _revi
  { {0xe81e014e,0x79820050,0xd6d70139,0x64581d7e}},	//   येगा_, ptow, йты_, _sevi
  { {0x3ea202d2,0x7ae30150,0x78a10030,0x35b4005e}},	//   _makt_, ënte, _falv, ібор
  { {0x78a11d7f,0x7afb00bc,0xc34a006b,0xd49a1021}},	//   _galv, _zjut, ляме_, ури_
  { {0x2418054f,0x20d4008c,0xa6860719,0x60c51d80}},	//   роны_, _päin_, _глед, _rohm
  { {0x6443002e,0x765900dd,0x11d90015,0xb2740033}},	//   _efni, _gewy, لوجة_, плюш
  { {0xeab101d8,0x61200123,0xa6a9006e,0x64411d81}},	//   וֹם_, köld, _خالق_, bcli
  { {0x27380023,0x61200084,0x64a31d82,0x9f35005e}},	//   _cũng_, jöld, _нача, жеві
  { {0x27380092,0xaf090015,0xddc6002a,0x673a0144}},	//   _dũng_, لقسم_, _tekś, _jutj
  { {0xbdd50080,0x27380092,0x5d550063,0x2bac000b}},	//   ообщ, _vĩnh_, жкат, घटना
  { {0xe1670086,0x60c501c2,0xae44002b,0x6120171f}},	// [3330] _ادبي, _tohm, سپلو, föld
  { {0xa7fc01e2,0x27380092,0x7ae905ba,0x361b000a}},	//   _adım, _tĩnh_, _smet, רומד
  { {0x8cbf000b,0x69c4007c,0xfbab0033,0x3b640015}},	//   लॉगो, äien, ытай_, كُلِ
  { {0x5a150004,0x78a11470,0x99d50021,0x7b18001a}},	//   омеѓ, _salv, يقات, síun
  { {0x78a1022d,0x5d7900b2,0xe29c0053,0x1a68002b}},	//   _palv, _דאָק, טשאר, صیلی_
  { {0xd90f0086,0x17c90175,0x6d4d1d83,0xe8f801c6}},	//   ریا_, игли_, mpaa, блі_
  { {0x6d4d1d84,0x07b60015,0x78a10960,0xf7490015}},	//   lpaa, قهوة_, _valv, جلبي_
  { {0x57a40010,0x7ae91d85,0xb21b001a,0x7afb1667}},	//   яшча, _umet, mgæf, _ujut
  { {0x27210016,0x64c50015,0x61200030,0x78a11d86}},	//   hóng_, قيةل, löle, _talv
  { {0x3365087a,0xe79b0029,0x5fc9000b,0x98f7002b}},	//   овог, _مخصص_, रहाल, _اثرا
  { {0x2ca30014,0xf1a9000a,0x64411d87,0x0000006a}},	//   _majd_, _שס_, rcli,
  { {0x6b850176,0xc0490dab,0xc5d5022a,0x1dd9000b}},	//   ithg, _יז_, _міль, णनात
  { {0x06380015,0xd250002b,0x3ea20123,0x021a005e}},	//   _اسمع_, وچک_, _rakt_, рінь_
  { {0x70560015,0x73c50015,0xa2aa000b,0x628d007c}},	//   تنسا, _ويشم, _जोर्, _ebao
  { {0xf8b20008,0xae5a005e,0x9325002b,0x27380016}},	//   ושם_, ирає_, ترین, _vũng_
  { {0xa3e2000b,0xee3f001a,0x63ae02de,0xd356004f}},	//   _नेट_, _snýr_, æbne, _ויקי_
  { {0xc6920008,0x6d4d02f2,0x63bc0123,0x0d490015}},	// [3340] ואן_, gpaa, ärnv, مشلي_
  { {0xdced0061,0xabd60058,0x6bd60058,0x0000006a}},	//   rtağ, يزات, يتار,
  { {0xeb9a0b44,0x0b4601f3,0x6d4d1d88,0x3ea21d89}},	//   рие_, цнен, apaa, _takt_
  { {0xb4d6000b,0x094a1797,0x7e760015,0xc9aa1d8a}},	//   _सत्_, ачки_, _بادئ, ивее_
  { {0x6b850125,0x1e97000a,0x673a18ee,0x0d7502ed}},	//   athg, _וככל_, _sutj, _ныря
  { {0x765d002e,0x9cb60015,0x83fc0085,0x4fba000a}},	//   ðsyn, _بمست, lađe, ֹצֵא
  { {0xd6da1d8b,0xceb2000a,0xdb830098,0x49090065}},	//   ити_, ֵי֙_, _огри, ाक़ो_
  { {0x83fc016f,0x758a03fa,0xd5661d8c,0xe55400af}},	//   nađe, асов_, отоп, пкињ
  { {0xc6f7008f,0x66d5002e,0x7c3900dc,0x66dc0030}},	//   ўных_, _tákn, _ábrá, _néke
  { {0x2db70643,0x6f16006f,0xe53d0030,0xa8d8004f}},	//   קלין_, hlyc, ójáé, _פַּת
  { {0x80be000b,0xdc8b05bd,0x0000006a,0x0000006a}},	//   शाने, בְכָ,   ,
  { {0x66dc0030,0x6235004a,0x9f990030,0xdb9b004f}},	//   _béke, яему, jáát_, בסטר
  { {0xe298008f,0x66d50107,0x54e60015,0xe729002b}},	//   цаў_, _záko, _وستق, _اسلو_
  { {0xdd3d002a,0x7ce002ad,0xb6060073,0x0000006a}},	//   rąży, _hörf, rašę,
  { {0x3ec70010,0xb4c8000b,0x92590238,0x403404d7}},	//   осаб, ैसी_, _лайт_, дерс
  { {0x66d5099c,0xceb80001,0xfebb002b,0xbcfb0030}},	//   _nákl, ољу_, جاست_, _evél
  { {0xdce60064,0x3f9e002e,0xc3280015,0x69c4007c}},	// [3350] _askı, ætur_, _بكين_, äiel
  { {0xbc4b0033,0x6d4d1d8d,0xac77009a,0x7b180052}},	//   рчае_, rpaa, تارش, síul
  { {0x309a013a,0xb09a0008,0x6d400152,0x3ed90015}},	//   _השתמ, _היתר, _éman, _هودج_
  { {0xb5fd018c,0x13bb0053,0x6d4d00f2,0xaa67005e}},	//   laše, יזבע, ppaa, ітек
  { {0xdce70064,0x99d70015,0xbf6d0046,0xc27c000a}},	//   şlıc, غتصا, říči, שרדי
  { {0x9d180063,0x47590063,0xed560135,0x08c4042b}},	//   _моят_, брия_, _מבשר_, мбін
  { {0x0058000a,0x6b600030,0x7b640195,0x47380033}},	//   חשות_, _vágá, _отте, очыў_
  { {0xe7080029,0x31790eba,0x7528002a,0x67221d8e}},	//   يتين_, kusz_, emdz, _choj
  { {0xe5710029,0x7ce00012,0x3179002a,0xad8b000a}},	//   رطة_, _dörf, jusz_, ׁנֵ֥
  { {0xdced04af,0x66d50156,0xb8d70015,0x6f0d01f9}},	//   krač, _zákl, _بترش, hoac
  { {0x7ce001d1,0x33f5005e,0xf3f10016,0xd3780085}},	//   _förf, ячис, oại_, guć_
  { {0x8bd6000a,0xa306000b,0x2721006f,0x61200030}},	//   פורו_, रवेज_, fóne_, kölc
  { {0x171a0053,0x763a0053,0xe2970139,0xa63a000a}},	//   _פונע, _הענג, чая_, _הגנר
  { {0x61200012,0x64a501da,0x67290a6a,0xdced0417}},	//   wölb, _хака, lmej, frač
  { {0x246700dc,0x320c002a,0x6023012b,0xdced1d8f}},	//   _című_, łdy_, едра, grač
  { {0xdfcf0015,0x82360015,0x20d4007c,0x660f0012}},	//   ديف_, _عربا, _käik_, ückw
  { {0x83fc016f,0xdced00bd,0x127b0053,0x1168002b}},	// [3360] rađe, arač, _האפע, _بلخی_
  { {0x7ce0002e,0xb886006f,0x6f160123,0x200c007c}},	//   _mörg, _kríž, slyc, üdis_
  { {0x205700f3,0x351a000a,0xeb971d90,0xb09b000a}},	//   _מייל_, צוענ, зих_, _פיטר
  { {0xdce4016f,0x672900bc,0xdb59005e,0x63ae02de}},	//   krić, jmej, іює_, åbni
  { {0xd378002a,0x7ae30079,0xa978005e,0xe83801c6}},	//   zuć_, ënta, ійку_, оплі_
  { {0x6c36002b,0x3f680061,0xfcf8000a,0x26f6000b}},	//   _رفرا, oğu_, _וּֽל, ुक्र_
  { {0xb8f4005d,0xd90d002b,0x2721006f,0x1be70663}},	//   _हक_, جیل_, zóne_, _едри_
  { {0xb8d3014e,0xd6d00015,0xfaa30cad,0x2b55002b}},	//   _जो_, ئقة_, _пасо, _آیند_
  { {0xba170067,0x186a04ae,0xdced1d91,0x0000006a}},	//   _فيفا_, _гази_, zrač,
  { {0xb4d6005d,0xb4c8005d,0x89db0008,0x03f80001}},	//   ससे_, ैसे_, _החמי, жној_
  { {0x6f0d003f,0xdc8b004f,0x0000006a,0x0000006a}},	//   yoac, זְכָ,   ,
  { {0xd7ef0029,0xdced00bd,0x7ce01d92,0x67bb000a}},	//   _حكم_, vrač, _förg, _למבק
  { {0xbcfb0089,0xa5960036,0x6f0d0045,0x7ce01d93}},	//   _svém, _хрещ, voac, _körd
  { {0x63bc0123,0xdced1d94,0x859b000a,0x31791116}},	//   ärns, trač, _לשדו, rusz_
  { {0x0f1b0029,0xf8b80092,0x351b000a,0xb5fd1587}},	//   مغرب_, _nhĩm_, _הוגנ, raše
  { {0x7ce00123,0xf413000a,0x33fb000a,0x59be000b}},	//   _lörd, _אפצ_, _להונ, ्हार
  { {0xdd940010,0xdd910015,0x98a50091,0x6f0d1d95}},	// [3370] наты, ضوا_, _eilę_, roac
  { {0xa1150029,0x7ce01d96,0x9d140585,0x6729013b}},	//   _زوجت, _nörd, едуч, zmej
  { {0x6ce40036,0x6729008c,0xcb680015,0x6d4b001a}},	//   хіте, ymej, كمله_, ígab
  { {0x2ee00026,0xdb23002b,0x64440061,0x99d90015}},	//   chif_, روشی, _şiil, يواء_
  { {0x3ea90079,0x89370015,0xa9690054,0x7ce00400}},	//   mdat_, أعصا, цила_, _börd
  { {0x008a00b2,0x7ff40086,0xe8f801c6,0x3ea91d97}},	//   ַרפֿ, _آسیا, плі_, ldat_
  { {0x917a0092,0x9be4005e,0xfaf30015,0x7ce00061}},	//   _mất_, _зітк, _كثر_, _dörd
  { {0x3fdc000a,0xd549006b,0xe29f001a,0x85490bbb}},	//   מקוב, опие_, boði_, озив_
  { {0x67290604,0x2d891d98,0x7ce00b1c,0x9475002b}},	//   rmej, ntae_, _förd, وددا
  { {0x3ea900f2,0x7ce00700,0x69ca0061,0x394d1d99}},	//   hdat_, _görd, çleş, _ites_
  { {0x47d50015,0xf770006e,0xb7d50040,0xdced0069}},	//   _تيار, _مان_, _تقاب, hraď
  { {0xa284002b,0x25a90160,0x0000006a,0x0000006a}},	//   ریخو, _šalu_,   ,
  { {0x917a0023,0x82360086,0x7ce008e9,0x3ea90123}},	//   _bất_, بردا, _höre, ddat_
  { {0x80d8000b,0x85050015,0x21670004,0x9f98001a}},	//   डसें, _توتن, ќири_, _báða_
  { {0x25ad007c,0x248b0073,0x0000006a,0x0000006a}},	//   lvel_, ėkmę_,   ,
  { {0xf4120008,0xef1a042b,0x234a002b,0x290e1d9a}},	//   _שפה_, іма_, _بسوی_, zofa_
  { {0xacca0036,0x6cd60015,0x25ad1d9b,0xb11a0058}},	// [3380] огаз_, وقرا, nvel_, _وقعا_
  { {0x3ea60024,0x25ad00dc,0x3ea91d9c,0xdd8f009a}},	//   žot_, ivel_, adat_, شوم_
  { {0x66dc0089,0x5f760015,0x00bb000a,0x25ad007c}},	//   _léka, _غادر, _ומימ, hvel_
  { {0x657b008c,0x1efa000a,0xbaba0058,0x0000006a}},	//   kuuh, _וּ֝מ, غداء_,
  { {0xd00f0074,0xe894006d,0xa2bf000b,0x7e9b000a}},	//   _ملی_, еаль, षात्, _וסכו
  { {0x83fc0085,0x7e640091,0xa3dd000b,0x274a0054}},	//   hađa, laip, णना_, очио_
  { {0xf093000a,0xd8380085,0x6284026a,0x25ad1d9d}},	//   דנו_, _jači_, _ocio, evel_
  { {0x7e64002f,0x356a0146,0xf56a1d9e,0x0000006a}},	//   naip, орон_, ошок_,
  { {0x2a160010,0xa534007a,0xd49a1d9f,0xff17004f}},	//   _цьвё, ннич, орн_, וקקת_
  { {0x7ce01da0,0x291800dc,0x6284001c,0x38cb0086}},	//   _före, _óra_, _acio, _والی_
  { {0x7ce01da1,0x917a0092,0xcc770008,0x3c7701d8}},	//   _göre, _rất_, וגית_, ותים_
  { {0xeb9100b2,0x83fc010b,0x78a80030,0x9f98001a}},	//   אָך_, gađa, _hadv, _ráða_
  { {0x660f0012,0x41e701c6,0x518403a7,0x35fa02be}},	//   ückt, фіна, кура, _براد_
  { {0x7ce00064,0x0ef9000b,0x65930033,0x6120008c}},	//   _yöre, ्क्स_, _рашу, töla
  { {0x7ed7003b,0xd47b0008,0x75370053,0x3ea9016b}},	//   وزرا, _ואול, _קאוד_, tdat_
  { {0xb5fd010b,0x22490064,0x62840125,0x66d50030}},	//   laša, _ufak_, _gcio, _rákk
  { {0x917a0023,0x78ba00f6,0x3ea91da2,0x629d1da3}},	// [3390] _tất_, _ontv, rdat_, meso
  { {0x61200030,0x78a8049e,0xb5fd1da4,0x629d1da5}},	//   löln, _nadv, naša, leso
  { {0x90540033,0x3a750c9a,0x73a9004f,0xbb540058}},	//   _швэц, елер, ּינֵ, َنْب
  { {0x7ce000c0,0xdbdc002e,0xaa580001,0x629d1da6}},	//   _röre, ráða, дицу_, neso
  { {0x2721002e,0x991502e1,0xc334000a,0x644a0f43}},	//   jóna_, нькі, דוף_, _offi
  { {0x8d5a00b2,0xf7710029,0xf3f10092,0x25ad00dc}},	//   _מכשי, هاب_, oạt_, vvel_
  { {0x7ce001d1,0xdb500015,0xb8d400c3,0x7ae21da7}},	//   _förb, _نَّ_, ختنش, bhot
  { {0xbcfb0089,0xdb07002e,0x644a1da8,0x7ae21da9}},	//   _svéh, _frjá, _affi, chot
  { {0xe7080029,0x6a17002b,0x629d01b1,0x6f03039f}},	//   بتون_, _آبزر, deso, _íncu
  { {0x7ce01daa,0x62841dab,0x24e6004a,0x98ac0045}},	//   _töre, _scio, емьи_, _vidă_
  { {0x94750086,0xa3490010,0x321e002a,0x20d4007c}},	//   ودگا, язна_, ętym_, _käiv_
  { {0x660f00b8,0x644a0fb7,0x46150015,0x629d1dac}},	//   ücks, _effi, _كوار, geso
  { {0xa4d50191,0xa6c8002b,0xb143004a,0x51ba0033}},	//   _поді, _تونل_, лнял, чыня_
  { {0x628b00c0,0xf99200a3,0x3cfb000b,0x25d6004c}},	//   _ögon, ארך_, ्वों_, _רוסן_
  { {0x7a360064,0x3989002e,0x7e641dad,0xb4440033}},	//   _kütü, hús_, taip, _рэчк
  { {0x76490064,0xbea30fd2,0x2327006b,0x629d1dae}},	//   ncey, ласк, _пощи_, ceso
  { {0x7e6400df,0x12fb000a,0x65691daf,0x1d26144a}},	// [33a0] raip, _מהקב, nseh, емам
  { {0xb53a004c,0x31570643,0x853a000a,0x0000006a}},	//   פגעש, _ריין_, פגעי,
  { {0x305b0008,0xda6f1db0,0x1b4a005e,0x78a81db1}},	//   _מדיד, ля_, їзди_, _radv
  { {0xb21b0e5f,0x7b2c0061,0xca260459,0x6da60058}},	//   mfær, _aşur, нфли, _كمجم
  { {0xb2f7004c,0xb21b02de,0xf98f0040,0x9a67002b}},	//   עצנס_, lfær, مبو_, رمول_
  { {0x7ae2003f,0xd6d9002a,0x61200030,0x6d8b000a}},	//   shot, ekł_, zöln, _מָלְ
  { {0x7a3601e2,0x5a96008f,0xc053000a,0xb21b081d}},	//   _bütü, _праф, נזה_, nfær
  { {0x8f9b000a,0xf7270033,0x65690012,0x8c1b0643}},	//   פיפי, нцый_, fseh, _זולי
  { {0xceb3000a,0x1a9b004c,0xd6270054,0x7e9b000a}},	//   ריח_, _צימע, ноће_, לסקו
  { {0xa5d70015,0xdce406c0,0xb21b001a,0xe8f70a10}},	//   عبير_, ksič, kfær, _злу_
  { {0xb5fd1db2,0x661d1db3,0x6ee3007c,0x656902f2}},	//   raša, ýskr, _hõbe, aseh
  { {0xb7db0008,0x92580080,0xb5fd0b6c,0xb21b02de}},	//   _מקבי, нают_, mašn, dfær
  { {0x612000dc,0x7792002b,0x629d1db4,0xb5fd1db5}},	//   röln, _شیکا, reso, paša
  { {0x644a04ed,0x27050024,0x2f3b0015,0xb21b1db6}},	//   _uffi, mēna_, كثرة_, ffær
  { {0xb21b002e,0xb5fd01a3,0x2f270004,0x629d1db7}},	//   gfær, našn, еќав, peso
  { {0x539b013a,0x612000f2,0x66d50089,0x39890077}},	//   _זיהו, löll, _páki, yús_
  { {0xb2740080,0x9d15005e,0x781d0065,0x4e1b0058}},	// [33b0] _слыш, вдач, _फर्क_, سترد_
  { {0x612000f2,0x8e140010,0xb5fd0085,0x6abb1db8}},	//   nöll, удуц, kašn, _snuf
  { {0xf0920008,0xb5fd044c,0x9f4b008c,0x539b000a}},	//   _דני_, jašn, ömät_, ּידו
  { {0xb5fd016f,0xf4130053,0xfbd00029,0x7b7400e6}},	//   dašn, אפע_, حتك_, اطلا
  { {0xbea40033,0x6d4f0030,0x61201db9,0x4a4402a3}},	//   _саўк, _utca, köll, унів
  { {0x2be1014e,0x66d5002e,0xfdf6000a,0x39891dba}},	//   पनदा, _jákv, _יצרת_, rús_
  { {0x3f47007c,0x9b89012c,0x39891dbb,0x66e51215}},	//   _jõu_, _تنزل_, sús_, кока
  { {0x65690020,0x291c1dbc,0x0000006a,0x0000006a}},	//   tseh, alva_,   ,
  { {0xd6ce0029,0xd378005c,0x0609006d,0x7ce00123}},	//   تقي_, erć_, ьник_, _höra
  { {0x66d50084,0x656900b8,0x8cc4005d,0x7b2c0011}},	//   _nákv, rseh, रायो, _uşur
  { {0x3f470020,0x65691dbd,0xe6950015,0x7a360061}},	//   _nõu_, sseh, _للاد, _tütü
  { {0x65690020,0x645e0020,0x216a0286,0x6120008c}},	//   pseh, _õpin, мими_, tölo
  { {0xe7300087,0x8cc4000b,0xe4d50015,0x50660015}},	//   _اصل_, रामो, _لتثب, َاسِ
  { {0xb97a000a,0xe3b0002b,0x8899004c,0x20d4007c}},	//   ונשי, _گره_, ובֿי, _näit_
  { {0x6f630004,0x26cf002a,0xb74c004f,0x05160058}},	//   иврз, _kogo_, ּׂמֹ, _جيوب_
  { {0xf77200b2,0xe3b00086,0x26cf001c,0xb21b0e5f}},	//   יקל_, _دره_, _jogo_, rfær
  { {0xb21b1274,0x8c4612ba,0x6e430054,0xdea2002b}},	// [33c0] lgæn, везе, реуз, هیگی
  { {0xb21b0084,0x317b05bd,0xadb70015,0x26cf1dbe}},	//   pfær, _קאיד, ضهما_, _logo_
  { {0x3eab0041,0x5f06008f,0x6ee30020,0xd00a0175}},	//   _fact_, _азна, _sõbe, _цене_
  { {0x26cf07c4,0xca74002b,0xdc290015,0x68e11dbf}},	//   _nogo_, انشک, رسله_, _alld
  { {0x3ea00e8c,0x1e57000a,0xb9940058,0xe8ea02ed}},	//   meit_, _בשכר_, التب, ммдд_
  { {0x7ce000c0,0x3ea01dc0,0xbb560015,0xf74a0015}},	//   _föra, leit_, _لنسب, وجبه_
  { {0xa3e3005d,0xf0930b7b,0x08d50010,0x7ce000c0}},	//   पैम_, ינג_, ыцця, _göra
  { {0xaf770053,0xeb0d005d,0x6d561dc1,0x20d4007c}},	//   דעקס_, िकृत_, opya, _käis_
  { {0xe4e6008f,0x66d50227,0x96b70054,0xe29f001a}},	//   вінн, _náku, тују_, veð_
  { {0x3ea0018b,0x80d1005d,0xb5fd0024,0xd49a0585}},	//   heit_, _सकें, pašn, фри_
  { {0x3ea0018b,0x26cf001c,0x6c7b0008,0xccf3000a}},	//   keit_, _fogo_, וריד, שכת_
  { {0xc2b80036,0x3ea00030,0x6120008c,0xd6cf0015}},	//   влює_, jeit_, söll, _وقل_
  { {0xdb210014,0x316d038d,0x39441dc2,0xa5da0086}},	//   ítés, éez_, _jums_, _تبار_
  { {0x394415ff,0x612000dc,0x104b0080,0xab6512b3}},	//   _mums_, lölj, ьями_, ngüí
  { {0xd8380048,0x601803ad,0x73c30040,0x3eab1dc3}},	//   _taču_, воря_, _نيوم, _pact_
  { {0x3ea000dc,0xe437000a,0xfbe1000b,0x7ee40033}},	//   geit_, _ברוח_, पनसम, ацуе
  { {0x1df80139,0x9f34005e,0xbd680054,0x5d990033}},	// [33d0] веты_, реті, врхе_, экаў_
  { {0x912b0015,0x09be000b,0x2fd8001a,0xf1b2000a}},	//   _تسبق_, ्हैय, byrg_, _פסי_
  { {0x644f005c,0x69d600cb,0x63480046,0xbb850015}},	//   ścig, øyen, _měno, الصي
  { {0x2d8004f9,0x93fb000a,0x3ea000da,0x0000006a}},	//   buie_, ולבי, ceit_,
  { {0xd84e0092,0xddcd002a,0xeab000c3,0x26cf1dc4}},	//   rọng_, ngaż, تعل_, _rogo_
  { {0x1b770015,0x7ce0038f,0x9b450040,0x23c20065}},	//   _لدرج, _hörn, _منسو, षमाद
  { {0xc7950029,0x612000c0,0x0b88009c,0xa7840015}},	//   اشتب, följ, _исти_, لشيو
  { {0x05a90036,0xbb840029,0xead41dc5,0x958502ed}},	//   евий_, _خلفي, _кось, глие
  { {0xb5fd00df,0xa51d0033,0x04451191,0x34f900ce}},	//   rašo, зянi, лепн, ехню_
  { {0x645e0005,0x3ea000b8,0xf494005e,0x53c91114}},	//   _õpil, zeit_, арюю, егом_
  { {0xe7840010,0x69d91dc6,0xdce4003d,0x26cf1dc7}},	//   _вучо, lywe, nsiā, _togo_
  { {0x73e2007a,0xdb96000a,0xc2c5002b,0xb21b02de}},	//   союз, נדרט_, ليپي, rgæn
  { {0xcb12000a,0xd36e002b,0x69d900aa,0x11da0015}},	//   מלט_, يهی_, nywe, روسة_
  { {0x3ea015f6,0x8a16000a,0xe3b10015,0x645c001a}},	//   weit_, רחשו_, _هرب_, ðrit
  { {0x7ce0002e,0x3ea01dc8,0xdee61dc9,0xd007004a}},	//   _börn, teit_, гови, гере_
  { {0x2d801dca,0x51f60067,0x539a000a,0x6da60076}},	//   tuie_, _مسخر, _ניפו, либа
  { {0x5185000d,0x3ea01dcb,0xb21b02de,0x657b0012}},	// [33e0] _куќа, reit_, ngæl, nruh
  { {0x3ea00014,0x612000dc,0xe572000a,0x8cc4000b}},	//   seit_, zölj, מַע_, राधो
  { {0x7ce000c0,0x394400da,0x1c390033,0x78ae016e}},	//   _förn, _sums_, вяць_, _óbvi
  { {0xb4160053,0x20d40020,0x62861dcc,0x298a080e}},	//   אקעס_, _täis_, ngko, еско_
  { {0xf5480023,0x69d90034,0xceb3015b,0x6f041dcd}},	//   _mục_, gywe, _פיש_, mnic
  { {0xf5480023,0xc237000a,0x8b66002b,0xfc67002b}},	//   _lục_, ארנו_, _مارم, _مخفی
  { {0xebe60da6,0xc7af004a,0x7c270850,0x7d0b0030}},	//   _совп, щё_, _борг_, égse
  { {0x6d461dce,0xa3c9000b,0x8f9b000a,0x6f041dcf}},	//   _kuka, ोहन_, תיקי, nnic
  { {0x612000dc,0x1a060a93,0x6f041dd0,0x8b0b004f}},	//   rölj, _спам, inic, _טִמֵ
  { {0x6d46022d,0x44f40036,0x6f041dd1,0x66dc0030}},	//   _muka, рпос, hnic, _kékk
  { {0x443801d1,0x27ea0134,0x63480089,0xd497044e}},	//   är_, _åbn_, _věno, уры_
  { {0xf5480092,0x657b00bc,0x61200030,0x6aa20395}},	//   _cục_, bruh, lölh, neof
  { {0x41e4008f,0xa2f40010,0xf5480092,0x7ae30079}},	//   біра, спяч, _dục_, ënti
  { {0x224c0046,0x672d006f,0x6f041dd2,0xf3f5009a}},	//   ědka_, ňajt, enic, اتیک
  { {0xc4f700f3,0x6d4605d8,0x40350165,0x6aa2118e}},	//   _תמוז_, _auka, ревс, keof
  { {0xf3c90086,0x2f180036,0x6d460375,0xadbd0033}},	//   _جبهه_, гось_, _buka, мабi
  { {0x70550086,0x644f005c,0x8cf50010,0x6d460375}},	// [33f0] _پنجا, ście, азац, _cuka
  { {0xeb0d014e,0xbcfb0003,0xd4910016,0x1e340033}},	//   िक्त_, _avér, hìn_, снуў
  { {0xfff90074,0xd4970008,0x7f1900a2,0x6e951dd3}},	//   _شکست_, רכבת_, _ليدز_, _кину
  { {0x1b780029,0x7ce000c0,0x7ac80015,0xdced0085}},	//   اصلة_, _föro, ُولِ_, krać
  { {0x3f83016f,0xaa68002b,0xf8651dd4,0x69350822}},	//   luju_, امهٔ_, авло, анду
  { {0xe9d8008f,0x612000b8,0x02e2005d,0x2618005d}},	//   ыкі_, völk, _पत्न, _पड़ी_
  { {0x3f831ae7,0x61200012,0x6d460d24,0xeafb0058}},	//   nuju_, wölk, _zuka, _كررت_
  { {0x6d4601e2,0x7c3a0107,0xbbe1000b,0x2b4d0046}},	//   _yuka, _útra, पनीक, _čech_
  { {0xbcfb0089,0xaeb6000a,0xc98700d7,0x88870015}},	//   _uvés, בִיו_, _љуби, _مؤام
  { {0x3f831cff,0x6f040d0e,0xe9ff0016,0xb4651dd5}},	//   kuju_, znic, _ngẩn_, школ
  { {0x3f83016f,0x78a30f55,0x98a70045,0x73060238}},	//   juju_, menv, amnă_, ипоз
  { {0xdced016f,0x3f830085,0xc5950054,0xf98700c3}},	//   brać, duju_, _видј, يب_
  { {0x62860f38,0x6f041dd6,0xe44e0004,0x9ae8000a}},	//   rgko, vnic, _мж_, רַתִ
  { {0x6f040050,0x412a087a,0x6d461dd7,0xdcf60091}},	//   wnic, того_, _ruka, tryč
  { {0xf5480023,0xa2e60080,0x201e002e,0x6d461dd8}},	//   _tục_, _войд, æti_, _suka
  { {0x539a0008,0xb5fd0844,0xdee3006b,0x139a000a}},	//   _ייצו, jašk, ооси, _יבצע

  { {0x7ce001d1,0x78a30079,0x5d6a0121,0xdcf60091}},	// [3400] _förl, kenv, тизм_, sryč
  { {0xccc30080,0x6f0404c6,0x6c56005e,0x6d460085}},	//   обуй, snic, ртає, _vuka
  { {0x307b0008,0x807b000a,0x207b004c,0x3f830085}},	//   _באינ, _בניצ, _באיא, cuju_
  { {0x91830092,0x41b30086,0x6d461dd9,0x6249000a}},	//   _hết_, _امیر, _tuka, ְנוּ_
  { {0x91830023,0x64431dda,0x6aa21ddb,0x19f601ca}},	//   _kết_, _ogni, reof, јџер
  { {0x307a0053,0x6aa2002d,0xdced0085,0xe9e2002a}},	//   דאַנ, seof, vrać, jaźń_
  { {0xe3a704b6,0x61200030,0x999f002a,0x98a5003d}},	//   _بر_, rölh, _czuł_, _ailē_
  { {0xd6d70080,0x3f7b0053,0xab2a07f7,0xe72f0040}},	//   иты_, דאקס, _роба_, وصي_
  { {0x3f83010b,0x645e0020,0xe4c60033,0xdddd002a}},	//   zuju_, _õpik, аённ, _zesł
  { {0x02af005d,0x63b80089,0x3eb200f2,0x0d970008}},	//   _जोड़न, _prvn, hdyt_, סכים_
  { {0x7ce00123,0x66e60579,0x2937004f,0x2d92005b}},	//   _rörl, _кожа, _כאמן_, htye_
  { {0x83fc016f,0x96ba0015,0x57fb000a,0x3f8300b3}},	//   nađi, _جائز_, _בלבו, vuju_
  { {0xe4e60036,0xf8da005d,0xbddb0251,0x35540040}},	//   _війн, _बकाय, _agèn, _انتز
  { {0x3d10005d,0xc5130029,0x3f830375,0x2bab000b}},	//   ़कों_, _وبوت, tuju_, ज़िमा
  { {0x9f05003b,0x2ee90176,0x4384003b,0x644f005c}},	//   موسو, thaf_, _العق, ścic
  { {0x2fcd016f,0x643b0008,0x3f83016f,0x92f40029}},	//   ćeg_, _בעונ, ruju_, _وأيض
  { {0x7ce00014,0xb5fd00bd,0x3f83016f,0x6c6b0054}},	// [3410] _törl, vašk, suju_, вшег_
  { {0x3e650092,0x7ce00c77,0xfd100015,0x5c750033}},	//   ặt_, _förm, وجل_, ёлет
  { {0x7ce001e2,0x01340029,0x78a30938,0xec150015}},	//   _görm, _بعيد, venv, حواد
  { {0xf9910015,0x0b4402a3,0x83fc0160,0x0000006a}},	//   كبت_, інін, gađi,
  { {0xda090086,0xe9a80115,0x19eb0015,0xd2b8000a}},	//   ديشه_, لدون_, خراً_, ילאת_
  { {0x31580008,0x612000f2,0x28c7000b,0x3208000a}},	//   סיון_, töli, लाधि, י֖וּ_
  { {0x4878017f,0x3a87054f,0xd7590015,0xb5fd1ddc}},	//   рсія_, _вызв, دلعت_, maši
  { {0xb5fd1ddd,0xfc4a002d,0xe9450086,0xba740029}},	//   laši, _tríú_, _هنرپ, _واقت
  { {0x28c7000b,0xdb0e1dde,0x78a31ddf,0x26cd013b}},	//   लादि, _urbá, penv, rjeo_
  { {0x612000dc,0xb5fd1de0,0x64440061,0x5b79000a}},	//   lölv, naši, _şiir, ְרָא
  { {0x7ce001d1,0xc2c60029,0xc1d0005d,0xf1a90008}},	//   _börj, ميدي, सङ्ग, _רס_
  { {0x47350124,0xc0490dab,0xfb19000a,0x9733002b}},	//   _унес, _טז_, רוֹמ, _بکتا
  { {0x2721002e,0x65941de1,0x29071de2,0xb5fd1de3}},	//   jóni_, _мацу, onna_, kaši
  { {0xe6040015,0x81d50033,0x270c0046,0x64430091}},	//   _بِهَ, іцяц, měna_, _ugni
  { {0x27310092,0xe8f50092,0xa3550031,0x29071de4}},	//   _cơng_, _đức_, _اختص, inna_
  { {0xe9ff0092,0x628d002d,0xdfcf00e5,0xab620061}},	//   _ngắn_, _gcao, ريق_, çüml
  { {0x270c0089,0xe0da0063,0x0d4a0015,0x91830016}},	// [3420] něna_, _бвп_, اشري_, _tết_
  { {0x2d9200dd,0xdcb10016,0x8d850015,0xee371748}},	//   rtye_, _ửa_, تشفن, сну_
  { {0x8a460015,0xaf0a012c,0xe7a6000b,0x3ea60170}},	//   مَان, _مقدم_, _कैंप, _линг
  { {0x0c370029,0x8f9b015b,0x29071de5,0x0000006a}},	//   حكمة_, _גיטי, enna_,
  { {0x064b0053,0xdce4005c,0x83fc016f,0x4996006b}},	//   _האָט_, esią, rađi, сшет
  { {0xf1b3000a,0xa9c50015,0x7ce01de6,0x270c0046}},	//   פסו_, تزمو, _mörk, děna_
  { {0xddd0002a,0x7794002b,0xace7006b,0x6ecc0065}},	//   żeńs, تیضا, _умра_, हापु
  { {0x2907002f,0x973c016f,0xf105021e,0x2d800b8e}},	//   anna_, _opće, _रद्द_, orie_
  { {0xceb30008,0x78b10123,0xf64f0015,0xb896006b}},	//   ליה_, ökvä, رئي_, _греъ
  { {0xa5340010,0x628d002d,0x7ae21de7,0x7ce00123}},	//   ўноч, _scao, lkot, _sörj
  { {0x4c9b0053,0x3cf0005d,0xad1b0053,0x5335006b}},	//   נשטע, _इतने_, רויר, жент
  { {0x7ae20007,0xfbd3000a,0xb7d70040,0x4422003d}},	//   nkot, לתת_, _دوما_, āk_
  { {0x644f005c,0x63480089,0x656f002d,0x41e40484}},	//   ścia, _měni, ácht, піра
  { {0x0577000a,0x1637000a,0x7ae21de8,0x2d800546}},	//   _פגום_, _הנדר_, hkot, drie_
  { {0x7ae200f2,0x4fc4009c,0x92950033,0x6120001a}},	//   kkot, пста, _дайц, jölu
  { {0x7ce000c0,0x0dcb0001,0xfebb002b,0x2d800293}},	//   _förk, лузи_, داست_, frie_
  { {0x3c470029,0x29070671,0x7d79002b,0x7e6d1de9}},	// [3430] مضاف, ynna_, شمار_, raap
  { {0x61150036,0xa50b000a,0xdce4002a,0x9c47024e}},	//   _єдну, ָּמִ, ysią, схал
  { {0xfb8404ab,0x28c7000b,0xb5fd1dea,0x660f0012}},	//   зычн, लासि, raši, ückz
  { {0x2d800011,0x291e15db,0xcb34006b,0x98ad0061}},	//   brie_, _akta_, пехъ, _ının_
  { {0x61200014,0xcec00089,0x127c004c,0x4eb6000a}},	//   rölv, ářet_, ראדע, _והרב_
  { {0x6eea002c,0x2779000d,0xe918005e,0x718c000a}},	//   _výbe, асиќ_, бочі_, רְאַ
  { {0x47580010,0x60dc0135,0xa6c910a1,0x47d50015}},	//   брыя_, רקונ, илка_, تيغر
  { {0x96b90124,0xba770086,0x612016a1,0x270c0046}},	//   руку_, _داست, lölt, těna_
  { {0x7ae901e2,0x4ae40010,0xceb40008,0x2721000b}},	//   _ilet, _эўра, פיץ_, मतौर_
  { {0x0395006b,0x1e3c004c,0x395d0034,0xe5050015}},	//   ормя, נגזא, mpws_, تبعي
  { {0x7ae9020a,0x130a0080,0x33f50036,0xe3b1002b}},	//   _klet, иной_, ючис, ذرد_
  { {0xdb1c038d,0x8c1a0008,0x92f60127,0x28c7000b}},	//   _arrê, יותי, ічні, लावि
  { {0x7ce001d1,0x63530011,0x612000dc,0x7bde005c}},	//   _förh, _bănc, költ, zypu
  { {0x7ae91deb,0xc952000a,0xc2430033,0x859a000a}},	//   _llet, ומך_, ьняк, _כשנו
  { {0x7ae90c58,0x8ccd005d,0xf456000a,0xf7670067}},	//   _olet, सानो, _ויצר_, با_
  { {0xc7b20008,0x8d660033,0x425600c3,0x7ce0008c}},	//   ובל_, жвае, _بنظر, _törk
  { {0x2d801dec,0xef1701f3,0x7ce002ad,0x644e0073}},	// [3440] urie_, іму_, _höri, žbie
  { {0xdd8f0087,0x61201ded,0x7ae91dee,0xd83e0069}},	//   ئول_, tölu, _alet, íčka_
  { {0xa09b0135,0xb5fd0085,0x272100bf,0x7ae91def}},	//   _דייט, mašu, lónu_, _blet
  { {0x639a0053,0x63bc00c0,0xb5fd00bd,0x539a000a}},	//   יסענ, årni, lašu, ייעו
  { {0xdb210014,0xd337000a,0x6120001a,0xbab70033}},	//   ítás, קרנה_, sölu, ўгіх_
  { {0x91bb0008,0xd8f70036,0x7ae9149d,0xb5fd0007}},	//   ימני, онії_, _elet, našu
  { {0xd90d0086,0x98dd0033,0x2b55002b,0x99e3006f}},	//   دیل_, ысцi, _فیلد_, ĺňan
  { {0x7c2e0198,0x2606005e,0xddc4003d,0x6b7c0045}},	//   _izbr, жчог, rciņ, răgă
  { {0x2900001c,0xc8960054,0x88c60015,0x9f9f0003}},	//   éias_, _мржњ, _وتطل, réée_
  { {0xb4e4005d,0x07a60661,0x4497004a,0x24f80033}},	//   नसे_, _мазн, овью_, ённы_
  { {0xd6da0086,0x1828002b,0x9471002b,0xb6cc0061}},	//   _پوشش_, _اقای_, رگوا, çüsü
  { {0xfc460089,0x8c1b000a,0x11d90015,0x7982002a}},	//   šího_, שוטי, موجة_, orow
  { {0x6120002e,0xc649006e,0x79820034,0xa69b004f}},	//   jöls, _اجمل_, nrow, _כשאפ
  { {0xf3f10092,0x7c2e0107,0x5efd000b,0x7ce00123}},	//   hạy_, _ozbr, रोन्_, _föri
  { {0x270c0089,0x3e6b000d,0x386c0026,0xcf3b0029}},	//   něno_, ишан_, _medr_, لأرض_
  { {0x9f050029,0x877b000f,0xa2d50018,0xa3c9000b}},	//   أورو, יאלי, _ريخت, ोहर_
  { {0x61200014,0x291c052c,0xdd940010,0x83fc016f}},	// [3450] tölt, kova_, маты, rađu
  { {0x61320134,0x7ae90cd8,0x798210ec,0x3d15000b}},	//   gæld, _slet, drow, तकें_
  { {0xf092011f,0x7982005c,0x612000dc,0xddc40007}},	//   _אני_, erow, rölt, raiš
  { {0xdcc4005d,0x539b000a,0x7982002a,0xddd3002a}},	//   राउज़, שיאו, frow, ągły
  { {0xc964005e,0x0ab80015,0x7e56000a,0xe9f8005e}},	//   двій, تطلب_, _מסרב_, онці_
  { {0x4dda0008,0xf5480092,0xe8f8017f,0x291c0263}},	//   _החשו, _cụm_, олі_, gova_
  { {0xf7710029,0x98a2006d,0x7982002a,0x87b9006b}},	//   ءات_, хище, arow, султ_
  { {0xdce4005c,0xf1cb005d,0x79821df0,0x7afb0061}},	//   dsię, ामान, brow, _umut
  { {0xdce4005c,0x7982118e,0x386c0034,0x291c00b3}},	//   esię, crow, _fedr_, bova_
  { {0x22490509,0x291c1df1,0xfcd6004f,0x5c8b004f}},	//   _agak_, cova_, ִ֥ית_, ׁרִ֣
  { {0x644f0050,0x14250010,0x3ea9008c,0xb5c9009a}},	//   ścio, ядом, keat_, _گوشم_
  { {0x8bd6000a,0x657a0125,0xe29a024f,0x2721016d}},	//   לותו_, óchú, щам_, tónu_
  { {0x3392002b,0x76d20058,0x515602ed,0xdce40535}},	//   ولیز, _سيوض, ятну, asię
  { {0xd47900b2,0x55ba0008,0x3d15005d,0xa7fc0064}},	//   _האַל, _למנו, तकों_, _adıy
  { {0x3ea9003e,0xa3cc005d,0x442002e1,0xb5fd1df2}},	//   feat_, रमण_, _цi_, rašu
  { {0xc7b200b2,0xd37a000a,0x25ad0d16,0xf412000a}},	//   עבן_, _הרקט, owel_, _רפה_
  { {0xb5fd003d,0x394500da,0x6da308b0,0x394d00e9}},	// [3460] pašu, _oils_, нита, _nues_
  { {0x6d230001,0x27050024,0xdb1c0152,0x645e0020}},	//   едуз, mēnu_, _irré, _õpit
  { {0x7ac60063,0x50db0008,0x61320134,0x60db000a}},	//   зсле, _החיצ, ræld, _הקינ
  { {0xec130087,0xa3be005d,0x79820ec5,0x25ad0c99}},	//   روند, ीमत_, trow, kwel_
  { {0x25ad0111,0xdebb000a,0xc8c7000b,0x291c18ca}},	//   jwel_, _המכל, लांट, tova_
  { {0x7982003e,0x394d0251,0xdb07002e,0xd90d0086}},	//   rrow, _dues_, _brjó, لیق_
  { {0x3f980440,0x7c2e1df3,0x4873002b,0x2721001a}},	//   ntru_, _uzbr, ردوس, jóns_
  { {0x79820050,0x6beb000f,0x4b7b000a,0x291c1df4}},	//   prow, _הַמַ, _לאלו, sova_
  { {0x39451df5,0x291c1df6,0xf770002b,0xe9d70033}},	//   _fils_, pova_, راژ_, _ект_
  { {0xfdf7000a,0x24f80033,0x9378045f,0xb5fd0085}},	//   פצית_, інны_, обот_, vašt
  { {0x7ce000c0,0xf71a0033,0xf8b30c44,0xdb07001a}},	//   _förv, _ліды_, _רשע_, _grjó
  { {0x52a70029,0xdce40091,0x69c01df7,0x8bd7004f}},	//   أصدق, priė, _krme, פוכו_
  { {0xe2980010,0x7d1e00dd,0x41c401b0,0x76bb000a}},	//   чаў_, kops, нёра, _למאפ
  { {0xa63b013a,0xe4240086,0xd7e60029,0xb5fd00f0}},	//   _הגדר, _يکدي, نك_, rašt
  { {0xc49b0008,0x649b000a,0xc1040021,0x749b000a}},	//   _השות, _הסוד, روفي, _היופ
  { {0xf7090092,0xd4090015,0x9f510030,0x8e480015}},	//   hần_, _بتهم_, nzzé_, كلفك_
  { {0x3ea914e6,0x3f98132b,0xc27c000a,0x63480046}},	// [3470] reat_, atru_, _הרחי, _věnu
  { {0x61ef0064,0x394d0152,0x3f8a003f,0xc172000a}},	//   ınlı, _rues_, bubu_, _שחי_
  { {0x9be40010,0x7b64007a,0x3ea91df8,0xb09a000a}},	//   ніцк, етче, peat_, _ויתר
  { {0x394d02c1,0xfc300015,0x25ad0034,0x628f1df9}},	//   _pues_, احك_, ywel_, ngco
  { {0x2a6d0020,0x6f0d1cb7,0x7e7d0789,0x39450e86}},	//   _veeb_, mnac, _idsp, _pils_
  { {0xa3be005d,0x6f0d00b8,0x475903ad,0x98a21dfa}},	//   ीमा_, lnac, ория_, више
  { {0x2a6d0005,0xe73901c5,0x69c01dfb,0x6f0d1dfc}},	//   _teeb_, оек_, _erme, onac
  { {0x64581dfd,0x657d00dc,0x6f0d0541,0x85790004}},	//   _afvi, ásho, nnac, осот_
  { {0x394d0020,0x6d470410,0x6d4f0045,0xddc4002a}},	//   _uues_, _kija, _juca, dciś
  { {0x7ce00677,0x18680054,0x6f0d1dfe,0x5efd000b}},	//   _föru, _нађи_, hnac, रोत्_
  { {0xd90c002b,0x6b56000a,0xcc56000a,0x6d471dff}},	//   _دیو_, ֽישׁ_, ובתי_, _mija
  { {0x6d5d0209,0x7ce00012,0xdced0061,0x6f0d06ed}},	//   _otsa, _hört, yrağ, jnac
  { {0x2360016f,0x7ce00b1f,0xfa76000a,0x78a40030}},	//   _čije_, _kört, וערת_, őive
  { {0x69b0005d,0x3f8a003f,0x67291e00,0x6d471e01}},	//   _आईसी, tubu_, llej, _nija
  { {0x6d5d1ce1,0x67291212,0x321e002a,0xddcd0061}},	//   _atsa, olej, łty_, tbaş
  { {0xbfc30063,0x27050024,0x3f8a1843,0x6f0d1e02}},	//   ъбск, mēns_, rubu_, gnac
  { {0x44270b7c,0xc6920008,0xddcd1e03,0xed4600d0}},	// [3480] _hyn_, כאן_, rbaş, днап
  { {0x3e6c0023,0x6e2b00b8,0x4c83005e,0x27170016}},	//   ết_, ügba, клув, băng_
  { {0xdced016f,0x7d1e0ea1,0xeb9718fa,0x6d471e04}},	//   građ, rops, дих_, _dija
  { {0x673b0050,0xbae50036,0xdced0061,0x44271e05}},	//   jmuj, нцій, prağ, _myn_
  { {0x6d471e06,0x44271e07,0x7ce00030,0x2d840030}},	//   _fija, _lyn_, _bört, _íme_
  { {0x644f005c,0x91f7000a,0x3c460015,0x67221e08}},	//   ścij, ומנו_, _يَحِ, _skoj
  { {0x98be0024,0x672902c1,0x7ce00061,0xf7090016}},	//   _citā_, flej, _dört, rần_
  { {0xd6d0003b,0x7ce00084,0x6729018c,0xf5e60036}},	//   اقة_, _vöru, glej, діом
  { {0x69c00011,0x7ce000c0,0x7cf20789,0xca97000a}},	//   _urme, _fört, _værf, _קדמי_
  { {0x6f0d0050,0x89db000a,0x6729008c,0x03f80054}},	//   znac, _וחמי, alej, зној_
  { {0x44270176,0x6ef10134,0x6f0d1e09,0xd4970afa}},	//   _cyn_, _håbe, ynac, фры_
  { {0x44270176,0x92580080,0x69c2000b,0x966305c8}},	//   _dyn_, мают_, लिपी, _акце
  { {0x914b0010,0x44270012,0x61f80033,0xf5930015}},	//   ючна_, _eyn_, дняў_, _للنج
  { {0x2ea7000b,0x67200030,0xd5af002b,0x44f70015}},	//   ख़्त, lomj, _خفه_, _يروج_
  { {0x48f90053,0x44270026,0x25ec000b,0xe8df0016}},	//   פּשא, _gyn_, आईवी_, _cuộn_
  { {0x6d47022d,0x8f340010,0x2cb80234,0x9f340033}},	//   _sija, весц, _aard_, весі
  { {0x8d770086,0x50670063,0xdd910015,0x6f0d1e0a}},	// [3490] بازا, _отна, طوا_, rnac
  { {0x6f0d0313,0x2cb80939,0xf5480016,0x973c0085}},	//   snac, _card_, _bụi_, _općo
  { {0x673b005c,0x67200085,0xf1bf016e,0x2fc10012}},	//   ymuj, komj, lvá_, _urhg_
  { {0xdbd10020,0x160e005d,0xf1bf0107,0x7e7d02de}},	//   müüg, ापार_, ová_, _udsp
  { {0x6d5d02d2,0x98dd0033,0xa2f8000a,0x0e5a000a}},	//   _utsa, йскi, ומאה_, _מדרב
  { {0x3eb90334,0xa7b5049d,0x798b0409,0xa3be000b}},	//   _hast_, есиј, rugw, ँटा_
  { {0x67290005,0xddc60024,0xab620064,0x25a61e0b}},	//   tlej, _iekš, çütl, _apol_
  { {0x7ce01e0c,0xe9ff0016,0x44271e0d,0x0000006a}},	//   _förs, _ngần_, _ryn_,
  { {0x7ce01e0e,0x7cf20134,0xf9880029,0x2cb81e0f}},	//   _tört, _færd, _ينفي_, _yard_
  { {0x3eb91e10,0x67bb0115,0x644e0085,0x442700aa}},	//   _last_, _واضح_, žbin, _pyn_
  { {0xc2090008,0xf7700086,0x67291e11,0xeb39000a}},	//   _פה_, _نان_, plej, ּעָש
  { {0x7af90064,0x660a0046,0x3eb9002a,0x44270123}},	//   _çatı, ámká, _nast_, _vyn_
  { {0x44270d4f,0x7cf20293,0x35a507be,0xe5a50783}},	//   _wyn_, _hære, _чалг, _чили
  { {0x64550061,0xd13200c3,0x7cf202de,0x645e007c}},	//   ızis, امس_, _kære, _õpip
  { {0x70530029,0x8fe60015,0x6ee3007c,0x8fa305f8}},	//   انفا, رأسم, _lõbu, ларе
  { {0x6eea0057,0x3eb908a1,0xf772004c,0x539a000a}},	//   _výbo, _cast_, טקל_, _זיקו
  { {0xa2ad000b,0x7cf2079b,0x7206002b,0x290e0034}},	// [34a0] ज़र्, _lære, _سودم, ynfa_
  { {0x3eb9003e,0xe29f002e,0xb19b0053,0x621b000a}},	//   _east_, miða_, _צייכ, _מופק
  { {0xd11d005d,0xe29f002e,0x9a6a0029,0x3eb91e12}},	//   पकरण_, liða_, كمال_, _fast_
  { {0x26dd005c,0x2fc50134,0x6ef10bfa,0x2cb81e13}},	//   _nowo_, ælge_, _påbe, _ward_
  { {0x2cb80ad3,0xc27b000a,0x5337004c,0x7ce00123}},	//   _tard_, פרסי, ײנסן_, _dörr
  { {0x6ef10134,0x317b004c,0xc173000a,0x7cf20723}},	//   _våbe, לאנד, נחו_, _bære
  { {0x7cf200fb,0xf0930008,0x7ce000c0,0xe29f002e}},	//   _værd, אנו_, _förr, yfð_
  { {0x61e600df,0x8f9b00f3,0xfd4d0016,0xda660021}},	//   kykl, ליצי, _nghị, _ساري
  { {0xd2510086,0x60de00dd,0x6720016f,0x56570015}},	//   یند_, _oopm, romj, رشيح_
  { {0xdb1500b8,0x61e60007,0xcd97000a,0xb97b000a}},	//   _erzä, dykl, עדית_, _מרמז
  { {0xccf3013a,0xe29f001a,0x4c9b004f,0x0000006a}},	//   רכת_, eiða_, הביו,
  { {0x7c3a002e,0xf1bf01c9,0x27e10012,0x78ba0030}},	//   _útru, tvá_, ähne_, _hatv
  { {0x66d30015,0x61e60091,0x84e605ab,0xf1bf0046}},	//   _حينئ, gykl, _подж, uvá_
  { {0x75210144,0xe9ce0033,0x313515d2,0xd62b004f}},	//   colz, ркi_, тегр, _מ֥וֹ
  { {0x3eb905d6,0x3ea01e14,0x5457000a,0xf457000a}},	//   _past_, ffit_, _אסון_, _איור_
  { {0x78ba1e15,0xdb230030,0x7cf20c4e,0x0000006a}},	//   _latv, érün, _nærb,
  { {0x2ee91e16,0x3eb91e17,0x61e60eae,0x70c90065}},	// [34b0] rkaf_, _vast_, cykl, िफ़ॉल
  { {0xdbd1007c,0x645a0f43,0x2ee900aa,0x70550067}},	//   püüg, ncti, skaf_, _جندا
  { {0x7cf20293,0x7d050061,0x3eb91e18,0x4b070033}},	//   _bærb, rihs, _tast_, нядб
  { {0xc01c0092,0x99800064,0x0f7a0053,0xf9910015}},	//   _lược_, çiş_, _קארב, لبت_
  { {0x442b0023,0xa2f8000a,0xc334000a,0x99d70067}},	//   ́c_, עמדה_, אוף_, عتصا
  { {0x31580008,0x09e2005e,0x600b000a,0x18a50054}},	//   עיון_, рошн, ּהֵ֔, такм
  { {0x8aa7008f,0xac1803e3,0xd8b800e6,0x61e6080c}},	//   _прад, _зору_, عدها_, zykl
  { {0x78a4010b,0x7cf20293,0x645a1e19,0x99850015}},	//   điva, _være, ecti, _للرو
  { {0x7ce0018b,0x2360016f,0x05760029,0xa2c5000b}},	//   _körp, _čija_, نمية_, ियन्
  { {0x78ba0007,0x6abb0586,0x61e61e1a,0xf622006b}},	//   _gatv, _hauf, vykl, рдьо
  { {0xc6e70191,0x399b001c,0xc01c0092,0x63850063}},	//   _підп, lês_, _dược_, ъгна
  { {0x78ba1e1b,0x91e607d9,0xe1ff1e1c,0x61e60b48}},	//   _zatv, воме, rbón_, tykl
  { {0x399b03af,0xcad60008,0xfad60053,0x98be0045}},	//   nês_, דורת_, דורך_, _uită_
  { {0x6abb00b8,0xf9920008,0x2d8900dd,0xa988000a}},	//   _lauf, ברך_, drae_, עָרִ
  { {0x61e600df,0x3ea0055e,0x1e960033,0xe1ff0030}},	//   sykl, tfit_, крар, lból_
  { {0x2907025c,0x24160008,0xfb820086,0xe1f200a2}},	//   hina_, _שחקן_, یگزی, _نسخ_
  { {0x657b00d9,0x6da60015,0xe1ff0030,0x3ea00030}},	// [34c0] nsuh, ضمام, nból_, rfit_
  { {0x98be00df,0xee3714f4,0xa3d5000b,0xbc630054}},	//   _kitą_, тну_, _सपा_, ивук
  { {0x644f0050,0x207b01ac,0x29071e1d,0x6abb0012}},	//   ściw, _קאטא, dina_, _bauf
  { {0xbad50010,0xe1ff00dc,0x7017000f,0x657b0209}},	//   лічы, kból_, _יחיד_, ksuh
  { {0x78ba00df,0xc3330008,0x7ce00123,0xe1ff0030}},	//   _patv, בוא_, _förp, jból_
  { {0xf1b30008,0xab640061,0xe1ff0030,0x29071e1e}},	//   יסד_, ttüğ, dból_, gina_
  { {0xd7ef0015,0x27e700cb,0x20a4000b,0x8b261de1}},	//   يكه_, gynn_, ख्यध, _адве
  { {0x8c1b039e,0xf5480016,0x399b016e,0xc8780061}},	//   _חולי, _lụt_, bês_, _doğa_
  { {0x399b001c,0x29071e1f,0xe1ff0030,0xaa430323}},	//   cês_, bina_, gból_, _ветл
  { {0x6abb005c,0xb9c50015,0x99330015,0x69c2042f}},	//   _zauf, _حتفه, _نفقت, mvoe
  { {0xd2510086,0x2b9c002c,0x13d30033,0xb3a90061}},	//   ینگ_, níc_, ажэў, _çılı
  { {0x57fb000a,0x5b7b000a,0x958600af,0x85ea011e}},	//   _קלאו, ורטא, _алде, _одев_
  { {0x69c20161,0x394c1e20,0x7ae3016e,0x9f45013f}},	//   nvoe, _kids_, ênti, álí_
  { {0xc50a0029,0x55770053,0xb6350053,0x2d8900dd}},	//   _تتصل_, _יעדן_, _גרױס_, vrae_
  { {0xcebb0001,0xf537000a,0x13b300c3,0x9f450046}},	//   мља_, _שנוי_, _نصيح, šlí_
  { {0xbd6b0001,0x4ea7006b,0x200c006f,0x6e640054}},	//   држе_, ърга, údia_, итуж
  { {0x69c20079,0x8d7400c3,0x3f8a1e21,0xd338004f}},	// [34d0] jvoe, لالا, arbu_, _ברהה_
  { {0x2c7c0089,0x657d00dc,0xcc0b0087,0xdea1002b}},	//   vádí_, áshi, وزان_, _گیری
  { {0xfd440010,0x99d40086,0x69c20234,0x29071e22}},	//   рэтн, یتها, evoe, vina_
  { {0xbcfb002d,0x60080008,0x3f910064,0x7ae01909}},	//   _dtéa, _יִרְ, muzu_, _comt
  { {0x69c2020a,0x394c043a,0xca84005e,0xe8f50015}},	//   gvoe, _bids_, ргій, ُستخ
  { {0x399b016e,0x7c220045,0x29071e23,0x6934062f}},	//   rês_, şora, uina_, анчу
  { {0x3f9101e2,0x97c50015,0x6abb1e24,0x0138000a}},	//   nuzu_, اقبو, _tauf, דרגת_
  { {0xe1ff00dc,0xd6790015,0xdb150030,0x8038000a}},	//   tból_, رحبا_, _oszé, כנוע_
  { {0x613202de,0xc987012e,0x29071e25,0xab64007f}},	//   fæll, _јуби, pina_, rtüş
  { {0x394c1786,0xe1ff00dc,0xe6c3002b,0x04b5006b}},	//   _gids_, rból_, اتژي, усия
  { {0xe1ff00dc,0x657b0044,0x29050061,0xd6db024f}},	//   sból_, ssuh, _imla_, _отд_
  { {0xcad50008,0xf5480016,0xe1ff0030,0x68e11e26}},	//   אוֹת_, _sụt_, pból_, _hold
  { {0x667a000a,0x8afa000a,0x68e11e27,0x64a5110c}},	//   _נטסק, תפרק, _kold, _бала
  { {0x3f91003f,0x2935004c,0xf8b3000b,0x7bc71d5b}},	//   fuzu_, טאָן_, ंजिय, _orju
  { {0x343900b4,0x44240086,0x68e11e28,0xb4bf000b}},	//   _אײַע, _پروف, _mold, ँयी_
  { {0x6ee30005,0xd00f0029,0x2b9c0089,0x5276017f}},	//   _sõbr, ألف_, víc_, _суку
  { {0xf5480016,0x644f002a,0xf652000a,0x62841309}},	// [34e0] _tụt_, ściu, מצן_, _idio
  { {0x01fb000a,0xbf64002b,0x61200012,0xc535000a}},	//   _נפיל, _نگرو, hölz, אָ֣ה_
  { {0x409b0053,0xb09b00a3,0xa2d8000b,0xdb1c1e29}},	//   _אביס, _אייר, याप्, _arrá
  { {0x69c209f2,0x9b250210,0xbaba0015,0x5aa90015}},	//   tvoe, афіл, عداء_, َانَ_
  { {0xddc40024,0x187402e1,0x2b9c0107,0xc27b000a}},	//   laiž, агля, síc_, תרני
  { {0xdd9f0089,0x26cf003f,0x69c20161,0x5dcb000a}},	//   ěňte_, _ango_, rvoe, _אֶלְ
  { {0x68e1048b,0x7ae00107,0xcc770447,0x2d920077}},	//   _dold, _tomt, _תעלה_, luye_
  { {0xe976002b,0x47340004,0xeb1f000b,0x6d4e1e2a}},	//   _مهرد, јнис, यकृत_, _hiba
  { {0x6d4e000c,0xa2d8005d,0x58960087,0x68e10867}},	//   _kiba, यान्, _مجاز, _fold
  { {0x68e1037e,0xd946006b,0x29ce001a,0xa507012e}},	//   _gold, _сези, aðað_, лења_
  { {0x69ba000b,0xe2f900fd,0xe60f002b,0x9cd7000a}},	//   _एनडी, вені_, قشی_, אויה_
  { {0xa1590010,0x973c016f,0x3f910061,0xfc17000a}},	//   каму_, _opći, vuzu_, רקטי_
  { {0x62840026,0x68e10064,0xd6eb000a,0x867b000a}},	//   _ddio, _yold, _רַבָ, _טראו
  { {0xe1040010,0x1ee7002b,0x628402f2,0xbcfb01c0}},	//   бясп, گوری_, _edio, _atén
  { {0xe44f0225,0x73c30015,0xaf090015,0xd818000a}},	//   _عضو_, _هيوم, نقسم_, דֵּש
  { {0xaf370087,0x98a7003d,0x7e770015,0x539b000a}},	//   ارست, ilnā_, طارئ, _ניחו
  { {0x63530045,0x5c75118f,0x60120030,0x232c004f}},	// [34f0] _răni, илат, tűmé, _ר֥וּ
  { {0x7c2e00c0,0x2d8705e3,0x2b4d0542,0xf083009a}},	//   _bybr, čne_, _siec_, _دیسپ
  { {0xfbab0010,0x6d4e013c,0xaa550684,0xba550004}},	//   этай_, _diba, авеш, авеј
  { {0xab2b0115,0xcb681e2b,0xbc380015,0x2d920077}},	//   رسال_, امنه_, اسكا_, buye_
  { {0x4e7a0008,0x2a980029,0xe9870001,0x442e002e}},	//   _בארצ, ائمة_, ућен, _lyf_
  { {0x5dc8000a,0x6d4e1e2c,0x1b770015,0xe0d5004c}},	//   _עֶרְ, _giba, _مدرج, שײַ_
  { {0xf6510029,0x58840010,0x68e11e2d,0x22450046}},	//   يئة_, сыча, _vold, ělky_
  { {0x6d4e003f,0x4585004a,0x69e80125,0x95851e2e}},	//   _ziba, агив, íseá, алие
  { {0x19590010,0x29ce002e,0xe5760139,0x54d5005e}},	//   _разы_, rðað_, азы_, ацну
  { {0xb3a90064,0xb4bf000b,0x94250bb1,0x5c8b004f}},	//   _çıkı, ँये_, импе, ׂרִ֣
  { {0x442e0034,0xb4e50157,0x03a513d0,0x53a51e2f}},	//   _cyf_, _नवी_, шино, шанб
  { {0x69c91e30,0xdced0091,0x96b81114,0xdce4003d}},	//   _kree, praė, _бушу_, oriģ
  { {0x7f570152,0x956700a4,0xc1060015,0x3eb20061}},	//   _auxq, _съед, لوحي, veyt_
  { {0x67240085,0x96a1000b,0x62f6002b,0xe3d50015}},	//   čije, क्रॉ, اسگذ, _نتبع
  { {0x302a005e,0xd079055f,0x6aa90123,0x6d4e1e31}},	//   товп_, ысяч_, _obef, _riba
  { {0xe8df0023,0x2d9202c1,0x539a039e,0x644f002a}},	//   _muốn_, tuye_, _סיפו, ścis
  { {0xed57019c,0xd1320029,0xad650029,0x80c6000b}},	// [3500] иот_, _ومع_, ماله, ायदे
  { {0x717b0008,0x2d920077,0xdd8f0015,0xb17b000a}},	//   _שניס, ruye_, بوك_, _שטיר
  { {0x1d190191,0xbea60010,0x8b260142,0xeb9a11b3}},	//   ують_, _канк, адже, тие_
  { {0x7c2e0107,0x298a0076,0x69c90106,0x0f7b000a}},	//   _vybr, вско_, _bree, _ברטל
  { {0x7c2e0050,0xc333013a,0x6f161e32,0x2a690077}},	//   _wybr, קוד_, mnyc, ñaba_
  { {0x6f160c09,0xc237000a,0x5a33005e,0x69c91e33}},	//   lnyc, ברנו_, цніт, _dree
  { {0xe8df0092,0x6f16005c,0x9d1b000a,0x2721006f}},	//   _cuốn_, onyc, _סולט, lóny_
  { {0x6b830011,0x69c917cb,0x6f161e34,0x8966005e}},	//   ânge, _free, nnyc, _вкаж
  { {0x69c91e35,0x2d801e36,0x3f5c0016,0x1dc9000b}},	//   _gree, nsie_, _líu_, रियत
  { {0x29d30015,0x3a09002b,0x2d801e37,0xf878000a}},	//   _بيكس, _حکمی_, isie_, _תְּל
  { {0xbc7b000a,0x44380cbb,0xc3070015,0x3f5c1e38}},	//   כנית, år_, لبحو, _níu_
  { {0x6f160050,0x2d8013e4,0xe5c60080,0x3f85002e}},	//   jnyc, ksie_, _вско, álum_
  { {0xd9f8005d,0x6f161ad1,0x442e0026,0x26db000a}},	//   ्छित_, dnyc, _wyf_, _שקדמ
  { {0xddcf0011,0x15fb0008,0xc10b0138,0x0000006a}},	//   _lecţ, _שִׁמ, тэме_,
  { {0x853b0008,0x7528005c,0xe53b000a,0x40350004}},	//   _שגוי, modz, _שתור, севс
  { {0x30140036,0x33db000a,0x2721006f,0xfebb002b}},	//   ідтр, _יחוד, fóny_, خاست_
  { {0x25ec000b,0x7cf2063b,0x831c000a,0x8f55009a}},	// [3510] आईटी_, _værn, _שוחז, _گنجش
  { {0xeb1f005d,0x6f16005c,0xebc70001,0xdbc7005e}},	//   यक्त_, anyc, иљен, ищеп
  { {0x6f16005c,0x2d801e39,0xba770015,0xba550015}},	//   bnyc, asie_, لاشت, مناع
  { {0x75280d55,0x6f161e32,0x9a880015,0x59b5000b}},	//   hodz, cnyc, لَمْ_, _आईआर
  { {0xe1ff02c1,0x5df90053,0x7f3a000a,0xa2d8000b}},	//   nzó_, _עפֿנ, _תערו, यात्
  { {0x69c90161,0xed56000a,0x6f0d1e3a,0x0000006a}},	//   _vree, _לבשר_, liac,
  { {0xd0f80008,0x6d450012,0x69c90079,0x3f5c00a1}},	//   שמות_, mmha, _wree, _xíu_
  { {0x6d45002f,0x70180008,0x660d002e,0x6f0d0c09}},	//   lmha, יחוד_, _þakk, niac
  { {0x6d45002d,0x8cdb000b,0x14d50058,0xd9980058}},	//   omha, नापो, مزدح, _نخلا_
  { {0x6f0d04ed,0x6d45002d,0x7528005c,0x6f16066f}},	//   hiac, nmha, godz, znyc
  { {0xf8b3000b,0xd7c8002b,0x6d450012,0x272101c0}},	//   ंजीप, _پونه_, imha, zóny_
  { {0x33f40010,0x6d45002d,0x6132002e,0xdce400bc}},	//   ючыс, hmha, mæli, vpič
  { {0xe2970080,0x6f16002c,0x3f5c002e,0x06560008}},	//   щая_, vnyc, _síu_, _הינך_
  { {0xd4660191,0x6f16005c,0x61460254,0x2a3a004c}},	//   _лише_, wnyc, сега, טערמ
  { {0x33950029,0xc2ea0029,0x43850029,0x201e0064}},	//   _العز, _معظم_, _البق, çti_
  { {0x83640015,0xc3050015,0x6f0d1e3b,0x6b650073}},	//   _بدول, _وبيو, giac, _mėgd
  { {0x82970008,0xf2970008,0x6f161e3c,0x4c560015}},	// [3520] _הדפס_, _הכפר_, rnyc, مضار
  { {0xddcf04f9,0x2d801e3d,0x6f161e3e,0x3f5c002e}},	//   _secţ, rsie_, snyc, _tíu_
  { {0xb5fd00df,0xf53600b2,0x7ce000dc,0x2d801e3f}},	//   rašy, צטער_, _körz, ssie_
  { {0x2d8000dd,0x639a0053,0xaf360086,0x272100bf}},	//   psie_, טסענ, _درخت, póny_
  { {0x08540036,0x8e07006b,0x929b004f,0x0000006a}},	//   овлю, _гняв_, רינת,
  { {0x6eea0107,0x99870045,0x7cf202de,0x2b581318}},	//   _výbu, şişi_, _kærm, _turc_
  { {0x370603fc,0xd7c6004a,0xf72a006b,0x7528006f}},	//   йчив, сёло, лций_, vodz
  { {0x7528005c,0x9c170008,0xe8df0092,0xceb30008}},	//   wodz, _החלק_, _buồn_, ִית_
  { {0x7528002a,0x186a1e40,0x4a5b004f,0x0000006a}},	//   todz, _бази_, _תדמו,
  { {0xe29f002e,0x6f0d1e41,0x0000006a,0x0000006a}},	//   miði_, ziac,   ,
  { {0x63a500b8,0xe29f002e,0x47890036,0x28130015}},	//   _ähnl, liði_, _всім_, _فوكس
  { {0x083b0053,0xe7370010,0x41e70036,0xe61a0036}},	//   _געבל, _лех_, біга, _йде_
  { {0x7982005c,0xbb3b0053,0x26c30024,0xb08b0010}},	//   nsow, טעטי, ējot_, лёве_
  { {0xe1ff1714,0xe3b20015,0xb08b0033,0x7982002a}},	//   rzó_, _فرع_, ыёме_, isow
  { {0xe1ff1e42,0x6f0d0a89,0xd47b00a3,0xdfd8006b}},	//   szó_, tiac, _גאול, бът_
  { {0x7982005c,0x290e003f,0x877b0135,0x6da50015}},	//   ksow, hifa_, טאלי, يمزم
  { {0x28b9005d,0x21640033,0xed5b002b,0x6f0d1e43}},	// [3530] _इसलि, _нтэг, اشرت_, riac
  { {0x6f0d002c,0x2295002b,0x40350004,0x463b004c}},	//   siac, _الکس, _мепс, רעמע
  { {0x6d451e44,0xabb50015,0x6f0d1e45,0x2d4d0160}},	//   rmha, تماث, piac, _užem_
  { {0xf2d400b2,0x539b0008,0x6d45002d,0xfaa5005e}},	//   ּעס_, ריאו, smha, іало
  { {0xb2bc0053,0xe9a80015,0xe1ff002a,0x0000006a}},	//   טמאר, مدون_, rbów_,
  { {0x0b7b0015,0x316901c2,0xb17c000a,0x98e50015}},	//   _مصرع_, _mtaz_, נטור, تكتو
  { {0xf7451a11,0xf8b9000b,0xd7880015,0x97250015}},	//   оеко, _इसीप, مخيم_, يفتو
  { {0x3b640063,0xc99b0015,0x3a750033,0xcff8000a}},	//   _хърв, _مخطط_, _флар, מצוה_
  { {0xceb404dc,0x3ea90a48,0xaeb6000a,0x98a7002a}},	//   ליק_, ifat_, חִיו_, elną_
  { {0xf505005e,0xa2a7000b,0x02b2000b,0xa25b016e}},	//   ізно, ट्स्, ज़्न, udôn
  { {0x28150029,0x59c7005d,0x6ef81e46,0xe79d003d}},	//   _بواس, लिवर, _líba, īmēš
  { {0x4acf005d,0x26c30024,0xdced003d,0xe29a1e47}},	//   _सोमव, ējos_, etaļ, шам_
  { {0x9f4c0089,0x02030210,0x82360115,0x98a7002a}},	//   ádí_, дзян, تردا, alną_
  { {0x6eea0046,0x20d60033,0xd12f0015,0x2d4d0085}},	//   _nýbr, цімс, َمَ_, _džek_
  { {0xc4470086,0x7ce000dc,0xe3b1002b,0xc7ac000a}},	//   _دیدن_, _törz, _آرت_, ְׁמָ
  { {0x9f5900dc,0x7cf200cb,0x7982002a,0x4bda002b}},	//   ázás_, _værm, ysow, یباد_
  { {0x82fa0074,0x2360016f,0x6cd6002b,0x61ef0f43}},	// [3540] _مرکز_, _čiji_, يقرا, cycl
  { {0xe126005e,0xe29f001a,0x2ef200aa,0x3519004f}},	//   _ємни, viði_, skyf_, ׁוּנ
  { {0xaf0a0015,0x9a6a0015,0xdee605f8,0x79820535}},	//   _نقدم_, لمال_, _дони, wsow
  { {0x3f980048,0xa25b006f,0x49ca1e48,0x0000006a}},	//   muru_, jdôl, илен_,
  { {0x3f980213,0x3a200061,0x290e068c,0x09e30033}},	//   luru_, çip_, tifa_, моцн
  { {0x7cf20134,0xe29f002e,0xf77200e5,0x7982002a}},	//   _mærk, riði_, واع_, rsow
  { {0x31a400dc,0x290e1e49,0x7982051e,0x645d005a}},	//   höz_, rifa_, ssow, ěsil
  { {0x31a400dc,0x78ad0085,0x27e00085,0x65aa0054}},	//   köz_, đava, ćin_, атог_
  { {0x26c2032c,0x1efb004c,0x75d40021,0x85460033}},	//   ľko_, ילקע, سيدا, жэне
  { {0x69c00014,0x3202002c,0x3f981e4a,0x97c60015}},	//   _isme, dzky_, kuru_, _وتضم
  { {0x4c9b0053,0xb68a0086,0x8857000a,0x4427005e}},	//   סשטע, _نپال_, _ושבע_, жцям_
  { {0x46d1000b,0x95ca0054,0x3f980f81,0x68e81e4b}},	//   _दोपह, _вука_, duru_, _hodd
  { {0x41e70033,0x31a40061,0x68e80061,0x471b004f}},	//   ціна, göz_, _kodd, _דואג
  { {0x32540010,0xf993000f,0xe44f002b,0x3f91002a}},	//   ьвяр, ורש_, عضی_, trzu_
  { {0x8854000a,0x3f850003,0x7497000a,0x50c80033}},	//   לֹֽא_, élu_, _ודוד_, цыям_
  { {0x33fb0008,0xff070010,0x926b0180,0x68e81e4c}},	//   _כהונ, цягн, _трка_, _lodd
  { {0xa2d8000b,0xe167002b,0x9d550015,0xa25b1d2c}},	// [3550] यार्, _بدبي, سنات, ndôm
  { {0x68e80335,0x629d0134,0xc534000a,0xf083002b}},	//   _nodd, lgso, פָּה_, _زیرپ
  { {0x69c000df,0xa3cd014e,0xfb840010,0x00ba000f}},	//   _asme, रिय_, дычн, _המתמ
  { {0x60c500f2,0xae0c000b,0xb4e7000b,0x629d1e4d}},	//   _hahm, _सेवन_, _यक्_, ngso
  { {0x7e7d03eb,0x68e81e4e,0x18690a3f,0x0000006a}},	//   _iesp, _bodd, бали_,
  { {0x7cf20293,0x91bc000a,0xa3cd000b,0x8d5a000a}},	//   _nærh, ימדי, रिम_, _לכשי
  { {0x4758008f,0xf7710002,0x8bd9005e,0xaab70015}},	//   орыя_, راث_, _умвс_, _وإرش
  { {0x1ab40036,0x6d5d1e4f,0x6d550061,0x2607000b}},	//   _обся, _kusa, _hiza, िछली_
  { {0xf42900f2,0x20cb000b,0x4afa004c,0x68e800e7}},	//   keää_, ायाध, _פּלײ, _fodd
  { {0x7afb0084,0xdb2600f2,0x9f4300f2,0x60c500b8}},	//   _hlut, öpöy, lyjä_, _nahm
  { {0xd91a0008,0x94750086,0x7ae91024,0xe3d50015}},	//   _פועל, يدگا, _koet, ستدع
  { {0x92b6003b,0x883a009d,0xf770002b,0x6d5d016e}},	//   أحدا, _התעו, _شام_, _ousa
  { {0x7ae90298,0x37080029,0x7cf30064,0x6d5d0776}},	//   _moet, _بْنُ_, _kırı, _nusa
  { {0x7cf200fb,0x7ae90005,0xa0671e50,0x3f981e51}},	//   _værk, _loet, зара_, turu_
  { {0xd9b8000b,0xa113002b,0x6d5d1e52,0x68e30079}},	//   _इन्ट, روفت, _ausa, ijnd
  { {0x8d660010,0xbf160015,0xd356000a,0xe37a000a}},	//   звае, أورب, _ציפי_, _פרפר
  { {0x12eb0008,0x3f981e53,0x7e640273,0x7e7d03fe}},	// [3560] _הַיּ, suru_, rcip, _desp
  { {0xdd8f003b,0x38af0064,0x7e7d007c,0x7cf2001a}},	//   اول_, nırı_, _eesp, _kæri
  { {0xdb050152,0x7afb00b8,0x68e80026,0x905b000a}},	//   othè, _blut, _rodd, _לכית
  { {0x68e804ed,0xdb050152,0x76590026,0xe9da0080}},	//   _sodd, nthè, _ngwy, йке_
  { {0x7ae200f2,0x638200dc,0xa3cd000b,0x38af0061}},	//   rjot, _kíná, रिड_, kırı_
  { {0x7e7d0050,0x7afb1e54,0x7bce0085,0x0000006a}},	//   _zesp, _elut, _trbu,
  { {0x6d5d018b,0xf76f0002,0x7afb1e55,0x224c0046}},	//   _zusa, هاي_, _flut, ědky_
  { {0x8c1b0008,0x8f9b000f,0xdc37004c,0x7afb1e56}},	//   _הולי, ציפי, _זאלט_, _glut
  { {0x69c00aee,0xd7ca002b,0x443a0085,0x68e80b58}},	//   _usme, _گواه_, _šp_, _todd
  { {0x76590026,0xb8650021,0x2003002a,0x7ae91e57}},	//   _egwy, _قامو, yzji_, _zoet
  { {0xa295042b,0x60c515da,0x92951e58,0x0000006a}},	//   мані, _rahm, манц,
  { {0xb7db0008,0x883b000a,0x9f45006f,0x6b650091}},	//   _לקבי, _פתאו, šlú_, _jėga
  { {0x6b650007,0xd7050015,0x5f00000b,0x23600085}},	//   _mėga, _تظلي, रसन्_, _čiju_
  { {0x7cf21e59,0x55bb000a,0x6ef80030,0x6d5d1e5a}},	//   _færi, _למדו, _bíbo, _rusa
  { {0x443a0023,0x29370053,0xe53b000a,0xdfd8006b}},	//   _áp_, פאלן_, _התגר, път_
  { {0x539b013a,0x961d0024,0x6d5d0375,0xc7d7000a}},	//   _היהו, saņe, _pusa, הולי_
  { {0x60c501e2,0xdddd0024,0x88c40089,0x9f4c0089}},	// [3570] _tahm, _iesū, _změň, ádá_
  { {0x81fc0008,0x7ae91e5b,0x9df80080,0x7afb1e5c}},	//   _להחז, _soet, чнут_, _slut
  { {0x7e7d0064,0xf09204dc,0x6d550d60,0xa3be000b}},	//   _tesp, _בני_, _viza, ुटि_
  { {0xa3cd005d,0xfbd00029,0xbcfb0003,0xdb26002b}},	//   रित_, دتك_, _suéd, وولی
  { {0x6d5d00b6,0x7ae9016b,0xdea4002b,0xe29f001a}},	//   _uusa, _voet, _سیلی, liðs_
  { {0x4dda000a,0x80c30065,0x0000006a,0x0000006a}},	//   _וחשו, िएटे,   ,
  { {0x7ae91e5d,0x0000006a,0x0000006a,0x0000006a}},	//   _toet,   ,   ,
  { {0x8cdb005d,0xd6ce0029,0x628d002d,0xdbd7008c}},	//   नावो, لقى_, _ndao, rääv
  { {0x917a0023,0x38af0064,0xdbd7008c,0x2b440033}},	//   _mật_, tırı_, sääv, _чэрг
  { {0x8389006d,0xb867002b,0xe1ff002a,0x628d0045}},	//   обов_, _رائو, ybór_, _adao
  { {0xccf200f3,0xebd5005e,0xa445005e,0x6ef81e5e}},	//   דכי_, звiл_, ьнод, _bíbl
  { {0x395f0020,0xc8780064,0xe29f002e,0xf089000a}},	//   _kuus_, _doğu_, ggð_, _כנ_
  { {0x64a519bf,0xa06a0033,0xe60e01b7,0xf5480016}},	//   _жала, жага_, _рд_, _lụy_
  { {0x395f0020,0x75440033,0x7bda0030,0x46bd000b}},	//   _muus_, _зніз, _átug, ्यवह
  { {0x917a0092,0x8fa31dd3,0x1fb515df,0x2f5602ed}},	//   _bật_, каре, нстр, дтас
  { {0x0eaa0033,0x6ef804e6,0x0000006a,0x0000006a}},	//   ўкай_, _víbo,   ,
  { {0x395f020a,0x312600d7,0xe1ff0077,0xa1c30033}},	// [3580] _nuus_, _одиг, lcón_, _абыд
  { {0x96dc0045,0x0000006a,0x0000006a,0x0000006a}},	//   ăşiţ,   ,   ,
  { {0x6c4a0029,0xe1ff0533,0x80db000a,0x50db004f}},	//   آلاف_, ncón_, _וחיז, _וחיצ
  { {0x200c006f,0x7cf20013,0xa2d40065,0x0000006a}},	//   údiu_, _nærv, _बोम्,
  { {0x3160001c,0x09ba0029,0x387e1e5f,0x7bda12d7}},	//   _juiz_, تطاع_, _petr_, _štud
  { {0xd90d009a,0x0000006a,0x0000006a,0x0000006a}},	//   میق_,   ,   ,
  { {0x31600f14,0xb906000b,0x08d50033,0xdca31e60}},	//   _luiz_, _बच_, эцця, _шари
  { {0x1efb0053,0x758a12d2,0x8c430180,0xe6630238}},	//   ַליע, осов_, _ресе, ктьо
  { {0xddcd0011,0x3ea00035,0xd5ba005e,0x0f37000a}},	//   mbaţ, igit_, іси_, ורקט_
  { {0x1c22005d,0xd5470015,0x8934000a,0x98a70046}},	//   _मशाल_, وليو_, _נָּא_, ilně_
  { {0x38cb0086,0x8c49000a,0xb9020157,0x4cbb004f}},	//   _باقی_, ּׂרִ, धा_, חזיו
  { {0x0cbb000b,0x7d0b0030,0x82d400ce,0x0000006a}},	//   _उस्म, égsz, воює,
  { {0xe7070086,0x54e60015,0xe29f001a,0xe4d60015}},	//   _تسلی, _يستق, rgð_, _يقصد
  { {0x672d044c,0x04580015,0xdb051e61,0x98a70046}},	//   čaje, _علبة_, rthé, dlně_
  { {0xe1f90007,0xd5c80092,0xc49b000a,0x93770021}},	//   šų_, _hề_, _ושות, _قصير_
  { {0xceb80001,0x867b0053,0xd5c80016,0x934402d9}},	//   мљу_, ַרבו, _kề_, _инје
  { {0x9f340036,0xc05b0127,0x6ca7006b,0x917a0016}},	// [3590] теті, _мін_, дреж, _vật_
  { {0xe97e005e,0x0c74002b,0xd011002b,0xf36a004f}},	//   _свiт_, ندمد, _ملخ_, ַדְּ
  { {0xd5c80016,0x98a7003d,0xbca40015,0xca790058}},	//   _lề_, jonā_, ضمني, كماش_
  { {0x1ae4005e,0xbcfb1e62,0x8f9a05bd,0x3f851e63}},	//   коєм, _québ, _צירי, šlus_
  { {0x38c40007,0xd5c80016,0x961d003d,0x18691e64}},	//   kūrė_, _nề_, kaņa, пали_
  { {0x270c0089,0x98a70024,0x6d88000a,0xf9900021}},	//   měny_, fonā_, _קָרְ, شبه_
  { {0x6c540010,0x58840033,0x38c40091,0xa7550054}},	//   _акру, тыча, dūrė_, нђић
  { {0xa3cd005d,0xd5c80092,0x0058000a,0xe7b20067}},	//   रिस_, _bề_, ושות_, اميد
  { {0xc8ab0063,0x270c0089,0x79a4077a,0xe619127d}},	//   _мъже_, něny_, _архе, яди_
  { {0x61320134,0x6b650091,0x56260033,0x31601e65}},	//   jælp, _jėgo, эжым_, _ruiz_
  { {0x260f0065,0xd36e009a,0x6b650073,0x36d51572}},	//   _तेरी_, یهی_, _mėgo, _пожр
  { {0x44390024,0xdb070003,0xe1ff010d,0x2d8b055c}},	//   ās_, élèb, rcón_, _ovce_
  { {0x6d47022d,0x3afa0053,0xbbac000b,0x38c40091}},	//   _ohja, פּטע, _टङ्क, būrė_
  { {0x64a51e66,0x270c0046,0xdbd7019a,0x673b1e67}},	//   _чака, děny_, _käär, lluj
  { {0xb4fa000a,0x6d4b0091,0x9522002b,0x8464006b}},	//   _מפסי, įgal, _حکيم, _ръче
  { {0xdbd70e2b,0xd00f0015,0x1288002b,0x33920015}},	//   _määr, حلف_, _کمکی_, _إليز
  { {0xdce60048,0x531b00a3,0x62861e68,0x8e0a0004}},	// [35a0] _atkā, _מוקצ, mako, чнав_
  { {0x3e7e0092,0x62861e69,0xd257000a,0x2f210091}},	//   ắt_, lako, _אשפה_, bėgo_
  { {0xeb97004a,0xbcfb016e,0x907b000a,0x2056005e}},	//   еих_, _suéc, _מטיי, _ятир
  { {0xfe720029,0xba260818,0x98a70046,0xd37a000a}},	//   _حدد_, ндек, plně_, פרנט
  { {0x82770053,0x71250086,0xddcd0045,0xceb3000a}},	//   גענע_, _سریل, rbaţ, _גיר_
  { {0xc2130008,0xc7c6068e,0x673b00bc,0x6f04016e}},	//   נהג_, есии, eluj, lhic
  { {0x8c43087a,0x629a0007,0xa09b00f3,0xe6bd000b}},	//   _бере, ėtoj, ליסט, ्यूज
  { {0xa6aa0029,0xcf93000a,0xcc3b004c,0x6616001a}},	//   سابق_, אטה_, _זעלט, _þykk
  { {0x62861e6a,0xe56f002b,0x3e5b000a,0x644301c2}},	//   dako, یطی_, הדפס, _azni
  { {0xd5c800a7,0x03f80001,0x6aa20026,0xc42a0f5c}},	//   _về_, дној_, lgof, зюме_
  { {0x5c970053,0x04580015,0x4438020b,0xb865006e}},	//   עכטע_, بلدة_, ær_, _شالو
  { {0x6aa20026,0x8c1b000a,0x57fb000a,0xd5c80016}},	//   ngof, לויי, _מלבו, _tề_
  { {0x961d0024,0x61f80033,0xdb0701f6,0x394e03a0}},	//   paņa, еняў_, éléb, omfs_
  { {0xa3cd005d,0x80cb000b,0xc4c60015,0xe3af002b}},	//   रिश_, ायें, _ستتو, جری_
  { {0xa2d8005d,0x40350004,0x7537004c,0x64a303ae}},	//   याख्, тевс, _ראוד_, _саја
  { {0x643b0008,0x9f6000dc,0xb7db000a,0xf43b000a}},	//   _מעונ, árás_, הקלי, _מתוש
  { {0x3d940457,0xdd9401b0,0x6ef80125,0xdd910040}},	// [35b0] литр, латы, _míbh, شوا_
  { {0x621c000a,0x75cf0030,0xac2715d2,0x0000006a}},	//   _מוחק, lőzö, нфек,
  { {0xe47b0053,0x3156004f,0x2d891e6b,0x0000006a}},	//   פראכ, _שיתן_, ssae_,
  { {0x9e1506b4,0x8bc40010,0xea000092,0x6f041e6c}},	//   _адмі, ысуд, uyết_, chic
  { {0xdb1c00dc,0xab64002a,0x80c5000b,0xdbd705ff}},	//   _arró, ężar, ाजपे, _säär
  { {0xe9d80033,0xe8f801f3,0x62861e6d,0xdbd701be}},	//   экі_, нлі_, zako, _päär
  { {0x7cf200fb,0xdce4002a,0x1dc9000b,0x62861e6e}},	//   _vært, jpię, रिकत, yako
  { {0x7cf20084,0xdbd70458,0x98b60024,0xe7390080}},	//   _færs, _väär, īgās_, ьей_
  { {0xe7f3005d,0xdb1c0077,0x62861e6f,0xf9900058}},	//   _अथवा_, _erró, vako, _هبل_
  { {0x7cf20084,0xd9550086,0xf8070004,0x3f980034}},	//   _hærr, _شناخ, _пчен, yrru_
  { {0x2c37000a,0xe8d6000a,0xdbce0061,0x62861e70}},	//   עָ֖ם_, _שוער_, rıça, tako
  { {0x64430057,0x4612002b,0x67b80015,0x86c4009a}},	//   _vzni, اویر, _سامح_, _ميمن
  { {0xe5e50086,0x6443005c,0x9ae80008,0x13070033}},	//   _جزای, _wzni, תַתִ, тняй_
  { {0x798b0034,0xa06a0004,0x8644005e,0xdd92002b}},	//   isgw, ќава_, _сніж, یوز_
  { {0x64430024,0x7412002b,0x25ad1e71,0x6f0401fd}},	//   _uzni, _پويا, ltel_, thic
  { {0x7cf2002e,0x539a000a,0xf3c80015,0x8fa30180}},	//   _nærr, _חיקו, _أبوه_, јате
  { {0xc2c90029,0xed5a05e6,0x9ea7006b,0x7bd50061}},	// [35c0] _سبيل_, доа_, ъвта_, _arzu
  { {0xc19b000a,0xbcfb0003,0x7bd5002a,0x5e550015}},	//   _קשיי, _stér, _brzu, ائِر
  { {0x7cf20bfa,0x6f041e72,0x961d003d,0xe0fb000a}},	//   _særs, phic, kaņo, _חליל
  { {0x4e7a0029,0xdb1c0144,0x7bd5002a,0x0000006a}},	//   _تحدد_, _arrò, _drzu,
  { {0xe8941e73,0xa2a5000b,0xd00f002b,0x62841e74}},	//   галь, _कास्, _هلی_, _meio
  { {0x66090048,0x6616002e,0x8884002b,0xa2d4000b}},	//   dzek, _þyki, ایان, _बोस्
  { {0x38cb0086,0xf0930008,0x711b000a,0x6d5c02f2}},	//   بانی_, בנו_, ווספ, _iira
  { {0xda650029,0x3e860007,0xdb1c0144,0x6d5c1e75}},	//   _ماكي, būtų_, _errò, _hira
  { {0x28e2014e,0x6f0304f9,0x7bd5002a,0x35e30033}},	//   पादि, _înce, _zrzu, ацэв
  { {0x7c3c002e,0x672d016f,0x6d5c1b8c,0xc7960033}},	//   _kyrr, čaja, _jira, _арды
  { {0x4c9b000a,0xd91b000a,0xdc9b0643,0xa3190098}},	//   וביו, _קובל, וייל, ежну_
  { {0x6562008c,0x6d5c1e76,0xc7f7000a,0x6b830045}},	//   _tuoh, _lira, _שזאת_, ângi
  { {0x6609005c,0x4a7b0008,0x7dfa003d,0xc5940004}},	//   czek, ורכב, _jāsā, _силј
  { {0xe9ce0010,0xa2a5000b,0xe8c00065,0x0000006a}},	//   скi_, _काव्, _एसोच,
  { {0xa4380191,0x54330086,0xb4be000b,0xf55b000a}},	//   _язку_, _پرور, ँजी_, _קדומ
  { {0x21670080,0x798b0026,0x97ab000a,0xbcfb0077}},	//   _итог, ysgw, וֹמֵ, _cuén
  { {0x6d5c1e77,0x98a7002a,0x5cab0054,0x7cd90b1e}},	// [35d0] _bira, loną_, дњег_, нмар_
  { {0x7c940029,0xfd390015,0x4238000a,0xc238000a}},	//   لشما, ركاب_, _בנחל_, _ברחו_
  { {0x7c3c0176,0x9f4500dc,0x6d5c1e78,0xa088000a}},	//   _cyrr, áló_, _dira, _בְרִ
  { {0xba740015,0x3ffa000a,0x3e350015,0xd259003d}},	//   لاهت, _נפרע, _مفجر, žņu_
  { {0x7e2b0036,0x991513ae,0xdd8401b0,0x7bd5002a}},	//   _ціна_, лькі, _высп, _wrzu
  { {0x7c3c0084,0xe0d50053,0x2dda0053,0x88c8005e}},	//   _fyrr, רײַ_, _אַלב, клів_
  { {0x6e3d0176,0x7c3c0176,0xf0b8000a,0x98a70b48}},	//   _hysb, _gyrr, דלור_, joną_
  { {0x7e6d0849,0x27e9016f,0x07b60015,0xa3d6000b}},	//   ncap, ćan_, اهية_, सिन_
  { {0x25ad1786,0xd5ae0015,0x05760015,0x86e80015}},	//   utel_, كفي_, همية_, ضعيف_
  { {0x2ed0005d,0x13e90080,0x69c90020,0x66091e79}},	//   _हफ्त, емой_, _isee, rzek
  { {0xd7c80086,0x660900dc,0x2907002d,0x25ad1e7a}},	//   _لوله_, szek, mhna_, stel_
  { {0x1614000b,0x9bb6000a,0x98be0091,0x91e607ec}},	//   _तेवर_, נהרה_, _bitė_, гоме
  { {0xa2a50372,0xfad6000a,0xe4c8002b,0x9756000a}},	//   _कार्, אורך_, ربین_, _עינו_
  { {0x361a00b2,0x2569002f,0xa2d4005d,0xf5920029}},	//   _אונד, _iúl_, _बोर्, _الوج
  { {0x60260063,0xd3b90033,0x443c0091,0x98a7002a}},	//   удва, _чулі_, _gyv_, coną_
  { {0x1ddf000b,0xb4440033,0xbcfb1e7b,0xf8c0000b}},	//   नमंत, _тэчк, _stép, _एस्प
  { {0xd7f80092,0x7f5d1e7c,0x715a0054,0x25691e7d}},	// [35e0] _ngăn_, _disq, _прос_, _júl_
  { {0xee370800,0x290700bc,0x6c86012c,0x7c3c1e7e}},	//   уну_, jhna_, الام, _pyrr
  { {0x69c90209,0xb4fa004c,0x63a10030,0x6a16002b}},	//   _asee, עלער, nuln, گبار
  { {0xab770029,0x6d5c00e8,0x8f9b000a,0x8a460015}},	//   امنا_, _wira, _איטי, هَان
  { {0x427b0053,0x6a16002b,0x98a71e7f,0xada301f3}},	//   גאנג, دبار, zoną_, _лаял
  { {0xd9f70033,0xba1700c3,0xa3d3000b,0x63a10030}},	//   ыніц_, ديها_, हटा_, kuln
  { {0x672d060b,0xf093000a,0xa2a5000b,0x63a10030}},	//   čajn, זנו_, _काल्, juln
  { {0xb6f40e88,0xa2d4000b,0xdbd2007c,0x7fd7000a}},	//   рзиј, _बोल्, _müür, רוקס_
  { {0xe9da0191,0x3b07000d,0x2569002d,0xfaf70008}},	//   _яка_, _сето_, _cúl_, _עצמי_
  { {0x38c80086,0x29071e80,0x63a100da,0x78ad006f}},	//   _جاری_, chna_, fuln, ľový
  { {0x4c9b00b2,0x07b70015,0x5c9b004c,0x78ad0de4}},	//   עשטע, _مهلة_, עשטײ, žový
  { {0x98a7005c,0xc6e30033,0x34470033,0xdb050125}},	//   roną_, _гішп, ычын_, othá
  { {0x7f5d0152,0x92580080,0xd1310015,0x395e1e81}},	//   _risq, лают_, قمح_, _kits_
  { {0x98a70091,0xbcfb039f,0x0000006a,0x0000006a}},	//   poną_, _cuél,   ,
  { {0x395e016b,0x63a101d7,0xffe404e5,0xb4fb004f}},	//   _mits_, culn, бютн, _אלגר
  { {0x395e1e82,0x7cf204d1,0x93930058,0x3e350058}},	//   _lits_, _særp, _اجوا, لفأر
  { {0x2d8f00dc,0x7f5d1e83,0x8d7400c3,0x9d151e84}},	// [35f0] ége_, _visq, مالا, адач
  { {0xfd130021,0x4c95004a,0x30a7006b,0x3c95004a}},	//   حجر_, рижс, _срив, рижё
  { {0xa3cd005d,0x515a0008,0x1cb800e6,0x9c4700e2}},	//   रिए_, _שכתו, طالب_, ухал
  { {0x04370053,0x4ffa000a,0x0000006a,0x0000006a}},	//   נטאש_, _סִינ,   ,
  { {0xdd0101e2,0x7cdb0024,0x6b650007,0xaa880015}},	//   ştır, _pārē, _mėgi, انهم_
  { {0x6ce70036,0x69c900bd,0x395e0024,0x2d040033}},	//   _сіме, _vsee, _cits_, _лясг
  { {0x80ad005d,0xd0f8000a,0x25690125,0x66e50004}},	//   _जाने, רמות_, _súl_, иока
  { {0xb8fc0372,0xfb580029,0xdb23002b,0x05b50033}},	//   _तो_, _مؤقت_, _اوری, асоў
  { {0xe1ff005c,0xeed6000a,0x2618000b,0x395e00da}},	//   mców_, בֵית_, _बेदी_, _fits_
  { {0xe9d80015,0xe1ff002a,0xa31e0046,0x63a11e85}},	//   _حذفت_, lców_, ědčí_, tuln
  { {0x044518a9,0xb909005d,0x0326000d,0xd8740225}},	//   ренн, या_, идон, _طالب
  { {0x25690014,0x216a03e7,0x63a11e86,0xcad5000a}},	//   _túl_, кими_, ruln, בוֹת_
  { {0x61460491,0xd1c70010,0xe297054f,0x3f86006f}},	//   иема, аляе_, шая_, _ňou_
  { {0x84670063,0x63a100dc,0xd6180087,0x859a000a}},	//   _съде, puln, _حتما_, _ישנו
  { {0x351a0008,0x3f16000d,0x6439004c,0x80c5000b}},	//   _בוסנ, аќат, _בײַג, ाज़े
  { {0xaad4000b,0xe1ff002a,0x8236002b,0x52760b1e}},	//   _ठोंक, jców_, _پربا, _туку
  { {0xa3cd005d,0x433b0008,0x29050356,0x6c760029}},	// [3600] रिक_, _בעקב, _olla_, لطائ
  { {0x80ad014e,0xa1130015,0x40961e87,0x9c5a0015}},	//   _जाये, _وويت, _трит, نجاز_
  { {0x309b0008,0x8ca7005d,0x6cd30031,0xa09b00a3}},	//   _בשימ, _चारो, تقلا, _בייט
  { {0xa3d6005d,0x98a70007,0x6c55005e,0xcc490015}},	//   सित_, monę_, стує, اؤكم_
  { {0x6f030011,0xddc40007,0x8289000a,0x395e00da}},	//   _înca, rbių, רְעֶ, _pits_
  { {0x39130036,0x89370010,0xdb051793,0x59370033}},	//   омір, апіс_, rthá, азіў_
  { {0x26cf00b6,0xb8ce005d,0xf72a0080,0x37060080}},	//   _bago_, _का_, кций_, ичив
  { {0xd6d71e88,0xb8820089,0x8f9b00a3,0x29051e89}},	//   ать_, _řídi, דיקי, _ella_
  { {0x6ed6002a,0x26cf1e8a,0xa96a0891,0xf52609fd}},	//   _zębó, _dago_, _риза_, ифон
  { {0x04660099,0xccf1000a,0x136a0350,0xd9461e2e}},	//   штим, ִ֛י_, кшми_, _тези
  { {0x9cd90053,0xb8dc000b,0x6cfb000a,0x22490030}},	//   אַרז, ेज_, דפיס, _szak_
  { {0xd6cf0029,0x291c05ba,0x57fb000a,0xd7fb000a}},	//   _يقل_, liva_, _שלאו, _שהאל
  { {0x8b570053,0x50670eb0,0xa4d40036,0x26c40796}},	//   ייטס_, итва, _голі, memo_
  { {0x45fb000a,0x65330015,0x291c1e8b,0xc307002b}},	//   _בהדג, _وروذ, niva_, ابگو
  { {0x8877000a,0x14db000a,0x33940058,0xef67009b}},	//   שתלב_, _שַׂמ, _البز, ръго
  { {0x2fcd005c,0xc43b0008,0x40340080,0x644a0024}},	//   łego_, _שתהי, цесс, _izfi
  { {0x22491e8c,0x629a0091,0x291c0c9e,0xe1d900ce}},	// [3610] _uzak_, ėtot, kiva_, _сдпі_
  { {0xe1ff0050,0xd6570008,0x61fd0107,0x291c02c6}},	//   wców_, שימת_, mysl, jiva_
  { {0x41d5000b,0x7055002b,0x5238002b,0x61fd04f8}},	//   दिवस, _دندا, _مسیح_, lysl
  { {0x26c4065d,0xf21c000b,0xab640033,0x6e320046}},	//   jemo_, _पेड़_, івіл, _žebř
  { {0xe1ff005c,0x66e5000b,0x26c41e8d,0xdb150030}},	//   rców_, कासक_, demo_, _iszü
  { {0x7c280085,0x7e56000a,0xa3c6000b,0x3ea91e8e}},	//   _ždre, _לסרב_, उबा_, lgat_
  { {0x3c450029,0xa0980008,0x26cf0c98,0x260f000b}},	//   _طَرِ, בדוק_, _pago_, _तेजी_
  { {0x06c90036,0x656f0107,0x3ea91329,0x44290085}},	//   угий_, ícho, ngat_, _ća_
  { {0x291c1e8f,0xd4d50033,0xa3a9000b,0xdb0502de}},	//   biva_, бінэ, गून_, tthæ
  { {0xdb1c038d,0x98f40029,0xf494005e,0x6aa60123}},	//   _aprè, _وثلا, орюю, _ökfr
  { {0x2bda005d,0xcad5000a,0x47d50021,0x26cf02f2}},	//   णिया, ֖וֹת_, _ديار, _tago_
  { {0xc6d40015,0x26c41e90,0x9bba004f,0x8505009a}},	//   _وتنت, cemo_, נצרפ, _گوتن
  { {0xab63005c,0x71260029,0xd9f9000b,0x3ea90123}},	//   ężyc, مرسل, ्नित_, dgat_
  { {0xd656000a,0xdb05007c,0x463a004c,0x3ea90045}},	//   _פיסת_, lthä, _גענע, egat_
  { {0x44760053,0xf3c80015,0xdee61e91,0xd0071e92}},	//   _פעקל_, _نبيه_, бови, бере_
  { {0x98a70050,0x23760086,0x52aa0001,0x291c044c}},	//   ronę_, _اميد_, _свим_, ziva_
  { {0xc27b0008,0x10a60036,0x657b008c,0x23b10030}},	// [3620] _גרפי, _липн, npuh, láj_
  { {0x26c40085,0xdb05007c,0xe572000a,0x291c030b}},	//   zemo_, hthä, לַע_, xiva_
  { {0xcfea04b6,0x1c390010,0xa3ca000b,0x1fb61368}},	//   _صفحه_, аяць_, रौप_, _успр
  { {0xfaa61088,0xee7a0058,0x1ab400ce,0x41b3009a}},	//   садо, _حصدت_, ібля, _بمیر
  { {0xda65003b,0x31570086,0xd94610b9,0x26c402d8}},	//   زاني, _خلیج_, беди, vemo_
  { {0x7f441e93,0x8b66006e,0x69db1e94,0x5a3300ce}},	//   lliq, _هارم, _drue, чніт
  { {0xdb78000a,0x291c1e95,0xab78000a,0x98a70046}},	//   _כְּש, riva_, _כָּז, loně_
  { {0xc6f80809,0xa3d6000b,0x7d1e16c8,0x85740c30}},	//   рних_, सिस_, lips, олих
  { {0x8a060010,0x26c41e96,0x291c1e97,0x8571002b}},	//   _узае, remo_, piva_, وگوئ
  { {0xd3b8005e,0x1514005e,0xbf05000b,0x26c40085}},	//   алої_, ідня, _रत्न_, semo_
  { {0x18770008,0x66e5000b,0x61fd0034,0x3d3b000a}},	//   _העבר_, काशक_, wysl, רגיס
  { {0xa3cd005d,0x61fd0ac8,0x7d1e0061,0x98a70046}},	//   रिज_, tysl, hips, koně_
  { {0xcb37000a,0x66e5000b,0xf2040033,0x71a40033}},	//   מאטי_, कारक_, пяро, паўз
  { {0x2d92020a,0xf1271e98,0xe627000a,0x7bdc001a}},	//   dsye_, сьмо, _ל֗וֹ_, _orru
  { {0x24b7009d,0x251b05bd,0x0000006a,0x0000006a}},	//   _להגן_, _גוגא,   ,
  { {0x69c00991,0x3f91005c,0x3ea91e99,0x0000006a}},	//   _opme, rszu_, ugat_,
  { {0xd0d5010f,0x644f005c,0x8cf5005e,0x7bce1c75}},	// [3630] _допъ, ęcie, озац, _asbu
  { {0x8c6715be,0x628f1e9a,0x8cc50058,0x7d1e0535}},	//   стад, laco, تقطه, gips
  { {0x69c00048,0xd0f8005d,0x6f030011,0xbc4b0256}},	//   _apme, ुसरण_, _înco, учае_
  { {0x69db0467,0x672d016f,0xa2bc000b,0x19f9004a}},	//   _prue, čajk, ष्प्, иэль_
  { {0x6f0d002f,0x7bdc0012,0xe1ff0144,0x628f1c75}},	//   mhac, _erru, nyó_, iaco
  { {0xf7710115,0xd3660087,0x60c70046,0x5fce0065}},	//   واب_, _يه_, nejm, _हैडल
  { {0xda7b0010,0x37860063,0x907c0053,0xd6e2002a}},	//   _бяз_, общо_, נטהי, kołę_
  { {0x8595000d,0x6d451e9b,0x627e002a,0x69db1e9c}},	//   ошоц, llha, ołoż, _true
  { {0xa7120015,0xd6291e9d,0x77621e9e,0xf5090fdc}},	//   بِيع, ропе_, _diox, инил_
  { {0x26d9002c,0x14250080,0xe3b100c3,0xdb051e9f}},	//   ôsob_, ждом, ورج_, sthä
  { {0x60c7005c,0x02c60f13,0xd6ce002b,0xf7730015}},	//   dejm, ойно, رقی_, _راض_
  { {0x8bd6000a,0xcb9a004c,0x6d450012,0x628f1ea0}},	//   קורו_, ױסשט, hlha, gaco
  { {0x51ba0010,0x32040264,0x216a01b7,0xbb3a0643}},	//   шыня_, ámy_, риги_, שערי
  { {0x320c005c,0x55ba000a,0x627e002a,0x4a5a000a}},	//   ądy_, _כמנו, dłoż, ידרו
  { {0x6b650007,0x61430c71,0x656b1ea1,0x656302f2}},	//   _mėgs, фера, _hugh, _iinh
  { {0x6d450014,0x6729002c,0xa3d6005d,0x7d1e00dd}},	//   elha, nnej, सिर_, wips
  { {0x60c7002a,0x6e930015,0x2395003d,0x6729008c}},	// [3640] bejm, بلقا, lāj_, inej
  { {0x61fb0012,0xdca3029b,0x656b1ea2,0x5f760021}},	//   äule, дафи, _mugh, _واجر
  { {0x656b0f4d,0x656303af,0x7f440277,0x672900bd}},	//   _lugh, _minh, pliq, knej
  { {0x656303af,0xe9da1174,0x656b003e,0x8ae3005e}},	//   _linh, ике_, _ough, дішл
  { {0x6d450026,0x5db60029,0x67291ea3,0x6c860058}},	//   blha, _بإجر, dnej, _ولحم
  { {0x6f04005c,0xf8060146,0x1d0a007a,0x307a004c}},	//   lkic, жчин, _теги_, באַנ
  { {0xe3a70074,0x7f3c000a,0x656b00da,0x09290015}},	//   _تر_, ְע֖ו, _augh, حسني_
  { {0x9c170008,0xceb3000a,0x672900bc,0x60c71ea4}},	//   _וחלק_, ֵית_, gnej, zejm
  { {0x628f002c,0xb5c70015,0x656302f2,0xbb431ea5}},	//   vaco, قويم_, _binh, _цетк
  { {0xa3d6005d,0x32d70092,0xd5b70010,0x2b461ea6}},	//   सिल_, _ủy_, ісы_, lloc_
  { {0xd7ca0086,0x65631ea7,0x67291ea8,0x64431ea9}},	//   _خواه_, _dinh, bnej, _cyni
  { {0x6563074c,0x64430026,0x61e200bc,0x6729006f}},	//   _einh, _dyni, _šola, cnej
  { {0x6f04002a,0x628f1eaa,0xe7170015,0x7ae4008c}},	//   dkic, raco, _بينت_, öity
  { {0x636a0054,0x6f040061,0x628f1e5e,0x0000006a}},	//   _криг_, ekic, saco,
  { {0x60c7018c,0xf3ef0029,0x6f0d0537,0xe778000a}},	//   rejm, _لأي_, thac, מָּך
  { {0xe7f2005d,0x3eaf00b8,0x80ad000b,0x2b460045}},	//   _अपना_, ügt_, _जावे, jloc_
  { {0xbf38005e,0x5c990033,0x200505e3,0x6c6b0054}},	// [3650] ізує_, йкая_, šli_, ашег_
  { {0x61e0002e,0x628d0020,0x67290559,0x6f04002a}},	//   æmle, _heao, znej, akic
  { {0x63a80844,0xe53b000a,0xdbd6007c,0xeab10058}},	//   nudn, סתבר, jääg, ّعت_
  { {0x6f04005c,0xa3db000b,0x5457015b,0xddcd00bc}},	//   ckic, ठित_, קסאן_, mbaž
  { {0xed5b0086,0xda78017f,0x72dc015b,0xe9d9004a}},	//   _نشست_, цях_, יקאג, скл_
  { {0xb17c01e4,0x8dfa000a,0x9e5a000a,0x718c004f}},	//   סטור, _ההשת, _לכרט, בְהַ
  { {0x67290cca,0x07a51e98,0xa09c000a,0x656b02b9}},	//   tnej, чайн, ביוט, _sugh
  { {0x80bb005d,0x8aa41eab,0xb6a30016,0x65631eac}},	//   श्ते, _оруд, _giầ, _sinh
  { {0x7eb60053,0x64430026,0x3b64006b,0x65631ead}},	//   פּקע_, _syni, _църв, _pinh
  { {0x67291eae,0xe61604ab,0x53f90015,0xe4d50015}},	//   snej, яды_, مرجح_, ستخب
  { {0x6563001c,0x6f1d0111,0xf1a90643,0x6729016d}},	//   _vinh, _omsc, _תס_, pnej
  { {0x67ba0008,0xd7ba0008,0x8c1a000a,0x32ba0015}},	//   _למעק, _לצער, מותי, حددة_
  { {0x64430050,0x656303af,0xdce60007,0x9f5e01b2}},	//   _wyni, _tinh, _sukč, átí_
  { {0x63a8002c,0xaa3a004f,0x85f6004f,0x0000006a}},	//   budn, מתרח, _מצנע_,
  { {0x9f5e0089,0x6f04005c,0xdee61eaf,0x78bc0030}},	//   ští_, tkic, пови, _örve
  { {0x539a000a,0x139a000a,0x8cc1000b,0x3e7c0046}},	//   _היקו, _הבקע, _रॉबो, kátů_
  { {0xdcf00046,0xf2d3000a,0x6f041eb0,0x0000006a}},	// [3660] řečt, _טעה_, rkic,
  { {0x6f040c3d,0x61db000a,0xe164002b,0x3e7c0046}},	//   skic, _פקיד, _تضعی, dátů_
  { {0xe0fb0008,0x7f460175,0x60fb000a,0x66000647}},	//   _הליל, _неож, _ההיק, zymk
  { {0x05bd000b,0xd4910016,0xda6f0058,0x20550138}},	//   ्बाब, hà_, هُم_, _ітэр
  { {0xd9461eb1,0xad26002b,0x7cf30030,0x497302a3}},	//   педи, _فرسو, _sűrű, еліс
  { {0xed570b9b,0x2d801eb2,0x91bb004f,0xd169004f}},	//   _ноя_, mpie_, ממני, חֻקֹ
  { {0x2ca70077,0xab640012,0x798900aa,0x99dd00bf}},	//   ónde_, grüß, _ewew, _vyňa
  { {0x8b9b000a,0x6b510123,0x63a80123,0x3202008c}},	//   _לבלת, tåge, vudn, kyky_
  { {0x9634006d,0xceb3000a,0x67200085,0x79890034}},	//   ьниц, גיח_, rimj, _gwew
  { {0x6b510123,0x63a80307,0xddcd0045,0x0000006a}},	//   råge, tudn, lcaţ,
  { {0x987b0008,0xc8b50010,0xccf3000a,0xa84a0015}},	//   _האבט, _юсты, תכת_, _الام_
  { {0x63a812ef,0xddcd0045,0x97730058,0x0000006a}},	//   rudn, ncaţ, _أُنش,
  { {0xc56a0029,0xc693000a,0x644f002a,0x63a80085}},	//   _احصل_, _נאס_, ęcia, sudn
  { {0xe9ce0010,0x865b000a,0xd625012c,0xdb050046}},	//   ткi_, _הדדי, _تعمي, ruhé
  { {0x94bb0008,0xdb1c07cf,0x4fc409fe,0xc0580033}},	//   _המות, _aprí, нста, зіт_
  { {0xdb1c002d,0x877b000f,0x2295002b,0x7eb90138}},	//   _bprí, מאלי, _کلکس, ўгас_
  { {0xe3b80064,0xfe700087,0xe29c000a,0xc0cb004a}},	// [3670] ltı_, ادف_, _השחר, _луне_
  { {0x4d980280,0xa3b00065,0x68fa02ad,0x0000006a}},	//   якую_, टंप_, _notd,
  { {0xe3b801e2,0x9f55005e,0x00ba000a,0xe4ed000b}},	//   ntı_, _овоч, _ומתמ, जाति_
  { {0x6f1d00b8,0xa3d4000b,0xf1b1000b,0x3e7c0046}},	//   _umsc, _हनन_, _जमान, tátů_
  { {0xeab00029,0xa3d3000b,0xd9590033,0x0000006a}},	//   اعم_, _सैन_, ошкі_,
  { {0x3e7c0089,0xe3b80064,0xa7790001,0x0000006a}},	//   rátů_, ktı_, ољих_,
  { {0xb09c0053,0xf8ae0086,0x32020227,0xb8d5000b}},	//   מיגר, شکل_, zyky_, _झा_
  { {0xead40010,0x68e819b6,0xfbd2000a,0xbae50015}},	//   _пось, _endd, _בתל_, _تكري
  { {0xeaf80015,0x671c000b,0xe6191eb3,0xd5ae0015}},	//   _عرفت_, बोधक_, юди_, لفي_
  { {0x59c40015,0x25720034,0x7afb1799,0x15f40065}},	//   _سيمك, _dâl_, _hout, ेनजर_
  { {0x89340029,0xbcfb0077,0x7afb1eb4,0xa7870058}},	//   _أعقا, _hués, _kout, _رشاو
  { {0x6f0304f9,0x7afb0df1,0xd5ae002b,0x23780030}},	//   _înch, _jout, دفی_, írja_
  { {0xd7060036,0x68e80026,0x7afb0493,0xe3b80061}},	//   _інше_, _yndd, _mout, atı_
  { {0xa5b2005d,0x6606003c,0x7dd80125,0x7afb1eb5}},	//   _आमतौ, økke, húsá, _lout
  { {0x5043000d,0xdb1c002c,0x04590015,0x2907001a}},	//   верб, _sprí, _بلغة_, ikna_
  { {0x620700dc,0x7dd80030,0x6d5501c2,0x7afb1eb6}},	//   örlé, júsá, _ahza, _nout
  { {0x4d660010,0x8d660010,0x12eb000a,0xef17005e}},	// [3680] дкав, двае, _וַיּ, єму_
  { {0xef1f0020,0x7e76002a,0x644e002a,0xfce6005e}},	//   _emü_, scyp, żbie, ьозо
  { {0x7afb038d,0x3eb300f2,0x2d801eb7,0x8e861eb8}},	//   _bout, äntö_, spie_, _огне
  { {0xfe720029,0x2d80014c,0xe51d000b,0x0aea006d}},	//   _جدد_, ppie_, योति_, юдей_
  { {0xddcd04f9,0xb17b0134,0x7afb1446,0xed5a0a62}},	//   rcaţ, rvåg, _dout, _мом_
  { {0x17fa0015,0x7ae91eb9,0xf7ea0058,0xe3b8007f}},	//   قرعة_, _enet, قربى_, ytı_
  { {0x7afb0161,0x60c1007c,0x25720034,0x9cd7000a}},	//   _fout, õlmi, _sâl_, _קולה_
  { {0xd757003b,0x8f9b000a,0x8cae000b,0xc053000a}},	//   وجيا_, קיפי, ुभवो, כזו_
  { {0x88c60029,0x88c50089,0xd6260015,0xa3b0000b}},	//   _يتطل, _směř, بعثي, टून_
  { {0xe3b80064,0x79fb0008,0x290700c0,0x8cc1000b}},	//   ttı_, _ולמח, ckna_, र्पो
  { {0x7afb1eba,0x8ca6000b,0x29170058,0x43940138}},	//   _yout, _चयनो, _تقلد_, эанс
  { {0xe3af0074,0x38630014,0xe3b80064,0x25720034}},	//   گری_, _újra_, rtı_, _tâl_
  { {0x672d018c,0x798200c7,0x6f030045,0xe3b80061}},	//   čajt, npow, _înci, stı_
  { {0xe3af0086,0x7dd800dc,0xe3b80064,0xc3740015}},	//   دری_, zúsá, ptı_, _كُتب
  { {0xd0d4006b,0x62860123,0x9f350033,0x69060052}},	//   ъоръ, bbko, ееві, _aðek
  { {0x539b000a,0x439b000a,0x63b7006f,0xdce6003d}},	//   _ויהו, _ובהג, žaní, _rukā
  { {0xa3d6021e,0x0687004c,0x7afb0f43,0x7982002a}},	// [3690] सिक_, _הכּל_, _rout, jpow
  { {0x7982005c,0x7afb0b42,0x7059176c,0xcc0b006e}},	//   dpow, _sout, _напр_, يزان_
  { {0xfd440033,0x7afb1eb4,0x0000006a,0x0000006a}},	//   тэтн, _pout,   ,
  { {0xd6d9005c,0x80bb005d,0x7d0e0012,0x99d50058}},	//   koła_, श्रे, _elbs, فتتا
  { {0x4e7a000a,0x0134002b,0x7ae900bc,0xa9a50054}},	//   _מארצ, _سعید, _vnet, хилд
  { {0xe9d806b4,0xe8f8022a,0xc98404b9,0x23b8006f}},	//   ькі_, млі_, туци, kéj_
  { {0x6286005c,0x7afb1ebb,0x9b740015,0xf7450561}},	//   ybko, _tout, _لاقص, неко
  { {0xbcfb0152,0x7ae91ebc,0x2249007f,0x6b5102dc}},	//   _guér, _unet, _oyak_, båga
  { {0xb9c70015,0xf5051ebd,0xcf58004f,0x99d40058}},	//   _تتأه, езпо, ובהת_, _لتلا
  { {0xf807005f,0xa3d3000b,0xfcfa000a,0xd9190015}},	//   _очен, _सईद_, ִּיל, _عياش_
  { {0x7bda00dc,0x8cc1005d,0x644f005c,0xccf2000a}},	//   _átut, र्यो, ęcio, אכי_
  { {0x0bb60008,0xd9f3000b,0x05750015,0x3f9e1ebe}},	//   עִיר_, _आपात_, _كاتد, átum_
  { {0xdfd20086,0xe1960010,0x9b16000a,0x1303005e}},	//   گيز_, эрнэ, תחרה_, узям
  { {0x80bb005d,0x7bd5005c,0x656f002d,0x2618000b}},	//   श्ले, _oszu, íchu, _बेटी_
  { {0x7982005c,0x6fb60015,0x2f560174,0x44f8009a}},	//   zpow, عمرا, етас, _ترنج_
  { {0xdb1c0057,0x6446002a,0x7982002a,0xdcba000b}},	//   _oprá, ękit, ypow, ैज्ञ
  { {0xc2e90029,0xd2660036,0x7bc71ebf,0x6da306a6}},	// [36a0] _زعيم_, _який, _apju, лита
  { {0xc50c0053,0x02c1000b,0xc1060015,0xfdd0000b}},	//   ֿלאָ, ष्ठभ, _أودي, _हनीफ
  { {0xda7a006b,0xb0b7004c,0x7ac6118a,0x1024002b}},	//   пял_, _אפיס_, есле, _شکسپ
  { {0x61e40263,0xbcfb01f6,0x2d4f03a0,0x0000006a}},	//   _kril, _quér, qüen_,
  { {0x2fe8005c,0xda650015,0xba290015,0xc333000a}},	//   ługę_, ناهي, وسهم_, נוד_
  { {0x6b5101d1,0x63ba0123,0x2018006f,0x2d4f0061}},	//   råga, yttn, ozri_, nüel_
  { {0xfaa6008f,0xe3a70021,0xb7660195,0xd6d9002a}},	//   _паво, _حر_, нтий, woła_
  { {0x97c30029,0x61e40077,0xf7430004,0x25ad0fc1}},	//   اقيو, _oril, лејо, fuel_
  { {0x34bd000b,0xc5260004,0x25ad1ec0,0x31ca000b}},	//   ौजूद, еќни, guel_, िबोध
  { {0xe9d70036,0xcdb7000a,0x399b000a,0x7bd5002a}},	//   _яку_, עפיה_, _מימד, _yszu
  { {0xdb1c0089,0x673c00dc,0x66e611d9,0xf8b300a3}},	//   _zprá, _írjo, _пожа, _תשע_
  { {0x61e416c8,0x69d5000b,0xe6c50015,0xe6c60015}},	//   _bril, _मैडी, _لتهي, _ستصي
  { {0x69060084,0x8cc1000b,0x3f570003,0xba9b000a}},	//   _aðei, र्डो, nçue_, הסכי
  { {0xf6290029,0x61e41ec1,0x89eb000a,0x2eeb1ec2}},	//   _تسمى_, _dril, הַלֵ, _sncf_
  { {0xe9ff0092,0x61e40c58,0xb4ac021e,0x35a6000b}},	//   _khảo_, _eril, गली_, _खिड़
  { {0xd4090015,0x3f83003d,0x6d5e11ec,0x61e40778}},	//   _تتهم_, rpju_, empa, _fril
  { {0x6ca71ec3,0x6722003f,0x61150010,0x271e000b}},	// [36b0] ереж, _mmoj, _адпу, _बगैर_
  { {0x63a81ec4,0x98ae0046,0xac740058,0xdca400af}},	//   ordn, rofě_, هامش, лађи
  { {0xdb1c04af,0x9be40010,0xab6b0021,0xfbab0151}},	//   _sprá, ліцк, سحاق_, ятай_
  { {0x8f9a000a,0xa5a1000b,0x220b000a,0x6e2c001a}},	//   _קירי, _खिलौ, ּפַּ, élbú
  { {0x12fa0053,0x25ad0003,0xaab40015,0x0dc80923}},	//   והײב, xuel_, اصمت, _пури_
  { {0xbb850029,0xf9900029,0x61dc000a,0xe918005e}},	//   _للسي, صبه_, פקוד, ночі_
  { {0xdc88000a,0x3c450015,0x47d20015,0x58940015}},	//   _רְשָ, _شَرِ, ليور, اجهز
  { {0x25ad1ec5,0xf5e907be,0xdb050012,0xa3e4000b}},	//   tuel_, дмил_, nthü, निन_
  { {0x6f030011,0x6b6c0064,0x644f002a,0x8cc1000b}},	//   _încu, _işga, ęcim, र्थो
  { {0xdbcc002e,0x58d90036,0xc9840054,0x67220085}},	//   _kóða, _ідея_, _љути, _emoj
  { {0x644a0026,0x78fa0053,0xd67b002b,0x9cd6000a}},	//   _cyfi, _קלעפ, _فحشا_, דותה_
  { {0x8cc1000b,0x61e41ec6,0xf1de000b,0x644a0034}},	//   र्तो, _pril, मिलन, _dyfi
  { {0xdb0800dc,0x471a0008,0x6d5e06bd,0xba9a000a}},	//   élés, _קונג, ympa, וסרי
  { {0xb1430a61,0x20d5005e,0x6535004c,0x7e7d1ec7}},	//   инял, лісс, _שאַף_, _afsp
  { {0x644a0026,0xf8b2000a,0x764b0034,0x2496002b}},	//   _gyfi, ישם_, _hygy, _شنيد_
  { {0x84640063,0x61e41ec8,0x6d5e0034,0xe436000a}},	//   _съче, _tril, wmpa, _ברצח_
  { {0x61e404f9,0xb13a0029,0xc69200f3,0x6b9c0085}},	// [36c0] _uril, _يأخذ_, יאן_, _svrg
  { {0xd2570008,0xdd8f0015,0xd6d9002a,0x0c790033}},	//   _בשפה_, توك_, koło_, есцы_
  { {0xeb971ec9,0x6b5100c0,0x764b0007,0x7d030123}},	//   вих_, rågn, _lygy, önsa
  { {0xfaa61eca,0x93fa000a,0x6207001a,0xba1a0058}},	//   тадо, ולעי, _örlí, ويضا_
  { {0x827700b2,0x6a160029,0x99d30015,0xe9730015}},	//   דענע_, خبار, لتوا, لهند
  { {0x8cc1000b,0xa9540033,0x3f570003,0x6b581ecb}},	//   र्दो, ыклі, rçue_, díge
  { {0xdbcc002e,0xc0100092,0xd8230054,0x60c30030}},	//   _góða, _đuổi_, идљи, _önme
  { {0x5b360010,0x764b0026,0xf7270033,0xe994002b}},	//   _рэгу, _bygy, кцый_, _مهرگ
  { {0x66030054,0x89660033,0xaa4608a0,0xab271ecc}},	//   ипћа, _акаж, _реал, _рота_
  { {0x03f80001,0xb4ac021e,0x2bc9000b,0x44f40579}},	//   еној_, गले_, _रहमा, упос
  { {0xe9ff0023,0xdb050c7f,0xb7d700c3,0xa29502a3}},	//   _thảo_, luhá, _لولا_, лані
  { {0x6722003f,0x764b0026,0x644a01c9,0xdb9b00f3}},	//   _umoj, _fygy, _vyfi, וסטר
  { {0x9258004a,0x63a81ecd,0x833400ce,0x522404b5}},	//   кают_, srdn, рнях, афра
  { {0x3494088d,0x644a0034,0xdb050003,0x2f1502dc}},	//   _сакр, _tyfi, rrhé, _måge_
  { {0x4035000d,0xe7e5000b,0x6b510123,0x7f940a32}},	//   уевс, किया_, fågl, иарх
  { {0x6d47002e,0xb7db00a3,0x93f7000a,0xfd8b004a}},	//   _skja, וקלי, _יצוא_, дёжи_
  { {0x7e550036,0x2d8f0152,0xdd910015,0x64460061}},	// [36d0] уває, ège_, صوا_, şkid
  { {0x15f5000b,0xe9ff0016,0x55bb000a,0xac191ece}},	//   ेहतर_, _nhạo_, וממו, нозу_
  { {0x69c900ed,0x7a0a003d,0x3c440015,0xf1bf1ecf}},	//   _spee, _lētā, لَكِ, ltá_
  { {0x6b5101d1,0xee840256,0x940b000a,0x394e08cf}},	//   rågo, _выро, וּדֵ, elfs_
  { {0xe8ee005e,0x8afd0046,0xceb2000a,0x2d54008c}},	//   бл_, _jiři, _פיך_, mäen_
  { {0xf1bf016e,0x6f0d1ed0,0x387e03a0,0x0000006a}},	//   itá_, lkac, _cftr_,
  { {0xf7710806,0x31580053,0x9782002b,0x27940033}},	//   حات_, דיגן_, میله, ашыр
  { {0x6f0d1ed1,0xdb05002d,0xcb690029,0x7528003d}},	//   nkac, rthó, _أمره_, eidz
  { {0xdb05002e,0x645c002e,0x66050080,0xd6d9002a}},	//   sthó, ýrin, уппа, soło_
  { {0xe616006d,0xfe38000a,0x3f9e0091,0x6b581ed2}},	//   удь_, כרחי_, štui_, ríge
  { {0x23d40010,0xc209000f,0xd6d70015,0xdc88000a}},	//   ацяр, _צה_, _لتشغ, כְרָ
  { {0xa77a0053,0x82f60004,0x5c36000a,0x2a69003d}},	//   _טרעפ, учоц, טרתן_, žabu_
  { {0x6d450005,0x6f0d005c,0x672910da,0xa3d3000b}},	//   koha, dkac, miej, _सैर_
  { {0x1c03005d,0x67290007,0x6d4500d9,0x412a00f4}},	//   लहाल_, liej, joha, хого_
  { {0x232a0036,0x660900dc,0x25bf0045,0x6d45058a}},	//   _поки_, lyek, ltul_, doha
  { {0x67290050,0xb0c4000b,0x25bf0045,0x26df0091}},	//   niej, _लॉरग, otul_, nduo_
  { {0x25bf0440,0x91e615e6,0xee3a1ed3,0x28c4000b}},	// [36e0] ntul_, _сопе, хна_, ल्डि
  { {0x98a70007,0xdd8f0002,0x0e630342,0x25bf1ed4}},	//   monė_, سوم_, скун, itul_
  { {0x6729002a,0x25bf007c,0x77f2000b,0xb17b0123}},	//   kiej, htul_, _अपेक_, nvån
  { {0xa3e4014e,0x41a8000b,0x6e460067,0x67290091}},	//   नित_, _कटास, _منجم, jiej
  { {0xe81c005d,0x7e9b000a,0x9f5f0046,0x67290091}},	//   _भेजा_, _אסכו, _írán_, diej
  { {0x6f030011,0xf1b3000a,0x7c660015,0xdb050030}},	//   _încr, מסד_, _مازل, ruhá
  { {0x8bd80008,0x6d5c0064,0x7bd8000a,0x6c360021}},	//   _בַּח, _ihra, _בַּק, _صفرا
  { {0x7528005c,0xe9da0033,0x758a031e,0xe757005e}},	//   widz, _пкб_, нсов_, лищі_
  { {0x163400a4,0x8cc1000b,0xc8b60015,0x8703004a}},	//   репя, र्वो, _مصاب, сяще
  { {0x88bc0089,0x6f0d1ed5,0x05730058,0x3981009a}},	//   _změn, zkac, حايد, _بیوف
  { {0x6f0d005c,0x629608b8,0x25bf0045,0x67291ed6}},	//   ykac, _beyo, atul_, biej
  { {0x66760029,0x6b650007,0xa77b000a,0x6729002a}},	//   _إدار, _bėgy, _נרדפ, ciej
  { {0x25bf0011,0xa2270015,0x6d5c05ba,0x659403ae}},	//   ctul_, ارجه, _ohra, _талу
  { {0xfebb0086,0x86370008,0x6f0d005c,0xf1bf11d4}},	//   کاست_, _גאדג_, wkac, rtá_
  { {0xe47b0008,0x2d5400f2,0x7497000a,0xf1bf1ed7}},	//   _ארוכ, täen_, _גדוד_, stá_
  { {0xfe730029,0xf3ef0029,0x212a002d,0x64581ed8}},	//   صدر_, _رأى_, aibh_, _izvi
  { {0x6d5c002f,0x6f0d131a,0x5cb90033,0xcec00046}},	// [36f0] _bhra, rkac, клаў_, ířat_
  { {0xb0b2014e,0x6f0d1ed9,0x67290c85,0xf657000a}},	//   _जाएग, skac, ziej, רסמי_
  { {0xa2bc014e,0x6296000c,0x8c190029,0x7055002b}},	//   ष्क्, _yeyo, خيار_, _خندا
  { {0x539b000a,0x98a90085,0x8d77012c,0x8c641eda}},	//   תיאו, đač_, _ماسا, студ
  { {0x60de01e2,0x25bf04f9,0x6d5c002d,0xfe9a0643}},	//   _yapm, xtul_, _fhra, _שישמ
  { {0x28f80080,0x6729002a,0x6d5c1edb,0xf8b1002b}},	//   лечь_, wiej, _ghra, تکر_
  { {0xdb1c1edc,0x67290007,0x644e007c,0x487801c6}},	//   _språ, tiej, übil, усія_
  { {0x88bc0089,0xf9930058,0x4990009a,0x0000006a}},	//   _uměn, _هبط_, _کیور,
  { {0x67290007,0x98a7002a,0x4535107c,0x8cb7004f}},	//   riej, enną_, ихот, ָּ֖א_
  { {0x25bf04f9,0xc5150086,0x672910da,0xfc46006f}},	//   rtul_, شبخت, siej, číva_
  { {0x661b0050,0x25bf1edd,0x47d50029,0xebd7000a}},	//   szuk, stul_, _خيار, רֵ֖י_
  { {0x25bf04f9,0x39471ede,0xb17b0123,0x25b6002b}},	//   ptul_, lons_, rvån, دهید_
  { {0xcad6000a,0xfad6000a,0x0000006a,0x0000006a}},	//   בורת_, בורך_,   ,
  { {0x39471edf,0x25ad006f,0x660601be,0x361a000a}},	//   nons_, mrel_, äkke, _בונד
  { {0xdfd200a2,0x212a0125,0x5f0619af,0x63f6012c}},	//   غير_, ribh_, азва, _نفوس_
  { {0x6d5c1ee0,0xc43a000a,0x8e860daf,0x61f10046}},	//   _shra, _שתקי, ргае, áhlý
  { {0xa1560063,0x1d260800,0x60de007c,0x6d5c1aba}},	// [3700] _външ, амам, _tapm, _phra
  { {0xdca60124,0x2fdf005c,0xb19b000f,0x319b000a}},	//   ражи, ługa_, _שייכ, _שבינ
  { {0x60c300dc,0x161d000b,0x0c260b1e,0x61e60123}},	//   _önma, _बेघर_, јмен, lvkl
  { {0x103b000a,0x9f7b000a,0xdee60b27,0x5e7a004f}},	//   _יגיע, _שנכח, _томи, _יָ֝ד
  { {0xd90d0086,0xc27b0008,0x8337000a,0xdb1e0030}},	//   کیل_, דרני, סאנס_, ntpé
  { {0xb21b002e,0x39471ee1,0xda650015,0x61fb0012}},	//   mbæt, gons_, حامي, äuli
  { {0xf0930008,0xf8030010,0x320b005c,0xb9230029}},	//   חנו_, жчын, zycy_, تفوي
  { {0x7bdb0008,0x257b0026,0xa3e4021e,0xab690018}},	//   _בקלו, _bêl_, निस_, _محقق_
  { {0xc6f7054f,0xe5060015,0x98be0091,0xe7f20065}},	//   рных_, لبدي, _aktą_, _अपका_
  { {0x75140004,0xa9c5002b,0x75060004,0x6d89000a}},	//   смоф, _دزفو, рџие, נָפְ
  { {0x3c77000f,0x2f150123,0x4c9b000a,0x69c21ee2}},	//   יתים_, _låga_, כביו, ltoe
  { {0x86460877,0x320b002a,0x25ad00aa,0x268a0040}},	//   _кнеж, tycy_, brel_, _شخصي_
  { {0x69c21ee3,0x7ae21ee4,0xe2980033,0x6932002a}},	//   ntoe, idot, шаў_, głeg
  { {0x7ae200f2,0x29c20092,0x320b002a,0x759b000a}},	//   hdot, _mưa_, rycy_, _יידח
  { {0x69c2022d,0x753d0014,0x34fb0008,0xb4fb000a}},	//   htoe, észe, _בהגד, _בלגר
  { {0x33fb000a,0x2f380015,0x23fb000a,0x88bc0046}},	//   _יהונ, لثقة_, _יהוא, _směl
  { {0x39470152,0xdcfd0024,0x629d1ee5,0x645d002a}},	// [3710] yons_, _atsā, maso, ęsie
  { {0x629d0e6d,0x30a703e3,0x7ae20739,0xdce7003d}},	//   laso, _трив, edot, _bijā
  { {0x39470152,0xbc480010,0xf092000a,0x25ad006f}},	//   vons_, ачце_, _מני_, zrel_
  { {0x629d1ee6,0x28c4000b,0x7fd6004f,0xc8c40065}},	//   naso, ल्सि, _פורס_, ल्सट
  { {0xa2bc014e,0xf1b40053,0x69c20159,0xc334000a}},	//   ष्ट्, ַסק_, gtoe, חוף_
  { {0xa9240036,0x88bc0089,0x629d10c9,0x66df000b}},	//   оділ, _uměl, haso, _खोजक_
  { {0xfb840010,0x39471ee7,0x6bd40015,0x257b0034}},	//   _мытн, rons_, _وتفر, _sêl_
  { {0x257b0026,0x7ae00007,0xfc46002c,0x39470493}},	//   _pêl_, _gamt, číta_, sons_
  { {0x9475002b,0x39471b65,0x69db1ee8,0xceb4000a}},	//   یدگا, pons_, _usue, קיץ_
  { {0x629d0c0a,0x25ad1ee9,0x8cca0065,0x0000006a}},	//   easo, rrel_, स्पो,
  { {0xb936004c,0x04451eea,0x7659002a,0xe29a012b}},	//   _פרעג_, сенн, _wzwy, лан_
  { {0x29051eeb,0x68e11eec,0x753d0030,0x2d851eed}},	//   _hola_, _hald, észb, _člen_
  { {0x29c20092,0x673e00dc,0xeb3a0053,0x68e11eee}},	//   _xưa_, épje, רערש, _kald
  { {0xd4790053,0xa3e4021e,0xc5f2000a,0x61e200bc}},	//   _גאַל, निश_, _מדד_, _šols
  { {0x09d4005d,0x8cca005d,0xb4b3021e,0x629d1eef}},	//   _धन्य, स्फो, टली_, baso
  { {0x93250015,0xceea006e,0x629d1ef0,0x29051ef1}},	//   _ورين, درسن_, caso, _lola_
  { {0x8d760029,0x0c760087,0x7ae01ef2,0x6da607f9}},	// [3720] صاءا, مداد, _ramt, сиза
  { {0xb21b002e,0x7ae0171c,0x3f9e0030,0xad260015}},	//   rbæt, _samt, átus_, حررو
  { {0x7ae00085,0x48e2000b,0xd00a1ef3,0x29c200a1}},	//   _pamt, _टोगो_, _сене_, _sưa_
  { {0x9b2513ae,0xfaa3005e,0x3f9e0091,0xb21b001a}},	//   офіл, зацо, štus_, mbær
  { {0xc3330008,0xd9100086,0xddc6005c,0x59f805c4}},	//   הוא_, ویر_, _wykł, реля_
  { {0xdd8f0029,0x629d0fce,0xd9430818,0x29051ef4}},	//   _سوف_, zaso, печи, _cola_
  { {0x2905003f,0x629d003f,0x7ae01ef5,0xdb1c02de}},	//   _dola_, yaso, _tamt, _oprø
  { {0xdc370053,0x98bc0091,0x29050125,0x69c21ef6}},	//   _האלט_, dovą_, _eola_, ptoe
  { {0x629d1ef7,0x68e11ef8,0x29050125,0x7792002b}},	//   vaso, _fald, _fola_, _کیبا
  { {0x4ddb0008,0x91790092,0xb97b000a,0xa3e4000b}},	//   נחיו, hận_, _ענבי, निल_
  { {0x8cca005d,0x629d07b9,0xc5130015,0xb633002b}},	//   स्यो, taso, ثبيت, قعیت
  { {0x23a9000b,0x2d05000b,0xe2ab006e,0xdb0503c1}},	//   _किरद, _शक्ल_, دادن_, sthö
  { {0xdcef0011,0x7d0305d7,0x29050061,0x753d0030}},	//   _jucă, önsk, _yola_, észc
  { {0x463b00b2,0x25bb000a,0x88bc0046,0x629d1302}},	//   _געדע, _עצומ, _směj, saso
  { {0x4ac8014e,0x29370053,0x629d1ef9,0xa818000a}},	//   रभाव, צאלן_, paso, בֵּי
  { {0x9f55005e,0xe437000a,0x6d4e1efa,0x2fdf002a}},	//   івач, _לרוח_, _akba, ługo_
  { {0xad670015,0x673c0030,0x1eea002b,0xcc990054}},	// [3730] مائه, _írju, جوقی_, ивац_
  { {0xe29f002e,0x0000006a,0x0000006a,0x0000006a}},	//   lað_,   ,   ,
  { {0xab9b0015,0x61ed006f,0x4fc71c44,0x29051efb}},	//   اخطر_, _hral, _успа, _rola_
  { {0xe29f0084,0x527c0053,0xb3bb01ac,0xeab000a2}},	//   nað_, ָנגא, רמאכ, فعه_
  { {0x9e670086,0x68e11efc,0x99d70029,0x7655005c}},	//   _دادن, _pald, إتصا, ęzyk
  { {0x88c8005e,0x63a10046,0xdb23002b,0x28c4000b}},	//   йлів_, ysln, _کوری, ल्लि
  { {0xe29f0084,0x6b95005c,0x68e11efd,0x88c40015}},	//   kað_, _uwzg, _vald, ستول
  { {0xe29f002e,0x2905002a,0x05a90342,0x291c014b}},	//   jað_, _wola_, авий_, ahva_
  { {0xe57604ab,0xa5f60054,0x68e11efe,0xe29f001a}},	//   озы_, жењу_, _tald, dað_
  { {0x89370018,0xe61601b0,0x98bc0091,0x62841eff}},	//   _اعرا, юды_, tovą_, _sfio
  { {0xe29f002e,0x64460064,0x61ed1f00,0x80c4000b}},	//   fað_, şkin, _aral, _लॉगइ
  { {0xe29f002e,0x61ed1f01,0xcad5000a,0x63a1001a}},	//   gað_, _bral, חוֹת_, rsln
  { {0x2005008c,0x64a51f02,0xdb2001d3,0x0000006a}},	//   älin_, _дала, étéb,
  { {0xe3b10029,0x3ce300bc,0x7bc50795,0xd5670a23}},	//   _قرب_, _najv_, kthu, _утеп
  { {0x61ed0005,0xa7a9000a,0x77a9000a,0xa3a40015}},	//   _eral, יֹּ֥, יֹּ֕, _فحين
  { {0x6aa9077c,0x91790016,0xb21b0e05,0x61ed1f03}},	//   _ndef, uận_, rbær, _fral
  { {0xcd2a0010,0x7bc50034,0x6e290046,0x61ed1f04}},	// [3740] ажае_, ethu, _žebr, _gral
  { {0x4d63005e,0xfc320015,0x6cd60015,0x6b58030b}},	//   дкув, وحا_, تقطا, tígo
  { {0x8b260191,0x1c390010,0x5ba50036,0xdcef003d}},	//   одже, бяць_, зріз, _atcē
  { {0x7b3c0198,0xa8020061,0xdb050046,0x5f79000a}},	//   ačun, şıkl, trhá, _לָשׂ
  { {0x6aa90176,0xd94615e6,0x2d4f0251,0x3ea01f05}},	//   _ddef, оеди, gües_, mait_
  { {0xf1bf00dc,0xda650115,0x3ea01f06,0x41b2000b}},	//   szág_, ساني, lait_, _जिनस
  { {0xfbc31b07,0x86c40015,0xbab60058,0xc7b00058}},	//   _обро, كيغن, _ومسب, رّة_
  { {0x3ea00152,0xd6d9005c,0xc6f80185,0xecc6000b}},	//   nait_, kołu_, сних_, र्रफ
  { {0xb17b003c,0x50ca005d,0xe29f002e,0x8cc1000b}},	//   rvåk, िभाष, vað_, र्को
  { {0x38c80086,0x6aa9005c,0x38cb0086,0x3ea00152}},	//   _داری_, _zdef, _نامی_, hait_
  { {0xe29f0084,0x1877000a,0xbc7b004c,0xf1bf0030}},	//   tað_, _ועבר_, יװיט, zzád_
  { {0x06650086,0x3ea000dc,0x8cca005d,0x61ed1f07}},	//   _کامپ, jait_, स्तो, _pral
  { {0x36360086,0xe29f002e,0x41e40484,0x3ea00003}},	//   _براس, rað_, міра, dait_
  { {0x7bc50026,0xe29f002e,0x6657000a,0x4a5b004f}},	//   ythu, sað_, _ובדף_, ידכו
  { {0xe29f002e,0x7d0700bd,0x78fb0008,0xaf07006b}},	//   pað_, _rojs, ספלו, очак
  { {0x23280001,0x3ea00030,0x61ed1f08,0x61e90f94}},	//   _моји_, gait_, _tral, åels
  { {0x61ed1f09,0xdcef0046,0x3f570061,0x2dd80058}},	// [3750] _ural, řeče, lçuk_, يبكة_
  { {0xa1280015,0xed51002b,0xa3e10065,0x765d0052}},	//   _وكيل_, رپا_, _नईम_, ýsyi
  { {0x79891f0a,0x60da007c,0x7d0705fb,0xdfdb006b}},	//   _stew, õtme, _vojs, _тъп_
  { {0x7d070050,0x52d800b2,0xfaa70036,0x7bc51f0b}},	//   _wojs, ַווע_, ішен, rthu
  { {0x5efa0008,0xd358000a,0x4efa000a,0x7bc51f0c}},	//   _הפרד, קידי_, _ההרו, sthu
  { {0xd6d9002a,0x0904008b,0x3978008b,0xdce7002a}},	//   hołt_, мпін, ісію_, _biją
  { {0x48091cd9,0xa08c004f,0x0000006a,0x0000006a}},	//   сейн_, בְחִ,   ,
  { {0x97d80029,0x103c000a,0x7f0b004f,0x8cd30065}},	//   تظهر_, יגוע, יהֶ֥, ड़को
  { {0x644601e2,0xd8380b6c,0x49b80015,0x947900ce}},	//   şkil, _reče_, _واكد_, йсну_
  { {0x6e200005,0x58bb0225,0xe576043d,0x14250189}},	//   _ümbe, _خارج_, язь_, здом
  { {0x6d89002c,0x3ea01f0d,0xa2e60818,0xdc3e0045}},	//   _hľad, yait_, понд, mţăm
  { {0x62810050,0xdc3e0011,0x2d8b0046,0xb2850033}},	//   ślon, lţăm, _otce_, дыёк
  { {0x21a30080,0x3ea01f0e,0xa1930010,0x2bd2021e}},	//   ниям, vait_, наўч, _सहभा
  { {0xeb18005d,0xeb08000b,0x321e002a,0x0596002b}},	//   _दत्त_, _वक्त_, ąty_, _راهگ
  { {0x3ea01f0f,0x29360053,0x34fa000a,0xb4fa000a}},	//   tait_, לאשן_, _להסד, _לפסי
  { {0xdd9200e6,0x04560015,0x673b007c,0xd6d9002a}},	//   فور_, _علية_, nnuj, połu_
  { {0x3ea01f10,0xb2bb0008,0xc333000f,0x0c7a0015}},	// [3760] rait_, _המפר, _רוח_, مصاب_
  { {0x3ea01f11,0x4096004a,0xd576000a,0xbd430058}},	//   sait_, _эрит, פתעה_, ّنْي
  { {0xa3e4014e,0x307b0008,0x0c260180,0x807b000a}},	//   निए_, _לאינ, џмен, _לניצ
  { {0x63be003c,0x70760086,0xab770015,0xc0470016}},	//   _åpne, _واگذ, سمها_, _lượn_
  { {0xceb300b4,0x0d830010,0xd6d9002a,0xda7900ce}},	//   _איר_, _плян, deł_, цяє_
  { {0xf8060036,0x6f0401a3,0xdb050012,0xa3cb000b}},	//   зчин, ljic, erhä, रझा_
  { {0x9d1b000a,0x6f04006f,0xad1b004f,0x0000006a}},	//   _פולט, ojic, _פולר,
  { {0xb7630033,0x753d0030,0x8f89000a,0x1ae31e64}},	//   нтый, észn, קְצֵ, _посм
  { {0x34940010,0xcad7000a,0x6e241f12,0xe4e600fd}},	//   мапр, _צומת_, nzib, пінн
  { {0x6e240045,0x62861f13,0x645d0073,0x6446007f}},	//   izib, ecko, ęsin, şkim
  { {0x8cc1005d,0xd6d9002a,0xa2c10065,0x0000006a}},	//   र्टो, beł_, _वाद्,
  { {0xf6e50191,0x1dac005d,0x92940010,0x6aa2003f}},	//   _оцін, _चिंत, наюц, naof
  { {0x87250015,0x7af6008c,0xcb13004f,0x0000006a}},	//   _تعلم, öyty, גלר_,
  { {0x6e24005c,0x27e9005c,0x98bc0007,0x6f040089}},	//   dzib, łane_, tovę_, ejic
  { {0x3d00014e,0xf55b0008,0x4f5b0029,0x98a70045}},	//   राने_, _הדגמ, مجرد_, lină_
  { {0x8cca005d,0x643b000a,0xf43b000a,0x394e0012}},	//   स्सो, _לעונ, _לתוש, hofs_
  { {0xa3e4014e,0xa2a2005d,0xf2d40053,0x98a70045}},	// [3770] निक_, _ख़त्, _טעק_, nină_
  { {0xf1b2005d,0xdb1c005c,0xd6d9002a,0x673b07c4}},	//   _जितन, _opró, zeł_, znuj
  { {0x63ba065d,0x4af9002b,0x7c670015,0xa088000a}},	//   nutn, يکرد_, سائل, _מְרִ
  { {0xadbd01f3,0x6f16006f,0x5b150033,0x3c440015}},	//   _камi, ckyc, ьмет, رَنِ
  { {0xf9880029,0xf9840036,0xad27002b,0x89a8005e}},	//   كنني_, егіо, _فرآو, зків_
  { {0x8dfa0008,0xe9d8042b,0x6ce4005e,0x63ba1f14}},	//   _והשת, які_, _пісе, kutn
  { {0x1bd4087a,0x67d2000d,0x98bc0046,0xccf2000a}},	//   _поря, воју, lově_, _בכם_
  { {0xe61917bd,0xa3bb000b,0x2ac40054,0x7b3c00bf}},	//   жди_, इंस_, _пљув, hčuj
  { {0x98a704f9,0xe981005e,0x98bc0046,0xcec00046}},	//   gină_, _разi_, nově_, ířit_
  { {0xd6d9005c,0x7c250264,0x3d00000b,0xf992000a}},	//   seł_, ozhr, राये_, _סרב_
  { {0x2d540005,0xd8740015,0x98bc0046,0x44650248}},	//   päev_, _كامب, hově_, ьвов
  { {0x57270031,0x98bc0046,0x11d601c6,0x78a31f15}},	//   _عراق, kově_, мігр, lanv
  { {0x28c4005d,0x2ee90026,0x98a70011,0xaefb0016}},	//   ल्कि, ddaf_, cină_, _phùn
  { {0x657d002d,0x45450029,0x6da20011,0x19b6000a}},	//   íshu, _تنتق, nţaţ, ופשר_
  { {0x93a80015,0x6f16006f,0x62880046,0xdfd2009a}},	//   _فايف_, tkyc, ědob, خيز_
  { {0xdbd9001c,0x9f550001,0x93b6000a,0x1eaa0015}},	//   nçõe, ењуј, _חלקו_, غازي_
  { {0x307a0029,0xdbd9001c,0xaefb0092,0xee3a11f2}},	// [3780] _وحدة_, içõe, _thùn, цна_
  { {0x6f16002c,0x7086006b,0xad5a008b,0x78a31f16}},	//   skyc, _югоз, ірах_, janv
  { {0xb6a30023,0x6f66000d,0xda7a05c4,0xe0fb000a}},	//   _phầ, _овоз, оял_, _וליל
  { {0xeab20015,0x7c65006e,0xcf93000a,0x60dc1f17}},	//   ئعا_, رالل, _שטר_, lerm
  { {0xdb1c0050,0xa2c1005d,0xfaa3119f,0x2baa000b}},	//   _spró, _वास्, тачо, _चटका
  { {0x753d00dc,0x7d0300c0,0x58d30010,0x98a70011}},	//   észl, önst, вошт, vină_
  { {0x38cb0074,0xd7f00029,0xec160015,0xb6a30016}},	//   تانی_, اكب_, _غورد, _thầ
  { {0x8cca014e,0x98a70011,0x0b1a0015,0x57260015}},	//   स्रो, tină_, _بقرة_, برتق
  { {0x60dc1f18,0xceb3000a,0x8703004a,0x55740515}},	//   kerm, דיח_, тяще, нгит
  { {0x2fdf0050,0x97c60029,0x60dc003c,0x4a750010}},	//   ługi_, _يتضم, jerm, _чыст
  { {0x61e4000c,0x987b000a,0x60dc1f19,0xddc60046}},	//   _asil, _ואבט, derm, _vykř
  { {0x7980003f,0xdbd9001c,0x68e81f1a,0xc873004c}},	//   _kumw, cçõe, _hadd, _סןף_
  { {0x61e400dc,0xc21b0036,0xf5060142,0x63ba1cf7}},	//   _csil, ієм_, _оздо, sutn
  { {0x637e0024,0x660f0c77,0x7b3c00bc,0xcf9b01ca}},	//   _līni, äcke, učuj, жја_
  { {0x68e81f1b,0x61e41f1c,0x94bb000a,0x57dc000b}},	//   _madd, _esil, _ומות, _मनोह
  { {0xc328003b,0x68e80876,0x98bc0046,0x98a71ed6}},	//   _يكون_, _ladd, tově_, miną_
  { {0x6458022d,0x8d790029,0x68fa0161,0xe29c000a}},	// [3790] _hyvi, سماء_, _ontd, _ושחר
  { {0x447b0053,0xe1670087,0x98bc0046,0x60dc1f1d}},	//   ַנדע, _تدبي, rově_, cerm
  { {0x3dc910ec,0x98bc0046,0xa3e4000b,0x70550015}},	//   staw_, sově_, निट_, _سنحا
  { {0xab940036,0xdd950010,0xfbd00086,0x160e000b}},	//   тиці, _памы, شتم_, िहार_
  { {0x78a31f1e,0xe9ce0033,0x290c1f1f,0x59b1000b}},	//   tanv, ык_, _boda_, ुंधर
  { {0x41b2005d,0x3f810020,0x41bc0008,0xf1b2005d}},	//   _जिसस, _kuhu_, קצוע, _जिसन
  { {0xa9270024,0x38ca002b,0x78a30400,0x3f811f20}},	//   _režī, ساوی_, ranv, _juhu_
  { {0x68fa00b8,0x291e002e,0x78a311bc,0x47d20015}},	//   _entd, _elta_, sanv, ايير
  { {0x99840029,0x3a540080,0xdbd9016e,0x58d50099}},	//   _للقو, _актё, rçõe, _поат
  { {0x7ae900f2,0x7afb0107,0xa91d0091,0x69cb0012}},	//   _haet, _hnut, _atžv, mtge
  { {0x56950063,0x7ae90020,0xdbd9001c,0x3d00000b}},	//   _зает, _kaet, pçõe, राते_
  { {0x8c1a0008,0x7ae900f2,0xbc1a000a,0x290702c6}},	//   פורי, _jaet, פורש, ljna_
  { {0xa2c1014e,0x78a100f2,0x20d60036,0x29c91f21}},	//   _वार्, _kelv, нівс, núa_
  { {0x61e400bd,0x7ae91f22,0x06380015,0x69cb1f23}},	//   _vsil, _laet, _تسمع_, itge
  { {0x05740031,0xdcee0016,0x69cb06a8,0x29c90016}},	//   _شاهد, _libă, htge, húa_
  { {0xe4560053,0xdee30cfa,0x3f810b28,0x60dc1f24}},	//   _איצט_, лоси, _duhu_, serm
  { {0xce470063,0x8d660080,0xc6920135,0xd5b2000a}},	// [37a0] езте_, евае, טאן_, ָׁב_
  { {0x76590026,0x69cb0012,0x2d54007c,0xa3e4000b}},	//   _mywy, dtge, väes_, निच_
  { {0x309b0008,0x76590026,0xa09b000a,0x68e81f25}},	//   _משימ, _lywy, _מייט, _radd
  { {0xbae50036,0x6122002c,0x2d9200dd,0x539a000a}},	//   кцій, _dôle, ppye_, פינו
  { {0x7ae90176,0x2bd2005d,0x6ae0000b,0x98a70b48}},	//   _daet, _सहवा, _नसीर, ziną_
  { {0x07e60054,0x7afb0353,0x103a004f,0x5963009b}},	//   ецим, _enut, ּגֵע, лъща
  { {0xb908014e,0xf0930008,0xd7e7000d,0x9d430818}},	//   _बस_, ננה_, емје_, _серд
  { {0x8b660074,0x76590176,0x7980003f,0x29c9002e}},	//   _سازم, _bywy, _tumw, búa_
  { {0x78a100dc,0x69cb0111,0xe4c60080,0xa84a002b}},	//   _felv, ctge, нённ, _کلام_
  { {0x76590026,0x98a70007,0x27e9002a,0xb17b0123}},	//   _dywy, tiną_, łana_, kvår
  { {0x97c50015,0x5b6a000a,0xc917000a,0xad1b000a}},	//   _لتنم, ּדָ֔, _רחבת_, פוטר
  { {0xcc3b0053,0x76590026,0xfbd3000a,0x78a10079}},	//   לעיט, _fywy, נתר_, _zelv
  { {0x94030086,0x6e3b002c,0xa2a2005d,0x200c008c}},	//   نویه, _ľubo, _ख़र्, ädin_
  { {0x1ee7002b,0x3f811f26,0xd5b9005e,0x45fb000a}},	//   کوری_, _puhu_, _ісі_, _מהדג
  { {0xdfd80063,0xbf1c000b,0x14d7000a,0xe4480058}},	//   нът_, नसून_, _נוהל_, _تلغى_
  { {0xa8570008,0x61220003,0xadd50054,0x2d820160}},	//   גילה_, _rôle, кобљ, _buke_
  { {0xe7e2005d,0x5d55017a,0x238c0046,0x2907002a}},	// [37b0] _कैसा_, вкат, _děje_, yjna_
  { {0xe6dd005d,0x7ae90026,0xdb1e0020,0x5ba70010}},	//   _मस्ज, _saet, htpä, ердз
  { {0x78a11f27,0x9bc80015,0xe3b80061,0xef1f007c}},	//   _relv, فولك_, nrı_, _tlü_
  { {0xe3b30053,0xe451000a,0x29c90077,0x69cb1f28}},	//   רױף_, בֶד_, túa_, ttge
  { {0x333c000a,0x753d0030,0x19eb0067,0x09e50bb1}},	//   התאמ, észk, ثراً_, толн
  { {0x88bc0089,0x7ae90026,0x69cb1f29,0x29c910e5}},	//   _směr, _waet, rtge, rúa_
  { {0x4af9002b,0x69cb1f2a,0x2d540012,0x6845006b}},	//   _يکصد_, stge, päer_, ънка
  { {0x7afb1f2b,0xf77100e5,0x69cb0012,0x0675006b}},	//   _unut, جات_, ptge, купя
  { {0x91820092,0x9fb60089,0x850c000b,0x637e003d}},	//   iện_, vřít_, ाउंट_, _mīnu
  { {0xe97500e5,0x601c0a64,0xa8020061,0x0000006a}},	//   _شهاد, nämö, ğırl,
  { {0x0395006b,0xa8020061,0xa91d00b3,0x3f570003}},	//   ърпя, şırl, _tužb, nçus_
  { {0x76590176,0xe72e0054,0x6f0f02b9,0xd6980033}},	//   _tywy, _ђе_, _nocc, _сiро
  { {0xd24f0015,0xe3b80061,0xf1bf1f2c,0x9f4c0046}},	//   ْنُ_, arı_, szán_, ídí_
  { {0xf8e1000b,0x2d821f2d,0x64c50015,0xf8b3000b}},	//   फ़िय, _ruke_, _شيبل, ीलिय
  { {0x10a318ba,0xa78c000a,0x6f0f1f2e,0xdb1e00cb}},	//   рисн, ּאמֹ, _bocc, ltpå
  { {0xc7b2103d,0x3eda0015,0x2216122f,0x6f0f1f2f}},	//   יבל_, بورج_, _афор, _cocc
  { {0x93130086,0x03570008,0xf8e1000b,0x3ea200cb}},	// [37c0] _خويش, _ביקש_, फ़ाय, _vekt_
  { {0x31bb000a,0xb17b0123,0xf1b90046,0x3ea20546}},	//   _קזינ, svår, áše_, _wekt_
  { {0xa7fc0064,0x106a0015,0xd838006f,0x61f6001a}},	//   _azın, _تحظى_, _rečo_, _hryl
  { {0x98a70007,0x6f0f02b9,0xdcb10016,0x3d00000b}},	//   minę_, _gocc, _ổn_, राहे_
  { {0xc3330008,0x98a70c85,0x3f570003,0x29d40015}},	//   סוד_, linę_, rçut_, ايتس
  { {0xe3b80061,0x6f0f02b9,0xcfa9002b,0xb227001a}},	//   yrı_, _zocc, _تایم_, _hræð
  { {0xb8da005d,0x97a30010,0x98a70870,0x6a8618a7}},	//   _आए_, арыл, ninę_, _алба
  { {0x6d5e11ef,0xe3b80061,0x8c4317b6,0x88bc005a}},	//   llpa, vrı_, _тесе, _eměp
  { {0xbb77000a,0xe663006b,0x1f5b000a,0xf98a0015}},	//   _יעלו_, итьо, ודקא, _آخره_
  { {0xe29a0023,0x660f00c0,0x98a70091,0x80b1000b}},	//   _đưa_, äcka, kinę_, _जयें
  { {0x91820092,0x39490cf7,0xd70607be,0x4cbb000a}},	//   yện_, éase_, _изжи, וזיו
  { {0x98a70007,0x63b50107,0x7b3c0085,0xe61a0054}},	//   dinę_, ázna, ačuv, _оде_
  { {0x2b46002c,0x6f0f1f30,0xa4d4005e,0x026b004a}},	//   čoch_, _rocc, _болі, ьшой_
  { {0x98a70007,0x2f1502ce,0x6d5e0079,0x61f600e7}},	//   finę_, _lågt_, jlpa, _dryl
  { {0xb4be005d,0x443a0020,0xb227001a,0x98a70091}},	//   इली_, _äp_, _bræð, ginę_
  { {0x5eb409ef,0x6d5e1f31,0x20070144,0xfebb002b}},	//   ийст, elpa, _ànim_, باست_
  { {0x6ca705c4,0xad670015,0x291c001a,0x61f60073}},	// [37d0] вреж, نائه, kkva_, _gryl
  { {0x01fa00a3,0xc0ab002b,0x98a70c00,0xbd440058}},	//   _נפתל, _کاکل_, binę_, لنقي
  { {0xb227002e,0x30a40010,0x98a70007,0x6f0f062b}},	//   _fræð, _трыв, cinę_, _tocc
  { {0xeab00002,0xc43b000a,0x501a000a,0x3f570003}},	//   قعه_, ותבי, _נורו, rçus_
  { {0x6eba0008,0x78a5002e,0x271f005d,0xdb26002b}},	//   _אזרח, ðhvo, _बतौर_, دونی
  { {0xeb930074,0x3ea91f32,0x7c871f33,0x18691f34}},	//   _نظر_, laat_, _шуме, нали_
  { {0x98a20080,0xc7a80015,0x97c400c3,0x645c007c}},	//   щище, نديل_, لتيم, üril
  { {0x307c01ac,0x27e9002a,0xa91d0085,0xa6e5058e}},	//   ואונ, łano_, _duža, ужил
  { {0x8cca000b,0x0f58000a,0x63ba002a,0xf9930015}},	//   स्को, כיהם_, ertn, _خبز_
  { {0x97c50015,0x27f70015,0x2018005b,0x0000006a}},	//   _مقطو, _لأصح, yyri_,
  { {0x9cd60008,0xf6d5005e,0x656f0046,0x69c60123}},	//   אותה_, _біля, ůcho, _äker
  { {0x15f50115,0x8bba000a,0x7bda004c,0x644f0045}},	//   _مستح, עזרת, ײַטק, şcio
  { {0xba3d0089,0x8236002b,0xfb1a000a,0x20b6004a}},	//   _zdůr, ارجا, גורמ, лёвс
  { {0x64a51f35,0x98a70007,0x25ad0943,0x61f600aa}},	//   _сака, tinę_, msel_, _vryl
  { {0x25ad1f36,0x201e1f37,0x7a2a0030,0xc4d20447}},	//   lsel_, áti_, _köté, _לגג_
  { {0x543a0053,0x28da005d,0x98a70007,0xdfcf0015}},	//   _רעקא, _मॉनि, rinę_, ثيف_
  { {0x25ad1f38,0x98a71ed6,0xbda50015,0x2ee00012}},	// [37e0] nsel_, sinę_, لحلو, reif_
  { {0x527b0053,0xdb0a0089,0xb19b0135,0x319b000f}},	//   _אנפא, ěnít, _רייכ, _רבינ
  { {0xf53600b2,0x25e5005d,0x62810089,0x69db0077}},	//   נטער_, _जैसी_, ělov, _apue
  { {0x3ea90111,0x0b460010,0x8456004c,0xa03b004c}},	//   caat_, ынен, אבעס_, _טעיפ
  { {0x99d30029,0xa91d00f0,0x7a360015,0xd357000a}},	//   متوا, _suža, دعائ, ניני_
  { {0xda650018,0xe9730015,0x8cca000b,0x672206c0}},	//   جامي, مهند, स्खो, _sloj
  { {0xd90d0086,0xdce60091,0x660f0123,0x7f440003}},	//   بیل_, _sukė, äckn, oniq
  { {0x7f440152,0xc6f81f39,0xab7a0015,0x7791002b}},	//   nniq, тних_, _أمرا_, زیها
  { {0x25ad1f3a,0x4a460033,0x0f7b004c,0x4992002b}},	//   gsel_, _снав, ערפל, _ایتر
  { {0x2956010f,0x80d6005d,0x03f80001,0xda4b000a}},	//   _събр, म्मे, вној_, _אֲבָ
  { {0x69c20026,0x86c60087,0x38cb0086,0x986a0015}},	//   luoe, _ميان, _سالی_, _أحذف_
  { {0xf1bf00dc,0xa91d05fb,0x932700c3,0xcc77000a}},	//   szám_, _južn, اردن, טגית_
  { {0xa596010f,0x25ad0026,0x3ea90177,0x98a70046}},	//   _срещ, csel_, vaat_, jině_
  { {0xa2c1005d,0x98a70089,0xdb0d0030,0xf0e8056d}},	//   _वाक्, dině_, áhúz, льск_
  { {0x753a08e0,0x351b000a,0x3ea91f3b,0x4f6b011e}},	//   mitz, _אוגנ, taat_, ешам_
  { {0x753a0b4c,0x3e070063,0x753d00dc,0xa91d016f}},	//   litz, лязв, észv, _nužn
  { {0xdb1e038d,0x7bdc1f3c,0x3ea91f3d,0x7ae21f3e}},	// [37f0] cupé, _apru, raat_, deot
  { {0x753a08e0,0x463b0053,0xd7f80011,0x3ea91f3f}},	//   nitz, געמע, _oră_, saat_
  { {0x417a000a,0xdfd10015,0x3ea91f40,0xbed503ae}},	//   _שנתב, _بيج_, paat_, _конј
  { {0x4f9a0008,0x8f9a0008,0x7f440251,0x539b000a}},	//   _שברצ, _שירי, cniq, גיאו
  { {0xa91d016f,0x628f02b9,0xe8ee0709,0xd7f80045}},	//   _dužn, icco, ол_, _ară_
  { {0xbca50015,0x6f0d0085,0x7a2a0030,0xe8f801c6}},	//   _خمسي, ljac, _söté, ллі_
  { {0xd70503ad,0x25ad0034,0x4809030c,0xf7710040}},	//   изки, wsel_, тейн_, ياب_
  { {0x4759006b,0x660f0123,0x6f0d1f41,0x25ad1f42}},	//   ърля_, äcko, njac, tsel_
  { {0xd7060080,0x6d4500f2,0x05a6004a,0x442c006f}},	//   рные_, onha, авый_, ezd_
  { {0x62880089,0x25ad1f43,0x612b0012,0x6d451f44}},	//   ědom, rsel_, _hülf, nnha
  { {0x78fa0135,0x612b00dc,0x8cca000b,0xc209000a}},	//   _שלעפ, _külf, स्टो, _קה_
  { {0x249801e2,0xf77000a2,0xb3820010,0x86c40015}},	//   ırma_, _فان_, ўлял, _هيمن
  { {0x8afd0046,0x442c002a,0xa2ba000b,0xf5050a32}},	//   _chři, azd_, ्लब्, _взло
  { {0x98a70089,0x628f1f45,0xa91d0b7e,0xf8a70015}},	//   vině_, acco, _mužo, غة_
  { {0x2bb10050,0x68fc02c1,0xd53a000a,0x398b0af5}},	//   jąc_, _órde, _שתצט, _løs_
  { {0x2bb1005c,0x98a70089,0x68e31f46,0x8cd8000b}},	//   dąc_, tině_, hend, न्नो

  { {0x63a30026,0x6e930015,0xed5a009c,0xa91d0085}},	// [3800] _hwnn, تلقا, воа_, _ružn
  { {0x41030010,0xf1bf00dc,0x61e90061,0x0c7a0021}},	//   _дзьв, zzák_, çele, نصاب_
  { {0xa3bb000b,0x60bb000a,0x00bb000a,0x65610123}},	//   इंट_, _בציד, _במימ, illh
  { {0x6f0d005c,0x98a70089,0x2bd7005d,0x6d451f47}},	//   cjac, pině_, _ठहरा, anha
  { {0x272a0092,0x7e9b0008,0x82d70053,0x88e6005e}},	//   _hùng_, _בסכו, שונג_, ижде
  { {0xe7b40015,0x68e31f48,0x7ae205ff,0x91f7000a}},	//   ممتد, gend, seot, ימנו_
  { {0x2b91002b,0x2bb1002a,0x8c4316fe,0xa91d0085}},	//   _فیلس, cąc_, _дере, _tužn
  { {0x6d5c00bd,0x68e31f49,0xf76f0015,0x272a0016}},	//   _hkra, aend, واي_, _mùng_
  { {0x753a0251,0x5506023f,0x3abb000a,0xc8b60015}},	//   titz, ачна, _שממנ, _نصاب
  { {0x6f0d09bb,0x783a0004,0x68e31f4a,0xf1bf0030}},	//   zjac, _иџет_, cend, szák_
  { {0x753a1f4b,0x6f0d005c,0x6e2d1f4c,0x8cc7000b}},	//   ritz, yjac, zzab, ालतो
  { {0x753a018b,0xd6d9005c,0x612b0020,0x26c200dc}},	//   sitz, koły_, _külg, ókod_
  { {0xf594003b,0x6d450176,0x78a80014,0x224d0064}},	//   _التج, ynha, _kedv, çek_
  { {0x361b0008,0x272a0092,0x15fb000a,0x3437002b}},	//   _בודד, _bùng_, _שהגע, اسید_
  { {0x272a0023,0x4ea70083,0x74670063,0xe3b80061}},	//   _cùng_, ираа, _кръв_, azır_
  { {0x272a0023,0xe47b0dab,0x93930029,0x747b039e}},	//   _dùng_, _ברוכ, _بجوا, _בנוג
  { {0x68e302c1,0x8cc2005d,0x9f54005e,0x6f0d1abc}},	// [3810] yend, _लाखो, івуч, rjac
  { {0x61ed166f,0x3f8500dc,0xc047002b,0xf1bf0125}},	//   _isal, ílus_, _نخجو, mrá_
  { {0x6d451f4d,0xa2c1005d,0x6e2d00dc,0xd2590024}},	//   rnha, _वाञ्, szab, ļņu_
  { {0xb4790053,0x68e31577,0x19b50015,0x2bb1002a}},	//   אָני, wend, محتج, rąc_
  { {0xe9190036,0x3df40010,0x8d770067,0x49cb056d}},	//   лоді_, _дзяс, _ناسا, туем_
  { {0x49b80015,0x88c8005e,0x68e31f4e,0x98a209dd}},	//   شاهد_, илів_, uend, пише
  { {0x60da0020,0xf1bf1f4f,0x68e31f50,0xe739120a}},	//   õtmi, hrá_, rend, лек_
  { {0x61ed0458,0xf1bf002e,0x6d5c0089,0x7bc50035}},	//   _osal, krá_, _zkra, muhu
  { {0x612b0014,0x673b0007,0x68e31864,0x7bc51f51}},	//   _küld, riuj, pend, luhu
  { {0x6aa90298,0xf1bf1f52,0xe7f9000b,0xa52514fd}},	//   _heef, drá_, ्मदा_, смод
  { {0xd8860086,0xf7850029,0x7bc50035,0xf1bf0a40}},	//   _اهمی, _الصَ, nuhu, erá_
  { {0x91e60121,0x98ae0091,0xa3b80065,0x56f40058}},	//   боме, rifą_, _चिर_, _وأنز
  { {0xd838010b,0x61ed0014,0xe7300029,0xc5880092}},	//   _reči_, _csal, _تصل_, _hồn_
  { {0x7bc5003f,0x6aa9016b,0x25b6002b,0xba56000a}},	//   kuhu, _leef, _اهود_, מסרו_
  { {0x0019008f,0x394700c0,0x798107c6,0xf1bf0c98}},	//   аўты_, inns_, _milw, ará_
  { {0x272a0023,0x24160008,0x840700dc,0x7f1a0015}},	//   _vùng_, _לחצן_, _előí, ديرز_
  { {0x11d70029,0x2fdf0011,0x1d8a0015,0xf772000a}},	// [3820] _هوية_, ăuga_, ائري_, לקל_
  { {0x6b800064,0x272a0092,0xdca60c71,0x23db000b}},	//   _simg, _tùng_, сажи, _बहाद
  { {0xb53a00b2,0xba09002b,0x2128002b,0xd6d9002a}},	//   נגעש, یزهٔ_, _ميکی_, soły_
  { {0x79810034,0x6d5c002a,0x9a6a0015,0x273a0091}},	//   _ailw, _wkra, همال_, vūno_
  { {0x28c9000b,0xdbda0061,0x3ea01f53,0xa3bb000b}},	//   _राशि, lçüt, mbit_, ेंड_
  { {0x25bf046c,0x71d7000a,0x19b90033,0xdc3c006f}},	//   drul_, מונד_, руць_, láča
  { {0x93bc0011,0x25bf0011,0xf093000a,0x78a804d1}},	//   nzăt, erul_, הנו_, _vedv
  { {0x6aa90298,0xa3ab005d,0x63be003c,0xa714042b}},	//   _geef, गठन_, _åpni, імпі
  { {0x79810026,0xe9a30e88,0xc6f704ab,0xba260033}},	//   _filw, _натп, сных_, _удак
  { {0xd90e002b,0xb6060085,0x73d81f54,0x3f821f55}},	//   _سیب_, vršć, адор_, _liku_
  { {0x78250015,0x83190015,0x8d5b000a,0xbd5b000a}},	//   _وعمل, لقدر_, רכיי, רכיש
  { {0xdb1e002c,0x2508002b,0x61ed1f56,0x25bf030d}},	//   kupí, ارکی_, _psal, brul_
  { {0x25bf0011,0x612b0061,0x05d30058,0x325500ce}},	//   crul_, _lüle, _فزوج, івгр
  { {0x16770008,0xa2d9000b,0xecc7000b,0xf1bf1f57}},	//   _הגדל_, _फॉर्, _लाइफ, rrá_
  { {0x653b000a,0x7d151f58,0x2ef50e3f,0x3dc00034}},	//   _תעוד, _rozs, озвр, eriw_
  { {0x3dc00034,0xd3710058,0x0000006a,0x0000006a}},	//   friw_, _تهب_,   ,
  { {0x9f600014,0xd2510086,0x80da005d,0x61ed1f59}},	// [3830] írás_, _زند_, _पॉवे, _usal
  { {0xd1310074,0x30a70784,0x6aa901f1,0x3ea01f5a}},	//   _آمد_, _урив, _seef, abit_
  { {0xec6b0033,0x3ea01f5b,0x7bc50a6a,0x0000006a}},	//   урак_, bbit_, uuhu,
  { {0x7bc5000c,0xde590010,0x8f88000a,0x798100aa}},	//   ruhu, _вамі_, _לְשֵ, _silw
  { {0xdaa80036,0xbddb0251,0xf3890016,0xda090015}},	//   свід_, _exèr, _nản_, ؤيته_
  { {0x2d9900f2,0x612b00dc,0x77950001,0xdd940033}},	//   _itse_, _füle, ојиц, _хары
  { {0x612b0061,0x63440030,0xd7091f5c,0xdb6b004a}},	//   _güle, lőne, инке_, _брал_
  { {0xf38900a7,0x25bf0011,0xe7760015,0xead40033}},	//   _bản_, trul_, يموث_, _нось
  { {0xf3890092,0xe6160892,0x2efa000a,0xd5ae0015}},	//   _cản_, жды_, בִיב, نفي_
  { {0xc5880092,0x451900a4,0x5cac000a,0xb9c40015}},	//   _tồn_, рция_, ְׁכַ, _رقمي
  { {0x2d8b0e6a,0xd4691179,0xd8380085,0x3eb90046}},	//   _luce_, рине_, _beču_, _odst_
  { {0x2d990020,0x442b002a,0x63bc1ad6,0x25bf00d4}},	//   _otse_, ąc_, árna, prul_
  { {0x10f6085d,0x6d89006f,0x6932002a,0xfe7f0f29}},	//   оявя, _uľah, płet, _maïs_
  { {0x2d83010b,0x3f82000c,0xf99204dc,0xe7dd000b}},	//   _nije_, _siku_, ורך_, _महाप
  { {0xe208005c,0xdc3c006f,0x3ea01f5d,0x25e50065}},	//   wróć_, táča, tbit_, जौरी_
  { {0x1f6602e1,0x6d4b0003,0xf3890016,0xd00f00c3}},	//   ікам, égan, _hảo_, خلف_
  { {0xe7e9005d,0x3f82002e,0x612b1bcb,0x3ea01f5e}},	// [3840] झौता_, _viku_, _süle, rbit_
  { {0x2d8b1f5f,0x5cc60015,0x70560015,0x3fe61092}},	//   _duce_, تغرق, _ونظا, _джов
  { {0xc616005d,0x2d830077,0x0bb6004a,0x9878006f}},	//   _तथ्य_, _dije_, ющая, _páči_
  { {0xe28d000a,0x2d991f60,0x27f8001a,0x0000006a}},	//   ְרוֹ, _ftse_, _árni_,
  { {0x93bc0011,0xe9cf0015,0xc333000a,0xe8941f61}},	//   nzăr, نغو_, ווא_, паль
  { {0xf3890016,0x89370033,0x0000006a,0x0000006a}},	//   _nảo_, опіс_,   ,
  { {0xf3890023,0xf72a0080,0xb8f2000b,0x6d4e0079}},	//   _sản_, иций_, _वा_, _ijba
  { {0x4b340086,0xd6d7030c,0x8f9b000a,0xd7570015}},	//   _عکاس, оть_, ביקי, يجيا_
  { {0xf3890023,0x7afd002e,0x59d1000b,0xfe7f0003}},	//   _bảo_, _ósta, _समयर, _haïr_
  { {0x99870011,0x6130079c,0x6b9e00cb,0x62960f0a}},	//   şiţi_, _hälf, oppg, _afyo
  { {0xd7ef003b,0x45470010,0x2cfb01ac,0x63440030}},	//   _لكل_, ўчым_, בליא, zőne
  { {0x51870835,0x92940010,0xe6930086,0xc2b8005e}},	//   жува, маюц, _قلمد, олює_
  { {0xf3890016,0x69c21f62,0x6b7b004f,0xf1bf01d3}},	//   _uản_, nroe, ירטנ, jzát_
  { {0x2d8b0089,0x98bc0091,0x3eab1f63,0x63440030}},	//   _ruce_, rovė_, _sect_, vőne
  { {0x28d2005d,0x29370053,0xd0d4006b,0x656f0003}},	//   _सानि, קאלן_, ьоръ, îche
  { {0x634400dc,0xcc0b002b,0x9d9b0015,0x69c21f64}},	//   tőne, یزان_, لخطأ_, kroe
  { {0xa8020064,0xd6d9002a,0x5cb90033,0x35c2000b}},	// [3850] ğıyl, niła_, йлаў_, _शिफ़
  { {0xc8c9000b,0xe5f7000a,0x2bbb0015,0xa8020061}},	//   _राइट, חזמר_, لاصة_, şıyl
  { {0xd2510086,0x63440030,0xfe7f0003,0x7f590323}},	//   _زنگ_, sőne, _païs_, _ганс_
  { {0xad9b002c,0xf41300a3,0x69c20034,0x539b000a}},	//   _prúd, ופע_, froe, ׁיבו
  { {0x8cd8005d,0x69c21f65,0xa022007c,0x2d990123}},	//   न्हो, groe, ööva, _utse_
  { {0x5d790053,0xf1bf00dc,0xed580010,0x4e7a0008}},	//   _לאָק, lzás_, _моў_, _לארצ
  { {0xb886001a,0xdb0503c1,0x0000006a,0x0000006a}},	//   _svíþ, tshä,   ,
  { {0xa3bb005d,0xf9890015,0x98ab0061,0xd6d9002a}},	//   ेंस_, _هنري_, ılın_, fiła_
  { {0xad9b006f,0xdb050123,0xa91d12ce,0x69c21f66}},	//   _hrúb, rshä, _luži, croe
  { {0xc5880023,0x799b02f2,0xa8a71f67,0xa91d0069}},	//   _gồm_, _ituw, _фрак, _ouži
  { {0x0ecb000b,0xcad5000a,0x9733002b,0xb465006b}},	//   िलाड, ֔וֹת_, _يکبا, якол
  { {0x91e6009c,0xd6d9002a,0xcad5004f,0x0000006a}},	//   поме, biła_, הוֹת_,
  { {0x61300020,0xd6d9005c,0x6d89002c,0x42230063}},	//   _jälg, ciła_, _zľav, едяв
  { {0x867a013a,0x25e0005d,0xe3a6002b,0x6d4b0003}},	//   _פרסו, _कहती_, _کشوی, égal
  { {0xdfd20029,0xa06a070e,0x645c007c,0xe4d60067}},	//   عير_, сава_, ürit, _رويت_
  { {0xa91d016f,0x0000006a,0x0000006a,0x0000006a}},	//   _duži,   ,   ,
  { {0x6ead005d,0x13db000b,0x5d860015,0x6130007c}},	// [3860] _ज़रु, _बहुभ, سلال, _nälg
  { {0x4d630083,0xd709004a,0x2ee90034,0x0000006a}},	//   екув, ́ние_, aeaf_,
  { {0x711b00b2,0x28d2005d,0xa7fc0064,0x5ba50036}},	//   _הויפ, _साबि, _ayın, дріз
  { {0x3ae8002b,0x69c21f68,0xc8c90065,0x22f7004f}},	//   تبطی_, troe, _राउट, ּ֖אן_
  { {0xc3330008,0x4efb000a,0x6a130015,0x61300123}},	//   עוד_, _ההכו, فبور, _välf
  { {0x612b0005,0x69c21f69,0x672b001a,0x38c8002b}},	//   _küla, rroe, _algj, زاتی_
  { {0xd6d9005c,0x97c60015,0x61e402f2,0xa96701ca}},	//   wiła_, ستثم, _lpil, џија_
  { {0x96ea0191,0xf3890023,0x9f490064,0x8f9b0008}},	//   ська_, _cảm_, ıkça_, זיקי
  { {0x96b70001,0x290f001a,0x61e402f2,0x3ad30058}},	//   чују_, ýjað_, _npil, _سيلز
  { {0xa98b0008,0x79b7000a,0xce37000a,0xa5330033}},	//   _הָאִ, _מלמד_, פאית_, еньч
  { {0xd6d9005c,0x61e41f6a,0xe60f002b,0xe3b80061}},	//   siła_, _apil, نشی_, ayın_
  { {0xd6d9002a,0xa91d10af,0x6d5e1f6b,0x0000006a}},	//   piła_, _ruži, hopa,
  { {0xa91d1f6c,0xf67a002b,0x637f003d,0x6d5e1f6d}},	//   _suži, _امشب_, _jūni, kopa
  { {0xf67b0008,0xd5cb000a,0x857a006b,0x28df000b}},	//   _האדמ, _הֶהָ, _усет_, प्पि
  { {0x04db0008,0xb4660015,0xcf88005e,0x657a0012}},	//   _הקול, _عدته, зсуд_, mmth
  { {0x7ae4007c,0x656802dc,0x0000006a,0x0000006a}},	//   õitl, lldh,   ,
  { {0x788300dc,0xbf1d021e,0xb2bc000a,0xf1bf0030}},	// [3870] _kívü, _नवीन_, _המחר, rzás_
  { {0xfd470010,0x628e0024,0xa91d016f,0xfc460b7e}},	//   чэбн, ānoš, _tuži, čína_
  { {0xa0220020,0x7b94005e,0x799b0079,0x60c8002a}},	//   ööta, ерії, _stuw, ódme
  { {0x1b190010,0xceeb0086,0x201e006f,0xfa55002b}},	//   ўжды_, _اردن_, ätie_, ورشگ
  { {0xa2c0005d,0x4efa0008,0xe9ce006b,0x1efa004f}},	//   _वयस्, _והרו, ък_, _ולרע
  { {0x5d850086,0xc893002b,0x3208000a,0x61300c9e}},	//   _زلزل, راتژ, ל֖וּ_, _välg
  { {0x6e200020,0xe7390a61,0x47d2006e,0xdb1e0030}},	//   _ümbr, жей_, نيور, supá
  { {0x28d2000b,0x65681f6e,0xfbd2004f,0x0000006a}},	//   _साथि, eldh, _שתן_,
  { {0x80ce005d,0x06090036,0xea17002b,0x27311f6f}},	//   _ताले, інок_, _عذرخ, _láng_
  { {0x05760029,0x7aeb00b8,0xa3b90029,0xe3b90e3f}},	//   ومية_, legt, ياجر_, обо_
  { {0x69d90ced,0x61e41f70,0xc2c60015,0x69cb1f71}},	//   ltwe, _spil, ويدي, luge
  { {0x59d1005d,0x61300020,0x6d5e003f,0x6d4b0030}},	//   _समार, _mäle, zopa, égaj
  { {0x7bc5018b,0x6d5e000c,0xe7300029,0xd6d9002a}},	//   hrhu, yopa, _حصل_, liło_
  { {0x38600011,0x7aeb00dd,0x27310016,0x212c0125}},	//   şire_, hegt, _báng_, ódh_
  { {0xe0d2002b,0xd6d9002a,0x6d5e1075,0x61fd0795}},	//   _یزد_, niło_, vopa, avsl
  { {0xf4120008,0xdbc60020,0x27310092,0xeb0c000b}},	//   _יפו_, _köög, _dáng_, _सचेत_
  { {0xb2bb000a,0xf1aa0015,0xf1bf0030,0x69d90079}},	// [3880] _ומפר, _باعه_, szár_, jtwe
  { {0x41760086,0x80a6002b,0x8c9500fd,0x63a100bf}},	//   _تابس, _تمدن, ерці, opln
  { {0x69d905d6,0x61300f3a,0xdbc6007c,0xe1650015}},	//   etwe, _väld, _löög, _ثديي
  { {0x69cb1f72,0x61300012,0x8a460015,0x69d91f73}},	//   fuge, _wäld, وَان, ftwe
  { {0xceb3009d,0x62490008,0x63760f7b,0x7bc50045}},	//   _שיש_, ּנוּ_, mánd, arhu
  { {0xfbc60036,0x63760ab3,0xb7d80015,0xc237000a}},	//   _обго, lánd, كوتا_, ורנו_
  { {0x9992005c,0xc7ba0033,0xa91d0091,0x569416fe}},	//   ódła_, цёл_, _nužu, найт
  { {0xc5880023,0xcc570135,0x7d1c04e2,0x63761f74}},	//   _hồi_, _חבלי_, _hors, nánd
  { {0x69d9005c,0xbb43049d,0xb9930015,0x7d1c1f75}},	//   ctwe, _ретк, _للقب, _kors
  { {0xd6d9002a,0x44f4004a,0x6376039f,0x48760369}},	//   biło_, хпос, hánd, _قداس
  { {0xd6cf0a0b,0xd6d9002a,0xc5880016,0xe2f901f3}},	//   _ит_, ciło_, _mồi_, пені_
  { {0x7d1c038d,0x3d05005d,0xfbb7000a,0x41e701f3}},	//   _lors, _होने_, ופטת_, міга
  { {0x27310023,0x7d1c049c,0xa2640063,0x660f00c0}},	//   _sáng_, _oors, върл, äckt
  { {0x7d1c0a3a,0x461300c3,0xdb1e1f76,0x7ae4007c}},	//   _nors, _جوهر, lupä, õitj
  { {0xe5710008,0xdfd80063,0x69cb00b8,0x79881f77}},	//   _עַד_, мът_, zuge, _midw
  { {0x33180029,0x1ee7002b,0x7bc50057,0x63760077}},	//   _يزيد_, بوری_, vrhu, gánd
  { {0x171b00b2,0x7e2b0010,0x93780002,0x80da000b}},	// [3890] קומע, ціва_, _تصور_, _पॉके
  { {0xc5880092,0x7d1c1f78,0x6602002a,0x2d870012}},	//   _bồi_, _cors, _mrok, öne_
  { {0xd0110074,0xe3b80064,0xe1ff0077,0xdb1e0f6a}},	//   _صلح_, nsı_, lvó_, kupä
  { {0x0f270191,0xca750010,0x637602c1,0x613000f2}},	//   _цьом, нулы, cánd, _väle
  { {0xdddd0050,0x89a80036,0xd6d9005c,0x7aeb11a8}},	//   _wysł, дків_, wiło_, regt
  { {0x69cb1f79,0x7aeb00c5,0x63a10107,0x64460061}},	//   ruge, segt, ypln, şkiy
  { {0x6d4511ba,0xa8480015,0xdbc6007c,0x68450033}},	//   miha, ولهم_, _söög, энка
  { {0xf7710806,0x6d45013c,0x66021455,0x69d90012}},	//   دات_, liha, _brok, ptwe
  { {0xd6d9002a,0xa6e20033,0x2cb10030,0x99d70015}},	//   siło_, ужыл, _kezd_, _تتزا
  { {0x6d450084,0xf3890023,0xf992000f,0xd6d9002a}},	//   niha, _hải_, _ערב_, piło_
  { {0x6b8900dc,0x934604ab,0xa7d40015,0x383405aa}},	//   _kieg, енне, _لتنص, _инфр
  { {0xdbc60020,0xd7fa000a,0x8c1a000a,0xc169000a}},	//   _töög, _מהעל, לותי, _הח_
  { {0xe5b40010,0x6d451f7a,0xe6bd000b,0x66270015}},	//   _айчы, kiha, ोलीज, _تراك
  { {0x412a0191,0x6b891f7b,0x2bd0005d,0xe6100086}},	//   чого_, _lieg, _हमला, _خشم_
  { {0x637602c1,0x6f1d1f7c,0x8026002b,0x33f40033}},	//   tánd, _bosc, ررسم, _ачыс
  { {0xc5880023,0x3f9e0048,0x672900f2,0x6b891f7d}},	//   _rồi_, ītu_, nkej, _nieg
  { {0x3f9e0024,0x612b1f7e,0x63761f7f,0x7d1c1f80}},	// [38a0] ūtu_, _küll, ránd, _pors
  { {0x10160010,0x98a70007,0x63760077,0x6e36002a}},	//   _зьмя, minė_, sánd, rzyb
  { {0x7d1c08e1,0x98a70007,0xe5720135,0xbc6a0015}},	//   _vors, linė_, אַף_, أمان_
  { {0xeab20029,0x7d1c069b,0xb60500bd,0x28d2021e}},	//   اعا_, _wors, _košč, _साहि
  { {0xf38a0023,0x98a70007,0x26c200dc,0xef210024}},	//   _cải_, ninė_, ókom_, _daļā_
  { {0xf1b30008,0xf38a0092,0xc5880016,0x497301f3}},	//   נסו_, _dải_, _tồi_, гліс
  { {0xfce30036,0x67ce0030,0x17f70015,0xfc1a006e}},	//   _щоро, dőjá, فرية_, _عقرب_
  { {0x66021f81,0xdb1e007c,0x98a70091,0x75d40021}},	//   _prok, uupä, kinė_, نيبا
  { {0xde7a005e,0x262a0033,0x98a70073,0x0000006a}},	//   орiї_, яцко_, jinė_,
  { {0x98a70007,0x2e3b000a,0x65610034,0x273a0091}},	//   dinė_, פגינ, golh, vūnu_
  { {0x386100b8,0x44270010,0x73d70033,0x15f2000b}},	//   ührt_, ецям_, ндэр_, _अनवर_
  { {0x6729006f,0x98a70091,0x7528003d,0xd80b000a}},	//   ckej, finė_, skdz, _מִדָ
  { {0xa5f80001,0x612b00b8,0x291e013c,0xda03000b}},	//   _целу_, _füll, _kota_, लियत_
  { {0x656103af,0x291e022d,0x44250089,0xe1ff0077}},	//   colh, _jota_, byl_, rvó_
  { {0xa0220020,0x4ea70180,0xb4be021e,0x34fb000a}},	//   ööpa, ерза, ेली_, _מהגד
  { {0x98a70007,0xa7fc0061,0x201e006f,0x63ba0e1e}},	//   binė_, _ayık, ätia_, mstn
  { {0x98a70007,0x290c1f82,0x6d450332,0x291e007c}},	// [38b0] cinė_, _onda_, tiha, _oota_
  { {0x63760156,0x612b0020,0x63ba1f83,0x7c94002b}},	//   ráne, _külm, ostn, هشما
  { {0x6b891f84,0x987f0046,0xf38a0016,0x6d451f85}},	//   _pieg, _péči_, _sải_, riha
  { {0x6d450b71,0x61f60026,0xe9d10015,0x290c1f86}},	//   siha, _ysyl, لغت_, _anda_
  { {0x6b890024,0xceb60008,0x831a004c,0x3ea91f87}},	//   _vieg, _בפרק_, ווײז, mbat_
  { {0xf38a0016,0x63ba1f88,0x48e5005e,0x18691f89}},	//   _vải_, kstn, токв, мали_
  { {0x9c650086,0x7d540001,0x291e1f8a,0x63ba1f8b}},	//   _شهرو, _сврх, _dota_, jstn
  { {0xf38a0023,0x3d05021e,0x06091f8c,0x63ba02de}},	//   _tải_, _होते_, дник_, dstn
  { {0x63ba032c,0x44251f8d,0xb4be005d,0xceb40135}},	//   estn, wyl_, ेलू_, ניץ_
  { {0x67291f8e,0x7afb1f8f,0x3f8b0085,0x98a70091}},	//   skej, _haut, _licu_, vinė_
  { {0x7afb1f90,0x65610030,0xd9f9000b,0x39471f91}},	//   _kaut, rolh, ंिकत_, mins_
  { {0x7afb0048,0x98a700df,0x656100dc,0x26c30091}},	//   _jaut, tinė_, solh, ėjos_
  { {0x63ba00bd,0x291e003f,0x39471a8b,0x7aba000a}},	//   astn, _yota_, oins_, וצרו
  { {0x66060134,0x36ad0053,0x98a70007,0xb60500bc}},	//   ække, _אָדער_, rinė_, _vošč
  { {0xd0590036,0x98a70870,0x612b1f92,0x3b020030}},	//   ерті_, sinė_, _külj, lépő_
  { {0xe45600b2,0x394700c7,0x98a70091,0x7afb1f93}},	//   _שיקט_, hins_, pinė_, _naut
  { {0xb15a0015,0x4d66006b,0x63760030,0x3dc9183a}},	// [38c0] _يؤخذ_, вкав, pánb, graw_
  { {0xed570001,0xad9b1f94,0xdca61c3f,0x6376013f}},	//   воу_, _trún, тажи, bánc
  { {0x69db1f95,0x26c200dc,0x80d7005d,0x98bc0011}},	//   _aque, ókok_, _बाते, hivă_
  { {0x291e1f96,0x7afb0939,0xab27006b,0xca4a0015}},	//   _sota_, _caut, коха_, ولاه_
  { {0x7fe2014e,0x8c960127,0xada60004,0x5d860015}},	//   _पहुँ, _арбі, _јагл, _للحل
  { {0x63ba1f97,0x39471f98,0x823b004c,0x07e60054}},	//   ystn, gins_, וענצ, вцим
  { {0x7afb0152,0xf093000a,0x291e1f99,0x6b661cd9}},	//   _faut, סנה_, _vota_, _аква
  { {0x7afb00df,0x26060036,0xc0530008,0xb6f400d7}},	//   _gaut, вчог, יזו_, узиј
  { {0x291e0251,0xae05005d,0xc6f7044e,0xe9d70ea6}},	//   _tota_, रियन_, тных_, _икт_
  { {0x290c1f9a,0xb4be021e,0x05780015,0x7bde0085}},	//   _unda_, ेले_, عمدة_, otpu
  { {0x3cfa005d,0x1cb7000a,0x6cab000a,0xd876009a}},	//   _उसने_, כליל_, וֹכְ, _شائب
  { {0x46a60063,0xfbd3000a,0x63760307,0x7bde0028}},	//   _радв, סתר_, vánc, itpu
  { {0x3f801835,0x7bde1de9,0x63ba0c4e,0x0000006a}},	//   dmiu_, htpu, sstn,
  { {0xf993000a,0xc1050015,0x27310030,0x9954000a}},	//   ירש_, دوسي, _tánc_, אֹֽד_
  { {0x55770008,0xc5790053,0x1048004a,0xd24e002b}},	//   _שעון_, _אָקט, вяти_, قچی_
  { {0x63760089,0xa8570008,0x39470186,0x57fb000a}},	//   ránc, דילה_, zins_, וללו
  { {0x629d00dc,0x7db40015,0x2731006f,0x7afb1f9b}},	// [38d0] mcso, لصلا, _jána_, _raut
  { {0x612b0064,0x7afb17da,0x629d0030,0x3ea90144}},	//   _mülk, _saut, lcso, sbat_
  { {0x637600dc,0x5478000a,0xd251002b,0x3158004c}},	//   lána, תְּנ, _خنک_, _ביזן_
  { {0x629d00dc,0x3dc9005c,0x5a3505b3,0x6e320030}},	//   ncso, praw_, лнет, ókbó
  { {0x333c0008,0x63760030,0xd5a6002b,0x7afb19ad}},	//   ותאמ, nána, _دف_, _vaut
  { {0xe8f802e1,0x4dda000a,0x9996002b,0x39471e83}},	//   клі_, _אחשו, دپور_, uins_
  { {0x63760125,0x7afb1f9c,0x57a40054,0xf7450fac}},	//   hána, _taut, ашња, леко
  { {0x39471f9d,0x98bc0011,0x63760030,0x9b740021}},	//   sins_, tivă_, kána, _ناقص
  { {0xd4d9008f,0x63760014,0x5a470010,0x4a55042b}},	//   ньні_, jána, _рэва, _скас
  { {0x99900011,0x236900bd,0x6ab900da,0xf7950033}},	//   şaţi_, _akaj_, lawf, _бажэ
  { {0x98bc0011,0x6b9502c1,0xb6d50015,0x8d5c000a}},	//   sivă_, _juzg, _مقاع, וכזי
  { {0x25790152,0x11d60484,0x28df000b,0xf8df000b}},	//   dèle_, лігр, प्रि, प्रय
  { {0x33200152,0xaad1005d,0x63760f08,0x9343004a}},	//   _voix_, _हाईक, gána, сняе
  { {0xb6020089,0xa2ba005d,0x94050015,0x236907c4}},	//   čátk, ्लङ्, _موته, _ekaj_
  { {0x3d17005d,0xf4840001,0x69cb00b8,0x6717000b}},	//   नाने_, _кућн, hrge, थापक_
  { {0x69c4005d,0xd0070001,0xad9b001a,0x6d891f9e}},	//   _रिली, ћете_, _trúl, _džam
  { {0xc69200a3,0xd37b0643,0x637b000a,0x6da60054}},	// [38e0] מאן_, _ארקט, _אנקד, уиза
  { {0xc8d2014e,0x23b7005d,0xfca90031,0x7bde0b14}},	//   _साइट, _आबाद, نامو_, ttpu
  { {0xa3bb005d,0x5aca007a,0x80db000a,0x00f7000a}},	//   ेंट_, елем_, _אחיז, _גזים_
  { {0x2ca701e2,0xda7a03a9,0x69cb0034,0x68e31f9f}},	//   ında_, нял_, frge, efnd
  { {0x82d700b2,0xe3a70086,0x59f81654,0x4e270238}},	//   רונג_, _گر_, теля_, _боян_
  { {0x39990152,0x28df000b,0x6d4b0003,0x2731013f}},	//   _dès_, प्लि, égat, _rána_
  { {0xe3a703ef,0xd90d0086,0x8b95034e,0x63760307}},	//   _در_, ظیم_, _вруч, zána
  { {0xb8cb005d,0x17060086,0x48f0000b,0x273101c0}},	//   _क्_, افظی_, _इसको_, _pána_
  { {0x290f002d,0xc8d60015,0xe6660174,0xa53407d1}},	//   álaí_, _مزاع, ытко, инич
  { {0x59830080,0x637600dc,0x46a4000b,0x69c00061}},	//   _глуб, vána, _ग्रह, _ivme
  { {0xb893003b,0xd6c40074,0x24580191,0xa8560099}},	//   _المع, _نمای, тань_, _стај
  { {0x84330036,0x6376084c,0x25790003,0x0877004c}},	//   снює, tána, vèle_, _געבט_
  { {0xdc270064,0x96b9022a,0xf3640033,0x629d0030}},	//   köğr, _руху_, стэн, rcso
  { {0x629d0014,0x25790152,0x63761723,0x25f3000b}},	//   scso, tèle_, rána, ्टरी_
  { {0x629d03c0,0x63760014,0xc8d2000b,0x612b0012}},	//   pcso, sána, _साईट, _jüli
  { {0x6376001a,0xbf67002b,0x61301fa0,0x2369035f}},	//   lánn, ادآو, _häll, _ukaj_
  { {0x613001d1,0x612b0020,0xc334000a,0x68e30034}},	// [38f0] _käll, _lüli, _לוק_, yfnd
  { {0x3cff014e,0x627c0008,0x02e1005d,0x61ed0035}},	//   ईयें_, _אנחנ, ग्रह_, _ipal
  { {0x768b0064,0x69c0003c,0xbc0702bf,0xb09a000a}},	//   _köyü, _avme, ычай, _ביתר
  { {0x6376002d,0xeeab005e,0xb9c50015,0x32091fa1}},	//   hánn, _яток_, لقصي, _kray_
  { {0x99d7003b,0x69cb1fa2,0xdeba000a,0xda650004}},	//   اتصا, urge, _שמשל, јвли
  { {0x319c004c,0xf99000c3,0xac940033,0x81b8004f}},	//   עבונ, سبه_, _гарш, נהוג_
  { {0xd8b80031,0x4759006b,0x5c040033,0x0000006a}},	//   ادها_, крия_, _лята,
  { {0x99d70015,0xdb05001a,0xd709004a,0x637d010d}},	//   _متطا, rshó, тние_, nénd
  { {0x8579000d,0x7d1200dc,0x61300012,0xe7080015}},	//   ксот_, _újsá, _bäll, طتين_
  { {0x6606002e,0xd5e80015,0x4ddc000a,0x6352003d}},	//   ækka, اعين_, תחזו, māni
  { {0x99840029,0x61ed0273,0x9cd6000a,0x69c60804}},	//   _اللو, _apal, בותה_, _åker
  { {0x60c50125,0xe7870033,0xc4820033,0xe28605a7}},	//   _adhm, _сузо, ўлюк, илни
  { {0x9980032c,0x85c80029,0x85a70001,0x25070086}},	//   šiť_, _مِنْ_, _сјед, _مرغی_
  { {0x613001d1,0x763a0053,0xdb050152,0x463a0053}},	//   _gäll, _בענג, sphè, _בענע
  { {0x63520024,0xa06a1fa3,0x7ae91fa4,0xc4d200a3}},	//   hāni, тава_, _obet, _וגו_
  { {0x68000014,0xef870015,0x75230046,0x63761fa5}},	//   lájá, لَّى_, _honz, máno
  { {0x63761fa6,0x7dc6002b,0x25bf1e19,0x32091fa7}},	// [3900] láno, شقان, nsul_, _gray_
  { {0x127b0053,0xfc3200e6,0xc1bb000a,0x5bc60015}},	//   _באפע, يحا_, _שמיש, لتصف
  { {0xf53600b2,0xc5f2005d,0xd6a5005e,0x9aa60015}},	//   סטער_, _अन्य_, _сiчн, لماو
  { {0x25bf0005,0x305b0008,0xd488000a,0x7c23008c}},	//   ksul_, _ידיד, אָנֹ, änra
  { {0x680000dc,0x6b821fa8,0x929b000a,0xd357000a}},	//   kájá, rmog, דינת, סיני_
  { {0x67220020,0x82770053,0x58d7005e,0x637d1fa9}},	//   _sooj, בענע_, идія_, méne
  { {0xbad60033,0x637d0030,0xd7f00015,0x68000030}},	//   _візы, léne, سكة_, dájá
  { {0x613000c0,0x3ea0142d,0x96ea0342,0x15d80054}},	//   _säll, ncit_, тька_, гмић_
  { {0x66e2005d,0x99e90002,0xbb3b004c,0x637d01ce}},	//   क्षक_, _معلق_, _סעמי, néne
  { {0x96a6005d,0x89db000a,0x85530015,0x612b007c}},	//   _ट्रॉ, _בחמי, ْخَط, _tüli
  { {0x63761faa,0x61ed1fab,0x3d17000b,0x4cbb000a}},	//   ránn, _spal, नाते_, כזיו
  { {0x3209003e,0x637d0d46,0xb7db004f,0x59ba0065}},	//   _pray_, kéne, _יקבי, _उबार
  { {0x6130022d,0x6d400007,0x637d00dc,0x15a70063}},	//   _täll, _įman, jéne, _къщи_
  { {0xf6690086,0x38690011,0x59c9000b,0x75231fac}},	//   _صحنه_, şare_, _रिसर, _gonz
  { {0xc57b000a,0xe809000b,0xe3f70015,0xdb050003}},	//   _שרות, विया_, _نعيش_, sphé
  { {0x3f8f0084,0x61300604,0x442c0034,0x65680030}},	//   ögu_, _jälj, myd_, lodh
  { {0x442c0176,0x637d1714,0xe3b80064,0xdd9100e6}},	// [3910] lyd_, géne, ayıt_, سوا_
  { {0x52e3000b,0x11440015,0xdca70033,0x98b20046}},	//   ट्रॉ_, _وَيُ, ршап, ěděl_
  { {0x443e1fad,0x515a000a,0x442c0034,0x656f0003}},	//   nzt_, _תכתו, nyd_, îchi
  { {0x637600dc,0x63520024,0xfbd00015,0xc43b000a}},	//   jánl, tāni, بتك_, כתבי
  { {0x2cb8003c,0x442c0026,0x98a50c5b,0x7c3e1249}},	//   _ferd_, hyd_, биле, azpr
  { {0x63a40227,0x5ba70296,0x2cb81fae,0x26c60030}},	//   _činn, _враз, _gerd_, _adoo_
  { {0x013801e4,0x2d99063b,0xc8f8002b,0x65680030}},	//   שרות_, _huse_, شويچ_, dodh
  { {0x3eb90f9a,0x00580008,0xc0580008,0xc7a80029}},	//   _jest_, ישות_, יבוץ_, جدول_
  { {0xb88209f0,0xd7060080,0xad9b002d,0x443e0024}},	//   _þínu, сные_, _brúi, ezt_
  { {0x442c0176,0xd7e70191,0xf9900806,0x25bf0011}},	//   fyd_, _відо, _قبل_, rsul_
  { {0x3cfa005d,0x3eb90251,0x442c0026,0x98a70007}},	//   _उससे_, _oest_, gyd_, linį_
  { {0xe6950029,0x6376002c,0x26c200dc,0x637d0030}},	//   _الإد, ráno, ókot_, yéne
  { {0x98a70007,0xa696000a,0xf556002b,0x06850015}},	//   ninį_, _הכנה_, _گلوب_, _الشُ
  { {0x62630036,0xa0a3068e,0x637d01c4,0x753a059b}},	//   ївра, зард, véne, chtz
  { {0x251a013a,0x1dda014e,0x3eb91983,0xaad8000b}},	//   _תוצא, यूनत, _best_, _डालक
  { {0x637d0014,0x6e930029,0xdd920029,0x98a70007}},	//   téne, كلفا, كور_, kinį_
  { {0x6130022d,0x2d9101e2,0x0eb90010,0x659a004c}},	// [3920] _jälk, _bize_, русы_, ָיעק
  { {0x3eb90005,0x98a70007,0x637d00dc,0x27e9005c}},	//   _eest_, dinį_, réne, łany_
  { {0x41760074,0x637d0014,0x3eb90ced,0xdd8f0002}},	//   _پاکس, séne, _fest_, روم_
  { {0x2cb80298,0xbaba0029,0xaaba0086,0x98a70007}},	//   _werd_, اداء_, ادار_, finį_
  { {0xd00f002b,0xcec40046,0x98a70091,0x660d0091}},	//   _قلی_, atří_, ginį_, _šakn
  { {0x613000c0,0xd6d9002a,0x8b961faf,0x3f9a1fb0}},	//   _sälj, egł_, _грач, _kupu_
  { {0xb900014e,0xa7fc0064,0xa09b004c,0x57f4005e}},	//   _था_, _ayır, ניקט, іпит
  { {0xcb6a0010,0x6f0403b0,0xaac50015,0x98a70091}},	//   _сабе_, ndic, _وتقن, binį_
  { {0x442c0b7c,0x61301fb1,0x612b0700,0x98a70091}},	//   wyd_, _välj, _kült, cinį_
  { {0x443e018b,0x442c020a,0x5dfb000a,0x69c21fb2}},	//   tzt_, tyd_, נפינ, msoe
  { {0x6568000c,0x78ba0048,0x612b0064,0xd7960015}},	//   rodh, _ietv, _mült, _الصخ
  { {0x673b1fb3,0x442c1fb4,0x3c77000a,0x443e0012}},	//   chuj, ryd_, מתים_, rzt_
  { {0x69c2020a,0x78ba0007,0x443e145e,0x66760031}},	//   nsoe, _ketv, szt_, _ادار
  { {0x3eb90005,0x91790016,0x69c20034,0x2d991fb5}},	//   _sest_, uần_, isoe, _ruse_
  { {0x889b00b2,0xdbf10089,0x4035000d,0xe3b80061}},	//   רבלי, _příj, цевс, ayır_
  { {0x2d911fb6,0x69c200dd,0x7f75005e,0x5457000a}},	//   _size_, ksoe, ігає, _לבוב_
  { {0x612b0064,0x4af9002b,0x9e150033,0x8cdd000b}},	// [3930] _bült, یکرد_, ўдзі, _पादो
  { {0x78ba00fb,0x3eb91fb7,0xdb1e002a,0x69c200aa}},	//   _netv, _west_, kupó, dsoe
  { {0x69c200dd,0x28d2000b,0x8c590015,0x3eb91fb8}},	//   esoe, _साजि, جلاء_, _test_
  { {0x98a700df,0xa088000a,0x79c90058,0x3a751fb9}},	//   tinį_, _לְרִ, لوصف_, олер
  { {0x7ccb0024,0x4993002b,0x9cb50015,0x6f9f0065}},	//   tērē, سیار, _ومحت, _खंडू
  { {0x612b00b8,0x98a70007,0x527c0053,0xb9250029}},	//   _gült, rinį_, אנדא, تفتي
  { {0xe809005d,0x98bc0046,0x60c8002a,0x98a70091}},	//   विधा_, livě_, ódmi, sinį_
  { {0x612b0014,0x69c200dd,0x8038000a,0xdb231f15}},	//   _küls, bsoe, מנוע_, öräl
  { {0xf814002a,0xc5190033,0xe5590054,0xcf2c000a}},	//   ążać_, аўні_, ијој_, רֽוֹ
  { {0x613000c0,0xb4620086,0x6f0402c6,0xe809000b}},	//   _välk, ژگيه, zdic, विदा_
  { {0x26340023,0xc2090008,0xf8b20008,0x15e5000b}},	//   ào_, _שה_, _חשב_, _कहकर_
  { {0x659503ca,0x63ad1fba,0x0000006a,0x0000006a}},	//   _даду, _čand,   ,
  { {0x4ade005d,0xbebb00aa,0x63761fbb,0xc24305b5}},	//   फ्टव, _voël, lánk, дняк
  { {0xb17b00c0,0x25ad1fbc,0x660900cb,0xd49b0e7c}},	//   stån, mpel_, mvek, _срд_
  { {0x61300020,0xa2e61c0c,0xc0e3006b,0x6aa2002a}},	//   _jäli, _дойд, ьорк, ycof
  { {0x69c20026,0x91820092,0x0eaa0033,0xfe05000b}},	//   ysoe, iển_, ркай_, रिंस_
  { {0xfd4a09e8,0xa2e50015,0xc0960015,0x6f041fbd}},	// [3940] азак_, _رأين, _وجدت, rdic
  { {0xbd83017f,0xdca10033,0x3f9a0573,0x38600045}},	//   дгук, есцi_, _tupu_, şiri_
  { {0xb53a0053,0x637600dc,0x644100b8,0x637d0003}},	//   סגעש, vánj, nzli, léna
  { {0xdb1e002e,0x69c2014c,0x6da60015,0x307b000a}},	//   vupó, tsoe, _ومجم, _כאינ
  { {0x394e1a8b,0xc9f60015,0xaa470937,0x6abb0034}},	//   tifs_, تساع, опца_, _deuf
  { {0x69c2020a,0x6bd60015,0x19b90033,0x79810034}},	//   rsoe, _وتأر, суць_, _chlw
  { {0x17f70029,0x3d17000b,0xf8030033,0x78ba006f}},	//   قرية_, नारे_, дчын, _vetv
  { {0xf0930008,0x8f9b000a,0xa2d6000b,0x394e0003}},	//   ונו_, סיפי, _भाग्, sifs_
  { {0xd6770015,0x27310016,0x998907c4,0xdb0502ad}},	//   يحًا_, _mánh_, šaš_, tshö
  { {0x2bd1005d,0x27310016,0x7c47001a,0xdb150030}},	//   _हिमा, _lánh_, _úrræ, öböl
  { {0x4c9b0008,0x29ff005c,0x66e61fbe,0x04580015}},	//   יביו, ałać_, _можа, صلحة_
  { {0xe3af002b,0x5334004a,0xad9b006f,0x6b9c1fbf}},	//   کری_, деют, _krút, _murg
  { {0xe4da0086,0x644102c6,0xf2040033,0x637d0324}},	//   _نوشت_, azli, мяро, géna
  { {0x3cf6000b,0x7228005e,0x1677000a,0xa3b5000b}},	//   ीयों_, іцяв_, _וגדל_, _चौक_
  { {0x27310092,0x6b9c0020,0x2f190080,0x6441002a}},	//   _bánh_, _nurg, бовь_, czli
  { {0x27311fc0,0x2fcd0085,0x98bc0046,0x3dd20034}},	//   _cánh_, čeg_, tivě_, fryw_
  { {0x3dd20026,0xd2510087,0xdddd0024,0xd14b002b}},	// [3950] gryw_, _سند_, _izsū, _نشدن_
  { {0xdfdb010f,0x91820023,0x63a4016f,0xd1310015}},	//   _към_, yển_, _činj, _أمد_
  { {0x70fa0008,0x60fa0008,0xdc980036,0x612b00dc}},	//   _ההתח, _ההתק, івці_, _fülr
  { {0xad9b1fc1,0x27310016,0x29ff002a,0x63761fc2}},	//   _csúc, _gánh_, yłać_, gánh
  { {0xe9d80484,0x7e7d003d,0x6d580085,0x644108d2}},	//   жкі_, _uzsp, čvar, zzli
  { {0x68f80020,0x3f891fc3,0x41d30065,0x6b9c1fc4}},	//   gevd, lmau_, _तिनस, _furg
  { {0x6abb00b8,0x6bd40015,0xdd940033,0x2d83008c}},	//   _teuf, _يتفر, _цары, _ihje_
  { {0x61300356,0xdcfd0007,0xd7ee0029,0x63760264}},	//   _väli, _pusė, اكي_, ránk
  { {0xe616056d,0xae0e0065,0xfe0e0065,0x59d20065}},	//   зды_, सियन_, सियस_, _सियर
  { {0x6441018b,0x63761fc5,0xa4450080,0x3eb2002a}},	//   tzli, pánk, знод, zbyt_
  { {0x29ff005c,0xd4690001,0xf8b2000a,0xe6950015}},	//   słać_, сине_, _נשא_, _فلاد
  { {0x64410c1f,0x8c1a000f,0xdc36004c,0x25ad1fc6}},	//   rzli, צורי, פארט_, ppel_
  { {0x2d8300f2,0x969a000a,0x64411022,0x06960015}},	//   _ohje_, _השנה, szli, _عنوة_
  { {0x27310092,0x29071fc7,0xc5680015,0x29fd006f}},	//   _sánh_, ndna_, _وحول_, _mňa_
  { {0xb4d7021e,0x29051fc8,0x69d90079,0x3075004a}},	//   िली_, _mala_, huwe, дутс
  { {0x69d9000c,0x6e960029,0x1dc7000b,0x6352003d}},	//   kuwe, سلطا, _लिखत, rāns
  { {0xf7720008,0xd357000a,0x733b004c,0x6b9c1fc9}},	// [3960] תקן_, _מיקי_, _לעקס, _surg
  { {0x6b9c1fca,0xa91c002c,0xee370185,0x11460015}},	//   _purg, _ohľa, чну_, _رَجُ
  { {0x309b0008,0x69d90111,0xbc6a002b,0xc173000a}},	//   _לשימ, euwe, حمان_, _אחז_
  { {0x23a1005c,0x6b9c0064,0x539a000a,0x20dc000b}},	//   _mój_, _vurg, צינו, _बाँध
  { {0xcb670010,0x63761fcb,0xceb3000a,0x29051fcc}},	//   чаце_, gáni, _ריש_, _bala_
  { {0x29fd002c,0x69cd005d,0x6b9c1fcd,0xfd3a0015}},	//   _dňa_, _सिरी, _turg, _اكسب_
  { {0x68f80061,0x6d4e0ad4,0x7c6500c3,0x3b0a145a}},	//   revd, _imba, _قافل, _лево_
  { {0xf0930008,0xa6140e44,0x5c5b000a,0x29050125}},	//   ענה_, дмич, _הדלק, _eala_
  { {0xb0dc005d,0x63760077,0x29051fce,0x35e30033}},	//   _बांग, cáni, _fala_, нцэв
  { {0x9a3b0008,0x2a3b0008,0xaa3b000a,0x8434005e}},	//   _התמק, _העממ, _התמח, дноє
  { {0x3f890026,0xa438022a,0x59750033,0x79530015}},	//   ymau_, ізму_, _цыту, _ثَلا
  { {0xf7430457,0x66e3000b,0x987b004c,0x6130007c}},	//   _пехо, _गायक_, _פראק, _mälu
  { {0xdb05002d,0xdb1e0046,0x5745006e,0x518709a8}},	//   nphá, jspí, _تخلف, зува
  { {0xf617013a,0x45fb000a,0xa91c006f,0x660214cf}},	//   _מחדש_, _להדג, _yhľa, _isok
  { {0x69d900b8,0x85030015,0x84e70040,0x63760030}},	//   zuwe, _سوين, _رفيق_, záni
  { {0x6d4e0f4d,0x637d1fcf,0x290700bc,0x2731013f}},	//   _amba, méno, zdna_, _páni_
  { {0x3f890176,0xa3d4005d,0x4d9808f0,0x610f0073}},	// [3970] rmau_, िंक_, зкую_, tėlė
  { {0x91bc000a,0x2bd1000b,0x637600bf,0x7bc51fd0}},	//   _המזי, _हिदा, váni, tshu
  { {0xd2510086,0x629a0089,0x7055002b,0x6130007c}},	//   _سنگ_, ětov, _آنجا, _pälv
  { {0x69d9000c,0xfbd000e6,0x6d4e0dd3,0x2bb80015}},	//   tuwe, اتل_, _emba, سامة_
  { {0x2a980015,0x99a80015,0xa2a2000b,0x66d60061}},	//   أئمة_, كُنْ_, कुट्, zükü
  { {0x63761fd1,0x2ca5007c,0xd9980040,0x0000006a}},	//   ráni, _üld_, سخها_,
  { {0xccf2039e,0x69d902f2,0xaf57000a,0x29051fd2}},	//   _שכל_, suwe, ּׁ֥ה_, _vala_
  { {0x05a90191,0xeab30029,0x29050508,0x7d070030}},	//   овий_, _سعر_, _wala_, _hajs
  { {0x05b90074,0x61300012,0x29051fd3,0x6d8900b3}},	//   زگشت_, _kält, _tala_, _užas
  { {0xb4d7021e,0xb9c40015,0x53c90c1c,0x0000006a}},	//   िले_, _أقلي, огом_,
  { {0xa3d4014e,0x7d071fd4,0x660201c2,0x637d013f}},	//   िंग_, _majs, _esok, rénn
  { {0x0000006a,0x0000006a,0x0000006a,0x0000006a}},	//     ,   ,   ,
  { {0xe56e010f,0x127a0029,0xd6d9002a,0x23a1002a}},	//   _аз_, تحدث_, chła_, _wój_
  { {0x659400d0,0x659a000a,0x74290015,0xc5650015}},	//   _зачу, _ויסק, _وكشف_, _تُتي
  { {0xdff50146,0x28e0000b,0x9103006b,0xd0070175}},	//   нять, _नासि, ъпре, мере_
  { {0x26df003f,0x672b01d7,0xf1bf0030,0xaf7500af}},	//   nguo_, _jogj, gyás_, ећућ
  { {0x9e660086,0x63a40787,0xcd2a0033,0xb606001a}},	// [3980] ذارن, _čini, ожае_, mráð
  { {0x1e830010,0xb606001a,0xc535000a,0x201e007c}},	//   тлум, lráð, וָ֣ה_, ätis_
  { {0x711b0053,0xcdc90643,0xdb1e001a,0x1ae6024f}},	//   _וויפ, שך_, sspí, доем
  { {0x3cfa005d,0xceb60015,0xdbc7001a,0xc8e0000b}},	//   _उसके_, _تحدث, _vöðv, _नाहट
  { {0x63680064,0x613000c0,0x4efb000a,0xf9fa0015}},	//   mınd, _fält, _והכו, تراث_
  { {0x636801e2,0xda650225,0x6d4e1fd5,0x38c8002b}},	//   lınd, راني, _umba, ساتی_
  { {0x613000c0,0x31570053,0xb606002e,0x0f56000a}},	//   _häls, ויסן_, kráð, ֽיִם_
  { {0x636801e2,0x85a6000d,0x6009000a,0x8b260033}},	//   nınd, мјод, לִפְ, _ўдае
  { {0x89d70015,0x80c1000b,0x98a60891,0xd3790160}},	//   _يوفر_, वरमे, _жизе, nuće_
  { {0x05760058,0x6d5e0c4e,0x6368007f,0x2d4f0535}},	//   باعد, nnpa, hınd, yżem_
  { {0x672b0014,0x63680064,0x99800007,0x9cd70008}},	//   _fogj, kınd, šių_, וויה_
  { {0x2bd1005d,0x2d981fd6,0xd5ba07be,0x63680061}},	//   _हिसा, _lire_, _дск_, jınd
  { {0x636801e2,0xd379016f,0x41e40010,0x6376002e}},	//   dınd, juće_, кіра, jánu
  { {0xe44f0086,0xd379016f,0xa5070054,0x26c41fd7}},	//   اضی_, duće_, _жеља_, lamo_
  { {0x636801e2,0xa3cb005d,0xf1940036,0x4fc40c1d}},	//   fınd, _लिए_, тирь, кста
  { {0x2f180036,0x2d981fd8,0x660d1c4e,0x26c41fd9}},	//   мось_, _aire_, _šaki, namo_
  { {0xd379010b,0x9d150004,0xf38a0016,0xfe700015}},	// [3990] guće_, ндач, _nảy_, لدك_
  { {0x0216000a,0xd578000a,0xc578000a,0x2d980003}},	//   _נחתם_, פָּר, פָּט, _cire_
  { {0x2d981fda,0x61300607,0x8af91fdb,0x26c4191e}},	//   _dire_, _vält, знес_, kamo_
  { {0xf38a0023,0x63680064,0x8b94005e,0x61300012}},	//   _bảy_, cınd, вріч, _fäls
  { {0xad9b002f,0x613000f2,0x63760c23,0xe9a80015}},	//   _grúp, _tält, mánt, ودون_
  { {0xde160053,0x63761fdc,0xaa560015,0x3ea90045}},	//   _אַלץ_, lánt, علوا_, lcat_
  { {0x2d4f005c,0xe7391fdd,0x97c4006e,0x28e00065}},	//   yżej_, зей_, نتيم, _नारि
  { {0x26c400bd,0x6605004a,0x6e29002a,0x05b50033}},	//   gamo_, епиа, _żeby, нсоў
  { {0x29d50806,0x317100dc,0x59c9000b,0x3f990085}},	//   _سياس, kozz_, _रिटर, _misu_
  { {0x63680064,0x89170087,0x14251fde,0x27310046}},	//   zınd, _تبرئ, едом, _ránu_
  { {0x63680064,0x2d4f002a,0x26c40085,0x973c0085}},	//   yınd, eżek_, bamo_, _suće
  { {0x3f99010b,0x794d005c,0xe611002b,0x26c41fdf}},	//   _nisu_, dźwi, _مشت_, camo_
  { {0xdb050084,0xf38a0092,0xb606001a,0x21a302ed}},	//   pphæ, _xảy_, rráð, лиям
  { {0x25d600b2,0x06560008,0x260c005d,0x6e200251}},	//   _נוצן_, _אינך_, ़िरी_, _àmbi
  { {0x636801e2,0xe4650020,0x2d980152,0x63760030}},	//   tınd, ööde_, _rire_, fánt
  { {0x539a0008,0x61300123,0xf26a006b,0x2d981fe0}},	//   _ציפו, _päls, _нийл_, _sire_
  { {0x636801e2,0x36190008,0x0d8600a5,0x2d980003}},	// [39a0] rınd, הוּד, елан, _pire_
  { {0x636801e2,0x26c41fe1,0x61300123,0x59c9000b}},	//   sınd, zamo_, _väls, _रिजर
  { {0xf53600b4,0x63680064,0xeb9a09ef,0x60bb000a}},	//   עטער_, pınd, чие_, _מציד
  { {0x205700b2,0x2bd1005d,0x2d9800ea,0x0b460033}},	//   _טייל_, _हिरा, _wire_, энен
  { {0xd3570008,0x7e9b000a,0x26c41fe2,0xf8b0002b}},	//   עיני_, _מסכו, vamo_, لکا_
  { {0xdbc7007c,0x4937008b,0x67d400f4,0x2bd80065}},	//   _rööv, нзію_, воку, _डिपा
  { {0x91820092,0xdb1e0125,0xd90d002b,0x1c04000b}},	//   iền_, aspá, تیل_, _रनिल_
  { {0xdb0e00c0,0x59c9000b,0xb7630033,0xc6f80098}},	//   _avbö, _रिचर, лтый, фних_
  { {0xbb4302bf,0xcb67004a,0x6acb000a,0x5eeb000a}},	//   _сетк, _чате_, _זֶבַ, הַיְ
  { {0xa3cb005d,0x61fb001c,0xd90d002b,0xf8a90015}},	//   _लिख_, çulm, _وین_, _قدمه_
  { {0x628404ed,0x799a003f,0xd92b000a,0x4aa4000b}},	//   _azio, _iitw, _מֵאָ, _ओलाव
  { {0xdbc70020,0x2259004a,0x637d0046,0xe5a60054}},	//   _tööv, димы_, ménk, _зиди
  { {0x7bde00d9,0x799a003f,0x75d300e6,0x92940033}},	//   hupu, _kitw, _مينا, лаюц
  { {0xa4d40191,0x3f990020,0x2127002b,0x6284002a}},	//   _рокі, _sisu_, ريزی_, _dzio
  { {0x8f870054,0x20c40033,0x75350030,0xa98b000a}},	//   ећал, ысяг, özze, לָלִ
  { {0x447b0008,0x799a005c,0xe47b000a,0x747b000a}},	//   _מנוע, _litw, _מרוכ, _מנוג
  { {0x3f990048,0x5d990010,0x3ea91b44,0x3f9e001a}},	// [39b0] _visu_, дкаў_, rcat_, ítur_
  { {0xceeb0074,0x63761549,0xbd780036,0xfd610016}},	//   _کردن_, sánt, ебує_, _huyế
  { {0x3f9900d9,0x9c190015,0x7c670015,0x4255002b}},	//   _tisu_, بياء_, رائل, _سنگر
  { {0x7ae20849,0x54570053,0x9f35005e,0x64480091}},	//   ggot, עסאן_, _ремі, izdi
  { {0x799a005c,0xd7f80011,0xf771002b,0x7bde1fe3}},	//   _bitw, _apă_, یاب_, aupu
  { {0xb9b200e6,0x7ae200bd,0x60c70d99,0x61300123}},	//   جموع, agot, najm, _jälp
  { {0x6f0d0085,0x63680061,0xd942110d,0xdcfc0091}},	//   odac, nınc, рещи, _airė
  { {0x91820092,0xd00c000a,0x6448003d,0x08340033}},	//   iến_, פּוֹ, dzdi, ыхія
  { {0x91820023,0xd7060080,0x3b640063,0xd6a8002b}},	//   yền_, тные_, _сърв, رديم_
  { {0xdb0500b8,0xb8860089,0xdb1c00dc,0x2bd8000b}},	//   sphä, _stíž, özöl, _डिमा
  { {0x14220010,0x87d4006e,0x6f1d0d16,0x60c71fe4}},	//   адэм, _مغنا, _onsc, dajm
  { {0x637600dc,0x628402b9,0x69d91fe5,0x6f0d0535}},	//   váns, _pzio, orwe, jdac
  { {0x6f0d0026,0xdea2002b,0x69cb1fe6,0xe809000b}},	//   ddac, ییدی, nsge, विका_
  { {0x6f1d018b,0xa6840036,0x672907c4,0x64a20513}},	//   _ansc, _слід, ljej, _каша
  { {0x7f440152,0xc7ac000a,0x0442006b,0x69d90012}},	//   thiq, ּׁמָ, _вещн, hrwe
  { {0xd36f003b,0x672900d9,0x673b12e1,0x66f9000b}},	//   _وهو_, njej, nkuj, ्यटक_
  { {0x76490061,0x63a31fe7,0xdca60684,0xdd92012c}},	// [39c0] nzey, _hunn, вази, لور_
  { {0xc50c0053,0x6c960015,0x62a3003d,0x25f4000b}},	//   ּלאָ, نشاط, āvoš, ्बती_
  { {0x40d900b4,0x7f44038d,0x1c390010,0xfba90036}},	//   _אַרײ, phiq, няць_, етій_
  { {0x6b8903af,0x7ae20007,0x799a0035,0x8e860015}},	//   _cheg, ugot, _sitw, _للجه
  { {0xf98a0086,0x7bde1fe8,0x7ae210b1,0xbb470015}},	//   وخته_, supu, rgot, ضلون_
  { {0x497305fc,0x6d4500b8,0x7bde1fe9,0x35c4000b}},	//   аліс, chha, pupu, लीफ़
  { {0x69cb00dd,0x8b960004,0xd6d9002a,0xbc76002b}},	//   asge, _арач, liły_, _شهرب
  { {0x6b9b04ed,0xd6d00029,0x60c70085,0xbebb00aa}},	//   _giug, حقة_, zajm, _hoër
  { {0xe9a6010f,0xd379016f,0x3f7b004c,0xd6d9002a}},	//   _разп, juća_, ואקס, niły_
  { {0x91820023,0x636801e2,0x4a750010,0x799a016b}},	//   yến_, yınc, _сыст, _uitw
  { {0x4427005e,0x2738001a,0x14180015,0xe3af0015}},	//   вцям_, _léni_, ريحة_, يرَ_
  { {0xfd610023,0x54530063,0xf837000a,0xc6a303ae}},	//   _quyế, рвют, _שנאת_, _крши
  { {0x290c1fea,0xd5b00086,0xa5f80001,0xd3790085}},	//   _kada_, _افت_, _челу_, guća_
  { {0xe466007c,0x63a31feb,0x63680061,0x1637000a}},	//   ööst_, _funn, tınc, _בנדר_
  { {0xfd610023,0x4ea70083,0x290e0026,0xc058017f}},	//   _tuyế, врза, idfa_, віт_
  { {0xe3af0086,0x63680064,0x88bc0046,0x69cb0034}},	//   _برو_, rınc, _hněd, ysge
  { {0x6f0d017e,0xc2990191,0x5f940036,0x8e150033}},	// [39d0] rdac, _яких_, ритт, ыдац
  { {0xc5340008,0xb0b7000b,0x50b7000b,0xbebb00aa}},	//   נָּה_, _अभिग, _अभिष, _poës
  { {0x290e0026,0xd131002b,0x63680061,0x673b002a}},	//   ddfa_, _نمک_, lına, ykuj
  { {0x41c40086,0x6f1d1d04,0x5db70015,0xd6d9002a}},	//   _حقیق, _unsc, _لإسر, biły_
  { {0x69cb00b8,0x637d1fec,0xd6d9002a,0x63680061}},	//   usge, géni, ciły_, nına
  { {0x69cb1fed,0xbfc40046,0x290c1fee,0x99d40067}},	//   rsge, řížs, _cada_, شتها
  { {0xd0f8013a,0x6d550064,0x69cb0012,0xf7f50015}},	//   דמות_, _imza, ssge, استد
  { {0x63a31fef,0x88340010,0x59c50015,0x409c000a}},	//   _runn, рэшц, _ميرك, ובוס
  { {0x99d90029,0x290c002d,0x89d90086,0x63a31ff0}},	//   _سواء_, _fada_, _سوار_, _sunn
  { {0x290c0048,0x60c500b8,0x7ae90046,0x91820016}},	//   _gada_, _nehm, _hcet, iễn_
  { {0xf8b20008,0xd6d9002a,0x65660030,0xf5560058}},	//   _השב_, ziły_, ékha, طلَب_
  { {0x63a302d2,0x07090015,0xc654002b,0x3f47007c}},	//   _vunn, _سيتي_, افیک, _jõud_
  { {0x20d60036,0x290c0064,0xbb3a0053,0xf772000a}},	//   лівс, _yada_, גערי, _פקד_
  { {0x75440010,0x06e3005d,0x865a000a,0xa116002b}},	//   _кніз, _गाँव_, _אדני, دوست
  { {0xd6d9005c,0xd379016f,0xdb1e0123,0xa0670515}},	//   wiły_, suća_, lspå, гара_
  { {0x2eb500d7,0xd6d2004f,0xc7b2004f,0x7ae900d4}},	//   исус, ֶׂב_, מבל_, _ncet
  { {0x0321000b,0x4d660033,0x9da60015,0xddc50015}},	// [39e0] यारह_, гкав, اصره, لآلي
  { {0x365a0053,0x3d280086,0x02030010,0x7e7d1ff1}},	//   ײכענ, ختری_, _узьн, _dysp
  { {0xdd8f003b,0xe4a80008,0x10160010,0x9f5e00dc}},	//   أول_, דֹנָ, _сьпя, ító_
  { {0xbae50036,0xbda60087,0x290c1ff2,0xb17b02d2}},	//   ицій, _محسو, _sada_, ståt
  { {0x290c013c,0x8f9b004c,0xda77006b,0x0000006a}},	//   _pada_, _ריכי, ляш_,
  { {0x3f800251,0xd90d0086,0x1c04000b,0x637d1ff3}},	//   lliu_, ویق_, रबदल_, réni
  { {0x1826002b,0x8c461ff4,0xb8cc000b,0x290c1ff5}},	//   اقعی_, _севе, _गल_, _vada_
  { {0x8c1b0008,0xa8170002,0xd6d9002a,0xdb1e008c}},	//   _אולי, اتور_, ykłe_, uspä
  { {0xe4c60892,0x290c1ff6,0xa3e6000b,0xba090015}},	//   лённ, _tada_, यून_, _لتلك_
  { {0x35f70086,0xa9760180,0x5f16000b,0x93f41ff7}},	//   اريد_, _субј, _पोस्_, апоц
  { {0xb993003b,0x49170008,0x3f800007,0x8319002b}},	//   _اللب, _תקבל_, kliu_, نقدر_
  { {0xdc3b0053,0x41e7017f,0x63680061,0x4613002b}},	//   געטר, ліга, tına, _گوهر
  { {0x60c5019a,0x7ae6001a,0x36360040,0x3f800091}},	//   _pehm, _öktu, _حراس, dliu_
  { {0xe9ce0033,0x63680061,0x973c0085,0xc693000a}},	//   цкi_, rına, _kućo, _פאס_
  { {0xdfd80063,0x6557000a,0x68f50061,0x8557000a}},	//   лът_, _תבוא_, _özde, _תשוב_
  { {0x1fb4004a,0x63680061,0x1847000a,0xbdd5024f}},	//   ссёр, pına, רְךָ_, иобщ
  { {0x3f470020,0xe806000b,0x1dc0000b,0x77f1000b}},	// [39f0] _nõue_, _वैसा_, शीलत, _अङ्क_
  { {0x3f800091,0x1637000a,0x7ae902b9,0x7e7d01c0}},	//   aliu_, אנמר_, _scet, _vysp
  { {0x2d4f0050,0x7e7d005c,0x04db0008,0x3f800251}},	//   dżet_, _wysp, תקבל, bliu_
  { {0xb17b00c0,0xcf270015,0xeafb0015,0xab0b0015}},	//   fråg, _إردي, عرضت_, عتاق_
  { {0x3f680061,0x4aa80033,0x645e0073,0x0000006a}},	//   oğun_, укін_, _žpil,
  { {0x26c9016f,0x4dda000a,0x19b80015,0x2bd9009a}},	//   _žao_, _בחשו, اطنة_, _لارک_
  { {0xb17b1ff8,0xe7310029,0xab95005e,0x0138000a}},	//   mråd, قصة_, _виві, ררות_
  { {0xdb1e00c0,0x96f90033,0x6c54004a,0xdb0702de}},	//   tspå, тэку_, _уксу, _stjæ
  { {0xf5050063,0x6f0f1ff9,0xff18000a,0x7545008a}},	//   азпо, _macc, רקחת_, иниз
  { {0x5a340c53,0x851f000b,0x6f0f1ffa,0x39400079}},	//   _унут, बाइट_, _lacc, ëist_
  { {0xdb1e00c0,0xd4690175,0xc867006b,0x89340021}},	//   sspå, тине_, _стаи, _اعقا
  { {0x17f80029,0x3634002b,0xcc76000a,0xdb1e01d0}},	//   _حركة_, _گرمس, יעתה_, pspå
  { {0xf7700196,0x8b76000a,0xa3e6000b,0x6d891ffb}},	//   _عام_, שתרע_, यूब_, _džaz
  { {0xa06a08fb,0x1664005e,0x686d004c,0xd3790085}},	//   вага_, _увім, _װײַזע, vrće_
  { {0xd4790053,0x1fb5022a,0x9fc70658,0x9f560054}},	//   _באַל, йстр, игра_, ањај
  { {0x6f0f04ed,0xdfa50029,0x24a70007,0x43730015}},	//   _cacc, صحفي, šumą_, _وهور
  { {0x5de6005e,0x3da7004a,0x9e650015,0xee371cd9}},	// [3a00] ржза, икто_, ماكن, ант_
  { {0x8cb60661,0x621b004f,0x3f800073,0x0000006a}},	//   рсач, _יופק, sliu_,
  { {0x273800dc,0x6f0f0682,0x6c4a00e5,0xbc19005e}},	//   _ként_, _facc, خلاف_, ліці_
  { {0x501b00a3,0x39451ffc,0x88bc0046,0x7c850054}},	//   _סוכו, _alls_, _oněc, суђе
  { {0xbe670010,0x2bd8000b,0xdebb000a,0xdca6016a}},	//   _ваяж_, _डिवा, _במכל, _ваги
  { {0x6f04018b,0xb953005e,0xa3e6000b,0xb7d40015}},	//   leic, овіщ, यूड_, مقتب
  { {0xb8070029,0xe7580036,0xa926001a,0xacfb000a}},	//   ليوم_, ликі_, _alþý, _שהלכ
  { {0x39450251,0x681c0011,0x98a5002a,0xe6040058}},	//   _ells_, _rădă, _rolą_, مِعَ
  { {0x48e615b3,0x758a0ac9,0x9adb000a,0xe6030015}},	//   _возв, ксов_, _שחמט, قِيَ
  { {0x6f041ffd,0x25a602b9,0x23690085,0x69db000b}},	//   heic, _vuol_, _sjaj_, _निती
  { {0x04580029,0xd6c40086,0x637d00dc,0xac900033}},	//   الجة_, _همای, ként, овiш
  { {0x883b000a,0x27fe01d7,0x6b821ffe,0xe73a004a}},	//   _שתאו, _iptn_, nlog, _шее_
  { {0x64450005,0x6f0f1fff,0xdb0900b8,0x05b40002}},	//   _ühin, _racc, _ließ, _امتح
  { {0xd5fb0008,0x3178002a,0x14180015,0xd62b000a}},	//   _ספור, gorz_, _ميتة_, _י֥וֹ
  { {0x6f04002d,0xe5710008,0x6f0f04ed,0x6b822000}},	//   feic, _מַה_, _pacc, klog
  { {0xddc4005c,0x57fb000a,0xc7d7000a,0x747b000a}},	//   dził, כללו, יולי_, _שנהג
  { {0x6b820198,0x2d4f005c,0x59d2000b,0x6ca7006b}},	// [3a10] dlog, dżer_, _सिगर, ареж
  { {0x6bd70015,0x6b82003d,0xed070099,0xfa37009a}},	//   لتصر, elog, јџан, یرشد
  { {0x63680064,0xbca40029,0x6b820313,0x6f0f2001}},	//   kınl, زمني, flog, _tacc
  { {0xadbd0010,0x59d50015,0x99d50015,0x637d2002}},	//   _памi, مغتر, متتا, cént
  { {0x63680064,0xf8b4000b,0xde64006b,0x2738001a}},	//   dınl, ुरूप, _дърп, _léns_
  { {0xdb0700c0,0xaa68002b,0x09480004,0x18692003}},	//   _stjä, جمهٔ_, ичји_, лали_
  { {0x98f40115,0xc0d8000a,0xf9900067,0xbb85002b}},	//   تثنا, שֵׂה_, ذبه_, _هلسي
  { {0x6b820251,0x63680061,0x2ee92004,0x37aa002b}},	//   clog, gınl, ngaf_, دئوی_
  { {0xe57905b3,0x0f58000a,0xd6190058,0x0000006a}},	//   лзи_, ייהם_, اتبا_,
  { {0x6f04018b,0x99850029,0xa5090001,0x39450251}},	//   zeic, _الطو, ћена_, _ulls_
  { {0xc209000a,0xe611002b,0x0000006a,0x0000006a}},	//   _רה_, زشک_,   ,
  { {0xdb070123,0x67222005,0x870402ed,0x0000006a}},	//   _utjä, _gnoj, _мяче,
  { {0xd774003b,0x6f042006,0x527601fe,0xb5a70c02}},	//   _بالع, veic, суну, _трей
  { {0x6f0400b8,0x98ac0024,0x6b8201a3,0x45b6000a}},	//   weic, _kodā_, zlog, _הפסל_
  { {0x6f040048,0x637d0387,0x63680061,0x753c0030}},	//   teic, tént, lınm, örze
  { {0x27ea0134,0x03d60008,0x2bd1000b,0xe436000a}},	//   _åbne_, _הוקם_, _हिजा, _לרצח_
  { {0x6f04018b,0x63680064,0x80ba005d,0x637d0077}},	// [3a20] reic, nınm, ्रदे, rént
  { {0x5bc60029,0xd257000a,0xdd8f00c3,0xdb1e063b}},	//   متصف, _לשפה_, فوق_, lspø
  { {0x636801e2,0x61e60064,0x6f0400b8,0xf55a0053}},	//   yınl, lukl, peic, נדעמ
  { {0xf093013a,0x5f060033,0xcaca0054,0xd6d9002a}},	//   _מנת_, _узма, угде_, ykła_
  { {0xceb300b2,0xb347001c,0x395c0012,0x6b822007}},	//   _מיר_, luçõ, tivs_, rlog
  { {0xa7b8000d,0xe91802a3,0x6b822008,0x91f7004f}},	//   алку_, рокі_, slog, ממנו_
  { {0x6c360074,0x395c00c0,0x6d5e2009,0xe465007c}},	//   _افزا, rivs_, mipa, ööle_
  { {0xcc3b0053,0xa3e6005d,0x6d5e200a,0x501b000a}},	//   _געלט, यंस_, lipa, רוקו
  { {0x2b55002b,0x3f47007c,0xc6d30067,0x63680061}},	//   _بیند_, _jõua_, ستيت, rınl
  { {0xdb2300dc,0x03f80001,0x61e6200b,0x79b7000a}},	//   öröl, аној_, dukl, _ללמד_
  { {0x7d7b000a,0xd91b000a,0x6445007c,0xa3ab000b}},	//   רניו, _תובל, _ühil, _कूद_
  { {0xdc9b00b2,0x8c1b000a,0x6d5e200c,0x97ab000a}},	//   טייל, אוטי, hipa, _עֹבֵ
  { {0x6d5e200d,0x66e30010,0x613000f2,0xe6960029}},	//   kipa, _хоча, _häly, _الشد
  { {0x067b00b2,0xe3af0074,0x6d5e0553,0x99860046}},	//   _ענגל, بری_, jipa, tvoř_
  { {0x20990010,0xc7d8000a,0xd48f0461,0x6d5e200e}},	//   рквы_, יַּכ, _хр_, dipa
  { {0x3ceb005d,0x7eb90063,0x66f8000b,0x7e2b005e}},	//   _चाहे_, ргас_, ंभिक_, ліза_
  { {0x171b00b2,0x61e60064,0x6ca70029,0x443e200f}},	// [3a30] נומע, cukl, مصال, lyt_
  { {0x2dd40010,0x657a2010,0xdd910015,0x5e440015}},	//   яжур, noth, ذوا_, أَكْ
  { {0xfbd00074,0xbc680029,0x65680134,0x443e2011}},	//   فتن_, ممكن_, indh, nyt_
  { {0x6d5e0035,0x648b000a,0x50b8002b,0x7d050012}},	//   aipa, רְמְ, _پدید_, sehs
  { {0x443e00f2,0xf2d40053,0x6d5e0020,0x4095002b}},	//   hyt_, פעס_, bipa, _دلگر
  { {0x7ff40074,0xa7b50054,0x5ba70033,0x27150016}},	//   _بسیا, осиј, _граз, _ền_
  { {0xe7d5005e,0xd7ee0015,0x61e6068c,0x657a1abc}},	//   цілю, نكو_, zukl, doth
  { {0xc1a5000b,0xe73900a5,0x443e2012,0x65681de9}},	//   _गू्ग, реи_, dyt_, endh
  { {0x05a60080,0x63aa00b8,0xdb1c002e,0xae1c005d}},	//   овый_, _aufn, _evró, नियन_
  { {0x05760029,0x95550115,0x61e62013,0x7a88000a}},	//   يمية_, تخبا, vukl, _הָעַ
  { {0xf6d50036,0xe29f002e,0x29072014,0x9cd6000a}},	//   _діля, veða_, mena_, חותה_
  { {0xf770040b,0x98a5005c,0x6d5e2015,0x61e62016}},	//   _كان_, _rolę_, zipa, tukl
  { {0x2b7a0053,0x6d4b0024,0x15390086,0x07080015}},	//   שטרײ, īgaj, _پزشک_, _ديني_
  { {0x5a9a0008,0x3cf5005d,0x8fa60ea6,0x31af0064}},	//   ישרא, ीजों_, жаве, _düz_
  { {0x61e60213,0xa0a3049d,0x2611000b,0x23760015}},	//   sukl, дард, तिकी_, _وابح
  { {0xb347001c,0x77691347,0x9f860033,0xa067005e}},	//   ruçõ, nnex, ігад, іата_
  { {0x9f4b002e,0xecba0015,0x98a5002a,0x539b000a}},	// [3a40] ðmát_, لطات_, _wolę_, _דיקו
  { {0xf1b901b2,0x6d5e003f,0x63a42017,0x29071cbc}},	//   íše_, uipa, _hiin, jena_
  { {0x63a42018,0x6d5e0213,0xf81e005c,0xe0fb000a}},	//   _kiin, ripa, ążkę_, _דליל
  { {0x80ba005d,0x31af0064,0x8a460015,0x6d5e2019}},	//   ्रवे, _yüz_, يَان, sipa
  { {0x63a40209,0xcb070031,0x443e0647,0xad9b0030}},	//   _miin, زيون_, zyt_, _csús
  { {0x69db005d,0x4d780008,0x63a40fb2,0x5cf50033}},	//   _निरी, _הָֽא, _liin, _нясу
  { {0x98be04f9,0x98a30054,0x274a0054,0x6d5c201a}},	//   _altă_, миље, ичио_, _imra
  { {0xcb6a0010,0x442004af,0x63a40604,0x973c0085}},	//   _табе_, _či_, _niin, _kući
  { {0xcf930008,0x29071af9,0xf56a005e,0x55061456}},	//   וטה_, bena_, ишок_, очна
  { {0x443e022d,0xb603002c,0x88bc0046,0x64540054}},	//   tyt_, úšaj, _zněn, звођ
  { {0xd6cf201b,0xad1b00b2,0xdb000003,0x657a201c}},	//   _от_, בויר, _aimé, roth
  { {0x63b50264,0x74ba000b,0x04630033,0xea000016}},	//   ízna, _श्रृ, ьтым, huật_
  { {0xdb9b00a3,0x63a40509,0xe3a4002b,0x443e008c}},	//   יסטר, _diin, _کشتی, syt_
  { {0x6f16002a,0x443e201d,0x63760030,0xa5070588}},	//   edyc, pyt_, iány, _меча_
  { {0x63a404f9,0xb4d6005d,0x94bb0008,0x4035201e}},	//   _fiin, िणी_, _דמות, чевс
  { {0xa3b70086,0x2907201f,0x2349002b,0x1ee7002b}},	//   _باور_, zena_, _دستی_, توری_
  { {0xd379010b,0x4d890015,0xa3e6000b,0x3254006b}},	// [3a50] jući_, مَرُ_, यूर_, _овър
  { {0x6ac3005d,0xd379016f,0x8d74006e,0x63760030}},	//   शर्र, dući_, والا, dány
  { {0x76400026,0x6ec70015,0x8234002b,0xdab90033}},	//   hymy, _وتحق, _فریا, былі_
  { {0xddc40048,0x90e70086,0x9b680033,0x5ba80033}},	//   dziņ, _اسکن, ошча_, ікім_
  { {0xd379016f,0xaa070015,0xceb6000a,0xf8a9002b}},	//   gući_, تظاه, _מפרק_, مگاه_
  { {0x07f90029,0x7e9a000a,0x2e3a000a,0xb8d50015}},	//   مربع_, _לסרו, _הגשנ, ستتش
  { {0x29071159,0x26f8000b,0xa8480015,0x98a21293}},	//   rena_, ्जूर_, يلهم_, нише
  { {0x27e72020,0xdb23002b,0x29072021,0x3ce90045}},	//   runn_, _توری, sena_, şivă_
  { {0xc9870001,0xddc40024,0x63a4138c,0xcb12000a}},	//   _дужи, aziņ, _riin, _אלן_
  { {0x34390029,0x6445007c,0x78270015,0x63a42022}},	//   مسجد_, _ühik, _وعال, _siin
  { {0x6f160026,0xa3e6000b,0x63a405ff,0x7d150030}},	//   ydyc, यूल_, _piin, _mazs
  { {0xd7fa0008,0xd8740115,0x6b56000a,0x69c903f8}},	//   _להעל, _غالب, ֤ישׁ_, _kwee
  { {0x63a42023,0xc243006b,0x56670058,0x170a009a}},	//   _viin, еняк, _بداف, _دفنی_
  { {0x55ba0008,0x361a0008,0x412a0036,0xd13200e6}},	//   _המסו, _לונד, щого_, رمز_
  { {0x3d0f005d,0x67540086,0xf9920008,0x201e2024}},	//   ड़ने_, _رییس_, גרם_, íti_
  { {0x0eaa008f,0xe7e3000b,0x1eaa0015,0xdb000324}},	//   скай_, _गिना_, صاري_, _timé
  { {0xee3a0c55,0xf7c7002a,0x6f162025,0xfce60c91}},	// [3a60] щна_, ężył_, rdyc, зозо
  { {0x98ac00df,0x6561001c,0x2ce80086,0xd379016f}},	//   _kodą_, nilh, تظری_, vući_
  { {0x315700b4,0x913b0008,0x64410026,0x7640005c}},	//   _זיין_, _העיק, nyli, zymy
  { {0xea640086,0x2f56042b,0x3f47007c,0xeb97098a}},	//   وپای, _хтос, _jõul_, пих_
  { {0xda650086,0x8f1b000a,0x39d30015,0xe9d70033}},	//   واهي, _הוכת, فينأ, зміч_
  { {0x637600dc,0xcfa9002b,0xdd92002b,0x69230054}},	//   rány, _دایم_, _سوز_, емља
  { {0x17f70029,0x6561016e,0x660205a1,0x7af1008c}},	//   كرية_, dilh, _spok, ähtö
  { {0xddc40024,0x7bdb000a,0x86f2002b,0x45b8004a}},	//   rziņ, _לקלו, ريخچ, огию_
  { {0x75382026,0xbebb0079,0x656101ce,0xeb971411}},	//   _povz, _poëz, filh, _хит_
  { {0x03d8006b,0xb882001a,0x20050061,0x76400034}},	//   омощ_, áísk, çlik_, rymy
  { {0x7640022d,0x58bb0008,0x04660036,0x78250029}},	//   symy, _המבצ, ятим, _يعمل
  { {0xc7b3000f,0x4acc000b,0x6d4b003d,0xaacc0065}},	//   _טבע_, ारिव, īgai, ारिक
  { {0x35f70086,0x7afd07fd,0x26f8000b,0xf1bf0046}},	//   _فرود_, _öste, ंभीर_, upá_
  { {0x61e00014,0xc5eb000a,0xe5a3005e,0xe8ee005e}},	//   ámla, _הַהֹ, _зичи, влi_
  { {0x34fb013a,0x662f0053,0x7d1500bd,0xb4fb000a}},	//   _ההוד, _באַװײ, _razs, _לפגי
  { {0xf1bf00dc,0x9f050015,0x35d1000b,0x8f341301}},	//   ppá_, بورو, _दौड़, несц
  { {0x01650015,0x394c2027,0x0000006a,0x0000006a}},	// [3a70] _يُعَ, _olds_,   ,
  { {0xed8b0033,0x9f430046,0x9d1403ae,0x7cd90033}},	//   ёсак_, mují_, ндуч, імер_
  { {0x9f430089,0x60fa0008,0x70fa0008,0x69ca005d}},	//   lují_, _והתק, _והתח, सीसी
  { {0x6d452028,0x7fd6000a,0x7e2b008b,0xd5dd0065}},	//   skha, _קורס_, _ліга_, _मिलज
  { {0xe9d80010,0x9f430089,0xdb1e005c,0x64412029}},	//   зкі_, nují_, espó, zyli
  { {0xada4008f,0x3f890026,0x644100f2,0x67390303}},	//   _паўл, llau_, yyli, _sowj
  { {0x9f430089,0x3f890026,0x6561001c,0xdb1e0030}},	//   hují_, olau_, vilh, gspó
  { {0xec340036,0xeab00029,0xf09400a3,0x9f430046}},	//   _янсь, _معك_, ענק_, kují_
  { {0x64410176,0x80bf005d,0x50bf005d,0xd7560086}},	//   wyli, ्राइ, ्राष, بليت_
  { {0x9f430089,0x63b50046,0x25bf0022,0x6441202a}},	//   dují_, ízno, rpul_, tyli
  { {0xbcb6000a,0xb17b0123,0xb8e1000b,0x661b05ff}},	//   ופתו_, trån, ंड_, svuk
  { {0x8c1a0008,0x888c0053,0x3cfd000b,0x935a005e}},	//   קורי, _פראַ, र्ते_, ірну_
  { {0x3f890026,0xd379016f,0xd1c70010,0xc6d40015}},	//   dlau_, juću_, мляе_, _ستنت
  { {0x2242003c,0x3f890034,0xd3790085,0xc692004f}},	//   rykk_, elau_, duću_, _סאג_
  { {0xb4e9000b,0x21a30296,0x30750b27,0xa3cc0065}},	//   यली_, тирм, еутс, शीद_
  { {0x26cf0050,0x60c101e2,0x9f430089,0x3f890034}},	//   _jego_, ılma, bují_, glau_
  { {0x88bc0089,0x9f430089,0x26cf002a,0xd3790085}},	// [3a80] _sněm, cují_, _mego_, guću_
  { {0x3eb9002e,0x3f89013c,0xdb24001a,0x6462001a}},	//   _efst_, alau_, ðsþj, _æviá
  { {0x201c0030,0x3f89202b,0xfb82002b,0x0aea0015}},	//   _évi_, blau_, نگری, قرشي_
  { {0x26cf010b,0x09e60036,0x0b461402,0xea8a004a}},	//   _nego_, додн, ьнен, обел_
  { {0x539b000a,0x6288002a,0xbdfa0067,0xef1f02ad}},	//   קינו, ędow, _برجا_, _thür_
  { {0xc9830457,0x3984002b,0xe894202c,0xf84a005e}},	//   кущи, ریاف, наль, жчий_
  { {0x9f430089,0x6d4e079b,0x98a7002a,0xb906000b}},	//   zují_, _ilba, yjną_, _भय_
  { {0xf0930008,0x27e0060b,0x26cf202d,0x5fe1000b}},	//   כנו_, čin_, _cego_, _फिसल
  { {0xe4e60036,0xa4d4005e,0xc6f70174,0x6a831a2f}},	//   мінн, нопі, фных_, _алта
  { {0x9f430089,0x4a570008,0xee09004c,0x3f80007c}},	//   vují_, _חשמל_, פּפֿ, hoiu_
  { {0x3f890026,0x3d0f000b,0xb47c0033,0xdb00202e}},	//   ylau_, ड़ते_, скнi, _limí
  { {0xf6d60074,0x36060029,0x9f430046,0x798a0034}},	//   _آزاد, _يواف, tují_, llfw
  { {0x5187202f,0x92940010,0xa2db000b,0xf79b000a}},	//   дува, каюц, पृष्, _ובאמ
  { {0x9f430089,0x3015107b,0x3f890416,0x0000006a}},	//   rují_, ндгр, wlau_,
  { {0x61e60064,0x74140029,0xdfd10015,0x9f430046}},	//   arkl, _أوبا, طيء_, sují_
  { {0x2d8300cb,0x9f430046,0x6d4e2030,0x3f8901c2}},	//   _skje_, pují_, _alba, ulau_
  { {0x11d90029,0x20050089,0x88bc0046,0x25a90125}},	// [3a90] _عودة_, ůli_, _vněj, _éalt_
  { {0x30152031,0x91bc000a,0x3f892032,0x84a9004f}},	//   _здор, _ומזי, slau_, ִינִ
  { {0x9949032c,0xd379016f,0xdab90033,0x3f890034}},	//   núť_, suću_, пылі_, plau_
  { {0x309a013a,0xceeb0086,0xa3e62033,0xb09a000a}},	//   _משתמ, _بردن_, _पिन_, _מיתר
  { {0x6eba0008,0x6f0d2034,0xaa0b0015,0x010b000a}},	//   _מזרח, meac, تزال_, ַלֵּ
  { {0x6f0d002d,0x63680061,0xaffb004f,0x0000006a}},	//   leac, lınt, ַּ֔י,
  { {0x0138000a,0x8bb40015,0x718c000a,0x7c841d8c}},	//   ורגת_, _لإقا, קְדַ, _ауте
  { {0x6f0d002f,0xac94005f,0xef120008,0x2d81006f}},	//   neac, _расш, ָּה_, lohe_
  { {0xf6510015,0x3989001a,0xb17b2035,0xa9c709a0}},	//   طئة_, húsi_, trål, _ісак
  { {0xe00f005d,0x6f0d002d,0xd8b80021,0x3989006f}},	//   ाबाद_, heac, _قدما_, kúsi_
  { {0x26cf0050,0x63680064,0x08f80015,0xe36603ae}},	//   _tego_, kınt, _ترقب_, екни
  { {0x59c6000b,0x91e607d1,0x0000006a,0x0000006a}},	//   रीकर, номе,   ,
  { {0x6f0d002f,0x15f3000b,0x61e6003d,0x69d92036}},	//   deac, _आमिर_, urkl, nswe
  { {0x463a0053,0x963a000a,0xb607003d,0x60d52037}},	//   _מענע, _מגנט, rošī, gazm
  { {0x6f0d002d,0xf8b2000a,0xc4f6000a,0xf1dc000b}},	//   feac, רשל_, _נזקי_, _बिकन
  { {0x69d900dd,0xa3c8005d,0xd2520031,0xddcd002a}},	//   kswe, _लौट_, _منع_, dzał
  { {0x20d60010,0x9f582038,0x3f800045,0xdb00059d}},	// [3aa0] _пінс, ntré_, roiu_, _limã
  { {0x3257000a,0x6e930015,0xa3e3000b,0x6da60c91}},	//   _נסים_, الكا, _फटा_, хиза
  { {0xd9100074,0xc173013a,0x1c390010,0xdd8f0115}},	//   ییر_, _תחת_, мяць_, حول_
  { {0x6f0d002d,0xc446004c,0x3ce60045,0x69d902ad}},	//   ceac, ערײַ_, şov_, fswe
  { {0xdcfc0024,0xda650086,0x69d92039,0xe91800ce}},	//   _ekrā, پاني, gswe, долі_
  { {0x1db5000b,0x6b830045,0x47d40015,0x9a67006e}},	//   _अंतत, îngr, نيتر, عمول_
  { {0x2d98018b,0xddcd005c,0x8b660015,0x6abb0034}},	//   _ihre_, czał, _كارم, _ffuf
  { {0xa8470029,0x3ea60024,0x7bfb000a,0xaac50058}},	//   عليم_, žotu_, _מפלצ, _لتكن
  { {0x3cfd000b,0xff17000a,0x7afd203a,0xdb1c0003}},	//   र्वे_, תקפת_, _östa, _ntré
  { {0x6b82203b,0x89db000a,0x7caa000a,0xfcaa000a}},	//   loog, _מחמי, ּבֹ֥, ּיֹּ
  { {0xd4980191,0xed57000a,0x79530015,0xdb1c01f6}},	//   ької_, גביר_, _حَلا, _atré
  { {0xe7b7000a,0x88bc0046,0x291c0030,0x6b82203c}},	//   _נהדר_, _sněh, ldva_, noog
  { {0xd46a002b,0xf204203d,0xdb050123,0x15140033}},	//   تحکم_, ляро, pphö, _адля
  { {0xf5780015,0xb7f4000b,0x6b82203e,0xf617004f}},	//   _تمتع_, _इमाम_, hoog, _נחוש_
  { {0x6f0d017e,0x74670063,0x351b000a,0xa4b7000a}},	//   teac, _пръв_, _מוגנ, _אלוה_
  { {0xa3f70008,0x0000006a,0x0000006a,0x0000006a}},	//   _נמחק_,   ,   ,
  { {0x6f0d017e,0x7bdc01e2,0x636801e2,0xf1a7203f}},	// [3ab0] reac, _avru, rınt, _прон
  { {0x6f0d002d,0x4ea41070,0xad670015,0x8de40015}},	//   seac, урса, راءه, اكله
  { {0x69c000df,0x2fd90029,0xc4d30008,0x70bf000b}},	//   _atme, _توجد_, רגע_, ्रील
  { {0xeab00074,0xddcd005c,0x6e950015,0xf24b000a}},	//   معه_, rzał, _للجا, ּגַּ
  { {0xdb070084,0xddcd005c,0x61fd2040,0x6ce7005e}},	//   _stjó, szał, ntsl, _піве
  { {0xfbd30031,0x61fd0c0d,0xdcfd006f,0x19580033}},	//   _متر_, itsl, _husľ, начы_
  { {0x69c001e2,0xac9404c2,0xe7392041,0x69d92042}},	//   _etme, _барш, дей_, sswe
  { {0x6abb003f,0x25b90227,0xfb19000a,0x69d92043}},	//   _ufuf, íslo_, _קוּמ, pswe
  { {0x57240029,0x48ab006b,0x7bc51234,0x5f190065}},	//   طريق, _етем_, lphu, _पसन्_
  { {0xb9c40029,0x637d00dc,0xaa880015,0x64a52044}},	//   _إقلي, mény, _أنكم_, капа
  { {0xf3e50063,0xa3cc005d,0x9f582045,0x98ac0046}},	//   ъжно, शील_, stré_, _lodě_
  { {0x06990029,0xcad5000a,0xe611002b,0xdb000030}},	//   _قناة_, כוֹת_, _نشت_, _kimá
  { {0x20d60036,0xe2970484,0xaada000a,0xbada000a}},	//   ківс, каю_, וחרר, וקרת
  { {0x6e2002c1,0x0656000a,0x236c0030,0xafe600ce}},	//   _ámbi, _בינך_, ődj_, когл
  { {0x998f0007,0x61fd2046,0x20730033,0xb424009a}},	//   lygų_, atsl, алёў, _معيو
  { {0xc323006b,0x290e2047,0x98ac0046,0x9f5a00cb}},	//   _вмък, zefa_, _bodě_, _oppå_
  { {0x98d1000b,0xf8d1000b,0x539b000a,0x7983002a}},	// [3ac0] हराए, हराय, _קיפו, konw
  { {0x64450005,0x69db005d,0x63ae002d,0xdd8f0115}},	//   _ühis, _निजी, _úiné, قوق_
  { {0x79830034,0xdee6004a,0x6b820546,0x0000006a}},	//   donw, _иони, toog,
  { {0xa3e6000b,0xb4ae000b,0x9a6a0015,0x4ae30138}},	//   यूट_, _कल्_, ومال_, аўша
  { {0x79830176,0x6a130021,0x637d0030,0x6da60015}},	//   fonw, لبور, gény, _لمحم
  { {0xf8060036,0x3ea60024,0xaa570015,0x0000006a}},	//   вчин, žots_, خلها_,
  { {0x9d1b0135,0x7d1c002d,0x97d70015,0x290e2048}},	//   _קולט, _iars, نظير_, refa_
  { {0x9c170008,0x9714023e,0xe7e3000b,0x907b000a}},	//   _בחלק_, умиц, _गिरा_, וטצי
  { {0x68ed00dc,0xddcd002a,0x69c00795,0xcb57000a}},	//   ándé, czań, _utme, _ססמה_
  { {0x7e9b0008,0x092a0015,0x189a0015,0x7bc3001a}},	//   וספו, _تسري_, _قضاة_, ínug
  { {0x29550063,0xe2f90036,0xd6d20087,0x2617000b}},	//   _сътр, нені_, _نقض_, _बैठी_
  { {0x7bdb000f,0xb17b0971,0x61fd0cbf,0x7d1c2049}},	//   וקטו, pråk, ttsl, _lars
  { {0x0737000a,0x5214005e,0x8ca2000b,0xa3e60065}},	//   _שאדם_, адят, केतो, यूज_
  { {0x70bf005d,0xc56a0029,0x25d70053,0x80bf005d}},	//   ्रेल, _تحصل_, _יודן_, ्रें
  { {0xdfd80063,0x6671002b,0x6537000a,0xd0d401b7}},	//   кът_, _نگیر, _באגף_, росъ
  { {0x0ccb005d,0x3eaf0134,0xd437000a,0xd3710015}},	//   िर्म, øgt_, _ירוק_, _دهب_
  { {0xa3ac005d,0x2b8e013f,0x0378000a,0x7d1c204a}},	// [3ad0] _कूट_, mých_, _שתחת_, _bars
  { {0x637d00dc,0x2d87204b,0x50670010,0x2b8e0227}},	//   vény, ône_, _атма, lých_
  { {0x2ca701d1,0x7d1c204c,0xe1ff07db,0x6ca7204d}},	//   änd_, _dars, ltó_, траж
  { {0xfecb0029,0x63b50089,0x6568003f,0x2b8e0107}},	//   _تبدو_, ízni, hidh, ných_
  { {0x64480176,0x0f360053,0x7d1c204e,0xe1ff204f}},	//   hydi, _ערשט_, _fars, ntó_
  { {0x7d1c0007,0x2b8e0264,0x4dfa004c,0x5dfa004c}},	//   _gars, hých_, _אפשא, _אפשנ
  { {0xccf20008,0x2b8e0264,0x6f1d0012,0x7983145d}},	//   _לכם_, kých_, _kasc, ronw
  { {0xe61909fe,0x63ad2050,0xdb000030,0xe7b20015}},	//   еди_, _nian, _timá, حميد
  { {0x645a0024,0xe1ff00dc,0x89fb0015,0x9f5a0123}},	//   ezti, jtó_, _تعزز_, _uppå_
  { {0x6f1d04ed,0x28ac005d,0x63ad007c,0xf84b0248}},	//   _lasc, _चलचि, _aian, _очей_
  { {0x63ad2051,0x80bf000b,0x64480034,0xfd56004f}},	//   _bian, ्रैं, gydi, רשתי_
  { {0xc7b204dc,0x18a40036,0x6f1d2052,0x9f600061}},	//   _הבא_, _таєм, _nasc, ürür_
  { {0xd6d9005c,0x63ad1801,0x65680573,0xb716004f}},	//   mał_, _dian, bidh, _תקנג_
  { {0x673b0198,0xf8c6005d,0x28c6005d,0xd6d9005c}},	//   ljuj, रुपय, रुपि, lał_
  { {0x63ad2053,0x6fb60021,0x65a80054,0x6143024f}},	//   _fian, امرا, _ртцг_, щера
  { {0xd6d9005c,0x9f550001,0x673b01a3,0x6d43008c}},	//   nał_, ањуј, njuj, önan
  { {0x6e930029,0xdd920002,0xe1ff0077,0x23770031}},	// [3ae0] ملفا, مور_, ctó_, _حميد_
  { {0xdcfc005c,0x6acc000b,0xbce50015,0x63ad0799}},	//   _okrą, ार्र, لأمو, _zian
  { {0xcea90008,0xd6d9005c,0x8ae60036,0x7d1c2054}},	//   פי_, kał_, гілл, _vars
  { {0x6b9b002f,0xd6d9005c,0x7d1c2055,0x7afd08e9}},	//   _chug, jał_, _wars, _östl
  { {0xd6d9005c,0x28f804f5,0x673b0085,0xd9461191}},	//   dał_, вель_, djuj, леди
  { {0xc27b00b2,0x6e2b0008,0x35dd000b,0xb60500bc}},	//   ערסי, _אֵלַ, _मिज़, _mašč
  { {0xd6d9005c,0xb8060002,0x8b9600d8,0x2c34000a}},	//   fał_, ابته, _брач, _דָּם_
  { {0xd6d9005c,0xb09b0008,0x7fd7015b,0xb807002b}},	//   gał_, עיקר, אוקס_, اييم_
  { {0x64480026,0x2b8e0264,0x63680030,0xd6260015}},	//   wydi, vých_, tűnn, اعبي
  { {0x3dfb004c,0x63ad2056,0x64482057,0x645a0012}},	//   עליד, _sian, tydi, tzti
  { {0x2b8e0156,0x63ad052a,0x68460015,0xd6d9002a}},	//   tých_, _pian, _حَال, bał_
  { {0x291e1761,0xe4470029,0xd6cf0015,0xd6d9002a}},	//   _hata_, الَى_, _فقم_, cał_
  { {0x645a0014,0xe53408fb,0x77920086,0x2b8e04af}},	//   szti, _вель, _پیکا, rých_
  { {0xe6930029,0x85f70008,0x628d003f,0xe5f7000a}},	//   _الهد, _עמוס_, _vyao, _עזור_
  { {0xe1ff04f3,0xcf9b00d7,0x4fc40484,0x291e0338}},	//   stó_, еја_, йста, _mata_
  { {0xa3b9005d,0x291e005c,0x2f180a2c,0x7bde01ab}},	//   _अंत_, _lata_, лось_, dspu
  { {0x59e0005d,0xde58005e,0x6b9b0034,0x7bde2058}},	// [3af0] _निगर, гаті_, _rhug, espu
  { {0xd6d9005c,0x6b9b003f,0x6fb90658,0x6f1d2059}},	//   zał_, _shug, _игор_, _wasc
  { {0xc174013a,0xb605018c,0x656f0152,0x8c590015}},	//   _לחץ_, _zašč, échi, خلاء_
  { {0xfbd00074,0x4c940080,0xfb84004a,0x6f1d0125}},	//   ستم_, щихс, бычн, _uasc
  { {0xf8a90086,0x291e205a,0xd6d9002a,0x7bde205b}},	//   چگاه_, _bata_, chły_, aspu
  { {0xd6d90050,0xf8a90086,0xda780010,0x31bc004c}},	//   wał_, نگاه_, ыях_, עזונ
  { {0xd0f80008,0xd6d9005c,0x6b9b0eea,0x5d540036}},	//   אמות_, tał_, _thug, _укрт
  { {0x60d7205c,0x06090c7c,0x5ba41b5d,0xb17b01d0}},	//   _lexm, вник_, _груз, nsåb
  { {0xd6d9005c,0x291e1b91,0x0f58004f,0x673b205d}},	//   rał_, _fata_, טיהם_, rjuj
  { {0xa5090124,0xd6d9005c,0x291e205e,0x8546004a}},	//   њена_, sał_, _gata_, изыв_
  { {0x28150074,0xf9900015,0xf8b2000a,0xd6d9002a}},	//   _خواس, _ربك_, _ושב_, pał_
  { {0x883a004f,0xe81b0065,0xa856004f,0x16390058}},	//   _בתעו, _भैया_, _דיעה_, _لستة_
  { {0x6cf7005d,0xf7840029,0xeb3a0053,0x7ae4002d}},	//   ुभाग_, _النَ, דערש, óiti
  { {0x64a51c55,0xdcfe003d,0x19b6000a,0x3c05000b}},	//   _кала, kopā, יפשר_, _रहूँ_
  { {0x3f470020,0xdfa60029,0xb4fa000a,0xc4280015}},	//   _nõus_, لحري, _יפסי, _مثيل_
  { {0x63b50046,0x6d55205f,0xaec62060,0x9888004f}},	//   íznu, _alza, рбал, רָשֵ
  { {0x91a00092,0x0eaa0010,0x4d66070e,0xdc3c00bd}},	// [3b00] _trì_, ткай_, акав, ršča
  { {0x11db000a,0x3fc6002b,0xa1e90015,0x7bde057a}},	//   _שחיב, _نگری_, _إريك_, tspu
  { {0x161c005d,0xdc750033,0x4ac60015,0x1d890015}},	//   _बैनर_, быць, لياق, ائقي_
  { {0x7bde0084,0xdb1c0011,0x291e0f8a,0x32020046}},	//   rspu, _strâ, _sata_, otky_
  { {0x291e000c,0x7bde2061,0xaa16023e,0x2b9c0046}},	//   _pata_, sspu, рфеј, jíce_
  { {0x60dc002e,0x07e60001,0x320d0061,0xf1b904b2}},	//   narm, ацим, çeyi_, íši_
  { {0xa8a30063,0x0137000a,0xb8de000b,0xebe3004a}},	//   орък, ירסת_, _इल_, _морп
  { {0xab740074,0x36d40001,0xdb07002e,0x57180080}},	//   _انرژ, љопр, _stjö, ужия_
  { {0x291e03a2,0x60dc2062,0x8b8b004f,0x0000006a}},	//   _tata_, karm, _יָמֶ,
  { {0xe5720029,0xe4a60e77,0x95380004,0x354619cc}},	//   تطع_, ирно, узот_, рхив
  { {0x33200251,0x3cfe005d,0xd49a0063,0x7e03000b}},	//   _baix_, _लाने_, ъри_, _रङ्ग_
  { {0x3d06005d,0x60dc002d,0xf3671411,0x60ce02dc}},	//   स्ते_, earm, ртон, ebbm
  { {0x60c20045,0x16370015,0x35b602ed,0x60dc2063}},	//   _şoma, _نسوة_, _тщес, farm
  { {0xa187008f,0x224b00c0,0x51870418,0x32d50016}},	//   рымл, ryck_, рума, ấy_
  { {0x657d00dc,0xe3b0002b,0x656f0003,0x320204b2}},	//   éshe, ثری_, èche, atky_
  { {0x644700f2,0xa8570008,0x60dc0111,0x9f43006f}},	//   äjie, בילה_, aarm, lujú_
  { {0x539c000a,0x23690061,0x60dc0c0c,0xedd50015}},	// [3b10] _ביהו, _imaj_, barm, صياد
  { {0x91a00023,0x61440001,0x7afb1213,0x9f43006f}},	//   _trí_, _мења, _scut, nujú_
  { {0x5ba70010,0x9f4b002e,0x98bc0046,0x7afd0123}},	//   ардз, ðmót_, skvě_, _östk
  { {0x9f43002c,0x9a9d0033,0x1a65009a,0x0000006a}},	//   hujú_, нулi, میزی_,
  { {0xbf360b7b,0xda090029,0x9f43002c,0xe9f8005e}},	//   _הארץ_, ايته_, kujú_, инці_
  { {0xdcfc005c,0xe9870001,0xe8f80036,0x2bd9002b}},	//   _okrę, шћен, илі_, _مارک_
  { {0x9f43002c,0x31580008,0x67d20004,0x2bcb01ca}},	//   dujú_, שיון_, поју, _југо_
  { {0x27e92064,0x32020247,0x60dc2065,0x0078004f}},	//   čan_, ytky_, zarm, יתוי_
  { {0xd4d906b4,0x04b50033,0x09f40015,0x9f581ecf}},	//   льні_, йсня, _وأكد, ntrá_
  { {0x4519085d,0x9f43006f,0x45352066,0x6d90008c}},	//   уция_, gujú_, схит, täai
  { {0xb895003b,0x33200152,0x2b9c0107,0x78fa000a}},	//   _الاع, _paix_, síce_, _תפעו
  { {0x75d2002b,0x833a0004,0x69cb0079,0xdb0e2067}},	//   _کيوا, учот_, opge, _kubá
  { {0xdb1c005c,0x9f43002c,0x1b7a004c,0x6d90008c}},	//   _zwró, bujú_, רטרע, säai
  { {0x23b20086,0x9f43002c,0x21330016,0xa06a0138}},	//   _کميس, cujú_, _cnxh_, гага_
  { {0x03a60180,0x32020057,0x63c60046,0xf5760015}},	//   _лико, stky_, ěrné, _دموع_
  { {0xd0070001,0x249818b8,0x3f890034,0xdb0200aa}},	//   љете_, ürme_, goau_, rmoë
  { {0xa2f70008,0x7bc70091,0x60dc2068,0xf1bf19fe}},	// [3b20] _המפה_, _atju, parm, lván_
  { {0xc69200a3,0x74ad000b,0x23690085,0x9f580144}},	//   לאן_, ुखपृ, _zmaj_, strà_
  { {0xbc6a0087,0x61e40293,0xdb1c047e,0xab2a12ae}},	//   دمان_, _hvil, _atrá, ложа_
  { {0x9f43032c,0xa3cc005d,0x7bc30adb,0xda7a0457}},	//   zujú_, शीट_, ínua, лял_
  { {0x290701f9,0x0000006a,0x0000006a,0x0000006a}},	//   ffna_,   ,   ,
  { {0x9f43006f,0x9d56006e,0x6f162069,0x58d3206a}},	//   xujú_, _انست, leyc, пошт
  { {0x9f43002c,0xb17b01de,0x3d140065,0x88bc005a}},	//   vujú_, orår, ड़ीं_, _dněp
  { {0xb8ef005d,0xcc770008,0xceb2000a,0x2907001a}},	//   _व्_, _העלה_, ּי֙_, afna_
  { {0xdcfc005c,0x163a0015,0x61e413f0,0x9f43006f}},	//   _skrę, اسعة_, _nvil, tujú_
  { {0xb996003b,0x91a90023,0xa3b9000b,0x28cf000b}},	//   _الطب, _trả_, _अंश_, _स्पि
  { {0x9f43002c,0xdb1c0089,0x3cfd000b,0x290c01d7}},	//   rujú_, _ztrá, र्टे_, _ibda_
  { {0x04630afa,0x9f43006f,0xf7431d8c,0x9f58005a}},	//   ятым, sujú_, _нехо, ytrá_
  { {0x753c0030,0x9f43006f,0x25d9002b,0xc6960067}},	//   örzs, pujú_, _نهنگ_, _اشاع
  { {0xd2580010,0x60230089,0xf6170008,0x63a60bba}},	//   сцю_, jímá, _לחדש_, amkn
  { {0xf4840086,0x85030015,0x61e4206b,0xf1be0065}},	//   _باشی, _روين, _evil, _एंथन
  { {0x3d06005d,0xe7f0021e,0xa492002b,0xa857000a}},	//   स्से_, _घटना_, _ویکت, זילה_
  { {0x93bc0011,0x9e3402ed,0x7cd900af,0x1df902ed}},	// [3b30] zvăl, петч, имар_, резы_
  { {0x5637004c,0x6ce40033,0xf1b9006f,0x6ca70a0b}},	//   זאמע_, зіце, íšu_, бреж
  { {0xdb1c206c,0xd2510086,0xfbd00015,0xf36b000a}},	//   _strá, _رنگ_, ّته_, ְדְּ
  { {0x6bd40029,0x3945206d,0x33fb004c,0xbad40033}},	//   ستمر, _sols_, רהאנ, пішы
  { {0xf1bf206e,0x3945206f,0x531c000a,0xd9450b59}},	//   zván_, _pols_, טואצ, жели
  { {0x61dc000a,0x8e36000a,0x0000006a,0x0000006a}},	//   נקוד, _ונשא_,   ,
  { {0xddd6005c,0xf9900087,0x39452070,0x3cfe000b}},	//   czył, ربه_, _vols_, _लाते_
  { {0x6d4702c1,0x58940029,0x0058000a,0x9b581489}},	//   _hoja, أجهز, משות_, _лист_
  { {0x8579000d,0x5967006b,0xe4d50015,0xdb1c0046}},	//   исот_, _лъжа, يتدب, _utrá
  { {0xf1bf00dc,0x6b8b2071,0x3cfd000b,0x853c0091}},	//   tván_, logg, र्चे_, smėn
  { {0x61e41303,0x6d472072,0xccf2000a,0x69c9008c}},	//   _svil, _moja, וכי_, _htee
  { {0x96550063,0xdc88000a,0x27e10046,0xd2aa1c35}},	//   _мълч, מְרָ, áhnu_, икне_
  { {0x84e52073,0x05740086,0xd6270015,0xd29a005e}},	//   _долж, _کاند, _دعاي, ртні_
  { {0x412a2031,0x85a70001,0x28cf021e,0xc5e8000a}},	//   шого_, _ујед, _स्मि, _הַקֹ
  { {0x63e40015,0x7ae92074,0x7d172075,0x5437009a}},	//   _فسيك, _odet, dexs, _درشر
  { {0xef1a0099,0x61e40c17,0x75232076,0x92b60058}},	//   јма_, _tvil, _hanz, _بحثا
  { {0x92e90225,0x5fb6000b,0x7bc3001a,0xee3a0719}},	// [3b40] _طريق_, _आंकल, ínun, шна_
  { {0x3d14005d,0x7ae90061,0xb17b0123,0xfd96005e}},	//   ड़ें_, _adet, lsån, ішаю
  { {0xe456004c,0xac3a0033,0x69c90601,0x10a60a32}},	//   ֿינט_, шчах_, _atee, _финн
  { {0xeb97005f,0xddd6005c,0x75230fe6,0x9c830264}},	//   оих_, rzył, _lanz, účas
  { {0xddd6005c,0x7ae90026,0x6a1600e5,0x49a60b1e}},	//   szył, _ddet, تبار, ојка
  { {0xed5a0001,0xd9100086,0xe7ea2077,0xd9430054}},	//   _тог_, عیض_, афик_, дељи
  { {0xd7f0003b,0x69c900f2,0xfc0308d7,0xd83a0033}},	//   ركة_, _etee, _опро, рэл_
  { {0x75230111,0xfb560086,0xda65002b,0xdb1c1a93}},	//   _aanz, _بپرد, _کافي, _stræ
  { {0x77910086,0x8e7a0643,0x3a2d2078,0x0000006a}},	//   ریها, ינֵה, _grep_,
  { {0xce370008,0x752304ed,0x03f80054,0x18360015}},	//   קאית_, _canz, бној_, _وراح
  { {0x836b0029,0x4cbb0008,0x6d43008c,0x43952079}},	//   لصحف_, יזיו, önai, занс
  { {0xd3a70010,0x8c1b000a,0xf62a005e,0xaab10065}},	//   ўроп, בוטי, _віки_, ुँचक
  { {0xc617005e,0x667600c3,0xa2bc0065,0xa77b004f}},	//   _моїх_, _بدار, _एलर्, _דראפ
  { {0x7523018b,0x3d14005d,0x1a9b004c,0x6b75002a}},	//   _ganz, ड़ों_, ייכע, rągi
  { {0x20990139,0xab620061,0x63680030,0x4f6b0e7c}},	//   сквы_, şüyo, zűni, ашам_
  { {0x98a50024,0x7523207a,0x9992006f,0x8f340033}},	//   _solī_, _zanz, ždňa_, месц
  { {0x3eaf00b8,0x201e002e,0x11d70029,0xdcbb0142}},	// [3b50] ägt_, ætir_, _بتعد, аще_
  { {0xdd9100a2,0xd578000a,0x80f50139,0xcd280054}},	//   روا_, צָּר, _эпох, ожђе_
  { {0x6b150001,0x6d4712d7,0x69c915fc,0x20050144}},	//   змеђ, _voja, _stee, àlid_
  { {0x501a0008,0x648b000a,0x3a2d00da,0xead4005e}},	//   _פורו, בְדְ, _prep_, доць
  { {0x7f3a0008,0x4f3a000a,0xeab00021,0x539c000a}},	//   _הערו, _התרע, نعه_, ביאו
  { {0xf7710086,0xe9a80115,0x6d5e207b,0x6d47008c}},	//   کات_, يدون_, chpa, _uoja
  { {0x6b8b04ed,0xc174000a,0x63680061,0x7523207c}},	//   pogg, וחס_, rınz, _ranz
  { {0x907c0008,0x307c000a,0x75231c75,0xfb180015}},	//   יטוי, יאונ, _sanz, _وقّع_
  { {0x28cf005d,0x29d50086,0xddd6005c,0x69c40045}},	//   _स्थि, _رياس, czyń, ţier
  { {0xf770002b,0x2eb8000b,0xb4650214,0xfe36004f}},	//   _یان_, _अल्त, зкол, פרתי_
  { {0xb97a0053,0xccf20053,0xc95205bd,0xa5640067}},	//   _פרעז, עכט_, _רמב_, بدين
  { {0x889a0008,0x28cf000b,0x6b75002a,0x637600bc}},	//   _הבעי, _स्ति, rągw, kšne
  { {0x66ba0008,0x7523207d,0x76ba000a,0x479a000a}},	//   _המנה, _tanz, _המנפ, _פינס
  { {0x442e0003,0xb17b0123,0x45d200af,0x0000006a}},	//   _frf_, ssån, _џојс,
  { {0x6f0f06d5,0x8fa6078d,0x7bc3001a,0xe53a004f}},	//   _bbcc, заве, ínul, _לתסר
  { {0x03a3006b,0xcf250015,0x237a004f,0xa3ad0065}},	//   _пищо, ورقي, _לָ֥מ, कगण_
  { {0x63a40035,0x2ee0002d,0x42fb000a,0x2d840030}},	// [3b60] _ihin, raif_, _ההפס, _ímek_
  { {0x28ac005d,0x26dd005c,0xb17b0123,0x0000006a}},	//   टेडि, _lewo_, nsål,
  { {0xa3de021e,0x00bb000a,0x60bb000a,0x63a4052d}},	//   दीप_, _למימ, _לציד, _khin
  { {0xeb9a005f,0x0b460010,0x99ea0015,0xcb6a0054}},	//   щие_, янен, معتق_, љаде_
  { {0x98be0011,0xcb070002,0x61e6207e,0xb9c60015}},	//   _notă_, سيون_, nskl, ستشه
  { {0x7e9b0008,0xdb1c0c77,0xf8b0002b,0xddd6002a}},	//   _לסכו, _strä, نکا_, rzyń
  { {0x6d9000f2,0x2b770086,0x711b000a,0xddd6002a}},	//   säas, _کینگ_, מוספ, szyń
  { {0x5c7b0008,0x9634204d,0x6c7b000a,0xab7a00c3}},	//   _האלה, дниц, _האלפ, _امرا_
  { {0xbb3b0008,0x7e6400b8,0xa3de000b,0x98be0045}},	//   _פעמי, nzip, दीन_, _cotă_
  { {0x4a5b0008,0xe60f0021,0x63a402f2,0x29180125}},	//   _הדמו, اشي_, _ahin, _úra_
  { {0xb4bc005d,0x986a0015,0xd92b000a,0xe3d2004c}},	//   _अली_, _احذف_, _לֵאָ, _פֿילאַ
  { {0x7ae2003f,0x63a41e72,0x883b000a,0x4c9b000a}},	//   naot, _chin, _לתבו, מביו
  { {0xeb910008,0x46a3207f,0xb7e0000b,0x61e62080}},	//   דָם_, _зацв, _गौतम_, gskl
  { {0x867b000a,0x5637004c,0x7ae201b3,0x6d4a1696}},	//   _פרגו, _מאדע_, haot, öfal
  { {0xd5a50086,0x7ae2007c,0x63a40125,0x853c0091}},	//   _تلوی, kaot, _fhin, ymėj
  { {0xd4970135,0x63a401b5,0x547b000a,0xd47b000a}},	//   _מכות_, _ghin, _לטוו, _לאול
  { {0xfe730040,0xf1b70065,0x0000006a,0x0000006a}},	// [3b70] ردر_, _इंटन,   ,
  { {0x6ca700a4,0x637600bc,0x0000006a,0x0000006a}},	//   преж, ršne,   ,
  { {0x8c190070,0xf2d5000a,0x9c190015,0x8e2600af}},	//   تيار_, ֵעַ_, تياء_, кoг_
  { {0x98b20046,0x6d5c0030,0x3a750c9a,0xa3de000b}},	//   žděn_, _elra, млер, दीय_
  { {0x539c0008,0xd2b8000a,0x692501cf,0x0000006a}},	//   זיאו, פלגת_, дмла,
  { {0x6f0d2081,0xceb2015b,0x5c070033,0x34db0065}},	//   lfac, _שיך_, _няба, _मजेद
  { {0x29c209f0,0xb8e5005d,0xd942006b,0xdb1c16a9}},	//   _eða_, _एल_, тещи, _strå
  { {0x6f0d018b,0x80380008,0x1bb80015,0x905c000a}},	//   nfac, לנוע_, _رافع_, מכות
  { {0x276a002b,0x629a002a,0x6f0d0012,0xc5190033}},	//   تشوی_, ętok, ifac, оўні_
  { {0xe5760010,0x63a42082,0x6d450123,0x6e2d17cd}},	//   дзь_, _shin, njha, ivab
  { {0xe8550015,0xa3b90015,0x68e32083,0x98e40058}},	//   _تناد, غادر_, mand, _سكنو
  { {0x6b56000a,0x68e32084,0xe29a2085,0x29c2001a}},	//   ֥ישׁ_, land, жам_, _yða_
  { {0x1634008f,0xa3b9005d,0x27e0016f,0x68e3003f}},	//   _пеця, _अंक_, ćine_, oand
  { {0xf6520008,0x32dc0092,0x55ba000a,0xa3e6000b}},	//   _בצד_, ậy_, _ומסו, _पिच_
  { {0x63a4003e,0x66092086,0x6729002a,0xdfd20015}},	//   _thin, ltek, odej, ئير_
  { {0x63a4003f,0x853c0007,0x67292087,0x8fa60054}},	//   _uhin, ymėk, ndej, фабе
  { {0xa19e0010,0x11d70029,0xdd9200e5,0xe3a7002b}},	// [3b80] _вынi, _قوية_, نور_, _تشوی
  { {0x67290089,0x68e32088,0x66092089,0x0000006a}},	//   hdej, jand, itek,
  { {0x7ae20020,0x7e6400b8,0xdd8f0015,0x67290046}},	//   taot, szip, جول_, kdej
  { {0x25ee005d,0x1efa0015,0x7ed60015,0x672900bc}},	//   _इटली_, _بعدة_, _تزدا, jdej
  { {0xfa360002,0xf98a002b,0x68e3208a,0x6609208b}},	//   براد, يخته_, fand, jtek
  { {0x764600f2,0xada60033,0x68e3208c,0x6da606a6}},	//   äkym, _цагл, gand, _цига
  { {0xd7940063,0x2bf50010,0x644700f2,0xa3b9000b}},	//   никъ, _пятр, äjil, _अंग_
  { {0x2f5b0053,0xd6d00029,0xf7720031,0x68e3208d}},	//   ַדינ, دقة_, ضاع_, aand
  { {0x66090014,0xf8cf005d,0x8a030063,0x28cf005d}},	//   gtek, _स्वय, _изте, _स्वि
  { {0x67290089,0x636800dc,0x7afd0c77,0x68e3208e}},	//   adej, zűnt, _östr, cand
  { {0x04580029,0x4498005e,0xd498005e,0x58bb000a}},	//   سلحة_, явою_, якої_, _ומבצ
  { {0x291c208f,0x69c00b63,0x97a5005e,0x66090546}},	//   leva_, _kume, _зріл, btek
  { {0x394c0048,0x69c02090,0xeb91004f,0xf204009b}},	//   _kods_, _jume, רָי_, кяро
  { {0xdb1c0152,0xda4b0008,0xf1ab0015,0x85040015}},	//   _duré, חֲלָ, تاجه_, _أوغن
  { {0x34fb0008,0x69c02091,0xb4da000b,0xb0a9000b}},	//   _והוד, _lume, ़री_, छेंग
  { {0x68e32092,0x291c2093,0x6e2d0072,0xdb1c03a0}},	//   zand, heva_, tvab, _etrú
  { {0x7bce2094,0x6e2d0003,0x69c006ae,0x291c008c}},	// [3b90] _atbu, uvab, _nume, keva_
  { {0x291c1007,0x61fd0209,0xdd9b017f,0x201a001a}},	//   jeva_, musl, іша_, éfið_
  { {0x68e32095,0x4384002b,0x6e2d007c,0x69c02096}},	//   vand, _سلیق, svab, _aume
  { {0x68e32097,0x395e0144,0x6d90008c,0xc49b000a}},	//   wand, _alts_, säap, חשבת
  { {0xe9d80010,0x68e32098,0x539c000a,0x7ae00034}},	//   дкі_, tand, קידו, _demt
  { {0x291c2099,0x4dda000a,0x7afe0091,0x68e3209a}},	//   geva_, _מחשו, ėpta, uand
  { {0xa7b5209b,0xbb1b0086,0x999100dc,0x68e3209c}},	//   нсиј, _وزرا_, éből_, rand
  { {0xaffa00b2,0x7ae00134,0xb0b8000a,0xfbd2000a}},	//   פּצי, _gemt, ופוס_, _תתן_
  { {0xe6160256,0x69c0209d,0x68e3209e,0x6729209f}},	//   еды_, _gume, pand, rdej
  { {0x61fd0005,0x7bc80152,0x291c04ed,0x394c20a0}},	//   dusl, _éduc, ceva_, _gods_
  { {0x69c000b8,0x9f580003,0xdc3c0085,0x660920a1}},	//   _zume, suré_, ršća, stek
  { {0x35da005d,0x68e120a2,0xdb0e016e,0xd6d9002a}},	//   _मौक़, _held, _subú, ykły_
  { {0x61fd0005,0x7e7b20a3,0x68e120a4,0x0000006a}},	//   gusl, _župn, _keld,
  { {0xc5680015,0x68e100cb,0x45450058,0x2b5f03a0}},	//   _يحول_, _jeld, _سنبق, _lluc_
  { {0x03960f13,0xd4790053,0x68e120a5,0xc952004f}},	//   _прия, _מאַל, _meld, נמל_
  { {0x20050251,0xdcd8000b,0x61fd20a6,0x0000006a}},	//   àlia_, यर्फ़, busl,
  { {0xdee10010,0xe506005d,0xc7b200f3,0x02460015}},	// [3ba0] русi_, _शामि_, רבן_, _أَخَ
  { {0x8d760029,0x7ae00061,0x2cbc00cb,0x69c020a7}},	//   راءا, _semt, øvd_, _rume
  { {0x291c04ed,0x60db000a,0xadb70015,0x50db0447}},	//   veva_, _מקינ, رهما_, _מחיצ
  { {0x69c00034,0x09e61cc9,0x725a004f,0xca8602ed}},	//   _pume, еодн, ּכַפ, нгей
  { {0x68e10064,0x291c20a8,0x82d7004c,0x629a002a}},	//   _beld, teva_, גונג_, ętow
  { {0x291c20a9,0x3d06000b,0x68e120aa,0xfcd600c3}},	//   ueva_, स्खे_, _celd, _سيرج
  { {0x7bce0123,0xc8c700c3,0xdca3012b,0x291c20ab}},	//   _utbu, روين_, _бари, reva_
  { {0x69c00c60,0x68e10020,0x3f80002d,0x501b000a}},	//   _tume, _eeld, nniu_, פופו
  { {0x68e120ac,0xb9c60015,0x96270015,0x291c20ad}},	//   _feld, _ستذه, فكيك_, peva_
  { {0x61fd0020,0xba170002,0x7d1e0030,0xd90e002b}},	//   vusl, _سيما_, neps, _طیب_
  { {0x249802de,0x23600079,0x59750033,0x72d520ae}},	//   ærm_, _blij_, _рыту, конф
  { {0x61fd0458,0x68e120af,0xd3f80054,0x3f5c001a}},	//   tusl, _zeld, тeст, _síun_
  { {0x3f80005c,0xe1ff0077,0x28ac0065,0x0000006a}},	//   dniu_, azón_, टेरि,
  { {0x3f8020b0,0x463b004c,0xf1240b9b,0x6d4e20b1}},	//   eniu_, _מעדע, льсо, _noba
  { {0xdfd10029,0x1fa70010,0x7d1e03f3,0x61fd080d}},	//   شيء_, ераг, deps, susl
  { {0xc49b0008,0xcf980001,0x2d870844,0x1847000a}},	//   _משות, еју_, čnem_, תְךָ_
  { {0x2b9c0089,0x81c3003d,0x6d4e019e,0x0000006a}},	// [3bb0] mích_, ķēsi, _boba,
  { {0x2b9c0089,0xc27c000a,0xf27c004c,0x3f80002a}},	//   lích_, _מרחי, _מרחש, aniu_
  { {0x6144000d,0x61ed0198,0x6d4e044c,0xfcab002b}},	//   _сеќа, _hval, _doba, سائو_
  { {0x2b9c02d5,0x6008000a,0xaa550004,0x68e120b2}},	//   ních_, _אִשְ, квеш, _seld
  { {0xaa58061d,0x2bb80015,0xe1ff0077,0x314b000a}},	//   ницу_, رامة_, nuó_, ּתֶּ
  { {0x2b9c0092,0x6d4e20b3,0xaffb000a,0x9732009a}},	//   hích_, _goba, ִּ֔י, یکنا
  { {0x01380008,0x68e1158b,0xf813002b,0xe7310015}},	//   תרות_, _veld, استگ, لصة_
  { {0x6d4e0050,0x2b9c01b2,0x68e10ec9,0x403c000a}},	//   _zoba, jích_, _weld, לגוג
  { {0x27e0016f,0xf6510015,0x59f801b7,0x2b9c0046}},	//   ćina_, شئة_, _петя_, dích_
  { {0xdb1c0293,0x3f80002a,0x290520b4,0xe1ff0077}},	//   _strø, zniu_, _ucla_, duó_
  { {0x61ed0100,0x8458024f,0xf7f40058,0x3f800535}},	//   _aval, ерят_, _مسند, yniu_
  { {0x87d40029,0x7d1e0046,0x36d51e2e,0xe1ff04e6}},	//   _إغلا, zeps, _родр, rzón_
  { {0x2d87002c,0xcad6000a,0xa5450015,0xc2ba0015}},	//   čnej_, כורת_, _لضغو, بادئ_
  { {0xf67a0053,0x74290015,0xf8ce0016,0x61ed20b5}},	//   _קאסמ, _يكشف_, hứng_, _dval
  { {0x28c6005d,0xdff5007a,0x61ed20b6,0xf992000a}},	//   रुटि, лять, _eval, ירך_
  { {0x93fa0008,0x2b9c0f1b,0x3d14005d,0x4427003e}},	//   _חלקי, cích_, न्ने_, _isn_
  { {0x672b0d85,0x6d4e20b7,0xaec320b8,0xcde600ce}},	// [3bc0] _magj, _poba, рбул, тозй
  { {0x3f800007,0x321e002a,0x4d6320b9,0x645c0c4e}},	//   sniu_, łtys_, акув, ørig
  { {0x6faa0124,0xfbc3008f,0xb513005d,0x6366002d}},	//   _овог_, абхо, त्यय_, _cóng
  { {0xe29f002e,0x5ea60015,0x4427180b,0x7d1e088a}},	//   afðu_, _لمجل, _msn_, seps
  { {0x2b9c0057,0x6f040123,0x298a0de9,0x6d4e20ba}},	//   níci_, mgic, мско_, _toba
  { {0x38c80086,0x2b9c0089,0x44270107,0x6d580123}},	//   راتی_, zích_, _osn_, övad
  { {0x317b0008,0xebe320bb,0xb8070002,0xa17b000a}},	//   ורסמ, _восп, نيوم_, וטסט
  { {0x59dd005d,0x80aa000b,0x0000006a,0x0000006a}},	//   _नौकर, _टरने,   ,
  { {0x8f9b013a,0x69260083,0xb5a60080,0x85b820bc}},	//   ויקי, _имаа, крой, нлис_
  { {0x201a20bd,0x6b820085,0x73d81114,0x61ed005a}},	//   _oppi_, lnog, ндор_, _rval
  { {0x2cfb0008,0x2b9c0107,0x3cfb000a,0xf48a004a}},	//   וליא, tích_, ולינ, ьщик_
  { {0x18770008,0x787901ac,0xc2c50015,0xe1ff0077}},	//   _בעבר_, _אָנו, طيسي, tuó_
  { {0xddd6005c,0x2b9c20be,0x201a20bf,0x28cf000b}},	//   rzyś, rích_, _appi_, सुवि
  { {0x6b820e18,0x0657000a,0x2b9c0046,0x672020c0}},	//   hnog, _בידך_, sích_, lemj
  { {0xa184008f,0x1c0e000b,0x4f5b002b,0x6366001a}},	//   рыял, _सहगल_, وجرد_, _bónd
  { {0x3c2c0030,0x63660077,0x2f18005e,0x0000006a}},	//   zóvá_, _cónd, кось_,
  { {0xdbca0020,0x636602c1,0x6b8212da,0xa3de0231}},	// [3bd0] _mõõt, _dónd, dnog, दीर_
  { {0x636602c1,0x7c3a055c,0xf1ab009a,0xdb1c016d}},	//   _póng, _štra, _تابه_, _durí
  { {0x6b820176,0x6be40029,0x70550015,0x8af9096d}},	//   fnog, لكلم, _إنجا, енес_
  { {0x4ea7008f,0x4c940080,0x7b94005e,0x547b000a}},	//   _арга, шихс, арії, וטבו
  { {0x4efa20c1,0x3c2c0030,0xaa080015,0xfbd3002b}},	//   _אהרו, tóvá_, نزول_, _چتر_
  { {0xdb1c0011,0x6b8220c2,0x090400ce,0x2ee90546}},	//   _curâ, anog, ипін, laaf_
  { {0xf1b4000a,0xd2e3000b,0x9815002b,0x17b90004}},	//   בסס_, _ख़ूब_, ابتا, нѓиќ_
  { {0xab9506f7,0x07090021,0xc7250a32,0x7c3a171f}},	//   _сибі, ريخي_, удий, _átra
  { {0x853c0007,0x79c80029,0x29160125,0xda16002b}},	//   ymėt, _لوقف_, ídaí_, _مسلک
  { {0x2ee9042f,0x2259002a,0x0000006a,0x0000006a}},	//   haaf_, dysk_,   ,
  { {0x672b00dc,0xa3e90010,0xb907021e,0xf8b1009a}},	//   _tagj, эдна_, पर_, _اکش_
  { {0xe6110086,0x9f580125,0xb7da000a,0x660020c3}},	//   _هشت_, turí_, _נקני, bumk
  { {0xd5ae002b,0x3634002b,0x07a4005e,0xff24002b}},	//   تفی_, _پرنس, _таїн, یبری
  { {0x867a000a,0x6e20016e,0x09b5004c,0xf9870067}},	//   _ארנו, _âmbi, רפֿט_, صب_
  { {0x764600f2,0xb4df005d,0x2b9c0089,0xb4fa000a}},	//   äkyv, तरी_, síci_, _טפסי
  { {0x80d4005d,0x44250034,0xdb1c039f,0x6e3b0160}},	//   _ब्रे, mwl_, _purí, _šuba
  { {0x224601e2,0xe1f20086,0x3daa0054,0x6b820085}},	// [3be0] _çok_, _اسب_, екао_, vnog
  { {0xf1bf0030,0x6e2401c2,0x8c4618dc,0x6720003d}},	//   rvát_, rwib, лезе, zemj
  { {0x44250026,0x201a002e,0x5bc50015,0x6f040123}},	//   nwl_, _uppi_, لتنف, pgic
  { {0xe513005d,0x67d1003d,0xdb1c20c4,0xeb9a0015}},	//   त्ति_, _mājd, _turí, رضات_
  { {0x3202002c,0xd37b0053,0x6a13012c,0x0e56006b}},	//   nuky_, ערנט, مبور, _съня
  { {0x75210014,0x082a004a,0xc213000a,0x6b821207}},	//   jelz, еции_, צהו_, snog
  { {0x8d631dfa,0x8cda000b,0xcfb6000a,0x2259002a}},	//   _увре, _प्यो, ְלִי_, zysk_
  { {0x17540063,0x998d0011,0x44250026,0x35f420c5}},	//   рвия, _preţ_, dwl_, апир
  { {0xe4e60036,0xfaa30010,0x28cf000b,0x6d5e20c6}},	//   лінн, _гато, _स्कि, okpa
  { {0x7c22005c,0x80d4021e,0xd6170015,0x44250034}},	//   łoru, _ब्ले, اتيا_, fwl_
  { {0x0d97013a,0x9f5802c1,0xcd97039e,0x7d7b000a}},	//   רכים_, ntró_, רדית_, תניו
  { {0x78a8016f,0x5c3701ac,0x62350088,0x439520c7}},	//   _izdv, ארטן_, аему, рамс
  { {0xa77b0053,0xd7930029,0x442520c8,0x637606c0}},	//   _אראפ, _النخ, awl_, ošnj
  { {0x44250026,0xe29f001a,0x31350bbb,0xb357002b}},	//   bwl_, ggða_, шегр, ئیکا_
  { {0xe3b00074,0x6568002d,0x2ee90177,0xf3ef0015}},	//   تری_, mhdh, taaf_, _فأي_
  { {0x889b000a,0xaf370067,0x643b000a,0x82390923}},	//   גבלי, درست, _טעונ, _азис_
  { {0xccfb0124,0x79830026,0xdd75009c,0x9b45002b}},	// [3bf0] еће_, ynnw, агањ, ینطو
  { {0x6376018c,0x657a002f,0x31c40063,0x867b000a}},	//   jšnj, nith, _усъв, גרמו
  { {0x2ca70caf,0x67d1003d,0x91ba000a,0x6ca712ae}},	//   ånd_, _kāje, _שמתי, ураж
  { {0xa2e3005d,0x799a0035,0x6e95005e,0x8b670015}},	//   _ख़ोज_, _aktw, _виму, دائم
  { {0x20030046,0x61ef01b3,0xf9910040,0x63ad20c9}},	//   luji_, nscl, يبت_, _mhan
  { {0x4e7a0053,0x645a0007,0x8dfa000a,0x6d5e20ca}},	//   _יארצ, kyti, _בהשת, ckpa
  { {0x31580008,0x657a2034,0x9c29000a,0x8d48000a}},	//   ריון_, dith, _בֵּ֥, _עֲשֵ
  { {0x63ad20cb,0x657a0112,0x645a00cd,0x96b920cc}},	//   _nhan, eith, dyti, купу_
  { {0xa3e7005d,0x7bc700d9,0x9f4c0152,0x7e6d003f}},	//   मीन_, _huju, édé_, nzap
  { {0x7bc720cd,0xb4df005d,0x200320ce,0x055500a4}},	//   _kuju, तरे_, kuji_, ртия
  { {0x934602bf,0xb5a80015,0xb8870033,0xd8380085}},	//   анне, دايك_, _суай, _grč_
  { {0x63ad20cf,0xddc40045,0xdb1c0046,0x98a5003d}},	//   _chan, nziţ, _kurá, _galā_
  { {0xc7b2000a,0x15450912,0x657a01f9,0xdb1c039f}},	//   _ובא_, _велм, bith, _jurá
  { {0x63ad0026,0x44250034,0x65680125,0xe08600c3}},	//   _ehan, pwl_, chdh, لجزي
  { {0xd4660036,0xafe601e5,0xb4fa000a,0x61fd00cb}},	//   _вище_, робл, _ספקי, arsl
  { {0x6b89060b,0xd0070001,0x7aeb0134,0x63ad20d0}},	//   _njeg, јете_, jagt, _ghan

  { {0x539b01d8,0x7aeb00dd,0xb17b0123,0xef170054}},	// [3c00] _שיפו, dagt, tsåt, јму_
  { {0xbce50015,0x20030046,0xee3720d1,0x2b58002b}},	//   مأمو, buji_, шну_, گیرد_
  { {0x1c390010,0x61e40026,0xe0fb0008,0xf0aa04ab}},	//   ляць_, _hwil, _בליל, _школ_
  { {0xeafa0029,0x2907002e,0xb5fd00bd,0x7aeb0134}},	//   ئرات_, egna_, azši, gagt
  { {0x9f5820d2,0xba18002b,0xdb1c002a,0xda340088}},	//   stró_, ايتا_, _stró, селы
  { {0x61e4003f,0x28f7004a,0x497300fd,0x26c2006f}},	//   _mwil, аешь_, оліс, ľkom_
  { {0x9d1b000a,0x68ea20d3,0x26c220d4,0x478a1cd9}},	//   _שולט, rafd, žkom_, ксим_
  { {0x61fd002e,0x7aeb002d,0x2ca718b8,0x8bd7039e}},	//   yrsl, cagt, ünde_, _כולו_
  { {0x63ad0176,0xbafb0008,0x657a1740,0x8afb000a}},	//   _rhan, _שהמש, tith, _שהמי
  { {0xa9060074,0x645a0091,0x94aa0015,0x63ad20d5}},	//   _خبرن, tyti, َادِ_, _shan
  { {0x69310086,0x657a20d6,0x7bc020d7,0x63ad20d8}},	//   _رکور, rith, _kimu, _phan
  { {0x68e80176,0x657a20d9,0x20030046,0x59dd000b}},	//   _hedd, sith, vuji_, नीकर
  { {0x75d40086,0xa5f80001,0x645a20da,0x2c08000b}},	//   _ايتا, _селу_, syti, ांडू_
  { {0x20030046,0x7e6d00bc,0x645a20db,0x65930015}},	//   tuji_, vzap, pyti, _وجور
  { {0x63ad162b,0xdb1e0089,0xdfd5004a,0x3fb70015}},	//   _than, _švýc, собы, لإرس
  { {0xdcfe0048,0x60da0064,0x94bb000a,0x68e820dc}},	//   kopē, ıtma, _במות, _ledd
  { {0x68e80176,0x7a1a0024,0x61e40026,0x91e40054}},	// [3c10] _oedd, nātā, _gwil, _доње
  { {0x98b8005d,0x6b9b05d7,0x621a000a,0x7aeb00aa}},	//   ेखाए, _skug, _עותק, wagt
  { {0x636600dc,0x6aa9005c,0x5c07006b,0x6e360091}},	//   _hóna, _szef, ряза, avyb
  { {0x7e990086,0x41c40086,0xc9f50029,0xdb5b0063}},	//   _منجر_, _دقیق, مستع, ъюз_
  { {0xf1da005d,0x7ac40036,0x195902bf,0x7bc0013c}},	//   _बढ़ान, ісце, лады_, _dimu
  { {0xceb60008,0x7a1a0024,0x98ac0064,0x2d8f00dc}},	//   _לפרק_, dātā, _aldı_, éged_
  { {0x7aeb0035,0x68e80304,0x286b006b,0x70f8004f}},	//   pagt, _dedd, ърдо_, שֶׂב_
  { {0xbb85003b,0xef11000a,0xf8ae002b,0x6d55078e}},	//   _الري, הּ֙_, رکل_, _hoza
  { {0x16390029,0x68e80026,0xa7620063,0xfa55002b}},	//   اسبة_, _fedd, якъд, _ارزگ
  { {0x7ae920dd,0x85490195,0x7bc00bba,0x6d550e2a}},	//   _heet, узов_, _zimu, _joza
  { {0x94750029,0x3f8b002a,0xc7cb0033,0xe3ba07be}},	//   إدخا, _ojcu_, _рызе_, лбо_
  { {0x67b50054,0x7a1a003d,0x78bc001a,0x6d41001a}},	//   _убеђ, bātā, _úrva, _ólaf
  { {0x6366002d,0x7ae90100,0xe1ff20de,0x9475002b}},	//   _cóna, _meet, gró_, شدگا
  { {0x999f0050,0x6d550024,0x86360135,0x23cf000b}},	//   _usuń_, _noza, _לאנג_, _संपद
  { {0x3fa60029,0x3d0b000b,0xa067201e,0xdb00008c}},	//   مصرف, ालने_, бара_, _yhmä
  { {0xe513000b,0xa3e7000b,0xe1ff0077,0x63761289}},	//   त्रि_, मीण_, bró_, kšni
  { {0xee3a008f,0x7bc004ed,0x9eaa000d,0x69c11740}},	// [3c20] ына_, _rimu, уваа_, _oile
  { {0xa3de000b,0x80660054,0xf237000a,0xed570248}},	//   दीक_, _гвож, _פריץ_, боу_
  { {0xd5c80092,0x3a2d00e8,0x68e820df,0x6ac600a2}},	//   _nền_, _asep_, _redd, مقام
  { {0x8fc50086,0xcb09005e,0x5f46006e,0x69c120e0}},	//   _گزین, ихід_, _انحل, _aile
  { {0xffb7000a,0xa3e7000b,0x539b000a,0x69c120e1}},	//   _ללטש_, मीत_, נינו, _bile
  { {0xdd9204b6,0x313a0053,0x7a1a0024,0xd5c80092}},	//   _روز_, רײַב, vātā, _bền_
  { {0xe0d30053,0x7bc0064e,0xf0e6000b,0x69c120e2}},	//   לײג_, _timu, _क़ैद_, _dile
  { {0x2d9a20e3,0xe1ff005c,0x26df0035,0x68e80495}},	//   lope_, czów_, gbuo_, _wedd
  { {0x68e80bbc,0x69c10d3d,0x09e3090a,0xb4c00065}},	//   _tedd, _file, _нотн, ंख्_
  { {0x0e57000a,0xda650015,0x8e57004c,0x94180004}},	//   משפט_, _بافي, צייג_, ажот_
  { {0xebe60010,0xe60f0086,0xb8960015,0xe8d7000a}},	//   авiк_, وشی_, _الضع, _הובר_
  { {0x69c120e4,0xe1ff07ea,0xf3670245,0x5c37004f}},	//   _zile, tró_, стон, צרכן_
  { {0x36360029,0xaaba000b,0x171b000a,0x86c30015}},	//   _دراس, ेशिक, _תודע, _عيون
  { {0xe1ff20e5,0x85f7004f,0x80d40065,0xd0d4009b}},	//   rró_, _פצוע_, बुले, зоръ
  { {0xc7f8000a,0xa3e7000b,0xe3c90016,0xb7f8000a}},	//   יִּר, मीद_, _hằn_, יִּט
  { {0x2e4b006b,0x44a3012c,0x9ed920e6,0x9f0502be}},	//   лязо_, _عميق, рмат_, تورو
  { {0xa2a0005d,0x42dc0053,0x67d10024,0xedd50015}},	// [3c30] _गुप्, _עקזע, _māja, زياد
  { {0x7ae90020,0x443c049f,0x865b0643,0x6600003d}},	//   _seet, _krv_, אדמי, irmk
  { {0x6b75000d,0x7ae90020,0x69c120e7,0x6fb50015}},	//   олжу, _peet, _rile, _ومخا
  { {0xcf27002b,0x69c120e8,0x1bb80015,0x2bb80015}},	//   _اردي, _sile, مانع_, مانة_
  { {0x7ae920e9,0x69c920ea,0xbf36000a,0xe1ff002a}},	//   _veet, _quee, _וארץ_, rzów_
  { {0xc27c0008,0xe1ff002a,0x69070033,0x637607c4}},	//   נרגי, szów_, сядз, ršni
  { {0x47d200e5,0x69c120eb,0x40ec000a,0x02fb000b}},	//   ويور, _vile, אַחֲ, ्लाह_
  { {0x3f890176,0xf7710070,0x23cf005d,0x69c120ec}},	//   nnau_, بات_, _संबद, _wile
  { {0x645c0d2b,0xf5050036,0x443c17df,0x9f6001c4}},	//   ørin, озпо, _arv_, érés_
  { {0x7c2e0026,0x98a7002a,0xe57920ed,0xe93b002b}},	//   _ysbr, edną_, рзо_, _حسرت_
  { {0xdce5006f,0x34a90912,0xa34a1797,0x23690045}},	//   kohľ, рвно_, азна_, _blaj_
  { {0x2bd0000b,0x96b90054,0x637a1dd4,0xd6390138}},	//   _तूफा, _кулу_, рсор_, _вякі_
  { {0xd6e8000a,0xe796002b,0xe29708f0,0x442e007c}},	//   _הַצָ, _بالک, жая_, _esf_
  { {0x6f1d018b,0x3f890313,0x443c002e,0x7aba000a}},	//   _absc, enau_, _frv_, יצרו
  { {0x659a00a3,0x3f890034,0x4f7a004a,0x93960015}},	//   _דיסק, fnau_, ащая_, _وجبا
  { {0x20870036,0xdee60015,0x2bd0000b,0xa3ae0065}},	//   ійти_, تأسي, _तंबा, _कठि_
  { {0x27e0016f,0xbea320ee,0xf8c9000b,0x98c9000b}},	// [3c40] ćini_, датк, िखाय, िखाए
  { {0x4c860063,0x31a400dc,0xc1060087,0xa1570054}},	//   олзв, közi_, _بودي, _мању_
  { {0x2d9a20ef,0x8c260015,0xfc2a004a,0x7ac620f0}},	//   rope_, تفاه, ржек_, осле
  { {0x8cda014e,0xd116005d,0x3e700152,0xeb9a0080}},	//   _प्रो, द्रण_, _côté_, шие_
  { {0xbddb08e0,0x094a20f1,0x93b7000a,0xee371899}},	//   _crèd, ички_, קלנו_, _дня_
  { {0x422b000a,0xe9770033,0xfb74009a,0xd7fa04c5}},	//   שֵׁ֣, обіш_, _کپرگ, ауи_
  { {0xf66a002e,0xd90d0086,0x4b260015,0x18670054}},	//   kvæð_, ایم_, _وعرف, жаји_
  { {0xc7ba0080,0x8b2307c1,0xeb970098,0xcc77000a}},	//   шёл_, _одсе, _дис_, _ועלה_
  { {0x5986000d,0x27e90085,0xc5260004,0xc6f70033}},	//   _длаб, ćana_, оќни, цных_
  { {0x443c002c,0x20bc000b,0xd46a0015,0x7bde1bf2}},	//   _prv_, ोखाध, لحجم_, oppu
  { {0x3f890176,0x3202006f,0xa9bb000a,0x7ae220f2}},	//   ynau_, erky_, _כזמר, obot
  { {0xd7760015,0x926b0262,0xa295008b,0xd37b1032}},	//   _بائع, арга_, замі, рчо_
  { {0xa7730010,0xb5fd0089,0xf749002b,0xd5c80016}},	//   _ўліч, uzšt, _دجله_, _kềm_
  { {0xd2580010,0x2fd70015,0x9f5802b9,0x3ce4000b}},	//   іця_, قترح, errà_, गरों_
  { {0xd5b80048,0x7528032c,0xd5c80092,0x645c0020}},	//   mmā_, medz, _mềm_, ärid
  { {0xa8570008,0xa1150086,0x7528005c,0x1dc50015}},	//   חילה_, _کودت, ledz, كْرِ
  { {0x3f890026,0x9757000a,0x6366005a,0x9f4a0052}},	// [3c50] rnau_, קימו_, _zóno, erbó_
  { {0x8c67003b,0x752800dc,0xeca70001,0x6ca7110d}},	//   يطان, nedz, ојен, ореж
  { {0xbc4b0010,0x752820f3,0xdee70015,0x2569006f}},	//   шчае_, iedz, _وأحي, _júla_
  { {0xb09a000a,0x7de70033,0x7b74006e,0xb5fd0046}},	//   _ליתר, _мігд, وطنا, lyše
  { {0x7bde0024,0x9a270015,0x09e50033,0x442c0034}},	//   appu, تعان, чолн, hwd_
  { {0x4bdb0086,0xae5a0008,0xceb2000a,0x75280228}},	//   _نبرد_, _הכשר, _נים_, jedz
  { {0xa3ae005d,0x53c6000b,0x6d4701c2,0xe802000b}},	//   कतम_, _रंगश, _inja, रंगा_
  { {0x6f0d20f4,0xdb1c20f5,0x31a40030,0x1daf000b}},	//   ngac, _strö, rözi_, _जीतत
  { {0x79a700d0,0x7afb0091,0x6d4720f6,0x497520f7}},	//   _држе, _idut, _knja, _елас
  { {0xa5090001,0x7ac4005e,0x36180033,0x6e2004d6}},	//   љена_, _істе, іцыю_, _ämbe
  { {0x044518a9,0xc209000a,0xac310033,0x6e2d0ccc}},	//   ченн, _תה_, дзiл, hwab
  { {0xeaa700e6,0xd6b6002b,0x15f50015,0x067501f3}},	//   فع_, _کشمک, _فستح, _нуля
  { {0xd36f0015,0x442c0034,0x6b8b20f8,0xe7c40065}},	//   اهُ_, awd_, ingg, _लूटप
  { {0xb2270084,0x763a0053,0x6e2d002a,0xe20b001a}},	//   _svæð, _לענג, dwab, _stóð_
  { {0x64a21186,0xc4d2000a,0x6609008c,0x9f4e01c0}},	//   _паша, _אגו_, luek, šník_
  { {0xf4120008,0x10a30036,0xdfcf0029,0x0fc30033}},	//   _נפח_, хисн, طيك_, ейсн
  { {0x67290024,0xa3e7005d,0x644e007c,0xb4bb000b}},	// [3c60] ieej, मीर_, äbiv, _अणु_
  { {0xdd920029,0x6b8b0049,0xe1ff0030,0xf297000a}},	//   روض_, engg, rzót_, _מכפר_
  { {0xdd8f003b,0xe1ff00dc,0x515b000a,0x6e2d0ef3}},	//   دول_, szót_, _הכיו, awab
  { {0x7f4a0029,0xe3c90092,0x7528005c,0x8025002b}},	//   _الحق_, _nằm_, zedz, _کریم
  { {0x7ae220f9,0x59f80033,0x201820fa,0xe9a60033}},	//   rbot, целя_, ltri_, падп
  { {0x69330036,0x721b000a,0x6b8b20fb,0x91f7000a}},	//   еншу, מונח, angg, למנו_
  { {0x7c5a0029,0x7528002c,0x201820fc,0x200a20fd}},	//   _الزر_, vedz, ntri_, nubi_
  { {0x95d8005f,0x7528005c,0x9c17000a,0x20180e01}},	//   одит_, wedz, _מחלק_, itri_
  { {0x7bce0375,0xe66620fe,0x96f70015,0x3a3f20ff}},	//   _hubu, ятко, سعير_, _grup_
  { {0x24e3005e,0x89db000a,0x2018014b,0xb9c50040}},	//   нцюг, _לחמי, ktri_, _قتله
  { {0x75280048,0xd5b80024,0x6366002e,0x442c0111}},	//   redz, rmā_, _tónl, uwd_
  { {0x98ac0048,0x93270029,0xd5b80024,0x442c0026}},	//   _gadā_, أردن, smā_, rwd_
  { {0xcb130053,0x27e0016f,0x16340457,0xdb9b000a}},	//   עלש_, ćinu_, _целя, מסטר
  { {0xdb09002d,0x35b3042b,0xb6bb000a,0xf8cc000b}},	//   _mheá, _збір, _הצדי, ाशिय
  { {0x443a0092,0x26c2002c,0x251b000a,0xb4e8000b}},	//   _ép_, ľkou_, _הווא, बरी_
  { {0xee3f0089,0x3f5c002e,0x26c20057,0x8cb3000b}},	//   _prý_, _síur_, žkou_, _अरबो
  { {0xc3340053,0x6e2d02f2,0xce94006b,0x7bdc2100}},	// [3c70] _נוץ_, uwab, еатъ, _atru
  { {0x853c0007,0xd578000a,0xc578000a,0x77a500e1}},	//   klėm, קָּר, קָּט, róxi
  { {0x2d810064,0x394b0092,0xe1ff002a,0xbddb0003}},	//   rihe_, _đcs_, czór_, _brèc
  { {0x23cf005d,0xcff60008,0xf092000a,0x7bce2101}},	//   _संसद, _קצרה_, _יני_, _dubu
  { {0xcf560008,0x7f3a000a,0xff56000a,0x99d70021}},	//   _חברת_, _וערו, _חברך_, ستشا
  { {0xdb09002d,0xa3b4000b,0x3238000a,0xdb1c0034}},	//   _dheá, _जीन_, פטון_, _strô
  { {0x999f00dc,0x238800dc,0xb4ab000b,0xdb021e83}},	//   éről_, lője_, _खरे_, cloï
  { {0xeafb0086,0x853c0007,0xbddb028f,0x3b550033}},	//   _درست_, slėl, _grèc, _ўкар
  { {0x7bd20024,0x61fb0085,0x98c7002b,0xb4e80065}},	//   ējuš, šulj, _فغان, बरू_
  { {0xb4650296,0xe4510058,0xdce7013b,0x0000006a}},	//   дкол, نضج_, _oljč,
  { {0x9cd6000a,0x321900aa,0xa3e70065,0xe3c900a1}},	//   וותה_, etsy_, मीं_, _tằm_
  { {0x889a0008,0x6609007c,0x389a000a,0x798302f2}},	//   _ובעי, puek, _ויענ, linw
  { {0xf7700225,0x0caa005d,0x95550029,0x44230089}},	//   _حال_, _कर्म, _يختا, ůj_
  { {0xd5bb078f,0x66ba0008,0x20182102,0xd1320015}},	//   _усе_, _ומנה, ttri_, خمس_
  { {0x7f5a000d,0x8fa62103,0xbf66002b,0x853c0091}},	//   ојат_, даве, ودرو, klėj
  { {0x0395008f,0x93960015,0x2d8f0030,0x79830012}},	//   _прыя, _تجتا, égen_, hinw
  { {0x1da9005d,0x290e0026,0x63a40eeb,0x7bce154a}},	// [3c80] कतंत, ygfa_, _ikin, _subu
  { {0x4e1901f3,0x6b82028a,0xe2a90015,0xdd8f00c3}},	//   яюся_, wiog, _عاين_, لوق_
  { {0xec770098,0x0000006a,0x0000006a,0x0000006a}},	//   мпф_,   ,   ,
  { {0x61e904f9,0x200501cb,0xf456004c,0xe46a007c}},	//   ţele, álie_, ויער_, ltöö_
  { {0xe46a007c,0x6a130021,0x63b60034,0xcbc5006e}},	//   otöö_, نبور, _mhyn, رزمي
  { {0x6b8200df,0x7c3a002c,0x929b000a,0x3eaf0012}},	//   siog, _štru, חינת, ügte_
  { {0xa3ae005d,0xa2a0000b,0x7bdc2104,0xaf58000a}},	//   कता_, _गुस्, _utru, ּׁ֖ה_
  { {0xc6f82105,0x96ea042b,0x96341944,0x6d5c03b8}},	//   чних_, цька_, ениц, _hora
  { {0x6d5c2106,0x98a70046,0x0000006a,0x0000006a}},	//   _kora, odně_,   ,
  { {0x63a400b6,0x6d5c00d9,0x6d580020,0x4a5b000a}},	//   _akin, _jora, övah, _ודמו
  { {0x7bda038d,0xb4de005d,0x238800dc,0x6d5c2107}},	//   _étud, _तभी_, zője_, _mora
  { {0x69c6005d,0x63b60026,0x69c812af,0x7c3a0030}},	//   ादकी, _chyn, _hide, _átru
  { {0xe2ab0086,0x66730015,0x69c82108,0x5a9b004c}},	//   تادن_, _لدور, _kide, ַשלא
  { {0x6d5c2109,0xe9ff0016,0x63a40f0a,0xa492002b}},	//   _nora, hiếc_, _ekin, _لیخت
  { {0xd59b000a,0x69c8210a,0x853c0091,0xdcfe013b}},	//   _ובגל, _mide, ylėj, gipč
  { {0xc3fb0008,0x238800dc,0x93fb0008,0x69c8210b}},	//   _ולהש, tője_, _ולהי, _lide
  { {0xd0d50063,0xadb5000d,0xfebb0086,0x69c8002d}},	// [3c90] _попъ, ебаш, زارت_, _oide
  { {0x2569002e,0xb035008b,0x23880030,0x23b20030}},	//   _núll_, _знош, rője_, mája_
  { {0x23b200dc,0x2ca702de,0x23880030,0x753800bc}},	//   lája_, ænd_, sője_, _mavz
  { {0x69c80493,0x6ec70015,0x7d080030,0x6d5c0125}},	//   _aide, _يتحق, térü, _eora
  { {0x7e76005c,0x6d5c210c,0x23b20030,0xaa58007e}},	//   czyp, _fora, nája_, мицу_
  { {0x61ed000c,0x6d5c210d,0x75381eed,0x69c8210e}},	//   _mwal, _gora, _navz, _cide
  { {0x31580053,0x69c80aa6,0x6bd40015,0x798300a9}},	//   ויגן_, _dide, _لتقر, rinw
  { {0xd00c000a,0x23b20030,0x61ed002a,0x6d5c210f}},	//   קּוֹ, kája_, _owal, _zora
  { {0x63b60176,0x76421a8b,0xd9ab006b,0x7f5d1915}},	//   _rhyn, _croy, _дъжд_, _mosq
  { {0x69c80064,0x78270015,0xc4c9000b,0x23b20030}},	//   _gide, _يعال, रशेख, dája_
  { {0x23d50010,0x98ac0011,0x98140806,0x61ed0278}},	//   эцпр, _vadă_, _لبنا, _awal
  { {0xd7c80029,0x69c8005c,0x8675005e,0x883a000a}},	//   _قوله_, _zide, _плеє, _מתעו
  { {0x7bc90152,0xc7b20008,0x57780015,0x644e007c}},	//   _mieu, _עבד_, _تصلح_, äbir
  { {0x7bc912f6,0x57f9000a,0x61ed0079,0x6366039f}},	//   _lieu, ּלּו, _dwal, _móni
  { {0xf992000a,0xdfd200e5,0x7f5d2110,0xa2a0000b}},	//   טרך_, اير_, _bosq, _गुर्
  { {0xe29a010f,0x7bc92111,0xe46a0020,0x75380a05}},	//   _най_, _nieu, stöö_, _zavz
  { {0x61ed0176,0xdd9204c9,0x661b0d25,0x6d5c12d7}},	// [3ca0] _gwal, هور_, ntuk, _pora
  { {0xd29b013a,0x661b022d,0xa3b4005d,0x7e76005c}},	//   _משפט, ituk, _जीत_, rzyp
  { {0xdca10010,0x26190092,0x6d5c2112,0x9b06000d}},	//   асцi_, hèo_, _vora, езед
  { {0x673b0050,0x79810026,0xeb972113,0x6d5c00b8}},	//   jduj, _amlw, них_, _wora
  { {0x6d5c002f,0xd9d70036,0x7bc92114,0xb866002b}},	//   _tora, емії_, _dieu, کاشو
  { {0x61fb0e51,0x64432115,0x9d46011e,0x0000006a}},	//   áuli, _orni, _џевд,
  { {0x7dc90007,0x2c34000a,0xc7c60923,0x680e0030}},	//   _užsa, _בָּם_, нсии, dődá
  { {0xf7720029,0x76422116,0x8c1b000a,0xc053000a}},	//   طاع_, _proy, _מולי, רזה_
  { {0x661b00df,0xadc30092,0xf6520029,0x2508002b}},	//   gtuk, _hoạc, ائع_, وردی_
  { {0xf9fb000a,0x69c817ca,0x64432117,0x8e7b004f}},	//   _מהממ, _uide, _brni, פניה
  { {0x61ed0705,0x64430085,0x661b2118,0x25600144}},	//   _swal, _crni, atuk, _sòls_
  { {0xd4970010,0x67220b6c,0x23b20030,0x76422119}},	//   эры_, _uboj, tája_, _troy
  { {0x61f8008f,0x78a40061,0xbddb0003,0x52241377}},	//   нняў_, şivd, _arèn, лфра
  { {0xe8ee02e1,0x25720003,0x23b20030,0xda4b004f}},	//   алi_, _bâle_, rája_, הֲלָ
  { {0x395e0277,0xd3a7211a,0x3d14000b,0x2d8f0030}},	//   _mots_, _прип, दलने_, égem_
  { {0x34370015,0x395e211b,0x9f3402a3,0x23b207f4}},	//   _أسود_, _lots_, лесі, pája_
  { {0x539c000a,0xa3ae000b,0x61ed002a,0x7bc90003}},	// [3cb0] _מיהו, कतर_, _uwal, _rieu
  { {0x40950015,0x2dab0015,0x1e340033,0x7bc910eb}},	//   _للخر, ساءً_, ынуў, _sieu
  { {0x7bc90003,0xe58b000a,0x661b002a,0xb0c7030c}},	//   _pieu, הָאָ, ztuk, _ящик
  { {0xead8005e,0x9056000a,0x0000006a,0x0000006a}},	//   емці_, _סברו_,   ,
  { {0xe9d80010,0x23960024,0xee870010,0x7bc9211c}},	//   екі_, nāja_, _чыно, _vieu
  { {0xb08b000a,0x2d8502ad,0x0a480138,0x0000006a}},	//   ּנֵ֖, _öle_, эзій_,
  { {0x01380008,0xb7950001,0x98350010,0x395e211d}},	//   גרות_, крић, тэлі, _dots_
  { {0x394c211e,0xd6ce0015,0xb038000a,0xdb1c0046}},	//   _ends_, يقى_, תנהג_, _kurý
  { {0x661b022d,0x1a5b0029,0x645c211f,0xd5c80016}},	//   utuk, _عشرة_, ärin, _lều_
  { {0x89340087,0x66240015,0x2396003d,0x661b2120}},	//   _معما, اريك, dāja_, rtuk
  { {0x661b0c8d,0x33d40010,0x3d19021e,0x3ea6003d}},	//   stuk, ліят, _पाने_, ļoti_
  { {0x644300bd,0x23c50033,0xc7d6000a,0x7eb80052}},	//   _vrni, лёўв, _סוני_, _júpí
  { {0xd2f2000b,0x2396003d,0xe6040058,0x8afa004f}},	//   _अजीब_, gāja_, _مِنَ, והרי
  { {0x3ceb005d,0x25720003,0x98ac002a,0x91e30e16}},	//   टरों_, _pâle_, _wadą_, роре
  { {0xb4fa000a,0xc952000a,0x61430054,0x64432121}},	//   _חפצי, סמל_, јеса, _urni
  { {0xd00f0225,0x7bd800dc,0x20052122,0x2fc30015}},	//   تلف_, ívum, ália_, لقِّ
  { {0xaec60033,0x91960099,0x64412123,0x4f230054}},	// [3cc0] тбал, _ајнш, lvli, јдуб
  { {0x6d8b0048,0x5bca005d,0xf06601b0,0x66090d3d}},	//   kļau, िद्व, _акоп, irek
  { {0xceea0036,0x6db6003d,0x5f062124,0xa3e4000b}},	//   _одне_, _kņaz, _изна, _पढ़ा_
  { {0xaa8a002b,0x66092125,0x67d1003d,0x09e62126}},	//   ونام_, krek, _gāji, водн
  { {0x82d700b2,0x395e08e0,0x66090134,0x66e20089}},	//   דונג_, _pots_, jrek, níků
  { {0x5e770008,0xc27b0008,0x39130036,0x3d19000b}},	//   _יתכן_, ורני, имір, _पाये_
  { {0xa3c4000b,0x98130015,0x395e0144,0x66092127}},	//   ौदा_, لبيا, _vots_, erek
  { {0xf093011f,0x466a1a9d,0x66092128,0x47341206}},	//   ינו_, дром_, frek, унис
  { {0x395e08e0,0x9a250029,0x96630054,0xb8c90065}},	//   _tots_, _معلن, икће, _गु_
  { {0xb5fd0046,0xdebb000a,0x200a00bc,0xad3a02a3}},	//   myšl, ומפל, krbi_, звiт
  { {0x59750010,0x74140015,0x66092129,0xb4d2000b}},	//   _сыту, دوجا, arek, _वली_
  { {0x23960048,0x9f580125,0x1dd2000b,0xe8ba002a}},	//   tāja_, arrú_, तदात, _mężó
  { {0x2d8f0014,0x5187212a,0x1394005e,0x7d03013f}},	//   égek_, вува, рияю, ónsk
  { {0xd8380247,0xdb1c1807,0x68f8212b,0x94d30138}},	//   _ksč_, _kuró, navd, _кошц
  { {0x84380029,0x50f40063,0xa3b4000b,0x656f0003}},	//   _أكبر_, рзст, _जीव_, êche
  { {0x6ab2005d,0x8afd0089,0xdb1c002a,0x6d4e212c}},	//   _जरूर, _koře, _muró, _anba
  { {0x28a9005d,0x98a70024,0x1df804ab,0x27e90085}},	// [3cd0] _चुनि, ienā_, кеты_, ćani_
  { {0xdcb10023,0x9be70036,0x8afd0046,0x2fc000bc}},	//   _ở_, відк, _moře, amig_
  { {0x9f5802c1,0x6acb000b,0x3d941114,0x0000006a}},	//   guró_, िश्र, шифр,
  { {0x6d4e00c0,0x8f190008,0xc4770008,0x3a75212d}},	//   _enba, _אוֹת, כתבו_, ллер
  { {0x3f89212e,0x2011016f,0x9e670015,0x61fd001a}},	//   miau_, luzi_, _شاحن, nssl
  { {0xdb1c018b,0x6d8b0024,0x0d640063,0x3f89212f}},	//   _zurü, tļau, _късм, liau_
  { {0x2011000c,0xb8db005d,0x23b20030,0xab950054}},	//   nuzi_, _घर_, fájl_, _бављ
  { {0x3f890176,0x6fd6000b,0xb7d20015,0x66092130}},	//   niau_, _मंसू, حقيب, trek
  { {0xdb1c163c,0x7bd50061,0xd4f501b0,0xab8415f4}},	//   _euró, _huzu, ляны, _турк
  { {0x2011000c,0x3f890026,0x7bd5003f,0x660600dc}},	//   kuzi_, hiau_, _kuzu, ákka
  { {0x05540033,0xb17b00cb,0x3f890091,0x66092131}},	//   ртыя, rpål, kiau_, srek
  { {0x36d50083,0xd808000a,0x91e606c3,0x7bd51022}},	//   _содр, _יִנָ, ломе, _muzu
  { {0x3f890026,0x66050839,0x4b7a000a,0xe1f10015}},	//   diau_, _спла, תארו, ْسِ_
  { {0xe4e70036,0xb33b016e,0xbddb0003,0x92a90535}},	//   _рідн, boço, _crèm, _skłó
  { {0x5f06010f,0x2011003f,0x659a004c,0x3f960004}},	//   лзва, guzi_, _אױסװ, граѓ
  { {0x3f892132,0xf412000a,0x13a8002b,0x1eca0004}},	//   giau_, _הפה_, _جنبی_, елби_
  { {0x023a0015,0x539b000a,0x63a60030,0x2fc02133}},	// [3ce0] _أثبت_, _ריפו, mokn, rmig_
  { {0xee370010,0xad660087,0x23b90030,0x7bd51999}},	//   ыну_, داره, réje_, _buzu
  { {0x711b00b2,0xbb46085d,0x40950036,0x3f892134}},	//   _אויפ, лежк, _врят, biau_
  { {0x3f890026,0x1037000a,0xcaf60015,0x63660030}},	//   ciau_, _עטכם_, اساب, _tónu
  { {0xe918022a,0xc9860004,0xab770015,0x98a7003d}},	//   волі_, луки, دمنا_, venā_
  { {0xaa470054,0xb4d2000b,0x6f160034,0x6e360034}},	//   упља_, _वले_, lgyc, mwyb
  { {0x3d19005d,0x68f806ca,0x3ea6003d,0x6e360034}},	//   _पाते_, ravd, ļotu_, lwyb
  { {0x7c930029,0x61e40f3a,0x61fd0123,0x57b401ca}},	//   _الفص, _otil, yssl, јбит
  { {0xfad70008,0x7bd500b8,0xda0a0086,0x6e360026}},	//   _תומך_, _zuzu, _سياه_, nwyb
  { {0xecb8005d,0x2011003f,0xce37000a,0xbddb0144}},	//   _अराफ, yuzi_, נאית_, _brèj
  { {0x2d8f00dc,0xa2c2005d,0x63550355,0xed57004c}},	//   égei_, रेस्, авну, אביר_
  { {0x63a60030,0x389b000a,0xb33b016e,0x7bc22135}},	//   gokn, _איבנ, roço, nmou
  { {0x3f890007,0xbddb0144,0x6e36002a,0x25a52136}},	//   viau_, _prèm, jwyb, boll_
  { {0x3f890026,0x5184017d,0x61e90045,0x463b004c}},	//   wiau_, буса, ţelo, _רעגע
  { {0x3f890026,0x04db000a,0x63660077,0x88bc0046}},	//   tiau_, _אקול, _cóns, _oběm
  { {0x7bc20089,0xd4910092,0xe44f0015,0x853c0091}},	//   jmou, oàn_, _رضى_, alėt
  { {0x3f890fc6,0x9e150010,0x4dd70015,0x7bd52137}},	// [3cf0] riau_, рдзі, اترس, _suzu
  { {0x3f890176,0x22492138,0xc6b7004f,0x9e080058}},	//   siau_, _irak_, רהמי_, ايلك_
  { {0x3f890176,0xe1ff0014,0x7c35004a,0xd59b004c}},	//   piau_, lsó_, реех, עבבל
  { {0x305a004c,0x6a150021,0x6d582139,0x2417004f}},	//   _סדרד, لبتر, övar, רחאן_
  { {0xe9ff0023,0xfaa50180,0x9a240015,0xe1ff0077}},	//   _trận_, јало, معون, nsó_
  { {0x63a60030,0xd9450047,0x19580033,0x0cd400f4}},	//   zokn, реки, лачы_, _горю
  { {0x25a5213a,0xa3b5000b,0x63a60030,0xe739213b}},	//   voll_, झता_, yokn, вей_
  { {0xef120008,0x16390029,0xfb870033,0x22490085}},	//   ַּח_, نسخة_, _сыгн, _orak_
  { {0x05550033,0x0000006a,0x0000006a,0x0000006a}},	//   атня,   ,   ,
  { {0x27050023,0xe6280029,0x79c800e6,0xf993002b}},	//   ồn_, اثين_, _موقف_, _ابر_
  { {0xf1c80089,0x61e4213c,0x63a607ce,0xb9c40031}},	//   ntář_, _stil, tokn, _اقلي
  { {0x2249213d,0xcad5000a,0xeaa70015,0x02c60a32}},	//   _brak_, יוֹת_, قع_, ийно
  { {0x13070010,0xc6d40015,0x66cb0061,0xe56e1301}},	//   шняй_, _اتمت, _dökü, _дз_
  { {0xa2c2005d,0x69c3002d,0x63a61bf1,0xf9870002}},	//   रेष्, nmne, sokn, زب_
  { {0x853c0007,0x7d0000dc,0x7bc2213e,0x69c3213f}},	//   alės, hárí, ymou, imne
  { {0x68401724,0xe3b90061,0x9f58001a,0xb4c3000b}},	//   ládá, ltın_, gurð_, ्शी_
  { {0x7de506e4,0xdb1b0092,0x853c0007,0x433b000a}},	// [3d00] مسلم, _thuê, plėt, _יעקב
  { {0x01fb00b2,0x3d10000b,0xb2bb000a,0xc535000a}},	//   _שפיל, ालें_, _במפר, יָ֣ה_
  { {0xc0590010,0x67d1003d,0x9f58001a,0x6faa0015}},	//   _біў_, _mājs, burð_, _لهدف_
  { {0xdbdf002e,0x69c32140,0xd6d9002a,0x4ae30033}},	//   _víðt, emne, ydła_, оўша
  { {0x79c60010,0x7bc22141,0x7dc60015,0x6249000a}},	//   айдз, rmou, _نتسك, ָנוּ_
  { {0x99f50127,0x9056000a,0x89f50033,0x645c019a}},	//   сяці, ֹסֵף_, сяцц, ärik
  { {0xa967050e,0x31570053,0x798a0026,0x98a70045}},	//   рија_, ייסן_, rifw, venă_
  { {0x69c310ad,0xab5d002a,0xfb16009a,0x86f8009a}},	//   amne, _biżu, _خورج, اکاس_
  { {0xba2900e5,0x65632142,0xa773005e,0x4aaa002b}},	//   _مسلم_, _bonh, ільч, _شارپ_
  { {0x656303af,0x65c30054,0xc8f8000a,0xd6d9002a}},	//   _conh, обња, _תִּכ, rdła_
  { {0xe2f90036,0x2cfb004f,0x656f01f6,0x0000006a}},	//   лені_, כליא, êcha,
  { {0x2636002a,0x22a30046,0xe3b90061,0xe1ff0030}},	//   _tło_, _léků_, atın_, tsó_
  { {0x36360087,0x5214006d,0x1709002b,0xe57a2143}},	//   _خراس, одят, _صفوی_, _изд_
  { {0xd5af0036,0x3d10005d,0x0665002b,0xd67b000a}},	//   _єс_, ालों_, _دامپ, _שָׁכ
  { {0x657a002f,0x3f87000d,0xf044004a,0x98ac0046}},	//   mhth, аѓаа, оэто, _radě_
  { {0x853c00df,0x2fcf001a,0x442e01c2,0x98ac0046}},	//   plės, ögg_, _ipf_, _sadě_
  { {0x539c0008,0x3eaf2144,0xdef80010,0x7dc90091}},	// [3d10] _שיחו, ægt_, рыс_, _užsk
  { {0x201e0251,0xdcf900e5,0x5d54005e,0xf1ab002b}},	//   àtic_, افات_, окут, _جابه_
  { {0x9f35022a,0xc19a000a,0xfaf70015,0x0dc80fbb}},	//   _лені, _תשתי, لأشخ, рути_
  { {0x91a00023,0xe4570053,0xcb080015,0xe9a8002b}},	//   _trị_, ייבט_, ليمن_, یدون_
  { {0xf2d400b2,0x98a70007,0xb5fd0007,0x0b440033}},	//   קעס_, ieną_, ryšk, ўнін
  { {0x69c304f9,0xada40010,0x27310092,0x89a80036}},	//   umne, _маўл, _ạn_, аків_
  { {0x256900dc,0x63ad00dd,0x3c93002b,0x443c007c}},	//   _múlt_, _okan, _بیاز, _nsv_
  { {0xf7710029,0x65632145,0x2bb80015,0x69dc19c2}},	//   ثات_, _sonh, _ناقة_, _črev
  { {0x9f5e038d,0x443c0024,0xea63002b,0x6563016e}},	//   été_, _asv_, _بپذی, _ponh
  { {0x66e7000b,0xca740015,0x88bc0046,0xba74006e}},	//   _ट्रक_, _بافغ, _oběh, _بافت
  { {0xf2c9000a,0xd91a000a,0xb4c3000b,0xe3b90061}},	//   _נע_, _תועל, ्शे_, rtın_
  { {0xc169000a,0xb7cb0015,0x6c56004f,0xa5f902ed}},	//   _אח_, _شباك_, צירא_, _беду_
  { {0xc6a70001,0x657a002d,0x8505002b,0x644a2146}},	//   _тржи, bhth, _هوشن, _erfi
  { {0x1ddb005d,0xf6520008,0x657a1cf8,0x11d70015}},	//   _बढ़त, _מצד_, chth, صوفة_
  { {0xe1f20086,0x2fda0086,0xdee60805,0x660200bc}},	//   _کسب_, اورد_, йови, _zvok
  { {0x439300d7,0xaf79005e,0x03a3006b,0xef17058f}},	//   _најс, асує_, _нищо, ймс_
  { {0x0ef90010,0xcc8a002b,0x6d8b002a,0xdcee003d}},	// [3d20] рэсы_, گناه_, rżan, _albā
  { {0xcf89004c,0xc5b9000a,0x32022147,0x7515004f}},	//   ײט_, אֶ֣ר, msky_, מַ֣ע_
  { {0xab5d005c,0x61f60026,0xbca60029,0xcc8a0029}},	//   _niżs, _hwyl, حماي, دناه_
  { {0xcb16003b,0xeafa0806,0x8afd0089,0x03d6000a}},	//   إذاع, ارات_, _pořa, צונם_
  { {0xbb470015,0x3096002b,0x831b000a,0xaa580432}},	//   صلون_, _خشکس, רונז, рилу_
  { {0x2d8f0014,0x6bda002b,0x7f440003,0x2d8c2148}},	//   éget_, _موسس_, ldiq, _öde_
  { {0xdc280024,0x764b0335,0x7d0b0091,0x66022149}},	//   rķēt, _argy, ėgst, _svok
  { {0xab960029,0x7f441662,0x9b960015,0x29d602be}},	//   _الرغ, ndiq, _الرت, _هيرس
  { {0xba560063,0x8b8b0008,0xda630608,0xe72a002b}},	//   _утвъ, _עָלֶ, _евти, نسکو_
  { {0xea770008,0x2e3b000a,0x20050030,0x3202214a}},	//   _הגמר_, נגינ, álik_, dsky_
  { {0x764b0026,0x4d5b0053,0xd7ea0ea6,0xc4d00015}},	//   _ergy, אדיצ, _смее_, بْد_
  { {0x4c9b214b,0x1cb70008,0x29f6005c,0x5c9b0053}},	//   רשטע, מליל_, oła_, רשטײ
  { {0x386e0026,0xa5f8098b,0x5558091b,0x657a214c}},	//   lyfr_, _телу_, _валя_, phth
  { {0x61f60026,0x98a70007,0x29f6002a,0xdfd50033}},	//   _dwyl, seną_, iła_, жовы
  { {0x7dc900df,0xc0580036,0x63e60029,0xf878000a}},	//   _užsi, біт_, _استك, בְּל
  { {0x29f6005c,0x7e6d0064,0x7497000a,0x4ea70b1e}},	//   kła_, tyap, _לדוד_, брза
  { {0x61f60176,0x644f003d,0x6e2402f2,0x2ddb0015}},	// [3d30] _gwyl, ācie, gtib, ابرة_
  { {0x29f6005c,0xd6d9002a,0x6b890091,0x0dc8005e}},	//   dła_, ydło_, _smeg, бухи_
  { {0x29f6005c,0x3ed50015,0x940b000a,0x6abb002a}},	//   eła_, _وقدر, ָּבֵ, _szuf
  { {0x7bc00bba,0xe3b90061,0x291e214d,0x0000006a}},	//   _chmu, ktım_, _acta_,
  { {0x2d8f0014,0x2bb80029,0x29f6005c,0x78a40064}},	//   éges_, حالة_, gła_, şivl
  { {0x98be0064,0x18690063,0x99d40067,0xbddb0003}},	//   _altı_, иали_, ستها, _brèv
  { {0x29f6005c,0x2003002a,0x6d55214e,0x961d003d}},	//   ała_, nsji_, _inza, izņe
  { {0xef110008,0x257b0003,0x29f6002a,0x06091c35}},	//   וּ֙_, _mêle_, bła_, аник_
  { {0x96b9022a,0x8c440045,0x20050085,0x81c3003d}},	//   шуку_, ăşes, šlih_, ķēji
  { {0x7afb018b,0xa5090001,0xd7fb0098,0x7c250125}},	//   _heut, јена_, _буд_, othr
  { {0xf9920008,0x7afb0375,0x78ac0264,0xbddb0003}},	//   _קרב_, _keut, čové, _grèv
  { {0x61f60026,0x853c0007,0x7c25214f,0x8c1a0008}},	//   _pwyl, slėp, ithr, סורי
  { {0xbb3a0053,0x32040057,0xeb3a004c,0x42ba0033}},	//   בערי, émy_, בערש, рыню_
  { {0x7afb00b8,0x95c50015,0x67290030,0x32022150}},	//   _leut, _بيته, lfej, rsky_
  { {0xc9520008,0x29f6005c,0x6d452151,0x69db007c}},	//   ומם_, zła_, ddha, _luue
  { {0x6d55018b,0x29f6005c,0x7afb1bfd,0x61f60034}},	//   _anza, yła_, _neut, _twyl
  { {0x20d608fb,0x69c10089,0x672900dc,0x61462152}},	// [3d40] _мінс, _ohle, ifej, _депа
  { {0x22400005,0x8cb60431,0x7db60010,0x0c760086}},	//   _isik_, осеч, ісац, يداد
  { {0xdd8f0029,0x7afb00b8,0x3157000a,0xf98a002b}},	//   خول_, _beut, _ויין_, یخته_
  { {0x6d45003f,0x29f6002a,0x44250034,0x2d8f0003}},	//   adha, tła_, itl_, éger_
  { {0x7afb0334,0x7c25002d,0x98a70c85,0x20182153}},	//   _deut, athr, menę_, luri_
  { {0xbddb0251,0x29f6005c,0x672900dc,0x07e60054}},	//   _prèv, rła_, efej, оцим
  { {0x29f60050,0x307a0053,0x20182154,0x6fb0000b}},	//   sła_, יאַנ, nuri_, ूतपू
  { {0xb7ca0015,0x35f4004a,0x69c10012,0x20050046}},	//   جبتك_, ппир, _ehle, álii_
  { {0x4425005c,0x7bdc2155,0x65940afa,0x20182156}},	//   etl_, _huru, запу, huri_
  { {0xceb3000a,0x7bdc2157,0x7c45001a,0x20182158}},	//   ויח_, _kuru, _ótrú, kuri_
  { {0x9cdb039e,0x7bdc2159,0x6615002a,0x67290030}},	//   יקיפ, _juru, ązka, bfej
  { {0x9f5100dc,0xd62a0175,0x883b000a,0xe3b00015}},	//   sszú_, _воде_, _כתבו, َرَ_
  { {0xe2980010,0xfa6a000a,0x7bdc088a,0x69c10046}},	//   жаў_, ׁכֹּ, _luru, _yhle
  { {0x7c25215a,0x20180045,0x291c215b,0x257b01f6}},	//   ythr, furi_, ngva_, _pêle_
  { {0xe9ff0092,0x224000dc,0x2018215c,0x03b70015}},	//   _trần_, _esik_, guri_, _وإعد
  { {0x20030050,0xe47b000a,0xa2f5004a,0x3a26215d}},	//   rsji_, _כרוכ, _эпич, ktop_
  { {0x0ec5005d,0x7e600251,0xedd50015,0xa116002b}},	// [3d50] लेंड, _àmpl, سياد, _کوپت
  { {0x82340086,0x721a000a,0x7bdc215e,0xe3b90061}},	//   _آريا, _פותח, _buru, ktık_
  { {0x2018215f,0x913a000a,0xe7100091,0x7bdc2160}},	//   curi_, _העתק, dėžė, _curu
  { {0x7bdc01e2,0x23960048,0x69db0020,0x69c10089}},	//   _duru, tāji_, _puue, _shle
  { {0x0e08004a,0x69c12161,0xaf5a004f,0xbddb01f6}},	//   _мэри_, _phle, _הכרכ, _crèt
  { {0x4dda0008,0xcdf6000a,0x44250046,0x2b460144}},	//   _לחשו, _ממשי_, ytl_, adoc_
  { {0xf7710029,0xd0f8000f,0xdcfc0085,0x40ec000a}},	//   فاة_, חמות_, _smrć, בַחֲ
  { {0x309c0008,0x1606005d,0xc7a80015,0x909c000a}},	//   ישומ, _शिखर_, يديل_, יסוק
  { {0x20182162,0x67292163,0xfb340138,0x0000006a}},	//   zuri_, rfej, _інфэ,
  { {0x67291e86,0xfcd6000a,0x270c0091,0x76492164}},	//   sfej, ּ֥ית_, vėnų_, rvey
  { {0x9d28000a,0xc5680015,0x58050015,0xe3b20015}},	//   חֵרִ, تحيل_, _روشك, فرح_
  { {0x58ba000a,0xddcd0085,0x88ba000a,0x637a004a}},	//   _המעצ, jzaž, _הזעי, ссор_
  { {0x44252165,0x0596009a,0x6d8b0535,0x93bd00d4}},	//   stl_, _کانگ, rżaj, ptăn
  { {0x20182166,0xc5f2004c,0xd1790033,0x200c0794}},	//   turi_, _טדד_, оссі_, ádio_
  { {0x645c022d,0xa508000a,0xdfd20021,0xb4fa000a}},	//   ärit, _וּפִ, فيس_, _הפצי
  { {0x20180011,0xcf5900fd,0xe043004a,0x32192167}},	//   ruri_, оруч_, энси, busy_
  { {0x3f670001,0x20182168,0xd24f0015,0x7bdc2169}},	// [3d60] чито_, suri_, _مني_, _suru
  { {0x201804f9,0xf1bf216a,0xddcb0064,0xdca60e44}},	//   puri_, ltán_, ğişm, пази
  { {0x50db0008,0xdb0b0134,0x6bd60087,0x7be6005e}},	//   _לחיצ, ilgæ, ستار, їждж
  { {0x8fa60010,0xf1bf002d,0x7bdc0064,0x2293002b}},	//   _хаме, ntán_, _vuru, _آلیس
  { {0xade3005d,0x0ab60015,0xdb0b216b,0xaa5c005e}},	//   _कूपन_, أحاد, ulgá, релi
  { {0xdb1b0092,0x88bc0089,0x7bdc216c,0xe3b90061}},	//   _chuâ, _obět, _turu, ttık_
  { {0x3a26216d,0x0720005d,0x58d303ae,0xf1bf0030}},	//   stop_, _यादव_, ношт, ktán_
  { {0x4c9b0008,0x780c005d,0xe3b90064,0x2768002b}},	//   _הבלו, _सटीक_, rtık_, تشتی_
  { {0xf6230124,0xc6f7044e,0x9aeb000a,0x2396003d}},	//   едњо, чных_, _הַבִ, nāju_
  { {0x270c0092,0x09690029,0x99860002,0xd498005e}},	//   ớn_, _وإلى_, _علاو, жкої_
  { {0x8881002b,0x4427005e,0xa3f30033,0xb603003d}},	//   _لیون, пцям_, няўш, ēšam
  { {0x18770008,0xa2950010,0x92950033,0x69ca216e}},	//   _מעבר_, дамі, дамц, lmfe
  { {0xe9ff0092,0x6fd6000b,0xae1e000b,0x95ca0684}},	//   _trấn_, _मंजू, यूमन_, _лука_
  { {0xd6570008,0x89eb000a,0x32190bba,0x645c216f}},	//   _מידת_, מַלֵ, rusy_, äris
  { {0xdb1b002d,0x55bb000a,0xe44f0015,0x753a0012}},	//   _shuí, _המגו, _مضي_, metz
  { {0xa857013a,0x987b0053,0xd3a40010,0x753a00b8}},	//   הילה_, זאלט, _прып, letz
  { {0x9d550086,0xc334000a,0x61f001c0,0x63af2170}},	// [3d70] وچست, _טוק_, čilý, mocn
  { {0xcf270086,0xfc330015,0xdc99005e,0x753a0012}},	//   _کردي, فحص_, овзі_, netz
  { {0x8d740015,0xd5b801ec,0xdb0b2171,0x0000006a}},	//   راكا, ilā_, logé,
  { {0xdecb11f3,0x63af0bba,0x61e90045,0x2396003d}},	//   _гугл_, nocn, ţelu, bāju_
  { {0xd5b80048,0x2bcc005d,0x8afd0046,0xd94510b3}},	//   klā_, ़ग़ा, _hořk, дели
  { {0xeab00029,0xbddb0152,0x99670457,0xa2c2000b}},	//   دعم_, _frèr, ятел, रेट्
  { {0x1866006b,0xab95005e,0x39452172,0xa9040015}},	//   дащи_, _живі, _vals_, ربون
  { {0x85e90036,0x0058000a,0xe1ff0144,0x61ed2173}},	//   одив_, לשות_, nyós_, _otal
  { {0xdb1b0092,0xe7080087,0x39450251,0x6d472174}},	//   _thuâ, ستين_, _tals_, _kaja
  { {0x4917005d,0x6d47013c,0xd5e80058,0xddcd0535}},	//   _नाटो_, _jaja, أعين_, jzaż
  { {0x6d472175,0xf8750087,0x61ed2176,0x6fbf000b}},	//   _maja, _تهاج, _atal, ्षां
  { {0x98a70046,0xe705002b,0x18980058,0x0000006a}},	//   zeně_, _آسای, _عضلة_,
  { {0x1c1f005d,0xc4470086,0x645c008c,0xa50904bc}},	//   मंडल_, زیکن_, ärir, _дела_
  { {0xdb0b01d1,0xc7b90030,0x2396003d,0x6d472177}},	//   llgä, llő_, vāju_, _naja
  { {0x2bd9005d,0x61ed2178,0x6fd6005e,0xa3660015}},	//   _बंगा, _etal, діац, _يُتو
  { {0x23960048,0xe3b70063,0xe29a2179,0xd36f0015}},	//   tāju_, _общ_, _май_, _نهى_
  { {0xdfcf0015,0x6d471785,0x661b008c,0x2d930600}},	// [3d80] شيك_, _baja, nuuk, fixe_
  { {0x7ae9001c,0x41da000b,0x78a40061,0xf1da000b}},	//   _afet, _यूएस, şivi, _यूएन
  { {0x515b0008,0x200501cb,0x6d470844,0xfc320015}},	//   _וכיו, álit_, _daja, ضحا_
  { {0x7d070014,0xeb970511,0xc7b90030,0x661b0601}},	//   térí, мих_, jlő_, kuuk
  { {0xb9b60067,0x09e3217a,0xf1bf0030,0x6f0402ac}},	//   ومصع, вочн, ktál_, maic
  { {0x7ae903af,0x6443016f,0x27380092,0x6f04217b}},	//   _efet, _osni, _ẩn_, laic
  { {0xf1bf0030,0x8c43004a,0xd197004f,0x7ae901e0}},	//   dtál_, _иере, וכסי_, _ffet
  { {0x8b95042b,0xf60a004a,0x8b260033,0x6d4709df}},	//   _зруч, охой_, _ідзе, _zaja
  { {0x6d47003f,0xe6030015,0x661b02f2,0xa926096d}},	//   _yaja, نِيَ, guuk, _одал
  { {0x6286066f,0x19c30033,0x61ed0061,0xa5bd0091}},	//   dzko, _абум, _rtal, ltųj
  { {0xc953039e,0x986a0015,0x443e0079,0x245802a3}},	//   _שמע_, _بحذف_, uwt_, чань_
  { {0x753a018b,0x93bd0011,0xd5b80024,0x938b00fd}},	//   setz, ptăm, slā_, існа_
  { {0xc6760115,0x66760018,0xf8e2000b,0x914b006b}},	//   _تطاب, _تدار, _पलाय, очва_
  { {0x76bb000a,0xb6bb000a,0xdb0b2171,0x0000006a}},	//   _ומדפ, _וצדי, rogé,
  { {0xdb0b01d1,0xd48f0036,0x4f6b06ff,0x6d47217c}},	//   llgå, _рр_, ошам_, _raja
  { {0xbed50004,0x4f940054,0xdfd00015,0x6d47217d}},	//   еобј, врђу, ليّ_, _saja
  { {0x6286005c,0x6d47217e,0x5d55017a,0x61ed217f}},	// [3d90] czko, _paja, нкат, _utal
  { {0x20050014,0x71750029,0xc05b0036,0x3d19000b}},	//   ális_, _أهدا, _дім_, दलें_
  { {0x6d472180,0x5b1506ac,0xe521000b,0x9be402a3}},	//   _vaja, емет, _मासि_, вічк
  { {0x4fc7008f,0x501a0008,0x6d470375,0x8afd0046}},	//   _існа, _צורו, _waja, _koři
  { {0xa3c2005d,0x34bb000b,0x3df401b7,0x63660077}},	//   ्गत_, _उर्द, _изяс, _cóny
  { {0x7d0a002e,0xc4c60015,0xda78004a,0x661b008c}},	//   ófst, _مْ_, ьях_, vuuk
  { {0xb8040015,0x88bc0046,0x3cf80015,0x8804012c}},	//   نبيه, _sběr, _تعُد_, نظيم
  { {0x8bc40010,0xf7710021,0x7d050061,0x661b008c}},	//   _асуд, طاب_, lahs, tuuk
  { {0x9f510014,0xf65100e6,0x4a5502e1,0x0a150087}},	//   lszó_, ائب_, _якас, _سواح
  { {0x88c70015,0x44650004,0x661b01be,0xaaa8000b}},	//   _قتال, евов, ruuk, _छुटक
  { {0x5fdb005d,0x661b00f2,0xc7b900dc,0xf1bf163c}},	//   _मंगल, suuk, plő_, rtál_
  { {0xf1bf2181,0x628601f1,0x8afd005a,0x644302dc}},	//   stál_, tzko, _boři, _vsni
  { {0xe2920029,0x59c4000b,0xf1bf0030,0xf2e7002b}},	//   اذج_, _लीडर, ptál_, رکيه_
  { {0x23960048,0x3d19000b,0x64a52182,0x66090072}},	//   tājs_, दलों_, _пала, msek
  { {0xe4e40036,0xb4640029,0x98be0011,0xa06a2183}},	//   _річн, _لديه, _iată_, чава_
  { {0x22520134,0x42260a23,0x23690015,0x3eb90827}},	//   _tryk_, _здив, _يحيي_, _byst_
  { {0x539b013a,0x2fd90026,0x9f58002d,0x639b000a}},	// [3da0] _מיקו, _disg_, osrú_, _מסקנ
  { {0xbd460015,0x66090473,0x3eb90034,0x6f042184}},	//   عناي, isek, _dyst_, saic
  { {0x6026008f,0x2b58002b,0x6b822185,0xc0960058}},	//   _ядна, ویسد_, thog, _سجدت
  { {0xe29f002e,0xc05300f3,0x60c10061,0x3b860033}},	//   laða_, _עזר_, ülme, элег
  { {0x6b820111,0xbaba0029,0xcb070029,0x63a4003f}},	//   rhog, أداء_, ريون_, _mjin
  { {0xe8940f54,0xe29f001a,0x20180034,0x66092186}},	//   каль, naða_, orri_, dsek
  { {0xc173000a,0xcdb7000a,0xdca60054,0x6d5c0123}},	//   רחו_, _נפלה_, _чави, _inra
  { {0x9634032e,0x175409ef,0xf093000a,0x9c0b0c44}},	//   вниц, твия, טנו_, _מִמִ
  { {0x98be0045,0xe29f001a,0xe9a60033,0x6609078a}},	//   _bată_, kaða_, _заап, gsek
  { {0xa4d400fd,0x3633006e,0x557402ed,0x0000006a}},	//   копі, اريس, тгот,
  { {0x98be04f9,0x38610012,0x0d97000a,0xd49a1ebd}},	//   _dată_, ährt_, תכים_, яри_
  { {0x889b0008,0x69da2187,0xc6a60004,0x8afd0046}},	//   _צבאי, _hite, _прли, _poři
  { {0x2fd90026,0x69da0eca,0x98be0045,0xd1bb0015}},	//   _risg_, _kite, _fată_, كاسا_
  { {0x865b000a,0xe29f001a,0x8a7b004f,0x65940138}},	//   _מדדי, gaða_, לאכת, _шалу
  { {0x69da2188,0xf1bf00dc,0x65750030,0x5f950004}},	//   _mite, lták_, özhe, вивт
  { {0xddd6002a,0x94bb000a,0x69da2189,0x6d5c02ad}},	//   czyź, _ממות, _lite, _anra
  { {0xa3e4000b,0xf1bf0030,0x69da016e,0x03d8000a}},	// [3db0] _भूत_, nták_, _oite, _אוהם_
  { {0x63bd00c0,0x69da218a,0xe29c000a,0x2fd90034}},	//   llsn, _nite, _משחר, _wisg_
  { {0x61d60008,0x8c590029,0x320b005c,0x7c590015}},	//   _שותף_, بلاء_, lscy_, بلار_
  { {0x3f67005f,0x3b640063,0x7d0a001a,0xf1bf0030}},	//   _чтоб, лъчв, ófsr, kták_
  { {0x9f510014,0xaa450080,0xc334000a,0x69da218b}},	//   sszó_, телл, טוף_, _bite
  { {0xf1bf00dc,0x6609007c,0x442c003d,0x69da218c}},	//   dták_, vsek, ktd_, _cite
  { {0xdb0b0467,0xd8220036,0xa9660063,0x98be0011}},	//   logí, адщи, тища_, _rată_
  { {0x905c0008,0x6609187b,0x69da06ad,0x70de000b}},	//   לכות, tsek, _eite, _मल्ल
  { {0x6e2d0c5c,0x6609008c,0x320b002a,0xf1bf0030}},	//   ntab, usek, jscy_, gták_
  { {0x17fb0029,0x63a400dd,0x13e90080,0xd5ae0015}},	//   _فرصة_, _sjin, ммой_, يفي_
  { {0xd6ab0086,0xe29f002e,0x98140086,0x1956000a}},	//   _کدام_, vaða_, _مبنا, _שבעל_
  { {0xb8f4005d,0x6e2d218d,0x9cd6000a,0x91e6218e}},	//   से_, ktab, כותה_, коме
  { {0x69c8022d,0x4393008f,0xe29f002e,0x247c0092}},	//   _yhde, раўс, taða_, ảm_
  { {0x29070705,0x10a6004a,0x61460054,0x6e2d218f}},	//   nana_, вигн, њева, dtab
  { {0x25b60029,0xe29f001a,0xf992000a,0xa988000a}},	//   _جهود_, raða_, ברם_, תָרִ
  { {0x7e76022d,0x63a4003f,0xd00f0015,0x7bc90034}},	//   tyyp, _ujin, غلق_, _nheu
  { {0x29072190,0x79810034,0xe29f001a,0xfce61d9e}},	// [3dc0] kana_, _ollw, paða_, возо
  { {0xed5a005e,0xf0ba002b,0x290712fc,0x0000006a}},	//   ьоз_, _يادش_, jana_,
  { {0xe6be005d,0xf1bf00dc,0xcb6a0001,0x6e2d2191}},	//   _ऊर्ज, zták_, маже_, atab
  { {0x79810176,0xe3b90061,0x69da2192,0x91e10065}},	//   _allw, ltır_, _site, _गूँज_
  { {0xdb150014,0x61e40152,0x290705e0,0xae1e000b}},	//   óbál, _juil, fana_, यूशन_
  { {0x644f03eb,0x91660092,0xdc130064,0x61e42193}},	//   ācij, _bổ_, ağıt, _muil
  { {0x26c000df,0xf8030010,0x98a50007,0x91660016}},	//   _šio_, ачын, _dalį_, _cổ_
  { {0xf1bf0014,0x78ba04af,0x320b002a,0xc7c60099}},	//   tták_, _vytv, yscy_, њски
  { {0xe3b901e2,0x09e6065e,0x49ba0029,0xcf9304dc}},	//   ktır_, _розн, _قائد_, יטה_
  { {0x69da0384,0xf1bf0030,0x98a50091,0x29072194}},	//   _uite, rták_, _galį_, cana_
  { {0xf1bf00dc,0x9d1b0135,0xad1b00f3,0x320b002a}},	//   sták_, וויט, וויר, wscy_
  { {0x61e4003e,0xc8840064,0xf1bf0030,0x87250015}},	//   _buil, ışı_, pták_, _معهم
  { {0x645e0089,0x98be0870,0xc7d7000a,0xc56a0015}},	//   _špid, _datą_, _סודי_, _يحتل_
  { {0x3f82008c,0xc10500c3,0x320b002a,0x2454006e}},	//   _alku_, طوري, rscy_, _منتس
  { {0xb33b001c,0xf484002b,0x20d40015,0xda080016}},	//   ança, _حاشی, لتفج, hỏ_
  { {0x8d74002b,0xe3b90061,0xdce70046,0x61e40125}},	//   یالا, atır_, _pojď, _fuil
  { {0xdfd8010f,0x98ae002a,0x61e40f4b,0xa3c2000b}},	// [3dd0] тър_, refę_, _guil, ्गर_
  { {0xbbcb005d,0xdce70024,0xbcf4005e,0x6e2d2195}},	//   िष्क, _bojā, ипущ, rtab
  { {0x6e2d2196,0xc172000a,0x82b4002b,0x61e40079}},	//   stab, _החי_, _محیط, _zuil
  { {0x90560008,0x9986005c,0xdd030064,0x29072197}},	//   _עברו_, proś_, ırın, wana_
  { {0x91660092,0xee870080,0x8f1a000a,0xde64006b}},	//   _sổ_, _рыно, _אורת, _кърп
  { {0x9aa40029,0xa9240036,0xaa560029,0xc27c000f}},	//   جمهو, иділ, الوا_, ורדי
  { {0x0138013a,0xdd940010,0x29072198,0x7bc92199}},	//   דרות_, _тары, rana_, _theu
  { {0xd7750015,0xcb690067,0x2907219a,0x394c219b}},	//   طابع, _ثمره_, sana_, _eads_
  { {0xff5f0034,0x2907219c,0x9599219d,0xa6650058}},	//   _nhîm_, pana_, етну_, اطعو
  { {0x91660092,0x394c0024,0x61e4053a,0x8934006e}},	//   _tổ_, _gads_, _ruil, _نعما
  { {0xa3c2000b,0x61e40125,0xb8e9000b,0x9475006e}},	//   ्गल_, _suil, ोध_, ادخا
  { {0x2905219e,0x8c1a0008,0x8c36000a,0x63860054}},	//   _hela_, עורי, נטרס_, угма
  { {0x22490014,0xf7d60008,0x96280015,0xe3b90061}},	//   _csak_, _עונש_, _لكنك_, ttır_
  { {0x869a0053,0x95840010,0x569a004c,0x05790015}},	//   _אינז, _кліе, _אינצ, _سمعة_
  { {0xa5da0053,0x75340030,0xf992000a,0x84440015}},	//   _אַהי, égző, זרם_, _نخيل
  { {0x661b016f,0x61e40c1b,0x8afd0089,0xdfa50015}},	//   oruk, _tuil, _mořs, لحقي
  { {0x733b00b2,0x1fa720ae,0xbc6a002b,0x8d1a002b}},	// [3de0] _טעקס, укти_, کمان_, فزار_
  { {0xa3e7000b,0x2905016e,0x5bdc000b,0xce470033}},	//   _बढा_, _nela_, यद्व, ызуе_
  { {0x2d8300bd,0x8236002b,0x9f4e0030,0x0000006a}},	//   _dlje_, _شرکا, ínók_,
  { {0x501b013a,0xd9cc005d,0xa09b0053,0x7dc2002c}},	//   _אוטו, ाष्ट, _טייט, pôso
  { {0x8e7607c1,0xf1a9002b,0x2fc00a3a,0x394c219f}},	//   _сунч, _سایه_, mlig_, _pads_
  { {0x2905038d,0xfce30a2c,0x82d70053,0x3cec00dc}},	//   _cela_, _горо, אונג_, _üdv_
  { {0x17f7003b,0x8cd3000b,0xbbe90015,0x981300c3}},	//   هرية_, भेदो, _لرقم_, مبيا
  { {0xa3e7005d,0x6d4e21a0,0x2fc0153c,0x466a0120}},	//   _बढ़_, _haba, nlig_, ером_
  { {0x2905002e,0x6d4e1640,0x2fc018b7,0xf1b4000b}},	//   _fela_, _kaba, ilig_, ंकान
  { {0x1637003b,0x6d4e013c,0x186a0aed,0x2fc00012}},	//   اسية_, _jaba, _пази_, hlig_
  { {0xcdb70008,0xc4450086,0x6d4e21a1,0x97260029}},	//   רפיה_, لیون_, _maba, _مفاو
  { {0x2d9a0045,0x6d4e21a2,0x2fc007a3,0xb3870015}},	//   hipe_, _laba, jlig_, اجده
  { {0x518721a3,0x2fc0153c,0x228421a4,0x0000006a}},	//   гува, dlig_, бург,
  { {0x2249018c,0x6d4e1c3a,0xa4d4017f,0xe5a3076f}},	//   _vsak_, _naba, _колі, _личи
  { {0x54330029,0xc977000a,0xd5bb000a,0x2fc00034}},	//   _هرير, נגלי_, _רזול, flig_
  { {0x8d770086,0xc275000d,0x6d4e0035,0xb4c2000b}},	//   گارا, _влиј, _aaba, ्धी_
  { {0x6d4e21a5,0x925b0015,0xe3140015,0x80b1000b}},	// [3df0] _baba, _أشعر_, _طبيب, _आँके
  { {0x8d770002,0x261c000b,0x443c007c,0x6d4e21a6}},	//   دارا, _मिनी_, _kpv_, _caba
  { {0x6d4e00df,0xa2d9000b,0x2905013c,0x9af50015}},	//   _daba, _नृत्, _rela_, لكات
  { {0xdb350054,0x661b0061,0xdb0b0030,0x290521a7}},	//   редњ, yruk, fogá, _sela_
  { {0x290503af,0xb4c2005d,0xca490015,0x0ae8005e}},	//   _pela_, ्धु_, ئلته_, удій_
  { {0x09af005d,0xc27c0053,0x3f8921a8,0x2d9a21a9}},	//   टवेय, ערגי, lhau_, cipe_
  { {0xa3e4005d,0xc9840001,0x515c000a,0x8178000a}},	//   _भूल_, ључи, תכוו, רגוס_
  { {0x3f890026,0xf7710115,0x7f4f21aa,0x29050034}},	//   nhau_, تات_, _jacq, _wela_
  { {0x64581ae1,0x3f890026,0xda1c005d,0x6d4e1843}},	//   _arvi, ihau_, _नियत_, _yaba
  { {0xe576004a,0x7f4f01f9,0xe8950138,0x661b21ab}},	//   изы_, _lacq, _казь, rruk
  { {0x2fd20034,0x2fc01e4c,0xf8b1002b,0x7d0701ea}},	//   ymyg_, ylig_, _بکش_, _mejs
  { {0xe72e019c,0x7f4f04ed,0xf6d50033,0xbcb6000a}},	//   _ќе_, _nacq, _кіля, יפתו_
  { {0x3f890026,0xb77a000a,0x87d40015,0xa5f80054}},	//   dhau_, _שאנש, _اغلا, _бечу_
  { {0x7d070089,0x3d0f000b,0x80b1000b,0x644a008c}},	//   _nejs, ाणों_, _आँखे, ämiä
  { {0x6fb60196,0x2fc0153c,0xdfd200c3,0x0478002b}},	//   لمسا, tlig_, قيس_, _ملوک_
  { {0x6d4e0553,0x439300d7,0xbea60033,0x261c000b}},	//   _saba, _мајс, аабк, _मिमी_
  { {0x6d4e21ac,0x93bd0011,0x98be005c,0x0e66042b}},	// [3e00] _paba, rtăt, _datę_, шкан
  { {0x4d630036,0xc27b000a,0x76590034,0x2fc00778}},	//   окув, _סריי, _mrwy, slig_
  { {0x6d4e0005,0x0fda0029,0x93bd0045,0x3137000a}},	//   _vaba, _لبحث_, ptăt, _דנים_
  { {0xfbc30b18,0x93bd0045,0x0b170015,0x3f891a2b}},	//   обхо, ltăr, لقمة_, chau_
  { {0xfce60036,0x7ae40057,0x4efb000a,0x60e50030}},	//   _вого, žito, _בהכו, _átmá
  { {0x93bd0011,0xf1bf002c,0x99d30087,0x59d30015}},	//   ntăr, stáv_, يتوا, يغور
  { {0x76590026,0x31570053,0x0f56000a,0x3f800091}},	//   _arwy, שיצן_, ֹיִם_, okiu_
  { {0x76590026,0x3f800007,0xf1bf0030,0x7dcb0012}},	//   _brwy, nkiu_, ltát_, rüse
  { {0xd0fb014e,0x7bc20089,0x76590026,0xfe36000a}},	//   ्रमण_, mlou, _crwy, ׁרֵי_
  { {0x76590026,0x645802c6,0x96b70054,0x7bc221ad}},	//   _drwy, _prvi, јућу_, llou
  { {0x2ec3014e,0x765900dd,0xc5730029,0x68460015}},	//   _शर्त, _erwy, تطيع, _خَال
  { {0x287b0008,0x76590026,0x93bd0011,0xbcb7000a}},	//   _שנאמ, _frwy, etăr, שפטו_
  { {0x76590026,0x7f4f21ae,0xdd21005a,0x0000006a}},	//   _grwy, _racq, _růži,
  { {0xa63b000a,0xf67b000a,0x7bc20046,0x1167009a}},	//   _סגור, _באדמ, hlou, جلسی_
  { {0x3f890176,0xb4930001,0x7ff70015,0x7d0721af}},	//   thau_, _мишљ, ؤسسا, _rejs
  { {0x04db0008,0x764b0034,0x76590034,0x93bd13d7}},	//   _בקול, _ysgy, _yrwy, drăg
  { {0x3f890176,0x3e070063,0x645d0024,0x7bc20089}},	// [3e10] rhau_, рябв, āsie, dlou
  { {0x93bd0011,0x9e14005e,0x213a01d7,0xb2bc004f}},	//   ctăr, ідхі, _gbph_, _במחר
  { {0x70550074,0x2dd80029,0xc0d5002b,0x8c6721b0}},	//   _انجا, شبكة_, _ديدب, штад
  { {0x8b940036,0x7bc20003,0x9c640015,0x201e006f}},	//   оріч, glou, تهمو, átie_
  { {0x7f3a0053,0x2d8f0152,0x0a6b006b,0x7d070030}},	//   _גערו, èges_, ържи_, _tejs
  { {0x5d85003b,0x9e76000a,0xecf80033,0x7bc221b1}},	//   _السل, _הגשה_, _верш_, alou
  { {0xf1bf0014,0x7bc221b2,0xe739107b,0x6d4521b3}},	//   ltás_, blou, гей_, meha
  { {0x7bc208e0,0xf935002b,0x6d4521b4,0xda09002b}},	//   clou, _گذرگ, leha, _ميره_
  { {0xf1bf0014,0x87240015,0x28f90033,0x99861253}},	//   ntás_, زعيم, _безь_, stoš_
  { {0x27170023,0xc9740029,0xdb020003,0x6d4521b5}},	//   ển_, _والث, nnoî, neha
  { {0x044503e7,0x61f621b6,0xb4e7000b,0x321e002a}},	//   щенн, _styl, _भली_, ątym_
  { {0x76590026,0x03a609ef,0xd36f0015,0xcc3a004c}},	//   _trwy, симо, ّهَ_, נערט
  { {0xf6680074,0xd29a0036,0xd299005e,0xf1bf0030}},	//   _نحوه_, утні_, атрі_, jtás_
  { {0x7bc20046,0xf9870040,0x6729038c,0xdb0b0123}},	//   zlou, سب_, lgej, logä
  { {0x656321b7,0x43f50015,0x33f50015,0xddd6002a}},	//   _innh, _استأ, _استس, rzyż
  { {0x442504f9,0x93bd1354,0x13060001,0x67290509}},	//   mul_, stăr, _узим, ngej
  { {0x442504f9,0xa3b5000b,0x93bd0045,0xf1bf0030}},	// [3e20] lul_, जकर_, ptăr, ttát_
  { {0xf297000a,0x69c30030,0x7c2521b8,0x3257000a}},	//   _לכפר_, jlne, fuhr, _פסים_
  { {0x98a700df,0x8c950036,0x442521b9,0x5177000a}},	//   menė_, орці, nul_, _הגיב_
  { {0x0b1a0029,0x44250011,0x91660092,0xf1bf0f49}},	//   اقشة_, iul_, _hồ_, stát_
  { {0x44250005,0x7ed6002b,0xf1bf0030,0x6d4521ba}},	//   hul_, _دزدا, mtár_, beha
  { {0x7bc221bb,0xda6500e6,0x44250ca6,0x67290030}},	//   slou, تامي, kul_, egej
  { {0x6c86003b,0xa9670e88,0x307a004c,0x7189000a}},	//   _الأم, сија_, טאַנ, יְקַ
  { {0x9c170008,0x65630026,0xf1bf1a4b,0x69c30ba8}},	//   _לחלק_, _annh, ntár_, alne
  { {0xceb30008,0x35f70086,0x5e9b004c,0x4425096f}},	//   ּית_, یرید_, ָביק, eul_
  { {0x442521bc,0x454a09fd,0x67290072,0x0000006a}},	//   ful_, учим_, agej,
  { {0xf1bf0030,0x442521bd,0xb6e6006b,0x8d4b000a}},	//   ztás_, gul_, _люлк, אֲכֵ
  { {0xe29f002e,0x290e003f,0x29c90077,0x6d450030}},	//   laði_, lafa_, núan_, zeha
  { {0x10e7002b,0x9757000a,0x91660016,0x363300c3}},	//   یژگی_, _ליאו_, _bồ_, _فروس
  { {0xe29f0084,0x3d22005d,0x442521be,0x75d30067}},	//   naði_, मलों_, bul_, _فينا
  { {0x442521bf,0xf537000a,0xd818000a,0xd3e90061}},	//   cul_, _הטור_, יֵּש, üştü_
  { {0x53a40292,0xaad9000b,0x7ae400bc,0x290e21c0}},	//   _најб, बेडक, žitj, hafa_
  { {0xf1ab0086,0xd1310029,0x5d990010,0x6b820020}},	// [3e30] _ماده_, _قمة_, акаў_, dkog
  { {0xf1bf00dc,0x2d87002c,0xd7f80045,0x8e140033}},	//   rtás_, óne_, _otă_, ядуц
  { {0x6d4521c1,0xf1bf0077,0x0af90015,0x0000006a}},	//   reha, stás_, لفاظ_,
  { {0x53c9005d,0x23c9005d,0x6d4521c2,0xb09a004f}},	//   रतिश, रतिद, seha, _כיתר
  { {0x2bb10050,0x442521c3,0x398b0293,0xd338000a}},	//   jące_, zul_, _løse_, מראה_
  { {0xb4e7005d,0x2bb1002a,0x61fd00aa,0x89a8005e}},	//   _भले_, dące_, ipsl, бків_
  { {0x44250011,0xb17c0008,0xa3e4000b,0xa2d9000b}},	//   xul_, רטור, _भंग_, नेत्
  { {0xcb340063,0x63ad0297,0xd00c000a,0x442521c4}},	//   _несъ, _njan, נּוֹ, vul_
  { {0x69c3002c,0x1bd40080,0xfa55002b,0x85e90004}},	//   plne, _хотя, _برزگ, јдов_
  { {0xf1bf21c5,0x442521c6,0x63ad21c7,0xfe36000a}},	//   ztár_, tul_, _ajan, קרתי_
  { {0x9346004a,0xe719002b,0x4425007c,0x394721c8}},	//   онне, _نيات_, uul_, mens_
  { {0x44250440,0xc16901ac,0x39470a3a,0x2ed2000b}},	//   rul_, _בח_, lens_, _दृढ़त
  { {0x5156000d,0x0cc6005d,0x442521c9,0x99650046}},	//   отву, _वर्म, sul_, _můžu_
  { {0x442504f9,0x91660092,0x6b891ae8,0xb0fa002b}},	//   pul_, _bố_, _lleg, شفرض_
  { {0x91660092,0xd00a0001,0x6b8920bf,0x394721ca}},	//   _cố_, ребе_, _oleg, iens_
  { {0x82a60036,0xeee70015,0xdf4a0054,0xf2df0034}},	//   _майж, قِّي_, јзад_, rdâr_
  { {0x1dc5005d,0x8fa3000d,0x39470106,0xb6ac000a}},	// [3e40] वतंत, фате, kens_, ְׁבֹ
  { {0x6b8921cb,0xc50c004c,0x50460054,0x7197002b}},	//   _aleg, ָלאָ, _деоб, _ونيز_
  { {0xf1bf00dc,0x2bb1005c,0x7dd01581,0x29c90077}},	//   ptár_, zące_, jäse, túan_
  { {0x39471c01,0xda7a02ed,0x0000006a,0x0000006a}},	//   eens_, иял_,   ,
  { {0xc9f30029,0xe29f002e,0x5f03042b,0xad260015}},	//   وسوع, taði_, _ізра, _ورسو
  { {0x4a530036,0x2d9e0064,0xaa530010,0x394721cc}},	//   ькіс, _öte_, ьвіш, gens_
  { {0x290e0084,0xe29f002e,0x58d30004,0xda0b000b}},	//   rafa_, raði_, мошт, सीबत_
  { {0xc6f8005e,0x8b6600c3,0xb8e2000b,0x907b000a}},	//   щних_, _باسم, _एँ_, יטצי
  { {0x394721cd,0x056a0180,0x8546004a,0x853c0091}},	//   bens_, ајни_, оэне, snėm
  { {0x63ad21ce,0xc9860115,0x2bb1002a,0x394721cf}},	//   _sjan, _بشري, rące_, cens_
  { {0xccf3000a,0xa3e4000b,0x69d80012,0xd6b4002b}},	//   וכת_, _भूख_, mmve, _کشاک
  { {0x27f3002c,0x661d121a,0xf746006d,0x21ef007c}},	//   žané_, šska, _федо, _püh_
  { {0x91660023,0x753d0014,0x290c0020,0xcb13000a}},	//   _số_, ősza, _keda_, ולר_
  { {0x867300ce,0x0000006a,0x0000006a,0x0000006a}},	//   _юліє,   ,   ,
  { {0xcf9b209b,0xdfd50892,0xb7f8000a,0x61d80033}},	//   аја_, зовы, מִּט, імся_
  { {0x3947069b,0xd0fb000b,0x52150180,0xb066007c}},	//   zens_, ्रहण_, _едит, _sfää
  { {0x39470152,0x63bd0077,0x645a06c7,0x30e700ce}},	// [3e50] yens_, mosn, lvti, _мінб
  { {0x6b8921d0,0x91660092,0x7db40029,0x93bd0045}},	//   _sleg, _tố_, وصلا, brăc
  { {0x394721d1,0xc0580036,0x63bd007c,0x6b8921d2}},	//   vens_, _дія_, oosn, _pleg
  { {0xd4910092,0x394700dd,0x61ed1438,0x2d8a21d3}},	//   gày_, wens_, _kual, _elbe_
  { {0x290c00e8,0x61ed0375,0x539c000a,0xd35c000a}},	//   _beda_, _jual, סידו, ידאל
  { {0xa2ce000b,0x61ed12d3,0xc058002b,0xdcee0045}},	//   _सरस्, _mual, _اشیا_, ădăc
  { {0x91660023,0x764202c1,0x98a70024,0xac180001}},	//   _hỗ_, _apoy, menī_, _мору_
  { {0x6b89005c,0x060921d4,0xaba9002b,0xe29f001a}},	//   _uleg, бник_, _اهرم_, laðu_
  { {0xd7060080,0x8f9c0053,0x6d5521d5,0xa3df000b}},	//   чные_, ייהי, _kaza, थगन_
  { {0xdce7005c,0xe29f002e,0xb9980139,0xa3e7000b}},	//   _poję, naðu_, _двух_, बदल_
  { {0x3209003e,0xa2d9005d,0x657c0123,0x99640033}},	//   _away_, नेस्, örha, _ўтул
  { {0x61b4000b,0x61ed01c2,0x883a000a,0x6d5521d6}},	//   ंक्ष, _bual, _לתעו, _laza
  { {0x61ed0467,0xe29f002e,0x91660092,0x0000006a}},	//   _cual, kaðu_, _nỗ_,
  { {0xa6e1002e,0x6d551981,0x321e0057,0xf676004c}},	//   öðug, _naza, čty_, _מײנט_
  { {0x63bd003f,0xd059005e,0x291a0030,0xe1ff03a0}},	//   bosn, орті_, ópai_, apó_
  { {0x7ae4002c,0x73060080,0x09a8000b,0x7ae901d7}},	//   žiti, _эпиз, _औद्य, _nget
  { {0xe29f002e,0x6d5521d7,0x69c121d8,0x91660016}},	// [3e60] faðu_, _baza, _okle, _cỗ_
  { {0xe29f0084,0x6e360091,0x61fb001a,0x6d55160c}},	//   gaðu_, rtyb, íule, _caza
  { {0x717b0008,0x6e360007,0x317b000a,0xb17b000a}},	//   _הניס, styb, _האיד, _הטיר
  { {0x290c0005,0x261c014e,0x441a0053,0xacb30015}},	//   _seda_, _मिली_, מועס, رمنغ
  { {0x6d67002f,0x8e560010,0xba730087,0x6f041801}},	//   áraí, _этні, فاوت, mbic
  { {0x64430298,0xaa570015,0x6d5521d9,0xf806070c}},	//   _opni, ثلها_, _gaza, пчин
  { {0x8c4321da,0xd90d0086,0xdb1b002d,0xf77200e6}},	//   _пере, شین_, _chuó, فاظ_
  { {0x69c101e2,0x6d5521db,0xc053000a,0x6afa004f}},	//   _ekle, _zaza, תזה_, _הִ֑ו
  { {0x6d5501e2,0x290c183c,0x65940033,0x63bd0085}},	//   _yaza, _teda_, дапу, vosn
  { {0x61eb0152,0x1dbe005d,0xe59801f3,0x1e57004f}},	//   _égli, ्तित, ікні_, לשפר_
  { {0x36330086,0x61ed002d,0x61e5002c,0x320900da}},	//   وریس, _sual, _rihl, _sway_
  { {0x60c5022d,0x9582005c,0xd49701b0,0x6e2421dc}},	//   _ryhm, _żąda, яры_, krib
  { {0xe2980010,0x61ed050d,0xe3b00015,0x2bb1002a}},	//   заў_, _qual, ارٍ_, nąca_
  { {0x26db00f3,0x7d0e0012,0xfe7f0034,0x63bd0030}},	//   _הקדמ, _nebs, _sgïo_, sosn
  { {0x63bd00bd,0xe53b039e,0x853b000a,0x6d5521dd}},	//   posn, _התור, _הגוי, _raza
  { {0x4fc40b08,0xb33b016e,0x61ed21de,0x93fb004f}},	//   есуа, biça, _tual, _פלחי
  { {0xe29f0084,0x6d5521df,0x2bb1005c,0x539c0008}},	// [3e70] taðu_, _paza, jąca_, _ליהו
  { {0x27e621e0,0x2bb1002a,0x7ae90034,0x82340058}},	//   _lion_, dąca_, _sget, _أريا
  { {0xe29f002e,0x5c040033,0x645e0085,0x6e2421e1}},	//   raðu_, еяча, _špij, arib
  { {0x60080008,0x8a590024,0xe29f001a,0x69c121e2}},	//   _מִשְ, ņēmā, saðu_, _skle
  { {0x6d55000c,0xddeb0086,0x19950036,0x6e2421e3}},	//   _taza, _درجه_, мадя, crib
  { {0xbd450029,0xd90f002b,0x992b004a,0x2fc921e4}},	//   _تنسي, ایا_, сюда_, llag_
  { {0x2369016f,0xd0f8000a,0x8c420012,0x27f60015}},	//   _onaj_, המות_, ößtm, وفود_
  { {0x69c1005c,0x27e60125,0x7ae90045,0x661d21e5}},	//   _wkle, _cion_, _uget, ásko
  { {0xa3c3005d,0x0f580008,0x6f0f21e6,0x645c21e7}},	//   ्तन_, ליהם_, _mecc, ærin
  { {0x39150086,0x2fc900b8,0x4a54005e,0x25a90015}},	//   _آواز, hlag_, _якус, تدعي_
  { {0xa3e90033,0x7d050125,0xe3b90061,0xa34a06a6}},	//   юдна_, ibhs, arım_, озна_
  { {0x78880029,0x58ba000a,0xf2a602d9,0x29c90030}},	//   _عَنِ_, _ומעצ, димп, kúak_
  { {0x7ae400bd,0xe2970256,0xf772000a,0x6f04013b}},	//   žitv, дая_, _שקד_, vbic
  { {0x94050021,0x7a88000a,0x27e620ca,0x6f1d21e8}},	//   _قوته, פָרַ, _zion_, _adsc
  { {0x04920015,0x2bb1002a,0x7dcb0061,0x91e321e9}},	//   _للوح, ząca_, rüsl, торе
  { {0x201e0085,0x6f0f21ea,0x200400bf,0x6e240bbc}},	//   štio_, _cecc, ďmi_, trib
  { {0x0eaa008f,0x6f0406a2,0x62730015,0x6d5a001a}},	// [3e80] цкай_, rbic, _لهيئ, _ótak
  { {0x6e2416c8,0x93f9000a,0x6f0421eb,0x31e60058}},	//   rrib, ַלְי, sbic, _تسعّ
  { {0x92650086,0x6c4a03c4,0x51f6002b,0x7d0e0085}},	//   _قدیم, تلاف_, _عسکر, _vebs
  { {0x7d05002d,0x5aca21ec,0x7d0e21ed,0x442500da}},	//   abhs, олем_, _webs, irl_
  { {0xda77006b,0x28f80280,0xf8a60065,0xaa5c0138}},	//   дящ_, пель_, गप्प, селi
  { {0x2fc0002d,0x2bb1002a,0x6f0f02f5,0x61eb0003}},	//   loig_, rąca_, _zecc, _ègle
  { {0x19b90010,0xa3c3005d,0x4b260029,0xa2a5000b}},	//   чуць_, ्तम_, _يعرف, _चेन्
  { {0x97a3065e,0x501b000a,0xba1a002b,0x4c9b000a}},	//   крыл, קופו, _ويزا_, _ובלו
  { {0x993a0010,0x9e7b004c,0xcb37000a,0x7791002b}},	//   _мяжу_, ַנטפ, _קאמי_, دینا
  { {0x44980036,0xceb3000a,0x271e0016,0x8a7b004f}},	//   звою_, כיח_, ịn_, _ואמת
  { {0x684601f3,0xe73a07d0,0x29c90030,0x201e21ee}},	//   _інда, _меж_, zúak_, átil_
  { {0x7879000a,0x88c50015,0x69ca21ef,0xdcf501c0}},	//   _מָנו, _أتكل, llfe, _rozč
  { {0xc2cb0015,0x4394004a,0xb7db000a,0x3a2621f0}},	//   تبدل_, таяс, _וקאי, nrop_
  { {0x6f0f21f1,0x3d08000b,0x9583006b,0x66d70030}},	//   _secc, षरों_, _илче, súké
  { {0x656a002d,0x55bb000a,0x14730015,0xe9ce0033}},	//   _infh, _ומגו, _لايج, ыкi_
  { {0x442c0176,0x93780029,0xa857000a,0xbfab0033}},	//   mud_, _يصير_, וילה_, ітве_
  { {0x6f0f04ed,0x442c21f2,0xa7fc0061,0x63a80144}},	// [3e90] _vecc, lud_, _yrıc, èjne
  { {0x6da40001,0x2fc921f3,0x69ca0030,0x2c8b0015}},	//   виђа, slag_, jlfe, يئاً_
  { {0x442c21f4,0x2fc900cb,0xdda4006f,0x91b80058}},	//   nud_, plag_, _žňú_, _تطير_
  { {0x291e00dc,0x61fb0011,0xad9b1ad6,0x69ca21f5}},	//   _adta_, ţulu, _stúd, elfe
  { {0x6a670015,0x4efa000a,0xa9691a9d,0x314b000a}},	//   بطال, _מהרו, зила_, ַתֵּ
  { {0xdb0b002d,0x442c21f6,0x7dd00123,0x6e2d0003}},	//   ingé, kud_, läsn, muab
  { {0x6e2d003e,0xb8f7005d,0x645c001a,0x442c21f7}},	//   luab, _सर_, æril, jud_
  { {0x442c0005,0xa2f9000b,0x06090973,0x6be50058}},	//   dud_, ंडोज_, пник_, _أكرم
  { {0x645d003d,0x67260030,0x6e2d0077,0xed55000a}},	//   āsim, ókja, nuab, ֲבֹר_
  { {0xe5710029,0x20fb000b,0x442521f8,0x7bcb21f9}},	//   اطة_, ्रोश_, trl_, llgu
  { {0x290700bd,0x442c21fa,0xd4691179,0x98a70007}},	//   mbna_, gud_, чине_, menį_
  { {0xb902005d,0x6e2d007c,0x0000006a,0x0000006a}},	//   ने_, kuab,   ,
  { {0x2bb7000b,0xc604005e,0xe7980369,0xb383066a}},	//   _अदना, _азій, _تخلص_, улял
  { {0x442500bc,0x201e0085,0x442c0c6b,0x6e2d21fb}},	//   prl_, štim_, bud_, duab
  { {0x2bb1005c,0xdc320024,0x75d200e5,0x1beb000b}},	//   jąco_, kļāv, _حيوا, _जंगल_
  { {0x3f890375,0x49060157,0xdee6027c,0x25a50072}},	//   gkau_, _स्नो_, еоби, lill_
  { {0x4d660010,0x6e2d21fc,0x8d660033,0x25a50125}},	// [3ea0] нкав, guab, нвае, oill_
  { {0x7dc60086,0x25a521fd,0x7afb003f,0xb2bb000a}},	//   رقان, nill_, _afut, _ממפר
  { {0x10a60036,0xf1bf00dc,0xcb0a0015,0x3137000a}},	//   _чинн, orán_, كيان_, _אריך_
  { {0x7c230125,0x25a521fe,0x63a60d57,0x6e2d21ff}},	//   ánra, hill_, nikn, buab
  { {0x6f63005f,0xbd8a0029,0x25a52200,0xf1bf0077}},	//   _связ, _فنحن_, kill_, irán_
  { {0x6f160064,0xc213000a,0xdca62201,0xedd60067}},	//   layc, נהו_, _заги, _سيزد
  { {0xfdbe005d,0xd7f10092,0x07e60001,0xbf9a000a}},	//   ्तीफ, _cũ_, нцим, ּיִש
  { {0x442c2202,0x4c3b000a,0x93bd0045,0xb33b016e}},	//   vud_, _מתלב, stăz, viço
  { {0xf1bf2203,0xfe36000a,0xcf93000a,0x63a62204}},	//   drán_, ׂרֵי_, טטה_, dikn
  { {0x63a60084,0x38c80086,0xfe370053,0x2e370053}},	//   eikn, _قاضی_, עריי_, עריש_
  { {0x46ea0083,0x442c007c,0x43950129,0xcd97004f}},	//   _еден_, uud_, ванс, גדית_
  { {0xdc8b0008,0xf1bf002d,0x86c60015,0x395c0045}},	//   לְכָ, grán_, _كيان, ldvs_
  { {0x442c21f6,0xdb9b000a,0x25a500c7,0x1634030c}},	//   sud_, לסטר, bill_, _реля
  { {0x66e32205,0x9657000a,0xf1bf1ace,0x442c2206}},	//   _соча, _נשוא_, arán_, pud_
  { {0xc4f700b2,0x10480036,0x23790015,0xe3b0002b}},	//   _אזוי_, няти_, _يمتد_, _گرو_
  { {0x9e95002b,0x6e2d2207,0x3f8f001a,0x394e02ad}},	//   پارچ, tuab, ógu_, hefs_
  { {0xc5f30053,0x8d870080,0xe3b0002b,0x62860123}},	// [3eb0] ָדע_, нужд, _درو_, cyko
  { {0x2249016f,0x3f8901f1,0x0000006a,0x0000006a}},	//   _ipak_, skau_,   ,
  { {0x7c950015,0xeb390033,0xa0740138,0x0000006a}},	//   خلاص, дзеш_, _быўш,
  { {0xa3c3014e,0x501a0008,0x0b580010,0xcbc7002b}},	//   ्ति_, _קורו, ершы_, رزاي
  { {0xdc130064,0xff16000a,0xfbd00015,0x4174002b}},	//   rşıt, _בקרת_, حتل_, _شایس
  { {0x7dcb0020,0xf2d40053,0xf8a9002b,0xc4c60015}},	//   küsi, נעס_, وگاه_, _نْ_
  { {0xa3c3014e,0x3158000a,0xa158000a,0x753d0030}},	//   ्ता_, גיון_, גבוה_, őszk
  { {0x1bd50010,0x7afb003f,0xf77100a2,0x291a001a}},	//   _робя, _ufut, شاب_, ópar_
  { {0x25a52208,0x853c0091,0x63a60085,0xe80d000b}},	//   till_, ynėt, vikn, _सबका_
  { {0xb4650036,0x45850063,0x62862209,0x98bc005a}},	//   вкол, тгов, vyko, nevě_
  { {0xccf20008,0x2c37000a,0x3cfa000a,0x25a5189f}},	//   יכי_, תָ֖ם_, ולתנ, rill_
  { {0xf6750015,0xdb0b002a,0xb5fd00bc,0x87070015}},	//   _لاتخ, mogó, evše, _أبال
  { {0xf770006e,0x25a5220a,0x69c30158,0xdb0b1022}},	//   _دال_, pill_, oone, logó
  { {0x412a0191,0x63a6220b,0xdb000003,0x6286220c}},	//   ього_, sikn, _emmè, ryko
  { {0x03aa0029,0x43860015,0x69c301b3,0x28a7000b}},	//   _يدعو_, _للثق, ione, _केमि
  { {0xe4e40036,0x62660457,0x69c3215a,0xcf260015}},	//   _січн, _авиа, hone, ضرري
  { {0x69c30a5e,0xee3a1393,0x63a4220d,0x59c1000b}},	// [3ec0] kone, ьна_, _imin, शकार
  { {0x69c306f5,0xdb000152,0x661b0e95,0x0d4a0015}},	//   jone, _immé, isuk, بشري_
  { {0x69c3065b,0xc50c004c,0xa7fc0061,0x8db5005e}},	//   done, פלאָ, _arın, усті
  { {0xf1bf0089,0x661b0607,0x6a8600d7,0x7c33005e}},	//   hrál_, ksuk, клеа, реїх
  { {0x63a404ed,0xc333000a,0x3f8c0091,0x69c3220e}},	//   _mmin, שוד_, ūdus_, fone
  { {0x5d78000a,0xe8380033,0x63a402de,0x661b04d1}},	//   _אָֽנ, епкі_, _lmin, dsuk
  { {0x63a4022d,0xd7f80092,0x6d5c002d,0xa96700d7}},	//   _omin, _trăm_, _iara, тија_
  { {0x6d5c220f,0xcc57000a,0x00bb000a,0x58830033}},	//   _hara, _בבלי_, ומצמ, рыша
  { {0x6d5c2210,0x201e0085,0x661b02f2,0x7c3e04a3}},	//   _kara, štih_, gsuk, ltpr
  { {0x63a42211,0x5574017a,0x6d5c2212,0x69c32213}},	//   _amin, угот, _jara, cone
  { {0x19b90146,0x6d5c1027,0xd3710015,0x7c3e2214}},	//   _чуть_, _mara, مهد_, ntpr
  { {0x6d5c20fb,0x23b5002b,0xa7fc0061,0x03c4004a}},	//   _lara, امحس, _yrın, исям
  { {0x86c30086,0x32540033,0x661b0030,0x2bb3000b}},	//   _پيون, авяр, csuk, ंचता
  { {0x02d3000b,0x7c3e2215,0x6d5c2216,0x63a42217}},	//   _सरीन, ktpr, _nara, _emin
  { {0x25ab038d,0xdb1b0092,0xd0100015,0xe5e50015}},	//   ècle_, _khuô, ْلِ_, _إثني
  { {0x63a4005c,0x6d5c0035,0x40340001,0x64580061}},	//   _gmin, _aara, јетс, _isvi
  { {0x6d5e0298,0x93b8000a,0x13b8000a,0x6d5c2218}},	// [3ed0] fdpa, _שלחו_, _שהחל_, _bara
  { {0x5c0702c5,0x3155004a,0x63a41835,0xa3c3000b}},	//   вяда, _своё, _zmin, ्तव_
  { {0x6d5c2219,0x443e221a,0x8fe70015,0x69c3221b}},	//   _dara, ntt_, _لأحم, vone
  { {0xff0402c5,0x69c3221c,0x69c80061,0x1a950033}},	//   _вярн, wone, _akde, лаеў
  { {0xbea40010,0x6d5c221d,0x69c3221e,0x98be0091}},	//   _ваўк, _fara, tone, _katė_
  { {0x644a02de,0x3859004a,0x69c3008c,0xf1bf001a}},	//   _opfi, ерию_, uone, krám_
  { {0xc1740008,0x317c000a,0x6ce4005e,0x2bbb0015}},	//   יחס_, ורגמ, _віте, _قارة_
  { {0xdb1b0092,0x6d5c221f,0x69c32220,0x60c8007c}},	//   _chuô, _zara, sone, üdmi
  { {0x6d5c01e2,0x7f5d1a8b,0xf1bf0030,0x443e2221}},	//   _yara, _masq, trál_, ett_
  { {0x69da000b,0xe4750033,0x7d150030,0xdb0b0314}},	//   _पीपी, гумэ, _jezs, ingí
  { {0x661b2222,0xb936004f,0x0d96004f,0x28380058}},	//   ssuk, _תרעג_, רכתם_, _لأنة_
  { {0xa8220086,0x7f5d0144,0xe29a0b1e,0x79812004}},	//   _اکون, _nasq, еам_, _holw
  { {0x69da0945,0x82360087,0x15452223,0x171a000a}},	//   _yhte, درجا, _белм, _נוסע
  { {0xf6520008,0xcad6000a,0x41b5056d,0x76590034}},	//   _לצד_, טורת_, асст, _iswy
  { {0xb1840089,0x7f5d1650,0x201e0030,0x80e50015}},	//   šťov, _basq, éti_, لأفل
  { {0xd138005c,0x6d5c2224,0xceea0054,0xaf950054}},	//   żą_, _sara, едбе_, ашуј
  { {0xa3c3014e,0x0e66008f,0x85f60053,0x2616005d}},	// [3ee0] ्तर_, ыкан, ָמעס_, पीपी_
  { {0x3c3c0014,0x429b000a,0xad250015,0x6d5c190e}},	//   tív_, _נסיב, لرمو, _qara
  { {0x31570053,0x6d5c2225,0x657c0123,0x1cba0015}},	//   _גיין_, _vara, örhi, رائب_
  { {0x2f560191,0x207b0053,0x93bd0011,0x8bc50036}},	//   _стос, _נאכא, luăr, асід
  { {0x6d5c2226,0xfa670033,0x8337000a,0xaa580054}},	//   _tara, лацк_, ראנס_, тилу_
  { {0xada60001,0x443e2227,0x79810034,0x1db8000b}},	//   _сагл, ytt_, _colw, _आदित
  { {0x764b0091,0x2616000b,0x0f560c44,0x3f822228}},	//   _apgy, पीनी_, ָיִם_, _koku_
  { {0xf0930008,0x3f8200f2,0xa84700e6,0x853c0091}},	//   מנו_, _joku_, اليم_, riėm
  { {0xa91c002c,0x09360070,0x7981002a,0x853c0091}},	//   _voľb, _مراج, _folw, siėm
  { {0xaa930029,0x79810026,0x09e62229,0xae57000a}},	//   _الكث, _golw, _созн, נסיס_
  { {0xdb1b0092,0x48060937,0xa5d7012c,0xdb020046}},	//   _thuô, _спев, دبير_, dnoú
  { {0xe8d7000a,0xdcee0046,0x443e222a,0x395e0c10}},	//   _גובר_, _sobě, rtt_, _hats_
  { {0xdcee0089,0x82a70004,0xeb91000a,0x98f50016}},	//   _pobě, ушне, חָם_, _mản
  { {0x365b0008,0x7dcb0061,0x395e00da,0xc1050058}},	//   _נכונ, nüst, _jats_, شوري
  { {0x43950010,0x20d40015,0x6ff5002a,0x44260015}},	//   _вайс, متفج, _kąci, _إرتف
  { {0x29c9002e,0x998601b2,0xc43b000a,0xe1f0002b}},	//   núar_, spoň_, _נתחי, _کسي_
  { {0xc334000a,0xaaa4000b,0x1ef80015,0x7dcb0475}},	// [3ef0] _הופ_, _खेलक, اعفة_, küst
  { {0x442c222b,0x395e0072,0xa7fc007f,0x0000006a}},	//   ord_, _nats_, _arım,
  { {0x98f50092,0x7f5d0251,0x7dcb0064,0x70fa0008}},	//   _bản, _tasq, düst, _בהתח
  { {0x98f50092,0x442c1d10,0x907a00a3,0xc8ff000b}},	//   _cản, ird_, _סטרי, ॉर्म_
  { {0x6f0d013c,0x2bb80015,0xee87054f,0xfe35004c}},	//   mbac, دالة_, _сыно, _דאָך_
  { {0xda620036,0x395e055e,0xe9d802a3,0x3d95222c}},	//   івщи, _cats_, гкі_, _тигр
  { {0x6f0d2029,0x79810150,0x0138000a,0x4b070033}},	//   obac, _volw, ארות_, _бязб
  { {0x2d83001c,0x6e2d00bd,0x395e00da,0xcff8000a}},	//   _hoje_, orab, _eats_, נצחה_
  { {0x2d830955,0xbb84003b,0x442c0991,0xe616065e}},	//   _koje_, _القي, erd_, ады_
  { {0x68e700dc,0x6d45002d,0x2d830007,0x45d5000d}},	//   _újdo, nfha, _joje_, јцит
  { {0x0445087a,0x7dcb00b8,0x29c9001a,0xddcd002a}},	//   шенн, lüss, búar_, ował
  { {0x23b30015,0xc482008b,0x626619db,0x6e2d222d}},	//   ْمَس, іляк, авма, krab
  { {0x69da005d,0x3f82222e,0x442c00ed,0x31a60015}},	//   _पीडी, _roku_, ard_, لمحف
  { {0xd6260083,0x23af00f2,0x395e0251,0xdcfe0024}},	//   _тоше_, töjä_, _xats_, āvīg
  { {0xc0e60457,0x7dcb0359,0xf992000a,0x660900cb}},	//   ровк, hüss, חרם_, lpek
  { {0xb4c1005d,0x0c760086,0x64411c14,0x221603ae}},	//   ंथी_, یداد, mtli, _кфор
  { {0xf7720008,0x6441222f,0xa3b5000b,0x2e260015}},	// [3f00] חקן_, ltli, ड़कर_, شفاف
  { {0xd24f0086,0xe3b90064,0xddcd002a,0x64412230}},	//   _کنی_, brıs_, ewał, otli
  { {0xed570010,0x6c36002b,0xd7f80045,0x3f822231}},	//   рох_, شفشا, _trăi_, _toku_
  { {0xdcf60064,0xdb0b001c,0x9992002a,0x6e2d2232}},	//   ıcıl, ligê, żdża_, brab
  { {0x395e2233,0x64412234,0x3a200125,0x8e76009b}},	//   _pats_, htli, éip_, _тунч
  { {0xa3dd014e,0x2a150010,0xf84a0036,0x60c90064}},	//   _तीन_, сьцё, вчий_, şeme
  { {0x7dcb0ac0,0xf8370015,0xf7720058,0x0000006a}},	//   rüst, لسيث_, قاظ_,
  { {0x7dcb0005,0xf1bf1a4b,0xddc4002a,0x98f50016}},	//   süst, nuár_, ywiś, _uản
  { {0xd6d72235,0x6441005c,0x98a50061,0x7dcb007c}},	//   ить_, etli, _dalı_, püst
  { {0x80f5005d,0x27ef002e,0x64412236,0xccf1000a}},	//   _आलेख_, _eign_, ftli, ּ֛י_
  { {0xdbe80053,0x442c2237,0xd92b000a,0x7cf7004c}},	//   _פֿאַר_, urd_, _יֵאָ, יזיס_
  { {0x93a7005e,0x291c2238,0x0000006a,0x0000006a}},	//   ршод, lava_,   ,
  { {0x9f4200f2,0xf1bf00dc,0xeb91000a,0x6d450034}},	//   _mikä_, nság_, פָט_, yfha
  { {0xddcd002a,0x6f0d2239,0x629d0030,0x291c223a}},	//   zwał, wbac, rzso, nava_
  { {0xddcd005c,0x64411527,0x1fa7223b,0x6f0d223c}},	//   ywał, ctli, араг, tbac
  { {0xcf980124,0xa3d2014e,0x828b0010,0x291c223d}},	//   ају_, वतः_, _асоб_, hava_
  { {0x291c223e,0xfe700029,0x6d070015,0xd132002b}},	// [3f10] kava_, ودك_, لباق, _کمپ_
  { {0x2b5f0024,0xf1bf0307,0x93bd0045,0x4d98056d}},	//   _sauc_, dság_, grăv, акую_
  { {0x201e0089,0x9af50029,0xccf80054,0x2fd20034}},	//   átit_, مكات, рћу_, blyg_
  { {0xdea10086,0x2d83002a,0x3a751831,0xcb69011e}},	//   _فیزی, _woje_, йлер, ѓале_
  { {0xca490029,0x2d830007,0xf1bf00dc,0x7f76000a}},	//   الته_, _toje_, gság_, _הערב_
  { {0x9f42022d,0x27ef043a,0x98a50061,0xa91c006f}},	//   _eikä_, _sign_, _salı_, _poľa
  { {0x7c95003b,0x6c850029,0xf7710015,0xdb0b0123}},	//   _الأص, _الزم, كاة_, dogö
  { {0x9f970251,0x5ba4034e,0xb0b8000a,0xf0b8000a}},	//   nçà_, _друз, יפוס_, ילור_
  { {0xddd60046,0x291c223f,0x0000006a,0x0000006a}},	//   evyř, bava_,   ,
  { {0xa9280036,0xf9930067,0x644111ef,0xb867002b}},	//   _віце_, _ببر_, ttli, _پائو
  { {0x84580063,0xd5e80015,0xb9c40015,0xd7fb0004}},	//   арят_, جعين_, _بقلي, _руз_
  { {0x7dd0177b,0xad9b001a,0x64412240,0xd886002b}},	//   räsi, _stúl, rtli, _دهمی
  { {0x66052241,0xcad5000a,0x7dd0008c,0xc24300fd}},	//   _упла, מוֹת_, säsi, пняк
  { {0x91030758,0x64410012,0x61460054,0x11da0058}},	//   зпре, ptli, љева, اوسة_
  { {0xdcfc03eb,0xf1bf0030,0xdfd20015,0xaffa0058}},	//   _norā, zság_, كيس_, افرا_
  { {0x4fa30063,0xfe7a0010,0xe4d20002,0xd00f00e5}},	//   писв, лёзы_, _عقيد, علق_
  { {0x67c10048,0x32460029,0xdd8f0086,0xa3bd000b}},	// [3f20] mējd, _انخف, کول_, _आदत_
  { {0x6e2b00dc,0xe3b90064,0x627b0135,0x2eb5005e}},	//   ágba, nsın_, _ענינ, істс
  { {0xcb6a0001,0x6ab0000b,0x25d6000a,0x0fda002b}},	//   лаже_, जप्र, צוען_, _مبحث_
  { {0x201e0007,0xf236000a,0x5ba5005e,0xf1bf0030}},	//   štis_, ֶרֶץ_, оріз, tság_
  { {0xe3b90061,0xab27006b,0x93bd0045,0x291c2242}},	//   ksın_, соча_, prăv, tava_
  { {0x5d860029,0x7d960029,0xda650029,0x4a53005e}},	//   _الآل, _السؤ, غاني, якіс
  { {0xf1bf00dc,0xc86603fa,0x3c78000a,0xcc78000a}},	//   sság_, стли, _דָּב, _דְּר
  { {0xbb43005f,0xf76f0002,0xc7c60054,0xf1bf0030}},	//   _неск, فاً_, љски, pság_
  { {0xd6d0003b,0xf66a0087,0x7f77000a,0xdb0b0003}},	//   بقة_, احبه_, מעקב_, digè
  { {0x7d1e045a,0x0e5b000a,0x6f19002a,0x39990003}},	//   naps, נדיב, ówcz, _pèse_
  { {0x4d7b0053,0x07a60180,0xa4d80432,0x6355004a}},	//   אריע, _лажн, рдну_, овну
  { {0xc7f70008,0x18770008,0x08770053,0x4871002b}},	//   _הזאת_, _לעבר_, _לעבט_, _آگوس
  { {0x7bdb000a,0x2bc9000b,0x82a40033,0x7d1e2243}},	//   טקטו, िकता, заўж, kaps
  { {0x0657004f,0xd657004f,0xc05b00ce,0xe4f2009a}},	//   _לידך_, _לידת_, ліб_, _عقبگ
  { {0x351b000a,0x251b000a,0xbddb0003,0x25d7000a}},	//   _גוונ, _גווא, _opèr, _הוגן_
  { {0xa3bd005d,0xd5b80024,0x69da000b,0x4034012e}},	//   _आदि_, lnā_, _पीसी, џетс
  { {0x88bc0089,0x22590080,0xa3b8002b,0x8237002b}},	// [3f30] _sděl, _типы_, _داور_, _ارعا
  { {0xa3c3000b,0xd5b8003d,0xd578000a,0x23b20091}},	//   ्तक_, nnā_, סָּר, ršje_
  { {0xa91c002c,0xdb0b0003,0x3af5004a,0x9f630030}},	//   _poľn, ligé, оялс, ívók_
  { {0x93bd0011,0x398b0293,0x7c940015,0x60da0061}},	//   crăt, _løst_, أشكا, ütme
  { {0x7f3a0053,0xa91c002c,0xd6c6002b,0xd5b8003d}},	//   _דערו, _voľn, _آق_, knā_
  { {0xa9691411,0x7d1e2244,0x0000006a,0x0000006a}},	//   рика_, caps,   ,
  { {0x2616014e,0x88bc0089,0xab950036,0x8c09000a}},	//   पीसी_, _uděl, _диві, _כִּ֤
  { {0xc864006b,0xd5b8003d,0x5629012f,0x69ca002a}},	//   ятчи, enā_, ажим_, aofe
  { {0x7bcb088f,0x9b880015,0x055502ed,0x67c101ec}},	//   mogu, _انقل_, отня, vējd
  { {0x05a90080,0xdb0b2245,0xdb000030,0xc9840004}},	//   рвой_, digé, _immá, _нухи
  { {0xe3ba0080,0x7dd01897,0x58040015,0xb859006e}},	//   ибо_, mäst, _فولك, _خلاص_
  { {0x3ce1005d,0xfbc9005d,0x42ea2246,0x1c11000b}},	//   _करने_, िकिम, имно_, डीएल_
  { {0x92930033,0xdb0b0003,0x645c001a,0x0000006a}},	//   даўц, rigè, ærir,
  { {0x7dd00a94,0xf9870067,0xb979004f,0x0f120065}},	//   näst, ذب_, ׁנָי, ़र्स_
  { {0x7bcb0005,0xea000092,0x2b4d0107,0x434601b7}},	//   kogu, _đậm_, _obec_, _дейв
  { {0xd00f0015,0x673b2247,0x20051702,0x7dd02248}},	//   ضلك_, nguj, ília_, häst
  { {0x10f60010,0x7dd00437,0x7d1e2249,0x0d861764}},	// [3f40] _мяня, käst, taps, олан
  { {0x5bd2005d,0xe0d20067,0x7dd0008c,0x55b9000a}},	//   तत्व, _يزد_, jäst, ׁמּו
  { {0x6563224a,0xcb0a012c,0x7bcb1756,0x7d1e224b}},	//   _manh, ليان_, fogu, raps
  { {0x2905224c,0xe800000b,0x27f80030,0xa91c006f}},	//   _afla_, _लंबा_, _érni_, _poľo
  { {0xff570008,0x79c60010,0xaaba0015,0xba170015}},	//   _ובכך_, ойдз, جدار_, قينا_
  { {0x291a002f,0xf806224d,0x082a165b,0xaa570021}},	//   úpa_, очин, ации_, تلها_
  { {0x23ca005d,0xf1bf0107,0x7d1c08cf,0x69ca224e}},	//   रवाद, práv_, _iers, rofe
  { {0x65631786,0xc7b90030,0x7d1c224f,0x6f042250}},	//   _aanh, gnő_, _hers, ncic
  { {0xda660087,0x6563001c,0x6e242251,0x7d1c2252}},	//   _بازي, _banh, nsib, _kers
  { {0xe3b90064,0x7dd01b45,0x7d1c1915,0x3e4e003d}},	//   asıl_, mäss, _jers, mētā_
  { {0x3209003e,0x3e4e0024,0x2cfb00a3,0x7dd0177b}},	//   _stay_, lētā_, יליא, läss
  { {0xf1bf0089,0x6b8200dc,0xd49708f0,0x6e242253}},	//   hrát_, njog, юры_, ksib
  { {0xf1bf0107,0x3e4e003d,0x67260030,0x7414002b}},	//   krát_, nētā_, ókju, _کوبا
  { {0x6563001c,0x5bb7005d,0xdb0b0152,0xd2580033}},	//   _ganh, _अद्व, rigé, ццю_
  { {0x3f87000d,0xf20f000b,0xf8ca000b,0x628f002a}},	//   оѓаа, ़ीज़_, िथिय, syco
  { {0x23280001,0xdfd00015,0x489b004c,0x67200085}},	//   _доћи_, نيّ_, בילװ, namj
  { {0xccfb0001,0x7d1c0375,0x59ca000b,0x5d990033}},	// [3f50] аће_, _bers, ाकार, бкаў_
  { {0x79880176,0x93bd0011,0x61c6000b,0x8cb9000b}},	//   _nodw, crăr, लकृष, ्थलो
  { {0x515a0008,0x7bcb0007,0x7dd00ac8,0x6e242254}},	//   _הכתו, togu, väst, asib
  { {0x7d1c09f2,0x6d4e0123,0x67c1003d,0xf1bf1945}},	//   _eers, _ebba, zējb, arát_
  { {0x7d1c0176,0xea000023,0x03d8000a,0x9f7a000a}},	//   _fers, _đảm_, קודם_, _הנרח
  { {0x8dfa013a,0x89a80036,0x4e160008,0xa3dd005d}},	//   _להשת, оків_, _מחשב_, _तीस_
  { {0x63ad0005,0x319c013a,0xf1b40008,0x78570086}},	//   _oman, שבונ, וסס_, تیاز_
  { {0x3858003b,0x7d1c00b8,0x65630035,0x5fbd000b}},	//   تشهد_, _zers, _sanh, ्किल
  { {0x3964022d,0x3e4e003d,0xdb26002b,0x7d050012}},	//   össä_, cētā_, _رولی, ochs
  { {0xda980015,0xe93b0015,0x6606001a,0x7d050012}},	//   _بخفض_, _خسرت_, íkka, nchs
  { {0x6563022d,0xe7190086,0x8d480008,0x8afd0089}},	//   _vanh, _هيات_, חֲרֵ, _zařa
  { {0x6b890079,0x25a2003d,0xf1a9000a,0x6f1d2255}},	//   _joeg, īkla_, _גס_, _nesc
  { {0x8c490064,0x93bd0011,0xc7b200a3,0xa3bd000b}},	//   laşı, trăr, _אבא_, _आदर_
  { {0x6b890026,0xf1bf1772,0x64a514a4,0x6787004c}},	//   _loeg, drás_, _нала, _קאַטע
  { {0x6f1d17e7,0xa06a0063,0x251a01d8,0x3e4e0024}},	//   _besc, щава_, _הוצא, zētā_
  { {0x7d0500b8,0x6fb60029,0xf4940015,0x02460015}},	//   echs, أمرا, _تشهد, _فَبَ
  { {0x59cb005d,0x539b00a3,0xdfcf0067,0xf1bf2256}},	// [3f60] िवार, _ליקו, ايق_, grás_
  { {0x7dd000f2,0x63ad091d,0x75212257,0x6b9b2258}},	//   väss, _zman, nalz, _alug
  { {0xcea90008,0x7dd000b8,0x60fb000a,0x70fb000a}},	//   ני_, wäss, _להיק, _להיח
  { {0x7d1c0050,0x8c490064,0xcdc90053,0x6f1d2259}},	//   _wers, daşı, אך_, _gesc
  { {0x7d1c19f8,0x7988005c,0x98be0007,0x5b2300e6}},	//   _ters, _podw, _patį_, رفول
  { {0x3e4e0024,0xb069002b,0x7dd0008c,0xb60500bc}},	//   rētā_, _اصیل_, räss, _mešč
  { {0x307a0053,0xc1730008,0x3e4e0024,0x6720003f}},	//   מאַנ, תחו_, sētā_, tamj
  { {0x3ce1005d,0xa91c002c,0x6b9b002e,0x9cbb000f}},	//   _करते_, _koľk, _glug, _הצלח
  { {0x98b10024,0xfaa3225a,0x4427225b,0x2d8a225c}},	//   ībām_, _зато, _avn_, _kobe_
  { {0xf64f06e4,0x63ad016f,0x5a9b0008,0x5a63182e}},	//   ائي_, _sman, _השמא, _якуб
  { {0xdcfc005c,0xf1bf001a,0x291e1147,0x5335016a}},	//   _gorą, krár_, _ieta_, мент
  { {0x57fb0008,0xdc8b000a,0xa87b000a,0x987b000a}},	//   _הלאו, צְיָ, _לאבר, _לאבט
  { {0x27070092,0x6f1d03b0,0x69d8225d,0x6fbd0065}},	//   _ống_, _resc, olve, ्कसं
  { {0x16770008,0x67c10024,0xa3dd000b,0x291e0003}},	//   _מגדל_, mēja, _तीर_, _jeta_
  { {0x67c10024,0xdfd5054f,0x94d30033,0xdd1f0046}},	//   lēja, довы, _пошц, tíži
  { {0xbfd90036,0x291e225e,0xf1bf0896,0x94bb000a}},	//   ідає_, _leta_, trás_, _למות
  { {0xddd00089,0x6f1d1722,0x67c1003d,0xe4f6000b}},	// [3f70] _řeši, _vesc, nēja, ूँकि_
  { {0xf1bf00dc,0x7d0500b8,0xe29c000a,0xa2b8000a}},	//   rrás_, uchs, _לשחר, _מפחד_
  { {0x7d0500b8,0xceeb0086,0xac19005e,0x6b9b115b}},	//   rchs, _گردن_, іоду_, _plug
  { {0x8c490064,0x7d0500b8,0xfc300031,0xd72d005e}},	//   vaşı, schs, احل_, _рiше
  { {0x6b890111,0x957c0007,0x5f940063,0x291e225f}},	//   _voeg, rmąj, _чият, _beta_
  { {0xac191174,0x67c10024,0x44250089,0x9e7a000a}},	//   _могу_, dēja, ysl_, _ונשפ
  { {0x246c0089,0x6b8909f2,0x7e6d2260,0x99d4002b}},	//   _něm_, _toeg, lvap, رتها
  { {0xefc80092,0x69d82261,0x409c000a,0x060900d8}},	//   _địch_, alve, מבוס, оник_
  { {0xb6590036,0xbbc9000b,0x291e2262,0x7e6d04f8}},	//   іших_, िकीक, _feta_, nvap
  { {0x291e0084,0x1dbf005d,0x4425003d,0xbebb0547}},	//   _geta_, ्वित, tsl_, _geëe
  { {0xb80803c4,0x64a504c2,0xf494004a,0xd5b10016}},	//   _فيلم_, фана, еряю, rí_
  { {0x7e6d0107,0x61c6000b,0x672b02de,0x02460015}},	//   kvap, लक्ष, _udgj, وَجَ
  { {0x644e0064,0x43930010,0x67c10024,0x66240015}},	//   çbir, таўс, cēja, _كروك
  { {0x4a5a000a,0xc692000a,0x68e40046,0xb60500bc}},	//   חדשו, _באד_, řide, _vešč
  { {0xdb0000f2,0x43860029,0x2d8a20ef,0x7e6d0061}},	//   _ymmä, _يلتق, _robe_, evap
  { {0xe3b20029,0x200c0024,0x04560015,0xafe320ae}},	//   _جرت_, īdi_, _آلية_, восл
  { {0x2bb3000b,0xa1c62263,0x4d660033,0x9f400144}},	// [3f80] ूचना, _обид, мкав, rmià_
  { {0xee370036,0x22570086,0x3237000a,0x76490061}},	//   ьну_, _کلید_, _קטין_, itey
  { {0x013500b2,0x1d190036,0x764900f2,0x67c10024}},	//   _אָרט_, яють_, htey, zēja
  { {0x76490064,0xa91c002c,0xcce50015,0x3ebf0085}},	//   ktey, _toľk, رسلي, _žute_
  { {0x65680026,0xfd120015,0x291e2264,0x2d8a2265}},	//   yddh, _لجأ_, _peta_, _tobe_
  { {0x67c1003d,0x957c0073,0x0000006a,0x0000006a}},	//   vēja, rmąk,   ,
  { {0x291e2266,0xfc0300d7,0x8b26009c,0xf54e0016}},	//   _veta_, _апсо, _одве, _bụng_
  { {0x6f160026,0xdb240086,0x67c10024,0x33200144}},	//   nbyc, _سوئی, tēja, _neix_
  { {0xf54e00a7,0xba090015,0x291e2267,0x3946009b}},	//   _dụng_, _فتلك_, _teta_, _онаг
  { {0x67c10024,0x2b440016,0x05ba0015,0x0000006a}},	//   rēja, _hcmc_, تدعت_,
  { {0x6d39000a,0xad37000a,0x67c1003d,0x98ac0061}},	//   הֲרו, וניס_, sēja, _tadı_
  { {0x67c10048,0x6e36005c,0x64482268,0x0000006a}},	//   pēja, kryb, rtdi,
  { {0xe298008f,0x61f70123,0x64482269,0x16370058}},	//   даў_, _pixl, stdi, _قسوة_
  { {0x246c0089,0xf1bf0125,0x41e401f3,0x6e360073}},	//   _těm_, asán_, віса, dryb
  { {0x44a30029,0x10480080,0xd0d40063,0x8557000f}},	//   _لموق, мяти_, воръ, _חשוב_
  { {0x2d8e0012,0x8fa5002b,0x7e6d0123,0xf1bf0030}},	//   öfen_, رمذه, tvap, csán_
  { {0xf2c40033,0x93bd0045,0x7e6d008c,0xdfd8006b}},	// [3f90] _асэн, nsăm, uvap, фър_
  { {0xaad2000b,0xdb0b16ee,0xa5d8000a,0x7e6d019a}},	//   _तड़क, rigí, פַּי, rvap
  { {0x5c040033,0x6e360091,0x7e6d142c,0x0000006a}},	//   вяча, aryb, svap,
  { {0x8f19000a,0x7dcb01d3,0x0000006a,0x0000006a}},	//   _מוֹת, nüsz,   ,
  { {0xdfd1002b,0x89d6002b,0xf54e0016,0xc212004f}},	//   _ليگ_, کوور_, _rụng_, ָ֔ד_
  { {0xfd100086,0xda620a61,0xae1a000a,0xa3e6000b}},	//   _نجف_, увши, _מושכ, _बीन_
  { {0x20010020,0x7dcb0030,0x2bd9002b,0x0b5b0058}},	//   _juhi_, küsz, _فارک_, _وشرب_
  { {0x501c013a,0xd0f804dc,0x7afb00d9,0x1665226a}},	//   קוחו, ומות_, _ugut, евим
  { {0xea000016,0xb8d60157,0x8cb90065,0xf54e00a1}},	//   _đầm_, _चे_, ्थको, _vụng_
  { {0x099b0015,0x7649226b,0x8938226c,0xc48506da}},	//   _بضرب_, rtey, _опус_, елок
  { {0x6f160046,0xf54e0016,0x33200144,0x7649226d}},	//   ybyc, _tụng_, _peix_, stey
  { {0x6e360007,0x67c1003d,0x4c9a000a,0xdcfc002a}},	//   yryb, mējo, פברו, _dorę
  { {0x67c10024,0x659504f7,0xbb3a01ac,0x9599005e}},	//   lējo, _паду, הערי, _нтку_
  { {0x3f8f001a,0x25a80015,0x27ed19ff,0x1545009b}},	//   ögun_, _يدوي_, lmen_, _чекм
  { {0xddc4065d,0xf536000a,0xf992000a,0xf1bf0046}},	//   jviš, _טנסי_, נרל_, psán_
  { {0x273a0064,0xc2460036,0xa2e6054f,0x8e0a0674}},	//   münü_, _зник, _пойд, знав_
  { {0x27ed1024,0x273a0064,0xee3a226e,0x0eaa0033}},	// [3fa0] imen_, lünü_, яна_, чкай_
  { {0x27ed018b,0x5d67067a,0xdca6226f,0xe0d20058}},	//   hmen_, ниум_, нази, _مزج_
  { {0x88bc0089,0xbc6a0015,0x273a0061,0x718b000a}},	//   _jdět, ثمان_, nünü_, _זְכַ
  { {0x67c10024,0xec130086,0xda660029,0xe4a8000a}},	//   dējo, اوند, فاتي, וֹנָ
  { {0xc3330008,0xfeba0018,0xfa33002b,0x4efb000a}},	//   רוד_, _راحت_, هرود, _מהכו
  { {0x7db60029,0x27ed2270,0x2fc002f2,0xa9060015}},	//   _أصحا, emen_, lnig_, ربتن
  { {0xfce32271,0x6b5600fd,0xa3e0000b,0xe872002b}},	//   _боро, _птах, थता_, انبگ
  { {0x2fc02272,0x6d5e0032,0xd8b70015,0xa77400eb}},	//   nnig_, lepa, عدوا_, тлич
  { {0xe60f0086,0x7c3e01df,0x2fc02273,0x6d5e08cf}},	//   یشی_, lupr, inig_, oepa
  { {0x9f4000f2,0x6d5e0553,0xdcfc002a,0x2fc00034}},	//   lmiä_, nepa, _porę, hnig_
  { {0xd6da0086,0x18360015,0x4427005e,0xc445002b}},	//   _کوشش_, _سراح, нцям_, نیون_
  { {0x889b0008,0x67e50030,0x6d5e2274,0xf36706bf}},	//   _משבצ, tóje, hepa, хтон
  { {0xc1eb0033,0x9f40008c,0x7c3e007c,0x6d5e2275}},	//   зьве_, imiä_, hupr, kepa
  { {0xc6b500b2,0x1a9b0053,0x9f4000f2,0x660f002c}},	//   _בלױז_, ליכע, hmiä_, ícke
  { {0xc097002b,0x273a0061,0x6d5e2276,0xc058008b}},	//   رجست, cünü_, depa, ніт_
  { {0x987b00b2,0x25530064,0xc2750180,0x443e2277}},	//   האלט, ağlı_, _алиј, mut_
  { {0x67c10024,0xde58005e,0x443e2278,0x4ea70054}},	// [3fb0] zējo, наті_, lut_, хрва
  { {0x6602022d,0x4e1800e6,0x11d90015,0x5bc9000b}},	//   _muok, عتقد_, _زوجة_, िक्व
  { {0x6602022d,0x443e2279,0xf36b000a,0x7537000a}},	//   _luok, nut_, ּדְּ, תאבד_
  { {0x8048011f,0xc4d30053,0x67c10024,0xdab90015}},	//   _אֲשֶ, אגע_, vējo, وهات_
  { {0xa3c4000b,0x218b000a,0x273a0061,0xa969227a}},	//   ्वत_, ּאֶ֣, zünü_, дила_
  { {0xade5005d,0xbd450115,0x67c1003d,0x6d5e227b}},	//   _कठिन_, _جنسي, tējo, cepa
  { {0x18660063,0xf7710015,0xbc58005e,0x443e227c}},	//   ващи_, لاة_, _парє_, jut_
  { {0x67c10024,0xd7ee0015,0x40ec000a,0x3f890049}},	//   rējo, يكو_, הַחֲ, njau_
  { {0x443e0152,0x64580024,0x61ee0026,0x67c10024}},	//   eut_, _apvi, ymbl, sējo
  { {0x67c10024,0x68e40089,0xd5a3002b,0x273a0061}},	//   pējo, řida, الدی, tünü_
  { {0x443e227d,0x98170015,0x69da000b,0xf9900015}},	//   gut_, _أبطا, _पीटी, _ابق_
  { {0x273a0064,0x98140015,0x6d5e227e,0x0396123a}},	//   rünü_, _إبلا, zepa, троя
  { {0xa2d5005d,0x273a0061,0x443e227f,0xa3c30065}},	//   _युद्, sünü_, aut_, _एआर_
  { {0x3ea90024,0x443e2280,0x8636000a,0x67e5002a}},	//   dzat_, but_, _יאנג_, bójc
  { {0x443e2281,0xdfd200e5,0x61ee108a,0x6fb60015}},	//   cut_, ليس_, rmbl, نمسا
  { {0xa067000d,0xdee6023e,0x3ebf0085,0xbfc32282}},	//   њата_, воби, _žuta_, абск
  { {0x2fc00084,0x6d5e0523,0xa7fc0061,0xdc300046}},	// [3fc0] rnig_, tepa, _asıl, _výče
  { {0x2fcd0844,0xdb0b163c,0x2fc00034,0x6448002a}},	//   čega_, vigá, snig_, łmiń
  { {0xdd10002c,0x0137000f,0x31370447,0xfc320015}},	//   _týžd, _ברית_, _בנים_, شحا_
  { {0x99d30086,0xa3c4000b,0xeb971a3a,0x2d9a00aa}},	//   یتوا, ्वि_, ких_, skpe_
  { {0x9f4000f2,0x443e2283,0x9dba0033,0x7c3e2284}},	//   rmiä_, zut_, _жыву_, supr
  { {0x660200f2,0x7f442285,0x443e2286,0xa2c3000b}},	//   _ruok, lgiq, yut_, रपत्
  { {0x1c390080,0xa3c4000b,0x76590034,0xdcee003d}},	//   _пять_, ्वा_, _apwy, _mobī
  { {0x443e022d,0xf0930008,0x7523003f,0xf76f00e6}},	//   vut_, שנה_, _aenz, قاً_
  { {0xc9660063,0x75232287,0x7bc20046,0x02e1000b}},	//   _ивай, _benz, mnou, _नरेन
  { {0x660200f2,0xdcee0024,0x48b6004a,0x60c90061}},	//   _vuok, _nobī, _ищет, şemi
  { {0x6d3b000a,0x986a0015,0x3d3b000a,0x443e07b9}},	//   ותינ, _تحذف_, וגיס, uut_
  { {0x040d0023,0x443e0375,0x75230079,0x7bc22288}},	//   _hưởn, rut_, _eenz, nnou
  { {0x3f8f002e,0x7e9a0024,0x7bc200da,0x369a0067}},	//   ögum_, _jāpā, inou, _تضاد_
  { {0x7bc20089,0x656a0134,0x65930010,0x443e2289}},	//   hnou, _uafh, _вашу, put_
  { {0x7528005c,0x7bc20089,0x9f35022a,0x31c4006b}},	//   madz, knou, леві, рсяв
  { {0x3ea908e0,0xa8570008,0xc4f7004f,0xd904009a}},	//   tzat_, כילה_, _בזוי_, _ژی_
  { {0x7bc20089,0x9e150010,0x7c2e069c,0x5d55017a}},	// [3fd0] dnou, удзі, _avbr, лкат
  { {0xd256000a,0x80e70015,0x4dd90015,0x7528228a}},	//   _עשתה_, _لأجل, رواح_, nadz
  { {0x9cb50087,0x5b150054,0x93bd0045,0x3ea90030}},	//   دمات, гмет, drăz, szat_
  { {0x09cb005d,0x409a000a,0x75281d08,0x442c0079}},	//   िव्य, _נברס, hadz, isd_
  { {0x1995006b,0xda640015,0xaa040015,0x75281ed5}},	//   ладя, لاوي, لِني, kadz
  { {0x75280048,0xca760086,0xf2d40053,0xf2da004c}},	//   jadz, اموش_, סעס_, ײַנל
  { {0x31580008,0x23d3000b,0x9f590003,0x7528002a}},	//   דיון_, सवाद, _aisé_, dadz
  { {0x7523228b,0x6e2d16d3,0x6f0d228c,0xf7710040}},	//   _senz, osab, ncac, صاب_
  { {0x6d45002d,0xaab7021e,0x4ab7000b,0xf771002b}},	//   ogha, _अधिक, _अधिव, لاک_
  { {0x6d45228d,0x45851b07,0x7528002a,0xceb405bd}},	//   ngha, угов, gadz, ייפ_
  { {0xfbb7000b,0x2d91228e,0xb8670015,0xa91c006f}},	//   _आगाम, _moze_, _جاءو, _voľt
  { {0xe72e0124,0xf77000e6,0x75230586,0xdce71e1b}},	//   _ће_, _وان_, _wenz, _najč
  { {0x69c3038d,0x7523228f,0x92b60015,0x7b060046}},	//   onne, _tenz, احجا, _ústř
  { {0xa06a008f,0x957c0050,0x040d0092,0x3aba000a}},	//   нага_, gląd, _xưởn, תמשנ
  { {0x6e2d01e2,0x6561001c,0x69c32290,0x8fa607f7}},	//   esab, melh, inne, гаве
  { {0x6d4500dc,0xdd110107,0xdfa90067,0xad9b006f}},	//   egha, výši, نطقه_, _stúp
  { {0x9e660086,0x644f0011,0x6e2d2291,0x63a42292}},	// [3fe0] دازن, ăciu, gsab, _ilin
  { {0x52b2005d,0x65610111,0x51661d82,0x63a42293}},	//   ीपीस, nelh, _своб, _hlin
  { {0x7bc20089,0x3076009c,0xdce7006f,0xf1bf0030}},	//   tnou, _супс, _fajč, zsák_
  { {0x3f9e0024,0x6d452294,0xd24f002b,0xba6a0015}},	//   ītus_, agha, _بنی_, فحتك_
  { {0xd00f0074,0x64412295,0x7bc20b62,0x20050046}},	//   _ولی_, huli, rnou, íliv_
  { {0xe894005f,0x63a42296,0xa3e6000b,0x64412297}},	//   иаль, _llin, _बीस_, kuli
  { {0x6441000c,0x7bc20089,0xdd8f0015,0xa8330015}},	//   juli, pnou, _عوف_, معيش
  { {0x75280050,0xa91c002c,0x212a0125,0x2b91002b}},	//   wadz, _poľs, habh_, _ویلس
  { {0x2bb10050,0x040d0023,0x9b930029,0xcf930008}},	//   jący_, _tưởn, _القت, מטה_
  { {0x442c00dc,0x63b60026,0x63a42298,0x4a5b000f}},	//   tsd_, _amyn, _alin, _אדמו
  { {0x75280d55,0xf1bf00dc,0x799b000a,0x200c0046}},	//   radz, ssák_, _רשבס, ídil_
  { {0x75281332,0xdc9b000a,0x97a5005e,0x63a42299}},	//   sadz, גיטל, _кріл, _clin
  { {0x877b0053,0x41b50015,0x7528002a,0x25560015}},	//   _ראדי, لمحر, padz, _منشآ
  { {0x9f49002f,0x301b0029,0x6441229a,0xe452002b}},	//   rmaí_, فترة_, buli, _هفتگ
  { {0xb97b00b2,0xd0840080,0xdb0000dc,0x6441229b}},	//   ענלי, быти, _elmé, culi
  { {0xb4c0000b,0x161b000b,0xd327005e,0x6e2d229c}},	//   ंपी_, पीकर_, _ськи, tsab
  { {0x93fc0008,0xa3c4005d,0x6e2d003f,0x2bb1002a}},	// [3ff0] _אלהי, ्वर_, usab, cący_
  { {0x6fb5002b,0x6e2d229d,0x61fe0034,0x6f0d229e}},	//   _چمدا, rsab, _gipl, scac
  { {0x2dd8003b,0xfd100015,0x6d45229f,0xfb150015}},	//   ابقة_, سجل_, rgha, لواج
  { {0x1604005d,0x6d45002d,0x501a039e,0x656116a6}},	//   रदार_, sgha, _שורו, zelh
  { {0x3ce1005d,0x15f6000b,0x6b620033,0x65610030}},	//   _करके_, ीदार_, ікша, yelh
  { {0x67c10024,0xdd870033,0x69c322a0,0xf9c702ed}},	//   mēji, _сымп, unne, ыщен
  { {0x67c10024,0x0198000a,0x18a50033,0x2bb1002a}},	//   lēji, רכוש_, райм, zący_
  { {0x69da003c,0xd8b80029,0x06550033,0x644122a1}},	//   _ekte, ددها_, атоў, vuli
  { {0x2d9c0014,0x0a150015,0x67c1003d,0x656122a2}},	//   öveg_, _ضواح, nēji, telh
  { {0xe5760010,0xbebb0409,0x63a422a3,0xc97700c3}},	//   азь_, _reël, _slin, _حارث
  { {0xe97a0008,0x0bb50008,0x397a00a3,0x9f970251}},	//   _שנעש, ֹלָם_, _שטענ, nçó_
  { {0x644122a4,0x96750010,0x9cd6000a,0x61fe04d2}},	//   ruli, _выкі, יותה_, _sipl
  { {0x644122a5,0xc243006b,0x8bd6000a,0x656103d4}},	//   suli, оняк, שורו_, pelh
  { {0x1a9a0053,0x463a0053,0x67c10024,0xc0aa0015}},	//   דישע, _יענע, dēji, نازل_
  { {0x3947003e,0x5f060355,0x55ba000a,0x41270004}},	//   igns_, изва, _במסו, росо_
  { {0x201800e8,0x63a40573,0x73fa004f,0x83d30058}},	//   rpri_, _ulin, _בּ֥ו, _ويوص

  { {0x8fa303ad,0x6df60015,0xdf150033,0x61fe22a6}},	// [4000] цате, لكرا, сьсь, _tipl
  { {0x67f500df,0x637b00f2,0xbc1a0036,0x60de006f}},	//   _išju, _tänä, віді_, _typm
  { {0xf53600b2,0x3157103d,0xdd8f00e6,0x913b000f}},	//   שטער_, _דיין_, بول_, _בעיק
  { {0xf4560053,0x54560053,0xba2a002b,0x8bc50033}},	//   ייער_, יסען_, نستم_, бсід
  { {0x67c10024,0xe9800033,0x0000006a,0x0000006a}},	//   cēji, залi_,   ,
  { {0xd8760015,0xc8660015,0x2d8c007c,0x2d9e0003}},	//   لاعب, لطبي, _õde_, _ôte_
  { {0x7c85000d,0x588604f7,0x4c98000a,0x8d5b000a}},	//   _луѓе, рыла, _גֹּא, _שכלי
  { {0x9c170008,0xda660086,0x25a00152,0xc7c6009c}},	//   _כחלק_, _پاري, _œil_, јски
  { {0xd6d00029,0xe895005c,0xfaa322a7,0x09360015}},	//   ثقة_, gółó, _дато, _نراج
  { {0x5e570008,0x1659002b,0xc6f7056d,0xd90e009a}},	//   סייע_, اسيک_, шных_, _غیب_
  { {0x03f90001,0xddcd0011,0x67c10024,0x4d790053}},	//   лној_, lvaţ, zēji, אָרא
  { {0x06560029,0x9cd7000a,0x58bb000a,0xe8d7000a}},	//   _ننصح, שוטה_, _במבצ, _דובר_
  { {0xe7b30015,0xeb91000a,0x8c480061,0x42050015}},	//   _بمند, הָם_, _yuşç, إِسْ
  { {0xc1050029,0x67c10024,0x7e7601b2,0x3ce6000b}},	//   صوري, vēji, dvyp, _करूं_
  { {0x0443000d,0xd57b000f,0x6ff70015,0x54440015}},	//   _дејн, _שָׂר, لسرط, _انعك
  { {0x34fb0008,0x67c10024,0xa4fb000a,0x25a2003d}},	//   _בהוד, tēji, _בלוט, īklu_
  { {0x41e70010,0xa3b8002b,0x8ed80015,0xdc0f0046}},	// [4010] _віна, _خاور_, لذكر_, _věčn
  { {0x67c10024,0x200522a8,0x7ae9002a,0x69d822a9}},	//   rēji, ílis_, _rzet, jove
  { {0x629d00f2,0x69d822aa,0x67c1003d,0x91f40058}},	//   lyso, dove, sēji, _بأيا
  { {0x443e002f,0x67c10048,0xcbd80010,0x67c80046}},	//   irt_, pēji, афіі_, dějo
  { {0x443e018b,0x7b740029,0x629d22ab,0xaa67023b}},	//   hrt_, تطلا, nyso, ртек
  { {0xe9d8022a,0x69d80aee,0xda62005e,0x7ae900bc}},	//   акі_, gove, ївщи, _vzet
  { {0x31580053,0x99990007,0x013801d8,0x1138000a}},	//   ייגן_, _ūsų_, ברות_, שָׂר_
  { {0x1bd40036,0x63bd22ac,0xfc300058,0x0000006a}},	//   _дося, jisn, _زحف_,
  { {0x7ae9016f,0x443e22ad,0xe7680015,0xd706004a}},	//   _uzet, ert_, شحين_, щные_
  { {0x69d81ae0,0x06540033,0x5589076f,0xdc39004f}},	//   cove, ітыў, убом_, ְעָר
  { {0x5fc7000b,0x232a0709,0x7e7b00b3,0x2905013b}},	//   रचाल, лони_, _šupl, _igla_
  { {0x06b8002b,0x88ba000a,0x63bd01d7,0xd7740015}},	//   انیک_, _גזעי, gisn, _وانع
  { {0x68e10134,0x443e22ae,0x87d40067,0x113a0033}},	//   _hyld, art_, _بغلا, лявы_
  { {0xcad60008,0x3d21005d,0xf505004a,0x661b11ec}},	//   מורת_, यरों_, _узко, mpuk
  { {0x3ce6005d,0xa7fc0064,0x443e0085,0x63bd01d7}},	//   _करें_, _arıy, crt_, bisn
  { {0xa3ac005d,0x2a6d00bd,0x24510057,0x6fb60015}},	//   _गति_, _oseb_, mám_, حمرا
  { {0x2005001a,0x32090cf7,0x8eea005e,0x8236012c}},	// [4020] ílir_, _guay_, умав_, _اربا
  { {0x67c115e5,0x0000006a,0x0000006a,0x0000006a}},	//   mēju,   ,   ,
  { {0x67c10024,0x01fb039e,0xdd8f0015,0x7c3e016b}},	//   lēju, _תפיל, عوم_, urpr
  { {0x7f860029,0x7f19005e,0x24510016,0x7ae00034}},	//   _الحن, _віру_, iám_, _pymt
  { {0xca560083,0x19940063,0xdb590036,0xc333000a}},	//   стењ, жаля, рює_, לוא_
  { {0x2002000c,0xddcd0011,0xa898018f,0x443e22af}},	//   _hiki_, rvaţ, иклу_, yrt_
  { {0x247700a7,0xdce70024,0x4991002b,0x6d5c1f86}},	//   _năm_, _tajā, بیلر, _ibra
  { {0xa61403ad,0x501b000a,0x907b004c,0x245114b9}},	//   омич, נופו, רטקי, dám_
  { {0x5ebb00b2,0x8f9b0053,0x69d822b0,0x753c002a}},	//   ָזיק, טיקי, pove, órzo
  { {0xddc40048,0xe5b40010,0x67c10024,0x68e10bfa}},	//   stiņ, ійны, dēju, _fyld
  { {0x629d0026,0x68e10cd8,0xf64f0086,0x24770016}},	//   wyso, _gyld, وئی_, _căm_
  { {0x9f400152,0x629d00f2,0xd2510015,0x443e22b1}},	//   blié_, tyso, ونج_, rrt_
  { {0x63bd0955,0x32090092,0x518722b2,0xe707002b}},	//   risn, _quay_, бува, _اسمی
  { {0x6114078f,0x443e22b3,0xe6c7000a,0x25a2003d}},	//   здру, prt_, _ל֔וֹ_, īkls_
  { {0x68110024,0x1fa70033,0x63bd22b4,0xbebb00aa}},	//   _kāda, браг, pisn, _teëk
  { {0x02a72031,0x68110024,0xc4c5002b,0x60180033}},	//   _гром, _jāda, _بتهو, сцёр_
  { {0x67c1003d,0x7ee7112c,0x877b05bd,0xa3540015}},	// [4030] cēju, сцве, נאמי, _رخيص
  { {0xdcfc0048,0x0e340033,0x76400091,0x2002007c}},	//   _norē, яную, irmy, _eiki_
  { {0x705500e6,0x3156000a,0xa2d5002b,0x7bd9002a}},	//   _بنجا, _ויתן_, _ديکت, towu
  { {0x60080008,0x8f470080,0xe1ff005c,0xf413004c}},	//   _לִשְ, _уход, zwól_, לפע_
  { {0xc3340008,0x245100dc,0xeb900115,0x99f5005e}},	//   פוס_, zám_, عظم_, оякі
  { {0x9f4200f2,0x7bd9002a,0xa2c0000b,0xb077000a}},	//   _ehkä_, sowu, _लेफ्, ֶׂ֥ה_
  { {0x319c00b2,0x67c10024,0x0138000a,0xa3d9000b}},	//   רבונ, zēju, זרות_, ़का_
  { {0x2fc90026,0xd7090080,0x24510057,0x25be0034}},	//   nnag_, шние_, vám_, eitl_
  { {0x05a90036,0xef120008,0xbebb016b,0x6f7a000a}},	//   ивий_, וּת_, _beëi, בְיו
  { {0xdcf50048,0x67c10024,0x24510107,0xd789002b}},	//   _nozī, vēju, tám_, انکو_
  { {0x91660092,0x845801b7,0xd38a08fc,0xa6a8002b}},	//   _lộ_, брят_, айне_, لایق_
  { {0xd8d600b2,0xe8d60053,0x67c10024,0x9f400003}},	//   _וועט_, _ווער_, tēju, plié_
  { {0x6b60002e,0xa2d6006e,0x2451013f,0x6ab70065}},	//   _hágæ, زيست, sám_, _अधोर
  { {0xd3780050,0x64a522b5,0x67c10024,0x7ae600cb}},	//   ść_, _мала, rēju, _økte
  { {0x67c10024,0xe3d60015,0xf8c9000b,0x93bd0045}},	//   sēju, _وتبع, िपिय, rsăr
  { {0x91660023,0xa2d5021e,0x1fa7058f,0x25780030}},	//   _bộ_, _युक्, окси_, rülő_
  { {0x672b03c0,0x44270176,0xa2260086,0xcd360015}},	// [4040] _megj, _hwn_, _برعه, قراب
  { {0xa3c4005d,0x672b00dc,0x25780030,0x8146002b}},	//   ्वक_, _legj, pülő_, _بندن
  { {0x660322b6,0x515b000a,0x7e7d0012,0x200222b7}},	//   _mink, _דכיו, _ersp, _tiki_
  { {0x533700b2,0x6830002d,0x644122b8,0xddce002a}},	//   ַנצן_, _lódá, irli, ódłe
  { {0xadeb005d,0x644100b8,0x7d0d002d,0x298a00d0}},	//   _जीवन_, hrli, íosú, иско_
  { {0x44270041,0x127b0053,0x6d5c22b9,0x2056004f}},	//   _own_, יאנע, _ubra, ַיִל_
  { {0x7afd01b2,0x9939124a,0x7189000a,0x672b00cb}},	//   _ústn, сячу_, מְקַ, _begj
  { {0xaa460036,0x2d9822ba,0x248002c6,0xb09b000a}},	//   _мебл, _hore_, _čim_, ייצר
  { {0x2d980720,0x858a0033,0x44270034,0x3ae8002b}},	//   _kore_, аёна_, _awn_, _طبری_
  { {0x6830002d,0xa2d5005d,0x98bf003d,0x68ed0046}},	//   _códá, _युग्, ūrām_, řada
  { {0x2d9822bb,0x68110024,0x7d7b01d8,0x44270034}},	//   _more_, _tāda, בניו, _cwn_
  { {0x66031220,0x7879000a,0x2d9822bc,0x249e002a}},	//   _eink, _לָנו, _lore_, rytm_
  { {0x2bdb005d,0xdcf50024,0xc7f70008,0xc2c50015}},	//   यकता, _pozī, _וזאת_, سيسي
  { {0xbf9b001c,0xa184054f,0xf5770015,0x660322bd}},	//   _ciên, мысл, _ومنع_, _gink
  { {0x84380029,0x0ffb0029,0x142a005e,0x44270034}},	//   _اكبر_, لعرب_, _тіло_, _gwn_
  { {0x4fc70010,0x644822be,0xa3b80015,0xe3b30021}},	//   ісва, mudi, _واير_, _زرع_
  { {0xdce7005c,0xdefb0080,0x2d980495,0xa6fa000a}},	// [4050] _mają, рыв_, _bore_, בִ֑י
  { {0xe1ff005c,0xd9040086,0xbf9b0092,0x6568002d}},	//   zwój_, _لی_, _giên, nedh
  { {0xbc680015,0x644822bf,0x71f80058,0x0000006a}},	//   يمكن_, nudi, _بريس_,
  { {0xa0880008,0x644802b9,0x80a40015,0x67e50535}},	//   _וְשִ, iudi, _آمَن, rójk
  { {0xc5f80024,0x672b003c,0x1b780029,0x2d9807c6}},	//   kmē_, _regj, تصلة_, _fore_
  { {0x672b002e,0x4efa0008,0x2d9822c0,0x010b000a}},	//   _segj, _להרו, _gore_, ׁלְּ
  { {0x660300df,0x644822c1,0x7e6d00aa,0x6c541e64}},	//   _rink, judi, lwap, _окру
  { {0x600c0643,0x660322c2,0x475802ed,0x2d980160}},	//   בִזְ, _sink, орья_, _zore_
  { {0xba770086,0xdce7002a,0x16620088,0x44270034}},	//   _بازت, _dają, евым, _swn_
  { {0x0d96000a,0x4427002a,0x3f990bba,0x5dba004f}},	//   ִ֛ים_, _pwn_, _losu_, ֶ֖יה
  { {0xbf9b0023,0x6441016b,0xbebb08cf,0xd469004a}},	//   _riên, urli, _geëv, щине_
  { {0x644100b8,0x5695006b,0x4758005e,0x660322c3}},	//   rrli, _нает, _мрія_, _wink
  { {0x66030780,0x28df005d,0x24520086,0x6811003d}},	//   _tink, _पुति, ونیس, _kādo
  { {0xdce7005c,0x6d1b005d,0xf98700e5,0xa696000a}},	//   _zają, _प्लग_, رب_, _מכנה_
  { {0x03a608b0,0x7649001a,0x60260239,0x644822c4}},	//   _нико, luey, ядва, cudi
  { {0xf43a0008,0xc43a0008,0x2d98065b,0xc00322c5}},	//   _התקש, _התקי, _sore_, епск
  { {0xa3d9000b,0x023a0015,0x69ca0034,0x2d9822c6}},	// [4060] ़कर_, _اثبت_, ynfe, _pore_
  { {0xc27b00b2,0xb2bb0008,0x3f8f002e,0x63a600dd}},	//   _פריי, _למפר, ögur_, lkkn
  { {0x319b0008,0x1d190036,0xc19b0008,0x219b0008}},	//   _הבינ, юють_, _השיי, _הביא
  { {0x2d98003e,0xdb0022c7,0x0000006a,0x0000006a}},	//   _wore_, _almá,   ,
  { {0x93bd0045,0x6a13005e,0x2d9822c8,0x09e622c9}},	//   spăg, еміу, _tore_, подн
  { {0xc213000a,0xceb3004c,0x7bcb22ca,0xedd60058}},	//   עהו_, _טיר_, angu, _ريزد
  { {0xb4ea005d,0x68ed0089,0xcfb6000a,0xdce7002a}},	//   _मरे_, řadn, ּלִי_, _pają
  { {0xcc570008,0x6c57000a,0x644810ad,0xa7fc0061}},	//   _מבלי_, _מילא_, vudi, _asır
  { {0xb7130015,0x65680030,0xaa4315df,0x35f41411}},	//   ربيش, tedh, _петл, мпир
  { {0xb21b0084,0x7bc20a72,0x758a004a,0x644822cb}},	//   lvæg, liou, ссив_, tudi
  { {0xe3b90064,0xd91b000a,0xc5f8003d,0x6448014b}},	//   msız_, _הובל, rmē_, uudi
  { {0x644822cc,0xb4cc005d,0x7bc200da,0x64910091}},	//   rudi, _रखी_, niou, džią
  { {0xb2870010,0x36330015,0x0595002b,0x644822cd}},	//   чынк, _كروس, سایگ, sudi
  { {0xddcd005c,0xe3b90064,0x6e3600dd,0xe6c50015}},	//   ztał, nsız_, dsyb, _تتمي
  { {0xf55b0008,0x155b000a,0xf1b00015,0x98a70045}},	//   _הדומ, _הכוב, اءُ_, mană_
  { {0x9473003b,0x3ce0005d,0x5f9400c9,0x98a70045}},	//   _أدوا, _कड़े_, нист, lană_
  { {0x63ad22ce,0xdcfc0007,0x7988003f,0x5d990033}},	// [4070] _ilan, _korė, _ondw, окаў_
  { {0x799a0334,0x0dbb0015,0xedd40015,0x7e6d0547}},	//   _notw, حارث_, ّيْد, rwap
  { {0x515a0008,0x63ad14c5,0x200c0046,0x6811003d}},	//   _וכתו, _klan, ídit_, _rādo
  { {0x7bc20041,0xff250086,0x7bcb22cf,0x79880034}},	//   giou, _تبدی, ungu, _andw
  { {0x799a0176,0x1ee70086,0x63ad003f,0x0f7a000a}},	//   _botw, _روسی_, _mlan, _וארב
  { {0xddcd0050,0xdcfc00df,0xf8a90086,0x63ad22d0}},	//   stał, _norė, يگاه_, _llan
  { {0x7bc200da,0x63ad22d1,0x9f40001a,0xddcd002a}},	//   biou, _olan, omið_, ptał
  { {0x7bc20041,0x63ad042f,0xe6191021,0xbc560069}},	//   ciou, _nlan, оди_, žšíc
  { {0x799a0026,0x68110024,0x0907006b,0x6d4a16ee}},	//   _fotw, _tādo, _ечем, ófag
  { {0x63ad22d2,0xa3e6000b,0x80d6000b,0x31af0061}},	//   _alan, _बीज_, _मुझे, _yüze_
  { {0x69c30ae5,0x67650015,0x8c68000a,0x6b9b22d3}},	//   mine, _يُطل, ִיךְ_, _koug
  { {0x21e400b8,0xdc88000a,0xddcd002a,0x63ad22d4}},	//   höht_, פְתָ, ltań, _clan
  { {0xc7b200a3,0x98a70045,0x69c322d5,0xcb36000a}},	//   _בבא_, bană_, oine, וארי_
  { {0xdcee0048,0x65940010,0x98a70011,0x63ad22d6}},	//   _labā, _пачу, cană_, _elan
  { {0x11d70029,0x28b0000b,0xc0e322d7,0xbf9a0054}},	//   ذوفة_, जनयि, ворк, ођач_
  { {0xa3e6005d,0x2fda0086,0x7bc2003e,0x63ad1a62}},	//   _बीच_, آورد_, xiou, _glan
  { {0x6e360007,0x7bc217ce,0x6f16055e,0x0357000a}},	// [4080] usyb, viou, rcyc, _חיפש_
  { {0xad6600b0,0xcf890053,0x69c322d8,0x6f1622d9}},	//   باره, ױט_, jine, scyc
  { {0x7bc2003e,0xbc6a0115,0x6b9b0493,0xaf0a0015}},	//   tiou, تمان_, _boug, _وقدم_
  { {0x69c322da,0x6b9b1d95,0x799a02f2,0xfaaa002b}},	//   eine, _coug, _sotw, يهاي_
  { {0x7bc20041,0x799a0050,0xe3b90064,0x69c30aa0}},	//   riou, _potw, tsız_, fine
  { {0x6b8900bd,0x69c30c5a,0xda650015,0x497309a0}},	//   _eneg, gine, عاني, кліс
  { {0xec160074,0xaf39002e,0xb4cc005d,0xe3b90064}},	//   _آورد, _óþæg, _रखे_, rsız_
  { {0x17f70029,0x9cd7000a,0xc053000a,0x6b9b22db}},	//   ورية_, _חולה_, דזה_, _goug
  { {0x056a0180,0x98a70045,0xf76f0015,0x49ca006b}},	//   ојни_, tană_, شاي_, _длан_
  { {0xc9860115,0xad760033,0x63ad22dc,0x6a9b000a}},	//   _تشري, звiц, _slan, _ושמנ
  { {0x44380084,0x9f40002e,0x6b9b0003,0x98a70045}},	//   ér_, ymið_, _youg, rană_
  { {0xe7170086,0x03f8002b,0xe3b90061,0xb865012c}},	//   _قيمت_, وژيک_, apın_, _سامو
  { {0xc17b005e,0xd7fb000a,0x57fb000a,0x41e7005e}},	//   оїв_, _והאל, _ולאו, діва
  { {0xa4d40191,0x224b0334,0x6d4b0030,0x661d0046}},	//   _полі, ruck_, őgaz, íske
  { {0xcf9b0292,0x2eed044c,0x98be0061,0x15170015}},	//   оја_, _šef_, _katı_, _غزوة_
  { {0x08770053,0x63ad013c,0x9e090015,0xc43b000a}},	//   ועלט_, _ulan, كيرك_, _ותהי
  { {0x9f40002e,0x6b9b0493,0x24580425,0x69c3008c}},	// [4090] rmið_, _roug, lém_, yine
  { {0xd6570008,0x6b9b003e,0xdce7005c,0x20750033}},	//   וימת_, _soug, _zaję, _злоў
  { {0x645a022d,0x24580089,0x24f40008,0x61e50375}},	//   ntti, ném_, תֶּם_, _ikhl
  { {0x60fa0008,0xcf270086,0xce950063,0x645a22dd}},	//   _מהתק, _تردي, _замъ, itti
  { {0x245801cb,0x645a0079,0x9f050067,0xf1bf0030}},	//   hém_, htti, _سوسو, ppád_
  { {0x68e80176,0x245802d5,0x7d250067,0x7bc00144}},	//   _bydd, kém_, _سفرن, _emmu
  { {0x98be0064,0x853c0007,0xe73902bf,0x6b9b22de}},	//   _batı_, rkėl, пей_, _toug
  { {0x68e80176,0xa69505e6,0x69c322df,0xddcd002a}},	//   _dydd, ерој, sine, stań
  { {0x68e8002e,0x645a22e0,0x59c50015,0x98a7002a}},	//   _eydd, etti, _كيرك, daną_
  { {0x68e80176,0xe895008f,0xd4d90033,0x201c0030}},	//   _fydd, _пазь, зьмі_, _évig_
  { {0x853c0007,0x69c10943,0x64a5011c,0xa3ea0891}},	//   okėj, _imle, хана, здна_
  { {0xe3b203c4,0x61e50509,0x7ae9008c,0x96b90054}},	//   ارد_, _akhl, _kyet, _нулу_
  { {0xda0f005d,0x645a22e1,0x6d55005c,0x76a70015}},	//   ादित_, atti, _ocza, _تحاك
  { {0x765b001a,0x8839000a,0xb636000a,0x245822e2}},	//   mtuy, ּתּו, _טרנס_, bém_
  { {0xe3b2003b,0x2458016e,0xddc40061,0x05760058}},	//   _مرة_, cém_, etiş, _سمية_
  { {0x201e0048,0xafe322e3,0xc1780091,0xc1030015}},	//   īti_, госл, žė_, اوِي
  { {0xc7b20053,0x765b00d9,0x201e0f28,0x0d8603de}},	// [40a0] אבן_, ntuy, ūti_, нлан
  { {0xe1f200e6,0x680a002a,0x7c660040,0xa7fc007f}},	//   _حسب_, _mędr, فاصل, _apıl
  { {0x28df014e,0x315700b2,0xa157000a,0x0b4610cb}},	//   _पुलि, _איין_, _אביה_, енен
  { {0x6d550064,0x501b000a,0x68e81afc,0x69c122e4}},	//   _ecza, _מוטו, _rydd, _amle
  { {0x5b130036,0x5bc500e6,0xab770015,0x2458016e}},	//   уміт, ختلف, عمها_, zém_
  { {0x63af0024,0x98a7002a,0x645a22e5,0x082a0fdc}},	//   ībni, zaną_, ytti, пции_
  { {0xd90d0086,0xab2a0317,0xf8060a24,0x7ae922e6}},	//   زین_, _нова_, нчин, _eyet
  { {0x24580089,0x86260036,0xf0930008,0x69c10030}},	//   vém_, ньое, רנה_, _emle
  { {0x68e80026,0x67c80046,0xdce5003d,0xca8602bb}},	//   _wydd, dějt, mehā, _ягай
  { {0x98a7005c,0x9a3b0008,0xaa3b000a,0x1e57000a}},	//   waną_, _מתמק, _מתמח, עשיר_
  { {0xa4d4022a,0x98a7002a,0xed600033,0x9f420030}},	//   тоні, taną_, угiм_, _ekké_
  { {0x38cb0086,0x645a22e7,0x24580425,0x628422e8}},	//   _عالی_, rtti, rém_, _brio
  { {0x35a60033,0x69c10034,0x62841c77,0xf7730643}},	//   _падг, _ymle, _crio, _תקנ_
  { {0x04940029,0x6578003c,0x22440057,0x67e5002a}},	//   _للتح, _uavh, ámka_, bójs
  { {0x9f35008f,0x62841519,0x33990015,0x0000006a}},	//   кеві, _erio, _ينتج_,
  { {0x8d770086,0xddc40061,0x628422e9,0xc2c50058}},	//   کارا, ttiş, _frio, _ليعي
  { {0xa3de000b,0x9ac40033,0x8afd0046,0x628422ea}},	// [40b0] तकर_, _псiх, _obřa, _grio
  { {0x98b0000b,0x5d540b1e,0xa1150015,0x201e0144}},	//   जनाए, лкут, _جودت, ític_
  { {0x7c670029,0xdb35000d,0xbc380015,0x9f5a0144}},	//   عائل, веењ, فسنا_, _cupó_
  { {0xa03a0053,0x64480064,0xe9a9002b,0xe2c8002b}},	//   _קערפ, irdi, ژگان_, _آویو_
  { {0xbf360008,0x7d2400dc,0x853c0007,0xf8c9000b}},	//   _בארץ_, ítsé, rkėj, िप्प
  { {0x89a80036,0xc27c000a,0xdb070030,0xdced0061}},	//   нків_, פרוי, _ámít, şkın
  { {0xa3e1000b,0x6811003d,0x0000006a,0x0000006a}},	//   थवा_, _kādi,   ,
  { {0x765b0061,0x49bb002b,0x7c2522eb,0x46190138}},	//   ttuy, _کارد_, mphr, мцоў_
  { {0x200b0011,0xba5500d7,0xf1e1000b,0x7bd80003}},	//   _mici_, _швај, पकान, évue
  { {0x3ce6005d,0x69c10012,0xeaf8006e,0x4af6002b}},	//   _जुडे_, _umle, _سرقت_, _شکند_
  { {0x7c250125,0x6f1d0079,0x5f9402ed,0x478b011e}},	//   nphr, _ofsc, ни́т, _нсдм_
  { {0x200b04f9,0xe72e023e,0x680a002a,0x628422ec}},	//   _nici_, _ње_, _wędr, _prio
  { {0xe2971561,0x27ff22ed,0xe756002b,0xb4ca000b}},	//   вая_, mmun_, _شلوغ_, लपॉ_
  { {0x200b22ee,0x6f1d0111,0xc60d005d,0x27e002c6}},	//   _aici_, _afsc, सदीय_, čine_
  { {0xcfaa0086,0x200b016f,0xddd60057,0xc0e60c71}},	//   وارم_, _bici_, jvyš, товк
  { {0x9f4f002e,0xf456000a,0x613f0061,0x27ed00a6}},	//   ögð_, _סיפר_, _açlı, nlen_
  { {0x27ed22ef,0x93fb000a,0x7649001a,0x8e0a06b3}},	// [40c0] ilen_, _קלפי, nrey, днав_
  { {0x27ed018b,0xa2f7000a,0xac9a0015,0x1d190033}},	//   hlen_, _במפה_, ونذا_, еюць_
  { {0x6c330015,0xed572205,0x27ed22f0,0xcc8a0015}},	//   لفلا, тох_, klen_, بناه_
  { {0xe6270092,0xfba9005e,0xac450015,0x27ed22f1}},	//   _phố_, нтій_, ائله, jlen_
  { {0xeef50033,0xda77006b,0xddd6006f,0x27ed22f2}},	//   _бярэ, вящ_, avyš, dlen_
  { {0xdb0b002e,0x28f8007a,0xa2bb000a,0x8025002b}},	//   rigð, нель_, ומנט, _جریم
  { {0x27ed0026,0x5f19000b,0x186700af,0x660a22f3}},	//   flen_, युक्_, ваји_, _rifk
  { {0x27ed22f4,0x76490064,0xcc77000a,0x6448128d}},	//   glen_, frey, _בעלה_, vrdi
  { {0xb8e9014e,0xda6500e5,0xcf93000a,0xf6230054}},	//   _ले_, _مالي, שטח_, адњо
  { {0x6448018c,0x27ff0049,0x05780015,0x4498005e}},	//   trdi, amun_, رمجة_, евою_
  { {0xad370008,0x27ed22f5,0x64480f29,0xa85602d9}},	//   כניס_, blen_, urdi, _штај
  { {0xd5b00074,0xa73a03c4,0x7649002e,0x64480123}},	//   _گفت_, _آثار_, brey, rrdi
  { {0x68110024,0x9f40008c,0xdcf500bc,0x048a002b}},	//   _rādi, iliä_, _razč, سخگو_
  { {0x442e0034,0xe6c50015,0xe534005e,0x213822f6}},	//   _twf_, _حتمي, _секь, garh_
  { {0x9999006f,0x64a30099,0x40340190,0x200b01d3}},	//   _ísť_, _ваја, иерс, _pici_
  { {0xa347008f,0x5f2405e6,0x645d0045,0x7497000a}},	//   _рэкл, ифуз, ăsit, _ידוד_
  { {0x291e01d1,0xfe700029,0xdb0000dc,0x0f1400fd}},	// [40d0] _ofta_, يدك_, _elmú, рмую
  { {0x68ed0089,0x865b0008,0x8d790015,0x265b004c}},	//   řadi, ודמי, عماء_, וכמא
  { {0x6811003d,0x27ed22f7,0x27ff22f8,0x0000006a}},	//   _tādi, ylen_, ymun_,
  { {0x9b440015,0xe4ab000a,0x0000006a,0x0000006a}},	//   لنمو, וֹדָ,   ,
  { {0xeab00031,0x27ed04d1,0xfecb002b,0xd94507d1}},	//   يعه_, vlen_, _آبجو_, гели
  { {0x27ed17e7,0x487900a4,0x764912e2,0x99d70115}},	//   wlen_, есия_, vrey, ختصا
  { {0x27ed22f9,0xc19c000a,0x1866006b,0xf7710015}},	//   tlen_, ושגי, гащи_, ماة_
  { {0x86990083,0xd0f8000a,0x764922fa,0x27ed22fb}},	//   етот_, כמות_, trey, ulen_
  { {0x317100dc,0x61ee00c0,0x672922fc,0x3ea922fd}},	//   kezz_, ylbl, rbej, nyat_
  { {0x59b7014e,0x27ed22fe,0x98c705e6,0xceb40643}},	//   _अतिर, slen_, _исел, שיץ_
  { {0xa87b0015,0x85940033,0x58d422ff,0x7649001a}},	//   _تحذر_, ршыц, _кофт, srey
  { {0xc20901c8,0xddcd044c,0x3ea90375,0xccf2000a}},	//   _זה_, jvaž, kyat_, מכי_
  { {0x8bd6000a,0x59b7000b,0xbb76000a,0xc447002b}},	//   רורו_, _अतार, נעשו_, ریکن_
  { {0x463a004c,0xddcd0085,0x67c1003d,0x7afd01c0}},	//   _טענע, evaž, jējz, _ústu
  { {0x75d20002,0xc0aa0015,0xdfd20015,0xe1ff002a}},	//   _ديوا, راسل_, ميس_, twór_
  { {0x645c0251,0x44f30016,0xd36f0015,0x20000045}},	//   àrie, _ị_, _فهى_, umii_
  { {0xdfcf0029,0x93fb000a,0xfd120015,0x130a005e}},	// [40e0] سيك_, _אלקי, مجا_, _яний_
  { {0xa0c60086,0x127b004c,0xed57098a,0xc27b004f}},	//   _ميخو, _טאפע, лоу_, _טרפי
  { {0xf53600b2,0x68110024,0xacf6049d,0xbc19005e}},	//   רטער_, _kādu, учај, вічі_
  { {0x65ad002c,0xb09b0008,0x7c650015,0x6c330067}},	//   _súhl, _ניכר, شامل, صفها
  { {0x8cd0005d,0x60d60024,0x0a940033,0x19580174}},	//   _दशको, šamā, ралю, валы_
  { {0xf8b00086,0x8277004c,0x09e3055f,0xb21b001a}},	//   يکا_, טענע_, бочн, kvæn
  { {0xcc780008,0x3c780008,0xbc78000a,0x07e60054}},	//   _בְּר, _בָּב, _בְּט, лцим
  { {0x8b660015,0xf76f0015,0x6aad0030,0x7c3e2300}},	//   _حاسم, كاً_, önfé, mspr
  { {0xd6d00015,0x36d401e3,0x7c3e2301,0x35b420b9}},	//   تقة_, ропр, lspr, ибир
  { {0xa5f80001,0xba0a0015,0x7dcb002a,0xed220033}},	//   ђену_, _أترك_, ożsa, абiў_
  { {0x6d43002d,0xd7ef04f5,0x0d97000a,0x2ed1000b}},	//   ónai, _гу_, אכים_, _सख्त
  { {0xdb00016e,0x7c3e2302,0x69ca02ac,0x9cd7004f}},	//   _romê, ispr, life, רוטה_
  { {0xdcf50048,0x7c3e0012,0x6594013d,0x98a70046}},	//   _mazā, hspr, _валу, kaně_
  { {0x7657000a,0xf67b000a,0x41c40033,0x66e30054}},	//   _עבוד_, _נאומ, бёса, _уоча
  { {0x10480036,0xd48f0080,0x351b0135,0x251b0643}},	//   ляти_, _ур_, _אוונ, _אווא
  { {0x6d4a2303,0x753a0012,0x443e2304,0x7c3e0ef2}},	//   ófan, latz, mst_, dspr
  { {0x69ca00dc,0x443e2305,0xcfe80021,0x7c3e2306}},	// [40f0] kife, lst_, افقه_, espr
  { {0xdd910015,0x7c3e1fb7,0x443e2307,0x3e880058}},	//   غوا_, fspr, ost_, دَكَ_
  { {0x9f49002d,0x998d0064,0xdb000003,0x69ca2308}},	//   llaí_, _ateş_, _homè, dife
  { {0x443e002f,0xa09a000a,0x753a0012,0x5457004c}},	//   ist_, _סירט, hatz, רסאן_
  { {0x443e00b8,0x7f3a000a,0xda640015,0x753a0012}},	//   hst_, _שעשו, ماوي, katz
  { {0x80ca005d,0x3238000a,0x443e2309,0xe9690b1e}},	//   _हेडे, נטון_, kst_, такл_
  { {0x443e230a,0x49b80086,0xa7b500d7,0x31580c44}},	//   jst_, داند_, исиј, איון_
  { {0x443e0838,0xf7710031,0x07a5230b,0x2d810030}},	//   dst_, زاب_, раин, ldhe_
  { {0x443e230c,0x86c5002b,0x959500e2,0x7bcb230d}},	//   est_, شيدن, ашні, migu
  { {0x273300a7,0x27e00198,0x443e230e,0x753a0251}},	//   ản_, čina_, fst_, gatz
  { {0x6aab0026,0x443e230f,0x98170015,0x236901c2}},	//   lygf, gst_, _إبطا, _bbaj_
  { {0x888a00b2,0xbef5005d,0x889a0008,0xf8ae0086}},	//   _שרײַ, _आरंभ_, _בבעי, _تکه_
  { {0x2d910298,0x443e2310,0x0574002b,0xf1bf0046}},	//   _onze_, ast_, _گاند, rpán_
  { {0x673b0007,0x76ba0008,0xdb000251,0x66ba000a}},	//   lauj, _שמספ, _domè, _במנה
  { {0x98a70089,0x68110024,0x9f490125,0x443e082b}},	//   vaně_, _tādu, alaí_, cst_
  { {0x673b00df,0x70530029,0x78800046,0x9f490125}},	//   nauj, تنفا, lává, blaí_
  { {0x6e460086,0xd0072311,0x7bcb1439,0x5e250015}},	// [4100] شنام, рете_, digu, معلق
  { {0xf8150092,0x78800089,0x7c3e2312,0x9d4603ad}},	//   _ước_, nává, tspr, режд
  { {0x98a70089,0x62860020,0x9f40002d,0x8c7a006b}},	//   raně_, lvko, iliú_, ъщат_
  { {0x1a2a0036,0xcb0a0018,0x63a42313,0x6ad1000b}},	//   вжди_, نيان_, _join, तपूर
  { {0x63a4038d,0x63b60176,0x673b00df,0x0aba0029}},	//   _moin, _mlyn, dauj, خطاب_
  { {0x63b60026,0x3eaf0134,0x63a42314,0x443e2315}},	//   _llyn, øgte_, _loin, yst_
  { {0x7b960191,0x788002d5,0xb9c30029,0x3c3c0089}},	//   _краї, dává, تقوي, _dává_
  { {0x96340191,0x2ca707fd,0xe7861d67,0x6c7b0643}},	//   бниц, ände_, руко, _באלפ
  { {0x443e0026,0x6b820034,0x3b070a2b,0xd6d9002a}},	//   wst_, mdog, _вето_, ogły_
  { {0xdb0008e0,0x443e0111,0x6b8200dc,0x63a4002d}},	//   _nomé, tst_, ldog, _aoin
  { {0x63b60176,0x19b90121,0xd6e2002a,0x201e0046}},	//   _blyn, _суть_, wałę_, ítil_
  { {0x753a00b8,0xae16000b,0x6b820486,0x443e0c10}},	//   satz, तदान_, ndog, rst_
  { {0x443e195d,0x63a414e6,0xc67600c3,0xddcd0227}},	//   sst_, _doin, _خطاب, braň
  { {0x463b00b2,0xdb0006be,0x443e1341,0xddd6002a}},	//   _יעדע, _comé, pst_, ntyń
  { {0xa184008f,0xd5fb0008,0x63b60026,0xe5e50029}},	//   цыял, _שפור, _flyn, _اثني
  { {0x63a42316,0x63b60335,0x649b039e,0x200f007c}},	//   _goin, _glyn, _יסוד, ögi_
  { {0x6b820034,0xa91c006f,0x7bcb2317,0x69c82318}},	// [4110] ddog, _maľb, vigu, _omde
  { {0x71750002,0x71790a32,0xc27c000a,0xa3b5000b}},	//   _اهدا, _сбор_, _ירחי, ज़ोर_
  { {0x2ca704f9,0xe2ab0086,0x6fb50086,0x5b370029}},	//   ând_, _ساکن_, _همدا, لعشر
  { {0x6f950029,0x6d5c0011,0x6b800026,0xa3e7000b}},	//   _الحض, _ecra, _camg, बकि_
  { {0xb21b0084,0x60db0064,0x673b0007,0x6b800061}},	//   kvæm, ğumu, vauj, _damg
  { {0x7bcb2319,0x4e16000a,0x39e8005e,0x9da8006b}},	//   sigu, _לחשב_, адіо_, _къса_
  { {0x78800089,0x7bcb0251,0x673b231a,0x76460091}},	//   vává, pigu, tauj, škyl
  { {0xba77002b,0xb21b001a,0x6b800e63,0x7640001a}},	//   _پارت, tvæl, _gamg, fsmy
  { {0x63a4002f,0x673b0f28,0x78800046,0x6f7a000a}},	//   _roin, rauj, tává, רְצו
  { {0xb5790a61,0x63a41e14,0xaab40015,0x6b80002a}},	//   ущих_, _soin, _بصفت, _zamg
  { {0x63a40493,0xb50a000b,0x2bc4000b,0x13a8002b}},	//   _poin, _हृदय_, लोवा, لندی_
  { {0xf1a9000a,0xdc88000a,0x645c0144,0xe29a231b}},	//   _אס_, בְשָ, ària, гам_
  { {0x1b7a0053,0x63a40af6,0x7981002a,0x6d47231c}},	//   נטשע, _voin, _kalw, _odja
  { {0xc6920008,0x41b5004a,0x853c0091,0xa1160067}},	//   _מאד_, осст, ukėt, صورت
  { {0x63a4022d,0x7981231d,0x8622009a,0x03a602ed}},	//   _toin, _malw, _وکیل, _гийо
  { {0x44240015,0x6d47231e,0x24430061,0x6d5c231f}},	//   _بروف, _adja, mım_, _scra
  { {0x24430064,0x13b70008,0x8fa32320,0x6b8010ad}},	// [4120] lım_, _להקל_, чате, _ramg
  { {0xe29b000a,0x1d0a0054,0x6b802321,0xfce61377}},	//   _עשיר, гези_, _samg, бозо
  { {0x24430064,0xb53a0053,0x7afb00dc,0x417b0135}},	//   nım_, רגעש, _azut, _גניב
  { {0x7e7d2322,0x4bd50033,0x99920046,0x64412323}},	//   _fssp, оўчу, údža_, isli
  { {0xab650024,0xe98001f3,0x7981108d,0x6b822324}},	//   daļā, далi_, _balw, rdog
  { {0x644100df,0x3f82022d,0xa2f70008,0x38cb0086}},	//   ksli, _haku_, זמנה_, گاهی_
  { {0x644100fb,0x5886065e,0x7afb00dc,0xc173039e}},	//   jsli, сыла, _ezut, פחה_
  { {0xf0930008,0x27e000bd,0x24430064,0xddd6005c}},	//   לנו_, čino_, dım_, styń
  { {0x7e642325,0x8f9b000a,0x6674002b,0x680a002a}},	//   ntip, ריפי, تگار, _kędz
  { {0xb8650074,0x7981172c,0x3f822326,0x442701d7}},	//   _ژانو, _galw, _laku_, _btn_
  { {0x53990036,0x8816002b,0xe375004a,0x7e642327}},	//   авня_, _طباط, олны, htip
  { {0x69d80048,0xb8de014e,0x61e1005d,0x4806005e}},	//   lnve, ुछ_, पक्ष, _упев
  { {0x6441131c,0xd6d9002a,0x7e64003d,0xb6380004}},	//   asli, tałe_, jtip, _тплф_
  { {0x24430064,0x865b000a,0x680a002a,0xa1590054}},	//   bım_, _עדוי, _nędz, јаву_
  { {0x44260115,0xdc3c0007,0x3f822328,0x24430061}},	//   _ارتف, _išėj, _baku_, cım_
  { {0x69d80012,0xc7b1000a,0x1fa41411,0xa0c40058}},	//   hnve, ֵ֑ן_, пруг, سيقو
  { {0x680a0050,0x3f870089,0xde590036,0x8ed80015}},	// [4130] _będz, ěnu_, разі_, مذكر_
  { {0x201a003f,0x7afb002a,0x998d07c4,0xa2b8004f}},	//   _fupi_, _rzut, _svež_, _לפחד_
  { {0xccfb0001,0x351b000a,0x7cd90015,0xbc7500c3}},	//   ућа_, אובנ, جواز_, تهاب
  { {0x395e003e,0x2d9c00c0,0x69d8014a,0x79810b90}},	//   _acts_, över_, enve, _salw
  { {0x69d8002e,0x6fb50086,0xc3340008,0x24430064}},	//   fnve, _همگا, לוף_, zım_
  { {0x6e2d04ed,0x24430064,0xd23c0008,0x3829005e}},	//   mpab, yım_, נגול, ажко_
  { {0xab65003d,0x9c29000a,0x29fd006f,0x6e2d2329}},	//   taļā, _כֵּ֥, _kňaz_, lpab
  { {0x501c000a,0xf6251293,0xb0b8004f,0x680a0535}},	//   נוחו, одио, מפוס_, _kędy
  { {0xa93d0010,0x7981232a,0xe616054f,0x9599226a}},	//   _адзi, _talw, оды_, атну_
  { {0x24430064,0xec350053,0xa44501e5,0x201e0030}},	//   tım_, ֿאָר_, онод, ítik_
  { {0x87e7087a,0x04950010,0xd4690175,0x628d0125}},	//   _люде, іроў, шине_, _arao
  { {0x244301e2,0xe6950002,0x94060015,0x6441232b}},	//   rım_, _ولاد, توجه, rsli
  { {0x24430064,0xbebb0111,0x628d10e0,0x6441232c}},	//   sım_, _geëx, _crao, ssli
  { {0xe6920086,0xe4d50015,0x24430061,0x360500c3}},	//   _آلود, _وتثب, pım_, _بوتف
  { {0x64430089,0x03a60b08,0xf992000f,0x73c60015}},	//   _uvni, _мико, ורם_, _ويتم
  { {0xd5e20092,0x680a005c,0x1f660033,0x7e64232d}},	//   _trọ, _sędz, ўкам, ttip
  { {0x3e870063,0xdb060064,0x628d002d,0x6e2d0035}},	// [4140] ойто_, ümün, _grao, gpab
  { {0xdd920074,0x7e64232e,0x201a1c3b,0x9cf6011e}},	//   بوط_, rtip, _tupi_, очеш
  { {0x7e6413b0,0x2a7f0020,0xec9a049d,0xdcfc00bc}},	//   stip, _asub_, штај_, _tarč
  { {0x2ca700c0,0xcb6a1791,0x3178002a,0x6d43001a}},	//   ända_, раде_, lerz_, ónar
  { {0xe28d000a,0x19940033,0xfaa30033,0x09e6011e}},	//   ָרוֹ, заля, мацо, оодн
  { {0x8d760086,0x317802ad,0x76460073,0x0000006a}},	//   _باحا, nerz_, škyk,
  { {0xbb560015,0x69d8232f,0x93bd00d4,0x0000006a}},	//   _ونسب, rnve, spăi,
  { {0xffb70053,0xca76044e,0x0c230127,0xa09b004c}},	//   ַליש_, _музы, _імун, שיקט
  { {0x39460033,0xba530015,0x69d90030,0x9a250058}},	//   _мнаг, _ينفع, óbeá, _فعلن
  { {0x28960001,0xda7b0008,0x9f510030,0xb21b01d0}},	//   _мјес, _דנמר, _öböl_, svæk
  { {0xd5b705d1,0x4917000a,0x628d0125,0x80ca0065}},	//   ісь_, _וקבל_, _srao, _हेले
  { {0x28c3000b,0xf1bf0030,0xdb000069,0x628d2330}},	//   _वेटि, ppák_, _lomí, _prao
  { {0x9f4908e0,0x51872331,0x0000006a,0x0000006a}},	//   llaç_, оува,   ,
  { {0xc1eb004a,0x65ad006f,0x6756002b,0x27e902d8}},	//   рьме_, _súhv, _ایکس_, čane_
  { {0x8557000a,0x63f70015,0xd6d9002a,0x1fa701f3}},	//   _ושוב_, _وأعر, mała_, ораг
  { {0xcf980124,0x09b7005d,0x6e2d0020,0x94bb000a}},	//   оју_, _अत्य, tpab, _כמות
  { {0xcd2b0015,0x82370015,0x2d83039f,0x0000006a}},	// [4150] لسان_, _برعا, _paje_,
  { {0xdc8b00d0,0xc05b02e1,0xd6d9002a,0x3178002a}},	//   исел_, _кім_, nała_, cerz_
  { {0xdb0003af,0x7188000a,0xd6d9002a,0x68270061}},	//   _domí, _וְרַ, iała_, _kıde
  { {0x207a00b2,0x307a0053,0x907a0008,0xbbb5000b}},	//   _פארא, _פארנ, _פטרי, ंसेक
  { {0x20090024,0xbf9a0008,0x7af6005c,0x7f9a0008}},	//   mmai_, _הירש, żytn, _הברז
  { {0x20091c46,0xc9840054,0xd6d9002a,0xa258000a}},	//   lmai_, дући, jała_, קבוק_
  { {0x01380008,0xcb350063,0xd6d9005c,0x1b770015}},	//   חרות_, _невъ, dała_, _ودرج
  { {0x60dc000a,0x3178002a,0x06550033,0xe762006b}},	//   יקונ, zerz_, птоў, евъп
  { {0xe81b005d,0xf6510015,0x9b880015,0xd6d9002a}},	//   _पूरा_, رئة_, _بنقل_, fała_
  { {0xd6d9002a,0xc565007e,0xc7b80085,0xe61600c2}},	//   gała_, чкок, _ruđe_, ядь_
  { {0xb9c40115,0x20090030,0x84580195,0x3178036d}},	//   _تقلي, kmai_, орят_, verz_
  { {0x78fa0008,0x69080008,0x0000006a,0x0000006a}},	//   _הפעו, _וּנְ,   ,
  { {0x471a0008,0xb1840046,0xa2d60040,0xcad50c44}},	//   _הונג, íťov, سيست, לוֹת_
  { {0x91b10092,0xc6d40029,0x7c290522,0x216a0054}},	//   _đạt_, _تتمت, _čern, љиви_
  { {0x10a60063,0x75310024,0x8236002b,0x92a9002a}},	//   чивн, īdzē, _کربا, _połó
  { {0x27ed0577,0xc7b80085,0xef1a0cab,0x8fa32332}},	//   noen_, _tuđe_, сма_, насе
  { {0xcd360015,0x03d7000a,0xdee32333,0xdb000046}},	// [4160] كراب, _מוקם_, еоти, _pomí
  { {0x22440107,0xc535000a,0xfce60054,0x6d430030}},	//   ámku_, לָ֣ה_, позо, ónap
  { {0x711b0053,0xb5fa0053,0xe1ff0077,0x224c002a}},	//   _לויפ, צלעכ, otón_, ądku_
  { {0xdb0004f9,0x161b005d,0xd6d9005c,0x20090011}},	//   _româ, नदार_, zała_, cmai_
  { {0x27ed0234,0xcaf60015,0x9b890015,0x61ee00bc}},	//   doen_, أساب, تخلف_, oobl
  { {0x4efb000a,0x61ee2334,0x8c461ea5,0x0000006a}},	//   _להכו, nobl, _неге,
  { {0x38c80086,0x3157004c,0x2d980123,0xfce309da}},	//   غاتی_, ליסן_, _inre_, _зоро
  { {0xd6d90050,0xf803008f,0x27ed003c,0xdcfc0024}},	//   wała_, нчын, goen_, _garā
  { {0xa3c0005d,0xd6d9005c,0x9f4000dc,0x61ee07c0}},	//   ंघन_, tała_, llió_, kobl
  { {0x273a0092,0xb9c6002b,0x61ee0046,0x7abb000a}},	//   ẫn_, _عقاي, jobl, _הצמו
  { {0x20090007,0xd6d9005c,0x61ee0844,0xb4b6000b}},	//   ymai_, rała_, dobl, छने_
  { {0x9cd7000a,0xd6d9002a,0x389b004f,0x3ce40065}},	//   לויה_, sała_, _ליבנ, _टखने_
  { {0x59b0000b,0xa3be0157,0xd6d9002a,0xd6d700ce}},	//   _जकार, _इतर_, pała_, _нтш_
  { {0xd49a0036,0xf67b000a,0x867b000a,0xbf9b2335}},	//   _гри_, _לאדמ, _לרדו, _chên
  { {0x657a1fb7,0x15fb000a,0xd5cb004f,0x7c29013b}},	//   meth, _ההגע, _לֶהָ, _čero
  { {0x20092336,0x04db000a,0x3014006b,0x4255002b}},	//   umai_, _לקול, едср, _قنبر
  { {0x645a0220,0x1ef80015,0x394c2337,0x925b0015}},	// [4170] luti, كعكة_, _odds_, _اشعر_
  { {0xd90404b6,0x27ed0111,0xbbb5005d,0xb2bc000a}},	//   _می_, zoen_, ंस्क, _למחר
  { {0xdcfc0048,0x69c0005d,0x753c002a,0x645a2338}},	//   _parā, वसनी, órzy, nuti
  { {0x6d5e00b6,0x394c003e,0x8af918fe,0xf457000a}},	//   agpa, _adds_, онес_, ליבר_
  { {0xc5f80024,0x645a007c,0xf1b9003d,0xdb00016e}},	//   klē_, huti, ūšu_, _romã
  { {0xe9d80010,0xfe9a000a,0xc8950054,0xb9c50015}},	//   пкі_, _וישמ, дрињ, بقتي
  { {0xb7b500a7,0xe739005f,0xf7710029,0x27ed079b}},	//   _dụn, оей_, ناة_, toen_
  { {0x645a2339,0x3ce6000b,0x9605000b,0x3f89233a}},	//   duti, _जुटे_, रष्ट_, ndau_
  { {0xdce70007,0x657a233b,0x645a0028,0x0f58000a}},	//   _pajė, feth, euti, פיזם_
  { {0x645a000c,0x657a0041,0xe6110015,0x27ed233c}},	//   futi, geth, خشب_, soen_
  { {0x9f4b0089,0xdb00002d,0xdcfc0045,0x645a233d}},	//   _akcí_, _iomá, _iară, guti
  { {0xd6ce0074,0x657a0026,0xd8740021,0x7c290073}},	//   اقی_, aeth, _سامب, _čerl
  { {0x3f890176,0x92930033,0x2b4d01c2,0xd6d9002a}},	//   ddau_, ваўц, _mdec_, mało_
  { {0xe1ff0077,0xd6d9002a,0x661d001a,0x645a233e}},	//   stón_, lało_, ísku, buti
  { {0xe1ff00dc,0xdfd20021,0x3075004a,0x2fc0233f}},	//   mtól_, نيس_, нутс, thig_
  { {0x3e660152,0xee3a2340,0x61ee0b6c,0xe1ff0030}},	//   tôt_, жна_, sobl, ltól_
  { {0x7dc01893,0x42c70063,0xd6d9002a,0x68e40061}},	// [4180] _löse, _огън_, iało_, ğidi
  { {0x3f890b7c,0xfd1200b0,0xe1ff00dc,0x6284003f}},	//   adau_, نجا_, ntól_, _isio
  { {0x93bd0011,0x319b000a,0xd6d9002a,0xdb200046}},	//   mpăr, _ובינ, kało_, štíc
  { {0x657a00dc,0x3e660152,0xdb4f0015,0xd6d9002a}},	//   zeth, pôt_, لَم_, jało_
  { {0xe1ff00dc,0xab770015,0xd6d9002a,0xbb432341}},	//   któl_, ظمها_, dało_, течк
  { {0xfaa307c1,0x7dc00012,0x3eaf0012,0x082a0579}},	//   таљо, _böse, ägte_, оции_
  { {0xdb000107,0xab2a022a,0xc173000a,0x61d7000a}},	//   _domá, _мова_, דחו_, ווסף_
  { {0x657a0176,0xf76f0070,0x4fbb0053,0x62840a6d}},	//   weth, لاً_, ַציא, _osio
  { {0x6e22002f,0x896603fc,0xe9da006b,0xd7c70015}},	//   íobh, _окаж, _дка_, بويه_
  { {0xfe9b0008,0x65ad002c,0xb8b60001,0xfcaa0008}},	//   קיימ, _súhr, _осећ, ַיָּ
  { {0x628400f2,0x3f890026,0x7d7b0447,0xd8ba0015}},	//   _asio, ydau_, חניו, _بدءا_
  { {0xb21b002e,0x7bc20161,0xd7930015,0x645a2342}},	//   kvæt, nhou, _للمخ, ruti
  { {0x6d4e06cf,0xe5c60146,0x7d1c00bc,0x46b60015}},	//   _odba, _оско, _ogrs, _تحاس
  { {0x3f890026,0x79880ed2,0x7d030107,0x7dc00012}},	//   wdau_, _jadw, ýnsk, _lösb
  { {0x69c60007,0x2918006f,0xf55b000a,0x7bc22343}},	//   _įkel, _úrad_, _ודומ, khou
  { {0x7bc20111,0x80a0005d,0x988b000a,0xd5b8003d}},	//   jhou, _ऑपरे, חָמֵ, lkā_
  { {0x799a00f6,0x7c2e0024,0x7bc205d6,0x0d67004a}},	// [4190] _ontw, _atbr, dhou, дъем
  { {0xd6d9005c,0x8d7700e5,0x63ad2344,0xed5b0015}},	//   zało_, بارا, _hoan, تشرت_
  { {0x2d87002c,0x3a2d2345,0xbc4b0033,0x798a0034}},	//   ľne_, _step_, ючае_, ddfw
  { {0xeb740010,0x7bc2069b,0x799a2346,0x2d8705fb}},	//   вышэ, ghou, _antw, žne_
  { {0xda640029,0xdb000107,0x8f36000a,0x79882347}},	//   ناوي, _pomá, _ראשו_, _badw
  { {0xd6d9005c,0x79880026,0x9f40002e,0xd2b8000a}},	//   wało_, _cadw, llið_, ולדת_
  { {0xd6d9005c,0x79880026,0x6d452348,0x7bc200da}},	//   tało_, _dadw, maha, bhou
  { {0x799a018b,0x5c070010,0xd5b80024,0x64482349}},	//   _entw, _цяга, ekā_, dsdi
  { {0x442e234a,0xf771002b,0xe1ff0030,0xd6d9002a}},	//   _atf_, ناک_, ttól_, rało_
  { {0x77b506d4,0x79880026,0x6d45234b,0xad19000a}},	//   _máxi, _gadw, naha, ּוֹר
  { {0x69c3002d,0xe1ff234c,0x66181253,0x4735008b}},	//   mhne, rtól_, _divk, _знес
  { {0xdb0000fb,0x6d4500b6,0xc1690008,0xe1ff00dc}},	//   _domæ, haha, _לח_, stól_
  { {0x63ad0023,0x93430033,0xe1ff0030,0x6d451c83}},	//   _doan, ыняе, ptól_, kaha
  { {0x85050015,0x76490061,0x6d45234d,0xe5680058}},	//   _كوشن, msey, jaha, _يمنى_
  { {0x7dc000b8,0x11d70029,0x6d45013c,0x7bc2234e}},	//   _lösc, روفة_, daha, yhou
  { {0x93bd0011,0x6729010d,0x6d43001a,0x6284234f}},	//   spăr, ncej, ðnan, _tsio
  { {0x6284003f,0x76490064,0xc333000a,0x8d5603ae}},	// [41a0] _usio, nsey, _עוז_, етеч
  { {0x7af6005c,0x6b9b0213,0xddcd002a,0x69c300bc}},	//   żytk, _anug, erał, jhne
  { {0x7bc2069b,0x113b000a,0x7988123d,0x913b000a}},	//   thou, _מתיל, _radw, _מעיק
  { {0x79880026,0x4fb60029,0xddcd005c,0x2e24002e}},	//   _sadw, _أصدر, grał, _töf_
  { {0xb21b0bfa,0x7bc21126,0xf1bf0030,0x6d450337}},	//   lvær, rhou, ppát_, baha
  { {0xf0470086,0x6d4e02de,0x6d450049,0x672b063b}},	//   _تعیی, _udba, caha, _afgj
  { {0x307a0053,0xddcd005c,0xb21b0af5,0x7c2e0971}},	//   לאַנ, brał, nvær, _utbr
  { {0x2d8a00b8,0x3ec50007,0xec160015,0xe109000a}},	//   _habe_, ųstų_, _أورد, וּפָ
  { {0x69c3002d,0x7bc00523,0xa5d7002b,0x63ad2350}},	//   bhne, _ilmu, کبير_, _roan
  { {0x69c313fd,0xceb30008,0x9327002b,0xb21b02de}},	//   chne, טיח_, کردن, kvær
  { {0x644800df,0xf8bf0004,0x23dc000b,0x1c0a000a}},	//   usdi, _сé_, मचंद, ּלָ֑
  { {0xd5b80048,0xb21b02de,0x58bb000a,0xb8650015}},	//   skā_, dvær, _ממבצ, _جاكو
  { {0x6d452351,0xdb0b0012,0x93b40033,0xd765002b}},	//   yaha, ckgä, убяц, _شنوی
  { {0xda10005d,0x7afd0293,0x27e02064,0x201918bb}},	//   ाषित_, _øste, činu_, _sisi_
  { {0x7bc00064,0x6d4500f2,0x80072352,0xb21b02de}},	//   _olmu, vaha, ечае, gvær
  { {0x34fb000a,0x70e1000b,0x94730015,0xe1ff0030}},	//   _מהוד, _नशील, _إدوا, otók_
  { {0x9f40002e,0x20192353,0xbe19005e,0x201e001a}},	// [41b0] rlið_, _visi_, джає_, ítir_
  { {0x9f40002e,0x867b000a,0x9df80054,0x9ce72354}},	//   slið_, הרמו, енут_, нцел
  { {0xdce7005c,0x447b004c,0xf99f0016,0x6d450d35}},	//   _obją, ּנדע, _đè_, raha
  { {0x1036000a,0x8c540015,0x6d450cc4,0x628b0030}},	//   _שטרם_, ائلا, saha, _ágos
  { {0x6d451640,0x69c31740,0xe1ff0030,0x232c004f}},	//   paha, thne, jtók_, ה֥וּ
  { {0xfa34002b,0xb23c004c,0x2d8a0383,0x7bc019fe}},	//   ارند, לעדז, _gabe_, _elmu
  { {0x718c000a,0x7e6d2355,0x69c304b2,0x18a50138}},	//   לְהַ, ltap, rhne, тайм
  { {0xf094000a,0x69c32356,0x27e902d8,0x6b9b0034}},	//   רנק_, shne, čano_, _unug
  { {0x9be4005e,0xba740067,0x7e6d2357,0xaa58012e}},	//   _сірк, _مالت, ntap, _питу_
  { {0xdb0001d1,0x68270010,0x7e6d0064,0xceb4000f}},	//   _domä, _зьдз, itap, ריץ_
  { {0x69c12358,0x394707fc,0xf502006b,0x7afd064c}},	//   _ille, mans_, изьо, _østb
  { {0x6b56000a,0x7d1a001a,0xddc40045,0x39472359}},	//   ֣ישׁ_, _útse, otiţ, lans_
  { {0xd2990036,0xddc40011,0xf5950015,0x7dc00123}},	//   нтрі_, ntiţ, _للإج, _lösa
  { {0xe5790036,0xd132002b,0xddc40045,0xdb1b0144}},	//   _цзк_, شمر_, itiţ, _lluï
  { {0xb21b00fb,0xa889000a,0x7e6d235a,0x2d8a235b}},	//   tvær, וָּ֥, etap, _rabe_
  { {0xc2c60029,0x2d8a047e,0xb21b02de,0x3947235c}},	//   _ليبي, _sabe_, uvær, hans_
  { {0xb21b0134,0x2606005d,0x321a0227,0x7e6d1c07}},	// [41c0] rvær, _सीडी_, _tipy_, gtap
  { {0xb21b00fb,0x1ea90029,0x859c000a,0xa2b7004c}},	//   svær, راقي_, ּשׁו, _ספיד_
  { {0x0b460036,0xc1bb0008,0x7e6d0035,0xdd8f0115}},	//   внен, _חמיש, atap, تول_
  { {0xacf5235d,0x248702c1,0xdca3009c,0x39471740}},	//   учуј, _msnm_, јаци, eans_
  { {0x4ad2000b,0xa3ea000b,0x3947235e,0xda63067a}},	//   _देशव, _मदन_, fans_, ивци
  { {0x5eeb000a,0x2606000b,0x3947235f,0xb8660058}},	//   _חַלְ, _सीढी_, gans_, نابو
  { {0x83fd0085,0xdca31afd,0x7ae92360,0xdb1b0144}},	//   luđe, _кари, _exet, _fluï
  { {0xd90d0086,0xab5d002a,0x39470547,0x69c10c6b}},	//   سین_, _elżb, aans_, _elle
  { {0x83fd016f,0x3ffb004c,0x5b57000a,0x39472361}},	//   nuđe, ופקע, _ששמן_, bans_
  { {0x3d20005d,0x39472362,0xe1ff2363,0xba090058}},	//   _बलों_, cans_, rtók_, _كتلك_
  { {0x69d82364,0xa7660004,0x99f7004f,0x8d5b004f}},	//   mive, _акед, _יזמה_, וכיי
  { {0xccf30008,0xe7370063,0x22590080,0x69d80957}},	//   יכת_, _аец_, нимы_, live
  { {0xe298008f,0x645d0c89,0x3a242365,0x957c002a}},	//   ваў_, ąsia, _jump_, gnąc
  { {0xca480092,0xcb13000a,0x69d82366,0x1677000a}},	//   iờ_, ילר_, nive, _סגול_
  { {0xca480016,0x3f8b01c2,0x3a2400c7,0x225e002a}},	//   hờ_, _pacu_, _lump_, ątka_
  { {0x39472367,0x7e6d2368,0x69d82369,0x645a236a}},	//   zans_, ttap, hive, mrti
  { {0x5d990010,0xdf440010,0x69d8236b,0x3947236c}},	// [41d0] нкаў_, рэсп, kive, yans_
  { {0xad670015,0x69d800bc,0x7e6d236d,0x394710d1}},	//   ضائه, jive, rtap, xans_
  { {0x63bd0007,0x7e6d236e,0x7afb01d7,0x39470c6b}},	//   oksn, stap, _syut, vans_
  { {0x645a002e,0xa5150053,0x83fd0085,0x3a240702}},	//   irti, אַנג_, buđe, _bump_
  { {0x8aa70063,0x2b4400d9,0xaac7002b,0xddcd002a}},	//   ържд, _demc_, ختان, oważ
  { {0x1a680086,0x69d80997,0xe81b000b,0xddc40045}},	//   ئیلی_, give, _पूजा_, rtiţ
  { {0xddc40011,0x2d810020,0x59640063,0x2606000b}},	//   stiţ, mehe_, ръча, _सीधी_
  { {0x2d810020,0x2cbc003c,0x178512d2,0x957c002a}},	//   lehe_, øvde_, угим, ynąc
  { {0x69d81782,0x16d90015,0x3a24236f,0x99670137}},	//   bive, عذبة_, _gump_, _ател
  { {0xddcd005c,0xceb20053,0x7dc000c0,0x69d802b9}},	//   jważ, ציי_, _lösn, cive
  { {0x59b8005d,0x2d8100b8,0xddcd002a,0xd877012c}},	//   _अवतर, iehe_, dważ, _جاذب
  { {0xdb1b0251,0x9f400234,0xe1ff002a,0xddcd002a}},	//   _lluí, rnië_, otów_, eważ
  { {0xe1ff0050,0x63bd00dd,0x98a70046,0x9f400079}},	//   ntów_, êrna, ybně_, snië_
  { {0xf1ce005d,0xa5940063,0xddc40007,0x27ff2370}},	//   होंन, _връщ, ktiš, llun_
  { {0x0574002b,0x957c002a,0x20b5004a,0x50b52371}},	//   _خاند, snąc, аётс, асту
  { {0xe1ff005c,0x200b0089,0xe3b2002b,0xb4fa004c}},	//   któw_, _chci_, _چرک_, _אפצי
  { {0xe81b005d,0x7655005c,0x27ff00f2,0xe1ff002a}},	// [41e0] _पूछा_, ązyw, ilun_, jtów_
  { {0x531b0008,0xdca60001,0xd23b0008,0xbd460086}},	//   _אופצ, лази, _רגיל, اناي
  { {0xd5ba004c,0x27e906f2,0x69d80ff6,0x83fd0085}},	//   עזעל, čanj_, vive, suđe
  { {0xab2a014d,0x3a2407c6,0x4fa6054c,0x0a6a2372}},	//   хода_, _pump_, _симв, ерки_
  { {0x673b00bd,0x69d811ef,0x11f6000a,0x0000006a}},	//   dbuj, tive, ְזֶל_,
  { {0x7c290f1b,0x7d0300b8,0x2000008c,0x8277004c}},	//   _červ, ünsc, llii_, רעסע_
  { {0x39450b4c,0xdce7005c,0x4dfb000a,0xe1ff002a}},	//   _dels_, _obję, _נפלא, atów_
  { {0xddcd005c,0x76aa15e6,0xfc1a0029,0xe1ff0030}},	//   zważ, етов_, _أقرب_, rtói_
  { {0xcfb7000a,0xd5b00015,0xdcee0091,0xa51c000b}},	//   טלקי_, قفة_, _pabė, नश्च_
  { {0x7a7b000a,0x27ff007c,0x645a00bc,0xda650015}},	//   _ארמס, alun_, trti, _خافي
  { {0x8d5b0053,0x35f30010,0xdb09002e,0xfdf7000a}},	//   עכטי, спэр, _hleð, רצית_
  { {0x6b82002d,0xd2510029,0xa73a0015,0x1bf4000b}},	//   neog, ينج_, _أثار_, इकिल_
  { {0x59b8000b,0xdb190012,0x63bd1147,0x0000006a}},	//   _अवार, chwä, rksn,
  { {0x171b000a,0x645a00bc,0xda4b000a,0xe0d30058}},	//   _נוגע, prti, עֲכָ, مزز_
  { {0x86070806,0xdb0002c1,0xd5fb000a,0xc9b7000a}},	//   _حقوق_, _comú, _רפור, נהלת_
  { {0xb5fd0107,0x2000037f,0xe1ff002a,0x1ac4000b}},	//   ruše, glii_, ytów_, वनाथ
  { {0x141c000a,0xc3b8000a,0xde58005e,0x6b822373}},	// [41f0] _אוהב, _תלחץ_, латі_, deog
  { {0x20000045,0xbddb0003,0x21671afd,0x0000006a}},	//   alii_, _avèr, _стиг,
  { {0x2d81000c,0xcd070608,0xdcf70045,0x672200bc}},	//   rehe_, учаи, dexă, _ogoj
  { {0xa134002b,0xccf80054,0xddc40091,0x2606000b}},	//   _پریش, ућу_, rtiš, _सीसी_
  { {0x394508e0,0xc6860015,0xa9692374,0xd358000a}},	//   _pels_, _بِ_, вила_, רידי_
  { {0x9f520152,0xe1ff005c,0xa8550e88,0x52d8000a}},	//   voyé_, rtów_, атиј, נוגע_
  { {0xe1ff0050,0x27ff002e,0xdb02002e,0xa405000b}},	//   stów_, tlun_, skoð, रताप_
  { {0x5a35000d,0x98a50011,0x765b02c1,0xe1ff002a}},	//   _внат, _află_, truy, ptów_
  { {0x39450152,0x2c51005c,0x6d470d25,0x6b840020}},	//   _tels_, ląd_, _keja, õige
  { {0x6d470375,0x64e90015,0x6d43001a,0x27ff1f9f}},	//   _jeja, َّةِ_, ðnah, slun_
  { {0xa3ea005d,0x79830111,0xd6a8002b,0xac8b0033}},	//   _मदद_, menw, ندیم_, дзiн
  { {0x79830176,0xb6010089,0x7e7d2375,0xad1a000a}},	//   lenw, _řáde, _opsp, כותר
  { {0x75d50086,0xd24f0029,0xe796002b,0x9814006e}},	//   _پيغا, ونَ_, _خالک, _ابلا
  { {0x865a0008,0x2c51002a,0x6d472376,0x798300c6}},	//   _ידני, kąd_, _neja, nenw
  { {0xa9880008,0x1c15000b,0xc5f40015,0x59b8000b}},	//   נָשִ, तगाल_, _اثنت, _अवसर
  { {0xa0670083,0xd259003d,0x79830383,0x44270045}},	//   јата_, šņa_, henw, _iun_
  { {0x3e6f0064,0xcd360015,0x93fb0447,0x44272377}},	// [4200] güt_, لراب, _שלפי, _hun_
  { {0x44200f4d,0x5d1a0029,0xe29b000a,0x44272378}},	//   _hii_, نتاج_, _ישפר, _kun_
  { {0x6d472379,0x515b000a,0x115b000a,0xb8750033}},	//   _deja, _בכיו, _בדיע, _блiз
  { {0x44270084,0xda660029,0xfc0300d7,0x3329000a}},	//   _mun_, لاتي, опхо, ְחוּ_
  { {0x0a94008f,0x44200011,0x4427237a,0x7983233f}},	//   салю, _mii_, _lun_, fenw
  { {0xe9f70010,0xd6d9005c,0xe2970053,0x7983237b}},	//   аніі_, nału_, יכנט_, genw
  { {0xfce3087a,0x4427237c,0xc7c60923,0xab2a00af}},	//   _доро, _nun_, исии, _аоба_
  { {0x44200005,0xf7f30015,0xb6a60015,0xe1ff0030}},	//   _nii_, يسيد, لإخو, ltót_
  { {0x44270467,0x8c1b0008,0x79830012,0xe9a60033}},	//   _aun_, _יולי, benw, _каап
  { {0x77bc0c98,0x4427237d,0x7c20237e,0xd6d9002a}},	//   _méxi, _bun_, _himr, jału_
  { {0x2fc00409,0x77860254,0x43950fbd,0xcd97000a}},	//   kkig_, _влез, банс, בדית_
  { {0x442700d9,0xdc8b000a,0xe73a237f,0xb81a0015}},	//   _dun_, דְךָ, _ред_, _شتاء_
  { {0x91f70029,0x6594192f,0xd3780010,0x2c51005c}},	//   لأسا, _галу, шчэ_, ząd_
  { {0xd4da0029,0x44272380,0x667b000a,0x7c200034}},	//   _لبعض_, _fun_, _סטוק, _limr
  { {0x44271a5b,0x52140127,0x44200011,0x7530002a}},	//   _gun_, ідст, _fii_, ądzą
  { {0xee1f005d,0xff070010,0xe0190036,0x251b000a}},	//   बद्ध_, аязн, ужбі_, _בווא
  { {0xd251003b,0x6d4708c0,0x5d5507de,0x83b6000a}},	// [4210] _عند_, _peja, йкат, _הִיא_
  { {0x2c51005c,0x8d740086,0x27e90844,0x65680123}},	//   tąd_, قاما, čani_, ngdh
  { {0x40950029,0x6c750001,0xfc67006b,0x91b800c3}},	//   _الجر, слеђ, ръзн, _خطير_
  { {0x0b580033,0x2fc003c1,0xfbd00040,0x44202381}},	//   аршы_, ckig_, وتن_, _xii_
  { {0xdb23001a,0x6d471342,0x2d870003,0x79830db6}},	//   _þríh, _teja, ônes_, tenw
  { {0x32380008,0x2ca700c0,0xb5fd2382,0x38950024}},	//   סטון_, änds_, kuša, _pār_
  { {0xb5fd0024,0x3b670063,0x317c000a,0x008a004c}},	//   juša, _възв, דרומ, ָרפֿ
  { {0x44272383,0xf7710115,0x7afd00cb,0x2d9100da}},	//   _run_, ساب_, _østo, _haze_
  { {0x64430026,0xc68e0015,0x44272384,0x26cd0085}},	//   _swni, فِي_, _sun_, uzeo_
  { {0x69ca00b8,0x4427013c,0x8698006b,0x7ae40125}},	//   chfe, _pun_, ртът_, úite
  { {0x69fa0053,0xb5fd0024,0xdddd003d,0x2d912385}},	//   _עלעק, guša, _apsū, _maze_
  { {0x9cd6000a,0x671b000b,0x48151191,0xf770012c}},	//   מותה_, _पृथक_, _умес, _يان_
  { {0x86c40015,0x6d58001a,0xd6d9002a,0x44201ade}},	//   _ويمن, óvak, tału_, _vii_
  { {0xd83e00bd,0xaaf6000a,0x44272386,0xa06a2387}},	//   ščen_, מזרח_, _tun_, лага_
  { {0xd4350031,0x8fa60785,0x24960015,0x05d4009a}},	//   _اعتب, баве, _هنود_, _بزنج
  { {0x29c2002e,0xf456000a,0xc0060138,0x0000006a}},	//   _aðal_, _היקר_, ёпак,
  { {0xc1e7002b,0xbea317b1,0xd0070de9,0x2d912388}},	// [4220] شکیل_, патк, сете_, _baze_
  { {0x7e6400dd,0xef170001,0x31860015,0x0000006a}},	//   ruip, сму_, _الدِ,
  { {0xe1ff001a,0x63a42389,0x0000006a,0x0000006a}},	//   fróf_, _knin,   ,
  { {0xb4fa004c,0xd24f002b,0xcb0a002b,0xdee6098b}},	//   אפעי, _تنی_, هيان_, _гоми
  { {0x7e6408e0,0xcaf60029,0xaad2005d,0x69ca130f}},	//   quip, حساب, _देखक, thfe
  { {0x9f49002e,0xcaa50029,0x22440057,0xba170015}},	//   llað_, تصمي, ámky_, مينا_
  { {0xc0f20092,0x8884002b,0x7c200123,0xa37b016e}},	//   _rượu_, تیان, _timr, liõe
  { {0x96340155,0xcc570447,0xa09b004f,0xb5fd01ec}},	//   ониц, _לסלק_, ריקט, vuša
  { {0xcf930008,0xa37b016e,0x76b7006b,0x7791002b}},	//   לטה_, niõe, йлър_, بینا
  { {0xc58a0080,0xf9c4002b,0x95d80004,0x6dbb002a}},	//   ущие_, _بحری, рдот_, płań
  { {0x293700b2,0xc7af005f,0x26c2238a,0x6d8b000a}},	//   _האבן_, _её_, ško_, אָכְ
  { {0xdc8b000a,0xdc9b000a,0x290c036d,0x74150015}},	//   נְיָ, איטל, _izda_, توجا
  { {0xadfa005d,0x11d90015,0xd7060054,0x57fb015b}},	//   ्तान_, لوحة_, _узди, _גלאו
  { {0x236d0050,0x63a400f2,0xb5fd099c,0xe717000a}},	//   żej_, _enin, lušn, _החדר_
  { {0x61150036,0xddd6002a,0x7bc2008c,0x83d50015}},	//   ідбу, krył, kkou, _ويتص
  { {0x543b00b2,0x628d002d,0xdfd4004a,0x2d85002a}},	//   _געהא, _tsao, посы, _źle_
  { {0x69c8003e,0xa37b001c,0xadb50010,0xbdb5009c}},	// [4230] _olde, giõe, обаш, обај
  { {0xe1ff0030,0x5d5509a0,0x0000006a,0x0000006a}},	//   rtós_, ікет,   ,
  { {0xb5fd00bd,0x9f49002e,0xbb550015,0xfc64006b}},	//   kušn, blað_, قناب, зъчн
  { {0xfd100029,0xf8a90086,0x69c8238b,0x69da238c}},	//   رجل_, یگاه_, _alde, _amte
  { {0x957c0050,0x1ee7002b,0x2d910061,0xb5fd1d8f}},	//   ciąg, _طوسی_, _taze_, dušn
  { {0x957c005c,0x3859004a,0xc27c000a,0x7bc2238d}},	//   niąd, арию_, טרדי, akou
  { {0xf9900002,0xa2db000b,0xb3cc000b,0x3158000a}},	//   عبه_, _पेस्, ासमख, זיון_
  { {0x69c8238e,0x6c840015,0x6fc9000b,0x7bc2238f}},	//   _elde, _علقم, रसिं, ckou
  { {0x07b60015,0x8f9c000a,0x56260033,0x77c6005e}},	//   تهية_, ריחי, ожым_, ільг_
  { {0xe6280029,0x984b0033,0x61e90003,0xb5fd036d}},	//   حثين_, _бяда_, éell, krše
  { {0x13a80086,0x7bc90384,0x6d58002d,0xa9080015}},	//   مندی_, _kleu, óvai, _هيكل_
  { {0x645c001c,0xf1a9000a,0xb8df000b,0xc3d60033}},	//   ária, _בס_, ुन_, іўны
  { {0x9c08000a,0x3ab9000a,0x98bc0046,0x63b601f6}},	//   מִשִ, ׁמֹנ, kavě_, _voyn
  { {0x38a004f9,0x7bc20089,0x83fd016f,0x7bc91deb}},	//   _fără_, zkou, vrđe, _lleu
  { {0x9f49002e,0x7bc90034,0x63f60015,0x1fb60098}},	//   tlað_, _oleu, _وأبر, осар
  { {0x0fb3000b,0x6fda0046,0x63a42390,0x7c2901c0}},	//   ीसगढ, můck, _unin, _čerp
  { {0xee370809,0x0ec4000b,0x0eaa0033,0xfd4a0054}},	// [4240] жну_, लैंड, шкай_, изак_
  { {0xad660002,0xed5a005e,0xe1ff002a,0xad650015}},	//   تاره, рож_, gród_, كامه
  { {0xcc360029,0x7bc90152,0x957c005c,0x6c860015}},	//   زراع, _bleu, siąg, تلام
  { {0xcb670010,0x61fc0422,0xa2c1000b,0xb5fd003d}},	//   жаце_, lorl, रैक्, kušo
  { {0xf38d00b2,0xbd460015,0x61fc0d16,0x7bc22391}},	//   טראָ, _ونحي, oorl, rkou
  { {0x3e7400f2,0x329b0053,0x7bc207b9,0xd9d7005e}},	//   mät_, יבנד, skou, омії_
  { {0x91a90023,0xa9672392,0x7bc92393,0x98a30054}},	//   _quả_, ција_, _fleu, дије
  { {0x17f70029,0xdb000064,0xcb671923,0xdffa000b}},	//   يرية_, _komü, _масе_, ंविद_
  { {0x7c3e0111,0xa9760054,0x3e740b24,0xdcf50091}},	//   lppr, _мужј, nät_, _bazė
  { {0x7c3e0581,0xd5ba2394,0x16d70015,0x7e760012}},	//   oppr, рси_, غذية_, ityp
  { {0xddcd0011,0x44380409,0xdffa000b,0x3e74008c}},	//   ltaţ, ër_, ंवाद_, hät_
  { {0xb5fd1007,0x47c30063,0x7c3e00aa,0x18670004}},	//   vrše, _обхв, ippr, _фаци_
  { {0x3e74022d,0x6716005d,0xddcd0011,0xa3bc000b}},	//   jät_, देशक_, ntaţ, _आकर_
  { {0x35f70074,0x3e7400f2,0xdb0016ee,0x05d30015}},	//   _ورود_, dät_, _homó, _يزوج
  { {0xc1050029,0xdb00005c,0x98ac0091,0x2607000b}},	//   سوري, _komó, _vedė_, हतरी_
  { {0x1e350010,0x443e2395,0x185b004c,0xddcd0091}},	//   знаў, mpt_, יכלע, ktaţ
  { {0x98bc0089,0x443e2396,0x0000006a,0x0000006a}},	// [4250] tavě_, lpt_,   ,
  { {0x7bc91786,0xdd910029,0xb5fd0089,0x443e0111}},	//   _sleu, عوا_, prše, opt_
  { {0x0cab000d,0x98bc0089,0x7bc92397,0xc172000a}},	//   штаи_, ravě_, _pleu, _אחי_
  { {0x70fa013a,0x60fa013a,0x2bb80015,0x1cb80015}},	//   _להתח, _להתק, يانة_, غالب_
  { {0xbf360632,0x394c00da,0x7bc90079,0x7dcb002a}},	//   _מארץ_, _beds_, _vleu, iższ
  { {0xdeba0008,0xe9d80484,0x3e7b0045,0x3f891c61}},	//   _המשל, окі_, râtă_, leau_
  { {0x225e005c,0xfc300015,0x443e0079,0x5fdf000b}},	//   ątki_, _لحق_, jpt_, _नगाल
  { {0x1a5b0029,0x2cbc00c0,0xd7750015,0x7b08001a}},	//   _نشطة_, ävde_, سابع, ðstæ
  { {0xddcd04f9,0x61fc0064,0xab660020,0xdb00002a}},	//   ctaţ, yorl, stüü, _domó
  { {0x6e3b0064,0xb5fd2398,0x8895006b,0x49b80021}},	//   _çubu, rušo, _низх, _والد_
  { {0x64a50010,0x232a0956,0x645c0091,0x22491d41}},	//   чана, йони_, šrin, _awak_
  { {0x2896000a,0x1416005e,0x61fc2399,0xdc88004f}},	//   _מדען_, яєпр, worl, חְשָ
  { {0x66a60053,0xb6a5004a,0x43930033,0xdb000144}},	//   _באַשט, _хилл, хаўс, _homò
  { {0x3e74022d,0xc692000a,0x2905239a,0xc6b6000a}},	//   vät_, _נאו_, _kyla_, _מהני_
  { {0x8fa6008f,0x5502005d,0x8785006f,0xb479004f}},	//   паве, _रुपए_, ahŕň, _הָ֥י
  { {0x3e74239b,0xdfd20015,0x600a0033,0x09b8000b}},	//   tät_, ريذ_, ёнам_, _अव्य
  { {0x61fc01e2,0xc2c60015,0x0e6602bb,0x22570058}},	// [4260] porl, _ريدي, якан, _فليد_
  { {0x7d1a002e,0x3e740437,0x929b000a,0xd29b000a}},	//   _útsk, rät_, _פיית, _פשיט
  { {0x91bb0008,0xdcfe0011,0x3b86000d,0xc1bb000a}},	//   _המיי, depă, злег, _המיש
  { {0xcb6a239c,0x3f89239d,0x6d43001a,0x7c3e0546}},	//   саде_, ceau_, ðnar, rppr
  { {0xf1b0014e,0xc3330008,0x957c002a,0xddd6002a}},	//   ञापन, גוד_, niąc, owyż
  { {0xddcd0011,0x2905239e,0x5eeb0008,0xc27b000a}},	//   rtaţ, _byla_, _הַלְ, מרני
  { {0x7dcb005c,0xdb00005c,0xddcd0011,0x3eb20045}},	//   yższ, _pomó, staţ, ţată_
  { {0xddcd04f9,0xf0930008,0xcc77000f,0x7077004c}},	//   ptaţ, תנה_, _מעלה_, לײצע_
  { {0x6d4e0d25,0x45d414c2,0xb6060033,0x7c2e01f1}},	//   _keba, допс, зянк, _hubr
  { {0x645c03af,0xddd6005c,0xcaa500e6,0xdcfe0045}},	//   ário, jwyż, _تصفي, cepă
  { {0x493b0008,0x443e00b8,0xa4d40036,0x9f5300dc}},	//   _הגבו, upt_, фоні, ődés_
  { {0x14190029,0x6d4e0e94,0x7e64239f,0x645c0091}},	//   تيجة_, _leba, krip, šrio
  { {0x46a30010,0x3f8923a0,0xeb91000a,0x6d5c184c}},	//   _пацв, veau_, כָם_, _odra
  { {0x171b011f,0x6d4e23a1,0xd6930054,0x798a0034}},	//   _הודע, _neba, _чишћ, nefw
  { {0x757b0008,0x6114005e,0x3f8923a2,0x9f3500ce}},	//   _הטופ, едру, teau_, дебі
  { {0x6d5c23a3,0x6b84007c,0x443c23a4,0x957c002a}},	//   _adra, õigl, _itv_, biąc
  { {0x7dc000b8,0x443c016f,0x6d4e0375,0x7e64089a}},	// [4270] _lösu, _htv_, _beba, grip
  { {0x200209f0,0x3f89038d,0x7c2e0085,0xdd9b0054}},	//   _ekki_, seau_, _bubr, љша_
  { {0x6d5c0026,0x60130064,0x3f8923a5,0x7e640213}},	//   _ddra, eçme, peau_, arip
  { {0x7c2e23a6,0x9056000a,0x443c23a7,0x2c750d3d}},	//   _dubr, _קברו_, _mtv_, råd_
  { {0x4f9a000a,0x7e6423a8,0x6d430061,0xfaa5002b}},	//   _וברצ, crip, ınab, بجای
  { {0x20090176,0x645804ed,0xb5fd0085,0xa37b007c}},	//   llai_, _ovvi, krša, mnõu
  { {0xfc640063,0xa37b0020,0x01380008,0x6d450c0b}},	//   _пътн, lnõu, הרות_, mbha
  { {0x6d45002d,0x9b94007e,0x6d5c1361,0x37090015}},	//   lbha, _писц, _zdra, يْثُ_
  { {0x442e0bcf,0x6d45002d,0x2009013c,0xb904000b}},	//   _auf_, obha, ilai_, _पे_
  { {0xe459006b,0x6b8b23a9,0xb9c50058,0xe91900ce}},	//   ожо_, legg, _تقطي, _дозі_
  { {0x957c005c,0x20090007,0x442e0400,0x6d450012}},	//   wiąc, klai_, _cuf_, ibha
  { {0xe72e1cf5,0xf7700074,0x78fa000a,0x6b8b23aa}},	//   _је_, _ماه_, _ופעו, negg
  { {0x27380023,0xd3780050,0xe56e23ab,0x67540086}},	//   _ứng_, ęć_, _из_, _سخنر
  { {0x27ed00b8,0xa37b007c,0x6b8b23ac,0x60350091}},	//   lnen_, dnõu, hegg, _sąma
  { {0x957c005c,0x9f8b002e,0xe3d60015,0x6d450125}},	//   siąc, töðu_, _يتبع, dbha
  { {0x6d4e23ad,0x600a0210,0x6b8b0181,0x43f60015}},	//   _seba, інам_, jegg, _تستأ
  { {0x6e270111,0x27ed23ae,0xf413000a,0x7e64007c}},	// [4280] _bijb, inen_, _בפה_, urip
  { {0x3f4c0023,0x27ed00b8,0x3f5e0016,0x200923af}},	//   ếu_, hnen_, ữu_, alai_
  { {0x225e005c,0xeb9a05c4,0x718b000a,0x27ff01d7}},	//   ątku_, жие_, _וְכַ, koun_
  { {0x27ed0298,0x6d45002d,0xab830afa,0x6d4e23b0}},	//   jnen_, abha, вушк, _weba
  { {0xddcd0b6c,0x27ed0012,0x320a0046,0x6d4e0275}},	//   staš, dnen_, olby_, _teba
  { {0xe2a7002e,0x6d430064,0x27ed23b1,0x0000006a}},	//   æðis_, ınac, enen_,
  { {0xdcfc0048,0x27ed00b8,0x8b660015,0x7c2e02f2}},	//   _varē, fnen_, _يارم, _uubr
  { {0xb5fd0085,0x6e270111,0x442e2219,0x2d9823b2}},	//   vrša, _zijb, _ruf_, _hare_
  { {0x7dc0002e,0x2d9823b3,0x7b300091,0x644123b4}},	//   _föst, _kare_, gėuž, epli
  { {0x7dc00482,0x2d9800dd,0x891600a2,0xcad7000a}},	//   _göst, _jare_, _قبائ, _חומת_
  { {0x20090026,0x2d9823b5,0xad18005e,0x38cb009a}},	//   ylai_, _mare_, овiр, _وامی_
  { {0x690b000a,0x443c0016,0x9837000a,0x661d0091}},	//   _וּדְ, _vtv_, _חטאו_, įska
  { {0xdcf50024,0xd5ba004a,0x2d980045,0xdb190012}},	//   _pazī, _мск_, _oare_, ckwä
  { {0xb5fd002c,0xf5770029,0x6b8b23b6,0x7dc00123}},	//   prša, _يمنع_, zegg, _möss
  { {0x26c40091,0x6e270546,0x0000006a,0x0000006a}},	//   lymo_, _rijb,   ,
  { {0xf48300fd,0x2009013c,0x2d9804d2,0xa8180643}},	//   _рушн, ulai_, _aare_, לֵּי
  { {0xd9040086,0x2d98038b,0x8e150033,0x6b8b23b7}},	// [4290] _چی_, _bare_, едац, vegg
  { {0x2bc7005d,0xcce70086,0xbe180036,0x2d980939}},	//   लस्थ, وساي, джує_, _care_
  { {0x7dc000c0,0xb5fd00bd,0xa37b0020,0x6b8b23b8}},	//   _röst, kršn, snõu, tegg
  { {0x26c400df,0x8b05002a,0xb5fd013f,0xb81c0138}},	//   kymo_, hnęł, tušk, _клiм
  { {0x442923b9,0xda340010,0x2d98052a,0x7f3a000a}},	//   _mia_, вечы, _fare_, _מתרג
  { {0xba3d0089,0x26c40007,0x2d9823ba,0x6441002a}},	//   _průb, dymo_, _gare_, ypli
  { {0x3f990020,0x27ff23bb,0x7e6d003d,0x6b8b23bc}},	//   _kasu_, toun_, luap, pegg
  { {0x442923bd,0xe7390004,0xb5fd20c0,0x27ed0c0d}},	//   _nia_, џеп_, muši, unen_
  { {0x27ed23be,0x6f7a000a,0x06960015,0x2d980123}},	//   rnen_, הְיו, فنية_, _yare_
  { {0xe9380086,0x7c2923bf,0x644123c0,0xe6160139}},	//   _قسمت_, _hier, tpli, нды_
  { {0x7c2923c1,0xdc030046,0x3e83003d,0x644123c2}},	//   _kier, _zčás, lītā_, upli
  { {0x98360053,0xdcda0053,0x889a000a,0x3f990085}},	//   _טרעף_, פֿיש, _מבעי, _nasu_
  { {0x2d83016f,0x9756000a,0xd6c3002b,0x442923c3}},	//   _obje_, _ניסו_, _جمشی, _dia_
  { {0x645500dc,0x66ba000a,0x644123c4,0xb5fd23c5}},	//   ázis, _ממנה, ppli, kuši
  { {0xf5050191,0xb5fd0024,0x64a2006b,0x2d9823c6}},	//   _язко, juši, _баща, _rare_
  { {0x44290023,0x7c2923c7,0x25db000b,0x35c5000b}},	//   _gia_, _nier, गोरी_, _लकड़
  { {0x7dd20134,0x2d9823c8,0xd00f0015,0x0dca0033}},	// [42a0] _læse, _pare_, صلك_, плай_
  { {0x3e830024,0x699f005d,0x2b5f0011,0x8d760015}},	//   dītā_, _गोली, _aduc_, عاءا
  { {0x35a6000b,0x139a000a,0xadb70015,0x539a000a}},	//   _कोफ़, ּבְע, عهما_, ּסְא
  { {0xf8b00086,0xf43a0053,0x7c2923c9,0xa03b000a}},	//   یکا_, לגעמ, _cier, _מעטפ
  { {0x32d8005c,0xb5fd0263,0x2d980042,0x8b05002a}},	//   _użyć_, vršn, _tare_, ynęł
  { {0x98a50064,0x7c2920a5,0xab270033,0x9f06002b}},	//   _adlı_, _eier, хоча_, _يوگو
  { {0xb5fd0007,0xba3d0046,0x7c291470,0x2e36001a}},	//   eršo, _průc, _fier, _hæf_
  { {0xdb2100b8,0x26c40007,0xf76f0115,0x6c7b000a}},	//   _äuße, tymo_, ماً_, _מאלפ
  { {0xc6f80191,0xadf4005d,0xddc40011,0xeb750033}},	//   ьних_, _आदान_, cuiţ, _шырэ
  { {0x442923ca,0xfcaa000a,0xa3e3000b,0x7c290028}},	//   _sia_, ִיָּ, फोन_, _zier
  { {0x4429000c,0x26c40091,0x8b05002a,0x224023cb}},	//   _pia_, symo_, rnęł, _atik_
  { {0x87da00e5,0x8b05002a,0x60350091,0xb8e6000b}},	//   _عباس_, snęł, _sąmo, ॉन_
  { {0x430b0036,0x518723cc,0x7bdb000a,0x9258006b}},	//   яхом_, нува, לקטו, наят_
  { {0xcb130008,0x45f80015,0x91a90016,0x7dd202de}},	//   טלר_, _تفتح_, _quà_, _læsb
  { {0xddc40011,0x442923cd,0x2537000a,0x3494005e}},	//   zuiţ, _tia_, _אנוש_, _райр
  { {0xc917000a,0xf0b40033,0x799a00aa,0x5f941119}},	//   תחלת_, ыйсь, _latw, лист
  { {0x8e770029,0x3f99016f,0x52151179,0x63ad0eeb}},	// [42b0] عارض, _vasu_, _идит, _inan
  { {0xf41f022d,0xb21b0134,0xbe640015,0x7c2923ce}},	//   lmä_, dtæg, اهلي, _sier
  { {0x3f990020,0x59a4000b,0x7c290be5,0x645a23cf}},	//   _tasu_, _गोधर, _pier, nsti
  { {0x3e83003d,0xb5fd2398,0xddc40045,0x645a23d0}},	//   tītā_, ruši, tuiţ, isti
  { {0x2bb80029,0x9f4923d1,0x7c2923d2,0xa37b007c}},	//   عامة_, nnaí_, _vier, viõl
  { {0x7c2923d3,0xf41f00f2,0x6fdd000b,0xdb1b0003}},	//   _wier, hmä_, नोरं, _joué
  { {0x66010161,0xed05002b,0x3e83003d,0xc172000a}},	//   volk, _شورپ, sītā_, ׁ֗ה_
  { {0x645a00fb,0xf41f002c,0x7dd20134,0xdb23002b}},	//   dsti, jmä_, _væse, _موزی
  { {0x799a013c,0x4ecc000a,0xc5d501f3,0x645a23d4}},	//   _fatw, ּ֖חַ, вінь, esti
  { {0x645a1430,0x6b9b23d5,0xd6c8002b,0x69ca23d6}},	//   fsti, _haug, عظين_, ckfe
  { {0x2240018c,0x6b9b1b4a,0xe1ff23d7,0x66012140}},	//   _stik_, _kaug, trón_, rolk
  { {0xa3dc005d,0x799a005c,0xd5b80024,0x957c005c}},	//   णों_, _zatw, ajā_, wnąt
  { {0x660100f2,0x76c4002b,0x6b84007c,0xd7580015}},	//   polk, _مغول, õigi, _سجنا_
  { {0x6b9b23d8,0x645a23d9,0xf50505a7,0x63ad23da}},	//   _laug, bsti, _изло, _enan
  { {0x91a90023,0x1c11005d,0xe1ff00dc,0x9f40002d}},	//   _quá_, ़ताल_, mról_, mniú_
  { {0xe1ff00dc,0xdfd200e6,0xddc4002a,0x6b9b23db}},	//   lról_, جير_, stiż, _naug
  { {0xf1c20024,0x441b000a,0xd00700c9,0x6d430061}},	// [42c0] _pašā_, _קופס, тете_, ınan
  { {0xdca6023e,0xa2db000b,0xe1ff0030,0x9f400125}},	//   кази, _पेट्, nról_, nniú_
  { {0xa03a0015,0x3ea0008c,0xe1ff0030,0x9f400125}},	//   _تأخر_, svit_, iról_, iniú_
  { {0x6b9b003e,0x9f40002d,0xaf0a0029,0x799a00e8}},	//   _caug, hniú_, _يقدم_, _satw
  { {0xe1ff0014,0xdaba0086,0x6b9b0472,0x0efa0010}},	//   król_, بهشت_, _daug, _цэны_
  { {0xe9f8008f,0x645a10d0,0x4973005e,0xba170015}},	//   энлі_, ysti, иліс, نينا_
  { {0x38c80086,0xf41f00f2,0x7d0300b8,0x8b960180}},	//   عاتی_, ymä_, ünst, _ирач
  { {0x2c7c002d,0xd6d9002a,0xb0ba0157,0xc6a6067a}},	//   míd_, lały_, _उपनग, врои
  { {0x60c7005c,0x4b7b0053,0xf76f0021,0x765b02f2}},	//   zyjm, _קאמו, زاي_, gsuy
  { {0xd6d9005c,0x6b8200dc,0xab290029,0xea77000a}},	//   nały_, lfog, _أسفل_, _בגמר_
  { {0xc8ca0074,0x7afd0293,0x98360033,0xd6d9002a}},	//   _توان_, _østr, _рэзі, iały_
  { {0x3d1a005d,0x645a23dc,0x78ad013f,0xf746053b}},	//   _भरने_, rsti, šový, _редо
  { {0xe73723dd,0xd6cf0015,0xc2b8005e,0xd6d9002a}},	//   _реч_, _وقم_, вляє_, kały_
  { {0x645a23de,0xd6d9002a,0x9f490125,0xa1640099}},	//   psti, jały_, rnaí_, ињск
  { {0xcf9b000d,0xd6d9005c,0xdfd50892,0xa617000a}},	//   мја_, dały_, говы, _שקוד_
  { {0x63ad23df,0x889b039e,0x938b0579,0x9ff40015}},	//   _unan, ובלי, _цска_, لأقص
  { {0x290c0123,0x6b9b23e0,0x5f9400ce,0x914b00af}},	// [42d0] _lyda_, _raug, шитт, _очна_
  { {0xab5d0050,0x6b9b00df,0x9d550029,0x867b000a}},	//   _może, _saug, انات, ורמו
  { {0xf518000a,0x673b0046,0x83fd0085,0xb5fd0091}},	//   תֵּל, ycuj, suđu, mušt
  { {0x3af5004a,0x6b820030,0x7bc023e1,0xda350138}},	//   лялс, gfog, _comu, геды
  { {0x290c0064,0x7bc023e2,0xab6401f3,0xab5d002a}},	//   _ayda_, _domu, рвіл, _noże
  { {0xd6d9002a,0x6b9b00da,0x0000006a,0x0000006a}},	//   cały_, _waug,   ,
  { {0xdb0000c0,0x6b9b0708,0xe73923e3,0xf1b4004f}},	//   _anmä, _taug, ней_, יסס_
  { {0x7c3a0152,0xdb00002c,0xab5d005c,0xccf2000f}},	//   _étra, _pomô, _boże, _הכל_
  { {0xe1ff00dc,0x5a34087a,0x6d5500d9,0x6fca0069}},	//   tról_, _внут, _keza, _dých
  { {0xa87b0015,0x957c0091,0xfbdf000b,0x2bdf000b}},	//   _يحضر_, liąj, पोरम, पोरा
  { {0x290c0b7c,0x6d550064,0xe1ff00dc,0xa3ea23e4}},	//   _gyda_, _meza, rról_, една_
  { {0xe1ff00dc,0xd6d9005c,0x61e5002d,0x69c123e5}},	//   sról_, zały_, _amhl, _hole
  { {0xe1ff00dc,0x5b7a004c,0x1b7a004c,0x1664005e}},	//   pról_, ערשא, עטשע, _ввім
  { {0xc6920053,0x6d550fd0,0xb5fd00bc,0xeab2004f}},	//   _לאד_, _neza, gušt, צֹר_
  { {0xdb190012,0x69c123e6,0xf8a70015,0xb1d902ed}},	//   chwö, _mole, حة_, тьях_
  { {0xd6d90050,0xb5fd0cbc,0x602600d0,0xc2c6002b}},	//   wały_, rušu, удба, _ميبي
  { {0xd6d9005c,0x0d86007a,0x8fa300a4,0x441b000a}},	// [42e0] tały_, ллан, щате, _אוקס
  { {0x02b7013a,0xb5fd016f,0xad650015,0x7bc00061}},	//   _עליך_, dršk, لامه, _somu
  { {0x317b1282,0x6d5523e7,0x0b46042b,0xd6d9002a}},	//   _ארימ, _deza, гнен, rały_
  { {0x75160053,0x9f060225,0x2c7c002d,0xd9be000b}},	//   אַדע_, _موجو, ríd_, ्स्ट
  { {0x1603014e,0x15f5005d,0x6fca002c,0x61e50026}},	//   रकार_, ीकार_, _rých, _ymhl
  { {0x6d550f55,0xba3d0046,0xda650015,0x69c10bda}},	//   _geza, _trůn, شاهي, _cole
  { {0x7dd2002e,0x7bc00057,0x69c123e8,0x58d405c4}},	//   _gæsa, _tomu, _dole, ройт
  { {0x38a30061,0xab5d002a,0x69c10125,0x98a30054}},	//   _dır_, _poże, _eole, сиће
  { {0x6b840005,0x6fca0156,0x5718006b,0x8c1b000a}},	//   õigu, _vých, ъжия_, _טולי
  { {0x69c123e9,0x290c0123,0x7c221419,0x88da02ed}},	//   _gole, _tyda_, lmor, _пьет_
  { {0x6fca002c,0x2db70643,0xa3b502a3,0xe7860e41}},	//   _tých, אלין_, абні, _було
  { {0x75d4002b,0x7c2223ea,0x6e2e23eb,0x0000006a}},	//   ايگا, nmor, _libb,
  { {0xe2980010,0xdcfc003d,0xa264006b,0x644323ec}},	//   гаў_, _barī, йърл, _etni
  { {0x69d8075b,0x26db000a,0x25ba007c,0x1677000a}},	//   nhve, _אקדמ, _õpl_, _עגול_
  { {0x69cc005d,0xdcfc0024,0xd0d40063,0x29370053}},	//   _तकनी, _darī, боръ, ראלן_
  { {0x6d430064,0x937b0015,0xa857000a,0xd499005e}},	//   ınam, _أصغر_, טילה_, _шрі_
  { {0xb5fd06e6,0x6e2e1c75,0x7c2223ed,0x539c000a}},	// [42f0] pušt, _bibb, dmor, _טיהו
  { {0x2d87006f,0xdcfc003d,0x22440030,0x6c350015}},	//   ýne_, _garī, ímke_, لفئا
  { {0xa1150086,0x6d550263,0x4c570015,0x69c123ee}},	//   _خودت, _veza, اضطر, _role
  { {0x20840029,0xcc0b0067,0x447705bd,0x69c10a8d}},	//   _الَّ, رزان_, רעאל_, _sole
  { {0xbd6b0001,0xe50b000b,0x1b780015,0xa37b007c}},	//   _прве_, _सुनि_, اصمة_, giõi
  { {0x684515ce,0x1a68002b,0x1c570015,0x89a8005e}},	//   анка, ایلی_, _مخرج, лків_
  { {0x8c250029,0x69c123ef,0xe7310015,0xe1ff23f0}},	//   _نفسه, _vole, يصة_, trój_
  { {0x28b6000b,0x5746006b,0xda670015,0x16651797}},	//   _अपरि, азъм_, _مائي, авим
  { {0x78a80007,0xfbd2000a,0x69c123f1,0x1a68002b}},	//   _erdv, _ותן_, _tole, _مینی_
  { {0x69d800b8,0x39a400dc,0xf505006b,0x7dd202de}},	//   chve, tésű_, изпо, _læsn
  { {0xe5220010,0x37c5002b,0xb8950015,0x98bc0091}},	//   ждэп, _پيشف, _خلاع, davė_
  { {0xcc760008,0x6aa923f2,0x45180010,0xddc40011}},	//   סגרת_, _kref, ыцыя_, oriţ
  { {0x6b89003f,0xdcfc003d,0x7e6d0030,0xe72e00af}},	//   _mbeg, _parī, jrap, _фе_
  { {0xa06a008f,0x200b0089,0x3a360008,0x6aa9003f}},	//   кага_, _akci_, ירשם_, _mref
  { {0x7c2207c6,0x6b890123,0x645c0030,0x90c3144f}},	//   ymor, _obeg, árit, обре
  { {0xba3d0046,0x34fa000a,0x6e2e01d0,0x6aa901e0}},	//   _průl, _שהקד, _sibb, _oref
  { {0xbe66002b,0x7e6d23f3,0x7c220804,0x539b000a}},	// [4300] شهاي, grap, vmor, _ייקו
  { {0x27e901cb,0x83fd0085,0x625b000a,0x998c003d}},	//   čany_, vrđi, _שכיה, _vidū_
  { {0x7e6d23f4,0xdcfc0535,0xad650369,0x6aa90052}},	//   arap, _obrą, صاله, _aref
  { {0xc1010092,0x7ac62372,0xcb6a0054,0x2ca7001a}},	//   _lượt_, исле, таде_, ænda_
  { {0x6aa90026,0x69340086,0xf413000a,0xb5fd0085}},	//   _cref, مکار, קפד_, arši
  { {0xceb30008,0x6aa90026,0xa37b0020,0x20ba005d}},	//   _ויש_, _dref, riõi, _उपाध
  { {0xa3c6005d,0x69d8020b,0x957c0535,0x6b840072}},	//   _एवं_, rhve, siąk, õigs
  { {0x4c9b0008,0x57a6000d,0x7bd900b8,0xcf56000a}},	//   _בבלו, ршка, chwu, ׁבֶת_
  { {0x19960001,0xab27006b,0x76b7006b,0x6aa923f5}},	//   _вјер, _вота_, илър_, _gref
  { {0x14ca0080,0x45b8027a,0xd498005e,0x76a7006b}},	//   выми_, угою_, гкої_, ртъв_
  { {0xd5b704ab,0xac9c0033,0xd497023c,0xc1010016}},	//   рсы_, дзiм, аря_, _dượt_
  { {0xc7c70080,0xd5b80024,0x96b70086,0xb8650015}},	//   _выше_, mmām_, _چاوز_, _داكو
  { {0x926b0063,0x41c70033,0xd5b8003d,0x76d30058}},	//   ърна_, аёва, lmām_, _ويمض
  { {0xf2070142,0x7e6d02b9,0x645c23f6,0x59be0065}},	//   рямо, vrap, áris, ्सटर
  { {0x55bb000a,0x361b000a,0x30a40033,0xa1580dfd}},	//   _במגו, _שווד, ортв, расу_
  { {0xb5fd052c,0x9f34005e,0x316d0045,0xdfd00015}},	//   vrši, жеті, şez_, ويّ_
  { {0xba3d0089,0x9df90254,0xddd6002a,0x93fc000a}},	// [4310] _prům, гнат_, dsył, _שלחי
  { {0xeca70124,0x27050023,0xcd2b0115,0x7e6d23f7}},	//   ијен, ồng_, نسان_, rrap
  { {0x3174002c,0x9e080015,0x6fd80125,0xb8860033}},	//   ňazí_, جيلك_, _síce, _блiж
  { {0x5b250029,0x2d8a23f8,0x66081af9,0xe451000a}},	//   مفضل, _ebbe_, hodk, לֶד_
  { {0xc3340008,0x501a015b,0x660801c2,0x15f8000b}},	//   קוס_, _תורו, kodk, ुवार_
  { {0xceb200b4,0x6fd80089,0x395c0123,0xc9870e64}},	//   _זיך_, _více, gavs_, руди
  { {0xf0940053,0x48580033,0x38580033,0x6fca01c0}},	//   ַנץ_, арыў_, арыю_, _výcv
  { {0xd0f8011f,0x3869044c,0x6aa923f9,0xe0f8000a}},	//   ימות_, čar_, _tref, יצוח_
  { {0x6aa9003f,0xba740015,0x060909dd,0x9f4e0030}},	//   _uref, _واكت, лник_, énék_
  { {0x5887065e,0xddc40085,0xb86b012e,0x660823fa}},	//   _выда, oriš, _ајде_, godk
  { {0xddcd00df,0xc1010092,0xa954005e,0xc3290c44}},	//   ktaž, _vượt_, _єкці, _נו_
  { {0xccf2000a,0xe1ff002a,0x27460046,0xbddb0003}},	//   לכי_, orów_, tínů_, _stèl
  { {0x87070080,0x27ed23fb,0xe4d6002b,0x0596002b}},	//   _тяже, mien_, لویت_, _گانگ
  { {0xd5b10070,0xddc423fc,0xba3d0046,0x61431a2f}},	//   _رفع_, kriš, _průj, зера
  { {0x27ed0111,0x7dd20134,0xddd6005c,0x3f6a23fd}},	//   oien_, _sæso, ysył, ливо_
  { {0x543a0053,0x6ab7000b,0x63e50015,0x743a004c}},	//   _געקא, _आपूर, _وسيك, _געקװ
  { {0xdfcf0029,0x754600dc,0xdd3c0007,0x0eaa0033}},	// [4320] ريك_, _érzé, rąži, ыкай_
  { {0xeef5008f,0x8d1a002b,0x27ed23fe,0xdd3c0091}},	//   іятэ, هزار_, hien_, sąži
  { {0x442000a7,0x7dc00014,0x27ed23ff,0x319b000a}},	//   _khi_, _kösz, kien_, _גבינ
  { {0x27ed022d,0xab5d005c,0xda660115,0x6f210061}},	//   jien_, _poża, ماتي, özcü
  { {0x395c0024,0x27ed2346,0xc333000a,0xc27b004c}},	//   tavs_, dien_, פוג_, ָרצי
  { {0xddc402c6,0x27ed0f55,0x61ee2400,0x7db600c3}},	//   briš, eien_, nibl, _اصحا
  { {0xa3ca005d,0x2a150010,0x8d5b000a,0xa7b8005e}},	//   ोसा_, цьцё, _תכלי, илку_
  { {0xb5fd0007,0x6d5e2401,0x44200016,0xd5b8003d}},	//   iršu, lapa, _nhi_, rmām_
  { {0x95d8004a,0xeab6000a,0x320a2402,0x6f79000a}},	//   идит_, _לִ֑י_, koby_, בְתו
  { {0x6d5e03ac,0xceb30008,0x7e9b000a,0x27ed0079}},	//   napa, פית_, נסיו, aien_
  { {0xab5d0050,0x18360086,0xddcd0011,0x66081ed9}},	//   _możn, _طراح, luaţ, rodk
  { {0x27ed0999,0x44202403,0xd91b000a,0x069a0015}},	//   cien_, _chi_, _גובל, _منصة_
  { {0xddcd0011,0x6d5e2404,0x44320fc4,0x8c1b000a}},	//   nuaţ, kapa, _diy_, טוטי
  { {0x41e4008f,0x867b00a3,0x2244002c,0x6d5e2405}},	//   піса, _תרגו, ímka_, japa
  { {0x84460225,0x6d5e08c0,0xd0d4006b,0xba3d0046}},	//   _اختل, dapa, поръ, _průk
  { {0x44200023,0xc5f80024,0xff070010,0x8e850015}},	//   _ghi_, lnē_, бязн, يلزه
  { {0xe3b00029,0xe7ea000b,0xddcd06c0,0x61ee19dc}},	// [4330] _أرى_, जोया_, rtaž, bibl
  { {0x71750086,0x657a003e,0x3f570092,0x27ed0186}},	//   _بهدا, ngth, ầu_, zien_
  { {0xddcd00df,0x69c5022d,0x2bdd005d,0x8f350010}},	//   ptaž, öhem, _मतदा, _менц
  { {0xe1ff005c,0x27ed2406,0x5b150cb0,0x6d5e019a}},	//   trów_, xien_, омет, aapa
  { {0x7e7900b2,0x27ed2407,0x9a87005e,0x4ea70004}},	//   _דאָז, vien_, суел, _урна
  { {0x27ed080c,0x6d5e0faa,0xddcd002a,0xceb2000a}},	//   wien_, capa, ntaż, _קים_
  { {0x79840029,0x60130064,0xdcfc005c,0x3ea91237}},	//   سؤول, eçmi, _obrę, lvat_
  { {0x2249013c,0x27ed0077,0x17c90e4d,0x3ea90046}},	//   _otak_, uien_, ргии_, ovat_
  { {0x9595008f,0x86c50086,0x06960015,0x0f58000a}},	//   ошні, زيدن, قنية_, ציזם_
  { {0x3ea900f2,0xd5e50036,0x86980063,0xfdfb000b}},	//   ivat_, іжни, стът_, ्विस_
  { {0xd7c90086,0x44202408,0x22492409,0xb8f50015}},	//   _پوشه_, _phi_, _atak_, _بكاب
  { {0x6d5e240a,0xba3d0046,0x232a1797,0x98170040}},	//   zapa, _průh, иони_, _ابطا
  { {0x6d5e0358,0x61ee240b,0xadfb000b,0xfdfb000b}},	//   yapa, tibl, ्वान_, ्वास_
  { {0xb21b0134,0x317e0012,0x3ea9007c,0x0000006a}},	//   stæn, ütz_, dvat_,
  { {0x4420240c,0x7f5a00d0,0x3ea90150,0xddcd0b7e}},	//   _thi_, ијат_, evat_, mpaň
  { {0x6d5e00d9,0x61ee240d,0x9f860033,0x320a240e}},	//   wapa, sibl, ўгад, soby_
  { {0x6e460074,0xfe720029,0x01360015,0xfdea0937}},	// [4340] زنام, بدأ_, _وعدد, адак_
  { {0x44d50023,0x2369018c,0x22930086,0x63a4240f}},	//   ó_, _zdaj_, _کلیس, _hain
  { {0x3ea9022d,0x63a42410,0x6d5e2411,0x957c002a}},	//   avat_, _kain, rapa, miąt
  { {0xddcd0011,0xa4fa0053,0x63a60177,0xc50c004c}},	//   tuaţ, בלעט, ndkn, נלאָ
  { {0x6d5e00b6,0x228400dc,0x1a9600a2,0xeab20029}},	//   papa, nök_, تجاج, بعا_
  { {0x629a005c,0xf2d3000f,0x63a42412,0xdd92002b}},	//   łtow, ועד_, _lain, _توس_
  { {0x6d5c0048,0xa37b03af,0x18970029,0x62860020}},	//   _iera, lhõe, قضية_, htko
  { {0xd90d0086,0xf76f0115,0x6d5c2413,0x2284025d}},	//   دیم_, ناً_, _hera, kök_
  { {0xab5d0050,0xc5f80024,0x6d5c0213,0x7c3c2414}},	//   _możl, tnē_, _kera, _hurr
  { {0xe5e60029,0xdb000003,0x22490061,0x6d5c2415}},	//   تثبي, _ramè, _rtak_, _jera
  { {0x7ae20014,0x77660063,0x63a42416,0x3ea90089}},	//   lzot, _дълж, _bain, zvat_
  { {0xa2950010,0xe6c60029,0x63a40c24,0x7bc21151}},	//   памі, _وتشي, _cain, njou
  { {0x68350007,0x11d90015,0x44d50016,0x63a42417}},	//   _išda, موحة_, á_, _dain
  { {0x69c80111,0xdb001d2c,0x6d5c2418,0x7ae22419}},	//   _jode, _camé, _nera, izot
  { {0xa3bb0074,0xe502005d,0xe5e70086,0x6ab7000b}},	//   _ناظر_, _रुचि_, _بزنی, _आप्र
  { {0xb4c8005d,0x63a402ff,0x69da0125,0x3ea9007c}},	//   ोनी_, _gain, _llte, tvat_
  { {0xee840010,0x6d5c0849,0x3e350029,0xd358000a}},	// [4350] дыхо, _bera, سفار, _ויחי_
  { {0x63a4241a,0x9e090015,0x69c8241b,0x6d5c241c}},	//   _zain, حيطك_, _node, _cera
  { {0x7c3c003e,0xc19a000a,0x6d5c241d,0xfc64006b}},	//   _curr, _השתי, _dera, дъчн
  { {0x69da241e,0xf2d5000a,0xf531000a,0x7c3c241f}},	//   _alte, ּעַ_, ׂ֥א_, _durr
  { {0x29f60050,0x69c82420,0x7ae20030,0x7d77006e}},	//   kład_, _bode, gzot, _واسط
  { {0x44d50092,0x69c820ea,0xe7a3000b,0x229c000a}},	//   ý_, _code, _खोजप, שֹׁמ
  { {0x22840014,0xcf270086,0x6e3d003e,0x69c82421}},	//   zök_, _درگي, _husb, _dode
  { {0x62860050,0x61c8005d,0x9f40002e,0x69da1fad}},	//   ytko, _रक्ष, nnið_, _elte
  { {0x9af90053,0xbb8400a2,0x63a42422,0x6d5c0f0a}},	//   _הפּח, _تلقي, _rain, _yera
  { {0x7f5d0152,0x63a42423,0x99d70021,0x6d452424}},	//   _lesq, _sain, _بترا, ncha
  { {0xb21b0134,0x63a40ae5,0xa562002b,0x9f40001a}},	//   rtæl, _pain, رگون, knið_
  { {0x62860d17,0x69c300bd,0x2284234c,0xd91a000a}},	//   ttko, ljne, tök_, _הועל
  { {0x98a70064,0x7dd30064,0xc73a000a,0x63a42425}},	//   manı_, _kısı, _התנת, _vain
  { {0x98a70064,0x22840097,0x63a406e8,0x853c0091}},	//   lanı_, rök_, _wain, ndėl
  { {0x22842426,0x6e3d00b8,0x7dd30064,0x9f40002e}},	//   sök_, _ausb, _mısı, fnið_
  { {0xe1ff005c,0x957c002a,0x6d5c2427,0x63a40125}},	//   wrót_, siąt, _sera, _uain
  { {0x22160036,0x6d5c0d25,0x7c3c1042,0x69cc000b}},	// [4360] _нфор, _pera, _surr, _तकली
  { {0x93250015,0xa37b007c,0x398f0061,0xdd9200c3}},	//   _غرين, liõp, nısı_, عوض_
  { {0x98a70064,0x31570b7b,0x6d5c2428,0x05c3000b}},	//   kanı_, _מיין_, _vera, _वचनब
  { {0x69c8018c,0xe4560053,0x6d45002d,0x00bb0008}},	//   _sode, פינט_, acha, _המטמ
  { {0x7bc200f2,0xe9800010,0x3b630015,0x69c82429}},	//   rjou, валi_, رُوِ, _pode
  { {0xed520086,0x98c60805,0x7bc20df4,0x8cb8002b}},	//   _سپر_, зсил, sjou, _وگاس_
  { {0xec770001,0x764b0026,0xa96700d0,0x6561242a}},	//   _нпр_, _atgy, чија_, dalh
  { {0xf0930008,0x6cfb0008,0x2d9a242b,0xf77200a2}},	//   גנה_, _הפלס, lepe_, راع_
  { {0x69c82188,0xa3c6000b,0x17f70015,0x23d00065}},	//   _tode, _एवज_, ثروة_, _हक़द
  { {0xba3d0089,0x69da001b,0xbadb000a,0x6561016e}},	//   _prův, _ulte, _הקמת, galh
  { {0xb4c8005d,0x53990080,0x395e0150,0x98a70061}},	//   ोने_, овня_, _iets_, banı_
  { {0x883b0008,0x65610020,0x58bb000a,0xf483002b}},	//   _התאו, aalh, _למבצ, راپی
  { {0x656103af,0xf3640010,0xf62a005e,0x853c0091}},	//   balh, этэн, _ліки_, ldėm
  { {0xa4100089,0x398f0064,0x75d40002,0x2614000b}},	//   ětší_, cısı_, _زيبا, _नीची_
  { {0x7f5d03af,0xddc40007,0xb21b002e,0x361b0008}},	//   _pesq, asiū, ltæk, _הוגד
  { {0x34fb0008,0x747b000a,0xd1300021,0x547b000a}},	//   _להוד, _הנהג, امِ_, _הטהו
  { {0x69c3005c,0x6d45242c,0x9f40001a,0x1e350033}},	// [4370] yjne, tcha, rnið_, днаў
  { {0x4df40036,0x9f40002e,0xc334000a,0x4ea40033}},	//   няєт, snið_, _אופ_, эрса
  { {0xc1720008,0x0dc80fea,0x24410016,0x6d45242d}},	//   _בחי_, чути_, _xóm_, rcha
  { {0xbddb0003,0x6d4502b3,0x398f0061,0x9be401f3}},	//   _suèd, scha, zısı_, нічк
  { {0x398f01e2,0xe810005d,0x98a70064,0x395e22d3}},	//   yısı_, ावना_, vanı_, _bets_
  { {0x2d9a04f9,0xf9c7034e,0xdeba000a,0x6d430061}},	//   cepe_, ящен, _ומשל, ınas
  { {0xf8920083,0x98a20b08,0x6561016e,0x98a70061}},	//   вајќ, вище, valh, tanı_
  { {0xb21b001a,0x7dd2001a,0x2441001a,0x5fe8000a}},	//   ftæk, _ræsi, _róm_, ּֽהּ_
  { {0xaa580083,0x6561242e,0x395e0251,0x97320086}},	//   _ниту_, talh, _fets_, نکها
  { {0x395e003e,0xc6480015,0x98a70061,0x853c0091}},	//   _gets_, أجيل_, sanı_, bdėm
  { {0x398f0064,0x3e83003d,0x6561242f,0xa37b007c}},	//   rısı_, lūtā_, ralh, tiõp
  { {0xc1690dab,0x6561242f,0x6fd82430,0x2d9a0160}},	//   _כח_, salh, _cícl, zepe_
  { {0xe60e1e66,0x398f0064,0x6561001c,0xa37b0020}},	//   _ад_, pısı_, palh, riõp
  { {0xc58e0092,0x24412431,0xc692000a,0xddc40091}},	//   _hồng_, _tóm_, _סאו_, rsiū
  { {0x1c0d000b,0xe8ee00af,0x386701d0,0x0000006a}},	//   िकाल_, ллy_, nsnr_,
  { {0x442b01c2,0x0000006a,0x0000006a,0x0000006a}},	//   cmc_,   ,   ,
  { {0x32460015,0x321a0015,0x2d9a0061,0xc58e0016}},	// [4380] _تنخف, _ويعد_, tepe_, _mồng_
  { {0x270c0023,0xc58e0016,0xce1a0138,0x0000006a}},	//   ớng_, _lồng_, іцаі_,
  { {0x91bb000a,0x412a0004,0x600a0054,0x59d1000b}},	//   _ומיי, _фоно_, _мном_, _तक़र
  { {0x395e2432,0xc58e0016,0xc053004f,0x2d9a01e0}},	//   _sets_, _nồng_, _שזר_, sepe_
  { {0xa3e3005d,0xa2a4000b,0x91d2000b,0x6d430061}},	//   फोट_, _चैम्, _हवाई, ınar
  { {0xc333000f,0x298a005e,0xee37006b,0x7c2b007c}},	//   דוד_, ісло_, _оня_, amgr
  { {0xd90f005e,0x22402433,0x3ea00079,0xc58e0016}},	//   ть_, _luik_, lwit_, _bồng_
  { {0x6bda0086,0x3f802434,0x98a30054,0xba3d0046}},	//   _بورس_, ngiu_, тиће, _průt
  { {0xc6f80036,0x96340c71,0x9f9c0125,0x5986011e}},	//   яних_, нниц, _níí_, _олаб
  { {0xb21b0084,0xba23008f,0xc6f703be,0x3ebb000a}},	//   rtæk, _адук, ьных_, קציב
  { {0x493b000a,0xd8380046,0xb21b001a,0xe53d0030}},	//   _וגבו, _ksčm_, stæk, ájáé
  { {0x22400079,0x7e762435,0x2ca7001a,0xee3f0046}},	//   _buik_, kryp, ændi_, _krýt_
  { {0xf7430036,0x518722b2,0xfd650092,0xc7d7000a}},	//   _речо, мува, _chuỗ, _קודי_
  { {0xf5930015,0xdb002436,0x5693012e,0x2240042f}},	//   _للهج, _namí, _рашт, _duik_
  { {0x3cfa005d,0x86370008,0x757b000a,0x9f400079}},	//   ्थों_, _קרוב_, _וטופ, chië_
  { {0x14cb005d,0x5f94222c,0x0000006a,0x0000006a}},	//   ाहरण, кист,   ,
  { {0xee3f0092,0x69d800cb,0x629a002a,0x7e76044d}},	// [4390] _quý_, kkve, łtor, gryp
  { {0xdce5002c,0xd5b80024,0x1155005e,0xddcd0045}},	//   rehľ, mmās_, _якою, draţ
  { {0x61f50064,0xc1560008,0x3156000a,0xf1b2004c}},	//   mizl, _אשתו_, _איתן_, _עסט_
  { {0xe8df0092,0x61f50061,0x60d6000a,0xee3f0016}},	//   _niềm_, lizl, _נורא_, _tuý_
  { {0x9f8a0020,0xddcd0011,0xdb0011dd,0xcb34006b}},	//   tööd_, graţ, _famí, вецъ
  { {0x61f501e2,0x8afd0046,0x92a9002a,0x52d8000a}},	//   nizl, _neře, _załó, וודע_
  { {0x5fd3005d,0xba3d0046,0x8cd6000b,0x853c0091}},	//   _सवाल, _průs, _मॅपो, adėk
  { {0x0138011f,0xdb000089,0x3138000a,0xb8d60015}},	//   ורות_, _zamí, ונום_, عويض_
  { {0xf3900023,0xddcd0011,0x98c40024,0x9b880015}},	//   _bảng_, craţ, ētām_, _تنقل_
  { {0xab620020,0x69b9005d,0xf3900092,0x69d808e9}},	//   _üüri, _एचटी, _cảng_, ckve
  { {0xd5e80029,0xf770002b,0x2d8102b9,0x68250030}},	//   بعين_, _چاه_, ighe_, tódd
  { {0x7dd2002e,0x61f5003d,0x224000aa,0xe29a1fdd}},	//   _hæst, eizl, _puik_, пам_
  { {0x2bc7005d,0x42ba0010,0x27ff2437,0xd7c8002b}},	//   _रचना, чыню_, mnun_, _تونه_
  { {0xdfd20086,0x75d50015,0x7a240144,0x65d50058}},	//   گير_, _سيعا, pòte, _سيعط
  { {0x9f9d002e,0x660600dc,0x25aa002b,0xc0e617bd}},	//   tæðu_, ékke, _رضوی_, ховк
  { {0xdfd20115,0x8fa30ea6,0x27ff2438,0x7dd21a93}},	//   دير_, ласе, nnun_, _læst
  { {0x27ff00f2,0xdb002439,0x9f9d001a,0xdee3159d}},	// [43a0] inun_, _mamã, ræðu_, готи
  { {0xdcee0064,0x7dd2243a,0xddcd0045,0x2c480061}},	//   _sabı, _næst, vraţ, _ağda_
  { {0x515b0008,0x7c960010,0xbddb0144,0x27ff001a}},	//   _מכיו, эрац, _suèc, knun_
  { {0xddcd0011,0x2026002a,0xab8319a5,0xdb000045}},	//   traţ, ówić_, гушк, _ramâ
  { {0x20000045,0xddcd0045,0x68080046,0xfaf20015}},	//   mnii_, uraţ, něde, دثا_
  { {0x6934002b,0x20000045,0xd9460015,0xa8a601d2}},	//   نکار, lnii_, رئتي, ерик
  { {0xde03243b,0x8b960010,0x27ff002e,0x38c8243c}},	//   _спри, _прач, fnun_, ظاتی_
  { {0x6c360029,0x27ff001a,0xfaa6243d,0x3b660015}},	//   _أفرا, gnun_, _пабо, _سُئِ
  { {0xd5b0003b,0x8f9b011f,0x59ab000b,0x20000d54}},	//   لفة_, ליקי, _टोकर, inii_
  { {0x7dd20134,0xa96a006b,0x6b82243e,0x0000006a}},	//   _gæst, _хижа_, lgog,
  { {0x8afd0089,0xe8df0092,0xf3ff016e,0x99f5005e}},	//   _veře, _tiềm_, tnã_, _ряті
  { {0x3211002a,0x9cd7000a,0xd8db004f,0x0000006a}},	//   wozy_, גוטה_, _מקבר,
  { {0xf3900092,0xf6d30015,0x8bd7000a,0x82370015}},	//   _tảng_, _مزود, תוכו_, فرسا
  { {0xddcd0007,0xd5b80024,0xf3900016,0x60d5002a}},	//   kraš, rmās_, _uảng_, tyzm
  { {0x3d1f005d,0xc60c000b,0x64a302d9,0x61f50061}},	//   _भरें_, सकीय_, _баја, rizl
  { {0xe8df0092,0xddcd0007,0x64850053,0xbfa80010}},	//   _hiểm_, draš, _סעפּ_, нтуе_
  { {0xe8df0023,0x6fd80cb1,0x60180033,0xc91d000b}},	// [43b0] _kiểm_, _mích, хцёр_, _फर्म_
  { {0x02fc04dc,0x12fc000a,0x44dc0016,0xddcd006f}},	//   _מלחמ, _מהחב, ỏ_, fraš
  { {0x70550086,0xc5f30053,0x6fd8002d,0xdb510015}},	//   _جنجا, נדע_, _oích, لَا_
  { {0x6d58002e,0x0056000a,0x68250030,0x0000006a}},	//   ðvar, _ששרת_, zódb,
  { {0xf9910029,0x28a6000b,0xd358000a,0xddcd0091}},	//   لبث_, _कैबि, תידי_, araš
  { {0xe9d8008f,0xbef6000a,0x4429243f,0x0000006a}},	//   нкі_, _יצרו_, _lha_,
  { {0xcd37002b,0x27ff001a,0xd262003d,0x07a50974}},	//   _سرسب, tnun_, _ziņā_, вайн
  { {0x44290092,0xe7392440,0x764200da,0x27ff2441}},	//   _nha_, мей_, _buoy, unun_
  { {0x27ff002e,0x6fd8002d,0xa3bb000b,0x5a350c6e}},	//   rnun_, _dích, घाई_, _анат
  { {0x44292442,0xad850033,0x68080046,0x8a370058}},	//   _aha_, евiч, věde, _أعرض
  { {0x7c3b003f,0x09b60053,0xd7950015,0x85940033}},	//   _kiur, _שפעט_, _للاخ, ушыц
  { {0x44290f4d,0xc2090008,0xc2c60015,0x9f400003}},	//   _cha_, _וה_, نيجي, phié_
  { {0x44dc0092,0xd24f0029,0x7c290034,0xf7180033}},	//   ả_, ينَ_, _mher, _пішы_
  { {0xdb0002c1,0x64c50015,0x412a00f4,0x4429007c}},	//   _jamá, _ليتل, дого_, _eha_
  { {0x7c290176,0x703a0010,0x86240010,0xc952000a}},	//   _oher, дчас_, _сьце, שמל_
  { {0x20000011,0x64430011,0x65630293,0xc003049d}},	//   unii_, _iuni, _henh, апск
  { {0x9d461191,0xfe4316d7,0x8fa30e4d,0x74a9000b}},	// [43c0] везд, инто, шате, टिकृ
  { {0xc3330008,0xc27b039e,0xddcd2443,0xbf22000b}},	//   _דוח_, _קריי, traš, _मरीन_
  { {0xa3c9021e,0x7c3b1501,0x64432444,0x65632445}},	//   लॉक_, _biur, _juni, _menh
  { {0xad250029,0xddcd0007,0x7c292446,0x644303b8}},	//   اركو, rraš, _cher, _muni
  { {0x64432447,0x2b4000bc,0xbaba0015,0x6b822448}},	//   _luni, žico_, بداء_, rgog
  { {0x656303af,0xddcd2449,0xed58006f,0x44dc0016}},	//   _nenh, praš, _ýľ_, ỷ_
  { {0x98c30063,0x67fe003d,0x2ca7063b,0xc173000a}},	//   исъл, līji, ændt_, בחו_
  { {0x7c3b0824,0xd6da03e7,0x69c500d5,0x29000045}},	//   _giur, дто_, öher, ăia_
  { {0x6825005c,0x99a400dc,0x2bab000b,0x960a0033}},	//   wódc, őtől_, _घोटा, дэна_
  { {0xc1d1005d,0x65630026,0xdb0c0020,0xe8df0092}},	//   _सकेग, _cenh, öhõi, huộc_
  { {0x9dd70008,0x7d7b000f,0x44dc0016,0xddc4036d}},	//   דויק_, וניו, ủ_, križ
  { {0xa7850002,0x65630161,0x64430cc4,0x0595002b}},	//   _مشهو, _eenh, _duni, پایگ
  { {0xa3c9005d,0xc594000d,0x44290134,0xc3540015}},	//   लॉग_, _билј, _vha_, شَّع
  { {0x67fe0024,0x65630026,0x35d3004a,0x069705bd}},	//   dīji, _genh, _вошё, _סדום_
  { {0x629a04f9,0x656800e8,0x859b00f3,0x4429244a}},	//   ătoa, madh, _חשוו, _tha_
  { {0xf537000a,0xf3f00015,0x6e3c244b,0x6568244c}},	//   _בנוי_, _وأي_, _airb, ladh
  { {0x6e3c0064,0x40340894,0x3d9500a4,0xbfa8006b}},	// [43d0] _birb, ретс, лиар, ътре_
  { {0xf41f0945,0x3f730023,0x7c29244d,0x8d7400a2}},	//   llä_, ệu_, _sher, لاما
  { {0x6e3c0007,0x7c290026,0x7d1c0026,0x70940033}},	//   _dirb, _pher, _cyrs, _каэф
  { {0x63ad0005,0x2d870050,0x50da000a,0x6568003f}},	//   _jaan, żne_, _נקרא, hadh
  { {0x600801e4,0xdb000089,0x7c3b0251,0x9a870180}},	//   _יִשְ, _pamá, _viur, туел
  { {0x7c290041,0x7d1c05d8,0x68350091,0x63ad244e}},	//   _wher, _fyrs, _išdi, _laan
  { {0x3da4010f,0x28a6005d,0x7c290b00,0xb9920015}},	//   _тряб, _कैदि, _ther, صليب
  { {0x656303af,0x7c2901cb,0xab9b0015,0x63ad244f}},	//   _senh, _uher, _تخسر_, _naan
  { {0x65680f4d,0xc99b0015,0x7e6d2450,0x65632451}},	//   fadh, _يخطط_, nsap, _penh
  { {0x656800dc,0xcc75000a,0xe5710015,0x6fd8016e}},	//   gadh, ְעָה_, حطة_, _víci
  { {0xe3660080,0x2452002b,0x6563016e,0x35c8000b}},	//   лкни, ینیس, _venh, ाउज़
  { {0xf1a90008,0xa93a0053,0x6568003f,0x185a000a}},	//   _מס_, _װײני, aadh, _נכנע
  { {0x656303af,0x6568003f,0x92f60484,0xc7b2000a}},	//   _tenh, badh, учні, _לבא_
  { {0x9b16000a,0xb2f5004a,0x64431650,0x2005001a}},	//   רחשה_, ряющ, _tuni, élin_
  { {0xb21b00fb,0xe0d50191,0xdb0000b8,0xf5560067}},	//   kræf, ають, _unmö, _صليب_
  { {0x63ad00b6,0xdce70089,0x67fe0024,0x8c430064}},	//   _gaan, ůměr, tīji, ışla
  { {0xd0070080,0x7e6d02f2,0x7d1c2452,0x539b004f}},	// [43e0] уете_, gsap, _syrs, _טיקו
  { {0xcf25003b,0xe0580086,0x67fe0024,0x6f1d002a}},	//   شرقي, _لیست_, rīji, _dysc
  { {0xb33b03af,0x63ad003f,0xe5f60053,0x67fe0024}},	//   meça, _yaan, נזער_, sīji
  { {0x6e3c00b8,0x8146002b,0x8afd0046,0xb21b02de}},	//   _wirb, _جنگن, _seřa, stæt
  { {0x7e6d00dc,0x853c0091,0xfb87002b,0xc017004f}},	//   csap, ldėt, ادمی, _תקכו_
  { {0x7df4002a,0x9f52001a,0x48aa012f,0x9d43042d}},	//   ińsk, ábær_, етим_, _герд
  { {0x2019022d,0x853c0007,0xed350033,0xfce60eaf}},	//   _yksi_, ndėt, _вэтэ, _сово
  { {0x61d1005d,0x9f49002e,0x27e2002e,0xd8b70015}},	//   _सक्ष, nnað_, ókn_, ادوا_
  { {0xeef70053,0x98ae0061,0x7bc00394,0x9b06004a}},	//   ָמיר_, rafı_, _inmu, _сзад
  { {0x1a9b0053,0x63ad0bc9,0x0ae900c3,0x68250125}},	//   _אימע, _saan, _شرقي_, róda
  { {0x63ad00b6,0x4d7b00b2,0x4e170008,0x7d7b0053}},	//   _paan, ערטע, רחיב_, ענטו
  { {0xd6d9005c,0x682500dc,0xccf30008,0x5335058b}},	//   był_, lódn, מכת_, иент
  { {0x2d9812b3,0x926b0033,0x11d90015,0x63ad2453}},	//   _obre_, эрна_, نوحة_, _vaan
  { {0x63ad000c,0x8556002b,0xe737006b,0xcb13000a}},	//   _waan, _حیدر_, _сеч_, מלר_
  { {0x9f490084,0x88980008,0x6fd80251,0x2005001c}},	//   fnað_, כֹּה, _lícu, élio_
  { {0x9f49002e,0x60180080,0x94730115,0xf3cb0015}},	//   gnað_, гося_, _ادوا, _سببه_
  { {0xb33b001c,0x8c430064,0x853c0007,0x179b0053}},	// [43f0] beça, ışma, adėt, עימב
  { {0x6b8902d7,0xa2270015,0x7bc00012,0x853c0091}},	//   _sceg, _حربه, _anmu, bdėt
  { {0x67fe0048,0x8d740029,0xd6d9005c,0xa3e9000b}},	//   līju, صالا, zył_, _यता_
  { {0x78510024,0x9f4b008c,0xab9506f7,0x2d980781}},	//   _jāve, ämät_, риді, _ebre_
  { {0xb5fd0007,0xe8df0092,0x2ddb0015,0x29f6002a}},	//   aršy, _kiệm_, _كبسة_, ałam_
  { {0x291e00c0,0x42dc0053,0xcd370086,0x68250030}},	//   _byta_, עקגע, _مرزب, gódn
  { {0x5dc80008,0x31580008,0xc174000a,0x71bc000a}},	//   _עֶשְ, ניהן_, צחק_, תצוג
  { {0xccf20008,0x7df4005c,0x7851003d,0xddc40045}},	//   _וכל_, yńsk, _nāve, psiţ
  { {0xda780063,0x6aa9003e,0xba740015,0xd7ee0015}},	//   _бях_, _usef, _هالت, بكي_
  { {0x67fe0048,0xdcf501e2,0xe8df0092,0xab5d005c}},	//   dīju, _hazı, _niệm_, _tożs
  { {0x8406005e,0xf2c9000a,0x69c11c5c,0xdcf50061}},	//   ипож, _קע_, _inle, _kazı
  { {0x672e0014,0x33f6005e,0xddc40091,0x68250030}},	//   önjü, рчос, isiš, módo
  { {0xe9ff0023,0x52a7006b,0xe1ff002a,0x68250030}},	//   _luận_, авям_, nsów_, lódo
  { {0xd9e5005d,0xca35000a,0xdcf50061,0x70b3000b}},	//   कसित_, ינָה_, _lazı, ुमूल
  { {0x05960086,0x9f49002e,0x853c0007,0xb33b12b3}},	//   _خانگ, tnað_, udėt, reça
  { {0x682500dc,0xf106000b,0xe1ff002a,0x853c0091}},	//   zódn, _रशीद_, ksów_, rdėt

  { {0x8d66005f,0x67fe0024,0x9f49002e,0x0d560015}},	// [4400] ивае, cīju, rnað_, لخاد
  { {0x957c0050,0xb21b0e5f,0xddd4002a,0x68350091}},	//   wiąz, græd, _żało, _išdu
  { {0x3eb9018b,0xdcf50064,0x717b0008,0x7b6603ad}},	//   _erst_, _bazı, _בניס, атле
  { {0x61fc01e2,0xcdc900b2,0x9f060086,0x3218005c}},	//   lirl, וך_, _نوجو, lory_
  { {0x61fc0125,0x68250030,0x853c0091,0xff650030}},	//   oirl, tódn, ndėr, öéől_
  { {0x42db0053,0x61fc2454,0x291e002a,0xb8b60058}},	//   כקנע, nirl, _pyta_, لإعت
  { {0x07e60001,0x99650036,0x67fe003d,0xc173000a}},	//   ицим, стіл, zīju, קחה_
  { {0xd90d0074,0xdb00002c,0x61fc2455,0xc053000a}},	//   رین_, _pamä, hirl, חזה_
  { {0x61fc0064,0x26060036,0x28a6000b,0x4b7b000a}},	//   kirl, ичог, _कैरि, _שאמו
  { {0x7c222456,0xf8b80016,0xd9430cab,0x44220079}},	//   llor, _trĩ_, _дефи, elk_
  { {0xdcf501e2,0x47d60086,0x07a60010,0xc8ca0087}},	//   _yazı, _پيشر, _ваен, _جوان_
  { {0x67fe0048,0xa2b3000b,0xb7d30015,0xe7830280}},	//   tīju, इटल्, _وقلب, _душо
  { {0x61fc1736,0x44250024,0x06540031,0x5c37004c}},	//   firl, ēl_, _انتح, ירטן_
  { {0x67fe0024,0xd9f8005d,0x32182457,0x7a2d001a}},	//   rīju, ्चित_, gory_, rútg
  { {0x67fe0048,0x04c70015,0x8c430061,0x3f67012e}},	//   sīju, _نووي_, ışka, итаб
  { {0xe53b0008,0x653b0008,0x645a2458,0x33f40015}},	//   _בתור, _בעוד, mpti, _وسيس
  { {0xb33b001c,0xd9f8005d,0x61fc2459,0xb21b0134}},	// [4410] meço, ्चात_, birl, træd
  { {0x3eb900bd,0xf1ab0086,0xd6570008,0x22290086}},	//   _vrst_, _شاخه_, יימת_, _حزبی_
  { {0x7234003b,0x68080089,0xe9ff0092,0x0c870010}},	//   _بريط, vědn, _quận_, рызм
  { {0x645a0007,0x628000dc,0x6801003d,0x1c4401c6}},	//   ipti, ámog, pēdi, інім
  { {0xd5b10092,0x6fd81967,0xfaa7054c,0xdd030061}},	//   hóa_, _víct, ршен, ğrıl
  { {0xbf360008,0xe1ff002a,0xba3d0046,0x224901c2}},	//   _לארץ_, rsów_, _hrůz, _muak_
  { {0xfb87008f,0x6ce40036,0xab870033,0x3ea9245a}},	//   _вызн, _діте, _вузк, lwat_
  { {0x1a680086,0x3f890026,0x3ea900aa,0xac190054}},	//   _چینی_, ngau_, owat_, _собу_
  { {0x19590256,0x501c000a,0xe6191adc,0x645a039f}},	//   _базы_, כוהו, лди_, epti
  { {0x69c1003e,0xa2c6005d,0xc485245b,0x99d40015}},	//   _unle, ामस्, блок, _وتلا
  { {0xf5050015,0xd90f002b,0x61fc1622,0x3218245c}},	//   صِحُ, _تیغ_, virl, vory_
  { {0x5c9a0053,0x3ea900d9,0x3218005c,0xbc19000a}},	//   נשרײ, kwat_, wory_, רוֹש
  { {0xddcd03eb,0x13a80086,0x43930010,0xe7300086}},	//   mpaņ, هنگی_, чаўс, _قصه_
  { {0x7583009a,0x64a50138,0x2588005a,0x0000006a}},	//   _بیدم, _гака, _vůlí_,
  { {0xddcd002a,0x50b50120,0x25a5245d,0x3ea901d7}},	//   braź, осту, mell_, ewat_
  { {0x037a0086,0x10090015,0x61fc0061,0x3218245e}},	//   _صحبت_, لتقى_, sirl, sory_
  { {0xf4130008,0x62800030,0x3ea902f2,0xbe660015}},	// [4420] _מפה_, ámod, gwat_, صهاي
  { {0x63a6245f,0x25a52460,0xa2f7000a,0x62890046}},	//   lekn, nell_, _למפה_, ámoř
  { {0xec7a0124,0x1d19008f,0xb5fa0053,0x3ea90035}},	//   упе_, аюць_, נלעכ, awat_
  { {0xb09b0008,0x68080089,0x28bd000b,0x6286008c}},	//   _גיטר, vědo, ्मनि, ouko
  { {0xeafa0031,0x3d18000b,0x2c0b002b,0x62862461}},	//   درات_, _बुरे_, دعلی_, nuko
  { {0xf9c4002b,0x25a500cb,0x9a670015,0xb4c7000b}},	//   تحصی, jell_, حمول_, _ईपू_
  { {0x6abb003f,0x7c222462,0xddcd002a,0xdce7002a}},	//   _eruf, plor, yraź, _odję
  { {0x62860c8d,0xa8470015,0xaa460033,0x68250030}},	//   kuko, حليم_, _геал, lódj
  { {0xe9ff0023,0x25a51519,0x6abb2463,0xf1a8000b}},	//   _quản_, fell_, _gruf, ग़ान
  { {0x54980010,0x78bc001c,0x44980286,0xe5c609c3}},	//   авоў_, _árvo, авою_, ссио
  { {0xd4970080,0x1dc9005d,0xd5b70080,0x70d2000b}},	//   бря_, रातत, ссы_, सहोल
  { {0x88c50015,0x224907c8,0x63a62464,0x645a2465}},	//   _بتكل, _puak_, gekn, rpti
  { {0xb33b001c,0x62860020,0x224101d7,0x25a52466}},	//   reço, guko, _pihk_, bell_
  { {0x07370008,0xe6770008,0xeab1000f,0x415402d9}},	//   _האדם_, _פתוח_, וֹל_, зврс
  { {0xba3d0089,0xcf9b000d,0xf2df0011,0x2615000b}},	//   _průz, лја_, ecât_, नकरी_
  { {0xa857000a,0xb5050015,0x63a9007c,0x62862467}},	//   מילה_, _بظهو, õend, buko
  { {0xe3b00015,0x1dc50015,0x752f002a,0x9df92468}},	// [4430] _سري_, يْرِ, ęcze, анат_
  { {0xdce70050,0x644a003f,0x3ea9005c,0x0657000a}},	//   _zdję, _kufi, rwat_, ציבך_
  { {0x21270092,0x40950015,0xa50b000a,0x7c84033d}},	//   _ánh_, _بلجر, ְּבִ, зуче
  { {0x60da0020,0x6abb002e,0x1d34005e,0x661a06c0}},	//   ätme, _pruf, їнця, hotk
  { {0xa9690feb,0xf42a008c,0xdce90061,0xfbd00015}},	//   аила_, lvää_, ınıf, عتم_
  { {0x200900c5,0x828c000a,0x0dcb2469,0x4879033d}},	//   lnai_, רְאֶ, _суми_, асия_
  { {0x25a5246a,0x20090091,0x62860012,0x644a0d91}},	//   vell_, onai_, zuko, _nufi
  { {0x8699000d,0x6abb246b,0x25a5246c,0xab940054}},	//   атот_, _truf, well_, _насљ
  { {0x7bcd0024,0x7a540029,0xb5d90015,0x7851003d}},	//   ķaud, _فضلا, لبدء_, _dāva
  { {0xceb4000f,0x661a0085,0xb33b0061,0x286b0099}},	//   ליפ_, gotk, reçl, _брдо_
  { {0xf9900015,0xc329000a,0x200901d7,0xf7950033}},	//   _سبل_, _סו_, knai_, _мажэ
  { {0x6286246d,0x59c7000b,0x68250030,0xeaa70040}},	//   tuko, लावर, zódj, وع_
  { {0x8c1a013a,0xf77000e5,0x15f50015,0x661a14a7}},	//   שורי, _سان_, _وستح, botk
  { {0x8236003b,0x27ff00e8,0x63a600dc,0x20090f28}},	//   ترجا, liun_, sekn, enai_
  { {0x6286246e,0xa06a042d,0xd5b8003d,0x27ed0012}},	//   suko, раба_, klāj_, ohen_
  { {0x24750024,0x54360086,0xf8b2000a,0x99dd0046}},	//   mām_, _برتر, ושל_, _buňk
  { {0x4420246f,0x7643003f,0x2636005c,0x24750024}},	// [4440] _iki_, _kiny, _głos_, lām_
  { {0x787000dc,0xe8df0016,0x2d960033,0x8d5a0481}},	//   _jóvá, huốc_, ўрас, ршат_
  { {0x24750048,0xdd8f0029,0x44201ca2,0xa3ce000b}},	//   nām_, ضون_, _kki_, राप_
  { {0xeb9a0083,0x764300b6,0x27ed00bc,0xf0b7000a}},	//   рид_, _liny, jhen_, _ולטר_
  { {0x05a9005d,0x539b0008,0xa9230089,0xddd60091}},	//   क़ाब, שינו, ížno, aryš
  { {0x7643025c,0x24750048,0x27ed177b,0xe9f70010}},	//   _niny, kām_, ehen_, оніі_
  { {0x24750048,0xe7861797,0xd9430054,0x44202470}},	//   jām_, оупо, мељи, _oki_
  { {0x24750048,0x7df4005c,0xa3ce000b,0x5c5b000a}},	//   dām_, ańst, राफ_, _כדלק
  { {0xa3ce005d,0xceb3000a,0x644a2471,0x95ca04b4}},	//   रान_, ֥ית_, _sufi, ауна_
  { {0x44f40036,0xf42a00f2,0x44202472,0xab090015}},	//   зпос, yvää_, _aki_, _اتفق_
  { {0x656a0084,0x24750024,0x76430049,0xe7aa004a}},	//   _vefh, gām_, _diny, _ввел_
  { {0x27ed0bcf,0x27ff0011,0x02d90021,0xdb0b0030}},	//   chen_, ciun_, موجب_, ldgá
  { {0x442000e8,0x5344006b,0xa3440033,0x661a2473}},	//   _dki_, дхра, дэрл, potk
  { {0x24750048,0x06650086,0x44202474,0x3567006b}},	//   bām_, _راهپ, _eki_, _дрън_
  { {0x64580d17,0x29f6005c,0x24750024,0xd48f02a3}},	//   _utvi, sław_, cām_, _юр_
  { {0x35e0005d,0x187b0053,0x7f07005e,0x5e450015}},	//   _पकड़, יטלב, оїзд, كَرْ
  { {0x54340074,0xc7d70008,0x6b51001a,0x6e940b1e}},	// [4450] _ترور, קומי_, _lógó, миту
  { {0xdcbb0725,0x61ee0012,0x443901fd,0x0e340248}},	//   ище_, chbl, lms_, дную
  { {0xe2140015,0x44392475,0x91bc004f,0x4f670058}},	//   _تبيع, oms_, _כמזי, _واحف
  { {0xf5370053,0xc4d3039e,0xfc300015,0x4bd8002b}},	//   קטאר_, וגע_, نحن_, يبند_
  { {0xeab30029,0xd5b80024,0x44392476,0x161a000b}},	//   بعض_, glāk_, ims_, नकार_
  { {0x7f3a009d,0x314b000a,0xa9660190,0x75ed006f}},	//   _לערו, ׁתְּ, пиша_, _kúze
  { {0xa3ce005d,0x68251043,0xc19c000a,0x27ed1e13}},	//   राम_, lódi, ישגי, then_
  { {0x24750024,0x4439016f,0xf7710031,0x75ed163c}},	//   vām_, jms_, راب_, _múze
  { {0x44320026,0xe945002b,0x86c5002b,0xeab000c3}},	//   _rhy_, _فرای, سيدن, _لعل_
  { {0x24750048,0x443900df,0x27ed06e8,0x27ff00e8}},	//   tām_, ems_, shen_, siun_
  { {0xec35004c,0x4420050b,0x4ddc000a,0x27ed2477}},	//   ּאָר_, _pki_, יחזו, phen_
  { {0x24750024,0xdce70089,0x38350139,0x889a000a}},	//   rām_, _nejč, _энер, _לבעי
  { {0x24750048,0xa3ce005d,0x61ee0034,0xd6ab00c3}},	//   sām_, राब_, thbl, _خدام_
  { {0x24750048,0x66ba0008,0x4432003e,0x68250030}},	//   pām_, _למנה, _why_, dódi
  { {0x35f80086,0x4432003e,0x442000e8,0x200c001c}},	//   _برند_, _thy_, _tki_, édio_
  { {0x8ca6000b,0xd47a000a,0xb4c9000b,0xddcd0091}},	//   _टैगो, _האקל, ोही_, graž
  { {0xd5b10092,0x1e860033,0x68130045,0xdb0b001a}},	// [4460] hóm_, ялам, căde, ldgæ
  { {0x42fb0008,0x645c0125,0x66012478,0x63b62479}},	//   _להפס, írig, nilk, _hayn
  { {0x63b601e2,0xddcd00bd,0x11db0008,0xdd8f0002}},	//   _kayn, braž, _החיב, اوم_
  { {0x20570053,0x9057004f,0x13b7004f,0x63b61a0f}},	//   _מיטל_, _מבטו_, ּ֔אל_, _jayn
  { {0x682502c1,0x63b6247a,0x6601247b,0x0000006a}},	//   códi, _mayn, kilk,
  { {0x89d80029,0x8277004c,0xee3700fd,0x2d8c0723}},	//   توتر_, לענע_, _ння_, _øde_
  { {0xe8380010,0xa8a30010,0xb21b0134,0x6601247c}},	//   опкі_, ерык, kræn, dilk
  { {0x7ceb0008,0x5c7b000a,0x010d015b,0x6c7b000a}},	//   _הַמֶ, _לאלה, ילוּ, _לאלפ
  { {0x61fe0251,0x86260010,0x9634247d,0x660104d1}},	//   _ompl, зьне, мниц, filk
  { {0xf9c40086,0x4a5b000a,0xba0a0015,0x7a2d006f}},	//   _تحری, _לדמו, _اترك_, lútn
  { {0xdcfc0064,0x69c8247e,0xb21b001a,0x68250030}},	//   _karı, _inde, fræn, zódi
  { {0xb21b00fb,0x7ae2003f,0x443915ff,0x21ef0012}},	//   græn, oyot, ums_, _mühe_
  { {0xe9ff0092,0xddcd247f,0x44392480,0x752f002a}},	//   _quần_, nsaţ, rms_, ęcza
  { {0x69da00f2,0x867b000a,0xdcfc0061,0x22450123}},	//   _jote, _פרוו, _ları, ölk_
  { {0xddcd010b,0x859b0008,0xd59b0008,0x3c2e002c}},	//   traž, _השוו, _הבול, zýva_
  { {0xe9ff0023,0x0ec8000b,0x61fe16c8,0xa3ce000b}},	//   _tuần_, रमंड, _empl, राण_
  { {0x69c82481,0xe9ff0092,0xadb500d0,0x93fc000a}},	// [4470] _onde, _huấn_, мбаш, _ללהי
  { {0xd5b80024,0x9f49002d,0x69da2482,0x68252483}},	//   ndā_, mhaí_, _note, ródi
  { {0xdcfc0064,0x6825001c,0x26c00007,0xc19a000a}},	//   _barı, sódi, _šiol_, _ושתי
  { {0xd7e60029,0x3eb200f2,0xf1b9003d,0xc7b90030}},	//   _شك_, äntä_, ēšu_, rlők_
  { {0x89d50036,0x8aa70010,0xa3ce021e,0x160c000b}},	//   дійш, яржд, रात_, िचार_
  { {0xceb2013a,0xa8590001,0x38590080,0xd2b8000a}},	//   _שים_, ојих_, орию_, פלות_
  { {0xa9c40010,0x7c840164,0x66012484,0x69da2485}},	//   эсцк, _путе, vilk, _dote
  { {0x69c82486,0x2d8c068c,0x6601002a,0xab66007c}},	//   _ende, _öder_, wilk, rsüü
  { {0x69da2487,0xc68e0015,0x63b616c4,0x66012488}},	//   _fote, لِي_, _rayn, tilk
  { {0xd706005f,0xa37b0005,0x69da2489,0xb38f0046}},	//   ьные_, skõl, _gote, ážní
  { {0xdcfc0064,0x45450015,0xb21b02de,0x6d88000a}},	//   _yarı, بندق, træn, הָרְ
  { {0xd91a00b4,0xa3ce005d,0x68e3248a,0x6601248b}},	//   _וועל, राध_, mynd, silk
  { {0x8b9a000a,0x28bd000b,0x29f6002a,0x7a2d006f}},	//   חברת, ्मवि, płat_, núto
  { {0x3253004a,0x35d4004a,0x65c20033,0x229602de}},	//   твёр, _почё, _абша, ræk_
  { {0x3cf9005d,0xf1c3000b,0x32430148,0x0000006a}},	//   ्पों_, शाजन, терг,
  { {0xc7b900dc,0xdfd200e5,0x8fa3248c,0xddcd0535}},	//   ndő_, خير_, касе, araż
  { {0xdb000084,0x9f49002d,0x1dc9005d,0xddcd002a}},	// [4480] _samþ, chaí_, रांत, braż
  { {0x7ae2000c,0xee3712c9,0xdcfc0064,0x72360015}},	//   vyot, дну_, _sarı, _تربط
  { {0x1cba0015,0xd344002b,0x20050144,0x68250030}},	//   غائب_, _تفکی, èlic_, lódu
  { {0x14d6004c,0x60d7000a,0xec34002b,0x6286248d}},	//   וועל_, _חוטא_, روشگ, orko
  { {0xbb43008f,0xdcb10092,0x19580010,0x68e3002e}},	//   вецк, _ẩn_, палы_, eynd
  { {0xddcd04f9,0x98c60805,0x62860209,0x68e30827}},	//   rsaţ, дсил, irko, fynd
  { {0x68e300fb,0xdcfc0064,0x98a30001,0x69da248e}},	//   gynd, _tarı, вије, _vote
  { {0xb906005d,0xc6e60036,0xf093000a,0xd117000a}},	//   _पथ_, діоп, דנה_, וקצה_
  { {0x69da248f,0xddcd002a,0x76aa005e,0xab5d002a}},	//   _tote, yraż, ітив_, _noży
  { {0x752f005c,0x7bc90057,0x69c82490,0xd49a12ba}},	//   ęczn, _zneu, _unde, орм_
  { {0x35f7003b,0xd5b80024,0xe9ff0016,0x439508a0}},	//   بريد_, rdā_, _quấn_, нанс
  { {0x9f49002f,0xab5d002a,0xa6e600ce,0x0000006a}},	//   thaí_, _boży, _ожел,
  { {0xa2c6005d,0x2508002b,0xddcd002a,0x96960004}},	//   ामग्, ترکی_, traż, _цреш
  { {0xe9ff0092,0xab5d002a,0x9f490125,0xe707002b}},	//   _tuấn_, _doży, rhaí_, _تسمی
  { {0x3015000d,0x9f400125,0x62862491,0xc105012c}},	//   едвр, chiú_, arko, روري
  { {0xb21b0084,0xdb000ef0,0x747b004f,0x0000006a}},	//   mræm, _samý, _ונהג,
  { {0x34380058,0xf0440138,0x0000006a,0x0000006a}},	// [4490] _تسود_, тэро,   ,
  { {0xc7b900dc,0x25ac0026,0xc334004c,0xa697000a}},	//   zdő_, nedl_, _שוץ_, וכמה_
  { {0xc53401d8,0xdcfc003d,0x7bc92492,0x3d942493}},	//   תָּה_, _marķ, _pneu, тихр
  { {0xdab90010,0x7a2d006f,0xdb00002a,0xc7b90030}},	//   зыкі_, túto, _namó, plői_
  { {0x7eb8002d,0x442b0125,0xab760015,0x2ef40033}},	//   rúpá, ilc_, رموا_, _азяр
  { {0x7bc90176,0xe9d80010,0x48b50063,0x1c00000b}},	//   _wneu, мкі_, ещит, लोबल_
  { {0xadab0054,0x4c17002b,0xdcee002a,0xf8920004}},	//   удeн, _قبرس, _odbę, гајќ
  { {0xbddb0152,0xd7750029,0xdb00002d,0xbb840015}},	//   _guèr, رابع, _camó, _للفي
  { {0xd70903ad,0xa3ce000b,0xda150054,0x3c352494}},	//   яние_, रास_, _здањ, gåve_
  { {0xceb2000a,0xb33b0144,0x09b80015,0x75ed0030}},	//   ניי_, neçu, _يطلع_, _búza
  { {0xdc39000a,0xdb000144,0x752f002a,0xe01f000b}},	//   ּעָר, _famó, ęczo, पवाद_
  { {0xab5d005c,0x44240016,0x62862495,0xf8b2000a}},	//   _poży, ôm_, trko, _תשא_
  { {0xc7d6000a,0x7c2b081d,0x62862496,0xe60e07c9}},	//   _רוני_, ilgr, urko, _бд_
  { {0xdb00005c,0xd24f0015,0xe2a7001a,0x2bc6000b}},	//   _zamó, صنف_, óðar_, _रोना
  { {0x1c1f005d,0xc952000a,0xf8a70015,0x30751114}},	//   यकाल_, רמל_, دة_, кутс
  { {0x62860085,0xb4fa000a,0xa3ba002b,0x34fa004f}},	//   prko, _מפצי, _رابر_, _מהצד
  { {0x44222497,0x63a40035,0x8d6605b3,0x92b60015}},	// [44a0] mok_, _ibin, евзе, _أحبا
  { {0xad650074,0xa3ce005d,0x271e0016,0x2388002a}},	//   نامه, राव_, ịng_, łują_
  { {0x8d930029,0x44220556,0xfce30a1f,0x7d930021}},	//   المش, ook_, лофо, المؤ
  { {0x44222498,0x80d90065,0x0000006a,0x0000006a}},	//   nok_, _नॅटे,   ,
  { {0x63a4003f,0x5b2304ab,0x7a361671,0xdb0008f3}},	//   _mbin, льша, hâte, _ramó
  { {0x442211ac,0xc333000a,0xcb070015,0x427b004c}},	//   hok_, אוד_, عيون_, לאנג
  { {0x25ac0089,0x44222499,0xb8660015,0x22440069}},	//   vedl_, kok_, راثو, ímky_
  { {0x6ec4000b,0x25ac0034,0xb09b000a,0x8c43249a}},	//   रिपु, wedl_, ליצר, _бесе
  { {0xa6140001,0x628000dc,0xd5b80024,0xd7570021}},	//   кмич, ámol, klāt_, رجيا_
  { {0x5b35008f,0x63a40a54,0xceb3039e,0x7c22249b}},	//   _рэсу, _abin, ריז_, loor
  { {0xa37b0020,0xf99300a3,0x7c4702de,0x3eb20535}},	//   lkõi, _תרע_, _årræ, hwyt_
  { {0x2bc6005d,0x4422249c,0x4917000a,0xa8570643}},	//   _रोमा, gok_, _אקבל_, _נידה_
  { {0xa2be005d,0x55e6086e,0xe60f002b,0x44040033}},	//   शिष्, _подб, ششی_, учэб
  { {0x7c220150,0x94d40015,0xf743005e,0x6d5c0012}},	//   hoor, _ليتش, _сечо, _nfra
  { {0xa3ce000b,0x690b000a,0x7c22249d,0x4422249e}},	//   राश_, ִּלְ, koor, bok_
  { {0x629a0011,0x6d5c0541,0x4422249f,0x98bc0061}},	//   ător, _afra, cok_, navı_
  { {0xa3b80074,0x7e640035,0xa3ce005d,0x883b000a}},	// [44b0] _ساير_, gpip, रार_, לגלת
  { {0x867b000a,0x63bd24a0,0x7c2224a1,0x3d94009b}},	//   פרבו, ldsn, eoor, лиур
  { {0x55770053,0x7c220171,0x63a800dc,0x629d0c19}},	//   געבן_, foor, ődne, ltso
  { {0x539c0053,0x7c220020,0x96b1000b,0x63bd24a2}},	//   ּיגו, goor, _अनलॉ, ndsn
  { {0x629d03c0,0x6d5c0026,0x7f760008,0xd358000a}},	//   ntso, _ffra, _בערב_, גידי_
  { {0xc334000f,0x4422163c,0xc9840054,0x010b000a}},	//   נוס_, zok_, гући, ּלֵּ
  { {0xdb0b00dc,0x7c220150,0x44220a4d,0x7c2c0003}},	//   iegé, boor, yok_, éorè
  { {0x69d80796,0x9783002b,0x46a5004a,0x88c40067}},	//   ajve, ایشه, ваив, اتول
  { {0xdcee0089,0x44220ce3,0xd5b10015,0xcb080015}},	//   _odbě, vok_, لفظ_, _كيفن_
  { {0x628f02b9,0x4422050b,0x62800030,0x55e51215}},	//   duco, wok_, ámom, тооб
  { {0xa3ce005d,0xd7e70036,0x764a0026,0x4422163c}},	//   राल_, _підо, _dify, tok_
  { {0x45180033,0x629d24a3,0xe8d6004f,0x645c01d3}},	//   эцыя_, ftso, _בוער_, íria
  { {0x21f40020,0x629d02de,0x4b7a000a,0x442224a4}},	//   _lähe_, gtso, וארו, rok_
  { {0x442224a5,0x21ef007c,0x6d5b0061,0x7a88004f}},	//   sok_, _püha_, _şuan, עָרַ
  { {0x41270036,0x21f400b8,0x442224a6,0xf99200a3}},	//   воро_, _nähe_, pok_, ירם_
  { {0x63a4000c,0xc0e3000d,0xe3b20031,0xddcd007f}},	//   _ubin, шоск, _ضرب_, tpaş
  { {0x539b01c8,0xf77200b2,0x7c2200f6,0xcf46006b}},	// [44c0] _חיפו, יקן_, voor, тнай
  { {0x4d6306ac,0x7c2200f6,0x023a0015,0xb33b0061}},	//   икув, woor, _تثبت_, reçt
  { {0x7c221c62,0xc2c9002b,0xdca10033,0x8c460b59}},	//   toor, _قبیل_, йсцi_, веже
  { {0xe727003b,0x3178005c,0xcb0a0087,0x1bba0015}},	//   _نص_, larz_, ويان_, بائع_
  { {0x7f1a0036,0x7c220150,0xd357000a,0x5e460015}},	//   _ціну_, roor, דיני_, _لَحْ
  { {0x6934002b,0x645e0140,0x7c22143e,0x3178002a}},	//   هکار, _épig, soor, narz_
  { {0x63bd0134,0xa37b0020,0x09e3049d,0x23b2000b}},	//   ydsn, skõi, ројн, ज़ाद
  { {0x67f5002c,0xb21b0134,0x7aa60015,0x20120030}},	//   _nájd, træk, _لإطل, nnyi_
  { {0x2768002b,0x3178002a,0xda080016,0xdb0c008c}},	//   وشکی_, karz_, hỏi_, öhäi
  { {0xca97000a,0xb21b02de,0x0000006a,0x0000006a}},	//   _בדמי_, rræk,   ,
  { {0xdb0b00dc,0x96330010,0x3178002a,0xe8df0016}},	//   vegé, рнэц, darz_, _thềm_
  { {0xd5be0024,0x78fb0053,0xd7e30033,0x09290015}},	//   _šāda_, _קלאפ, _вішо, _أسكي_
  { {0xc7f7000a,0xf6d30015,0x61e10123,0x63af00bc}},	//   _בזאת_, _نزود, öllo, recn
  { {0x1677000a,0x9f490061,0x349407bd,0x629d24a7}},	//   _יגדל_, lhaç_, _бакр, rtso
  { {0x8637000a,0x67f50030,0xdb0b0030,0x7851003d}},	//   _שרוב_, _fájd, regé, _pāvi
  { {0x58bb0008,0x88bb000a,0x7feb005e,0x2d9824a8}},	//   ומלצ, וזלי, єєва_, _acre_
  { {0x2caa00e8,0xdd9b0036,0x442924a9,0x02a40033}},	// [44d0] _apbd_, дше_, _ika_, _крэм
  { {0x21f4007c,0x644d0034,0xfc67006b,0xadf424aa}},	//   _pähe_, _hiai, въдн, апуш
  { {0xdb510029,0x644d003f,0x270e000b,0x645e0003}},	//   مَا_, _kiai, ापुर_, _épid
  { {0x21f40020,0x8b94005e,0xddcd006f,0x7bf90033}},	//   _vähe_, иріч, dsať, энер_
  { {0x3c3502ce,0x200924ab,0xaa58007a,0xc9f50015}},	//   gåva_, miai_, вичу_, ُستع
  { {0x200900df,0x443b0092,0x2b830092,0x4efa01ac}},	//   liai_, _lhq_, ực_, _טהרו
  { {0x07a50036,0x69250010,0x78890015,0x7a2d006f}},	//   гайн, ымка, رَةِ_, núti
  { {0x200900df,0x628000dc,0x01380008,0x68010024}},	//   niai_, ámok, כרות_, lēdz
  { {0xa3d7005d,0x5b150001,0x0ab80015,0x67f524ac}},	//   सान_, _смат, _لطلب_, _náje
  { {0xf99300b0,0x7ae40fb2,0xb21b02de,0x62800091}},	//   _خبر_, äite, bræi, šmok
  { {0x240a0063,0x20090007,0x644d0999,0x4dda000a}},	//   енни_, kiai_, _biai, תחתו
  { {0xb8f7021e,0x67f50046,0x317824ad,0x787a004f}},	//   ाम_, _báje, warz_, _נָבו
  { {0x3178005c,0x200924ae,0x7bfa000a,0x92930033}},	//   tarz_, diai_, תפרצ, баўц
  { {0xcb36004c,0x27ed0a3a,0x867a000a,0x442924af}},	//   טארי_, lken_, _טרנו, _eka_
  { {0x644d0030,0x20090030,0x7a2d001a,0x859a000a}},	//   _fiai, fiai_, rúth, _נשקו
  { {0x3178005c,0x200924b0,0xd3da0015,0x27ed24b1}},	//   sarz_, giai_, _سببا_, nken_
  { {0x27ed0298,0x8f7502e1,0x25f7000b,0xc43b000a}},	// [44e0] iken_, русі, एसपी_, _אתקי
  { {0x7a2d002e,0xdd920031,0xb2bb000a,0x71fa002b}},	//   búti, صوص_, _טמפר, _سرخس_
  { {0x67f50089,0xa91c002c,0x27ed24b2,0x319b05bd}},	//   _záje, _odľa, kken_, _אבינ
  { {0x27ed0298,0xa3d7005d,0xddc40007,0x7c3b17ce}},	//   jken_, साय_, tsių, _chur
  { {0xab770031,0xddc40091,0xead4071f,0xd4910016}},	//   امها_, usių, роль, hù_
  { {0x27ed0298,0x2d83010b,0xddc40007,0xc333000a}},	//   eken_, _gdje_, rsių, צוג_
  { {0xf9690036,0x2fc00079,0x0000006a,0x0000006a}},	//   трій_, odig_,   ,
  { {0xd6da24b3,0x6c360015,0xccab000a,0x38340180}},	//   ето_, _إفرا, _אֱמֹ, јнир
  { {0xa3ce000b,0x644d0c1b,0xb9960067,0xb4cc000b}},	//   राई_, _riai, _مشاغ, रम्_
  { {0x442901d1,0xa96a0029,0xceb3000f,0x661c00bd}},	//   _ska_, _أمام_, צית_, črko
  { {0x2ed1005d,0xb4be000b,0x16370015,0xf8660054}},	//   _सप्त, ँटे_, دسية_, _свео
  { {0x07b70029,0xd91b0008,0x2fc00111,0x78ba00dc}},	//   _مهمة_, _אובל, jdig_, _istv
  { {0xa3d7005d,0x20090007,0x518724b4,0x2fc024b5}},	//   साब_, viai_, лува, ddig_
  { {0x54e60029,0x2fc024b6,0xe1ff0077,0x2ca6002a}},	//   _مسبق, edig_, apón_, łody_
  { {0xb21b0134,0xf55b0008,0x2ee90026,0x1017002b}},	//   kræv, _אדומ, wyaf_, هبرد
  { {0x087700b2,0x9f4000f2,0x442f002d,0x2fc00035}},	//   טעלט_, kkiä_, _óg_, gdig_
  { {0x33a8010f,0x200900df,0xce95006b,0x6e9524b7}},	// [44f0] _също_, riai_, разъ, ризу
  { {0x200924b8,0x78ba016f,0x61ee0012,0x6e3c006f}},	//   siai_, _ostv, ckbl, _chrb
  { {0x515a013a,0x200900df,0x27ed0064,0x361b000a}},	//   _בכתו, piai_, yken_, עובד
  { {0x200c0152,0xce950063,0x657a24b9,0xa3ce000b}},	//   édit_, _камъ, hath, राए_
  { {0x8f7a000a,0x0f7a05bd,0x8f19000a,0x3ea00144}},	//   _שנשק, _בארב, _יוֹת, ctit_
  { {0x88c50029,0x53380053,0x17ed000b,0xf8650511}},	//   لتعل, אנדן_, जस्व_, авко
  { {0x657a02a8,0x28c5000b,0x14b0000b,0x7c3b1095}},	//   dath, विधि, _जनगण, _thur
  { {0x657a002f,0x7c3b003f,0xc7ae0015,0x37e5004a}},	//   eath, _uhur, ِّي_, роиг
  { {0x27ed24ba,0xab2b0015,0x657a24bb,0x06960015}},	//   rken_, _أسأل_, fath, لنية_
  { {0x75550054,0x8698006b,0xd6a8002b,0x7aeb0091}},	//   шњиц, утът_, اديم_, mygt
  { {0x21f40020,0xa8a70063,0x64a51c64,0x5dc8000a}},	//   _näha_, _щрак, шана, אֶרְ
  { {0x787a000a,0x74130015,0xdc88000a,0x9346004a}},	//   _יָדו, ْوَا, נְתָ, инне
  { {0x66670080,0xb7bd0045,0xdb0b0045,0x657a24bc}},	//   _съез, ulţu, legâ, bath
  { {0xcb12000a,0xd5a3002b,0x6613009a,0x657a24bd}},	//   קלם_, _طلبی, _دژبا, cath
  { {0xab5d0050,0xc243008f,0xc0460015,0x601a0091}},	//   _każd, інск, لخرو, eįma
  { {0x2fda0086,0x2fc00161,0x90e70015,0x1f660418}},	//   خورد_, udig_, جِّل_, ркам
  { {0xe1fa0033,0xfe720015,0x6023008b,0xed5a1cf3}},	// [4500] _агп_, تدأ_, ідуа, воз_
  { {0xc27b00b2,0xa3ce000b,0x3ea024be,0x7aeb02de}},	//   _שריי, राक_, rtit_, dygt
  { {0x7a2d002e,0x8fa60afb,0x3ea00a5e,0xa2be0065}},	//   nútu, _кане, stit_, शिक्
  { {0xc50c0053,0x25f7000b,0x9f40008c,0x5ba5005e}},	//   עלאָ, एसडी_, tkiä_, йріз
  { {0x6288005c,0x7c660086,0xab270054,0x0d760033}},	//   ądow, _چارل, аоца_, _выбя
  { {0x28860054,0xd337000a,0x9f40008c,0x4df5009b}},	//   аћив, ברנה_, rkiä_, _ляст
  { {0xe4660064,0x44c50024,0x9f40008c,0xec77008b}},	//   önüş, _nē_, skiä_, _впс_
  { {0x21ef007c,0x4cbb000a,0x68ea0034,0xc7c624bf}},	//   _rühm_, _במלג, ryfd, рски
  { {0x8f9b00b2,0x657a24c0,0x48130033,0x56770033}},	//   דיפי, tath, ўмыс, абыя_
  { {0x26c000df,0x95d8000d,0x657a002d,0xba9b000a}},	//   _šios_, удот_, uath, _בסמי
  { {0x78ba018c,0x7d7b0008,0x657a24c1,0xce37000a}},	//   _ustv, כניו, rath, שאית_
  { {0xb6a6000d,0xb8dc000b,0xa3ce000b,0x7bc224c2}},	//   _видл, ेट_, राग_, ndou
  { {0xd6cf0015,0xf2e4004a,0x46a30033,0x6aa224c3}},	//   _يقم_, оюро, _мацв, ntof
  { {0xd6fb000a,0xa6fb000a,0x7a2d171f,0x657a00aa}},	//   _שִׁש, _שִׁי, sútv, qath
  { {0xe63b0008,0x16b6005d,0xdfd502bf,0xa63b000a}},	//   _שתוכ, _अनुब, бовы, _שגור
  { {0x74150074,0x7bc0013c,0xd25b006b,0xab620061}},	//   _دوبا, _namu, _ицо_, çülm
  { {0x64580005,0x200c0251,0xdb230064,0x70550086}},	// [4510] _huvi, èdia_, ürül, _گنجا
  { {0x645800f2,0x2ddb0015,0x9df8004a,0x7bc0008c}},	//   _kuvi, خبرة_, анут_, _aamu
  { {0xdcbb0063,0x721a000a,0xcb550015,0x5b550015}},	//   ъща_, _תותח, مناظ, مَاء
  { {0xab95005e,0x61e50012,0xdb0b0030,0x9b3d01f3}},	//   сиді, _hohl, segí, нфлi
  { {0x61e500b8,0x7bc00251,0x201e0003,0x67f5006f}},	//   _kohl, _damu, étie_, _nája
  { {0x6458001c,0x7ae40020,0x65780227,0x38c7002b}},	//   _ouvi, äita, _nevh, لاعی_
  { {0x61e50107,0xb8680054,0x6d550030,0x1057004f}},	//   _mohl, ајње_, _igza, בֹ֖ר_
  { {0xe73924c4,0xc054000a,0x96950eaf,0x39340033}},	//   лей_, חזק_, брош, цэіс
  { {0xdb0b0012,0x6a550015,0x5629006b,0x6abb24c5}},	//   ndgü, _طَائ, лжим_, _usuf
  { {0x7bc0044b,0xa5b90054,0x64580091,0x44c501ec}},	//   _zamu, ућих_, _buvi, _pē_
  { {0x645804f9,0xf4940146,0x98f40015,0x628f24c6}},	//   _cuvi, оряю, _وثما, erco
  { {0x9cd60008,0x6458016e,0x75ed0046,0x69c124c7}},	//   צורה_, _duvi, _múzi, _hale
  { {0x97560008,0x8c1a000a,0x9bb6000a,0xfbd2000a}},	//   _הינו_, רורי, זהרה_, פתך_
  { {0xeb3a0053,0xbb3a00f3,0x93430033,0x69c324c8}},	//   טערש, טערי, яняе, ndne
  { {0x61e5013f,0xab5d002a,0x69c124c9,0x628f24ca}},	//   _dohl, _zaże, _male, arco
  { {0xa37b0020,0x69c124cb,0x0000006a,0x0000006a}},	//   skõr, _lale,   ,
  { {0x38a1002d,0x0d560015,0x0d8624cc,0x64580012}},	// [4520] hór_, مخاد, йлан, _zuvi
  { {0xab8c0064,0x38a1002e,0xa7fc0064,0x8d560127}},	//   _çözü, kór_, _atıl, стач
  { {0x8b6a0608,0xc1bb000a,0x8236002b,0x2d950033}},	//   гиев_, _גמיש, _پرکا, ўрус
  { {0x4fb60015,0x7bc20046,0x9036002b,0x75ed016e}},	//   _اصدر, udou, _درخص, _dúzi
  { {0x64460091,0xa954005e,0x539b000a,0x7bc224cd}},	//   imki, оклі, רינו, rdou
  { {0xe2a7002e,0x69c11470,0x7bc00573,0xad26002b}},	//   óðir_, _cale, _wamu, _هرزو
  { {0xf1b3013a,0x823b0053,0xf8aa0029,0x91bb000a}},	//   פסה_, װעקצ, ادته_, רמצי
  { {0x0d17000a,0x67f50077,0xb8d0000b,0x69c324ce}},	//   _הקלט_, _pája, _ओह_, adne
  { {0xa3d7000b,0x69c124cf,0x8c430788,0x645824d0}},	//   सास_, _fale, _хете, _suvi
  { {0x38a1005c,0xceb301d8,0x69c124d1,0xd5ba24d2}},	//   bór_, ליח_, _gale, уси_
  { {0xa3b50033,0xddc60091,0x7a2d001a,0x61e50b85}},	//   обні, _atkū, rútt, _rohl
  { {0x69c10050,0x97c50015,0xb93705bd,0x61e50012}},	//   _zale, _وتنم, _פראג_, _sohl
  { {0xe2980010,0xa3ce005d,0x69c1003f,0x61e50107}},	//   баў_, राज_, _yale, _pohl
  { {0x64580fef,0x7afd0061,0x2bcf000b,0xdb0b0030}},	//   _tuvi, _üste, _सोना, negá
  { {0x27e624d3,0x5467011e,0x0000006a,0x0000006a}},	//   _koon_, _лајм_,   ,
  { {0x61e500b8,0x7a2d006f,0x2ef5005e,0x27e60158}},	//   _wohl, nútr, озбр, _joon_
  { {0x63ad00b6,0x6d480156,0x61e50089,0x9ed90010}},	// [4530] _iban, _údaj, _tohl, шмат_
  { {0xaac7005d,0x442b107d,0xa3d7000b,0x83340021}},	//   लिसक, loc_, साव_, _عريض
  { {0x5e440015,0x69c124d4,0x0000006a,0x0000006a}},	//   أَلْ, _rale,   ,
  { {0xb21b0134,0x6fb50029,0xeb900087,0x27e624d5}},	//   præs, _بمحا, فظه_, _noon_
  { {0x38a1002a,0x63ad0125,0xb4d5000b,0x4f9a000a}},	//   wór_, _mban, _सप्_, _דברצ
  { {0xe7a6005d,0xda78054f,0x7d240030,0x38a1001a}},	//   क्सप, сяц_, étsé, tór_
  { {0x41fa0053,0x68450b75,0x69c124d6,0xf7710015}},	//   יִקײ, онка, _vale, واة_
  { {0x166514f4,0xd0f8000a,0xda67002b,0x442b0144}},	//   овим, ממות_, _هائي, joc_
  { {0x27e60035,0x6b8900dc,0x7e6d0012,0x79a7029b}},	//   _doon_, _ideg, npap, _грее
  { {0x38a1002a,0x63ad24d7,0x7a2d001a,0x2924001a}},	//   pór_, _aban, rúts, árað_
  { {0x27e6020a,0x0446087a,0xca480070,0x98a50007}},	//   _foon_, женн, _الله_, _bylą_
  { {0x38850048,0xc1690dab,0x5c9a0053,0x2bcf000b}},	//   mēr_, _יח_, סשרײ, _सोमा
  { {0xe72e0191,0x645e0003,0x13030033,0x466b1377}},	//   _це_, _épin, дзям, _срем_
  { {0x27e60111,0x63ad24d8,0x7c2b24d9,0xd6e8004f}},	//   _zoon_, _eban, hogr, _לַצָ
  { {0xdfd20087,0xa889000a,0x6b89002a,0xa50601ca}},	//   ويس_, יָּ֥, _odeg, _меша_
  { {0x6b89003f,0xb4d5000b,0x25f7000b,0x34b2002b}},	//   _ndeg, समी_, एसवी_, _آميز
  { {0x7e6d025c,0xa3d7021e,0xc7b2000f,0x7c2b24da}},	// [4540] gpap, सार_, ובן_, dogr
  { {0x0d860127,0xfd3a0015,0xfd120040,0x6b8924db}},	//   ілен, لكذب_, وجا_, _adeg
  { {0xd5fa0053,0x7e6d0035,0xb6070024,0xad6500e6}},	//   ספער, apap, mašī, ساله
  { {0xcdc90008,0xb09b0643,0x5aca030c,0x35db000b}},	//   כך_, _דיטר, илем_, बाड़
  { {0x0ab60087,0xda77006b,0x6b890034,0x27e602f2}},	//   تحاد, оящ_, _ddeg, _roon_
  { {0x27e60041,0x2010002a,0xc866067a,0xc8c50065}},	//   _soon_, śnić_, отии, विंट
  { {0x2e2f00b8,0xdb0b1730,0x23ca000b,0x67fc0030}},	//   rüft_, regá, ियाद, _léje
  { {0x76aa0457,0x76740004,0x7a3f0003,0xeb970763}},	//   атов_, плиф, vête, _мис_
  { {0xda650015,0x7a2d001a,0x6a83012b,0x442b24dc}},	//   _فالي, rútr, _олта, voc_
  { {0x27e600dd,0xa9f8000a,0x63ad02b9,0xe4a60294}},	//   _woon_, _פִּת, _sban, ормо
  { {0xa3d7005d,0x957c005c,0x2609000b,0x1c0a000a}},	//   साल_, ejąc, ाफ़ी_, ֹלָ֑
  { {0x7a3f0152,0xd37b0004,0x7e6d24dd,0xd40700ce}},	//   rête, шчо_, ypap, іяни
  { {0x68130045,0xe7370054,0x442b24de,0x753d0535}},	//   gădu, _дец_, roc_, ęsza
  { {0x67fc0a8b,0x0737000a,0x442b24df,0x0000006a}},	//   _déje, _ואדם_, soc_,
  { {0xba3d0089,0x957c005c,0xc05b0036,0x67e5004c}},	//   _způs, ając, ріг_, _קאָמע
  { {0x6825005c,0x6d580007,0x63ad0b63,0xb4fb000a}},	//   wódz, žval, _uban, _כלור
  { {0x0378000a,0x7ae4007c,0x8d77006e,0x9df901e9}},	// [4550] _ותחת_, äitl, قاضا, бнат_
  { {0xf2d200b2,0xe2a7002e,0x6b8902b9,0x7e6d24e0}},	//   _װעט_, óður_, _sdeg, rpap
  { {0x6ce4008f,0x91ba0008,0x61e1002e,0xd1310015}},	//   міце, _המתי, öllu, _سمح_
  { {0xf3ff001c,0x3211005c,0x3c3c006f,0x0000006a}},	//   nhã_, lizy_, tíva_,
  { {0xda350010,0x3fda0008,0xa9690709,0x7c2b224e}},	//   педы, _הקרב, била_, rogr
  { {0xb7bd0011,0xeab00015,0xceb2000a,0x997e0045}},	//   moţi, ضعه_, _רים_, răşi_
  { {0x67f50014,0x38580010,0xb6070007,0x7c2b24e1}},	//   _fájl, орыю_, našū, pogr
  { {0x997e0045,0x96950a96,0xc7b90030,0x69de24e2}},	//   păşi_, прош, llőz_, öper
  { {0xef64000a,0xf771002b,0x99d70015,0x0593002b}},	//   וֹת֙_, واک_, _وتطا, وادگ
  { {0x245a0024,0xc9f700e6,0xd706004a,0x2d810012}},	//   _zīmi_, _بسرع, яные_, nahe_
  { {0xc329000a,0x27f70015,0xd5e80015,0x8d76000a}},	//   _עו_, _وأصح, تعين_, הגתו_
  { {0x98170015,0x96b90138,0x7d0201d3,0x0000006a}},	//   _ببطا, _гуку_, _híré,
  { {0xc5f50063,0x11d6005e,0x28080015,0xb808002b}},	//   _някъ, півр, _بْنَ_, _بينم_
  { {0x68130011,0xc7b90030,0x21670004,0xdb0a0030}},	//   rădu, leő_, зири_, ínév
  { {0xe3c20061,0x0000006a,0x0000006a,0x0000006a}},	//   _alış_,   ,   ,
  { {0x6d48002d,0x99870089,0x753c0012,0xddc400bc}},	//   _údai, konů_, ürze, dpiš
  { {0x35d0005d,0x539b000a,0xd83e01c9,0x3f80016e}},	// [4560] _थोड़, _היפו, íčin_, raiu_
  { {0xb21b002e,0x7ae40020,0x614624e3,0x6286128d}},	//   nsæl, äitm, _непа, msko
  { {0xc173013a,0xe7bd014e,0x3b660063,0x6456003f}},	//   _אחת_, ्याप, пълв, _kiyi
  { {0x60db0008,0xb7bd0045,0x99870046,0xfc320015}},	//   _הקטנ, boţi, fonů_, رحا_
  { {0x4420000c,0x64560064,0xa3bf000b,0x628624e4}},	//   _mji_, _miyi, ीयत_, nsko
  { {0x433b004c,0x75ed0030,0x20120061,0x628624e5}},	//   זענב, _múzs, liyi_, isko
  { {0x7af20089,0x6e43005e,0x6f0400bc,0x442024e6}},	//   _řetě, _черз, lzic, _oji_
  { {0xc6f81017,0xfc1a0015,0xd7f00015,0xab6624e7}},	//   жних_, _اقرب_, ئكة_, _хвал
  { {0x628624e8,0xd5b00015,0xfaa4002b,0xb926002b}},	//   jsko, نفة_, _تجزی, _کفاي
  { {0x27ff0049,0xbafb000a,0x76730033,0x25860046}},	//   ahun_, _ההמש, эльф, dílí_
  { {0x67f50089,0x439524e9,0x628624ea,0x26cf24eb}},	//   _zájm, манс, esko, _ergo_
  { {0x6286016f,0xb900000b,0x6d3b000a,0x20120061}},	//   fsko, दम_, מתינ, jiyi_
  { {0xe2980010,0xa73a00c3,0x62860295,0xc68f00c3}},	//   паў_, _اثار_, gsko, _مِن_
  { {0x6f04005c,0xeab10008,0x171b000a,0x26c3003d}},	//   dzic, כֹל_, _פוגע, ājot_
  { {0x64a305e6,0x6f0420f6,0x4035067a,0x2d8124ec}},	//   _заја, ezic, девс, vahe_
  { {0x999e00df,0x75370008,0x2d810035,0x104b0036}},	//   _kitų_, _מאוד_, wahe_, сяги_
  { {0xdb080152,0x61470030,0x57fb000a,0x62860030}},	// [4570] _élèv, félé, צלמו, csko
  { {0xe1750029,0xddc40085,0x443924ed,0x1eea002b}},	//   _تُدخ, tpiš, lls_, غولی_
  { {0x645702c1,0x271e0092,0xc172004c,0xb7bd0045}},	//   _éxit, ịnh_, _שחט_, soţi
  { {0xa3d3005d,0xdb510029,0x44cc0089,0x2d810035}},	//   _होम_, نَا_, _mě_, sahe_
  { {0xddc40085,0x443924ee,0xfaa51055,0xb5fd1de3}},	//   spiš, ils_, фало, opšt
  { {0x443912e3,0x61470003,0x3ea924ef,0x2fc92300}},	//   hls_, célé, mtat_, ldag_
  { {0x44cc0089,0x44390024,0xd90f0086,0x27ff232a}},	//   _ně_, kls_, دیا_, thun_
  { {0x2fc924f0,0x443924f1,0x99870046,0xbd440015}},	//   ndag_, jls_, ponů_, _سنقي
  { {0x3c44008f,0xa3d7000b,0x3ea924f2,0x661d0030}},	//   _чэрв, साई_, ntat_, ésko
  { {0x44321af1,0x3ea924f3,0x44390c90,0x7af600cb}},	//   _sky_, itat_, els_, øyte
  { {0x798324f4,0x6f0424f5,0x75450138,0x44390052}},	//   manw, zzic, ьноз, fls_
  { {0x79830026,0x628624f6,0x2fc90079,0x3ea924f7}},	//   lanw, tsko, jdag_, ktat_
  { {0x13070010,0xe5a500a4,0x628624f8,0x7c390034}},	//   дняй_, _жили, usko, ilwr
  { {0xca960008,0x425524f9,0x86440033,0x2bcf000b}},	//   ודשי_, етст, _зніж, _सोसा
  { {0x20120064,0xa0a30c62,0x25860046,0x645c24fa}},	//   tiyi_, кард, sílí_, írit
  { {0x2fc900b6,0xa067000d,0x9426042b,0x628624fb}},	//   gdag_, ќата_, _імпе, psko
  { {0x20120064,0xb226000d,0x6df60015,0xfdea0033}},	// [4580] riyi_, _омил, وكرا, одак_
  { {0x6f0424fc,0xdb080003,0x2bc6000b,0x20120061}},	//   rzic, _élév, _रोजा, siyi_
  { {0x2a6d0176,0x61470030,0x61db000a,0x11db000a}},	//   _ateb_, rélé, _וקיד, _וחיב
  { {0xab5d005c,0x7c65002b,0xa3d70065,0x7a3f01f6}},	//   _ważn, ءالل, साए_, vêta
  { {0xbaba0029,0x3ea924fd,0xaaba0067,0xba2a002b}},	//   تداء_, ctat_, تدار_, يستم_
  { {0x0dba0015,0x7c390034,0xe876002b,0x286a1293}},	//   _باحث_, alwr, واعظ, орио_
  { {0x6d5c01a3,0x6da32143,0xada3153d,0x26cd0072}},	//   _igra, _шира, _шарл, eveo_
  { {0xab2a24fe,0x9b930015,0x7a3f0003,0x3e6401d3}},	//   _доба_, _للفت, rêta, _köt_
  { {0x9f490064,0x3ae8002b,0x7983233f,0x44cc005a}},	//   rkaç_, _عبری_, banw, _sě_
  { {0x79830034,0x2fc90030,0x63a424ff,0x67fc037b}},	//   canw, zdag_, _acin, _déja
  { {0xcd970008,0xe4150036,0x0d970dab,0xdb0b0613}},	//   ודית_, еднь, וכים_, regå
  { {0x8c430064,0xa295022a,0xd917002b,0x69c82500}},	//   _üşte, намі, _تيمش_, _hade
  { {0x6d5c2501,0x659409a7,0x44392502,0xf773000a}},	//   _ogra, _залу, rls_, _סקס_
  { {0xb21b0084,0x4af90053,0x44390024,0x44cc0089}},	//   msæk, פּרײ, sls_, _tě_
  { {0x859b000a,0xa5b7000a,0x2465003d,0x759b0447}},	//   _ושוו, _חלוק_, _tēma_, _וסוג
  { {0x7658000c,0x3ea90e26,0x44270015,0x63a40125}},	//   _hivy, ttat_, _ترتف, _gcin
  { {0x7658003f,0x3ea901a0,0x63bd004b,0xfebb0015}},	// [4590] _kivy, utat_, mesn, غارت_
  { {0x69da00cb,0x63bd2503,0x2fc92504,0x69c82505}},	//   _nnte, lesn, sdag_, _nade
  { {0x69ca0026,0x3ea92506,0x2ca70045,0x9b950015}},	//   ddfe, stat_, înd_, فلات
  { {0xf41f00f2,0xde590010,0x63bd0007,0x69ca232a}},	//   nnä_, _намі_, nesn, edfe
  { {0xa3e4000b,0xf41f008c,0x6b800012,0xbb18006e}},	//   पॉट_, inä_, _demg, وزها_
  { {0xe29c0008,0xa9690965,0xa2f8000a,0x99850015}},	//   קשור, чика_, ומדה_, رلبو
  { {0x69c82507,0xa855023e,0xb8650015,0x67f50046}},	//   _dade, нтиј, راغو, _háji
  { {0xb8d7005d,0x16bc005d,0x63bd2508,0x3158000a}},	//   _छह_, ्टूब, jesn, ויון_
  { {0x63bd00f0,0x7bdb02f2,0xfb340033,0x69c82509}},	//   desn, _inuu, _антэ, _fade
  { {0xdcee0089,0xf41f00f2,0x69c822fe,0x99d70015}},	//   _nebě, enä_, _gade, _تترا
  { {0x4519004a,0x63bd0046,0x5724002b,0x629d00aa}},	//   яция_, fesn, فریق, euso
  { {0x9f4b11e0,0x69c80820,0xf1a905bd,0x7981250a}},	//   _você_, _zade, _לס_, _helw
  { {0xe7840127,0x69da0034,0x629d250b,0x87040058}},	//   _рухо, _ynte, guso, _لبول
  { {0x63bd0026,0x7c22003d,0x59e2000b,0x6d580091}},	//   aesn, čori, पायर, žvai
  { {0x6026250c,0xf992000a,0x6d5c0034,0xd132012c}},	//   едва, טרם_, _rgra, امز_
  { {0xdee61c3f,0x03a60b1e,0x2bcf000b,0x63a40e2a}},	//   ноби, _џипо, _सोला, _ucin
  { {0x69ca0026,0x629d016e,0x2266002a,0x6d5c250d}},	// [45a0] ydfe, cuso, ówką_, _pgra
  { {0x20c60036,0xab5d005c,0xee371067,0x6e930058}},	//   _зйом, _inży, ену_, اللا
  { {0x317b000a,0x85f60053,0x6d5c00bd,0x69c8250e}},	//   _מאיד, עמעס_, _vgra, _rade
  { {0x69c801e2,0xb4fa0008,0x79810026,0xa508000a}},	//   _sade, הפעי, _aelw, וּנִ
  { {0x7afd0064,0x69c8250f,0xd7f10016,0x1f5b004f}},	//   _üstl, _pade, _gũi_, _מדכא
  { {0x63bd005c,0xead70010,0xca750010,0xa3be000b}},	//   zesn, эміі_, туцы, ुएँ_
  { {0x79810176,0xc1730008,0xf41f00f2,0xc2370053}},	//   _delw, נחה_, ynä_, ערצו_
  { {0xf0930008,0xab690015,0x7791002b,0x9b960015}},	//   אנה_, _يحقق_, لیما, _سلطت
  { {0xdb0600f2,0x601b00f2,0x3a26022a,0x98c00061}},	//   ämän, lämä, _змаг, ırız_
  { {0x69da0bcf,0x48e62510,0x25b7013f,0x35f402d9}},	//   _unte, _позв, _čelí_, тпор
  { {0x29180005,0x29070050,0x63bd00df,0x7658003f}},	//   _ära_, czna_, tesn, _vivy
  { {0x3f82016f,0x388c0089,0xad240033,0xdcf5003d}},	//   _neku_, měr_, эзiд, _zdzē
  { {0xfbd30008,0x1dd1005d,0x93f40033,0x63bd09db}},	//   אתר_, _सफलत, упяц, resn
  { {0xc1cb000b,0x1757000a,0x26db000a,0xd6db0643}},	//   ायेग, _נסגר_, _מקדמ, _מחדל
  { {0xadc30016,0x601b008c,0xb367006b,0x3f8207c8}},	//   _ngạc, jämä, _пъпк, _beku_
  { {0x653b0008,0x629d00dc,0xe53b000a,0x35a6000b}},	//   _מעוד, puso, _מתור, _खाड़
  { {0xf4580053,0x20180021,0x55ba000a,0x6003007c}},	// [45b0] _איהר_, رتفع_, ּמ֣ו, _nõme
  { {0x4df40036,0x5f440015,0x831c000a,0xc172002b}},	//   ляєт, انكل, _מוחז, _نگفت
  { {0xe29f002e,0x41de000b,0xe9df0016,0x0000006a}},	//   luð_, मारस, _đú_,
  { {0x2cb800e8,0x9be40033,0xdab90033,0x79812511}},	//   _dprd_, лічк, дыкі_, _selw
  { {0xe29f002e,0x8f9a000a,0xead400ce,0x51eb004f}},	//   nuð_, _קישי, лоць, ּקֶ֣
  { {0x127c0053,0xda090015,0xf993002b,0xb7bd0045}},	//   לאדע, بيته_, ابش_, inţe
  { {0xaa560015,0x9f40001a,0x99830091,0x48e50033}},	//   خلوا_, lkið_, _ųjų_, тойв
  { {0x79810026,0xe29f002e,0x46cd005d,0xbd440015}},	//   _welw, kuð_, ़िलह, _إنفي
  { {0x6d48002d,0xa3e5000b,0xe29f001a,0x8f9c000a}},	//   _údar, नान_, juð_, פיזי
  { {0x388c0089,0xe29f002e,0xa2c5000b,0x7a570015}},	//   běr_, duð_, िबन्, _أضرا
  { {0x2d8300bd,0xb7bd0045,0xd6a8002b,0x53dd000b}},	//   _meje_, enţe, ودیم_, यांश
  { {0xe29f002e,0xf8680015,0x17fb0015,0x9f40001a}},	//   fuð_, _أمني_, _عرضة_, kkið_
  { {0x72c3008f,0x65c50010,0x7c3a0152,0x3f8200b3}},	//   абяз, _абла, _être, _reku_
  { {0x1a9a0053,0xcb12000a,0x7a360003,0x72c30004}},	//   וישע, שלך_, lâtr, јбрз
  { {0xb7bd0045,0x9f40001a,0x3201006f,0x505a09b1}},	//   anţe, ekið_, _dlhy_, дшая_
  { {0x601b022d,0xe4c80029,0x63060058,0x7a3601f6}},	//   vämä, _أبون_, _لوبل, nâtr
  { {0xbf650015,0x3f820c1a,0xc049004c,0xdcfc0091}},	// [45c0] ادفو, _veku_, ַז_, _verč
  { {0x601b022d,0x25f7000b,0xe29b000a,0xad6500c3}},	//   tämä, एसटी_, _קשיר, هامه
  { {0x6026008f,0xd00a1179,0x2d832512,0x3f820844}},	//   _адна, _жене_, _deje_, _teku_
  { {0x67fc0003,0x388c0046,0xc0590033,0x44222513}},	//   _réjo, věr_, _піў_, nnk_
  { {0x67fc0152,0x09e6042b,0xa51e000b,0xe7e5000b}},	//   _séjo, кодн, _पश्च_, काना_
  { {0xc33301e4,0x67f500dc,0x5a33017f,0xceb3000a}},	//   בוד_, _máju, аніт, _דיש_
  { {0xa3e5005d,0x3ea02514,0xfce32515,0x7189000a}},	//   नाम_, luit_, _коро, תְנַ
  { {0x8c462516,0x7794002b,0x2fc02517,0x1de00065}},	//   _ребе, ایشا, neig_, नावत
  { {0xf6e30010,0xa3dc000b,0x96340719,0x3ea02518}},	//   ацэн, ठाई_, лниц, nuit_
  { {0xe29f002e,0x7ae4007c,0x44222519,0x6f49004f}},	//   vuð_, äitu, enk_, עֲקַ
  { {0x14190015,0x97c60015,0x8cd5000b,0xd7c7002b}},	//   فيدة_, _لتشم, णियो, رویه_
  { {0xd7ef0029,0xe29f002e,0x2a6404d2,0xb8650015}},	//   _وكل_, tuð_, _kumb_, _صامو
  { {0xa2d0005d,0xadf3005d,0x5187251a,0x15fc000b}},	//   दिष्, _आकलन_, кува, एसआर_
  { {0x52240010,0x3ea0251b,0xe4d40002,0x94d40015}},	//   афса, duit_, _مقتد, _ميتش
  { {0xc05b0036,0xb65b039e,0x2258004a,0xd7f80045}},	//   діа_, _קדוש, тиры_, _luăm_
  { {0xf0470010,0x28d3005d,0x443d005c,0xe29f002e}},	//   тэго, थिति, _ów_, puð_
  { {0x53140086,0xc0580036,0x4ea70063,0x3ea0251c}},	// [45d0] _پذير, тір_, ърва, guit_
  { {0x7c220176,0x9f40002e,0x925b0015,0xdd940015}},	//   enor, rkið_, _تشعر_, لجمع
  { {0x0c870033,0x7c22001a,0x760b000a,0x7af600cb}},	//   тызм, fnor, וּאַ, øytn
  { {0x200c08e0,0x3ea00011,0x8b940033,0x7c22251d}},	//   èdit_, buit_, аршч, gnor
  { {0xee840802,0x60030020,0x8f9a00a3,0xfb340010}},	//   _высо, _tõmb, _אירי, анцэ
  { {0xc334000a,0x7c970015,0x2a6400da,0xdb120030}},	//   סוס_, _لشرا, _dumb_, ágát
  { {0x628000dc,0x89d60029,0xc8880015,0x200201d7}},	//   ámoz, طوير_, نخيل_, _ylki_
  { {0xf7710029,0x6d4701a3,0x515c000a,0xd6c3002b}},	//   حاث_, _izja, וכוו, لمبی
  { {0x2a640198,0xdcfc003d,0x7ae4008c,0xab66007c}},	//   _gumb_, _ierā, äitt, spüü
  { {0x67f500dc,0xdb09016e,0x7a3601f6,0x0000006a}},	//   _ráju, _abeç, sâtr,
  { {0x3ea00011,0x98750004,0x7af90034,0x67f50030}},	//   zuit_, _слец, lywt, _bájt
  { {0x987a0053,0xe29a251e,0x4c9a000a,0x3c3c006f}},	//   _נאנט, нам_, עברו, tívi_
  { {0x8bd6000a,0xeab5000a,0x0000006a,0x0000006a}},	//   אורו_, נִ֨י_,   ,
  { {0xfb1600b4,0x471a0053,0xe6920015,0xcb36000a}},	//   אַלט_, _אונג, _الود, ראשי_
  { {0x7c220034,0x442201c2,0xe6100040,0x2fc0251f}},	//   ynor, pnk_, _بشن_, teig_
  { {0xd9c0005d,0xdcfc0024,0xa2bf000b,0x3ea02520}},	//   _एस्ट, _nerā, _लैक्, tuit_
  { {0xfd9a0015,0x70530015,0x6d47002a,0xe8890016}},	// [45e0] فئات_, إنقا, _azja, hẻ_
  { {0xfce6049d,0xa3e5000b,0xbe130015,0x3ea02521}},	//   лозо, नाथ_, موقع, ruit_
  { {0xd5fa0053,0x645e2522,0x660f006f,0x3ea02350}},	//   עפער, _épit, écky, suit_
  { {0xf5360053,0x0c260033,0xdde3003d,0xb09b000a}},	//   אטער_, ымен, āršo, _איטר
  { {0xa3e5005d,0x752f002a,0x3ea02523,0x7c222524}},	//   नात_, ęczy, quit_, rnor
  { {0xe91802e1,0x7c222525,0x2010002a,0xfa880016}},	//   колі_, snor, żnią_, rừ_
  { {0x67f5002c,0x6e2b00dc,0x602c0061,0xb21b2526}},	//   _nájs, égbe, ağme, msæt
  { {0xa3d3014e,0xb21b0134,0xf8030033,0x57a62527}},	//   _हों_, lsæt, йчын, ушка
  { {0x7bc22528,0x699612ab,0xdce70091,0x7c46003d}},	//   meou, _брех, _bejė, ārrē
  { {0x88c60029,0xb21b02de,0xe5c618fc,0x44b404bb}},	//   _متصل, nsæt, усио, абос
  { {0xce370008,0xd5b704ab,0x8e37004c,0xacca0033}},	//   ראית_, усы_, רניא_, дзiв
  { {0x7bc2003e,0x45470010,0x635515e6,0xd497004a}},	//   neou, ычым_, ивну, ырь_
  { {0xb21b0134,0xa3d6000b,0x9837000a,0xa8370643}},	//   ksæt, _सफर_, _גראף_, _גראד_
  { {0x0000006a,0x0000006a,0x0000006a,0x0000006a}},	//     ,   ,   ,
  { {0xb21b00fb,0xe4500086,0x7bc22529,0x661a252a}},	//   dsæt, تضی_, keou, mitk
  { {0x12e70036,0xa2c5005d,0x5064213b,0x661a252b}},	//   _біог, िबद्, стра, litk
  { {0x1de0005d,0x8e1502e1,0x66d300dc,0xa3f8000a}},	// [45f0] नांत, адац, műkö, _תמחק_
  { {0x27330023,0x27210023,0xdd950010,0xb7bd0011}},	//   ợng_, ẳng_, ражы, inţa
  { {0x645f0152,0x61fa0020,0x628f002d,0x644d0213}},	//   _épis, ötle, lsco, _khai
  { {0x7bc200da,0x807a000a,0x907a05bd,0x207a004f}},	//   geou, _שנרצ, _שטרי, _שארא
  { {0x644d002f,0x661a0375,0xab88002b,0xe9ce252c}},	//   _mhai, kitk, انهٔ_, ок_
  { {0xe9d8008f,0xceb2000a,0x7de7005e,0x628f252d}},	//   лкі_, _ויך_, _сімд, isco
  { {0xa3d6005d,0x25e8000b,0xb7bd0045,0xdb0b0061}},	//   _सफल_, जानी_, enţa, legü
  { {0x6603002c,0xd720000b,0x7bc200da,0xe8890016}},	//   _slnk, मपंथ_, ceou, rẻ_
  { {0x8a940029,0x628f005c,0x0ab80087,0x6f0d252e}},	//   _هؤلا, jsco, _مطلب_, nzac
  { {0x7af600f2,0x44290523,0x0f5800a3,0x75ed0030}},	//   äyte, _aja_, ניזם_, _húzz
  { {0x644d002f,0xe005005d,0x7c29252f,0xc6480015}},	//   _bhai, रसाद_, _kjer, دجيل_
  { {0x644d0541,0x6b8b2530,0x69c32531,0xeaa70015}},	//   _chai, nagg, lene, يع_
  { {0x7c29016f,0x7c3b003f,0x661a2532,0x63a60123}},	//   _mjer, _mkur, bitk, rgkn
  { {0x412a18a9,0xcad6000a,0x8b56000a,0x661a0428}},	//   вого_, בושת_, יירס_, citk
  { {0x644d002d,0x6f0d0045,0x36340067,0xdb19002a}},	//   _fhai, ezac, _ارنس, odwó
  { {0xc0030cb9,0x27ff06c2,0x69c31134,0x644d2533}},	//   опск, nkun_, hene, _ghai
  { {0xd00f003b,0x2bbb005d,0x0d86135d,0xfd760015}},	// [4600] ذلك_, ोजना, илан, لداخ
  { {0x6d5a0029,0xdcfc0011,0x80c6000b,0x66d20061}},	//   نجاح_, _neră, ाबदे, lıkç
  { {0x27ff002e,0x7bc2003e,0xb21b193d,0x27ed00e8}},	//   kkun_, teou, rsæt, kjen_
  { {0x661a00bd,0xb21b0134,0x76410034,0x6b8b18f8}},	//   zitk, ssæt, hlly, gagg
  { {0x6f0d0281,0x7ad40015,0xead40c6e,0xb21b02de}},	//   czac, إقتص, соль, psæt
  { {0xc9a70001,0x7c292534,0xd90d002b,0x7bc200da}},	//   авље_, _ejer, کیم_, seou
  { {0xa3c8005d,0x7c290293,0xa96700d0,0x6d4b002a}},	//   ैया_, _fjer, шија_, ęgac
  { {0x7c2913e1,0xd6da2535,0x3157004c,0x3c3c006f}},	//   _gjer, вто_, סיקן_, tívu_
  { {0x644d0176,0x66d20064,0x69c32536,0x29960015}},	//   _rhai, dıkç, bene, _نجاح
  { {0xceb30008,0xe8390089,0xceb7000a,0x644d2537}},	//   קית_, ější, ספיק_, _shai
  { {0x2dd900b4,0x35db005d,0x644d1ffd,0x25e8000b}},	//   אַרב, बाज़, _phai, जाबी_
  { {0x78fb0053,0x661a00f2,0x628f158f,0x7a3f0003}},	//   _שלאפ, sitk, tsco, vêti
  { {0xd7ef0029,0x82370029,0x628f04ed,0x2fd20026}},	//   _تكن_, لرسا, usco, ddyg_
  { {0x628f2538,0x54660001,0x36330021,0xb725004c}},	//   rsco, _књиз, _وروس, _פֿײַ_
  { {0x0494003b,0x46390053,0x56390053,0x644d0817}},	//   _البح, _געװע, _געװײ, _thai
  { {0x6f0d08e0,0xf55b0008,0xa3bb0002,0x69c32539}},	//   tzac, _בדומ, _شاعر_, zene
  { {0x60d300df,0x4439253a,0x645f0003,0x6b8b253b}},	// [4610] _žemė, mos_, _épiq, vagg
  { {0xa3e5014e,0xdb0b005c,0x4bd8002b,0x15f8000a}},	//   नाव_, zegó, یبند_, נִּמ
  { {0x27ed022d,0x41b60086,0x201e0251,0x4439253c}},	//   yjen_, _امپر, ètic_, oos_
  { {0x4439195f,0x2d87002a,0x7c94002b,0x69c3253d}},	//   nos_, źne_, زشما, wene
  { {0x7c29010b,0xe7e5005d,0x6b8b253e,0x79881745}},	//   _vjer, कासा_, ragg, _bedw
  { {0x89a80191,0x6240022d,0x6b8b02d7,0x88c50029}},	//   иків_, töoi, sagg, متعل
  { {0x27ff0084,0x49980036,0x4439253f,0xdb0b2540}},	//   tkun_, ртія_, kos_, tegó
  { {0x7c3b0f4d,0x44392541,0x7c29003f,0x5c070248}},	//   _ukur, jos_, _ujer, _тяга
  { {0xa9c7010f,0x06960029,0x44392542,0x27ff2438}},	//   _всек, منية_, dos_, rkun_
  { {0x3eda0053,0x27ff2543,0x49b8002b,0x27ed2043}},	//   אַטא, skun_, _نامد_, sjen_
  { {0x27ed0014,0x6b890020,0xddc60007,0xf2c90008}},	//   pjen_, _keeg, _sukū, _רע_
  { {0xb8dd005d,0x3eb2008c,0xa6c90067,0xdc88000a}},	//   ेब_, ytyt_, _موصل_, סְתָ
  { {0x1dc7000b,0x6b890159,0x1635004a,0x7c3a001a}},	//   रजात, _meeg, _ледя, _ítre
  { {0x3dd1005c,0xe7360054,0x853c0091,0x6b892544}},	//   _nazw_, _ћеш_, igėj, _leeg
  { {0x44392545,0x2000008c,0xa3e5000b,0xe29f001a}},	//   bos_, tkii_, नाश_, arð_
  { {0xb4fa0008,0x44390e75,0x6e3c0844,0x1f661ab5}},	//   _תפקי, cos_, _skrb, скам
  { {0x6292002c,0xa3e5000b,0x2000008c,0x22930021}},	// [4620] ýkoľ, नार_, rkii_, _فليس
  { {0xbd8a0074,0xe058002b,0x6da60015,0x02460015}},	//   انان_, _چیست_, إمام, _دَخَ
  { {0xe0580074,0xf8a50086,0x3eb200f2,0xad250015}},	//   _نیست_, _تک_, styt_, يرمو
  { {0x44d704f9,0x248301c0,0xfba900ce,0xac970058}},	//   _mă_, ájmy_, итій_, إننا_
  { {0xa91c002c,0x79880026,0xfaa306b3,0x6b89042f}},	//   _veľm, _pedw, зачо, _deeg
  { {0x2b980092,0xa2d9000b,0x44392546,0x7c660021}},	//   ức_, मित्, zos_, _هارل
  { {0x44392547,0xdca317bd,0xcc78000a,0x3c78000a}},	//   yos_, _нари, _כְּר, _כָּב
  { {0xc7c60a61,0xe4e6005e,0x44392548,0xe29f001a}},	//   сски, ґіон, xos_, yrð_
  { {0x44392549,0xa3ac000b,0xa3be000b,0x858a0033}},	//   vos_, खलन_, ीजन_, лёна_
  { {0xa96a0015,0xea77000a,0xad760033,0x63ad07f3}},	//   _إمام_, _לגמר_, авiц, _scan
  { {0x44d70440,0xd7ef0cb9,0x89db000a,0x443903b8}},	//   _că_, _еу_, _תחבי, tos_
  { {0xccf30008,0x44d70011,0x44390007,0x64a8000b}},	//   לכת_, _dă_, uos_, _कमीश
  { {0x65940010,0xa2d0005d,0xc7d70008,0x41e70484}},	//   _далу, दिग्, _לואי_, біва
  { {0x5558008f,0x17570008,0xdb0f0999,0x2d9c016e}},	//   _каля_, _הסדר_, édér, óvel_
  { {0xb5b70008,0xdb0b002e,0x60250007,0x61fa00c0}},	//   _הלוח_, hegð, lėmi, ötla
  { {0x4035008f,0x98a9005c,0x2d980026,0xc477000a}},	//   цебс, łać_, _adre_, _פתחו_
  { {0xbe190036,0x6b890020,0xf41f00f2,0x60250007}},	// [4630] ажає_, _reeg, miä_, nėmi
  { {0x6b890005,0xf41f022d,0xf2d40053,0xd9f4000b}},	//   _seeg, liä_, _זעץ_, _अवगत_
  { {0x2d8a254a,0x6b890020,0xdfd10115,0x8d740018}},	//   _debe_, _peeg, _قيد_, سالا
  { {0xab940036,0xf41f00f2,0x4af9004a,0x60250091}},	//   зиці, niä_, иэля_, kėmi
  { {0x78670014,0xdefb0139,0xfaa5005e,0x539c000a}},	//   _műve, _сын_, іако, רידו
  { {0x38c70086,0x6e440010,0xf41f008c,0xda340033}},	//   ماعی_, _неўз, hiä_, печы
  { {0xf41f022d,0xe7e5005d,0xf1b40008,0x01fc000a}},	//   kiä_, काला_, פסק_, רפול
  { {0xdd0e0064,0xf41f00f2,0x44d70045,0x600a0046}},	//   lışa, jiä_, _ră_, _týme
  { {0x44d70440,0x27f60029,0xc68e0015,0xfaf30015}},	//   _să_, تفيد_, نِي_, _عثر_
  { {0xe9db0015,0xdd0e0061,0x188b06eb,0xe6191411}},	//   _حذرت_, nışa, _бсдп_, рдо_
  { {0xd7c80074,0xf7730086,0xf1ad000b,0xf505005e}},	//   _گونه_, _فاش_, ञ्छन, ізмо
  { {0x44d70440,0x60250007,0x9cd6000a,0x28c2000b}},	//   _vă_, bėmi, קורה_, _वैटि
  { {0x42ba0010,0x26c90086,0x36050015,0x91d6005e}},	//   шыню_, _خطای_, _ووصف, оцві
  { {0x200c0024,0x66ba0008,0x3ea0254b,0xc8ad000b}},	//   īdim_, _כמנה, vrit_, _टमाट
  { {0xdb200030,0xe3b20015,0x4f660058,0xf41f005b}},	//   _ötöd, _قرة_, قاذف, biä_
  { {0x1dac005d,0xe7ec005d,0x5f06005e,0x3ea0254c}},	//   _चाहत, झाया_, озба, trit_
  { {0xd007017a,0x1756004c,0xdfcf0015,0x3f8b0085}},	// [4640] цете_, ַסער_, ضيل_, _decu_
  { {0x64460020,0x3ea0000e,0x31a60015,0x859c004f}},	//   llki, rrit_, _بمدف, ָשׁו
  { {0xa91c002c,0x24650024,0x7413002b,0x60250091}},	//   _veľk, _tēmu_, _رویا, zėmi
  { {0x3ea0038d,0x2d8a002c,0x0b460a93,0x7c950033}},	//   prit_, _webe_, онен, яруц
  { {0xf413000a,0xb4c6000b,0xa136002b,0x2d8a18ca}},	//   ופא_, _उन्_, _درکش, _tebe_
  { {0x317a0053,0x2023005c,0xddd50024,0xed5a0029}},	//   באַד, ąpił_, _aizņ, _نشأت_
  { {0xf1b2005d,0x5bc60015,0x53aa000b,0x8b96105a}},	//   _जानन, _وترف, _कांश, _мрач
  { {0x60250007,0x6d4e1cf7,0x9f49001a,0x0d17000a}},	//   tėmi, _izba, okað_, _וקלט_
  { {0xf41f00f2,0xc0530008,0x3b070063,0xc6f7054f}},	//   viä_, וזה_, _дето_, жных_
  { {0xc5fa000d,0xab290015,0x60250091,0xf426007c}},	//   рѓи_, _اسفل_, rėmi, ääne_
  { {0xf41f022d,0x6474022a,0x4a5b000a,0x60250091}},	//   tiä_, ягну, _כדמו, sėmi
  { {0x9f49002e,0x60250007,0x6b82254d,0x39130058}},	//   kkað_, pėmi, nbog, _غونز
  { {0x9347003b,0xf41f00f2,0xc34b085d,0xd62a004a}},	//   تخدم, riä_, ряне_, _коде_
  { {0xf41f022d,0x05b30015,0x44250030,0x41e400e2}},	//   siä_, _يمنح, ől_, міса
  { {0xf41f00f2,0xf878000a,0x859b000a,0xb05b0015}},	//   piä_, מְּל, _כשגו, لشرط_
  { {0x7a3f0152,0x60030020,0x753c0012,0x889b000a}},	//   nêtr, _tõmm, ürzu, יבלי
  { {0x85560074,0xd1670063,0x799a005c,0x0454002b}},	// [4650] _دیگر_, _мъни, _odtw, _تئود
  { {0x067b000a,0x41b2000b,0x28db000b,0xddcf0046}},	//   ינמל, _जायस, _मछलि, řeže
  { {0x442b0152,0xa2580015,0xf1b2000a,0x8234002b}},	//   onc_, _بشيء_, _אסי_, _تريا
  { {0xdfa70015,0x64580144,0x6d4e002a,0x27e602b9}},	//   _بحدي, _èxit, _dzba, _nnon_
  { {0x7f7600f3,0x80d3000b,0xde46002b,0xb7bd0045}},	//   _מערב_, डिके, _کیلو_, niţe
  { {0x3ea900e8,0xdcee0007,0x245201b2,0xdef40033}},	//   muat_, _nebė, máme_, _ўпры
  { {0x3ea9254e,0x24520107,0xb7bd0045,0xc7b90030}},	//   luat_, láme_, hiţe, tfő_
  { {0x97c5003b,0x08d40010,0xf8130086,0x95f5005d}},	//   ستعم, ьція, بستگ, ेस्ट_
  { {0xa3e5005d,0xdb2500f2,0xfbd2000a,0xc7a80015}},	//   नाई_, öpäi, _אתן_, زديل_
  { {0x97320086,0x99d40015,0x656f005a,0x386c0416}},	//   رکنا, _يتلا, ěcho, _fudr_
  { {0x0446022a,0x24520046,0x7c2b254f,0x0000006a}},	//   зенн, háme_, ongr,
  { {0x389704f9,0x644600f2,0xd8d6000a,0x7a3f0003}},	//   măr_, ulki, _מועט_, cêtr
  { {0xe72e001e,0x66e5053b,0x466b0e3f,0x7c2b2550}},	//   _че_, _хола, _трем_, ingr
  { {0xbb3a0053,0xeb3a0053,0x24520057,0xf67a000a}},	//   מערי, מערש, dáme_, _האסמ
  { {0xaf9a124a,0x753c0012,0x38970045,0xa7fc0061}},	//   йтах_, ürzt, năr_, _atıy
  { {0x6b9b003f,0x24520089,0x6b8d001a,0x749a000a}},	//   _ndug, fáme_, ðagl, _היקפ
  { {0xdfcf003b,0x12aa0015,0xbe66002b,0xe7ec000b}},	// [4660] ديق_, _ادعى_, سهاي, झाता_
  { {0x273a0023,0xa3b8005d,0x9f49002e,0x42db000a}},	//   ừng_, घ्र_, rkað_, _פקיע
  { {0x01fb0008,0x50462551,0x9f49001a,0x7c2b001a}},	//   _הפיל, _необ, skað_, fngr
  { {0x5bb80036,0x3ea908c0,0xa3e5000b,0x6aa22552}},	//   ілля_, buat_, नाए_, trof
  { {0x4422007c,0x3f9201d7,0x3a73008b,0x6b822553}},	//   iik_, mayu_, елір, rbog
  { {0x3f9200d9,0xceb301d8,0x6b821936,0x5e460015}},	//   layu_, _איש_, sbog, _رَأْ
  { {0x58860010,0xa3be000b,0x44222554,0xa3ac000b}},	//   чыла, ीजा_, kik_, खला_
  { {0x4c9b0008,0x44222555,0x56780a32,0x6e3e0030}},	//   _לבלו, jik_, обия_, lopb
  { {0xfaa32556,0x44222557,0x78a30123,0x7a3f0003}},	//   _пато, dik_, arnv, rêtr
  { {0x44980036,0xddce00dc,0xda65002b,0x14ca004a}},	//   овою_, _kibő, _قالي, быми_
  { {0x24590210,0xb97b000f,0x14190015,0x44222558}},	//   жань_, _הנבי, قيدة_, fik_
  { {0x69ca2559,0x88c50015,0xa2d9000b,0x4422255a}},	//   lefe, _تتكل, मिल्, gik_
  { {0xa3be005d,0xdcee0091,0x51870004,0x41e7008b}},	//   ीज़_, _tebė, зуба, піва
  { {0x24520089,0x44220049,0xb0d8000b,0x1473002b}},	//   váme_, aik_, डिंग, بایج
  { {0x7c2b0176,0x55bb009d,0x3cf8000b,0x25bb000a}},	//   yngr, _המוו, ूनों_, _הצומ
  { {0x987b0053,0x24520089,0x3ea9107d,0xf211000b}},	//   מאלט, táme_, tuat_, डोज़_
  { {0xdb1b002e,0xa8570008,0x2fc9002d,0x69ca255b}},	// [4670] _nauð, לילה_, reag_, kefe
  { {0x92b40029,0xa3e5005d,0x69ca049e,0xdb070003}},	//   _أحيا, नाक_, jefe, _élég
  { {0x40950015,0x76480091,0x69ca255c,0x7ae00125}},	//   _تلجر, ildy, defe, _armt
  { {0x7c2202d7,0x38970011,0x38660125,0xa088000a}},	//   gior, văr_, _nior_, _מְשִ
  { {0xf42a022d,0x3ea90251,0xeaae006b,0x69d80079}},	//   ltää_, quat_, ъй_, fdve
  { {0xdb1b002e,0x4422255d,0x7c22255e,0x69ca255f}},	//   _dauð, zik_, aior, gefe
  { {0x7c22005c,0xf42a00f2,0x38ca0086,0xf9900031}},	//   bior, ntää_, قايی_, ابه_
  { {0xb7bd0011,0x8699000d,0x63bd0111,0x49bb002b}},	//   onţi, отот_, jfsn, _گارد_
  { {0xfc300015,0x69ca0012,0x671d000b,0xf42a008c}},	//   _صحف_, befe, _बेशक_, htää_
  { {0x49bb0074,0x7bcb1220,0xe5710029,0xb7bd0011}},	//   _دارد_, legu, خطة_, inţi
  { {0xd5b80024,0x45190195,0x38661eff,0x44222560}},	//   enās_, юция_, _fior_, tik_
  { {0xc2090008,0xb901005d,0x76480007,0x45180010}},	//   _דה_, दि_, aldy, яцыя_
  { {0x15f50029,0x2480016f,0xd808000a,0x44222561}},	//   _يستح, _čime_, _מִסָ, rik_
  { {0x35fb0074,0x7c22005c,0xa5090010,0x6d4b002a}},	//   _درصد_, zior, _мела_, ęgaj
  { {0xb7bd04f9,0x216720bc,0x7e7d138a,0xe6560015}},	//   enţi, дири_, _atsp, _تلوث_
  { {0xd4360029,0xe3b20040,0xdee605a7,0x69ca002a}},	//   _تعتب, _شرب_, моби, zefe
  { {0x69c12562,0xff24002b,0x4256005e,0x3f9201c2}},	// [4680] _oble, ربری, _отот, rayu_
  { {0xdb1b002e,0x92660015,0x9f5902b9,0xe479000a}},	//   _rauð, _تدعم, _mosè_, ַרְכ
  { {0xdd8f0031,0xe433002b,0x9b6a12d2,0x5ce60015}},	//   شون_, _سفید, ошла_, بكال
  { {0xf767040b,0x69c100b8,0xcb0a002b,0x60db000a}},	//   _لا_, _able, ييان_, _וקטנ
  { {0xbd8a0029,0x99870007,0xa3d6000b,0x3329000a}},	//   _ونحن_, jonų_, _हसन_, ּחוּ_
  { {0xe6070086,0x99870007,0xdb230030,0x7c222563}},	//   _شش_, donų_, úrál, sior
  { {0x853c0007,0x3866001c,0x246c0046,0x7c2219ac}},	//   ngėt, _pior_, _těmi_, pior
  { {0xd7f0003b,0x38cb0086,0x6f16005c,0xc6f80809}},	//   اكة_, تاهی_, ozyc, зних_
  { {0x8b26008f,0x99870091,0x0000006a,0x0000006a}},	//   _ўдзе, gonų_,   ,
  { {0xbafb0008,0xf42a00f2,0x44201f0f,0x75d40002}},	//   _והמש, ytää_, _ami_, ريجا
  { {0x3dd80026,0xd7f10016,0x980a0058,0x0000006a}},	//   _marw_, _lũy_, _وتصف_,
  { {0x47d40021,0x69c12564,0x0000006a,0x0000006a}},	//   _سيتر, _zble,   ,
  { {0x236d00bd,0x27f70227,0x6240008c,0x63b40247}},	//   žejo_, žená_, töop, _žená
  { {0xf42a022d,0x22440015,0x34942565,0x6f16002a}},	//   ttää_, َنَّ, _закр, dzyc
  { {0xd2580010,0x7e670079,0x40352566,0x44202567}},	//   ьцю_, _rijp, еевс, _fmi_
  { {0xf42a00f2,0xe3f80029,0x442001c2,0x236b0015}},	//   rtää_, _يعيش_, _gmi_, _بحثي_
  { {0xf42a022d,0xcddb0001,0x7e670079,0xce94006b}},	// [4690] stää_, жње_, _pijp, катъ
  { {0x7bcb00b8,0x5dd50015,0xdd91006e,0x9f592568}},	//   wegu, عقائ, اوا_, _josé_
  { {0x550e000b,0x7bcb2569,0x99730046,0x6f160046}},	//   ानिए_, tegu, těži_, azyc
  { {0xdb510029,0x515a0008,0x6d470264,0x7bf90033}},	//   هَا_, _מכתו, _vyja, янер_
  { {0x6f16005c,0x6d47005c,0x3dd80026,0x645d256a}},	//   czyc, _wyja, _farw_, imsi
  { {0x3dd80026,0x7bcb256b,0x5e450015,0x20090091}},	//   _garw_, segu, _أَسْ, lkai_
  { {0xda62004a,0xedd40058,0xd942011e,0x7af60c4e}},	//   ывши, _جيّد, леши, øytr
  { {0x20090095,0x3ea60007,0x5c650015,0x99870091}},	//   nkai_, šote_, _أُرك, tonų_
  { {0x20090024,0x9058000a,0x2d910030,0x66e50033}},	//   ikai_, ובהו_, _keze_, хопа
  { {0xe6160080,0x78ae002d,0x99840015,0x644404a9}},	//   едь_, óivé, _للكو, _skii
  { {0xdddd0024,0x13a80086,0xc329000a,0xb8b40015}},	//   _atsū, وندی_, _פו_, _لإنت
  { {0x672a00dc,0xafdb0134,0x246c0089,0x99870007}},	//   ámjá, _skøn, _němu_, ponų_
  { {0x8c1a0008,0xe29703be,0xb3b1005d,0xa8020064}},	//   פושי, ная_, _झारख, ğıtm
  { {0xd2520074,0xddcd0091,0xfb1a004f,0xb146256c}},	//   انس_, epaž, לורמ, енгл
  { {0xb5b6000a,0x2fd90034,0x35f8002b,0x205613d0}},	//   _נלקח_, _basg_, _ترند_, етар
  { {0x251a0008,0x68e5008c,0x76410123,0x4420256d}},	//   _מוצא, ähdy, loly, _umi_
  { {0xddc600df,0x0eaa0010,0xee0a0004,0x2d910046}},	// [46a0] _aukš, якай_, пеал_, _beze_
  { {0x6e460225,0x8d850086,0x6f16005c,0x600a0046}},	//   رنام, نشمن, rzyc, _týmo
  { {0x2d910a9c,0x6f160050,0xb0af000b,0xeb080065}},	//   _deze_, szyc, जूदग, वन्त_
  { {0x207b0053,0xe7df000b,0xdca30004,0x601100cb}},	//   _מאטא, _खोला_, ѓачи, _påme
  { {0xd12f0074,0xdb83006b,0x3dd80034,0x539b000a}},	//   _نمی_, угчи, _tarw_, פיסו
  { {0x4a53005e,0x61fe256e,0x0000006a,0x0000006a}},	//   гкіс, _jopl,   ,
  { {0x76410026,0x245200dc,0xd8760015,0xf1b3000a}},	//   doly, záma_, راغب, אסו_
  { {0xd6d00015,0x7d120061,0x2fc0256f,0x4cbb004f}},	//   لقب_, ıksı, nfig_, _מזלו
  { {0x87e3005f,0x27fd2570,0x9f590003,0x76410030}},	//   ующе, _down_, _posé_, foly
  { {0x76410026,0x5a9b000a,0x8b0b000a,0x4b55006b}},	//   goly, _משמא, _מִבֵ, _ръст
  { {0xe4e30010,0x54550608,0x3e76001a,0x96b7002b}},	//   гіян, квот, _læt_, وایز_
  { {0x89370008,0xf484002b,0x27fd00da,0x69da2571}},	//   _ארבע_, _یابی, _gown_, _hate
  { {0x8c1b0008,0x41c70010,0x57fb000a,0xd7fb000a}},	//   לוטי, нёва, _מלאו, _מהאל
  { {0x24522572,0x7753005e,0x38ba00aa,0xef1f0030}},	//   ráma_, _скіф, oër_, _meüt_
  { {0x2fc00026,0x2fd90026,0xddcd0007,0x61fe0107}},	//   ffig_, _pasg_, tpaž, _dopl
  { {0x628d003f,0x69da0106,0x320a002a,0x94cc000b}},	//   _twao, _late, akby_, ़बीआ
  { {0x4034005f,0xf2070010,0xfe730070,0x6e250064}},	// [46b0] уетс, _зяно, ادر_, tihb
  { {0x2fd90026,0x8d740031,0xe45f20c6,0x20091147}},	//   _wasg_, هاما, lmö_, skai_
  { {0x2d91016f,0x463b0053,0xddd00011,0x2fd90034}},	//   _veze_, לעמע, şeşt, _tasg_
  { {0x853b000a,0xeab10015,0x69da0601,0xa09a004f}},	//   הגבי, لعت_, _aate, _קירט
  { {0x38ba00dd,0x539c000a,0x6e590015,0x3f892573}},	//   eër_, ליאו, _يلجأ_, mbau_
  { {0xddc60024,0x6c850015,0x69da2574,0x27fd00da}},	//   _tukš, _للسم, _cate, _sown_
  { {0x69da17e1,0x76410123,0x6b750cab,0x3ea90028}},	//   _date, voly, _албу, lrat_
  { {0x69da003e,0x3f8900b8,0xccf2000a,0x6d552575}},	//   _eate, nbau_, _דכל_, _izza
  { {0x41b2005d,0x06550033,0x69da2576,0x3ea9251f}},	//   _जालस, ктоў, _fate, nrat_
  { {0xe4750010,0xe7080015,0x49d9005e,0x69da2577}},	//   кумэ, عتين_, _ідею_, _gate
  { {0x27fd0041,0xa8020061,0x3ea9216b,0x57b5005e}},	//   _town_, ğırm, hrat_, _абет
  { {0xe3b200e6,0x657a002d,0x3ea92578,0x69da2579}},	//   جرد_, acth, krat_, _zate
  { {0x13a80086,0x61fe03ed,0x7bdb02f2,0x29070091}},	//   ونگی_, _popl, _mauu, lyna_
  { {0xa116002b,0x3ea9257a,0xe716000a,0xb21b02de}},	//   پورت, drat_, _שחסר_, spæn
  { {0x3e760134,0x3f8900b8,0xd59a000a,0x61461236}},	//   _sæt_, fbau_, _חבצל, тева
  { {0x7bdb0035,0xa3b9000b,0x93c30045,0x2609000b}},	//   _nauu, _चाय_, şări, िसकी_
  { {0x61fe21d5,0x6d55160a,0x6f660033,0x3ea9257b}},	// [46c0] _topl, _azza, тваз, grat_
  { {0x9f5900dc,0xee370185,0x60db002a,0x3e330015}},	//   _alsó_, вну_, łuma, لفقر
  { {0x69da0af3,0x602c0061,0x3ea9257c,0x3f890012}},	//   _rate, eşme, arat_, bbau_
  { {0x3e760134,0x3ea901cb,0xb4fa0c44,0x2907002a}},	//   _tæt_, brat_, ופעי, dyna_
  { {0x2f560010,0x69da257d,0x3ea9257e,0x2907001a}},	//   _штос, _pate, crat_, eyna_
  { {0x19580256,0xf2d3000a,0x0136004f,0x0000006a}},	//   налы_, יעד_, ֣רֶת_,
  { {0xc2130008,0x69da00b8,0xc173000a,0xbb860015}},	//   שהו_, _vate, סחה_, _للأي
  { {0xf0930008,0x7d0300c0,0x7791002b,0xa9670054}},	//   בנה_, änse, میما, њића_
  { {0x15aa006b,0x69da123d,0xbb46257f,0xa3c60065}},	//   мъни_, _tate, _реак, ईऍन_
  { {0x7bc22580,0x35f40598,0x0000006a,0x0000006a}},	//   lfou, упор,   ,
  { {0x2618014e,0x2907005c,0xa8a5012c,0x7ae22581}},	//   योगी_, cyna_, _مصنو, lvot
  { {0x657a002f,0x4c9b0053,0x3c3c002c,0xd91b000a}},	//   scth, ושטע, tívy_, _קואל
  { {0x9f5902d7,0x6d580057,0x7ae2001a,0x86960054}},	//   _così_, ývaj, nvot, _рјеч
  { {0x6594018f,0xf7e1002a,0x3ea92582,0x7ae22583}},	//   _саку, ążeń_, vrat_, ivot
  { {0x0657000a,0xf194005e,0xa1940a86,0x35a300af}},	//   _שיוך_, рись, расч, _тајг
  { {0xc8db000a,0x3ea92584,0xbfa80033,0x7ae22585}},	//   וקלט, trat_, ктуе_, kvot
  { {0x9f552586,0xd438000a,0x2907002a,0xa6f8000a}},	// [46d0] увач, _שטחי_, zyna_, עִֽי
  { {0x3f890012,0x7bc20079,0x8e140033,0x3ea92587}},	//   sbau_, efou, адуц, rrat_
  { {0x3ea92588,0x7bdb02f2,0xdcbb005e,0xc172000a}},	//   srat_, _pauu, ьща_, _לחי_
  { {0xa50b000a,0xab5d002a,0xfb870033,0x3ea90781}},	//   וּדִ, _zaży, тыжн, prat_
  { {0x41c0005d,0x7e550086,0x13c8000a,0xf1c0000b}},	//   श्वस, _منحص, דּוֹ_, श्वन
  { {0xf2d40053,0x201e0024,0x4a44005e,0x2907002a}},	//   שעס_, ītie_, анів, tyna_
  { {0x98e50015,0xac19007e,0x9f40001a,0x7ae20091}},	//   اكبو, _зову_, ljið_, avot
  { {0x31580008,0x2907002a,0x629d2589,0xafdb01d0}},	//   כיון_, ryna_, ksso, _skøj
  { {0xf9930067,0x2907002a,0x98be0073,0x0000006a}},	//   _نبض_, syna_, _rytą_,
  { {0xba550029,0x629d258a,0xcb12000a,0x6a550015}},	//   _صناع, dsso, _הלמ_, _صَائ
  { {0x629d258b,0x49470033,0x25e8000b,0xdb000144}},	//   esso, _рэаб, जाजी_, _admè
  { {0x629d258c,0x0000006a,0x0000006a,0x0000006a}},	//   fsso,   ,   ,
  { {0x8c1a0008,0xfbd2000a,0x32010046,0xb6a5004a}},	//   תורי, צתך_, _bohy_, _силл
  { {0x42560086,0x2fda002b,0x9f590144,0xdb19002a}},	//   انسر, کورد_, _cosí_, lewó
  { {0x8fa6008f,0xf652013a,0xe1650015,0x2b49002a}},	//   лаве, _הצג_, لدفي, żach_
  { {0xab5d002a,0x6286258d,0x7f1a0138,0x0000006a}},	//   _waży, ppko, нізу_,
  { {0x82360086,0x543b0053,0x63a40035,0x7f1a008b}},	// [46e0] _مردا, _רעפא, _idin, хіву_
  { {0x6446258e,0x4d160174,0x7bc2258f,0xa3be0065}},	//   loki, льет, wfou, ीजक_
  { {0xeafa0086,0xadb70029,0x61fa007c,0xed5a004a}},	//   کرات_, اهما_, ötlu, хож_
  { {0x644600df,0xdb19005c,0x0ecf005d,0xcaef000b}},	//   noki, jewó, _सैकड, चमंड_
  { {0x539b000a,0x69c30765,0xac070033,0x7bc212d6}},	//   תינו, ffne, ынца_, rfou
  { {0xcebf0089,0x5eeb000a,0x82d7004c,0x7bc20079}},	//   ěřte_, _אַלְ, טונג_, sfou
  { {0x7bc20177,0x64462590,0x6cd8000a,0x7ae2001a}},	//   pfou, koki, _בַּצ, svot
  { {0xc8c706e4,0xf093000a,0xb8cc000b,0x8c461e48}},	//   اوين_, זנה_, _कट_, _себе
  { {0x644600df,0x09e60238,0x49ca012b,0xa61412fd}},	//   doki, _йоан, _план_, имич
  { {0xf48605e6,0x20022591,0xba9b004f,0x6d4e0073}},	//   лумн, _loki_, _נסבי, _kyba
  { {0x88860080,0xfdf70c44,0x6446007c,0x1dc6000b}},	//   _слеж, אצית_, foki, र्यत
  { {0xe8d70008,0xc9530008,0x64460007,0x38cb002b}},	//   _תואר_, _המע_, goki, _سامی_
  { {0xe60f0086,0x63a40026,0x93270015,0x2d9a07ba}},	//   زشی_, _ddin, ارجن, kape_
  { {0xd5760080,0x6018002e,0x6284002d,0x63a42592}},	//   _судь, _límd, _dtio, _edin
  { {0x656f0089,0xc977000a,0x0467005e,0x54a60015}},	//   ěcht, רגלי_, _йтим, _إحتف
  { {0xc2750124,0xaffc0010,0x2483006f,0xb27515be}},	//   _клиј, носi, íjme_, _клиш
  { {0x69c8018c,0xa3cb000b,0x442b03fe,0x69c30034}},	// [46f0] _obde, _रॉय_, mic_, yfne
  { {0x629b0007,0x442b2593,0xdb19002a,0xdd940015}},	//   šuos, lic_, zewó, مجمع
  { {0xdcf50024,0x5c0702e5,0x63a400f2,0x2ce80088}},	//   _iezī, ляда, _ydin, льцо_
  { {0xf2d5000a,0x24b7004c,0x442b2594,0xdb0b0030}},	//   ֹעַ_, רהאן_, nic_, eggá
  { {0x68e80176,0x3ec40089,0x7f9a000a,0x8f9a000a}},	//   _ardd, ěstí_, _בברז, _בירי
  { {0xa2ad005d,0x627c0053,0xca490015,0x8d740015}},	//   _जिन्, ענונ, خلته_, _هافا
  { {0x5ce4008f,0x6ce40036,0xab950036,0xf7710029}},	//   _люта, _літе, _вибі, ياة_
  { {0x06c9005e,0x442b2595,0x0000006a,0x0000006a}},	//   вгий_, jic_,   ,
  { {0x7af6022d,0x55f502bf,0x63a402b9,0x7c2b0385}},	//   äytt, ачну, _rdin, migr
  { {0x7c2b2596,0xe5a50054,0x7a570015,0x7ae92597}},	//   ligr, јини, _إضرا, _iret
  { {0xa8a40e88,0x64462598,0x34a9006b,0x442b2599}},	//   _грчк, toki, ъвно_, fic_
  { {0xe3661174,0xa9040029,0x600a002c,0x78fa0008}},	//   икни, _ابْن, _tými, _בפעו
  { {0x8bd60008,0xe3560010,0xe708002b,0x6446259a}},	//   בורו_, ртнэ, _متون_, roki
  { {0x644602f6,0x471a004f,0x7c2b0072,0x0000006a}},	//   soki, _בונג, higr,
  { {0xdfd20087,0x442b259b,0x016600e2,0x91031673}},	//   ييس_, bic_, ркво, опре
  { {0x2eed0085,0x130602c8,0x30750421,0xe53a000a}},	//   _šefa_, _взим, сурс, _שתקר
  { {0x5ea6003b,0xa0670a21,0xee260033,0x7e260033}},	// [4700] شمال, рата_, амап, адаж
  { {0x6603022d,0x929b0008,0xe29b000a,0x329b000a}},	//   _jonk, _שיית, _ששיר, _שביד
  { {0x8f760036,0x6603259c,0xeb9a04b9,0x222b002b}},	//   _вугі, _monk, вие_, _جزيی_
  { {0x7d0301d1,0x05480053,0xa2ad005d,0x6d4e0107}},	//   änsa, נטאָ_, _जिम्, _vyba
  { {0x60180014,0x24590152,0x6d4e002a,0x5e460015}},	//   _címe, néma_, _wyba, _نَحْ
  { {0x7ae9259d,0xc3330008,0x9c860029,0x7bc90079}},	//   _dret, חוד_, _نشره, _ebeu
  { {0x8ccd005d,0xd90f0010,0x1dc6005d,0x7ae9259e}},	//   _सहयो, ць_, र्णत, _eret
  { {0x3f80002c,0x960e005d,0x2d981e72,0x28a7000b}},	//   nciu_, िस्ट_, _here_, _गिरि
  { {0x442b259f,0xf76f0015,0x2d9825a0,0x7ae925a1}},	//   vic_, واً_, _kere_, _gret
  { {0x9a6a0225,0xa3b9005d,0x442b002a,0x3ea025a2}},	//   _شمال_, _चाह_, wic_, isit_
  { {0x2d9825a3,0x3f80002c,0x397b0135,0xd946009c}},	//   _mere_, kciu_, _סטאנ, _тежи
  { {0x2d9825a4,0x3ea025a5,0xe3b00058,0x0000006a}},	//   _lere_, ksit_, ورُ_,
  { {0x6603056c,0x442b25a6,0xc5f8003d,0x79810034}},	//   _fonk, ric_, lmēm_, _yflw
  { {0x25080086,0x442b25a7,0x2d9825a8,0x171b000a}},	//   _مربی_, sic_, _nere_, _שֵׁמ
  { {0x365b0008,0xe4530070,0x442b25a9,0xf0270004}},	//   _שכונ, _وضع_, pic_, аќан
  { {0x34fb011f,0xa2d7000b,0x683e003d,0x9f590144}},	//   _יהוד, यबद्, bīde, _posà_
  { {0x78750007,0x8d770029,0x442925aa,0xc7d7000a}},	// [4710] _išve, لاضا, _ima_, סומי_
  { {0x273300a7,0x2d980011,0xdd950010,0x2ca702c1}},	//   ảng_, _cere_, сажы, ándo_
  { {0x7ae9016f,0x2d9825ab,0x7c2b0ecb,0x661a007c}},	//   _sret, _dere_, tigr, ihtk
  { {0x7ae925ac,0x547b015b,0xf5370643,0x2d980546}},	//   _pret, דטאו, סטאר_, _eere_
  { {0xf1ec005d,0x7c2b25ad,0x3f990034,0x3ea00030}},	//   _छोड़_, rigr, _iesu_, csit_
  { {0x2ba70092,0x6af40015,0xe7df000b,0xf9880015}},	//   ốc_, تثمر, _खोजा_, لنهي_
  { {0x442925ae,0xb7bd0011,0x7ae900da,0x2b5a002a}},	//   _oma_, liţi, _wret, ępca_
  { {0x0138011f,0x2d81115f,0x21380008,0x3138000a}},	//   ירות_, lche_, יטול_, ינום_
  { {0xb7bd0011,0x0ab80029,0x2d9825af,0x0593002b}},	//   niţi, _نطلب_, _yere_, يادگ
  { {0x442925b0,0x644d008c,0xda09002b,0x2d8125b1}},	//   _ama_, _akai, _حيطه_, nche_
  { {0xae1a013a,0x3f80005c,0x660325b2,0x2d8125b3}},	//   רותכ, yciu_, _vonk, iche_
  { {0xc209000a,0x1956000a,0x3ea0008c,0x3f990091}},	//   _אה_, _הבעל_, ysit_, _nesu_
  { {0xa3b9014e,0xb7da000a,0xa856000a,0xd7c8002b}},	//   _चार_, _תקני, _פינה_, _خونه_
  { {0xb7bd0011,0xdb0e0003,0x661a0b8e,0x442925b4}},	//   diţi, édéc, chtk, _ema_
  { {0x459a0053,0x707a002b,0x2d980144,0xe292002b}},	//   _עסקע, امرز_, _rere_, _کذب_
  { {0x3ea00f7a,0x442918db,0x7c3b0123,0x601806cb}},	//   tsit_, _gma_, _njur, _símb
  { {0x7d0300c0,0x3f8025b5,0xaf490015,0x441b000a}},	// [4720] änsn, rciu_, لشكل_, _תופס
  { {0x82360074,0xc3330135,0x02fb015b,0x42230033}},	//   _دربا, _מוח_, _עלימ, _ндыв
  { {0x44290b7c,0xecba0015,0x27ff001a,0x8d5a0891}},	//   _yma_, ططات_, kjun_, ушат_
  { {0x2d9803c2,0xeb9a0002,0xa3cb000b,0x6f0d0077}},	//   _were_, اضات_, र्प_, byac
  { {0x2d980020,0x7c3b00c0,0xcc880086,0xaab4005e}},	//   _tere_, _djur, انچه_, ійкі
  { {0x527b0053,0x2d8104ed,0x7c2908a2,0x3a3a007c}},	//   אנסא, cche_, _emer, õpp_
  { {0x71d7000a,0x3f990573,0xa3b9000b,0x1d07012e}},	//   מוסד_, _yesu_, _चाल_, _лери_
  { {0x6c3603c4,0xc7b900dc,0x6d5c25b6,0x76480034}},	//   _افرا, ggő_, _izra, wody
  { {0xa3cb005d,0x62960034,0xe9a608f7,0x76480535}},	//   र्फ_, _nwyo, _газп, tody
  { {0x644d15ff,0x442900e8,0xa3cb005d,0x7c2900bd}},	//   _skai, _sma_, र्न_, _zmer
  { {0x76480780,0xb7bd04f9,0xd5b80024,0x7c290026}},	//   rody, ziţi, rgā_, _ymer
  { {0xd7f7006b,0xdd1c006f,0x14a90065,0x799a0546}},	//   _гуш_, káža, _किरण, _hetw
  { {0xdb000089,0x2d8125b7,0x1dd80065,0x6aa202ad}},	//   _odmí, yche_, ड़ात, nsof
  { {0xf8dc000b,0x7792002b,0x34940033,0x98ac000b}},	//   _मनाय, _بیکا, _дакр, _घटाए
  { {0x95830050,0xd59b0008,0x44f4005e,0x442925b8}},	//   łącz, _גבול, _єпис, _tma_
  { {0x442911e0,0x90550010,0xb7bd0011,0x644d003f}},	//   _uma_, івац, tiţi, _ukai
  { {0x443925b9,0xff530067,0x6f0d0061,0x2d8125ba}},	// [4730] mns_, سخر_, uyac, tche_
  { {0xb7bd0011,0x2d8125bb,0x7c2925bc,0x799a25bd}},	//   riţi, uche_, _smer, _netw
  { {0x7c290111,0x22640089,0xfcd500e6,0x2d8125be}},	//   _pmer, řské_, تياج, rche_
  { {0x2d8125bf,0x443925c0,0xcb550054,0xafdb00cb}},	//   sche_, nns_, овећ, _sjøf
  { {0x799a0041,0xa3cb014e,0x8ca5005d,0x443925c1}},	//   _betw, र्य_, _चटको, ins_
  { {0xe29c00b2,0x929c000a,0x9f400012,0xd358000a}},	//   נשור, ניות, leiß_, ציגי_
  { {0xf8a90074,0x600a002c,0x98ac0007,0x27ff008c}},	//   شگاه_, _týmt, _dydį_, tjun_
  { {0xa3cb005d,0x6b8204ed,0x16a9004a,0x443925c2}},	//   र्म_, ccog, авии_, jns_
  { {0xd7060080,0x290e0064,0x1dc6000b,0xfae00046}},	//   жные_, ayfa_, र्वत, áště_
  { {0xf6250191,0x443925c3,0xf9930040,0x9f400012}},	//   ідно, ens_, _ربط_, heiß_
  { {0xa3cb005d,0x4439002e,0xdb1900b8,0xf992000a}},	//   र्भ_, fns_, gewö, _חרב_
  { {0xd7e4022a,0x6b9b0159,0x443925c4,0xe39a0054}},	//   _нічо, _jeug, gns_, шњој_
  { {0x35a50033,0x9346004e,0x0000006a,0x0000006a}},	//   _далг, інге,   ,
  { {0xcad6000a,0x79f9000a,0xda7a004c,0xdcfc0091}},	//   חושת_, ׁלָח, ינשר, _gerė
  { {0x7d0300c0,0x98a9000a,0x216a0d1f,0xaf9a123a}},	//   änsl, יֹּ֤, риви_, итах_
  { {0x6fb60029,0xdfd200e5,0xdddc0061,0x81c8003d}},	//   تمرا, بير_, _birş, _spēļ
  { {0x02460015,0xbe860015,0x3e7f0045,0x60180030}},	// [4740] _وَبَ, تجزو, _cît_, _címa
  { {0x237f002c,0x1816005d,0x7e56042b,0xdd1c006f}},	//   ľuje_, _तत्व_, ітац, ráža
  { {0xba2a002b,0x237f0fd0,0x6b9b25c5,0x0000006a}},	//   یستم_, žuje_, _beug,
  { {0x27430091,0x3e7f0003,0x6aa225c6,0x6d5c016d}},	//   _kūną_, _fît_, tsof, _vzra
  { {0x6d5c002a,0xdddc0030,0x8c650015,0x6b8225c7}},	//   _wzra, őzől, أطلن, rcog
  { {0xf1ca005d,0x4dd60015,0x5f030033,0x48aa25c8}},	//   िभिन, _بتحس, _ўзра, атим_
  { {0xa3cb014e,0x6d5c0024,0x7d030293,0x24520046}},	//   र्ड_, _uzra, ønst, lámu_
  { {0xc173000a,0x32c40061,0xec1600c3,0x2c7801c0}},	//   וחו_, köy_, _بورد, aždý_
  { {0xdcfc0007,0x4439063b,0x29d60015,0x473401c5}},	//   _perė, vns_, _ويرس, янис
  { {0xd6260029,0x6b9b00b8,0x44390495,0x60db002a}},	//   تعبي, _zeug, wns_, łumi
  { {0x7d7b013a,0xd7fa042b,0x69d825c9,0x3958001a}},	//   יניו, _вул_, meve, _árs_
  { {0xd7ef003b,0x69ca0012,0xdddc0030,0xb865012c}},	//   _لكم_, lffe, _mirő, _فانو
  { {0xc2b80036,0x78750007,0xb6060010,0xc17b005e}},	//   оляє_, _išva, _мякк, иїв_
  { {0x69d80c0a,0x3eb2002a,0x9f400012,0x1757000a}},	//   neve, dryt_, weiß_, _וסדר_
  { {0xcf9b25ca,0x6018002e,0xb5460086,0x7c390034}},	//   ија_, _síma, _بخشه, ynwr
  { {0x351b000f,0xd91b000a,0xcff4006b,0x69d825cb}},	//   _כוונ, בולל, мпсъ, heve
  { {0xa3cb021e,0xfeb80015,0x69d825cc,0xf3ff016e}},	// [4750] र्ण_, قالت_, keve, lmão_
  { {0x69d825b6,0x7db70058,0x9df802ed,0x2fc90c4e}},	//   jeve, تصرا, онут_, sfag_
  { {0xa3cb005d,0x61da000a,0xa25b0003,0x69d825cd}},	//   र्थ_, _הקתד, ntôm, deve
  { {0x601825ce,0x3eb20b56,0xab94005e,0xb4fb000a}},	//   _tíma, bryt_, диці, ילבר
  { {0x3ffa0008,0x7ccc0024,0x5db70029,0xf414000a}},	//   _הפרע, vērš, _وإسر, ופף_
  { {0x69d825cf,0xf2dc0008,0xd2b8000a,0xa3cb000b}},	//   geve, שַׁל, קלות_, र्त_
  { {0xa9690146,0x718c000a,0x621c000a,0x5ba70ffe}},	//   щика_, בְחַ, שווק, _мраз
  { {0x97d90036,0x113c000a,0x600b000a,0xccf2000a}},	//   ську_, יתול, יהֶ֔, _אכל_
  { {0xb6a30016,0xc054000a,0xe7310040,0xafdb0013}},	//   _giấ, וזק_, عصب_, _kjøb
  { {0x69d8151c,0x61e50227,0x19bb0015,0x99840015}},	//   ceve, _nahl, _خطرة_, _يلقو
  { {0x46380033,0x5dc8000a,0xca480058,0xe708009a}},	//   ўчыя_, חֶרְ, _بلله_, متین_
  { {0x78f80015,0x4346006b,0x45180033,0x683e01ec}},	//   _بعكس_, земв, юцыя_, līdn
  { {0x7e7d00df,0xa7c60086,0xb77a0008,0x92930010}},	//   _nusp, _رژيم_, _האנש, наўц
  { {0x867a000a,0x60180030,0xa18707be,0xf9870015}},	//   _פרצו, _címn, збра_, عب_
  { {0xe3b20029,0xf652000a,0x45fa000a,0x7e7d25d0}},	//   _كرة_, _רצו_, _להסג, _ausp
  { {0x7e750024,0xa3cb005d,0xa2d60015,0x1e861a2d}},	//   _aizp, र्द_, _فيعت, злам
  { {0xdfcf0115,0x441b00a3,0xf8b8000b,0xd0070734}},	// [4760] طيل_, _לוקס, _इम्प, чете_
  { {0x0ea7008f,0x9f420089,0x3eb200f2,0x2452013f}},	//   якуй_, _jaké_, rryt_, rámu_
  { {0xdcfc0024,0x717b000a,0xf8a5002b,0xafdb00cb}},	//   _ierī, _לניס, _جک_, _sjøe
  { {0x69d80041,0x61e5018b,0xb33b25d1,0x69ca0034}},	//   weve, _zahl, laça, wffe
  { {0x69d815fc,0x7f77000a,0x1e831301,0x0000006a}},	//   teve, _מעכב_, _плям,
  { {0x2eb50033,0xdd9200c3,0x1af30033,0xb33b0006}},	//   _ўсяс, _سور_, эпія, naça
  { {0x69ca0176,0x9f49002e,0xdb020077,0x7e7d0012}},	//   rffe, ljað_, rgoñ, _zusp
  { {0xdc8b000a,0x0d3b000a,0x69ca0034,0xebe31e98}},	//   _לְמָ, _הגלב, sffe, _посп
  { {0x8c430063,0xba3d0089,0xc6f7054f,0x69ca0012}},	//   _чете, _kvůl, зных_, pffe
  { {0x1dcf000b,0xba090015,0xadf2000b,0x601a0046}},	//   स्पत, _وتلك_, घाटन_, růmy
  { {0x9f470089,0x61e507c4,0xb33b016e,0x0000006a}},	//   ěné_, _rahl, daça,
  { {0x4917000f,0x287b000a,0x5335006b,0x320c008c}},	//   _מקבל_, _הנאמ, демт, ödyn_
  { {0xc34b006b,0x61e525d2,0xf3ff016e,0xb33b01f6}},	//   сяне_, _pahl, smão_, faça
  { {0x27e6002d,0x7d030123,0x26db000a,0x9f550003}},	//   _haon_, änsk, _לקדמ, _âgée_
  { {0xdcfc0048,0x2b52005c,0xb65b000a,0x865b000a}},	//   _derī, żych_, _הדגש, _הדגי
  { {0x61e500b8,0x85570008,0x653b0008,0x65570008}},	//   _wahl, _משוב_, _לעוד, _מבוא_
  { {0x02a4008f,0x23280001,0x27e625d3,0x644f25d4}},	// [4770] _прэм, _ноћи_, _maon_, moci
  { {0x628d003f,0x644f25d5,0x531c000a,0xa15925d6}},	//   _itao, loci, _לוחצ, _мапу_
  { {0xdb0900dc,0xf1b2000a,0x23cb000a,0x4ca80015}},	//   _ideé, _בסי_, ֶצַּ, كُلُ_
  { {0x644f25d7,0x79880079,0x2bbb0015,0x6d550046}},	//   noci, _afdw, صاصة_, _vyza
  { {0x7e7d01be,0x0ae80058,0x1f74009b,0x09e5011e}},	//   _uusp, كروي_, _плюя, долн
  { {0x2d850005,0x200b0f48,0x4efa000a,0x644f25d8}},	//   _üle_, _hoci_, _והשו, hoci
  { {0xa3dd014e,0x08d4008f,0x1c570015,0x63ad1d9a}},	//   ड़ा_, ецыя, _فخرج, _odan
  { {0x63ad000c,0xd0f80008,0xcc0b002b,0x3739005e}},	//   _ndan, למות_, _ازآن_, жчою_
  { {0x200b25d9,0x27e60125,0x644f25da,0xbae50058}},	//   _moci_, _daon_, doci, _تكذي
  { {0xa3cb005d,0xe6110029,0x7b740029,0x63ad25db}},	//   र्स_, ئشة_, _أطفا, _adan
  { {0x1dcf005d,0x0446087a,0xd46a239c,0xca480015}},	//   स्यत, денн, жине_, _علمه_
  { {0xa7150001,0xc2c60029,0xb715005e,0xf1a9000a}},	//   _одељ, ويجي, _одещ, _כס_
  { {0x63ad0176,0x0cba014e,0x9f4201b2,0xe2970139}},	//   _ddan, _उम्म, _také_, мая_
  { {0x04780086,0x628d002d,0x75480030,0x0736004f}},	//   _کليک_, _dtao, épzé, _קאסם_
  { {0x3cf9005d,0x644f002a,0xb33b25dc,0x27e602f2}},	//   ूहों_, boci, raça, _yaon_
  { {0xa4b6000a,0x037a0015,0x30550054,0x644f25dd}},	//   _חלקה_, _بحثت_, еђут, coci
  { {0x6da6023e,0x7f1a0033,0xb33b25de,0x9343004a}},	// [4780] диза, ціву_, paça, _инъе
  { {0x6b890ae9,0x9f49002e,0x601825df,0x63ad095b}},	//   _afeg, rjað_, _tímo, _zdan
  { {0xa3cb021e,0x01fb000a,0x9be6005e,0x614625e0}},	//   र्व_, _ופיל, ділк, _цена
  { {0xcdc900b2,0xad65002b,0x0000006a,0x0000006a}},	//   יך_, راله,   ,
  { {0x27e6002d,0xda660029,0x59f804f7,0x0a6a058f}},	//   _raon_, واتي, зеля_, орки_
  { {0x2bae0023,0x09e30001,0xbea303ae,0x644f13c3}},	//   ộc_, вољн, _јарк, zoci
  { {0x0000006a,0x0000006a,0x0000006a,0x0000006a}},	//     ,   ,   ,
  { {0xb8d6000b,0x2fc025e1,0x76aa0e4d,0xeb9a0477}},	//   _जि_, ngig_, отов_, _фиа_
  { {0xc8ca0074,0xd6da0036,0xc5f80024,0x6fd0000b}},	//   _ژوئن_, іти_, kmēt_, ड्यू
  { {0x7c2203af,0xda650029,0x163a0015,0x644f002a}},	//   lhor, _كالي, تسعة_, woci
  { {0xf9c70086,0x27e60035,0x2db70008,0xcdb70008}},	//   _تحقی, _taon_, ולין_, ופיה_
  { {0x7c2217dc,0x321800aa,0x7d0304f8,0xf8ad002b}},	//   nhor, ekry_, änsi, _اکو_
  { {0xa3cb005d,0x43940001,0x44250007,0x601800dc}},	//   र्ष_, ђарс, ėl_, _címm
  { {0x9f59002d,0x644f0f4b,0x200b25e2,0x7205009a}},	//   _tosú_, soci, _soci_, روزم
  { {0xdfd50256,0xdb0002de,0x55bb000a,0x25bb004f}},	//   новы, _udmæ, _ומוו, _וצומ
  { {0x212a0086,0xe3d00092,0x23c6005d,0x84470029}},	//   سيقی_, _hằng_, _वायद, _تختل
  { {0x200b02d7,0x628d003f,0x3df517b1,0xc05802a3}},	// [4790] _voci_, _utao, нзас, фір_
  { {0xb33b0251,0x7865001c,0x867b000a,0xa7fd0030}},	//   laço, móve, קרבו, tműk
  { {0x82340074,0x23c6000b,0x7c2225e3,0x7865001a}},	//   _جريا, _वामद, fhor, lóve
  { {0xe0d20053,0xfbab0036,0x7c221c9e,0xdea1002b}},	//   _גײט_, ітей_, ghor, _میری
  { {0x1dc7005d,0x24440064,0xd108002b,0xaac4006e}},	//   _लापत, nıma_, _فقیه_, نتون
  { {0xba770086,0x5db40058,0xedb40058,0x7c22005a}},	//   ذاشت, _لإفر, _لحفظ, ahor
  { {0x8bc70a61,0x3ea925e4,0xc19c004f,0xbd450058}},	//   _осад, lsat_, חשוי, _أنزي
  { {0xc5f80024,0x386618b7,0x765a00dd,0x7c2225e5}},	//   kmēs_, _chor_, elty, chor
  { {0xe3d00023,0xf7710196,0x99d70015,0x1dcf000b}},	//   _bằng_, داث_, _يتطا, स्थत
  { {0xe3b20086,0x24440061,0x8f58004f,0xb9950058}},	//   گرد_, dıma_, וסחא_, _ألاب
  { {0xa81b0015,0x3ea925e6,0xaa76004f,0xb33b01f6}},	//   _وتصر_, hsat_, _נתעד_, faço
  { {0xccf200b2,0x9d1a0008,0x68ea0030,0xa3cb000b}},	//   אכט_, פורט, üldő, र्ल_
  { {0x386d0d3d,0x0000006a,0x0000006a,0x0000006a}},	//   mmer_,   ,   ,
  { {0x3ea903f6,0x386d25e7,0xb33b0061,0x321e01c0}},	//   dsat_, lmer_, maçl, óty_
  { {0x3218020a,0xb5fe0092,0x59c4000b,0x361a039e}},	//   rkry_, _khơn, ल्टर, _מוסד
  { {0x14d60008,0x44e10007,0x24440061,0xd007030e}},	//   _נופל_, _ių_, bıma_, несе_
  { {0x442025e8,0x568c0053,0xc43b0008,0xf43b0008}},	// [47a0] _ili_, ַטאַ, _מתקי, _מתקש
  { {0xa3c0005d,0x386d00b8,0xdd920029,0x867a000a}},	//   ुभव_, hmer_, اوض_, פרעו
  { {0x44e100df,0x7c22003e,0x550f005d,0x386d002c}},	//   _jų_, thor, ाहिए_, kmer_
  { {0xf76725e9,0xc5f80048,0x25a525ea,0x63a6058a}},	//   _ما_, nmēr_, hall_, nakn
  { {0xa3b8014e,0xddcf0089,0xafdb003c,0x4176002b}},	//   _चयन_, řeše, _kjøn, _تاکس
  { {0xc3330053,0x25a5002e,0x63a60049,0xa37b007c}},	//   נוג_, jall_, hakn, rdõi
  { {0xe3d00023,0xeb9a0083,0x44200356,0xc213000a}},	//   _rằng_, _нив_, _oli_, רהו_
  { {0xc6f81f39,0xd5c2000b,0x9f96000a,0x370612ab}},	//   дних_, _शाहज, ׂדֶה_, ечов
  { {0xec370008,0x63a6013c,0x25a525eb,0x4a460a31}},	//   _נאמר_, dakn, fall_, _знав
  { {0x442014b1,0xceb3011f,0xcad7000a,0x443225ec}},	//   _ali_, נית_, _אומת_, _amy_
  { {0x99de008f,0x60180014,0x2a350010,0x442002d2}},	//   _нiва_, _címk, _рэтр, _bli_
  { {0x7ae21480,0xd91b000a,0x24440061,0x63a6088a}},	//   owot, _מובל, tıma_, gakn
  { {0xe298008f,0xee3f0089,0x25a525ed,0xb33b25ee}},	//   наў_, _svým_, ball_, raço
  { {0x171b00b2,0x7af600f2,0x25a525ef,0x442025f0}},	//   _צוגע, äyty, call_, _eli_
  { {0x9f470089,0x5067000d,0xb33b0341,0xa2ad000b}},	//   ění_, етаа, paço, _जिक्
  { {0x442002d7,0x7ae200dd,0x155b000a,0x455b000a}},	//   _gli_, kwot, _מכוב, _מכוס
  { {0x506425f1,0x3ea91d41,0x3f890045,0x0000006a}},	// [47b0] утра, usat_, rcau_,
  { {0x6ca713ae,0x92b40015,0xa2da000b,0x7528002a}},	//   ердж, _إحيا, _पैट्, ozdz
  { {0x442000f2,0xdcbb0063,0x7dc40086,0x3ea925f2}},	//   _yli_, яща_, اقمن, ssat_
  { {0x3ea90089,0xb33b0064,0xa3d4000b,0xdb1b0077}},	//   psat_, yaçl, स्प_, _acuá
  { {0x645d25f3,0xc43c000a,0x20090030,0xde950054}},	//   ilsi, התאי, mjai_, _јагњ
  { {0xf2d400b2,0xdc130064,0xcda9002b,0x20090030}},	//   רעס_, rşıs, _زهره_, ljai_
  { {0x6d420011,0x63a6013c,0x25a525f4,0x8d77002b}},	//   şoar, yakn, vall_, _ساسا
  { {0x386d002a,0x60180030,0x645d02de,0xe7250015}},	//   umer_, _címh, jlsi, َّثَ
  { {0x3c440010,0x25a525f5,0x24590057,0x63a60d9c}},	//   _сэрв, tall_, nému_, vakn
  { {0xb33b0064,0x4585006b,0x64440079,0xfaa80015}},	//   raçl, ъгов, _sjii, _أهلي_
  { {0xcec00089,0xb5fe0092,0x3a08002b,0x63a625f6}},	//   ěřit_, _thơn, _سکوی_, takn
  { {0x24590057,0xd6b5006b,0x69c3007c,0x66b50f78}},	//   kému_, _айдъ, lgne, _абду
  { {0xe3b80064,0x27ed25f7,0x20090030,0x2e240012}},	//   ğı_, mden_, djai_, _höfe_
  { {0x44e10007,0xe3b80064,0x27ed1fb7,0x91e60054}},	//   _tų_, şı_, lden_, њове
  { {0xa0a30080,0x20560c55,0x69c325f8,0x50b501c5}},	//   иард, втар, igne, лсту
  { {0x78480089,0x200900dc,0x44201a5d,0xf8b2000a}},	//   pěve, gjai_, _uli_, ישל_
  { {0x59e1005d,0x63a40024,0x27ed25f9,0xf4570447}},	// [47c0] फ़ार, _iein, iden_, _ביקר_
  { {0x27ed022d,0xfd76002b,0x7e230054,0x764100d6}},	//   hden_, نداخ, адуж, nnly
  { {0x63a425fa,0x601825fb,0xafdb00cb,0xad5a0248}},	//   _kein, _lími, _kjøl, фрах_
  { {0x27ed25fc,0x6f660015,0x63a40030,0xabb30015}},	//   jden_, _لهجم, _jein, لممث
  { {0x7ad40029,0xb06600f2,0xa3d4021e,0x63a40746}},	//   اقتص, _erää, स्य_, _mein
  { {0x7ae2005c,0xbda50115,0xda63106d,0xaa53008b}},	//   rwot, _محفو, авчи, авіш
  { {0x7d0301d1,0xadd70008,0x27ed0111,0xcc870033}},	//   änst, _שולח_, fden_, _абсе_
  { {0x6b850029,0x63a425fd,0xa3d4000b,0x60180125}},	//   _مشكل, _nein, स्म_, _bími
  { {0x09e60080,0xcf93000a,0xcc77000a,0x1dcf000b}},	//   _иоан, בטח_, _יעלה_, स्वत
  { {0x4b55010f,0xae05000b,0xdb0025fe,0x49ba00c3}},	//   _съст, रायन_, _remè, _زائد_
  { {0x24e3008f,0x63a423d8,0xe60f0015,0x66ef0030}},	//   ацяг, _bein, تشي_, tőkö
  { {0x47d30086,0x76410d4f,0x97c50002,0x68ed002a}},	//   _نيمر, anly, _متهم, ładc
  { {0xa3470033,0x63a425ff,0xf11b000b,0x37760033}},	//   тэнл, _dein, नन्द_, _рыжс
  { {0x752d0089,0x24590057,0xe717000a,0xa294005e}},	//   _řaze, vému_, _בחדר_, рарі
  { {0x2fd20026,0x301b0015,0xa1580839,0x78650030}},	//   ffyg_, وترة_, вару_, lóva
  { {0x7e7c069b,0x245901c0,0x63a42600,0xa7fd01d3}},	//   _airp, tému_, _gein, sműv
  { {0x6d5c0061,0x44392601,0x62842602,0xfebb002b}},	// [47d0] _ayra, mis_, _guio, ظارت_
  { {0x27ed01e2,0x24590107,0x6d5c0034,0x44392603}},	//   zden_, rému_, _byra, lis_
  { {0xf1a40010,0x200900dc,0x27ed2604,0x61d8000a}},	//   _трын, pjai_, yden_, _יוזף_
  { {0xc4d300b2,0x44392605,0xeab10015,0xbd680033}},	//   יגע_, nis_, معت_, труе_
  { {0x44390020,0x8f9a0008,0x8c160029,0x27ed0064}},	//   iis_, _רישי, طيور_, vden_
  { {0xdd940010,0x7d0300c0,0x44392606,0x78750091}},	//   _вары, änss, his_, _išvi
  { {0x69c32607,0xa3d4000b,0x09f60015,0x44392608}},	//   rgne, स्ड_, طفية_, kis_
  { {0x8699000d,0xf0940008,0x44392609,0x27ed260a}},	//   нтот_, בנק_, jis_, uden_
  { {0x27ed260b,0x63a403b8,0xd7f80054,0x4439260c}},	//   rden_, _rein, туј_, dis_
  { {0x4439260d,0x6729005c,0xceb40008,0x9f420089}},	//   eis_, rzej, ביץ_, _jaká_
  { {0x63a4260e,0x6284002d,0xf992039e,0xdb00260f}},	//   _pein, _suio, _הרב_, _remé
  { {0x289a0053,0x9cd6000a,0xdb000003,0x7c390034}},	//   _נינא, נורה_, _semé, niwr
  { {0x8c1a013a,0x63bb002e,0x63a42610,0x6b56000a}},	//   גורי, óuna, _vein, ֨ישׁ_
  { {0x44392611,0xe6c2001a,0xe5a50054,0xbb3a000a}},	//   ais_, _óháð, _сики, תעשי
  { {0x3d1d014e,0x63a42612,0x11390010,0x28c6000b}},	//   पनों_, _tein, вяты_, रूपि
  { {0x24830069,0x7ae92613,0x7e7c008c,0x44392614}},	//   íjmu_, _oset, _sirp, cis_
  { {0xbe860015,0x78480046,0xd5a7000b,0x7c390034}},	// [47e0] اجرو, něva, _ग़ाज, diwr
  { {0x683e0024,0xd1b2002b,0x61fe1bd0,0xee3725d6}},	//   rīdi, _دیسک, _unpl, гну_
  { {0x7ae90c8d,0x786500dc,0x9f470089,0x27330092}},	//   _aset, zóva, ěná_, ảnh_
  { {0xc1780007,0x60bb0008,0xac970015,0x201e003d}},	//   žės_, _אצטד, اننا_, ītis_
  { {0x6d5c0050,0x28c6000b,0xbab70015,0xa3cc000b}},	//   _wyra, रंभि, هدوء_, _लान_
  { {0xa3d4014e,0xf2d30008,0xb885006f,0x44392615}},	//   स्त_, צעו_, zlíš, zis_
  { {0x7ae90014,0x98a30001,0x69e20046,0x0d75004a}},	//   _eset, бије, _čteč, _вытя
  { {0x79810026,0xb814049d,0x78650030,0x7c650021}},	//   _eglw, рдиј, tóva, _ناقل
  { {0x57f3055f,0x44392616,0xcfb7004f,0x17f70058}},	//   спыт, vis_, אלפי_, طرية_
  { {0x68ed005c,0x44392617,0x5a560063,0x9adb000a}},	//   łada, wis_, _събу, _אחמט
  { {0x97c60031,0x29180e5f,0x44392618,0x0e57004c}},	//   _مقاو, _æra_, tis_, רשיט_
  { {0xb4270015,0x44392619,0xb6a600ce,0x44070138}},	//   اعدو, uis_, _бидл, учоб
  { {0xa3cb005d,0xe6930086,0xdc37004c,0x23c6000b}},	//   र्ग_, _هلند, ראכט_, _वारद
  { {0x659404ab,0xf773000a,0x4439261a,0xc6930643}},	//   _таку, _פקס_, sis_, _האס_
  { {0x66710086,0x361b000a,0xa1590800,0x1637000a}},	//   _بگير, _אוגד, таву_, _תנור_
  { {0x9582002a,0x443900da,0xff070239,0xafdb00cb}},	//   łądk, qis_, лязн, _tjøm
  { {0x1e350010,0x447c004c,0x0e350033,0x63b0005a}},	// [47f0] анаў, _אנהע, анаю, řiný
  { {0xf2d4000a,0xafdb00cb,0x3d27055f,0xa3dd000b}},	//   _העץ_, _kjøk, льев, ड़क_
  { {0xa8070064,0x627a000a,0x9b950015,0xc27a000a}},	//   ngıç, _שנתנ, للات, _שרתי
  { {0xf41f00f2,0xac740086,0x2c7e0046,0x1bd5261b}},	//   nkä_, مانش, _půda_, родя
  { {0xf41f00f2,0x9f42006f,0xf1d2000b,0x5fce0065}},	//   ikä_, _taká_, द्वन, _हॉटल
  { {0x387d0176,0xa3cc005d,0x8d7700e6,0xdeba000a}},	//   _siwr_, _लाभ_, _مازا, _במשל
  { {0x6d43002d,0xa8020061,0xafdb00cb,0xa9680058}},	//   únad, ğınm, _skøy, همهم_
  { {0xc888003b,0xb8cd005d,0x01380008,0xbd440015}},	//   دخول_, _कब_, טרות_, _انفي
  { {0x78a4016f,0xe7390054,0x3cef0046,0x762521a4}},	//   ćiva, ђео_, ťově_, имиз
  { {0xf41f00f2,0xe6160080,0x36690054,0x0000006a}},	//   ekä_, иды_, ђано_,
  { {0x9984040b,0x236900bd,0xe7b5002b,0xe708002b}},	//   _المو, _azaj_, _نماد, نتین_
  { {0xf770002b,0xbc19000a,0x7bc6001a,0x4424261c}},	//   _کام_, דוֹש, _ökut, óm_
  { {0x72c30256,0xfbd2000a,0x59da000b,0xf2c50138}},	//   обяз, קתך_, _मॉडर, йсён
  { {0xe297261d,0x65870138,0x0000006a,0x0000006a}},	//   рар_, _сыдз,   ,
  { {0x463a0053,0x505a0080,0x70560015,0x32530033}},	//   _בעסע, вшая_, لنسا, цвёр
  { {0xdb0b002e,0xd3ba0010,0x630602be,0x0000006a}},	//   yggð, _рукі_, _نوبل,

  { {0xe5a30023,0x84450029,0x27ef0557,0x56b5004c}},	// [4800] _điệ, _دخول, _magn_, יפּן_
  { {0xbda5003b,0x41aa000b,0x35bd000b,0x0d960033}},	//   محمو, _क़िस, _एएफ़, ршаў
  { {0xdddd0011,0xc1bb000a,0x71d7000a,0x91bb000a}},	//   _susţ, _במיש, _דויד_, _במיי
  { {0x601800dc,0x1024002b,0x27ef02f2,0xf1d2000b}},	//   _címt, _اکسپ, _nagn_, द्रन
  { {0xa3cb005d,0xf1aa005d,0xe809000b,0x6e200045}},	//   र्ट_, _क़ान, वाना_, _îmbo
  { {0xca560001,0x3ceb00f2,0xd357000a,0x5a33005e}},	//   штењ, äivä_, סיסי_, оніт
  { {0x68ed005c,0xf1b3000a,0x2c67007c,0x4ddb000a}},	//   ładn, קסה_, sõda_, _שחלו
  { {0xf0930008,0x6018002e,0x237f0046,0x6fd10030}},	//   חנה_, _tímu, žuji_, mócó
  { {0xffb70053,0x9634261e,0xb6060033,0xf646261f}},	//   ױליש_, йниц, аянк, ихон
  { {0x60de06f5,0x64460a6d,0x22580085,0xa6340033}},	//   _oppm, enki, jork_, ённі
  { {0xf41f00f2,0x77ca0010,0x2419055f,0x32132620}},	//   tkä_, _алег_, гоны_, _roxy_
  { {0x35ca005d,0x493b000a,0xd91b000a,0xa8070061}},	//   ़्ज़, _בגבו, _שואל, rgıç
  { {0xe6940029,0x63b60026,0xe60f002b,0xc34b004a}},	//   _التد, _ddyn, سشی_, тяне_
  { {0x26c40007,0xa3cb021e,0x94d40015,0xd6270054}},	//   mumo_, र्ज_, _هيتش, _воље_
  { {0x9f49002d,0x15fb000a,0x26c40091,0x31780015}},	//   rdaí_, _שִׂמ, lumo_, لحفظ_
  { {0xcf981cf5,0x02a7005f,0x757b0008,0xe809000b}},	//   ију_, _кром, _בטופ, वाया_
  { {0xb427002b,0xf773004c,0xe4d8002b,0x22582621}},	// [4810] _معکو, ַקע_, _شوکت_, bork_
  { {0x6018002e,0x433c000a,0x320c008c,0x6e200045}},	//   _símt, _שעזב, ödyt_, _îmbl
  { {0x601800dc,0x63b60026,0xa3d4000b,0x52740015}},	//   _címs, _ydyn, स्व_, _بايز
  { {0xc57900b2,0xccf80001,0xa3cb021e,0x69da04de}},	//   אָנט, шћу_, र्च_, _abte
  { {0x2ef4008f,0xa3d9005d,0xe2140086,0x78480089}},	//   _дзяр, ठ्य_, _طبیع, těvn
  { {0xa8020064,0xff16000a,0x09e1000b,0xe37c000a}},	//   şılm, _הקשת_, फ़ेय, דרדר
  { {0x601801b2,0xe8f50015,0x7cf00030,0x89d6012c}},	//   _tímt, إستخ, rórá, صوير_
  { {0x9f950005,0xdb000089,0x68ed005c,0x26c42622}},	//   _nüüd_, _zemí, łado, fumo_
  { {0x26c40007,0x0a940a1f,0x78650030,0x27ef2623}},	//   gumo_, _матю, sóvo, _vagn_
  { {0x06090142,0xa3cb000b,0x2480007c,0xc8c900c3}},	//   унок_, र्घ_, _siim_, _موطن_
  { {0x24960086,0x2480007c,0x8579004a,0x0000006a}},	//   ینید_, _piim_, ысит_,
  { {0x2e24002e,0x22581c67,0x6446008c,0x26c40091}},	//   _nöfn_, work_, unki, bumo_
  { {0xf7450054,0xe60e125c,0x734902ed,0x0000006a}},	//   _ћело, _ед_, ачёв_,
  { {0xf5950058,0xa3630058,0x0000006a,0x0000006a}},	//   _الغج, سُّو,   ,
  { {0x15420033,0xe6100015,0x660323cf,0xca7a000a}},	//   _нешм, _تشن_, _innk, טנשט
  { {0x6018002c,0x351a0135,0xdfd200e5,0xc952000a}},	//   _ríms, _תוקנ, ثير_, פמן_
  { {0xa0671e48,0x1ea90015,0x25ee000b,0x92b60058}},	// [4820] сата_, لالي_, _असमी_, _احبا
  { {0x60180014,0x83370008,0xdcfc0024,0xa3d4005d}},	//   _címr, _לאפס_, _agrā, स्र_
  { {0xa63a00b2,0x7afb0e0a,0x60de00c0,0xeb9a0080}},	//   נגער, _arut, _uppm, гие_
  { {0x7afb2624,0x32da004f,0xd00a012b,0x0000006a}},	//   _brut, ָחַנ, _семе_,
  { {0x7afb002f,0xcf930008,0x69ce0064,0x4422020e}},	//   _crut, _מטר_, _öbek, ikk_
  { {0x6d43002d,0x41db000b,0xee3a004a,0x78480046}},	//   únac, म्पस, _снг_, těvo
  { {0x89d30015,0x98a30054,0x907a000a,0x7afb2625}},	//   ستوط, пије, ְטִי, _erut
  { {0x26c400df,0xa097000a,0x87e60033,0x98a30054}},	//   tumo_, זדקק_, сюке, чиће
  { {0xaac5003b,0x8b260080,0xdb0e00f2,0x501b000a}},	//   _وتكن, _удае, äjäl, טוקו
  { {0xba2300d0,0x26c40091,0xa63401c6,0x44222626}},	//   _едук, rumo_, інні, ekk_
  { {0x8afd0089,0x26c41ea7,0xba3d0089,0x9e5b000a}},	//   _vyře, sumo_, _tvůr, רכיט
  { {0x397b0053,0x3eb200f2,0x7d7b000a,0x7c222627}},	//   _עטאנ, ksyt_, טניו, nkor
  { {0xcc3b00b2,0xb8570029,0xb7db000a,0x25ac0046}},	//   רעכט, _النص_, _תקדי, padl_
  { {0x290d005c,0x44222628,0x69ca2629,0x7d1e005b}},	//   ślał_, akk_, ngfe, kyps
  { {0x463b00b2,0xa3d5110d,0x7c22262a,0x765a002a}},	//   _געגע, _дойч, kkor, moty
  { {0x988b000a,0xef991d90,0x7c22262b,0x7f840058}},	//   טָמֵ, ркаш_, jkor, كلفن
  { {0xc3b8000a,0xdd9b005e,0x644d008c,0x8e150cfe}},	// [4830] _הלחץ_, гше_, _ijai, одац
  { {0x629d262c,0x3e6f007c,0x78650030,0xf1a704bb}},	//   mpso, küte_, góvj, _урин
  { {0x7175002b,0xdb00002a,0x7afb01b3,0xbd6b0033}},	//   _گهگا, _odmó, _srut, урае_
  { {0x69ca00dc,0x237f016f,0xd9e1005d,0x7c22262d}},	//   egfe, žuju_, फ़्ट, gkor
  { {0x5ba8008f,0x7175002b,0x63af006f,0x69d8262e}},	//   скім_, _دهگا, iacn, ffve
  { {0xe9d80010,0x5ee8000a,0x4429262f,0xdb0b0003}},	//   йкі_, _פַרְ, _lla_, nagé
  { {0x4422158b,0x721c000a,0x38ca002b,0x228f0061}},	//   ykk_, רווח, لايی_, _lük_
  { {0xe739005f,0x2ca70011,0x7afb2630,0x7c221b62}},	//   ией_, ându_, _trut, ckor
  { {0x7c290064,0x3ffa0008,0x5629006b,0x4ffa000a}},	//   _iler, בִיא, ижим_, בִינ
  { {0xc8ab010f,0x765a2631,0x3619004a,0x644d1d41}},	//   _бъде_, goty, рцию_, _ajai
  { {0x67d50191,0x240a085d,0x44292632,0xf3e62633}},	//   _можу, анни_, _bla_, ожно
  { {0xc209013a,0x7bcb2634,0x76480870,0x1956000a}},	//   _בה_, nggu, andy, _ובעל_
  { {0x44290f9a,0x61e72635,0x7bcb001a,0x765a002a}},	//   _dla_, fejl, iggu, boty
  { {0x442903af,0x64a50010,0xf6960015,0xdb0b0003}},	//   _ela_, _дака, _بنوع_, gagé
  { {0x7c222636,0xd1750033,0x71760015,0x7c3b0f0a}},	//   ykor, зыты, زهرا, _omur
  { {0xdfa60029,0xf1db005d,0x14760021,0xdb000030}},	//   تحسي, म्बन, _باتج, _lemá
  { {0xfe05005d,0xf99f0092,0x3daa0054,0x69ca0034}},	// [4840] रांस_, _đèn_, икао_, ygfe
  { {0x26c2016f,0xdb000057,0x9d46004a,0x7c292637}},	//   škog_, _nemá, оезд, _aler
  { {0x55ba0008,0x5ce60029,0x44292638,0x4177002b}},	//   שמעו, تكال, _yla_, _واپس
  { {0xab6603a8,0x7c290f4b,0x228f0061,0x99870091}},	//   овел, _cler, _yük_, kinų_
  { {0x3ce6002c,0x6da60015,0xdb000030,0xc477000a}},	//   ňov_, _ومحم, _bemá, קתנו_
  { {0x7c222639,0xdca605a7,0x25560046,0xe8ea0015}},	//   skor, _маги, nělé_, لربو_
  { {0xc27b0008,0xdb0002c1,0x7c2200dc,0xc213000a}},	//   ברסי, _demá, pkor, והג_
  { {0xdb000251,0xd6da120f,0x4c9b000a,0x69d50061}},	//   _temà, ато_, _כשלע, _özen
  { {0x69960063,0xaad1000b,0x75e60033,0xf1aa000b}},	//   _дрех, _समयक, оўне, करान
  { {0xd6d70010,0x44290111,0x19c30036,0x765a0073}},	//   іты_, _sla_, _обум, uoty
  { {0x65630176,0x61e70134,0x96170029,0x4429263a}},	//   _cynh, vejl, تغير_, _pla_
  { {0x98a3012f,0xd7f00015,0x9cd7004f,0x1e170065}},	//   _цице, _سكت_, חוטה_, _दक्ष_
  { {0x765a1e08,0x53340a32,0x28130040,0xc21b005e}},	//   poty, деят, _تونس, аєв_
  { {0x8ccb005d,0xe534044e,0x60180144,0x60c7005a}},	//   _हमलो, _нель, _símp, tujm
  { {0x307b0029,0x65630026,0x659b000a,0xd5b8003d}},	//   لحرة_, _gynh, _דיוק, nkām_
  { {0x36340086,0x1ddd000b,0xdb0f0061,0x98be0091}},	//   _برچس, न्नत, _çeçe, _lytį_
  { {0x23280001,0xdef80033,0x2d8700bc,0xed8b0033}},	// [4850] _моћи_, жых_, žnem_, асек_
  { {0x645d04f9,0xccfb0001,0xdd9b0219,0xc332000a}},	//   losi, иће_, рша_, _נוי_
  { {0x12780029,0x69c4000b,0x99870091,0x200f007c}},	//   _بحيث_, _राजी, zinų_, ögis_
  { {0x515a013a,0xe5710053,0x68ed005c,0x63ad263b}},	//   _לכתו, ײַב_, ładk, _jean
  { {0x63ad17ce,0xfaa5263c,0x645d003f,0x93fc000a}},	//   _mean, чало, iosi, ילאי
  { {0x7e7900b2,0x62850089,0x786502c1,0x63ad0541}},	//   _לאָז, _jiho, móvi, _lean
  { {0xa3cc005d,0x6925005e,0x645d263d,0x7afe003d}},	//   _लाल_, ямка, kosi, āpta
  { {0x1bb800b0,0x6fcb005d,0x8bc40fbd,0x99870091}},	//   _واقع_, िलिं, _осуд, tinų_
  { {0xd7060080,0x2019003f,0xafdb02de,0x65630034}},	//   зные_, _mosi_, _imød, _synh
  { {0xdb0000fb,0xa9070015,0x58870033,0x79a7045f}},	//   _bemæ, _وبان, _дыда, _фрае
  { {0x1ddd005d,0xf2c90135,0xcc75000a,0xd90c002b}},	//   न्यत, _תע_, ּעָה_, _نیو_
  { {0x63ad002f,0xb8ef005d,0x645d263e,0x35cf000b}},	//   _cean, वं_, gosi, त्ज़
  { {0x2d87002c,0x59d2000b,0x8c1a004c,0x63ad263f}},	//   ľnej_, _सामर, צושי, _dean
  { {0xf67500b2,0xf7700086,0x877a0053,0x2d87002c}},	//   _צײַט_, _شان_, _פאסי, žnej_
  { {0x16380029,0x62850375,0x76412640,0x9557002b}},	//   _بسنة_, _diho, mily, _بخشا
  { {0x764100f2,0x63ad0161,0x997e0045,0xa3ad000b}},	//   lily, _gean, lăţi_, गरण_
  { {0x6fad014e,0xcf89004c,0xaec60033,0x6a640144}},	// [4860] _ज़रू, ָט_, ябал, sòfi
  { {0x76410026,0xc333000a,0xf3f8003d,0x0e631c7d}},	//   nily, _רוז_, ēģu_, екун
  { {0xd5b10092,0xcea9000a,0x59d2000b,0xf652000a}},	//   iá_, רי_, _साबर, עצב_
  { {0xae05000b,0x9a8601c5,0xd5b100a1,0x0000006a}},	//   राउन_, пукл, há_,
  { {0x7641002e,0xab830174,0x0216000a,0x0eb90033}},	//   kily, нушк, ּחֶם_, _муры_
  { {0x69d501e2,0x78480089,0xa8a60a6c,0x3ea01e78}},	//   _özel, pěvk, прик, mpit_
  { {0x8afd0089,0x76410034,0xfce30429,0x3ea02641}},	//   _vyřa, dily, _поро, lpit_
  { {0x77920086,0x44fa0024,0xafdb0595,0x9cd7000a}},	//   ریتا, _rī_, _hjør, _מולה_
  { {0xafdb06f5,0x6aa90176,0xd5b80024,0xae20000b}},	//   _kjør, _gwef, skām_, _मकान_
  { {0x0f370008,0x984e0064,0x63ad2642,0x7a8b000a}},	//   פריט_, rşın_, _sean, _הָאַ
  { {0xa96a00e5,0x2c51002a,0x557401b0,0xaa570040}},	//   _امام_, ląda_, ьгот, _علما_
  { {0xb8650225,0x9f4002c1,0x645d0b9f,0x69dc2643}},	//   _قانو, ndió_, uosi, _öreb
  { {0xe809014e,0x260c005d,0x29180251,0xa6fa0015}},	//   वारा_, ़ादी_, _àrab_, _دعاء_
  { {0xc7450031,0x877b000a,0x321a2644,0x997e0045}},	//   _تضمي, _האדי, _copy_, căţi_
  { {0x63ad002f,0xd49a0054,0x62852645,0x20190714}},	//   _tean, _урл_, _viho, _posi_
  { {0xc5f8003d,0x206400af,0x2d9c01d3,0x0000006a}},	//   ldē_, еђув, űvel_,
  { {0xb6a30023,0xd3710029,0x3ea00035,0xafdb2646}},	// [4870] _nhấ, _جهة_, gpit_, _bjør
  { {0xc5f8003d,0xe803000b,0x26c42647,0xe731004f}},	//   ndē_, _शोना_, irmo_, כֵב_
  { {0xa3d4005d,0x4035047d,0xa37b007c,0x6ec2000b}},	//   स्क_, _женс, deõi, _लिथु
  { {0x22430a9c,0x92030024,0x7a2f003c,0x76410064}},	//   lijk_, žādi, _møte, zily
  { {0xb6a30023,0xda350033,0x6ffa000a,0x20d70061}},	//   _chấ, меды, _והרפ, lçi_
  { {0x9b04008f,0xafdb003c,0x32dc000a,0xb9c40058}},	//   эзід, _gjør, צחונ, فقهي
  { {0x23bf005d,0xe809000b,0xa3d0000b,0xaa560015}},	//   ्लाद, वाला_, शलम_, بلوا_
  { {0xccf2013a,0x76410026,0xdb000b14,0xac380058}},	//   _בכל_, wily, _bemä, _فسقط_
  { {0x997e04f9,0x22430111,0xd6ce0015,0xb9e7005e}},	//   tăţi_, kijk_, لقي_, _ніжи
  { {0x20d70064,0xba740015,0x7af4005e,0xd5b10016}},	//   kçi_, _كالت, _язує, uá_
  { {0xa25b001c,0x22430079,0xdb0e0030,0x99d40015}},	//   trôn, dijk_, óköz, _ستلا
  { {0xe8940010,0x3ea000f2,0x3e74002c,0xdd1c002c}},	//   _чаць, ypit_, mäte_, náša
  { {0xdb0000b8,0xfbb6000a,0x16390015,0xa5f90c9a}},	//   _gemä, ופרת_, _وستة_, _меду_
  { {0x14c5005d,0xb77a000a,0x05290004,0xa5f60054}},	//   _विपण, _ואנש, _молк_, _жељу_
  { {0x045a0015,0x2459006f,0x759a000a,0xdddc2647}},	//   _وجبت_, hémy_, _ויצח, _nirš
  { {0x98a70050,0x0eaa0033,0xdbcc001a,0xafdb00cb}},	//   czną_, жкай_, jóðk, _sjør
  { {0x3ea00089,0x93130015,0xdfcf0015,0x4477004c}},	// [4880] upit_, _لويش, شيل_, _קעפל_
  { {0xae0e005d,0x82860015,0xed03004c,0xd258002b}},	//   साधन_, _تجعل, גיטאַ, _ریزش_
  { {0x3ea00064,0x7c660029,0x0b8a0248,0xe803000b}},	//   spit_, واصل, осли_, _शोभा_
  { {0x5fb2005d,0x6fb2005d,0xdca30317,0xa06a084f}},	//   _ज़िल, _ज़िं, таци, _фама_
  { {0x8db60191,0x5f060010,0x9f4002c1,0x25ee000b}},	//   _осві, _ўзга, rdió_, _असली_
  { {0x9e76002b,0xef83033d,0x89d80015,0x6209000a}},	//   _آهست, _шляп, سوبر_, ּ֔סֶ
  { {0x2611014e,0xafdb06f5,0x35a7005d,0x6e2300dc}},	//   तानी_, _kjøp, _ग़ज़, önbe
  { {0xb6a30023,0x7d0300fb,0xb6f4049d,0xc173000a}},	//   _thấ, ænse, езиј, כחו_
  { {0x78ad016f,0xc6f7054f,0x15ea005e,0x8c430098}},	//   ćava, дных_, оєно_, _рете
  { {0xc5f8003d,0x0ae90015,0x3ead007f,0x0000006a}},	//   udē_, _عرقي_, _çete_,
  { {0x6e2004f9,0xc9850015,0x994a00c3,0x2508002b}},	//   _îmbu, _كشمي, _بلال_, سردی_
  { {0x69da005d,0x22430111,0xb937004f,0x260c0065}},	//   प्री, wijk_, _קראג_, ़ाही_
  { {0xe298008f,0x287b000a,0x236b0015,0x98a7002a}},	//   маў_, _ונאמ, تحدي_, rzną_
  { {0x20d70064,0x88c70089,0x06370015,0x2c7502de}},	//   tçi_, spěš, _يسوع_, måde_
  { {0x22430298,0x30850029,0x2b5a002a,0xf1e4000b}},	//   rijk_, فلسف, ępcy_, ग़ज़_
  { {0x4ea703f1,0x1eab0029,0xa3cc000b,0x3e890015}},	//   држа, قائي_, _लाए_, كَرَ_
  { {0x9f55004a,0x4084027a,0x799a1bd2,0x0000006a}},	// [4890] хвач, турб, _oftw,
  { {0x7c3a00df,0xff040080,0x7bde00dc,0xbd6b0080}},	//   _įtra, ъясн, őpul, орее_
  { {0x92580029,0xdcbb0248,0x644f2648,0x22580058}},	//   _تشير_, юща_, onci, _تجيب_
  { {0xdfa7003b,0x447c00b2,0xdddc00df,0x6458001c}},	//   _تحدي, ַנגע, _virš, _êxit
  { {0xd6c60225,0xa3d4021e,0x8f9a000a,0x644f2649}},	//   _حق_, स्ट_, _מירי, inci
  { {0x9f420089,0x7dc70015,0xdea4002b,0x2489264a}},	//   _jaký_, _تتحك, _شیمی, _liam_
  { {0x9f400084,0xd9960015,0x248901c2,0xe26c004f}},	//   ldið_, رنيت_, _oiam_, קֻדָ
  { {0xf42a00f2,0x3e7400b8,0xb066008c,0x2489013b}},	//   isää_, räte_, _isää, _niam_
  { {0x9f400084,0x47580010,0xf625250c,0x0a6b0180}},	//   ndið_, дрэя_, едпо, _држи_
  { {0xa3e2005d,0x69de0020,0xe6110015,0x644f1ecb}},	//   न्न_, õpet, اشة_, enci
  { {0xb8d40015,0x6c79004c,0xd46a098b,0x5c79000a}},	//   _لتنش, ּאָפ, зине_, ּאָה
  { {0x78fa000a,0x26d80045,0x0000006a,0x0000006a}},	//   _מפעו, ăror_,   ,
  { {0x42d50010,0x24890049,0x57270015,0xe72e0718}},	//   кіру, _diam_, _تراق, _се_
  { {0x471a0008,0x171a0008,0xbb3a0053,0x27ed264b}},	//   _מונג, _מונע, לערי, leen_
  { {0xafe60a7f,0xc0760001,0x9f470089,0x50b5009c}},	//   новл, ећањ, ěný_, ксту
  { {0x27ed02a5,0x24890092,0xdfd20029,0x2087123a}},	//   neen_, _giam_, طيط_, ейси_
  { {0x64460332,0xd00f0015,0x5059005e,0x27e0007c}},	// [48a0] miki, حلق_, єшся_, _öine_
  { {0xbe660086,0xe0da023e,0x27ed264c,0xd337000a}},	//   رهاي, _ево_, heen_, _נריה_
  { {0x61d700b2,0x27ed014a,0xabaa0015,0x63bb001a}},	//   _אויף_, keen_, كهام_, ðung
  { {0xae0e005d,0xc4d20053,0x33c9000a,0x23fb000a}},	//   साहन_, רגא_, ֵהוּ_, ּ֤אמ
  { {0x59f800a4,0xa3e2021e,0x24840227,0x6446007c}},	//   деля_, न्य_, íjmy_, iiki
  { {0x6446264d,0xa2bb000a,0xbb470015,0x6249006f}},	//   hiki, למנט, علون_, sľov
  { {0x64460508,0x644f0026,0x6b9b0026,0x6249006f}},	//   kiki, ynci, _ffug, pľov
  { {0x683e0048,0xd90d0086,0x61ee00b8,0x27ed0409}},	//   līdz, تیم_, hebl, geen_
  { {0xc5f80048,0xd6da005e,0x4ac60015,0xe7970015}},	//   klēt_, їти_, _سياق, رخيص_
  { {0x601800dc,0x64460cdd,0xab090015,0x2489264e}},	//   _címz, eiki, _تتفق_, _siam_
  { {0xa3cc005d,0x24590036,0x644622cc,0xdb0b00dc}},	//   _लाख_, дань_, fiki, magá
  { {0x27ed1024,0x78480046,0xa29501f3,0xdb0b0030}},	//   ceen_, těvu, камі, lagá
  { {0x2819002b,0x38660030,0x41e701f3,0x2489016e}},	//   _تفنگ_, _ikor_, ніва, _viam_
  { {0x644609e2,0x61ee264f,0xe6170fea,0xf10c000b}},	//   aiki, gebl, _пдч_, हमूद_
  { {0x2bd1014e,0x28c6000b,0x64462650,0x38660030}},	//   _हाला, रंटि, biki, _kkor_
  { {0x248900d9,0xd4680054,0x6446151e,0x601802ed}},	//   _uiam_, _пије_, ciki, нося_
  { {0x9f42002c,0xbe6500c3,0xc27501ca,0x9df91cc9}},	// [48b0] _taký_, نهري, _илиј, мнат_
  { {0x6b9b02b9,0x0000006a,0x0000006a,0x0000006a}},	//   _sfug,   ,   ,
  { {0x2374002b,0x61e1007c,0xa1590033,0x6d350015}},	//   _لایح, õllu, _цану_, خفاض
  { {0x683e0007,0xbca40015,0xd116000a,0xdea1002b}},	//   būdi, امني, _סקרה_, _نیری
  { {0x27ed2651,0x501a004f,0x0000006a,0x0000006a}},	//   veen_, _חורו,   ,
  { {0x7db40029,0x314b0008,0x27ed2652,0x02fc000a}},	//   _مصفا, ּתֵּ, ween_, פלומ
  { {0x27ed2653,0xa3e2000b,0x26c22654,0x6fc50065}},	//   teen_, न्ड_, ákon_, िणपू
  { {0xc5f80024,0x6e200011,0xd709004a,0x6d3a000a}},	//   klēs_, _îmbr, дние_, _חֲמו
  { {0x27ed2655,0x8ccd000b,0x64462656,0x61ee2657}},	//   reen_, दूरो, viki, yebl
  { {0x27ed022d,0x26c3018c,0x3866013c,0x61ee0144}},	//   seen_, čjo_, _ekor_, xebl
  { {0x6446229a,0x88c70015,0x61ee0079,0x853c0091}},	//   tiki, _ستال, vebl, lbėj
  { {0x61aa000b,0xa3cc000b,0x7c2b0079,0x04462658}},	//   कर्ष, _लाओ_, nkgr, темн
  { {0x61ee00dd,0x386d2659,0x6446265a,0x26cd265b}},	//   tebl, mler_, riki, queo_
  { {0x644614d0,0x61ee0077,0x7ae60123,0x263d006f}},	//   siki, uebl, _äkte, eňov_
  { {0x4f96000d,0xa06a265c,0xf1c0006f,0x25b6012c}},	//   врзу, дава_, žšou_, _شهيد_
  { {0x61ee020a,0x386d01e2,0x7ae900f2,0xdee60054}},	//   sebl, nler_, _opet, коби
  { {0xc7b200b2,0xd36f0029,0x60ce003e,0xa067265d}},	// [48c0] יבן_, _وهى_, subm, тата_
  { {0x386d265e,0x8d2a005e,0x7e7e008c,0xd1ba002b}},	//   hler_, мозв_, umpp, _کاکا_
  { {0xdd8f0031,0x0d0a0021,0x386d265f,0x853c0091}},	//   زون_, بقاً_, kler_, ybėm
  { {0x351a0053,0xf7670002,0x44202660,0x386d2661}},	//   ווענ, _نا_, _joi_, jler_
  { {0x44202662,0x80e2005d,0x6af30015,0x764300aa}},	//   _moi_, _पहुं, لثور, _omny
  { {0x6da30036,0xadba0086,0xa3e2005d,0x78750007}},	//   _вира, _زهرا_, न्त_, _išvy
  { {0xac9a0086,0x61e30064,0x386d2663,0x6444008c}},	//   _آنرا_, _önle, fler_, _omii
  { {0x44200b92,0xc6f82105,0x7c2b2664,0x3e660003}},	//   _noi_, ених_, ckgr, pôts_
  { {0xf76f0029,0xca480092,0x7c200125,0xdb0b1dde}},	//   ياً_, hời_, _iomr, pagá
  { {0xceb30008,0x35e30036,0x44200c0b,0xba0a0015}},	//   סית_, ацюв, _aoi_, _تترك_
  { {0x2c7501d1,0x443200dd,0x2db7000a,0x386d220e}},	//   låda_, _bly_, כלין_, bler_
  { {0x6d43002f,0x07a6017c,0x44202665,0x853c0091}},	//   únai, _радн, _coi_, lbėk
  { {0xa3e2005d,0x4420257e,0x27e602f2,0x3817000a}},	//   न्ध_, _doi_, _ibon_, _שקדם_
  { {0xa4d4005e,0xd0d5006b,0x65932666,0x6444008c}},	//   _бокі, логъ, _кашу, _emii
  { {0x442011e0,0x06750033,0x44320223,0x442b01c2}},	//   _foi_, _суця, _fly_, pkc_
  { {0xa3e2005d,0x443200aa,0x224d0030,0x853c0091}},	//   न्द_, _gly_, őek_, ybėj
  { {0xcddb0001,0xce94006b,0xb088004a,0xee95009a}},	// [48d0] дње_, иатъ, тёре_, ادرک
  { {0xe7e2014e,0x386d0064,0x645d0003,0x0e340484}},	//   क्ता_, zler_, érif, аную
  { {0xee8401d9,0x2d8715cb,0x386d2667,0x7ae92668}},	//   рыто, äne_, yler_, _spet
  { {0xb7e2000b,0x7c2000da,0xdd0d002a,0xd0110015}},	//   _कॉलम_, _comr, _półp, _الح_
  { {0xdd1c002c,0x5ba80010,0xc43c000a,0xd5b8003d}},	//   _vášm, ткім_, ותאי, nkās_
  { {0x853c0007,0x386d2669,0x69dc007f,0x7ae9013b}},	//   rbėj, wler_, _örel, _vpet
  { {0x386d266a,0x0593002b,0xbd450015,0x18690e37}},	//   tler_, یادگ, _إنزي, наки_
  { {0xb8db014e,0xf771002b,0x386d266b,0x1bbb002b}},	//   _अब_, یاک_, uler_, _زارع_
  { {0x386d266c,0x4420266d,0x3b55266e,0x9f590003}},	//   rler_, _roi_, _скар, _basé_
  { {0x7c20002c,0x69c102de,0x4420266f,0x386d2670}},	//   _zomr, _udle, _soi_, sler_
  { {0xc32900b4,0x442002d7,0xb7d50225,0x48e4005e}},	//   _צו_, _poi_, _مقاب, _воєв
  { {0x389a0053,0x889a000a,0x263d006f,0xb7940054}},	//   _װיסנ, _טבעי, vňou_, _кршћ
  { {0x27fd0176,0x44202671,0xe2971ab5,0xe7870033}},	//   _iawn_, _voi_, лая_, _ружо
  { {0xbb3a0053,0xf7700067,0x425506a6,0xe5a20974}},	//   געשי, _بام_, атст, _лиши
  { {0x463a00b2,0x44202672,0x365a000a,0x44f30091}},	//   _רעצע, _toi_, _אכסנ, _uţ_
  { {0x64440035,0x69cd005d,0x442002b9,0xe3b20067}},	//   _umii, _साझी, _uoi_, _ارث_
  { {0x6729000c,0x7d030134,0x06960053,0x447b004c}},	// [48e0] nyej, ænsn, ָדעם_, _אנקע
  { {0xc333011f,0x27fd0495,0x26df1b2e,0x9f400003}},	//   _לוח_, _lawn_, ituo_, nfié_
  { {0x661c002e,0xfd95005e,0xa37b007c,0x6df30015}},	//   örki, ршую, leõp, إكما
  { {0x9582002a,0x27fd0034,0xeaba123a,0x61fe2673}},	//   _łąko, _nawn_, ейд_, _hapl
  { {0x7528005c,0x4af80818,0xf8840054,0xd196000a}},	//   zydz, телю_, _коjи_, ְכֵי_
  { {0x673b002c,0x63b6002e,0x27e60026,0xcb07002b}},	//   dzuj, _leyn, _sbon_, ايون_
  { {0xa8a30010,0x7cf8000a,0xc8c7002b,0xa9340248}},	//   брык, _בִּק, هوون_, рейш
  { {0x76aa2073,0x20002674,0x27fd0026,0x61fe1ff9}},	//   нтов_, ndii_, _cawn_, _lapl
  { {0x59d60015,0x6f041915,0x27fd2675,0x2ee0092b}},	//   _مغار, nvic, _dawn_, ntif_
  { {0x14ca005f,0xa3e2021e,0x61fe2676,0x7528002a}},	//   ными_, न्स_, _napl, tydz
  { {0xb993003b,0xd7e60036,0xc9930029,0x18a6000d}},	//   _المب, _біло, _المظ, _саем
  { {0x87060086,0xd7f72677,0x2ee0215e,0x35d8000b}},	//   _مبتل, _буш_, ktif_, ब्ज़
  { {0xfe04014e,0x0464008f,0x629602c1,0x41c70010}},	//   रयास_, стэм, _cuyo, лёва
  { {0x69d501e2,0x9f4b002d,0xa294005e,0x41c70033}},	//   _özet, _tacú_, сарі, ыёма
  { {0xd5b80048,0xa3e2005d,0x2611005d,0xd59b000a}},	//   skās_, न्ह_, तारी_, _אבול
  { {0xd346002b,0x645d0140,0x50670fd5,0x69db0065}},	//   اییه_, érid, утга, _नाभी
  { {0x2dcb0001,0x69da2678,0x62962679,0x3da7012b}},	// [48f0] ећен_, _octe, _guyo, греб
  { {0x68fa0012,0xe731000a,0x2777000a,0xee840138}},	//   _ostd, קֵן_, רגמן_, быхо
  { {0x82340074,0x2ee00049,0xc19a000a,0xe8170065}},	//   _دريا, atif_, _בשתי, थामा_
  { {0x3e970115,0x69da0287,0xaab9002b,0x61fe09fa}},	//   _مؤسس, _acte, ندتر_, _zapl
  { {0x3d950036,0x2ee02114,0x26c20085,0xaae40015}},	//   _вигр, ctif_, škoj_, مسوو
  { {0xdd940010,0x3ea90849,0x329c0008,0xe7e2000b}},	//   _гары, mpat_, עבוד, क्सा_
  { {0x27fd00da,0xade40033,0xf9f60015,0x4439267a}},	//   _pawn_, _уцяк, شفيع_, khs_
  { {0x2bd9002b,0x27ff008c,0xdcee003d,0x2d9c0030}},	//   _جاسک_, udun_, _uzbā, űvet_
  { {0x63b60084,0xa3d9005d,0xd00c0008,0xdb26002b}},	//   _reyn, ालन_, תּוֹ, _پولی
  { {0x673b0089,0xdb0b00c0,0x7d02002a,0x63b6267b}},	//   rzuj, gagå, łose, _seyn
  { {0xa8cb0029,0x245b0007,0xf992000a,0x61fe007c}},	//   _سباق_, kšmę_, _ורב_, _rapl
  { {0x07d80002,0x9cd6000a,0x61fe267c,0x4439267d}},	//   _مذهب_, סורה_, _sapl, ghs_
  { {0x63bb0084,0x61fe0cd4,0x43760127,0x8c1a000a}},	//   ðuna, _papl, рунт, דורי
  { {0x09b50053,0x97560008,0x54360086,0x6f0402b9}},	//   יפֿט_, _דינו_, ارگر, vvic
  { {0x60860029,0x602602c5,0xe0860015,0xa37b007c}},	//   لشرك, адва, لجري, seõp
  { {0x32040050,0x7afb0005,0xf55a0008,0xdfd20029}},	//   śmy_, _osut, _בדצמ, تير_
  { {0x645d1f0d,0x5f03005e,0x20000bba,0x2d96070c}},	// [4900] érie, озта, rdii_, арес
  { {0xb2bb0008,0xa2bb00a3,0x35dd000b,0xee37267e}},	//   _שמיר, _שמיט, _माफ़, ану_
  { {0x7afb267f,0x63a1002a,0x6ec2000b,0xf41f007c}},	//   _asut, ślne, _लिकु, smäe_
  { {0xa3d9005d,0x115b00f3,0x00bb000a,0x26c20030}},	//   ालय_, _ידיע, _במטמ, ákok_
  { {0x539b000f,0x2c7c001a,0x6a860138,0x0000006a}},	//   דינו, vídd_, алда,
  { {0xf38d004c,0x26c20091,0xf2d3000a,0x49d7005e}},	//   ׂראָ, škok_, קעו_, идію_
  { {0xf1b3000a,0x6fca000b,0x7a340144,0x6a6d0052}},	//   חסו_, िणपं, _càta, júfu
  { {0xa5d8005d,0xacfb000a,0x58860033,0xa823002b}},	//   _माहौ, _בהלכ, шыла, يکنن
  { {0xe7e2005d,0xd6260015,0xb7e2000b,0x17f70015}},	//   क्षा_, لعدي, क्षम_, شرية_
  { {0xf6e30033,0x79b8004f,0x7506116f,0x0000006a}},	//   іцын, _תֶּה, аџме,
  { {0x0d970008,0xcd970008,0xaa3b0008,0x37c60086}},	//   יכים_, ידית_, _שתבח, _نياف
  { {0x04590015,0x26cd0077,0x69d50061,0x62980085}},	//   الحة_, breo_, _özer, _čvor
  { {0x7ae22680,0x883b000a,0xeb91000a,0xc458004a}},	//   ntot, _בתאו, לָם_, риях_
  { {0xb7e2005d,0xe7f9005d,0x69d82681,0xf7490015}},	//   क्रम_, ्यथा_, ngve, _حجمه_
  { {0x661c0084,0xd2580036,0x38950024,0x7ae20e95}},	//   örku, рця_, _pāri_, htot
  { {0x351b0008,0xdb0000b8,0x5f450015,0xd6d9002a}},	//   _יוונ, _bemü, منزل, szłe_
  { {0x7ae200dc,0xe7f9005d,0x41e70484,0xdb002682}},	// [4910] jtot, ्यता_, _кіна, _memó
  { {0xf41f00f2,0x63bd2683,0x31351a56,0x02440015}},	//   ljä_, lasn, _геор, _وَيَ
  { {0x8d68000d,0x7ae20024,0x61f50064,0xdd98017f}},	//   ајца_, etot, mezl, ршу_
  { {0x511a0008,0x3ea90123,0x69d82684,0x9871006f}},	//   _עֵינ, ppat_, egve, _pšč_
  { {0xee870256,0x13c8000a,0xdb000012,0x6e320030}},	//   _выво, בּוֹ_, _gemü, ákbó
  { {0xf41f00f2,0x6ca72003,0x6d590012,0xe9d8005e}},	//   hjä_, _враж, ßwas, икі_
  { {0x7ae20796,0x261a000b,0xd90f002b,0xc27c000a}},	//   atot, बानी_, بیا_, דרגי
  { {0x26cd02c1,0x9b890031,0x8ccc000b,0xe7e2000b}},	//   treo_, _منزل_, _हितो, क्ला_
  { {0xfbd20008,0xf1c0002c,0x8645005e,0x7afb007c}},	//   _מתן_, žšiu_, йниж, _usut
  { {0x26cd0467,0x63bb0084,0xa2ce005d,0x7994004a}},	//   rreo_, ðunn, _तिब्, _дифф
  { {0xd54914f4,0xd6240015,0x89340015,0x63bd0034}},	//   упне_, تعيي, _وعما, fasn
  { {0xd7950029,0x080b0015,0x60d50085,0xf976000a}},	//   _الإخ, _جزئي_, duzm, _הגעש_
  { {0xf7850029,0xd348002b,0xb886001a,0xd763002b}},	//   _الشَ, شیده_, sníð, _بنشی
  { {0x63bd007c,0xb3830033,0xe29701e1,0xc448009a}},	//   aasn, ялял, сар_, _چیدن_
  { {0x65870010,0x32430036,0xfbd8000b,0x2c51002a}},	//   _тыдз, черг, _डालम, lądu_
  { {0xdb000251,0x7f1a008b,0x0000006a,0x0000006a}},	//   _memò, лізу_,   ,
  { {0xdd960015,0xd007024f,0xdb020061,0x0000006a}},	// [4920] مجاع, щете_, mboç,
  { {0x60c90024,0xf772000a,0xddde0535,0x0000006a}},	//   ņema, לקן_, wopł,
  { {0xfc460089,0xdd8f0015,0x0197000a,0x1da7000b}},	//   římo_, فوك_, _לכיש_, गड़त
  { {0x7ae2041d,0x7ff6002b,0xfcb5004a,0xd00f0015}},	//   ttot, _اسدا, ющую, _كلٍ_
  { {0xa3d9005d,0x853c0007,0x0eb90033,0x7f1900fd}},	//   ालत_, lbėt, _вусы_, _кіру_
  { {0xbea30191,0x2002000c,0x3e360086,0x7ae22685}},	//   _харк, _haki_, _افسر, rtot
  { {0x28cf014e,0xf41f00f2,0xa8a30010,0x20020509}},	//   संगि, yjä_, прык, _kaki_
  { {0x6d5700b2,0x2002005c,0xdd8f0029,0x7d57000a}},	//   _הילף_, _jaki_, _أوف_, _הילד_
  { {0x501b0008,0x63bd00dc,0xa6c70015,0xd5b00015}},	//   רופו, vasn, مويل_, وفة_
  { {0x20022686,0x26ca00bc,0x68350030,0x63a42687}},	//   _laki_, čbo_, _váda, _afin
  { {0xe8530074,0xb8960029,0x63bd00e8,0xf993000a}},	//   _کنند, _الصع, tasn, _זרע_
  { {0x4917013a,0x24800092,0xd6da0063,0xdbf20089}},	//   _לקבל_, _chim_, _бтк_, _oříz
  { {0xb8650029,0x63bd2688,0x0000006a,0x0000006a}},	//   _بالو, rasn,   ,
  { {0x7d03002e,0x9f4b0030,0x26db000a,0x63bd1d48}},	//   ænsk, ámít_, _עקומ, sasn
  { {0x61f50064,0x54a60029,0x63a40026,0x25dd005d}},	//   rezl, _احتف, _ffin, _खाती_
  { {0x85570008,0x6557000a,0xa075005e,0xdbf20046}},	//   _לשוב_, _לבוא_, ігач, _bříz
  { {0x200201e2,0x59c8005d,0x61f5002c,0x20070089}},	// [4930] _daki_, रणार, pezl, ěni_
  { {0x2007005c,0x877b015b,0x78530045,0x290c2689}},	//   śni_, ראמי, răvi, _orda_
  { {0x3cf5000b,0x2c51002a,0x44fa003d,0x6d480091}},	//   ीटें_, ządu_, _jū_, _ždar
  { {0xfbd004b6,0x69c8268a,0xa3d9000b,0x7188000a}},	//   فته_, _adde, ालि_, _לְרַ
  { {0xcb690054,0xbae70033,0x44fa003d,0x290c268b}},	//   јале_, сцей, _lū_, _arda_
  { {0x8cd6005d,0x9a880015,0x35d4000b,0x290c0085}},	//   मूहो, مَنْ_, _दाग़, _brda_
  { {0xa3d9005d,0xdbf20089,0x89d60015,0x6f090046}},	//   ाला_, _zříz, زوير_, _šech
  { {0x013801d8,0xd8250036,0x29070fde,0x69c80778}},	//   מרות_, ідпи, rvna_, _edde
  { {0xba55000d,0x35d4000b,0x644f0390,0xd6a8002b}},	//   _двај, _दाख़, dici, یدیم_
  { {0x0a6b009c,0x644f268c,0x7a570015,0x74e90054}},	//   _срби_, eici, _اضرا, адог_
  { {0x24800023,0xe5710029,0xd874002b,0x644f268d}},	//   _phim_, بطة_, _کالب, fici
  { {0x546a0080,0x644f19b0,0xd46a268e,0x8b99000a}},	//   рамм_, gici, риме_, יבֹת
  { {0xd3350010,0x67d4042b,0x38690085,0xe29a268f}},	//   пэры, _хочу, čard_, раг_
  { {0xa5092690,0xe611002b,0xdb02016e,0x248001f9}},	//   _века_, _زشت_, sboç, _whim_
  { {0x200200b6,0xf41f022d,0x7bc90003,0xc692000a}},	//   _paki_, mmän_, _odeu, _קאו_
  { {0x1611005d,0xdbf20089,0xf41f2691,0x3e74006f}},	//   ़ाकर_, _příz, lmän_, mäti_
  { {0x1ea90029,0x26c200bd,0x9f590251,0x5ea60015}},	// [4940] مالي_, škov_, _casà_, زمال
  { {0x6292002c,0x7bc909ae,0x2d15000b,0x66032692}},	//   úkoľ, _adeu, णमूल_, _jank
  { {0x82360086,0x66032693,0xa63a004c,0x20022694}},	//   _هرگا, _mank, סגער, _taki_
  { {0x717b013a,0xf41f00f2,0xf1a90086,0x66032695}},	//   _כניס, hmän_, _پایه_, _lank
  { {0xda662696,0x7bc90026,0x44220079,0xd8380085}},	//   овди, _ddeu, ijk_, _juče_
  { {0x683c0152,0x316d0011,0xc333000a,0xbe160015}},	//   _méde, şeze_, ווד_, _بوسع
  { {0x644f0064,0x2d9802c6,0x08f70015,0x2c7c00e1}},	//   yici, _igre_, قريب_, aída_
  { {0x66030161,0xad1b000a,0x2fc002f2,0x644f2697}},	//   _aank, _דולר, naig_, xici
  { {0x66032698,0xcaa50015,0x7c220123,0x853c0091}},	//   _bank, _فصلي, mjor, ybės
  { {0x644f005c,0x66032699,0x69c8269a,0x89160058}},	//   wici, _cank, _udde, _وبائ
  { {0x35b30010,0xfdf70008,0x6603269b,0x4c4a000a}},	//   ьбэр, חצית_, _dank, ֹתָ֑
  { {0xd6d9005c,0x7c22269c,0x644f221a,0x843400ce}},	//   szła_, njor, uici, днює
  { {0x67560087,0x683c0003,0xb8650021,0xf207005e}},	//   _بخار, _céde, _عامو, ояво
  { {0x7e04014e,0x644f269d,0xfc460046,0xe5f0008c}},	//   रयोग_, sici, řího_, äjää
  { {0xa1941c64,0xe4530015,0x59df000b,0x69c2000b}},	//   дарч, _يضع_, प्टर, _रजनी
  { {0x2d98003c,0x20c50024,0x60c90024,0xa1580036}},	//   _agre_, rķi_, ņemo, іату_
  { {0xc3b80008,0xdd9b05b1,0x765a269e,0x13b8000a}},	// [4950] _ולחץ_, аше_, onty, _והחל_
  { {0x44290023,0xbe180036,0x9f4b0077,0xddab1021}},	//   _hoa_, ожує_, _sacó_, ртал_
  { {0x2016032c,0x68ed005c,0x765a0ec8,0x25dd000b}},	//   ácií_, ładz, inty, _खासी_
  { {0x26c40007,0x5067005e,0x8ccc000b,0x2c7c006f}},	//   ksmo_, _єтна, _हिरो, tída_
  { {0xe47c0053,0xf41f00f2,0x7d0e0012,0x3b0902c8}},	//   בראכ, ymän_, _erbs, село_
  { {0xceb20b7b,0x4429269f,0xd358000a,0x683504b2}},	//   _איך_, _loa_, חידי_, _pádo
  { {0x38ca0086,0x26c4001c,0x88c50015,0x660326a0}},	//   مايی_, esmo_, ستغل, _rank
  { {0x59d7000b,0x9b450015,0xcb69002b,0x6d3a000a}},	//   _ठाकर, _فنزو, _همزه_, _הֲמו
  { {0x66030c58,0x36350015,0xe8480015,0x6a170015}},	//   _pank, كردس, تجون_, _وبطر
  { {0x644d26a1,0x645d0003,0x79c80015,0x7e9c004c}},	//   _amai, érin, _ووقف_, בסזו
  { {0x4429001c,0xe9380029,0xb6580033,0x660326a2}},	//   _boa_, _وسمت_, ўшых_, _vank
  { {0x7c2900dd,0x397a000a,0xe97a000a,0xaacf000b}},	//   _joer, _הטענ, _הנעש, _हटाक
  { {0x987a0008,0x44290509,0xd8740015,0xa3e2000b}},	//   _פרנק, _doa_, _غامب, न्ग_
  { {0x24960074,0x412a0080,0x683c00dc,0x7c3b0144}},	//   _کنيد_, бого_, _véde, _llur
  { {0x55ba0008,0xe6100086,0x2175000d,0x7c3b0064}},	//   _המצו, _جشن_, дутр, _olur
  { {0x644d26a3,0xe81e000b,0x442926a4,0x386d26a5}},	//   _gmai, भाया_, _goa_, noer_
  { {0x2fc008f6,0xf43b000a,0xe7e3000b,0xfd9a0015}},	// [4960] raig_, _לתקש, _गाना_, مئات_
  { {0x9f4b00dc,0x2fc00144,0x68ed002a,0x94b9004f}},	//   ámát_, saig_, łady, ֶמְת
  { {0x6e9303c4,0xc19b000a,0x0baa0015,0x7c3b055e}},	//   رلما, _לשיי, ماشى_, _blur
  { {0xd6d90050,0x83360053,0xaae60015,0x91dc000b}},	//   kuł_, ּאַס_, كستو, _बाँई
  { {0x765a26a6,0xca0a006b,0x68350030,0x7c2926a7}},	//   ynty, йндж_, _vádl, _doer
  { {0x7c3b0020,0x38a30064,0xd6d9002a,0x7c2226a8}},	//   _elur, _sıra_, duł_, sjor
  { {0x60c80125,0x8289000a,0xc213000a,0x7c3b15f5}},	//   ádmh, קְנֶ, תהו_, _flur
  { {0x8d5b013a,0xd6da0036,0x971416b0,0x386d01de}},	//   _הכלי, бто_, дмиц, goer_
  { {0xf6e30033,0xd6d9002a,0xafdb00cb,0xaac9000b}},	//   нцэн, guł_, _imøt, _रिएक
  { {0xba29003b,0xceb30008,0xa5340036,0xdce7005c}},	//   _وسلم_, עית_, дноч, _wyją
  { {0x4429003f,0xfe37000a,0x05780015,0x2611000b}},	//   _poa_, פרטי_, تمدة_, ताजी_
  { {0x897b00b2,0x889b0dab,0x7d7b0008,0xe7e3000b}},	//   _פראצ, _הבאי, מניו, _गाया_
  { {0x288b0074,0x613700dc,0x82a7004a,0xa3ac000b}},	//   _اصلی_, külö, яшне, गड़_
  { {0x26c200df,0xd3540015,0x30a706eb,0x5ef2000b}},	//   škos_, رَّة, зрав, ुबन्_
  { {0xfa770008,0x442926a9,0x61141006,0xd5cb000a}},	//   פעלת_, _toa_, ндру, _הֶחָ
  { {0x5577000a,0x04db000a,0xf55b000a,0x656f0012}},	//   _מעון_, _הקהל, _לדומ, ßche
  { {0xdef10029,0x539c000a,0xa6fa000a,0x7c2926aa}},	// [4970] ضًا_, _פיזו, מִ֑י, _roer
  { {0xb2bc0008,0xd3580008,0x1cd90010,0x9e150033}},	//   _המזר, _משחק_, жджы_, ьдзі
  { {0xfe7000e6,0x7a2f00cb,0x32540033,0xd6d9002a}},	//   ادق_, _møtt, _чвэр, zuł_
  { {0x98c40089,0x5b550015,0x317e0012,0x645d26ab}},	//   štěn_, وَاء, ütze_, nnsi
  { {0xa3e2014e,0x386d1786,0x25dd021e,0x7c29016b}},	//   न्ट_, voer_, _खाली_, _voer
  { {0x645d0012,0x20090091,0x6d58006f,0x7a2f00cb}},	//   hnsi, ldai_, úvac, _nøtt
  { {0xbca50074,0xe8f90036,0x2ee9002e,0x9f40002e}},	//   _آمري, іли_, ltaf_, leið_
  { {0x77f9014e,0xd6d9005c,0x645d16c3,0x200926ac}},	//   ्येक_, tuł_, éril, ndai_
  { {0x2ee90176,0xfaf00070,0xd7060080,0xdb2300f2}},	//   ntaf_, _مثل_, дные_, äräl
  { {0xd6d9005c,0x8b080046,0x20090034,0xacf8002a}},	//   szło_, střá, hdai_, żółt
  { {0xb9250029,0x69c326ad,0x22840030,0x645d001a}},	//   _تفضي, mane, nöke_, fnsi
  { {0x628500dc,0x9f40001a,0x69c326ae,0x61370030}},	//   _ahho, keið_, lane, zülö
  { {0x20090176,0x69c30045,0x7a2f00cb,0xa01b0028}},	//   ddai_, oane, _føtt, _phön
  { {0xd2950036,0x27ed26af,0x20091221,0x6f0d0046}},	//   ерсь, lfen_, edai_, dvac
  { {0xafe60191,0x261a005d,0xd00a006b,0x629726b0}},	//   мовл, बारी_, оеве_, _dixo
  { {0x2fda0015,0x69c326b1,0xdb0b1945,0xe5040015}},	//   تورد_, hane, nagó, _أبوي
  { {0x27ed00b8,0xd1380007,0xf4130008,0x25a00061}},	// [4980] ifen_, šą_, _יפה_, _şili_
  { {0x568a0053,0x683c0152,0x201926b2,0x7c2d0123}},	//   ַטײַ, _méda, _ensi_, öarn
  { {0x11150010,0x61fc08c0,0x621b00f3,0x7e290015}},	//   _зьяў, merl, _וויק, أسقف_
  { {0x61fc26b3,0xa3e2000b,0x4fb60015,0xeb9a1764}},	//   lerl, न्च_, _تصدر, цид_
  { {0xaa460080,0xdb00002c,0xfaa30784,0xf236000a}},	//   медл, _nemô, вачо, ֽרֶץ_
  { {0x6df60015,0x6e960015,0x8b65002b,0x69c326b4}},	//   _تكسا, _زلزا, رانم, gane
  { {0x26f8005d,0x99850089,0x27ed26b5,0x7a2f00cb}},	//   ्ट्र_, _dolů_, ffen_, _røtt
  { {0x27ed0026,0x683e0024,0x0c3a0015,0x7792002b}},	//   gfen_, lūdz, _بكرة_, پیتا
  { {0x61fc26b6,0x683c0003,0x645d0003,0x69c326b7}},	//   kerl, _céda, érim, bane
  { {0x3869016f,0xb9c60086,0x645d0335,0x200924b0}},	//   čara_, _آقاي, wnsi, zdai_
  { {0xadd7000a,0x7a8b000a,0x7bc026b8,0x454a0c31}},	//   וויח_, _וָאַ, _kemu, ючим_
  { {0xb8650029,0x25b10064,0x6f0d26b9,0xf8b3015b}},	//   _كانو, ızla_, yvac, _ישע_
  { {0xc2b80036,0x28130029,0x7bc0013c,0xb8d3000b}},	//   мляє_, _جونس, _memu, ड़ी_
  { {0x877b000a,0x764115ab,0x61fc26ba,0x7bc026bb}},	//   _ואדי, chly, gerl, _lemu
  { {0xe5f70008,0xa2940036,0xa3e7005d,0x41740015}},	//   _חזור_, тарі, _पाप_, نافس
  { {0x60180036,0x7f950010,0x7bc0053e,0x69c326bc}},	//   мося_, еабх, _nemu, zane
  { {0x61fc26bd,0xe2ab0015,0x60dc003d,0x200926be}},	// [4990] berl, _بابن_, aurm, rdai_
  { {0xab5d0050,0x61fc02c1,0x443926bf,0x2ddb0015}},	//   _jeże, cerl, lks_, تبرة_
  { {0xbc190010,0x7bc000dc,0x443926c0,0x69c326c1}},	//   зілі_, _bemu, oks_, vane
  { {0x70550029,0x69c326c2,0x44390b9d,0x6d452059}},	//   _أنحا, wane, nks_, rzha
  { {0xfb350010,0x6d4500dc,0x443926c3,0x7fd6015b}},	//   эндэ, szha, iks_, _אורס_
  { {0xdeba0008,0xa2d7005d,0xd3380008,0x683c0152}},	//   _ממשל, _बिन्, ורדה_, _réda
  { {0x27ed0482,0xdb0b002f,0x3e7400c0,0x4439002e}},	//   tfen_, tagó, rätt_, kks_
  { {0xb907005d,0x44390111,0x3e7400c0,0x27ed00b8}},	//   _बम_, jks_, sätt_, ufen_
  { {0x27ed04de,0x69c326c4,0xf7080016,0x64980045}},	//   rfen_, pane, _củ_, _bţin
  { {0xe5250457,0x60dc0061,0x7bc026c5,0x5d99000a}},	//   едоп, yurm, _zemu, ּבֹה
  { {0xc8c90086,0x27ed00b8,0xa01b0012,0x68350247}},	//   _روشن_, pfen_, _diöz, _ládi
  { {0x61e50026,0x290526c6,0x78f80015,0x60dc0061}},	//   _achl, _isla_, _تعكس_, vurm
  { {0xfbd20008,0x61fc2084,0x76410034,0x69c126c7}},	//   נתך_, terl, phly, _kele
  { {0x69c103c0,0x9756013a,0x3ae90092,0xc756000a}},	//   _jele, _אינו_, iúp_, _אינץ_
  { {0x463a0053,0x69c126c8,0xae03000b,0x64560030}},	//   _מעסע, _mele, रजनन_, ézis
  { {0x2ff80086,0x44390abe,0x0eaa0033,0x7d02002a}},	//   بورگ_, cks_, зкай_, łosk
  { {0x2e36002e,0xdfcf00e5,0x61fc26c9,0x1e8626ca}},	// [49a0] _hæfi_, صيل_, perl, елам
  { {0x7bc00d25,0x9f400159,0x2d9c079b,0x69c126cb}},	//   _semu, lgië_, øve_, _nele
  { {0x163600b2,0x71bb0008,0x7bc008c0,0x41bb000f}},	//   ענער_, _מציג, _pemu, _מציע
  { {0xcdc9000a,0x433a000a,0x69c126cc,0x8ac601b7}},	//   מך_, ּעַב, _aele, ейдж
  { {0x29050064,0xa3de000b,0x4dd6005e,0x628e26cd}},	//   _asla_, _ढाई_, _півф, ombo
  { {0x5eeb0008,0x3e740012,0xfce60442,0xf7080016}},	//   _מַלְ, räts_, _пого, _rủ_
  { {0xf1b3039e,0x7bc0013c,0x9e77000a,0x443926ce}},	//   נסה_, _temu, _נגלה_, yks_
  { {0x17fa0015,0xc7c6004a,0x5718024f,0x6671002b}},	//   سرعة_, хски, джия_, یگور
  { {0x69c126cf,0x8c430080,0xc6f704ab,0xa3bf000b}},	//   _fele, _сете, еных_, इरस_
  { {0x60c90024,0x6e2e1b0c,0x443926d0,0xceb3000a}},	//   ņemi, _jobb, wks_, איז_
  { {0xdb0b001a,0x3ea226d1,0x78a101de,0x5c8a004f}},	//   lagð, _lukt_, _gulv, ּרָ֣
  { {0x61e5018b,0xf7080016,0x46a624cc,0x493b000a}},	//   _schl, _tủ_, _задв, _מגבו
  { {0xa3e7014e,0x443926d2,0x27e60116,0xd37b01f3}},	//   _पाठ_, rks_, _icon_, ячо_
  { {0x171b01c8,0x96060029,0xf2040010,0x471b000a}},	//   _מודע, _سبتم, лясо, _מודג
  { {0x3168012e,0x54e60058,0x0000006a,0x0000006a}},	//   ешто_, _أستق,   ,
  { {0xaf340074,0x4ea7087a,0x757b000a,0x628e26d3}},	//   گرفت, ержа, _מטופ, ambo
  { {0x63ad0cf9,0x63bb002e,0x660a26d4,0x6e2e0d3a}},	// [49b0] _ifan, ðunu, _kafk, _bobb
  { {0xa3d9005d,0x6e2e082f,0xa29501f3,0x929525d6}},	//   ालक_, _cobb, _шапі, _шапц
  { {0xf65300b2,0xad670029,0x6e2e26d5,0xa195012e}},	//   נצע_, رائه, _dobb, _јанч
  { {0x44ea04ed,0xe571000a,0x3ae9006f,0x69c126d6}},	//   iù_, בַד_, túp_, _sele
  { {0x63ad000c,0x09e505b3,0x6e950015,0x44ea0016}},	//   _mfan, волн, _للحا, hù_
  { {0x533800b2,0xff56000a,0x78a126d7,0x660a07c8}},	//   ענגן_, _יברך_, _pulv, _nafk
  { {0x02180008,0x63ad26d8,0xecf8022a,0xed580015}},	//   תחום_, _ofan, _перш_, _كشفت_
  { {0x683c0003,0xfbb7002b,0x69c126d9,0x109c004f}},	//   _dédo, _سحرخ, _wele, הבהב
  { {0xdcfc0024,0xfae00046,0xdb00081d,0x38a30061}},	//   _izrā, íště_, _afmæ, _kırk_
  { {0x69c1003f,0x63ad26da,0x0b88005e,0x99850045}},	//   _uele, _afan, _їсти_, _colţ_
  { {0x0446005f,0xd46a0124,0x9f49002d,0x55890c39}},	//   венн, дине_, dfaí_, ьбом_
  { {0x200b0085,0x387a002b,0x248926db,0x0000006a}},	//   _naci_, _قشنگ_, _cham_,
  { {0x6605119f,0x1de2000b,0xd36f0015,0x4463006b}},	//   _апла, _पालत, ْهُ_, рвяв
  { {0x2d9c032c,0x7a3d08e0,0x7d02005c,0xf6790053}},	//   ľvek_, _mèto, łosi, _קאַמ
  { {0x63ad0026,0xe297122d,0x20d5005e,0x90c3004a}},	//   _ffan, тар_, літс, ибре
  { {0xdfd20029,0x200b26dc,0x6e2e26dd,0x63890073}},	//   شيط_, _caci_, _sobb, _sūnū
  { {0xaf06006b,0x8f760033,0x6da61c4d,0xa3e70065}},	// [49c0] ъпал, туві, виза, _पात_
  { {0x6d960015,0x4f95005e,0x0000006a,0x0000006a}},	//   نشائ, урсу,   ,
  { {0x200b107d,0x515a0033,0x2d9626de,0x61460b27}},	//   _faci_, _ішоў_, трас, _рена
  { {0x69c5002e,0x7f860015,0x6e2e1abc,0x0000006a}},	//   ðhen, _للجن, _wobb,
  { {0x7c650031,0xea8a002b,0x63a90091,0x20000045}},	//   دالل, وختن_, ženg, meii_
  { {0x9cb60029,0xda660029,0xd91a004a,0x683c0003}},	//   _لمست, خاصي, дьи_, _pédo
  { {0x98c3008f,0x63a1005c,0xe81e000b,0x6cd9005e}},	//   асыл, ślni, भाला_, _пфтс_
  { {0x8d4b000a,0xfc1a0058,0x200000d4,0x0000006a}},	//   _חֲמֵ, _تقرب_, neii_,
  { {0xc0530008,0x6d670011,0x807b00f3,0xa6c70021}},	//   יזה_, ăraţ, ונקצ, نويل_
  { {0x14ca0080,0x75d40115,0x35b40256,0xf6f5002b}},	//   мыми_, ديدا, ыбор, ازيگ
  { {0xde150053,0x7bcd002e,0xd5b80024,0x4ddb000a}},	//   אַרץ_, ðaug, rbā_, וחיו
  { {0x2ee000dd,0x5fe1000b,0x1957000a,0x97a3011e}},	//   kuif_, _फाइल, _בבבל_, _кршл
  { {0xf7d7000a,0x8646006b,0xa30d000b,0x200000d4}},	//   _יואש_, _индж, िटेज_, deii_
  { {0x7df30089,0x0737000a,0x96f7005e,0x6f0426df}},	//   _měsí, _באדם_, _решт_, dwic
  { {0x24890023,0x6f0426e0,0xdfd50256,0xb5c7002b}},	//   _tham_, ewic, ловы, _شويم_
  { {0x44ce0050,0x63ad26e1,0xc1dc000b,0xab5d002a}},	//   mę_, _ufan, बलॉग, _leża
  { {0x228400c0,0x0f150010,0x44ce0c85,0x5f740015}},	// [49d0] söka_, ымаю, lę_, لاكر
  { {0xf1b7005d,0x9f040029,0x7a3d0144,0x4dd40058}},	//   _अभिन, ؤولو, _rèto, لتمس
  { {0x44ce0b54,0x72340029,0x3cd503fc,0x21640248}},	//   nę_, _خريط, ужес, _втяг
  { {0x44ce0050,0xfbd00029,0x29190046,0x1c1d000b}},	//   ię_, قته_, _čsa_, फाइल_
  { {0x9aa40058,0x2d0c0065,0xf092004f,0x38a3007f}},	//   لمنو, सटॉल_, _לנט_, _zırh_
  { {0x44ce1501,0x2fc90159,0x29c90015,0x6d41007c}},	//   kę_, laag_, رِبَ_, _ülao
  { {0x27ff020a,0xe8f50029,0x44ce20b0,0xdcf60045}},	//   teun_, استخ, ję_, ăcăn
  { {0xdcfc0024,0xd70926e2,0x44ce20b0,0x22580012}},	//   _uzrā, ение_, dę_, zirk_
  { {0xab94005e,0x27ff0045,0xe5a50979,0xb8040058}},	//   _виті, reun_, липи, شبيه
  { {0x9a870c1d,0xe7080015,0x9cd5000a,0x98a7002a}},	//   _рубл, ئتين_, ְוָה_, zynę_
  { {0x2258002e,0x44ce1501,0x6a9a000a,0x6f040b65}},	//   virk_, gę_, _נשענ, zwic
  { {0xc209013a,0xb8090029,0x2e36001a,0x6f040542}},	//   _מה_, _سيتم_, _hæft_, ywic
  { {0xe3550010,0x387f001a,0x2fc905a0,0x87240058}},	//   атрэ, mlur_, daag_, _نعوم
  { {0x387f002e,0x86440010,0x44ce005c,0x26cb006f}},	//   llur_, _кніж, bę_, ácou_
  { {0xc5f20008,0x44ce005c,0x213e002d,0xf219005d}},	//   _הדו_, cę_, áth_, दाज़_
  { {0x6f04018b,0x04950010,0xf8b2000f,0xc952000a}},	//   twic, _крыў, משל_, צמן_
  { {0x26cd002d,0x4420013c,0x644402f2,0x20000045}},	// [49e0] nseo_, _ini_, _ilii, reii_
  { {0x443202c1,0x69c5002e,0x539b000a,0x639b000a}},	//   _hoy_, ðhel, _איפו, _אספנ
  { {0x6d410020,0x6601005c,0x3f86002c,0x63a903cd}},	//   _ülal, ielk, ťou_, žene
  { {0xf76704b6,0x0b460404,0x443226e3,0x50db0053}},	//   _ها_, лнен, _joy_, _אקטא
  { {0x60c90048,0xa09b00b2,0xa3e7005d,0xf41f00f2}},	//   ņemt, _ריכט, _पास_, mmät_
  { {0xf41f00f2,0x387f002e,0xa2d7000b,0xe2a7001a}},	//   lmät_, elur_, _बिस्, ýðir_
  { {0x660126e4,0x442026e5,0x4e7b000a,0x387f001a}},	//   delk, _oni_, _נאלצ, flur_
  { {0x387f0084,0xc6f82105,0x44ce0091,0x44200034}},	//   glur_, вних_, vę_, _nni_
  { {0x44ce005c,0xab6602c8,0x8b660015,0xcb6707be}},	//   wę_, _свал, _صارم, _бате_
  { {0x26f706e4,0xf41f00f2,0x7ae21168,0x44ce10da}},	//   اريخ_, hmät_, muot, tę_
  { {0x9e770008,0x442026e6,0x443226e7,0xf98a0015}},	//   רגיה_, _bni_, _boy_, _أخذه_
  { {0xc94b0008,0x2b9a0064,0x44ce1501,0x439503fc}},	//   _אֲדֹ, _gücü_, rę_, ианс
  { {0x7ae20007,0x44ce0c85,0x442026e8,0x98a70046}},	//   nuot, sę_, _dni_, kyně_
  { {0xe298008f,0x44ce0b54,0x442026e9,0x644405ff}},	//   лаў_, pę_, _eni_, _elii
  { {0x765a26ea,0xa5d7002b,0x629e26eb,0x443226ec}},	//   mity, _صبور_, _dipo, _foy_
  { {0x7ae200df,0xe4d30086,0x765a23c1,0xe58b000a}},	//   kuot, _اتوب, lity, _אָחָ
  { {0xcddb03f1,0x7ae20007,0xf3f00029,0x2fc90150}},	// [49f0] ење_, juot, _رأي_, raag_
  { {0x59e0005d,0x70550086,0x7ae20007,0x68350089}},	//   _नागर, _چندا, duot, _jádr
  { {0x683c0030,0x443201d7,0x2d8702d6,0xc27c004f}},	//   _védj, _yoy_, åne_, _ארזי
  { {0x60c90048,0x6601005c,0x765a00f2,0xf42a00f2}},	//   ņems, zelk, hity, mpää_
  { {0x34c1014e,0x7ae200df,0x998c0089,0x765a1547}},	//   _शब्द, guot, _bodů_, kity
  { {0x50b80074,0x08d5250c,0xe9d60010,0x68350107}},	//   _جدید_, ация, акш_, _nádr
  { {0x38ca0086,0xda6e0029,0x3238000a,0xd825005e}},	//   نايی_, بُو_, רטון_, идки
  { {0x60c80008,0x2bbb0015,0x7ae20091,0x3158000a}},	//   נּוּ_, _سارة_, buot, טיון_
  { {0x7afb016f,0xeab000e6,0x7d02002a,0x442000bc}},	//   _uput, _فعل_, łost, _rni_
  { {0x387f0084,0xe6160080,0x443226ed,0xa2a0000b}},	//   slur_, адь_, _soy_, _गूग्
  { {0xdb020084,0xc3290008,0xf41f00f2,0x629e26ee}},	//   lboð, _קו_, ymät_, _ripo
  { {0xd7560074,0x2aab0134,0xfae70029,0x7bcb26ef}},	//   الیت_, _køb_, يث_, nagu
  { {0xa3e7005d,0x68e326f0,0x443226f1,0x58040015}},	//   _पार_, lund, _voy_, _دونك
  { {0x7bcb000c,0xf6b20029,0x6383022a,0x85050015}},	//   hagu, _بموج, ігра, _نوتن
  { {0x7ae200df,0x645d0251,0x442000e8,0x42550036}},	//   zuot, èric, _tni_, стят
  { {0x7bcb000c,0x645d1a87,0x0163005e,0x442026f2}},	//   jagu, érit, ікто, _uni_
  { {0x7bcb26f3,0xd47b0135,0xdfcf00e6,0x63a40035}},	// [4a00] dagu, _שאפל, بيق_, _igin
  { {0x7ae21203,0x7e230001,0x68e326f4,0x42530015}},	//   vuot, одуж, kund, _ونير
  { {0x68e30020,0x8c960036,0x11db000a,0x61db000a}},	//   jund, арді, _בחיב, _בקיד
  { {0xf09f26f5,0x7ae21203,0xdee605aa,0x6faa000b}},	//   _già_, tuot, _коми, _कलिं
  { {0x6b89005c,0x7fd7000a,0xec270015,0xd89d0033}},	//   _czeg, _דוכס_, شكوى_, _эфiр_
  { {0x7ae200df,0xc5f80024,0xaa530484,0x99f6005e}},	//   ruot, tnēm_, овіш, ряді
  { {0x765a022d,0xa8a30010,0x7ae20007,0xda650087}},	//   vity, орык, suot, حاني
  { {0xa2d7005d,0x7ae20007,0xd7fa085d,0xd8b70015}},	//   _बिल्, puot, тук_, جدوا_
  { {0xe7860127,0x765a0ac8,0x6835002d,0x09e626f6}},	//   шуко, tity, _pádr, _возн
  { {0xee31000a,0x7e620003,0x683c26f7,0x68e326f8}},	//   ִֽי_, éoph, _médi, bund
  { {0x24420467,0x765a26f9,0x3d04005d,0x48060036}},	//   _cómo_, rity, _रनों_, _впев
  { {0x765a022d,0x69c826fa,0xf8a9002b,0xa93b000a}},	//   sity, _hede, _صدمه_, _שתאפ
  { {0x5c970053,0x69c8013c,0xc7f7000a,0x59ba000b}},	//   יכטע_, _kede, _כזאת_, _उभार
  { {0x2245002e,0x66730021,0x69c826fb,0x63a426fc}},	//   ólk_, _ودور, _jede, _egin
  { {0x645d0152,0xa2a7000b,0x7bcb00ac,0xd8380085}},	//   éris, _टूर्, yagu, _auči_
  { {0x759b0008,0x859b000a,0x3911004c,0x659b0643}},	//   _בסוג, _בשוו, נטאַר, _ביוק
  { {0xfda70054,0x9df9067a,0x645d26fd,0x78a826fe}},	// [4a10] ајем, лнат_, misi, _ludv
  { {0x74bd014e,0x3869016f,0x63a4005c,0xd2510086}},	//   वीकृ, čari_, _zgin, _رنج_
  { {0x7bcb26ff,0x6b892700,0x9ccb0033,0x27f10030}},	//   tagu, _szeg, тыза_, őzni_
  { {0x68e32701,0xf412000a,0x7055002b,0x645d2702}},	//   vund, ּ֤א_, _چنگا, nisi
  { {0x68e300b8,0xf1db000b,0x69c82703,0x645d014b}},	//   wund, _बयान, _bede, iisi
  { {0x7bcb0035,0x645d1437,0x539c000a,0x68e32704}},	//   sagu, hisi, דידו, tund
  { {0x99150010,0x09f60015,0xda6201c5,0x645d2705}},	//   сьлі, صفية_, явши, kisi
  { {0xccf20008,0xb8ff005d,0x645d0064,0xc0520008}},	//   _מכל_, _ति_, jisi, ּ֖ה_
  { {0xe7f8000b,0xa2a7000b,0x86990004,0x68e32706}},	//   ्ज़ा_, _टूल्, лтот_, sund
  { {0x69c82707,0x8cd9000a,0x68e32708,0x645d2709}},	//   _gede, ְחָת, pund, eisi
  { {0x39150086,0xda7a0053,0x645d270a,0x5dfa004f}},	//   _دواز, _ענער, fisi, אפתנ
  { {0x6aa1018b,0xf1a9000a,0x98140021,0x6ca8000a}},	//   _hilf, _טס_, _وبنا, יֹשְ
  { {0xd874003b,0xe8740029,0x8c1a0008,0x69c80064}},	//   _بالب, _بالظ, אורי, _yede
  { {0xe5a5010f,0x683c0152,0x4b7a000f,0xdb02016e}},	//   _уики, _rédi, ראשו, scoç
  { {0x645d166f,0x64b50031,0x60860015,0x683c0003}},	//   bisi, _احتر, مشرك, _sédi
  { {0x6f16006f,0x645d270b,0x683c0003,0x63a4270c}},	//   tvyc, cisi, _pédi, _ugin
  { {0xef1a0010,0x9eea0015,0x44f1270d,0x7641270e}},	// [4a20] ыма_, طفال_, lá_, okly
  { {0x2d96004a,0x44f10016,0xee37270f,0xaaab000b}},	//   брес, oá_, бну_, _चढ़क
  { {0xcea90008,0x44f12710,0xfca90015,0x69c82711}},	//   תי_, ná_, لانو_, _rede
  { {0x44f10092,0xe588000a,0x0bf4005e,0x9f590077}},	//   iá_, בָנָ, іплю, _casó_
  { {0x7ff70086,0xb47b0053,0xda34004a,0x69c82712}},	//   _اسپا, אָגי, желы, _pede
  { {0x645d2062,0xe9800033,0x29180030,0x6e350085}},	//   zisi, малi_, _árak_, _gozb
  { {0x44f1002e,0xa3d8005d,0x61ea002e,0x69c82713}},	//   já_, ाणा_, _öflu, _vede
  { {0xdd8f0115,0x768f00cb,0x44f12714,0x79810034}},	//   _سوق_, høyd, dá_, _dylw
  { {0x1f5b0053,0x2ee00026,0x17f70029,0x69c82715}},	//   ָדיא, nrif_, صرية_, _tede
  { {0x645d0176,0xb9930086,0x7bc92716,0x8f37000a}},	//   wisi, _کلمب, _zeeu, צאיו_
  { {0x9986003b,0xd7fa097d,0x44f1016e,0xe5340033}},	//   _الاو, _бул_, gá_, цень
  { {0x3d00005d,0x66e62717,0x7cdc0045,0x2ee02718}},	//   _रहने_, _года, mără, krif_
  { {0xd796003b,0x073a04c9,0x645d2719,0xde6d0092}},	//   _الشخ, _حساب_, ériq, hươn
  { {0x2fc00012,0x645d271a,0x44f1271b,0x7afd02ad}},	//   ebig_, sisi, bá_, _äste
  { {0x365b013a,0xd258017f,0xd8d8000a,0x44f109ae}},	//   _תכונ, сця_, יַּך, cá_
  { {0x2ee00176,0xdbf10089,0x8c3d0011,0xa5650086}},	//   frif_, _přík, _mişc, _بدهن
  { {0xbda70029,0x2ee00026,0xc43c000a,0x4034004a}},	// [4a30] محاو, grif_, _תתחי, четс
  { {0xdd04000b,0xe45f008c,0x50b9002b,0xd25100c3}},	//   रबंध_, liö_, _نگرد_, _آند_
  { {0x11f80086,0x9f5902c1,0x4375002b,0x64b30045}},	//   _اوپک_, _pasó_, _دهکر, _tăie
  { {0x515a000a,0xe58b000a,0x91a60016,0xa01b0123}},	//   _ככתו, אָדָ, _đỏ_, _ehör
  { {0x79810176,0xa3e7005d,0xab2906a6,0x44f116ee}},	//   _sylw, _पाई_, рола_, zá_
  { {0x6ca7250c,0x69e70033,0x0f7a000a,0x656f0045}},	//   _граж, сюдз, _כארב, şchi
  { {0xaa560015,0x44f1016e,0x627c004c,0xb905005e}},	//   تلوا_, xá_, אנגנ, ізик
  { {0xeaf80074,0x44f104af,0xe8f60010,0x5d540256}},	//   _گرفت_, vá_, ілы_, _экст
  { {0x6aa1271c,0xb8d0000b,0x79810034,0x501c000a}},	//   _tilf, _टू_, _wylw, רוחו
  { {0x8f9c0053,0x9599226a,0x8b88000a,0x44f1271d}},	//   ניזי, итну_, _הָעֶ, tá_
  { {0x44f10092,0xdddc003d,0xe3c60058,0xad2700ce}},	//   uá_, _skrū, يْدَ, ивiс
  { {0x78a2271e,0xd456005e,0x6f1d0f3f,0xc95205bd}},	//   _giov, ітнь, _orsc, _קמא_
  { {0x6842008f,0xd629271f,0x44f12720,0xdc88004f}},	//   _інша, _воле_, sá_, מְשָ
  { {0x15ab006b,0x683c0003,0x10a6005e,0x38690085}},	//   _съди_, _dédu, живн, čaru_
  { {0xc05a0054,0x22840030,0xc692000a,0x683c0030}},	//   арац_, nöki_, _חאג_, _védv
  { {0x44d50048,0xa3e7005d,0xe3b20225,0x70860033}},	//   mā_, _पाए_, _غرب_, ігаз
  { {0x44d50024,0x44c700dc,0xceea0010,0x1f660010}},	// [4a40] lā_, lő_, рдзе_, цкам
  { {0x3eab00da,0x225700c3,0x9f400144,0x7bcd0052}},	//   _duct_, _وليد_, rgià_, ðaun
  { {0x44d50048,0x6f1d018b,0xde170015,0x9e650015}},	//   nā_, _ersc, تقلت_, ساكن
  { {0x984c0089,0xb4fa0053,0x29180030,0xde6d0016}},	//   věď_, ילער, _árai_, rươn
  { {0xb60500bd,0x3f820061,0x0000006a,0x0000006a}},	//   _kršč, _uyku_,   ,
  { {0x44d50048,0x5b13008f,0x4df50033,0x7cdc0045}},	//   kā_, ьміт, _няст, tără
  { {0x44d50048,0xbea30010,0x63b60026,0x78a202b9}},	//   jā_, _царк, _ofyn, _piov
  { {0x44d50048,0x44c700dc,0x47340180,0xdb200045}},	//   dā_, dő_, знис, ătân
  { {0xf0932721,0x7bc22722,0x466a1dd4,0xb60615df}},	//   ונה_, mbou, иром_, оянк
  { {0x683c0152,0x7cdc0011,0x7bc22723,0xf992009a}},	//   _rédu, pără, lbou, _قبا_
  { {0xf76f0086,0x44d50024,0xe45f00f2,0x683c0003}},	//   فای_, gā_, tiö_, _sédu
  { {0xd817005e,0x14190015,0x45470033,0x7ae22724}},	//   _моєї_, حيحة_, ючым_, orot
  { {0xfbd3013a,0xe60f0086,0xdc9b004c,0x63a9128d}},	//   ותר_, رشی_, ייטל, ženo
  { {0x768f003c,0x24800064,0xa3e7005d,0x46140087}},	//   tøye, _ekim_, _पाक_, _روبر
  { {0xa2d7005d,0x63b60026,0xf1bf000b,0x3cf6000b}},	//   _बिक्, _ffyn, ्रबन, ीबों_
  { {0x1eab0029,0x7ae22725,0xcd2b002b,0xa3a70015}},	//   لائي_, krot, یسان_, _بحثن
  { {0x3e890029,0xddab0254,0x6440008c,0x8c3d0061}},	// [4a50] مَرَ_, ател_, ömie, _nişa
  { {0x9e15008f,0x291e0064,0x3255017f,0xb60500bc}},	//   ядзі, _orta_, _хвор, _gršč
  { {0x6287016f,0x7ae22249,0x7d790015,0x3bb902a3}},	//   mljo, erot, حمار_, булю_
  { {0xd251002b,0x7bc20079,0x0196004f,0x69da03a0}},	//   _آنگ_, gbou, _מכתש_, _adte
  { {0x44c70014,0x44d5003d,0x291e2726,0x62870085}},	//   ző_, zā_, _arta_, oljo
  { {0x7f3a0008,0x4f3a000a,0x8f9a000a,0x3ea30079}},	//   _העשו, _התשע, _לירי, _uijt_
  { {0xa3eb005d,0x9f40002e,0x291e0085,0xac190432}},	//   मला_, lfið_, _crta_, _лову_
  { {0x3d00005d,0x44c700dc,0x7ae22727,0x44d5003d}},	//   _रहते_, vő_, brot, vā_
  { {0x78ba003c,0xbae40015,0x6f0d02f7,0x24920034}},	//   _ettv, _يكفي, nwac, _rhym_
  { {0x44c70014,0x44d50048,0xe3b20086,0x248000d9}},	//   tő_, tā_, کرد_, _skim_
  { {0x6f0d00b8,0x69c300bd,0x64b30045,0xa5090818}},	//   hwac, mbne, _băia, щена_
  { {0x44d50048,0x78fa0008,0x764a0034,0x44c70030}},	//   rā_, _לפעו, _elfy, rő_
  { {0x44d50024,0xd6d9005c,0x934303ad,0x38b1001a}},	//   sā_, była_, еняе, _hár_
  { {0x76ba0008,0x44d50024,0x471a0135,0x201e0045}},	//   _המספ, pā_, _לונג, _şti_
  { {0x38b10030,0xdb0c001a,0x27ed2728,0x6f0d0b65}},	//   _jár_, _áhöl, ogen_, ewac
  { {0x38b11718,0x2167000d,0x644f005c,0x6287008c}},	//   _már_, чиси_, chci, aljo
  { {0x38b1002f,0x2bcf005d,0x27ed0596,0x6fce000b}},	// [4a60] _lár_, _हज़ा, igen_, ़रबं
  { {0x644600f2,0x3d18000b,0xee3709c2,0xf8ab0016}},	//   lkki, फिले_, пну_, _ưới_
  { {0x38b1002f,0x7ae2005c,0x823b0008,0x6f0d003f}},	//   _nár_, wrot, _העיצ, awac
  { {0x6446022d,0x27ed0111,0xd6d9005c,0xb7ea000b}},	//   nkki, jgen_, zyła_, _टाइम_
  { {0x7bc220ea,0x64462729,0x83b7000a,0x68e30b2d}},	//   rbou, ikki, הִוא_, ernd
  { {0x82d70053,0x61ee00dd,0x38b11754,0x27ed0596}},	//   לונג_, ngbl, _bár_, egen_
  { {0x7e7e00cb,0x7bc20079,0x999a002a,0x38b10030}},	//   mopp, pbou, _żyły_, _cár_
  { {0x38b1002d,0x98a30001,0x7e7e272a,0x18a301ca}},	//   _dár_, није, lopp, најм
  { {0xf7720015,0xf093000a,0xab5d002a,0x69c30030}},	//   عاع_, ענח_, _odży, bbne
  { {0x0f570008,0x7e7e272b,0xcf57000a,0xf4d80004}},	//   פיים_, nopp, פבית_, омош_
  { {0x66081927,0x6f0d002a,0xab5d002a,0x320a272c}},	//   redk, zwac, _reżi, deby_
  { {0x6f0d002a,0xb935004c,0xd6d9002a,0x9f40001a}},	//   ywac, _קרײג_, syła_, yfið_
  { {0x7e7e0282,0xa857004f,0x22b8005a,0xafdb064c}},	//   kopp, _צידה_, věký_, _kløv
  { {0x56b700f3,0x2284001a,0x644f0034,0x6446272d}},	//   _צפון_, köku_, shci, akki
  { {0xc5fb0008,0xd5fb0008,0x50250015,0x64b30045}},	//   _הפוט, _הפור, وفسك, _tăia
  { {0xd4680124,0x11f70086,0x3034004a,0x6f0d0d24}},	//   _није_, _کودک_, несё, twac
  { {0x44292416,0x7a3d028f,0xf414000a,0xc058005e}},	// [4a70] _ina_, _mètr, _נפץ_, чір_
  { {0x9f40002e,0x3f870024,0xa3eb000b,0x42550067}},	//   rfið_, ānu_, मलव_, _آندر
  { {0x644d1a37,0x6abb0334,0x27ed2693,0x317e0012}},	//   _klai, _stuf, ygen_, ützt_
  { {0x26d90014,0x60d60008,0x44290085,0xdc56009a}},	//   ások_, _קורא_, _jna_, ورنک
  { {0xe46a00f2,0xc9a9004a,0xf41f008c,0xfaa7004a}},	//   ltöä_, овле_, ylän_, чшен
  { {0x644d0026,0xf2d40053,0x41bf000b,0x7e7e02b9}},	//   _llai, געס_, ्रिस, copp
  { {0x64460084,0xa3bf005d,0xdbc7002e,0xe46a008c}},	//   ykki, ेरा_, _föðu, ntöä_
  { {0xccf20008,0x320a005c,0x63a90a00,0x38b100dc}},	//   _שכן_, zeby_, ženj, _vár_
  { {0x5fc0005d,0x41bf005d,0x6abb003f,0xf1bf000b}},	//   ौरतल, ्रास, _utuf, ्रान
  { {0x06960029,0x7c3b003e,0xcb680029,0x4429272e}},	//   ونية_, _hour, _عمله_, _ana_
  { {0x240a085d,0xe5a50004,0x7de80030,0x2db6000a}},	//   онни_, ќини, lésü, ולתן_
  { {0x31c6005d,0x7c3b0493,0x644d272f,0x33202730}},	//   वर्ध, _jour, _clai, _prix_
  { {0x6446022d,0xf106014e,0x387f263b,0x386d2731}},	//   rkki, शब्द_, mour_, mner_
  { {0x64460020,0x387f0b77,0xeaa70115,0x479a000a}},	//   skki, lour_, ضع_, _וינס
  { {0x703a0036,0x320a2732,0x55ba000a,0x386d2733}},	//   очас_, reby_, _ומצו, oner_
  { {0x387f003e,0x7c3b2734,0x436a0fea,0xa2d7000b}},	//   nour_, _nour, _майн_, _बिच्
  { {0xdbc7002e,0x9e660015,0x386d2735,0x7e7e2736}},	// [4a80] _röðu, واطن, iner_, topp
  { {0x6e930086,0x7aeb0035,0x2284002e,0x44292737}},	//   پلما, dugt, töku_, _zna_
  { {0x44290176,0x55ac0053,0x7c3b2738,0x8c3d0061}},	//   _yna_, ציאַ, _bour, _vişn
  { {0xf5360053,0xdd8f0029,0x7c3b0493,0x7e7e2739}},	//   וטער_, جوم_, _cour, sopp
  { {0x6e4900dc,0x7c3b1c3b,0x386d0194,0xaab7006e}},	//   ásbó, _dour, dner_, ودور_
  { {0xf6470029,0xc333000a,0xaa570015,0xedd6002b}},	//   _شئ_, כוד_, ولنا_, _زيرد
  { {0x7c3b0493,0xdbc7001a,0x7aeb1bab,0x387f273a}},	//   _four, _töðu, augt, four_
  { {0xd6da24b3,0xd7e60036,0x386d1475,0x18970015}},	//   ото_, фіко, gner_, وضية_
  { {0x6e3c249f,0xceb3000a,0xac0701f3,0x63a9273b}},	//   _korb, ֣ית_, _інфа_, ženk
  { {0x4429002f,0x8b3b000a,0x2bcc000b,0xd90e002b}},	//   _sna_, _ותמצ, ारवा, _نیت_
  { {0x387f273c,0x2419004a,0xd6d9002a,0x644d0a1a}},	//   bour_, поны_, było_, _plai
  { {0x97c30010,0xc5f80024,0x6e3c25c5,0x387f273d}},	//   _айце, tnēs_, _lorb, cour_
  { {0x1b7b00b2,0x5b7b0053,0x6e3c0150,0x889b000a}},	//   ַטלע, ַרלא, _oorb, _ובאי
  { {0x44290026,0xe46a008c,0x6e3c273e,0x0000006a}},	//   _wna_, ttöä_, _norb,
  { {0x7de80030,0x6aa8273f,0x30a72740,0x44291005}},	//   zésü, _midf, драв, _tna_
  { {0x3cf2005d,0x43950033,0x44292741,0x44f82742}},	//   ँढने_, _пайс, _una_, mé_
  { {0xdef8054f,0x6e3c2743,0x44f811bf,0xe46a008c}},	// [4a90] дых_, _borb, lé_, stöä_
  { {0xb6a500a7,0x7c29002e,0x7c3b0493,0xed8b009c}},	//   _nhậ, _sner, _sour, осек_
  { {0x2d870134,0x7c3b0493,0x44f81fcf,0xafdb00cb}},	//   æne_, _pour, né_, _bløt
  { {0x7c940074,0x7de800dc,0xc19a000a,0x22840123}},	//   نشنا, tésü, _משתי, sökt_
  { {0xfbd00074,0xf4580135,0x6e3c2744,0x387f0ec3}},	//   شتن_, ויאר_, _forb, vour_
  { {0xa2b2005d,0xb6a50092,0x44f82745,0x661800bc}},	//   _इंस्, _chậ, ké_, _navk
  { {0x387f038d,0x79880026,0x7c3b0493,0xf8a9002b}},	//   tour_, _cydw, _tour, سگاه_
  { {0x6722010b,0xbca5003b,0x7c2900b8,0x63ad2746}},	//   _broj, _أمري, _uner, _ngan
  { {0xd706004a,0x6d450e1c,0xb6a5004a,0xe7160015}},	//   еные_, lyha, ниил, فييت_
  { {0xca480015,0x20192747,0x386d2748,0x7af40535}},	//   _قلقه_, _lasi_, sner_, żetó
  { {0x661800bd,0x44f80152,0x6c990008,0x79880026}},	//   _davk, gé_, ּשָׂ, _gydw
  { {0xa01b2749,0xdd0c002a,0x2019274a,0xc4c4002b}},	//   _skön, _róża, _nasi_, کتیو
  { {0xadf0000b,0x63ad02de,0x67220091,0x57470058}},	//   _चालन_, _dgan, _groj, _تخاف
  { {0xe60500f2,0x27ff001a,0xe7300021,0x02460015}},	//   ärää, lfun_, _خصم_, رَأَ
  { {0x7d020050,0x50960001,0x2d87005c,0x44f82285}},	//   łosz, ерађ, żnej_, cé_
  { {0x98730024,0x54360018,0x20190fd7,0x6e3c274b}},	//   mžēl_, _سربر, _casi_, _sorb
  { {0xceea0010,0x6496002d,0x66060030,0x2cbf0085}},	// [4aa0] ядае_, ráid, őkke, _čuda_
  { {0x6496002d,0x2019007c,0x66e20065,0x0000006a}},	//   sáid, _easi_, _खिसक_,
  { {0x6e3c274c,0x201904ed,0x6df30015,0x6d450030}},	//   _vorb, _fasi_, اكما, gyha
  { {0xeb9a0661,0x4c160021,0x6aa80123,0x20190022}},	//   пие_, عباس, _sidf, _gasi_
  { {0x205700b2,0x76480007,0xb6a50092,0x0b460033}},	//   _טיטל_, ykdy, _phậ, эндн
  { {0xf2d3214b,0x44f80152,0xb8660086,0xfaa303ec}},	//   רעג_, yé_, کاتو, гачо
  { {0xed140008,0x7c660029,0xa934033d,0x7ea90091}},	//   _בַּת_, _كارل, тейш, _užpa
  { {0xb908005d,0x44f8274d,0x63a905e3,0xacfb05bd}},	//   _बि_, vé_, ženi, _מהלכ
  { {0xd5bd014e,0xb6a50092,0xe666274e,0xbae60015}},	//   ोरंज, _thậ, етно, _سكاي
  { {0x44f8274f,0x63ad2750,0x49ba0021,0x7dab000a}},	//   té_, _sgan, _رائد_, ּ֑יִ
  { {0x44f82751,0x09290015,0x4733002b,0x88c60058}},	//   ué_, _يسمي_, نریز, _أتطل
  { {0xe73a0080,0x44f8274d,0xe7ea000b,0x67222583}},	//   _нее_, ré_, _टाटा_, _troj
  { {0x91a60023,0x44f80152,0x06140010,0xa2d4005d}},	//   _đó_, sé_, _адлю, _बौद्
  { {0xe9ce0033,0xc7a3006b,0x44f82752,0xae020065}},	//   акi_, _сичк, pé_, र्मन_
  { {0x361b0008,0x3d1a005d,0xdfd50802,0xc6930053}},	//   _מוגד, नटों_, ковы, _גאס_
  { {0x8c3d0061,0x44ce0091,0x63ad2753,0x0000006a}},	//   _pişm, mř_, _ugan,
  { {0x747c00a3,0xa022007c,0x62d90033,0x969a000a}},	// [4ab0] _מנהג, ööan, _ўмоў_, ִׁ֣י
  { {0x443900c0,0xdd9b0920,0x7ee40058,0x0000006a}},	//   ljs_, пше_, اكلن,
  { {0x24760024,0xbc1900fd,0xbbcc000b,0xbca50015}},	//   lāma_, ділі_, ारूक, نمطي
  { {0x44390123,0xd6d9002a,0xae02000b,0x2d8a063b}},	//   njs_, ysł_, र्बन_, _dybe_
  { {0x7de70036,0x24760024,0xee3f0016,0x2fc92754}},	//   _півд, nāma_, _buýt_, mbag_
  { {0x3eaa018b,0xd2b80008,0xab26006b,0x09e20004}},	//   _gibt_, עלות_, тоша_, аошн
  { {0xdd9402bf,0x99d40115,0xf1b4000a,0x6d430123}},	//   _бары, اتها, נסק_, änad
  { {0x63a1002a,0x3858004a,0x247601ec,0x0000006a}},	//   ślny, ерью_, kāma_,
  { {0x394903eb,0xc221000b,0x7c24003d,0x6820002a}},	//   ņas_, मयाब_, ķirt, _sądó
  { {0x89d9002b,0xa01b0123,0x7782030c,0xe6450137}},	//   _آوار_, _sköl, рльз, теоп
  { {0x4d8c000a,0x57f520b9,0x0000006a,0x0000006a}},	//   ּאכַ, _апет,   ,
  { {0xb9360053,0x3cf2000b,0x996404d5,0x3d090065}},	//   _ברעג_, ँढते_, _стул, _सहने_
  { {0xae02005d,0xc1bf000b,0xdc36004c,0xfe02000b}},	//   र्डन_, ्रूग, דארט_, र्डस_
  { {0x9756000a,0xdddc00b3,0x2ee90034,0x0000006a}},	//   _בינו_, _okrš, draf_,
  { {0xd179005e,0x016303ca,0x867a004f,0x0000006a}},	//   есті_, акро, _קרצו,
  { {0x78bc0030,0xafdb063b,0x6026009b,0xd25901ec}},	//   _érve, _slør, ъдба, īņa_
  { {0xdfcf0031,0xf487002b,0x0eaa0033,0x10a319db}},	// [4ac0] زيل_, _جاوی, дкай_, ритн
  { {0xc333000f,0x12aa0015,0x645d003d,0x3947001a}},	//   _כוח_, _تدعى_, īrie, kyns_
  { {0x30860029,0xc237000a,0xa3e6000b,0x2ee92755}},	//   _للدف, _סרטו_, _पया_, araf_
  { {0xd6d9005c,0x0b46042b,0x853a000a,0xcce50015}},	//   szły_, кнен, וגעי, اسلي
  { {0x768f06f5,0xbab30015,0xcab30015,0xf36d000a}},	//   tøyl, لمنب, لمنظ, ּדוּ
  { {0x0906005e,0xd9180021,0x8a03009b,0xdb090546}},	//   вчим, فيتش_, изче, _egeï
  { {0x628e002e,0x9e630e88,0xae02000b,0xf1b3000a}},	//   ilbo, _тврд, र्णन_, ססה_
  { {0xc1730008,0xa9270036,0xb814049d,0xdd8f0067}},	//   יחו_, тіше_, удиј, _ذوق_
  { {0xae02014e,0xc6f70080,0xdb00002e,0xdc75004a}},	//   र्थन_, вных_, _afmö, _сырь
  { {0x8f9b0053,0x9538000d,0xbf9b004c,0x44ce0046}},	//   ויפי, езот_, ויפש, tř_
  { {0xa01b001a,0x39580dec,0x69d82756,0x994a0058}},	//   _sköm, _års_, mave, _تلال_
  { {0xae02014e,0x443f0084,0x69d82757,0x442d039f}},	//   र्तन_, ðu_, lave, ñe_
  { {0x38b80084,0xc4580080,0xd2510015,0x7879004f}},	//   _hér_, тиях_, منح_, _אָסו
  { {0xe298008f,0x61bf005d,0xc2c40015,0xdb090003}},	//   каў_, ्रेष, شيفي, énég
  { {0x443f0092,0x69d80030,0xd258005e,0x2476003d}},	//   ưu_, iave, тця_, sāma_
  { {0x38b80084,0x628e2758,0xfdcb000b,0xa92304b2}},	//   _mér_, albo, िर्फ, úžil
  { {0x2d8e00b8,0xf3ff016e,0x6e990b1e,0x8fa40015}},	// [4ad0] üfen_, lião_, евар_, لمفه
  { {0x8fa40001,0xa2b0000b,0x1d6b0040,0x2ee92759}},	//   рађе, ंदर्, وصاً_, rraf_
  { {0x3da7008f,0xf3ff001c,0x69d8275a,0x2ee90064}},	//   траб, nião_, dave, sraf_
  { {0x8c3d01e2,0x63bd00dc,0x3035004a,0x69d80d37}},	//   _kişi, ncsn, _семё, eave
  { {0x7dc70015,0xf41f008c,0x09e50004,0xeb8e0a1f}},	//   _لتأك, idä_, голн, си_
  { {0xfe710074,0xf41f022d,0x69d80293,0x6fce000b}},	//   _اگر_, hdä_, gave, ़रअं
  { {0x08d4008f,0xd90f002b,0xdddc0085,0xeca700af}},	//   ацыя, تیا_, _ukrš, _ајан
  { {0x649d0125,0x0000006a,0x0000006a,0x0000006a}},	//   léif,   ,   ,
  { {0xe7310029,0xfc640063,0x07090015,0x69ca0030}},	//   صصة_, _търн, ريدي_, bbfe
  { {0x69ca021e,0x7bd900aa,0xf41f008c,0x394700aa}},	//   _स्पी, lawu, edä_, pyns_
  { {0xf3ff03af,0xa5040033,0xd46a0054,0x04461ecc}},	//   gião_, аяўл, еине_, генн
  { {0x26d900dc,0x36d5008a,0xf992004f,0xf8b2004f}},	//   ásos_, _бодр, _פרא_, _השא_
  { {0xd8380010,0xf74b0029,0x92f60010,0x6f07003d}},	//   _шэф_, _تجاه_, ычні, nībā
  { {0x8c3d0061,0x2cad02a1,0x41a50065,0xa564009a}},	//   _dişi, _lied_, _गृहस, ادین
  { {0xe2970124,0x50b52152,0x70b6002b,0xa594006b}},	//   уар_, исту, امرض, _кръщ
  { {0x8c3d04f9,0xdd3b002a,0x69d8275b,0x20550ef5}},	//   _fişi, _dąże, zave, атур
  { {0x6fb30029,0xdfcf0015,0x7afd0012,0x0000006a}},	// [4ae0] إمكا, ثيق_, _ästh,
  { {0x2bcc005d,0x533700a3,0xbbcc000b,0x01660015}},	//   ार्थ, _ענין_, ार्क, _مُخَ
  { {0x2cad020a,0x9be6008f,0x01fb0b7b,0xdd8f0029}},	//   _bied_, гілк, _אפיל, كوك_
  { {0x3ce6122c,0x6934002b,0x7bd900aa,0xa2cb000b}},	//   čov_, یکار, gawu, तीक्
  { {0x201201e2,0x38b80084,0x2cad0041,0x5bb701f3}},	//   meyi_, _sér_, _died_, улія_
  { {0x7f2b0008,0x20120061,0xceb3000a,0x98bc0091}},	//   _אֵלֶ, leyi_, _ליש_, hyvą_
  { {0xdd920074,0xf41f00f2,0x7c96275c,0xda6500c3}},	//   _طور_, ydä_, _брац, جاني
  { {0x6f16005c,0x64560007,0x3ad60018,0x38b80f3c}},	//   owyc, ūzij, _ميرز, _vér_
  { {0xc9f6003b,0xd5b0003b,0x6f070024,0x649d0125}},	//   _مساع, يفة_, cībā, léig
  { {0x4efb0053,0x38b8275d,0xceb3000a,0x8c3d0061}},	//   עליג, _tér_, זיז_, _rişi
  { {0xf76f0086,0x24590036,0x20120064,0x8b02002a}},	//   قای_, вань_, keyi_, łędn
  { {0xf993039e,0x8c3d0061,0x87260040,0x57260058}},	//   _הרע_, _pişi, _معتم, _مرتق
  { {0x41e7008f,0xf3ff001c,0x4e14000b,0x2813002b}},	//   ліва, sião_, ड़ाई_, _دونس
  { {0xd6270001,0x36f7000a,0xf3ff016e,0xa7730033}},	//   _боље_, _עצום_, pião_, _уліч
  { {0x6496002d,0xe0d50001,0x54e60015,0x25d7000a}},	//   máin, робњ, _إستق, _גוון_
  { {0x6018022a,0x64960f06,0x20120061,0x836700c3}},	//   лося_, láin, geyi_, _مدخل
  { {0x2dd5275e,0x9df90190,0xe8150065,0xe8060065}},	// [4af0] ижар, кнат_, ढ़ता_, व्या_
  { {0x539c0008,0x877b0008,0x63a90057,0xd338000a}},	//   _איחו, תאמי, žens, _תרזה_
  { {0x2cad275f,0x867b000a,0x20120061,0x38660045}},	//   _pied_, ערבו, beyi_, _omor_
  { {0x6f070024,0x3d05005d,0xe571000a,0xfbd00015}},	//   tībā, _रहीं_, חַד_, كته_
  { {0x1614014e,0x3fda0008,0x69d9000b,0x7bd9002a}},	//   तजार_, _בקרב, _नजदी, rawu
  { {0xeab00086,0x62870cd4,0x9aa40015,0xe9a9002b}},	//   سعه_, nojo, ممنو, نگان_
  { {0x6f070024,0x2cad2760,0xa3c5000b,0xdea4002b}},	//   sībā, _tied_, एडा_, _ایلی
  { {0xaae700b0,0xa6e524fe,0x649d0125,0xd709004a}},	//   _مسئو, ажил, néid, вние_
  { {0x86990083,0x6287090f,0x61e50057,0x6456003d}},	//   ктот_, kojo, _odhl, ūzik
  { {0x6726002e,0x60c500d9,0x649d002d,0x20120061}},	//   ækja, _othm, héid, zeyi_
  { {0x6f16005c,0x48150229,0x20120064,0x6287138a}},	//   zwyc, _вмес, yeyi_, dojo
  { {0x63ba0089,0xd46a18cd,0x38690123,0x6d8c004f}},	//   ětno, тиме_, _öar_, עָזְ
  { {0xb4630086,0xd6c30086,0x6496002d,0xe81e000b}},	//   تگوه, _امتی, báin, _मोटा_
  { {0x35a50010,0xca350008,0x6496002d,0x02190033}},	//   _калг, ׁנָה_, cáin, лісь_
  { {0x20120064,0x7643003f,0x16380015,0xd0120015}},	//   teyi_, _iony, _حسنة_, يلس_
  { {0x70560029,0xc952000a,0xa988000a,0x67240085}},	//   جنرا, קמן_, רָשִ, _šiji
  { {0x9e660010,0x20120064,0xe2e30033,0x6ec50015}},	// [4b00] авад, reyi_, _джып, متلق
  { {0x44202761,0x42db000a,0xcfa90015,0xbce60015}},	//   _hai_, _שקיע, طاقم_, لأصو
  { {0x442000df,0x5bc60015,0x764301c2,0x69d9000b}},	//   _kai_, لقال, _mony, _नज़ी
  { {0x649d002d,0x44202758,0xabaa0021,0x76430034}},	//   réig, _jai_, نهام_, _lony
  { {0x2b160080,0x44202762,0xf1da0065,0xfaa60138}},	//   рьер, _mai_, _बजान, аадо
  { {0xae02014e,0x44202763,0xe9f80033,0x73ad000a}},	//   र्शन_, _lai_, ункі_, ׂיאֵ
  { {0xfce3006d,0xf8b0002b,0x2d870030,0x6a1300c3}},	//   _моро, سکا_, ünet_, زبور
  { {0x9d1b0008,0x44202764,0xd90d002b,0x2716002a}},	//   _בולט, _nai_, عین_, _płn_
  { {0x7643000c,0xa2b2005d,0x6496002d,0x36040015}},	//   _bony, _इंग्, táin, موظف
  { {0xbafb0008,0x44321ee1,0xcdf6000a,0x865409c3}},	//   _בהמש, _any_, ׁמִי_, скох
  { {0x6496002d,0x44202765,0x2db7000a,0x24f80033}},	//   ráin, _bai_, ילין_, ынны_
  { {0xe7040086,0x6287002a,0x44202766,0x3329006f}},	//   _هستی, wojo, _cai_, _prax_
  { {0x53440080,0x44320089,0x6496002d,0x6287121a}},	//   охра, _dny_, páin, tojo
  { {0x17790010,0xb2870010,0x86c30029,0x4425002a}},	//   _ёсць_, рымк, _بيون, śl_
  { {0x44202767,0x3d05005d,0x6456003e,0x569b0008}},	//   _fai_, _रहें_, _flyi, _שיוצ
  { {0x7c202768,0x7f07005e,0x653b000a,0xa054005e}},	//   _namr, иїзд, _יעוד, овсі
  { {0x7c220176,0x53f80021,0x62872769,0x3f8f001a}},	// [4b10] ddor, _ضريح_, pojo, ægu_
  { {0xe3b00029,0x0e340036,0x6496002d,0x7d0100c0}},	//   _ترى_, оную, háil, _älsk
  { {0xc27c0008,0x127c0053,0x649d002d,0xdd910015}},	//   _ברזי, _באזע, péid, أوا_
  { {0x4c950080,0x8c3d0011,0x9be7005e,0xbbf8005e}},	//   щиес, _nişt, ріжк, ихії_
  { {0x69c100b8,0x6496002d,0x0c240010,0xa036000a}},	//   _pfle, dáil, ўмін, _הארה_
  { {0xdb0600dc,0x7a07005e,0x98e50015,0x5b340040}},	//   ámán, рядж, مكتو, تعمر
  { {0x38ca0086,0x787e003d,0x7643276a,0x30db004f}},	//   هايی_, zīve, _rony, דַ֖ע
  { {0x2178000a,0xa178000a,0x3eb9276b,0x64960125}},	//   יתור_, יעוד_, _kust_, gáil
  { {0xf5b50036,0x76430a72,0xc8640015,0x4420276c}},	//   йсню, _pony, تطوي, _rai_
  { {0x3eb90041,0x69070010,0x7c20276d,0x76b2002a}},	//   _must_, _вядз, _zamr, _słyc
  { {0x671c005d,0xb9950029,0x99850029,0x44201bac}},	//   _बैठक_, _الاب, _الضو, _pai_
  { {0xf09f0023,0x645d0007,0x7d1a0008,0xd7c90015}},	//   _nhà_, ūrin, נֵיה, _صوته_
  { {0x4420276e,0x386d276f,0x8c1a000a,0xf7940033}},	//   _vai_, mier_, נושי, _дацэ
  { {0x7643003f,0x386d2770,0x11da0015,0xd2520015}},	//   _uony, lier_, طورة_, أنس_
  { {0x88990053,0x44202771,0x200b0573,0xc5f8003d}},	//   ָבּי, _tai_, _bbci_, riēt_
  { {0x44e301e2,0xe3b20002,0x3eb910d1,0x386d2772}},	//   mı_, _عرب_, _bust_, nier_
  { {0x44e301e2,0x2fc000dc,0xd5db000b,0x8f970015}},	// [4b20] lı_, rcig_, _मजाज, منفذ_
  { {0x7c200084,0x3eb9003e,0x386d0252,0x2ee02773}},	//   _samr, _dust_, hier_, rsif_
  { {0x44e301e2,0x2ee01151,0xa3ac000b,0x5d860015}},	//   nı_, ssif_, _कृत_, حلال
  { {0xaae60029,0x4bda002b,0x2b94002b,0xb4fa004c}},	//   مستو, اباد_, قیزس, טלער
  { {0x6d5e005c,0x41760086,0x9f400077,0xd12f002b}},	//   szpa, _خاکس, rgió_, _قمی_
  { {0x4df52774,0x7d25002e,0x539b0008,0xf2d3000a}},	//   _мяст, ðusí, ניסו, לעד_
  { {0x386d0b7a,0x05db005d,0x5e570053,0x6496002d}},	//   fier_, _मज़ब, _פילע_, táil
  { {0x44e301e2,0xd90d002b,0xbebb0034,0x6f042775}},	//   dı_, ضیه_, _crëw, otic
  { {0x6f041139,0x64960125,0x76aa01b7,0x7791002b}},	//   ntic, ráil, лтов_, ویما
  { {0x386d020a,0x44e30064,0xee31000a,0x14ca004a}},	//   aier_, fı_, ֵֽי_, лыми_
  { {0x69da0048,0xda4b000a,0x4614002b,0xe415005e}},	//   _iete, _עֲמָ, موکر, однь
  { {0x0d970008,0x386d2776,0x69da1376,0x6f0401df}},	//   מכים_, cier_, _hete, ktic
  { {0x7ae4002f,0x4c9b0053,0x889b0008,0x69da013c}},	//   áith, טשטע, _עבדי, _kete
  { {0x44e30064,0x69da1151,0xe717000a,0xf1c90015}},	//   bı_, _jete, _לחדר_, شورى_
  { {0x915f0023,0x44e301e2,0xd4c60029,0x7ea90007}},	//   _bắt_, cı_, _اغتي, _užpi
  { {0xa2d4000b,0x915f0016,0xd5b8003d,0x69da2777}},	//   _बौक्, _cắt_, idām_, _lete
  { {0x9f34005e,0x0000006a,0x0000006a,0x0000006a}},	// [4b30] петі,   ,   ,
  { {0x69da2778,0xd3580008,0x291e1f1c,0xe1070033}},	//   _nete, _לשחק_, _osta_, _лямп
  { {0xf09f0016,0x6fb50015,0xdd9b1411,0x6f042779}},	//   _thà_, _ومدا, уша_, atic
  { {0xfebb0086,0x62950012,0xa01b0123,0x69da277a}},	//   _ماست_, llzo, _sjöf, _aete
  { {0x70550074,0x291e0667,0xa3ac000b,0xedd50015}},	//   _هنگا, _asta_, केप_, _ويحد
  { {0x44e301e2,0x1a29004a,0x3e040033,0x672d003d}},	//   yı_, ржки_, _нясв, _šajo
  { {0xa8590001,0xd9420063,0x52b5000b,0x386d277b}},	//   ијих_, дещи, ंदुस, tier_
  { {0xd6d1003b,0x7bc2277c,0x0aeb0015,0x315805bd}},	//   وقع_, ccou, _مرئي_, מיון_
  { {0x69ca014e,0x9f400084,0x291e0e75,0x0ee2000b}},	//   _स्वी, ngið_, _esta_, _पिछड
  { {0x44e30064,0x386d1741,0x96650033,0xa01b001a}},	//   tı_, sier_, ікне, _fjög
  { {0x64a6277d,0xca840015,0xe975002b,0x6f04003d}},	//   жана, _علمً, _بهاد, ztic
  { {0x44e30482,0x69da0111,0x6abb003f,0x6cfa000a}},	//   rı_, _zete, _kuuf, ספרס
  { {0x44e301e2,0x69da01e2,0x8c1a0008,0x888c004c}},	//   sı_, _yete, בורי, _גראַ
  { {0x44e30064,0x59cf0231,0xd6e8000a,0xa3d8000b}},	//   pı_, _स्मर, _הַקָ, िरह_
  { {0x645d002d,0x54e40015,0x20090034,0x60260239}},	//   bhsi, _فسيق, ffai_, одва
  { {0x6f04271e,0x645d00b8,0x3ff60015,0xa9270091}},	//   ttic, chsi, تكرر, mažė
  { {0x67290134,0x9f40002e,0xd00f0015,0xfe460004}},	// [4b40] nvej, ggið_, خلق_, онао
  { {0xa01b00c0,0xee37267e,0x14b5000a,0xe0da084f}},	//   _sköt, ону_, ַּ֣ר_, _кво_
  { {0x915f0092,0x3218277e,0xbc66005e,0x0c26027a}},	//   _tắt_, mery_, овжк, жмен
  { {0x7bc20152,0x7ae200f2,0x2609000b,0x51f6002b}},	//   ucou, tsot, ़्ती_, _اسکر
  { {0x2ca60026,0x78ba0007,0xbb43054f,0x7bc2277f}},	//   rmod_, _sutv, мецк, rcou
  { {0x1ad9008f,0x98c60511,0xc1ba000a,0x7bc202fc}},	//   сьць_, осил, ׁמְש, scou
  { {0xd5b80024,0x69da2780,0x115a000a,0xafb9001a}},	//   udām_, _vete, ידַע, _áááá_
  { {0xe8e00023,0x69da2781,0xf1b3000a,0x98a30054}},	//   hiệp_, _wete, וסו_, мије
  { {0x69da1bf1,0xc64a0015,0x0b170015,0x32180ca8}},	//   _tete, لجدل_, _وقفة_, kery_
  { {0x78ba0005,0x0f37004c,0xa5f80054,0xcf93000a}},	//   _tutv, קריט_, љену_, וטח_
  { {0xd7e60036,0x645d2782,0x68020046,0x5e9b000a}},	//   _діло, ūrim, _půjč, שביק
  { {0x2bb1005d,0x2ef200dd,0xafdb00cb,0xd7f70c02}},	//   ुँचा, kryf_, _fløy, _душ_
  { {0xf8b3000a,0x32182783,0x2fd202de,0x987b004f}},	//   _חשף_, fery_, dbyg_, _דראק
  { {0x2ef200dd,0x2fd20026,0x217b0015,0x321800da}},	//   dryf_, ebyg_, لحزب_, gery_
  { {0x306b023e,0x3228005e,0xe4d30015,0x40350004}},	//   ајан_, ціям_, _قتيب, певс
  { {0x91cb000b,0x2ef20034,0xcfab0058,0x768f0c4e}},	//   _त्रै, fryf_, لاءم_, søyt
  { {0x7de70015,0xdb190012,0xcdcb0015,0x62802784}},	// [4b50] قسام, ubwü, لذان_, émoc
  { {0x551e005d,0x32182785,0x9e070033,0xb51e000b}},	//   _बनाए_, cery_, ўчал, _बनाय_
  { {0x8d68000d,0x59de005d,0x621a000a,0x78a2006f}},	//   ојца_, _नज़र, _הותק, _ohov
  { {0xe58b000a,0x50f40033,0x2476003d,0xae45002b}},	//   בָדָ, _ўзят, tāmi_, _کپسو
  { {0x403a0008,0x103a000a,0xa03a000a,0xaac4012c}},	//   _הגרג, _הגרע, _הערפ, وتون
  { {0xdcfb0086,0x08d50063,0x4a440036,0x78a200dc}},	//   _پرسش_, пция, мнів, _ahov
  { {0x76b2005c,0x645d003d,0x9cc80033,0x2476003d}},	//   _płyn, īrij, _мыта_, sāmi_
  { {0x787e0048,0xb17c0008,0xd6c30086,0x67292786}},	//   tīva, יטור, ومبی, tvej
  { {0xab7d0010,0xf77100e6,0xc7b90030,0x7ad5002b}},	//   _сваi, عاب_, ldők_, _رقاص
  { {0x67292787,0xcb88000a,0xf9930021,0x05651eab}},	//   rvej, _וְעֹ, _قبض_, звон
  { {0x7a7a0053,0x32182788,0xab5d005c,0xa3d7000b}},	//   _פרעס, very_, _reży, ाऐं_
  { {0xfd560008,0x59cf005d,0x399a000a,0x768f00cb}},	//   פשרי_, _स्तर, _היעד, tøys
  { {0x8c1a0008,0xfbd20008,0x289a0053,0x7ae400bd}},	//   זורי, עתך_, _פינא, šitv
  { {0xaadd000b,0x768f00cb,0x32182789,0x649d059d}},	//   नीयक, røys, uery_, réia
  { {0xc692013a,0xe3b20086,0x649d002d,0x361a002b}},	//   _ראו_, برگ_, méin, _درنگ_
  { {0x649d016e,0x32180a5d,0xdce8003d,0xf992000a}},	//   péia, sery_, ūlīt, גרל_
  { {0x33fb000a,0x8236006e,0x1f6603a7,0x93fb004f}},	// [4b60] _ההפנ, _فردا, чкам, _הלפי
  { {0x0e6a0015,0x290706c0,0xe1fa2143,0x0000006a}},	//   حصري_, ktna_, _уго_,
  { {0x91bb000a,0xc1bb000a,0x0dc90015,0xae02000b}},	//   _למיי, _למיש, تبقى_, र्गन_
  { {0xe5720053,0x628e278a,0xdd8f0040,0x1c460342}},	//   ײַע_, lobo, دوم_, янем
  { {0xcfb70008,0x78a9007c,0x2a6c09ae,0x539b000a}},	//   _מלכי_, dmev, _pmdb_, ֖ינו
  { {0x26c2002c,0x19940617,0x5eeb000a,0x78a2278b}},	//   íkom_, маля, _לַלְ, _shov
  { {0x24760048,0xa3ac005d,0x621b000a,0x69230004}},	//   lāmu_, केत_, מוסק, емја
  { {0x5d7b0008,0xda660086,0xc8660036,0xc8630080}},	//   _האלק, _کاري, ятли, етьи
  { {0x24760024,0x9986002b,0x628e1a33,0xf62a00ce}},	//   nāmu_, _کلاو, kobo, біни_
  { {0x9f4b00dc,0xab770002,0x9a250015,0x0000006a}},	//   ímét_, _عملا_, _يعلن,
  { {0x997e0033,0x186a03ae,0x628e278c,0xd7ef1d3b}},	//   _стаi, _лажи_, dobo, _пу_
  { {0xf8aa0124,0x38a1005c,0x493b0008,0x88bb000a}},	//   _увек_, tóre_, _לגבו, _המאז
  { {0xa3be005d,0x93270029,0xc8650015,0xf80b000a}},	//   ेड़_, أرجن, _تطلي, _ה֔וּ
  { {0x6722008c,0x0737000a,0xf6d50033,0x2476003d}},	//   _isoj, _מאדם_, _ціця, dāmu_
  { {0x06b10089,0xc5eb000a,0x609b0015,0x65930033}},	//   řící_, _הַחֹ, مخرج_, _пашу
  { {0x55970008,0xf0b4017f,0x757b000a,0x661a278d}},	//   _מדוע_, ейсь, _לטופ, letk
  { {0x3375005e,0x1eab0015,0xfe71002b,0xdb09007f}},	// [4b70] _ігор, مائي_, نگس_, ünüd
  { {0x03780008,0x661a278e,0x1eea009a,0x628e278f}},	//   _מתחת_, netk, زومی_, cobo
  { {0xa25b032c,0x3cf7005d,0x55bb039e,0x8c3d0061}},	//   spôs, ँढें_, צמאו, _ahşa
  { {0xfc640063,0x6b750248,0x69c82790,0xab750054}},	//   нъчн, млеу, _afde, мгеш
  { {0x3ce9005d,0xcfab0086,0xeb8e2791,0x0dcb1411}},	//   _चटके_, _دادم_, ти_, _губи_
  { {0x2296002e,0x539c000a,0x29070123,0x7f3a000a}},	//   tæki_, ציגו, ttna_, _ועשו
  { {0x661a018c,0x649d002d,0xba080015,0x2bce000b}},	//   detk, véin, ستوك_, _ह्वा
  { {0x06c90146,0x97d9017f,0xd8790015,0xbc940054}},	//   огий_, цьку_, تمعت_, _засј
  { {0x2601005d,0x764a003f,0x649d0003,0x29072792}},	//   _शादी_, _bofy, téin, stna_
  { {0x3669005e,0x661a01d7,0x29070081,0x0000006a}},	//   іано_, getk, ptna_,
  { {0xa7870086,0x7ae9002e,0x9a84005e,0x628e2793}},	//   _کشاو, _hvet, _чутл, vobo
  { {0x7ae901c9,0xb8e1021e,0xc952000a,0x628e002a}},	//   _kvet, ंद_, _שמא_, wobo
  { {0x44630063,0x661a2794,0x442c0046,0x628e2795}},	//   твяв, betk, ěd_, tobo
  { {0x764a0176,0x76ba0008,0xa01b002e,0x01da0015}},	//   _gofy, _ומספ, _sköp, توسع_
  { {0x661c0020,0x628e2796,0xe2972797,0xe7d10065}},	//   õrke, robo, фар_, _सभाप
  { {0x27ff064e,0x10a30292,0x2476003d,0x628e0a90}},	//   ngun_, висн, tāmu_, sobo
  { {0x787e003d,0x61f90030,0x6aaa0034,0x6e270030}},	// [4b80] zīvo, áblé, ymff, _bajb
  { {0x649d002d,0xe2920002,0xecd5000b,0xde1a0015}},	//   héil, _جذب_, डीऍफ, تقطت_
  { {0x8c460036,0xdbc60020,0xd23b000a,0x823b000a}},	//   меже, _mööd, _וגיל, _ועיצ
  { {0x2bd5005d,0xed570036,0x69b3005d,0xae02000b}},	//   दरगा, ьох_, ेखनी, र्जन_
  { {0x671c005d,0x6e3900dc,0xe7e1000b,0x7ae90796}},	//   _बैंक_, ábbí, _गज़ा_, _cvet
  { {0xbe160086,0x787e0024,0x984c002a,0xbb430054}},	//   _توسع, tīvo, ość_, тељк
  { {0x661a0014,0x24760024,0xdd920086,0x7ae90808}},	//   vetk, nāms_, _شور_, _evet
  { {0x649d002d,0xada3070e,0x27ff01c2,0x787e003d}},	//   géil, _расл, ggun_, rīvo
  { {0x59cf005d,0xf0930008,0xc8b30015,0x2d9801d0}},	//   _स्वर, כנה_, خصوب, _hyre_
  { {0x7afd0123,0xaa570015,0x29d30015,0x7f3b004f}},	//   _åsta, _قلقا_, _ليكس, קעיו
  { {0xe01e005d,0x984c005c,0x38c80086,0xfdf7000a}},	//   _पसंद_, jść_, _راضی_, וצית_
  { {0x8434005e,0x62802798,0xacc705bd,0x661a2799}},	//   внює, émon, וּךְ_, setk
  { {0x984c005c,0xfbd3000a,0xe6660162,0xc34b0033}},	//   eść_, כתר_, _отко, цяне_
  { {0xe56f0086,0x179b000a,0xab4b004f,0x0000006a}},	//   اطی_, _וידב, חֲלֻ,
  { {0x38a100dc,0xd5fb000a,0x15fb000a,0x45fb000a}},	//   lóra_, _ופור, _והוע, _והוג
  { {0x27e400c0,0xd92b004f,0xa3ea0065,0x0000006a}},	//   namn_, חֵמָ, मणः_,
  { {0x3eb80084,0xa2b9000b,0x3f85002a,0xa3be0065}},	// [4b90] _birt_, _एंट्, _ślub_, ेडर_
  { {0x42550015,0x27e4156a,0x63a0007c,0xdd9b16db}},	//   _أندر, hamn_, ümne, оше_
  { {0x52740086,0x27ff0064,0x7ae9279a,0x3eb800da}},	//   _جايز, ygun_, _svet, _dirt_
  { {0x859b013a,0xfbd000a2,0x160e005d,0x44290604}},	//   חשבו, لته_, ़्तर_, _jaa_
  { {0x38a1002e,0xdee70029,0x4429279b,0x2d8e0012}},	//   jóra_, _تأجي, _maa_, üfer_
  { {0xf2d40053,0x5ee8000a,0x8b22004a,0x44290013}},	//   דעס_, _קַרְ, удше, _laa_
  { {0xd8760086,0x27ff1859,0xdbd9001a,0xaffb004f}},	//   کميت_, tgun_, _fæðu, ַּ֗י
  { {0x6496002d,0xf8ae0086,0x98a2085d,0xdbc60020}},	//   náit, مکن_, лище, _sööd
  { {0x2b900086,0x27ff0ab5,0xe73100e6,0x69ca000b}},	//   _پیوس, rgun_, اصب_, _स्की
  { {0x8a370029,0x984c005c,0x79c80015,0x6f7a000a}},	//   _تعرض, yść_, _يوقف_, לְיו
  { {0xa9070074,0xb579007a,0x7e600045,0x625902b9}},	//   _زبان, ящих_, _împe, _vìol
  { {0x3d07014e,0xc209013a,0x4d5a000a,0xd7c80015}},	//   _हमने_, _לה_, פדרצ, _قومه_
  { {0xdbc60020,0xb7da000a,0xcc56000a,0x4429279c}},	//   _tööd, _זקני, גברי_, _daa_
  { {0x4429022d,0x66f6013a,0x1606000b,0x2476003d}},	//   _eaa_, _נמצא_, _शायर_, tāms_
  { {0xf9920053,0x644d0011,0x2ee90026,0xe610002b}},	//   ָרן_, _foai, esaf_, _خشن_
  { {0x387f0084,0x7c290020,0x984c002a,0x4429279d}},	//   nnur_, _naer, rść_, _gaa_
  { {0x3f86001c,0xa3ac000b,0x20001837,0x7c2b0230}},	// [4ba0] çou_, केश_, rgii_, ddgr
  { {0x63a40717,0x3126279e,0x387f0012,0x645d00aa}},	//   _izin, _здог, hnur_, ëriv
  { {0x38a100dc,0x2497002b,0x41760015,0xdb0a006f}},	//   zóra_, _زنید_, _سادس, čnít
  { {0x7c291f8d,0x3eb80012,0xd35a000a,0x7c2b279f}},	//   _caer, _wirt_, ּדַל, gdgr
  { {0x6496002d,0x7c290273,0xc477000a,0xd5b8003d}},	//   láis, _daer, עתנו_, ldāt_
  { {0x63a4003f,0x38c8002b,0x2d9827a0,0x7c2b1223}},	//   _mzin, وابی_, _tyre_, adgr
  { {0x1e97000a,0x6da30684,0x387f001a,0x8e8301b7}},	//   _נכלל_, _бира, fnur_, _сгре
  { {0x7c290026,0xc173000a,0x9cb60015,0x7b09008c}},	//   _gaer, טחו_, _أمرت, östö
  { {0x63a4003f,0x501b000a,0xcb67005e,0x8c1b004c}},	//   _nzin, לוקו, _зате_, _צומי
  { {0xb6020089,0xba290015,0xa534005e,0x3ad30015}},	//   _část, _يسلم_, вноч, _إيلز
  { {0x44290595,0xa3d50139,0xfcaa000a,0x38a10125}},	//   _paa_, конч, ּיָּ, sóra_
  { {0x7d7b000a,0xe78627a1,0x442901f6,0x0000006a}},	//   לניו, _пуло, _qaa_,
  { {0xa3ac000b,0x80d9000b,0x442927a2,0x6aba01f9}},	//   केल_, _फौजे, _vaa_, _kitf
  { {0x6726002e,0x38850024,0x63a427a3,0x0000006a}},	//   ækju, mēra_, _dzin,
  { {0x1a9b0053,0x69ca002d,0x63a427a4,0x30a70d8a}},	//   פילע, icfe, _ezin, ерав
  { {0x759b0e22,0x859b0008,0xd59b000a,0x2ee90079}},	//   _מיוח, _משוו, _מבול, tsaf_
  { {0x6496002f,0x187b0008,0xf41f00f2,0x6ee40015}},	// [4bb0] ráit, פטמב, meä_, ُسْل
  { {0x765a0007,0x38a1002e,0x2ee90026,0x01d90015}},	//   nkty, jórn_, rsaf_, _تودع_
  { {0x63a40024,0x6496002d,0x40950015,0xe821000b}},	//   _zzin, cáis, _للدر, _मसला_
  { {0x6496002d,0xb4fb000a,0xacf40015,0x8c450054}},	//   láir, לפבי, اسلت, ђеле
  { {0x65640089,0x765a00cb,0xf24b000a,0x7c2927a5}},	//   _řihl, kkty, ּגֶּ, _vaer
  { {0x50d40086,0x2f5a000a,0x7ac40033,0xd5b8003d}},	//   _جزیر, _חדשנ, усце, ndās_
  { {0xac770015,0xf41f008c,0x7c290125,0x9d1827a6}},	//   _كارش, keä_, _taer, _порт_
  { {0xf99000a2,0x6496002d,0x765a002a,0xb8db000b}},	//   حبه_, háir, ekty, _ें_
  { {0xd7060080,0x387f00e8,0xa6e20010,0xc5d50033}},	//   вные_, rnur_, ажыл, кінь
  { {0xbab5002b,0xab74009b,0x0000006a,0x0000006a}},	//   _شماب, _сгуш,   ,
  { {0xc9590074,0x63a40014,0x69ca005d,0xe708002b}},	//   _تلاش_, _szin, _स्टी, وتین_
  { {0x6f0d005c,0x765a1256,0xa01b0123,0x2d870061}},	//   ktac, akty, _sjön, üney_
  { {0x03230191,0xa3ac005d,0xa856000a,0xd7f8006b}},	//   адян, कें_, _שינה_, _чух_
  { {0x998700dc,0x6496002d,0x9f4000aa,0x877a004f}},	//   lenő_, gáir, waiï_, _קאסי
  { {0x26c2032c,0x20c70016,0x40960de9,0x91e30684}},	//   íkov_, _cõi_, врат, росе
  { {0x20c70023,0x7eab00b8,0xdfcf0002,0x3e640123}},	//   _dõi_, nüpf, قيف_, _möte_
  { {0x6fb30021,0x63a427a7,0x0000006a,0x0000006a}},	// [4bc0] لمفا, _uzin,   ,
  { {0x3f9c003d,0x645d0091,0x02fb0643,0x8337004f}},	//   āvu_, ūrit, _קלימ, _יאפס_
  { {0xf8b3000b,0xa01b001a,0x61d7000a,0x6f0d27a8}},	//   ुदाय, _kjöl, _שוטף_, atac
  { {0xf5360053,0xaae60115,0xe536004c,0xfd95005e}},	//   כטער_, نستو, כטעט_, ушую
  { {0xbc670021,0xa01b0123,0x20550033,0x6f0d2678}},	//   ضمون_, _mjöl, _стэр, ctac
  { {0xf2d3000a,0xbb470015,0x68f80160,0x0000006a}},	//   סעו_, ئلون_, trvd,
  { {0xda6500e5,0xc27b000a,0xb9230015,0x9f49001a}},	//   داني, ורסי, لفوي, lgað_
  { {0x2617000b,0x61e70030,0xd9430054,0xd7f00015}},	//   _बॉबी_, zajl, рећи, حكة_
  { {0xbbde005d,0x9f49002e,0x799a005c,0xa09b000a}},	//   मरीक, ngað_, _wytw, ויקט
  { {0x963301b0,0x0000006a,0x0000006a,0x0000006a}},	//   аньц,   ,   ,
  { {0x765a27a9,0x4e350053,0x4614002b,0x6f0d002a}},	//   rkty, אָרן_, نوکر, ztac
  { {0x997900b2,0x897900b2,0x6f0d1f04,0x765a0123}},	//   _אָנפ, _אָנה, ytac, skty
  { {0x2813002b,0xdcfc0091,0x61e727aa,0xf41f008c}},	//   _خونس, _tyrė, tajl, reä_
  { {0x07a30001,0x17570008,0x9757000a,0x63a0007c}},	//   _тачн, _בסדר_, _בידו_, ümna
  { {0xc69300b4,0xa01b0084,0x6019006b,0xf41f005b}},	//   _דאס_, _fjöl, новя_, peä_
  { {0x20c71c23,0x260e014e,0x61e701e2,0x9f9d0084}},	//   _või_, त्री_, sajl, _bæði_
  { {0xb2ab005e,0x533509fe,0x9f49001a,0x8e150033}},	// [4bd0] _отож_, _септ, ggað_, лдац
  { {0x752f005c,0x20c70020,0xfe700015,0x6f0d27ab}},	//   łcze, _tõi_, يدل_, rtac
  { {0x2016002c,0xdd910029,0x8cf50054,0xb603006f}},	//   ícií_, حوا_, узец, úšik
  { {0xda05005d,0xbc180036,0x645d27ac,0x6f0d27ad}},	//   _राहत_, віші_, nksi, ptac
  { {0x9f9d002e,0xd6d9002a,0x61e50eb3,0xfc300015}},	//   _gæði_, były_, _kehl, تحل_
  { {0x61e50046,0xdcf70015,0x629527ae,0x6a14005e}},	//   _jehl, _لأرب, nozo, имчу
  { {0x7e600011,0xa3e3000b,0x6d430123,0x645d001a}},	//   _împa, धरा_, ånad, kksi
  { {0xccf2011f,0x7af60007,0x629500dc,0x66d90063}},	//   _לכל_, šyta, hozo, ньор_
  { {0x629500dc,0x0000006a,0x0000006a,0x0000006a}},	//   kozo,   ,   ,
  { {0xe9d30015,0x2bcb000b,0xb7bd0045,0x85490783}},	//   _ضغط_, ाडका, deţe, езов_
  { {0x69c102c1,0xf3e60860,0x3aba000a,0x62950030}},	//   _igle, лжно, _נמענ, dozo
  { {0x97250015,0xf8af002b,0xd6d9002a,0xa01b0030}},	//   _مفصو, _بکت_, zyły_, _eköz
  { {0xc87901e2,0xd808000a,0xe8940138,0x0000006a}},	//   miş_, _יִסָ, _таць,
  { {0x412a0a47,0x629500dc,0x4375007a,0xc879140d}},	//   ного_, gozo, руют, liş_
  { {0x216a04bb,0x7bc5005a,0x7ccc007f,0x9f9d0052}},	//   хиви_, ěhuj, _oğra, _sæði_
  { {0xc8790064,0x787e0024,0x251a0053,0x645d0334}},	//   niş_, tīvi, _נופא, cksi
  { {0x61e5018b,0x69c1116e,0xef1a02bf,0x442227af}},	// [4be0] _fehl, _ogle, эма_, mek_
  { {0x9f49002e,0x5d6a0080,0x442227b0,0xb2261cd9}},	//   rgað_, низм_, lek_, _смол
  { {0x44222514,0x2d9c0134,0xdca6017a,0x365a004c}},	//   oek_, æve_, гажи, עכענ
  { {0xcdc9013a,0x1613005d,0x442227b1,0x69c1001a}},	//   לך_, त्तर_, nek_, _agle
  { {0x6d430123,0x442227b2,0xc8791d56,0x6369004f}},	//   änar, iek_, diş_, ֻסוּ_
  { {0xab77003b,0x90e50086,0x442227b3,0xa95400ce}},	//   دمها_, _حسین, hek_, иклі
  { {0x645d00f2,0x442227b4,0x0e63005e,0x3f870061}},	//   yksi, kek_, _укрн, şnut_
  { {0xb6f4049d,0x442227b5,0xa6f40054,0x62951779}},	//   азиј, jek_, азиш, zozo
  { {0x205700b2,0x6a66002e,0x7c22003f,0x3b8614fc}},	//   טיקל_, _aðfe, meor, _слаг
  { {0x91d4000b,0xfb1b004c,0x442227b6,0x7c2227b7}},	//   _ब्लै, _אוממ, eek_, leor
  { {0x629527b8,0x08fa0067,0xa01b0123,0x7e7b000a}},	//   vozo, _سراب_, _sjöm, תאיז
  { {0x3d07014e,0x44220014,0x645d022d,0xa37b007c}},	//   _हमसे_, gek_, uksi, laõi
  { {0x62950014,0xb8930029,0x987b0053,0xb364006b}},	//   tozo, _النع, _אראק, бърк
  { {0xae03005d,0x442d27b9,0x6d41001a,0x7c221735}},	//   _लाइन_, že_, _álag, heor
  { {0x7c2206f5,0x629527ba,0xd49b0734,0xb7bd0045}},	//   keor, rozo, _при_, reţe
  { {0x442201e2,0x4fd5086e,0xb7bd0045,0xafdb00cb}},	//   cek_, ржат, seţe, _snøb
  { {0xf3ff001c,0x61e50064,0x62760024,0x7c2227bb}},	// [4bf0] lhão_, _tehl, iņoj, deor
  { {0xa37b0020,0xfe730015,0x6e2e27bc,0x9757000a}},	//   jaõi, حدر_, _cabb, אימו_
  { {0xf3ff001c,0x4add000b,0xc617000a,0xb2ba000a}},	//   nhão_, _नौजव, רחבי_, _שמתר
  { {0x7c2227bd,0x4c950080,0x50da000a,0x69c10034}},	//   geor, шиес, _שקרא, _sgle
  { {0x7dc70029,0x6e2e04ed,0xab2927be,0x1ab5006b}},	//   _متأك, _fabb, тола_, абдя
  { {0x2bd5005d,0x4efa000a,0x27e90085,0x442227bf}},	//   _ड्रा, _בהשו, _žan_, zek_
  { {0x3258013a,0xaa560001,0xc8790064,0xe45f00f2}},	//   רסום_, рију_, tiş_, kkö_
  { {0x5d84003b,0x7ccc0064,0x8b05002a,0x88350033}},	//   _الفل, _uğra, _pięć, рэкц
  { {0xc87901e2,0x7b670036,0x57460063,0xaa070115}},	//   riş_, _стве, изъм_, _مظاه
  { {0x44220ec5,0x2efc004c,0x69c127c0,0x95c80004}},	//   wek_, גלזײ, _ugle, луџа_
  { {0x3c750008,0x04460010,0xd46a0175,0x442227c1}},	//   ֹתָם_, аенн, вине_, tek_
  { {0x76b2005c,0x0d96000a,0x6f1d25c2,0x3e640123}},	//   _błys, יכתם_, _opsc, _möta_
  { {0x76b2005c,0x442227c2,0x2926002a,0x485a004f}},	//   _płyt, rek_, ętał_, _שכנג
  { {0x442227c3,0x368b070c,0x01660033,0xd5490015}},	//   sek_, _ясен_, акго, _للتو_
  { {0xc0760124,0x067a000a,0xc0e60a96,0x6e2e27c4}},	//   аћањ, _שנצל, робк, _rabb
  { {0xe7ac005d,0x251a0008,0x20870036,0x7cc50007}},	//   _चरमप, _יוצא, айси_, _gėri

  { {0x34b30015,0x04570015,0x765c001a,0xcff5002b}},	// [4c00] _بميز, _خلية_, öryg, صيلک
  { {0x64410024,0x2bde005d,0x6cd60015,0x9dba002b}},	//   ēlie, मर्थ, لقطا, نداز_
  { {0x10a60142,0x01fb000a,0xa0a61155,0x716a0de9}},	//   _винн, _בפיל, _ванд, _ранг_
  { {0xb53a004c,0x3d070065,0x33c9004f,0x0000006a}},	//   כגעש, _हमरे_, ְהוּ_,
  { {0x7e600011,0x6e2e27c5,0xcb34006b,0x7bc40091}},	//   _împo, _tabb, селъ, žiuo
  { {0x6a830080,0x649d002d,0x7af60007,0xb8f40029}},	//   олча, léit, šyto, مكتب
  { {0x6f04002d,0xc9e90015,0x44e30030,0x23ac0091}},	//   luic, اءهم_, jű_, lųjį_
  { {0x9cd70008,0x649d0c1b,0x97240015,0x0000006a}},	//   _כולה_, néit, مفعو,
  { {0x76aa0080,0xc9f60015,0xabfb000a,0x9bfb000a}},	//   ктов_, _نساع, _שהמר, _שהמט
  { {0x1daa005d,0xff17000a,0x69960238,0xd5340015}},	//   _करात, סקית_, _крех, مفخخ
  { {0x44e300dc,0x76b2005c,0xe45f00f2,0xce370008}},	//   gű_, _słys, tkö_, באית_
  { {0x7d030251,0x291e00d9,0x87260015,0xb7d80015}},	//   ànsi, _ipta_, _نعتم, _صوتا_
  { {0x6f0427c6,0x38660045,0x3d080065,0x439402ed}},	//   juic, _ilor_, ांडे_, жаяс
  { {0x3d07014e,0xe45f0123,0x471b004f,0xe9ce0138}},	//   _हमले_, skö_, _סווג, пкi_
  { {0x3135006b,0x415402d9,0xc8b4000a,0x386627c7}},	//   щевр, оврс, ֶּֽה_, _klor_
  { {0xc1040029,0x4e19000b,0xd91b000a,0x25bb000a}},	//   توفي, न्नई_, כולל, _בצומ
  { {0x30040015,0x1eab0015,0x3e890058,0x8f0b009b}},	// [4c10] تبُّ, نائي_, هَرَ_, ъхва_
  { {0x7e600045,0x644f0085,0x2cad27c8,0x291e0ce5}},	//   _împl, ljci, _shed_, _opta_
  { {0x7d790029,0x92b40015,0x8d790015,0xa15925d6}},	//   دمار_, _بحيا, دماء_, _сану_
  { {0xbd440029,0x62800057,0xcaf50015,0xe0d2004c}},	//   تنمي, émov, مستب, _מײט_
  { {0xd438000a,0xa036000a,0x6f1d00da,0x628727c9}},	//   יראק_, _פאשה_, _upsc, onjo
  { {0xa3ac005d,0x09e20010,0x20f30085,0x20090091}},	//   केट_, пошн, oći_, lgai_
  { {0xceb20053,0x649d002d,0xa3d7000b,0x721c000a}},	//   _מיך_, néis, िडा_, דווח
  { {0x6c850029,0x38290001,0x20090aa6,0x4c9400f4}},	//   _الرم, ужио_, ngai_, _дисс
  { {0xf7490086,0xa7120015,0xdd38003d,0x649d0003}},	//   اجعه_, كِيع, māša, héis
  { {0xd4d9008f,0x3618005e,0x5a440033,0x44e30030}},	//   льмі_, ацюю_, _мэха, tű_
  { {0x6287016f,0xc32901ac,0x9935002b,0x6f04002a}},	//   dnjo, _רו_, _دفات, zuic
  { {0xdd380048,0x44e300dc,0x15f3000b,0xa988000a}},	//   nāša, rű_, _आयकर_, _דָנִ
  { {0xa3d7005d,0x38a1002e,0x27ed0026,0x20f30085}},	//   िड़_, jóri_, maen_, eći_
  { {0x27ed0176,0xe611002b,0x388c0046,0x23ac0091}},	//   laen_, _رشت_, měra_, vųjį_
  { {0x76430050,0xa06a010f,0xdd380024,0xb6ac000a}},	//   _inny, гава_, kāša, _שׁוֹ
  { {0x320c005c,0xf992000a,0x4f960004,0x62872645}},	//   żdy_, פרן_, брзу, anjo
  { {0x3fcb0074,0xcf250029,0x64440035,0x649d002d}},	// [4c20] ادفی_, يركي, _inii, réit
  { {0x443227ca,0xf41f00f2,0xc2c60086,0xa3d6000b}},	//   _hay_, nnän_, _پيگي, ाँव_
  { {0x61ee1f10,0x52760086,0x5bc60115,0x44321636}},	//   mabl, _ناگز, مقال, _kay_
  { {0xdd8f0806,0xe3bf0077,0x659a004c,0x711b000a}},	//   رون_, leña_, איעק, _גוטפ
  { {0x4432043a,0xa2ce000b,0x3ad30015,0xda7a0ef5}},	//   _may_, _धूम्, كينز, ляк_
  { {0x523a00b2,0x44322652,0xb2ba000a,0xec16002b}},	//   רײַנ, _lay_, אמְר, _گورد
  { {0xdd380024,0x6a1300a2,0x7aed001a,0xfca9002b}},	//   bāša, سبور, áatr, _چاقو_
  { {0xc6f82105,0x4432162b,0x30db004c,0xec160067}},	//   аних_, _nay_, אַזע, _دورد
  { {0xe5c6005e,0x6d5e27cb,0xca760033,0x61ee27cc}},	//   йсно, lypa, _лужы, kabl
  { {0x70b4005d,0xbb3b0053,0x0f57000a,0xa5f80054}},	//   ंगुल, _געמי, ציים_, јену_
  { {0xb9960029,0x4432162b,0x9a3b000a,0x7e9b000a}},	//   _الضب, _bay_, _תתבק, רסיו
  { {0xd4c30033,0x76430034,0x629e01d7,0x443227cd}},	//   ясьп, _enny, _akpo, _cay_
  { {0x47360086,0x443214ea,0x389b000a,0x63050015}},	//   _دراز, _day_, _גיאנ, غوسل
  { {0xa6b60063,0x26b6004a,0x61ee27ce,0x649d0125}},	//   _усещ, _ущер, gabl, téis
  { {0xa6170008,0x4a5b0053,0xf67b000a,0x867b0447}},	//   _הקוד_, נדלו, _תאומ, _גרגו
  { {0x20090007,0x7bc40091,0x41d9000b,0x443227cf}},	//   ugai_, žiuj, _ब्रस, _gay_
  { {0x623527d0,0x61ee27d1,0x200927d2,0xdd38003d}},	// [4c30] _депу, babl, rgai_, vāša
  { {0x649d002d,0x6dc70080,0xf1c70089,0x63ad0024}},	//   péis, ссаж, část_, _izan
  { {0xddab0033,0x44320061,0xdd38003d,0x60190c02}},	//   утал_, _yay_, tāša, _коня_
  { {0xa3fb000b,0xef1f007c,0xac1908f7,0x6e250012}},	//   ्लिप_, _tpü_, роду_, sehb
  { {0xa3ea000b,0x2bcb0065,0xeab10058,0x0000006a}},	//   यरत_, िशबा, وعت_,
  { {0x7a070010,0x388515e5,0xdcf40061,0x388c0046}},	//   сядж, mēri_, _çağl, věra_
  { {0x46ce000b,0x08d40033,0xa925005e,0x27ed27d3}},	//   _हूबह, пцыя, ідил, taen_
  { {0x9c650086,0x317c000a,0xf8ae002b,0xb17c000a}},	//   _بهرو, טרומ, نکن_, טטור
  { {0x61ee0493,0x44320a1a,0x213801c0,0x27ed27d4}},	//   yabl, _ray_, zvrh_, raen_
  { {0x0696003b,0x4432003e,0xb6590268,0xe616007a}},	//   ينية_, _say_, рших_, одь_
  { {0xbc79000a,0x4432162d,0x61ee27d5,0x94260fdc}},	//   ֹנָת, _pay_, vabl, омне
  { {0xccf20053,0x61ee00da,0x290727d6,0x87b915be}},	//   וכט_, wabl, muna_, _култ_
  { {0x6d5e0050,0x44320092,0xd6db120f,0xa3af000b}},	//   zypa, _vay_, _сте_, _करण_
  { {0x11da003b,0x386d03af,0x443227d7,0x95cb27d8}},	//   شورة_, lher_, _way_, _суда_
  { {0x44320023,0x05950086,0x61ee27d9,0x290727da}},	//   _tay_, _باشگ, rabl, nuna_
  { {0xe3bf0467,0x41b50010,0x54730015,0x386d0012}},	//   seña_, ясят, _يهوذ, nher_
  { {0xe7b600b2,0xa0670403,0x61ee0493,0x8fa311fe}},	// [4c40] ַהער_, цата_, pabl, дате
  { {0x290727db,0xbb4a002b,0xa3af0157,0x7e7e008c}},	//   kuna_, یلان_, _करत_, uipp
  { {0xae19005d,0x290727dc,0x8d2a004a,0x7e7e2395}},	//   न्धन_, juna_, роев_, ripp
  { {0xcea901d8,0xc50c004c,0x6d5e0079,0x290727dd}},	//   די_, רלאָ, rypa, duna_
  { {0xc0530008,0x7ff7002b,0x386d007c,0x6d5e2402}},	//   _חזר_, _بسپا, dher_, sypa
  { {0x2907002e,0x6f162631,0x20e80045,0xae19000b}},	//   funa_, mtyc, oşi_, न्दन_
  { {0xed5a0036,0x38c80086,0x63a4003e,0xa96700d0}},	//   _тов_, حاتی_, _lyin, жија_
  { {0x386d003e,0x6f16005c,0x20e80064,0x87e60033}},	//   gher_, otyc, işi_, цюке
  { {0x63a4000c,0x290727de,0x6f1610ec,0xcb6712d2}},	//   _nyin, auna_, ntyc, _дате_
  { {0xda6600e5,0x290727df,0x386d0012,0x6f16002a}},	//   _باري, buna_, aher_, ityc
  { {0x63ad0eba,0x290727e0,0xe598005e,0xfe37000a}},	//   _szan, cuna_, скні_, קרטי_
  { {0x6f16005c,0x386d0043,0x248d016e,0x53470033}},	//   ktyc, cher_, õem_, охга
  { {0x8c1b000a,0x20e80045,0x629c27e1,0xe3b00015}},	//   בוכי, eşi_, foro, َرُ_
  { {0x63a4003e,0x6f160123,0x629c27e2,0xb77b004f}},	//   _dyin, dtyc, goro, _דאדש
  { {0xaffd008b,0xc693000a,0xc0cb27e3,0x0000006a}},	//   ловi, _קאצ_, руге_,
  { {0x200f0020,0x4395042b,0x62800003,0x78fb000a}},	//   ügi_, _найс, émor, יפלו
  { {0x20e80011,0x63ad27e4,0xd46b002b,0x2dcb0054}},	// [4c50] aşi_, _uzan, _محکم_, аћен_
  { {0xe3b00029,0xcddb0001,0xdd950010,0x2ca60026}},	//   _جرى_, рња_, пазы, elod_
  { {0x8fe70015,0x20e80045,0x6f1627e5,0x22b800c3}},	//   _وأحم, cşi_, atyc, _بديع_
  { {0xa3af021e,0x6fda000b,0xc19a000a,0x228d006f}},	//   _करा_, युदं, _לשתי, oľko_
  { {0xd5b10092,0xfe730067,0x7fd6015b,0x5274002b}},	//   hép_, _قدس_, _מורס_, _رایز
  { {0x5ba80010,0x72dc000a,0x539c000a,0x290727e6}},	//   цкім_, סקוג, בידו, tuna_
  { {0x386d0388,0x09f60015,0x6b8d0045,0xa9680015}},	//   ther_, سفية_, _ţigă, يمهم_
  { {0xbd4400e6,0x629c0f19,0x6bd40015,0x290727e7}},	//   _تنفي, zoro, _يتقر, runa_
  { {0x629c000c,0x7eab00dc,0x386d00b8,0x29070567}},	//   yoro, nüpo, rher_, suna_
  { {0x386d27e8,0xafdb00cb,0x36350058,0x290727e9}},	//   sher_, _snøl, سرخس, puna_
  { {0xe9d00002,0x386d02e7,0x64a627ea,0x7eab007c}},	//   _شغل_, pher_, зана, hüpo
  { {0x89340029,0x6f16005c,0xdb000003,0x629c002a}},	//   _زعما, ytyc, _symé, woro
  { {0x87040115,0xd3350033,0x629c27eb,0x96b90cfe}},	//   _قبول, мэры, toro, _луку_
  { {0xf7700074,0x70b4005d,0x2f1400c0,0x629c0a6f}},	//   _جام_, ंग्ल, väg_, uoro
  { {0x7e600011,0x213e002d,0xe5a212d2,0xe6b4002b}},	//   _împi, íth_, _пиши, _تلوگ
  { {0x629c27ec,0xf55a000a,0xefca004a,0xae19000b}},	//   soro, _לדצמ, слал_, न्सन_
  { {0x629c26e4,0xdfa60015,0xaf060033,0xb05b0123}},	// [4c60] poro, سحري, япал, _tiän
  { {0x673b00f2,0x6f16005c,0x38850024,0xa37b007c}},	//   ivuj, rtyc, mēru_, maõp
  { {0x6f160050,0x725b0008,0x6da60015,0x0c26159d}},	//   styc, _הכיפ, أمام, змен
  { {0x3d1c005d,0x9b6a022a,0x6f16157b,0x7eab0061}},	//   _नहीं_, йшла_, ptyc, lüpl
  { {0xcf3a005e,0xac970015,0x2ca627ed,0xfaa627ee}},	//   _учні_, أننا_, rlod_, падо
  { {0xe9940086,0xbb830015,0xe9800033,0x8d66014d}},	//   وهشگ, علوي, калi_, _евге
  { {0x672227ef,0xe467007c,0x0076000a,0x8aa5005e}},	//   _spoj, ööks_, ּתִי_, єрід
  { {0x76580064,0x0d17000a,0x50be000b,0xacfb000a}},	//   _sovy, _מקלט_, ्दिष, _להלכ
  { {0x07f70029,0x6f041d36,0x17f70015,0x7c650067}},	//   سريع_, nric, سرية_, _غافل
  { {0xe6780036,0x60c60024,0x6f04002d,0x442027f0}},	//   ійні_, _likm, iric, _abi_
  { {0x89db000a,0x4796002b,0x7bc90061,0x6f0427f1}},	//   _החבי, _کجاس, şmuş, hric
  { {0x2b20005d,0x60c60375,0x6f0402ad,0x7eab0546}},	//   _यहाँ_, _nikm, kric, eüpl
  { {0xa5f80175,0x883b000a,0x4c9b004c,0xe3bf0077}},	//   _делу_, _לתאו, משטע, reño_
  { {0xe3bf02c1,0xf7bb0008,0xa2c40001,0x8534002b}},	//   seño_, _הזדמ, ељск, _يوشچ
  { {0x38a10125,0xadeb000b,0xe3bf0077,0x6e3527f2}},	//   pórt_, टरसन_, peño_, _razb
  { {0x6e3501cb,0x30a4044a,0x0596002b,0x64a40004}},	//   _sazb, ерув, _واژگ, _паја
  { {0xbfab1292,0x93fc0008,0x3ed90015,0x6d580123}},	// [4c70] стве_, _הלחי, زواج_, ävan
  { {0x442b12d7,0x9df9005e,0x443923d8,0xeeab0033}},	//   lec_, інет_, lds_, ётак_
  { {0x6e350089,0x6f0427f3,0xe3b0002b,0x5ce40033}},	//   _vazb, aric, _لری_, еюча
  { {0xc0ab0031,0x442b0c6d,0x443927f4,0x6f041a2a}},	//   _داخل_, nec_, nds_, bric
  { {0x1a650086,0x443927f5,0x9056000a,0xa01b001a}},	//   ویری_, ids_, _חברו_, _fjör
  { {0x442b0152,0xa01b002e,0x2bb80015,0xbb4227f6}},	//   hec_, _gjör, سانة_, тешк
  { {0x63a8005c,0x0929005e,0xdd9408f0,0x442b013b}},	//   ędni, іжий_, _зары, kec_
  { {0xba770086,0x443927f7,0xf1b4000a,0xf8920004}},	//   _کارت, jds_, עסק_, кајќ
  { {0xfb150015,0xe7390004,0x442000c7,0x5749005e}},	//   _زواج, цеп_, _rbi_, ізом_
  { {0x443927f8,0x7c2b27f9,0x9995002a,0x442001d7}},	//   eds_, legr, ągłe_, _sbi_
  { {0xb5790080,0xe4e40033,0xff5f0034,0x7c39002a}},	//   ющих_, ніўн, _sgîl_, odwr
  { {0x947a005e,0xa99a000a,0x6f040f21,0x7c3927fa}},	//   існу_, _ובער, yric, ndwr
  { {0x087600b2,0xe7380036,0xd3480086,0x386200dc}},	//   _קענט_, _неї_, سیده_, ökre_
  { {0x78a927fb,0x77ba000a,0x78bb007c,0xafdb02de}},	//   llev, _ומנח, lmuv, _unøj
  { {0x3d0c005d,0xc05a03ae,0x26cf03b8,0x6f040079}},	//   _हमें_, орац_, _hugo_, wric
  { {0x38850024,0x61e10064,0xceea006b,0x04950033}},	//   mērs_, ılla, ждае_, _прыў
  { {0x93fb0008,0xaec60180,0x33fb000a,0xadfa0015}},	// [4c80] _ולפי, дбал, _והפנ, قراط_
  { {0x6f0427fc,0x3e640030,0x6fde000b,0x912a006b}},	//   rric, _köti_, _फ्रं, _джоб_
  { {0x6f0404de,0xbd460015,0x60c6003d,0x6cd3012c}},	//   sric, بناي, _tikm, نقلا
  { {0xbb86003b,0x32d400f2,0x50b606b4,0x6f0427fd}},	//   ولاي, _käy_, _існу, pric
  { {0x5bba000b,0xa01b1696,0x78a927fe,0x539b004f}},	//   ेशेव, _tjör, dlev, ֗ינו
  { {0x539b000a,0x0377000a,0x674c004c,0x7c390034}},	//   חינו, ותנת_, _באַקו, adwr
  { {0x44390e13,0x7c2b27ff,0x26cf2800,0x248008e2}},	//   yds_, begr, _augo_, _omim_
  { {0x8b26000d,0x29002801,0x5d7b000a,0xd8b700c3}},	//   _одбе, čia_, _ואלק, وديا_
  { {0x32d400f2,0x38850024,0x442b2802,0x61fe2803}},	//   _näy_, vērt_, vec_, _odpl
  { {0x98ae0064,0x26cf1688,0x7ae22804,0x443900da}},	//   ınır_, _dugo_, mpot, wds_
  { {0x89160029,0x7e600045,0x7ae22805,0x78a92806}},	//   _زبائ, _împu, lpot, blev
  { {0x27ef002e,0x7af60007,0xa3d6000b,0xb7d70015}},	//   _gegn_, šytu, ाँग_, _قوما_
  { {0x26c702d7,0xe29f002e,0x44392807,0x442b1361}},	//   _fino_, erða_, rds_, rec_
  { {0x6d410007,0x7c2b005c,0x78a02808,0x442b02c6}},	//   _šlam, zegr, lomv, sec_
  { {0x6aaa0026,0x6d582809,0x95530015,0x442b0678}},	//   ilff, äval, _لخيا, pec_
  { {0xb4fb000a,0xa937000a,0x7eb0008c,0xa4fb000a}},	//   _ולהר, וטלה_, väpa, _ולהט
  { {0xeb0d005d,0x69da280a,0xceb50054,0x7c2b280b}},	// [4c90] _समेत_, _ofte, ебаћ, vegr
  { {0x32550054,0x8d87002b,0x7eb0008c,0xeeab008b}},	//   _чвор, وشان, täpa, ітак_
  { {0x8c3d0064,0x61f50064,0xfbd30015,0x7ccc0061}},	//   _akşa, mazl, نتش_, _oğru
  { {0x1ddf0372,0x69da03c2,0x91ba0008,0xbb95006b}},	//   _प्रत, _afte, _ממתי, наещ
  { {0xee870010,0x38970045,0xeb8e067a,0x7eb0008c}},	//   _жыво, năre_, уи_, säpa
  { {0xdcfb0074,0xdb1e0030,0xb062014b,0x7c2b280c}},	//   _ورزش_, évág, ääva, segr
  { {0x78a9280d,0x6f0d280e,0x7ae2280f,0xc9840054}},	//   tlev, luac, apot, кући
  { {0x69da2810,0xc5f9005d,0x26c72811,0x78a90201}},	//   _efte, ूल्य_, _sino_, ulev
  { {0xb906000b,0x6f0d2812,0xf7710015,0x26c72813}},	//   _बढ़_, nuac, طاة_, _pino_
  { {0xf6510029,0x5b340086,0xdb260086,0x5eec000a}},	//   ائة_, _جعفر, _سومی, קַחְ
  { {0x27ef0293,0x99870046,0x2f23003d,0x05a90033}},	//   _tegn_, menů_, līgā_, явой_
  { {0xbc190008,0x8c19000a,0x8d5a000a,0xd8770015}},	//   הוֹש, הוֹי, לכתי, _غاضب
  { {0x3ea10005,0x2f230024,0x443e0046,0x69da0123}},	//   koht_, nīgā_, ět_, _yfte
  { {0xd7740225,0x6462005c,0x78f9000a,0x4b7a000a}},	//   _جامع, _świą, ּפּו, לארו
  { {0x71660015,0x602612ae,0x628e2814,0x6acb000b}},	//   راسك, ндва, rnbo, ादुर
  { {0x7afb003f,0x69d800bc,0xc952000a,0x244a0015}},	//   _ovut, zcve, נמן_, _رجعي_
  { {0x2d870077,0x99870046,0xb7bd0045,0x6f0d2756}},	// [4ca0] únen_, kenů_, feţi, guac
  { {0xef1704f7,0x539b000a,0xa2d5000b,0x3377000a}},	//   эму_, _מיפו, _यंत्, _נעים_
  { {0x9f42022d,0x653a0053,0x7afb0824,0x0217000a}},	//   _sekä_, ּענד, _avut, _אחים_
  { {0x59dd000b,0xdee62815,0x7ae22816,0x9cb60369}},	//   नुसर, _поми, tpot, رمشت
  { {0xcb670033,0xcb34006b,0x80d6000b,0x7ae20dba}},	//   наце_, телъ, _मंडे, upot
  { {0x7ae22817,0x7ae40045,0x0000006a,0x0000006a}},	//   rpot, ţito,   ,
  { {0x0903008f,0xdd9200e6,0xc213000a,0x99f5005e}},	//   гчым, _صور_, אהו_, тячі
  { {0x98a30001,0xb9230015,0x9d1b000a,0x6da30054}},	//   лије, افيي, _מולט, _сиса
  { {0x2f230024,0x57b4006b,0x61f50061,0x78a003c1}},	//   cīgā_, ъбит, yazl, romv
  { {0x9b930029,0xff7b0008,0x7f3b0053,0x8afb0008}},	//   _إلكت, פטימ, לעפו, _מהמי
  { {0xf76f0086,0xc58a0080,0x65942818,0xddce003d}},	//   لای_, ящие_, тану, _albū
  { {0x7ccc0061,0x38970045,0xe8d7004f,0x0000006a}},	//   _uğru, tăre_, _נודר_,
  { {0x291c00dc,0xae10000b,0x7eb00123,0x93f40033}},	//   ltva_, ालान_, väpn, ыпяц
  { {0xc2c5003b,0x0737000a,0xab4b004f,0x4614009a}},	//   ئيسي, _נאום_, הֲלֻ, _شوبر
  { {0x291c00dc,0xe29f002e,0xe4a711d9,0x6440016e}},	//   ntva_, nuði_, _прио, ômic
  { {0xd498008f,0xd92b000a,0x43850015,0xe58b000a}},	//   _пры_, הֵמָ, _للعق, _מָחָ
  { {0x9e070063,0xddeb0015,0x644d173e,0x5f740015}},	// [4cb0] ечел, كراه_, _inai, هاكر
  { {0x9f040029,0x6f0d0125,0x290e0573,0x03180015}},	//   اولو, ruac, kufa_, _أتيت_
  { {0x3eaf0024,0xa3d6005d,0xb7bd0011,0xdd910015}},	//   ēgt_, ाँच_, reţi, جوا_
  { {0xfbd00029,0x6fb50015,0xa156000a,0xf36b000a}},	//   مته_, _لمجا, _סברה_, ּדַּ
  { {0xab9b0015,0x4ca80015,0xe9ce0499,0x6f0d2819}},	//   أخضر_, رُهُ_, ик_, quac
  { {0x628700df,0xab640033,0x2f23003d,0x218b000a}},	//   nijo, ывіл, rīgā_, ּאֵ֣
  { {0x3238000a,0xc212000a,0x99320015,0xaffb000a}},	//   גטון_, ׁ֔ה_, لفوت, ִּ֗י
  { {0x7e600011,0x6bd40029,0x6287281a,0x2f2301ec}},	//   _împr, _متكر, hijo, pīgā_
  { {0x7eab0064,0x2ba8005d,0x5b1502e1,0x628709e2}},	//   tüph, _छुपा, _шмат, kijo
  { {0x7bd20024,0x7c3b281b,0x644d281c,0xada2006f}},	//   ājuš, _haur, _anai, čúva
  { {0x62870963,0xddd5002a,0xceb2000a,0x3e64001a}},	//   dijo, _kozł, שיי_, _götu_
  { {0x644d002f,0xddce0089,0x44240264,0xa988000a}},	//   _cnai, _dobř, ým_, _אָנִ
  { {0x987a00b2,0xe7390549,0xe7c0000b,0x3e640123}},	//   _קאנט, _цел_, शेदप, _kött_
  { {0x3e6400dc,0x628700f0,0x412a034e,0xd2520115}},	//   _jött_, gijo, мого_, جنس_
  { {0xc6160008,0x7fd6022a,0x3c420030,0x21a6012e}},	//   _יחסי_, візі, lévő_, тивм
  { {0xc003000d,0x7056002b,0x7c3b281d,0xc4d2004f}},	//   ипск, خنرا, _naur, _דגה_
  { {0x98450048,0xb4ae005d,0x291c0030,0x6287281e}},	// [4cc0] dēļ_, कती_, ztva_, bijo
  { {0x6287281f,0x6aa3003c,0x752f002a,0x5d6a004a}},	//   cijo, jonf, łczu, мизм_
  { {0x7c3b2820,0x7eb0005b,0x7e63005b,0x0000006a}},	//   _baur, säpo, önpa,
  { {0x7c3b2821,0x6faa0015,0xb509000b,0x9b8a00c3}},	//   _caur, _يهدف_, _विनय_, ونال_
  { {0x7c3b0781,0x6aa301ee,0xaefa0058,0x6a6f01d0}},	//   _daur, fonf, _ترجئ_, _søfa
  { {0x8ad50010,0xc333000a,0xcb670054,0xe189002b}},	//   уюцц, יוד_, ђаје_, _آئین_
  { {0x89130015,0x6e3c0045,0x3e640123,0x99130015}},	//   لبيئ, _iarb, _dött_, لبيض
  { {0xf41f00f2,0x291c00dc,0x290e2822,0x62872823}},	//   nnät_, rtva_, rufa_, zijo
  { {0x8c1b0008,0x291c2824,0x18330015,0xeac60033}},	//   _קומי, stva_, شريح, _абап
  { {0x09ba0029,0xddce0089,0x6aa32825,0x7c3b002a}},	//   _قطاع_, _pobř, conf, _zaur
  { {0xa96a0074,0xb7bd0011,0xca750010,0x24f80033}},	//   _تمام_, deţu, _суты, энны_
  { {0x2cfb00b2,0xb97b01ac,0x4917000a,0x897b004c}},	//   ולטא, _קנאי, _יקבל_, _קראצ
  { {0x63b60050,0x62871a91,0x6753002b,0x764d0030}},	//   _czyn, tijo, _نخور, ányí
  { {0x86730036,0x644d0026,0x38970045,0x3e640123}},	//   _кліє, _wnai, măra_, _möts_
  { {0x236d032c,0x62870944,0x9f4b002c,0x7c222826}},	//   šej_, rijo, _vecí_, kfor
  { {0x644d06e8,0x6557000a,0x8557000a,0x493b000a}},	//   _unai, _יבוא_, _ישוב_, וגלו
  { {0xdef803be,0xddd5005c,0x62870963,0xc0c80760}},	// [4cd0] вых_, _rozł, pijo, туре_
  { {0xb0620020,0x6ce70036,0x388c0046,0x765c008c}},	//   äära, віде, měru_, öryh
  { {0x6e3c2827,0x7c222828,0x5bcb000b,0x7c3b02b9}},	//   _darb, ffor, िश्व, _paur
  { {0xd577000a,0x6e3c0012,0x7d08001a,0x7188000a}},	//   כתבה_, _earb, _sérð, _יְרַ
  { {0x6e3c2829,0x7c3b282a,0x547c004f,0x0000006a}},	//   _farb, _vaur, וטאו,
  { {0xddde0045,0x6e3c282b,0xb0d2000b,0x752a0012}},	//   ripţ, _garb, _दूँग, _opfz
  { {0x7bd8003d,0x7c22282c,0x7c3b282d,0xdb0001c0}},	//   _šauš, bfor, _taur, _vymá
  { {0xf8a90086,0x6d4700f2,0xe946002b,0xc984005e}},	//   رگاه_, _irja, اروی, шучи
  { {0x62850111,0x7c8403e7,0xcb34006b,0xab2b0015}},	//   _omho, _туре, _кетъ, _تسأل_
  { {0xbf5a004f,0xdb0001d0,0x0000006a,0x0000006a}},	//   ׂ֣ית, _bymæ,   ,
  { {0x63ad0152,0x1994006b,0x4e36004c,0x3c75000a}},	//   _ayan, _кафя, אָכן_, ָתָם_
  { {0xf2c900b2,0xb4ae005d,0x62850026,0x9476002b}},	//   _זע_, कते_, _amho, اددا
  { {0xd7f8022a,0x57fa000a,0x63ad1419,0x389700d4}},	//   _рух_, _נלסו, _cyan, căra_
  { {0xd2950191,0x45450087,0xe29f002e,0x78750046}},	//   арсь, _منتق, kuðu_, _dáve
  { {0x50960001,0xb7bd0045,0xb8820046,0x2d87002a}},	//   грађ, reţu, _šíit, źnej_
  { {0x388c0089,0x9e66002b,0x14d6004c,0x386d153c}},	//   běru_, گارن, _גוקל_, nker_
  { {0x386d09f2,0xdfa50015,0x6d47282e,0x6e3c282f}},	// [4ce0] iker_, لحكي, _arja, _parb
  { {0x9e660086,0x44f1044c,0xa01b001a,0x7c222830}},	//   دارن, oš_, _umön, wfor
  { {0x85f60053,0x7875002c,0x386d2831,0x5d860015}},	//   רמעס_, _záve, kker_, دلال
  { {0x386d0111,0xeb9a058b,0x0137000a,0xbf9b016e}},	//   jker_, ние_, _ערכת_, _idên
  { {0x6e3c2832,0x62850026,0x4dd60067,0x7c222833}},	//   _tarb, _ymho, _متأس, rfor
  { {0xbb470015,0x44f12647,0x8b080046,0x386d2834}},	//   الون_, kš_, epřá, eker_
  { {0x14cf0231,0xe9df0016,0x7c222835,0xa92600c3}},	//   _संगण, _đút_, pfor, اعته
  { {0x63a90050,0x8d930015,0x98a7002a,0xc173000a}},	//   żeni, _الفش, ywną_, מחו_
  { {0x44f100df,0x6a160225,0xf7940033,0xeb9701e1}},	//   eš_, _مبار, рапэ, _бит_
  { {0x388c0089,0x35f4005e,0x386d2836,0x2ca62837}},	//   věru_, шпор, aker_, lood_
  { {0x38ba00dd,0xf1a4000b,0xf485002b,0xd5b00015}},	//   eëre_, _खुलन, لاحی, تفد_
  { {0x386d2838,0x399b000a,0x43750015,0x2ca62839}},	//   cker_, _איבד, لهجر, nood_
  { {0x657a0014,0x44f101a3,0xf20701f3,0x6d41283a}},	//   szth, aš_, ляво, _álav
  { {0x2ca6003e,0x63ad0297,0x99850091,0x05760058}},	//   hood_, _vyan, _galų_, _ماعد
  { {0x2ca60020,0xf494002b,0xe5f7000a,0xe9ce0033}},	//   kood_, _گشود, _גזור_, окi_
  { {0xdd010024,0xb5a5005e,0xd01800af,0x0000006a}},	//   ūtīt, _трій, лфу_,
  { {0x14b80029,0x26ce003f,0x44290253,0x2098054f}},	// [4cf0] _حدوث_, _kifo_, _iba_, укты_
  { {0xdd9b0036,0x11d90029,0xe29f002e,0x645d00cb}},	//   нше_, _جودة_, tuðu_, ljsi
  { {0xbc190484,0x261c000b,0x61da000a,0x2ca6283b}},	//   вілі_, _मानी_, _בקתד, food_
  { {0x6dc4004a,0xab620061,0xe29f001a,0x26ce00e7}},	//   ссуж, ğünl, ruðu_, _lifo_
  { {0x447c0053,0x4429283c,0x6ffa000a,0xef67006b}},	//   ענדע, _mba_, _שהשפ, _съно
  { {0xcb66198b,0x89350015,0x7dd20030,0xe29f001a}},	//   раше_, لعبا, rűsí, puðu_
  { {0xe509005d,0xfe9a0008,0xc175000a,0xcda90067}},	//   _विधि_, _יישמ, יחַ_, _شهره_
  { {0x6f0d0b1b,0x7c87049d,0xf8650004,0x3158000a}},	//   orac, _суге, рвио, ריהן_
  { {0x37750010,0x4ffa000a,0x6f0d283d,0xa3e9000b}},	//   рыйс, כִינ, nrac, यडन_
  { {0x386d0293,0xa52514dd,0x4429283e,0x6f0d0bbc}},	//   sker_, амод, _aba_, irac
  { {0x6f0d283f,0x44f10085,0xc9841adc,0x9e48004f}},	//   hrac, uš_, _луци, אֲרִ
  { {0x60cf0089,0x895a000a,0x99640033,0x44f10b46}},	//   _nicm, _בדעת, _утул, rš_
  { {0x27ed2840,0xf41f0123,0xe3b200c3,0x43930033}},	//   mben_, tnär_, ترد_, жаўс
  { {0x60cf002d,0x94760086,0x27ed2841,0xb77a000a}},	//   _aicm, ادگا, lben_, _באנש
  { {0x7c292842,0x045a0015,0x05770015,0x6ff6006b}},	//   _ober, _للغة_, _حاشد, ичах
  { {0x27ed00dc,0x3fe62843,0x62950486,0xd012006e}},	//   nben_, ржав, anzo, تلر_
  { {0x7eb000f2,0xf4870086,0x27ed11e2,0xc43b000a}},	// [4d00] läpi, _خاوی, iben_, _יתקי
  { {0x7e970029,0x7c292844,0x2ca60574,0x02fb000a}},	//   لنقر_, _aber, wood_, _שלימ
  { {0x27ed0014,0x2ca6003e,0x6be60029,0x76410034}},	//   kben_, tood_, لكام, idly
  { {0x61fc2845,0x4ae60033,0x6f0d0b9d,0x219b000a}},	//   larl, аўка, brac, _יביא
  { {0x612c00dc,0xa01b0123,0x27ed0030,0x6d430123}},	//   _fölö, _omöj, dben_, ånar
  { {0x27ed018b,0x93b70008,0x60c40e95,0x3218082f}},	//   eben_, בלנו_, lmim, ngry_
  { {0xfa6700d0,0xa81a0015,0x8933002b,0x2ca6007c}},	//   рајк_, نتظر_, قعيا, pood_
  { {0x91790023,0xec160086,0x31570053,0x27ed00dc}},	//   _hợp_, _خورد, שיקן_, gben_
  { {0xc6f7008f,0x98be0011,0x9873008b,0x61fc2846}},	//   аных_, _artă_, ільц, karl
  { {0xa3bd005d,0x27ed00b8,0xa9f8000a,0xcdd1000a}},	//   _अरब_, aben_, _תִּת, ּ֚י_
  { {0xa9a60036,0x27ed2716,0xda7b000a,0x58060015}},	//   _тижд, bben_, _שנבר, _نواك
  { {0x6f0d0026,0x34950010,0x61ee2847,0x68ea0012}},	//   yrac, самр, ebbl, mpfd
  { {0xec7100b2,0x47360086,0xa3b3000b,0x443f006f}},	//   פֿט_, _خراز, ढ़ें_, ľu_
  { {0x7875002d,0x7d030057,0x60c40375,0x443f2848}},	//   _iáva, ánsk, emim, žu_
  { {0xb6bb0008,0x6f0d005c,0x76bb0008,0xa294005e}},	//   _שצוי, wrac, _שמופ, царі
  { {0x44a4003b,0x38a10050,0x6f0d21fe,0x61ee0d16}},	//   _وموق, wórz_, trac, abbl
  { {0xe2ab00e5,0x5fa7000b,0x6f0d2849,0x6fb9029f}},	// [4d10] _لادن_, _कुशल, urac, угар_
  { {0x27ed0014,0x7e540036,0xe45f00c0,0x6f0d0541}},	//   zben_, овує, ljö_, rrac
  { {0xcdd80054,0xdbf70015,0x27ed166c,0x6f0d284a}},	//   рњу_, لأشع, yben_, srac
  { {0x3b550010,0x88bc0089,0xa13600f3,0x70550021}},	//   йкер, _zpěv, _פארק_, _انحا
  { {0x00560008,0x7c290012,0xe29f001a,0x27ed0030}},	//   _השרת_, _vber, erði_, vben_
  { {0x533800b2,0x7f3a0053,0x1bb80015,0x7dc70015}},	//   ינדן_, _געשו, جامع_, _نتأك
  { {0x27ed0014,0xaa560001,0xdd940033,0xdea4002b}},	//   tben_, сију_, _дары, _بیلی
  { {0x27ed00b8,0xd1980008,0x61fc2459,0xadbc0033}},	//   uben_, יכוי_, zarl, _расi
  { {0xbb85003b,0x61fc0064,0x27ed284b,0x3c440015}},	//   _الذي, yarl, rben_, _بَقِ
  { {0x27ed0014,0x6d4100dc,0x78750057,0x6a17002b}},	//   sben_, _álas, _dáva, _خبرر
  { {0xb6580010,0x36940010,0x8883002b,0x0446004a}},	//   ршых_, ўшыс, _ویتن, бенн
  { {0x25450048,0xb4c4000b,0x3e76001a,0x753d002a}},	//   _vēl_, ौदे_, _mæta_, łszo
  { {0xd36f0029,0xb7d20029,0x888a0053,0xb7da0053}},	//   ّهُ_, _عقوب, _גרײַ, _עקסי
  { {0xdb060030,0x61ee284c,0x91e30bc0,0x78a9005a}},	//   ímén, ubbl, зоре, loev
  { {0x55f60008,0x95c80001,0x787501b2,0x25aa0057}},	//   _המצב_, _кућа_, _záva, čilé_
  { {0x38a1005c,0x349300d7,0xdfd20015,0x64a3005e}},	//   tóry_, _најр, سيط_, _наща
  { {0xceea0010,0x63a912b3,0x3d1a000b,0x61fc284d}},	// [4d20] удзе_, üent, मूने_, parl
  { {0x3e760084,0xc7b20135,0xe29f001a,0x290e0034}},	//   _bæta_, לבן_, yrði_, yrfa_
  { {0xb5fa0053,0xa0a604f7,0x6da60015,0x26c50034}},	//   רלעכ, _ганд, حمام, imlo_
  { {0xab620064,0x8c950036,0x31570053,0x628e284e}},	//   şüml, орчі, _היטן_, libo
  { {0x78a9284f,0x804b004f,0x441b004f,0x999c01d3}},	//   doev, _עֲטֶ, רונס, vevő_
  { {0x2ce80086,0x42db0053,0x2613000b,0xdee30785}},	//   _نظری_, אקסע, _दागी_, _хори
  { {0xb509005d,0x88bc0089,0x3e76001a,0x999c0030}},	//   _विषय_, _opět, _gæta_, tevő_
  { {0x7c960029,0xf98f0029,0x08f70015,0xcd97000a}},	//   _الرص, عبو_, حروب_, _הדלת_
  { {0x6b630010,0xe819005d,0x628e0410,0x1ddc000b}},	//   _екта, _धारा_, kibo, _बलात
  { {0x8c440011,0xda650115,0x16d70015,0x0000006a}},	//   ăşur, _والي, حذية_,
  { {0x499a0063,0x44990036,0x915f0092,0xa96a0087}},	//   _стая_, ивою_, _mặt_, _حمام_
  { {0x23e4005e,0x7d030077,0xd8d7000a,0x7eab007c}},	//   зірв, ánsi, _הואט_, hüpp
  { {0x7eb0008c,0x938b098a,0xb0db0065,0x628e02dc}},	//   läpu, усна_, _मंहग, fibo
  { {0x171b0053,0x07370008,0x38660547,0x23bd000b}},	//   _עווע, _לאדם_, _hoor_, ोधबद
  { {0x54e60806,0x9f5900aa,0x3866053a,0x65932331}},	//   _استق, _gesê_, _koor_, _нашу
  { {0x76020089,0x43952850,0x6aaa2851,0x8597004f}},	//   bízí, _майс, hoff, _לדוג_
  { {0x1eab0015,0x2f190033,0x9df90c5b,0x867a000a}},	// [4d30] هائي_, розь_, инат_, ְר֣ו
  { {0x88bc0089,0x7415002b,0x628e2852,0x3d95004a}},	//   _zpět, _اوکا, cibo, оизр
  { {0x6d3500e6,0xbfd50015,0x6aaa0034,0xa50b000a}},	//   تفاض, _ويدع, doff, ָּבִ
  { {0x38662853,0x351b000a,0xa4bb000a,0xf3ff059d}},	//   _noor_, רואנ, נֶ֑י, naã_
  { {0xbca40029,0x629a0227,0x501a00a3,0x6d580309}},	//   أمني, čtov, _דורו, ävar
  { {0x1318000a,0x8de50015,0xe9390015,0x0f56000a}},	//   מחדל_, _ذكره, لسبت_, _וישם_
  { {0xbd450086,0x4879085d,0xeab0012c,0x787501c0}},	//   _بنزي, исия_, رعه_, _dávn
  { {0xd7092854,0x201b042f,0x2cbf01d7,0xa6e512fd}},	//   ание_, ngqi_, _uhud_, ожил
  { {0x8699000d,0x386605d6,0xa3e0000b,0xe611002b}},	//   итот_, _door_, _तलब_, وشد_
  { {0x78a4016f,0x78a9055e,0x70b5000b,0xeb980015}},	//   čiva, soev, ंतुल, _اضفت_
  { {0xad51005e,0xb9950015,0xe9d00058,0xa594009b}},	//   здiл, _بلاب, _كغم_, зрящ
  { {0x9d1a0053,0xc356006b,0x3755002b,0xa34a18fc}},	//   סורט, оъгъ, _وپاس, азма_
  { {0x628e00b6,0xcc3a0053,0x63ba005c,0x28df000b}},	//   tibo, בערט, ętno, _पंडि
  { {0x479a0053,0x7d020024,0x7d0000dc,0xf7480015}},	//   _דינס, ņosi, _járá, _دلهي_
  { {0x764300d9,0x628e2855,0xc0e305c0,0x6e372856}},	//   _iany, ribo, доск, dexb
  { {0x7ae92857,0x7643013c,0xa2d5000b,0x60310046}},	//   _otet, _hany, _यूक्, _němč
  { {0x764300b6,0x9e660036,0x442023a5,0xae1e000b}},	// [4d40] _kany, овад, _ici_, _पादन_
  { {0xaec30036,0x27ff00f2,0x3f802858,0x644400aa}},	//   дбул, haun_, rziu_, _haii
  { {0xdd8f0021,0x78750057,0x27ff01c2,0x76432859}},	//   نوك_, _návo, kaun_, _many
  { {0x61430089,0xf220000b,0x7cd702a3,0x91bb000a}},	//   sílá, _बाड़_, імір_, _כמיי
  { {0x64440035,0xe29f002e,0x6aaa285a,0xeb360021}},	//   _maii, arðu_, toff, تراخ
  { {0xfe790033,0x115a000a,0x7643285b,0x6f040ba4}},	//   _лёсы_, ֹדֵע, _nany, msic
  { {0x27140092,0x386604d0,0x673b01c2,0x1d071f8c}},	//   òng_, _poor_, ewuj, _мери_
  { {0x58d30063,0x6444166f,0xc6f80809,0x44200061}},	//   мощт, _naii, бних_, _nci_
  { {0x38661c15,0xf220005d,0x787c00dc,0x7643013c}},	//   _voor_, _बाढ़_, _néve, _bany
  { {0x0f570008,0xf76f0029,0x6456003f,0x63ab02de}},	//   קיים_, ضاً_, _anyi, _øgni
  { {0x2fc700a7,0x7643285c,0x6f040012,0x80d6000b}},	//   ̀ng_, _dany, hsic, _मंगे
  { {0xb4b5005d,0x3ce50030,0x7d000030,0x493b000a}},	//   झते_, _élve_, _zárá, _כגבו
  { {0x78750107,0x764326cc,0xfbca000b,0x926b006b}},	//   _závo, _fany, िधिम, арва_
  { {0x787c038d,0xcb130008,0x7643285d,0x2499002b}},	//   _déve, ולש_, _gany, _گنبد_
  { {0x20670001,0x867b000a,0x8978000a,0x9148004a}},	//   ођав, _דרגו, זָּה, очта_
  { {0xa2bb014e,0x6f040012,0xf8ca0065,0x93f502ed}},	//   _शीर्, fsic, ागिय, _эпиц
  { {0xcddb25ca,0x2fcf00c0,0xfe750004,0xa3f8000a}},	// [4d50] ање_, ägg_, плаќ, _ומחק_
  { {0x27140092,0x2ee6002d,0xc334000f,0x4439285e}},	//   àng_, íofa_, _חוץ_, les_
  { {0x7ae9285f,0x44392860,0x6b820012,0xeca70004}},	//   _stet, oes_, ezog, ојдн
  { {0x6f040012,0xb1140033,0x673b002a,0x2b4d1b23}},	//   bsic, _ўмяш, ywuj, _prec_
  { {0x09e52073,0x6d4e2861,0xfbd00115,0x78750030}},	//   полн, _erba, نته_, _sávo
  { {0x38970011,0x27e60026,0x44390043,0x27ff0034}},	//   mări_, _afon_, hes_, waun_
  { {0xc27c013a,0xceb2000a,0x010b000a,0x38970045}},	//   שרוי, _ניל_, ׁלַּ, lări_
  { {0x44392862,0xdb3b002b,0x2b4d1cb6,0xa765005e}},	//   jes_, _پسرش_, _trec_, зкид
  { {0x7643003f,0x38970011,0xaa0b0015,0x9be40033}},	//   _pany, nări_, _نزال_, _ціск
  { {0x787500dc,0x1b780029,0x787c0152,0xba7700e6}},	//   _távo, _بصفة_, _réve, _بارت
  { {0x649f0089,0x3a3a0020,0x261c000b,0xd8770015}},	//   zšiř, õppe_, _मारी_, _واصب
  { {0x644b0084,0x32cf005c,0x19ba0008,0x7643003f}},	//   _ógil, _użyj_, _המעב, _wany
  { {0xe72e008f,0xb7da0008,0x6496002c,0xd7580015}},	//   _яе_, _הקני, jšie, _وجها_
  { {0x11da0029,0xb6cc0064,0xe4d60086,0x44391349}},	//   صورة_, şürü, _کويت_, aes_
  { {0x15fa0008,0x09b50053,0x45fa000a,0x95cb004a}},	//   _ההצע, לפֿט_, _ההצג, _туда_
  { {0x53a6009e,0x27140092,0x443916c8,0x787c10e5}},	//   _найб, ùng_, ces_, _téve
  { {0x27fd0b7c,0x38970011,0x441b0008,0x1ee8002b}},	// [4d60] _mewn_, gări_, _הופס, زوای_
  { {0x59cb005d,0x6f042863,0x66011482,0xada60190}},	//   ाधार, rsic, nalk, пазл
  { {0x44e100dc,0x61fe0024,0x61db000a,0x9be6005e}},	//   _jó_, _iepl, _לקיד, пілк
  { {0x44e1002f,0x389704f9,0xcea9000a,0x6b820012}},	//   _mó_, bări_, אי_, tzog
  { {0x389704f9,0x44e1002d,0x66012864,0x261c000b}},	//   cări_, _ló_, kalk, _माली_
  { {0x63b600f2,0x6b8200b8,0xfbd0000b,0xeb070015}},	//   _myyn, rzog, _तृणम, أقوى_
  { {0x44e12865,0xa967050e,0x38c80086,0xbad50010}},	//   _nó_, зија_, يابی_, фіцы
  { {0xd90d0086,0x7ceb000a,0x44390f4b,0x387f2866}},	//   شیه_, _לַמֶ, xes_, ghur_
  { {0x76aa005f,0x6beb0008,0x44390c90,0x9b930015}},	//   йтов_, _הַבַ, ves_, _كلفت
  { {0xe72f00a2,0x4b7b000f,0x61fe2867,0xdb7b000a}},	//   اصي_, _האמו, _nepl, _הנמכ
  { {0x44e100a7,0x27fd0176,0x38970011,0x44390f4b}},	//   _có_, _fewn_, zări_, tes_
  { {0x1bf5014e,0x44e1002d,0x66010020,0x387f002d}},	//   आरएल_, _dó_, aalk, chur_
  { {0x61fe0409,0x66010009,0x23c7000b,0x7792002b}},	//   _bepl, balk, रेंद, _سیدا
  { {0x7c39002a,0x44e10125,0x175705bd,0x6496006f}},	//   zewr, _fó_, _מסדר_, všie
  { {0xa5d70087,0x44e1002d,0x44392868,0x76480034}},	//   _عبور_, _gó_, pes_, mddy
  { {0x389704f9,0xb97b0053,0x759b000a,0x859b000a}},	//   tări_, זנלי, _לסוג, _לשוו
  { {0xe2aa0086,0xe81d000b,0x9f34005e,0xbed805aa}},	// [4d70] _ژاپن_, फलता_, неті, здух_
  { {0xdcfc01e2,0x1bf5005d,0x38970011,0x76480026}},	//   _ayrı, आरऍल_, rări_, nddy
  { {0x38970011,0xfd390015,0x76480034,0x41c10065}},	//   sări_, تكاب_, iddy, _एरिस
  { {0x254c0089,0x69da1869,0x7c2b0012,0x38970045}},	//   _měl_, _agte, ufgr, pări_
  { {0xdb1b0092,0xfebb0086,0x2e4b006b,0xed60003d}},	//   _nguô, _هاست_, _ляво_, āžas_
  { {0x649604b2,0x27fd01f9,0x0000006a,0x0000006a}},	//   ošic, _sewn_,   ,
  { {0x66012869,0x69440015,0x3c95004a,0x6d340de9}},	//   valk, فضيل, _живё, _перф
  { {0x3158013a,0x69da020a,0x44e1002d,0xdcb10015}},	//   ליון_, _egte, _ró_, _شىء_
  { {0x44e1242e,0x6601286a,0x2edb0065,0x373900ce}},	//   _só_, talk, _बढोत, ічию_
  { {0xf1c0006f,0x76480034,0x7eb004f8,0xa01b1696}},	//   úšku_, gddy, näpp, _flög
  { {0x8ca4005d,0x58b80086,0x61fe286b,0xe579022a}},	//   _कदमो, _کالج_, _repl, ізм_
  { {0x63b6022d,0xc2090dab,0x69c1286c,0x629c0026}},	//   _pyyn, _כה_, _izle, wnro
  { {0x6601022d,0xe509005d,0xb05b00b8,0xae1e021e}},	//   palk, _विकि_, _phän, _पालन_
  { {0x36c4005e,0xa6c90015,0x6729002a,0x44e1286d}},	//   _збіг, _بوتل_, mtej, _tó_
  { {0xa116002b,0xc5080015,0xd5bb0b1e,0xafe60e40}},	//   ظورت, _فتيل_, _усд_, добл
  { {0x63b600f2,0xb4fa0447,0x34fa000a,0xa0b50054}},	//   _tyyn, _ולקר, _והקד, ељуј
  { {0xe4c70074,0xdfcf06e4,0xc1780007,0x61fe0107}},	// [4d80] _تصوی, ليف_, šė_, _tepl
  { {0x80be000b,0xb8810046,0x93250015,0xaae1000b}},	//   _वीरे, _šíle, _أرين, _पढ़क
  { {0xa06a0124,0xf2d30008,0x90460002,0xc10600e5}},	//   _дана_, _שעת_, _قنده, _توجي
  { {0x29070123,0x7875013f,0x6729286e,0x0000006a}},	//   dsna_, _dávk, ktej,
  { {0x7c650029,0x76480026,0x6b560015,0xaa580054}},	//   عامل, yddy, بضائ, зилу_
  { {0x752f005c,0x9f400107,0x8f8b000a,0x7afb002a}},	//   łczy, ncií_, _וְלֵ, _dwut
  { {0x29070123,0xa01b0123,0x6729286f,0x4432002a}},	//   gsna_, _flöd, etej, _oby_
  { {0xa3ae000b,0xac7a0015,0xb07b004c,0x807b004c}},	//   कथा_, _بمرض_, ַניז, ַניצ
  { {0x6f160026,0x17f70029,0x9f4001c9,0xba260054}},	//   nryc, ذرية_, kcií_, _одак
  { {0xb95a0029,0x09360015,0x44f4005e,0x44320a90}},	//   _وجاء_, _يراج, нпос, _aby_
  { {0xc58a0080,0x6d5a0030,0x6f160034,0xdddc003d}},	//   ющие_, _átad, hryc, _torņ
  { {0x6f16005c,0x7ae0003f,0x291c007c,0x9b4b002a}},	//   kryc, _kumt, muva_, ółgł
  { {0xbb3b0053,0x291c2870,0x6f160247,0xf8a90015}},	//   ֿעלי, luva_, jryc, _عدمه_
  { {0xeb910053,0xf7d700f3,0x6f162871,0x254c0046}},	//   אָל_, _חודש_, dryc, _těl_
  { {0x34950010,0x403504e0,0x306b0180,0x7792002b}},	//   _пакр, невс, ојан_, _سیگا
  { {0x54a70015,0xe7480016,0xc94b000a,0x30a400ce}},	//   _تحتف, _kỵ_, חֲמֹ, врув
  { {0x2bd0005d,0x93fc000a,0xc3fc000a,0xdd91002b}},	// [4d90] तेमा, _ולחי, _ולחש, گوا_
  { {0x752f0050,0x645a0024,0x291c0604,0xa41f000b}},	//   ńcze, ētie, kuva_, _भाँप_
  { {0xdd910029,0x7eb000c0,0x6ce4005e,0x291c014b}},	//   دوا_, räpp, віче, juva_
  { {0x711a000a,0x6f16002a,0x62952872,0x291c2873}},	//   _צורפ, bryc, lizo, duva_
  { {0x7ae0002d,0x5fa7000b,0x69c1002a,0xa01b0052}},	//   _cumt, _कुचल, _szle, _fmör
  { {0x539c0008,0x4efa000a,0x60cd2874,0x388c0046}},	//   חידו, _מהשו, lmam, měry_
  { {0x63ba005c,0x291c0024,0x08d500a4,0xba740015}},	//   ętni, guva_, нция, خانت
  { {0x60cd01e2,0x67290ce1,0x9b890015,0x62952875}},	//   nmam, ttej, _فنزل_, hizo
  { {0xb906005d,0x6295003f,0x60cd2876,0x29072877}},	//   _यू_, kizo, imam, ssna_
  { {0x443200e8,0x7a540029,0x47c20033,0x67292878}},	//   _sby_, _لضما, ыбыв, rtej
  { {0xceb200a3,0xc867006b,0x67292879,0x60cd287a}},	//   ריי_, _отди, stej, kmam
  { {0x44240064,0x58f6000a,0xb867002b,0x60cd006f}},	//   üm_, _נמנע_, _تائو, jmam
  { {0x78bb0057,0x8c1a000a,0x97250015,0xd8740067}},	//   mluv, הורי, _أفتو, _جالب
  { {0x43750036,0x6295287b,0xe5a509ba,0x68e1287c}},	//   туют, gizo, _пили, _kuld
  { {0xe6b40086,0xa5640029,0x1daf000b,0x1a9a004c}},	//   _جلوگ, _لدين, _जुलत, לישע
  { {0x60cd0035,0x6f16287d,0x63060015,0xa01b0123}},	//   gmam, tryc, _كوبل, _smör
  { {0x91e60f22,0xaec6049d,0x13a8002b,0x1fa706a6}},	// [4da0] _попе, ебал, _زندی_, екти_
  { {0x6e460074,0x7a330064,0x1ea90029,0xc333000a}},	//   عنام, nıtı, والي_, _עות_
  { {0xe2a90029,0xbd8a0015,0x6d5a10fa,0x51fb004f}},	//   _تاين_, أخذك_, _štab, _מהיצ
  { {0x388c0046,0x4422287e,0x4c860033,0xa01b0030}},	//   běry_, ngk_, элев, _elöb
  { {0x8b660029,0xc4d3004c,0x539b000a,0xbfd60058}},	//   عاصم, אגא_, ֔ינו, _سيسع
  { {0x68e10064,0xba170015,0x1994287f,0x531b000a}},	//   _buld, فيها_, каля, פוצצ
  { {0xa3d0005d,0x313a0053,0x78750057,0x200201d7}},	//   वेत_, לײַב, _závi, _keki_
  { {0x291c012d,0xb509000b,0x6d0b000a,0x98160015}},	//   ruva_, _विजय_, _מִמַ, ربعا
  { {0x86260010,0x9f402880,0x291c007c,0x7d1e2881}},	//   ньне, ncià_, suva_, lups
  { {0x68e100fb,0x2002002a,0xdb00002a,0x7a330061}},	//   _fuld, _leki_, _wymó, gıtı
  { {0x75d4002b,0x68e12882,0xe4e302a3,0x62952883}},	//   ضيحا, _guld, ліян, vizo
  { {0x20022884,0x6295002a,0xe7480016,0x38cb002b}},	//   _neki_, wizo, _tỵ_, _فانی_
  { {0x7def0030,0x62950480,0x64960091,0x7c22007f}},	//   nősü, tizo, ušia, igor
  { {0x752b00dc,0xa6c80015,0x4b7b000a,0x388c0046}},	//   élzá, _غوغل_, לאכו, věry_
  { {0x3e760084,0x60cd0064,0x8934000a,0xc177012c}},	//   _gæti_, tmam, כָּא_, ردست
  { {0x6295003f,0x25bb000a,0x60cd02f2,0x045b00c3}},	//   sizo, _מצומ, umam, _رجعت_
  { {0x20020064,0xa3d0000b,0x7c222885,0x14d8000a}},	// [4db0] _deki_, वेद_, dgor, _אוהל_
  { {0xa01b0012,0x60cd2886,0x2002007c,0x649601c0}},	//   _blöc, smam, _eeki_, nšin
  { {0x987304f9,0x60cd0064,0x4ea40b75,0xa3e8000b}},	//   nţă_, pmam, урта, मुक_
  { {0x6ac9000b,0xf3ff016e,0x351b000a,0xd0f6000a}},	//   िग्र, ijão_, לובנ, _שמרת_
  { {0xbb45017a,0x90540033,0xdde30030,0x626b004f}},	//   телк, _свяц, űrőn, ּכֶ֔
  { {0xff16013a,0xc33400f3,0x2002151e,0x9a890015}},	//   _בקשת_, רוס_, _zeki_, بَتْ_
  { {0x4993002b,0xaa560054,0xb08b000a,0x99800061}},	//   دیار, тију_, ּנִ֖, ğiş_
  { {0xccf20008,0x787c0152,0x64960007,0x78bb00f2}},	//   _ככל_, _dévo, ešin, uluv
  { {0x661500dc,0x2bd0000b,0xf7710015,0x3e76001a}},	//   ózko, तेदा, شاة_, _sæti_
  { {0x78bb2438,0xcfca004c,0x6d55002a,0x24802887}},	//   sluv, ומפֿ, _krza, _slim_
  { {0x764a0026,0xda08002b,0xe5a5013d,0x857805b5}},	//   _dafy, _سينه_, тини, есят_
  { {0xf7700086,0xc8c80015,0x7a330061,0x64962888}},	//   _گام_, _كولن_, sıtı, ašin
  { {0x98730011,0x93430892,0xe3b20015,0x6496006f}},	//   aţă_, аняе, شرح_, bšin
  { {0x67d40894,0xf7700040,0x7c2209bb,0xe736009b}},	//   _сочу, _دام_, zgor, _реш_
  { {0x998700df,0x2b910092,0xa0b60001,0x66c6002e}},	//   menų_, ạch_, вљај, uðke
  { {0x6603022d,0xc952000a,0xa3e8000b,0x43860015}},	//   _henk, סמן_, मुख_, _للبق
  { {0x6d470005,0x52aa0001,0x3fe30784,0x4ee5005e}},	// [4dc0] _asja, _овим_, ржув, гієз
  { {0x7d1a0123,0x5cf60033,0x9f400144,0x66032889}},	//   _åtsk, вяду, rcià_, _jenk
  { {0x6603288a,0x99870007,0x627b000a,0x13a8002b}},	//   _menk, ienų_, _חנינ, _زنگی_
  { {0x6486002f,0x787c0152,0x0fda0029,0x7d1e00e8}},	//   _dóig, _révo, _يبحث_, rups
  { {0x4fa30191,0x23bd0030,0x8b23004a,0x6d55288b}},	//   _вияв, májú_, идце, _erza
  { {0xcb670001,0x290c288c,0xcaa60040,0x7d1e288d}},	//   таље_, _pvda_, خصصي, pups
  { {0xce370008,0xc213000a,0xd954002b,0xa8a6030c}},	//   _שאלת_, בהו_, انبخ, крик
  { {0x787c0046,0x0000006a,0x0000006a,0x0000006a}},	//   _vévo,   ,   ,
  { {0x1ae60191,0xf093011f,0x6496288e,0x3ce6005d}},	//   _розм, ינה_, tšin, _जूते_
  { {0x78ad016f,0x64960091,0x99870091,0xe4e6005e}},	//   čava, ušin, genų_, кімн
  { {0xf76f0086,0x6603288f,0x29d30015,0x649624e6}},	//   مای_, _denk, _نيكس, ršin
  { {0x98730011,0xb8e8005d,0x99090015,0x7d03016e}},	//   rţă_, ोग_, _أغلق_, ânsi
  { {0xc1eb004a,0xa2af000b,0x64960091,0x163415b8}},	//   дьбе_, ंकल्, pšin, _беля
  { {0x66032890,0xfbd3000a,0x86e90015,0x35540058}},	//   _genk, יתר_, _أعنف_, _منتز
  { {0x649610ca,0xa63b000a,0x86070015,0xe0d30015}},	//   ošil, _חגור, _شقيق_, لزر_
  { {0x66082891,0x6603005a,0x64960417,0x0000006a}},	//   ladk, _zenk, nšil,
  { {0x44292892,0x3d05000b,0x24992893,0x50642666}},	// [4dd0] _ica_, हीने_, mism_, штра
  { {0xd9040074,0x24992894,0xc3b8000a,0x644d0079}},	//   _وی_, lism_, _בלחץ_, _haai
  { {0xf1ab0086,0x98c2000b,0x6608006f,0x644d042f}},	//   _زاده_, शताए, iadk, _kaai
  { {0xa1560008,0x859b000a,0x24990b29,0x8cb40033}},	//   _עברה_, ושבו, nism_, асіч
  { {0xff040010,0x501a0008,0x09cb005d,0x644d09e7}},	//   _вясн, _אורו, ाध्य, _maai
  { {0x2009020a,0x2499273c,0x4fd6000a,0x26dc01a3}},	//   laai_, hism_, _תושב_, _nivo_
  { {0xceb20008,0x44292895,0xf2d4004c,0x99320015}},	//   _הים_, _oca_, בעס_, مفوت
  { {0xa2bb005d,0x6f0d003d,0x66032896,0x11dc004f}},	//   _शीघ्, osac, _senk, וחוב
  { {0x66030007,0x60dd2897,0x7c2902b9,0xa7120015}},	//   _penk, _mism, _icer, مِيع
  { {0x272b02de,0x6608002a,0x20090079,0x44292898}},	//   røn_, gadk, haai_, _aca_
  { {0x3e76002e,0xf771002b,0xfe36000a,0x44292899}},	//   _gætu_, شاک_, ארתי_, _bca_
  { {0x3e76002e,0x44e80152,0x66030177,0x394e00dc}},	//   _hætt_, _dû_, _wenk, ülső_
  { {0xddce0007,0xe73905c4,0x6603289a,0x213a01d7}},	//   _pobū, _чел_, _tenk, _spph_
  { {0x479a103d,0x6486002d,0x171a004c,0x27ed0034}},	//   _אינס, _sóid, _נוצע, lcen_
  { {0x60dd289b,0x505a0033,0x7641289c,0x21750004}},	//   _bism, ншая_, mely, аутр
  { {0x249914e6,0x628700f2,0xf992000a,0x27ed289d}},	//   cism_, ahjo, צרן_, ncen_
  { {0xa3d0021e,0x4e1a002b,0x60dd0390,0x64960091}},	// [4de0] वेश_, فتاد_, _dism, nšim
  { {0xe1fa008f,0x7c291ad7,0x7641289e,0x644d0079}},	//   _яго_, _acer, nely, _zaai
  { {0x8db50010,0x67200085,0x8d560033,0x6f0d1807}},	//   асці, zumj, ытач, asac
  { {0xac250036,0xadb70029,0xa3e8005d,0x764100dc}},	//   ифік, دهما_, मुच_, hely
  { {0x3e760084,0x76410007,0x7f760001,0xde140086}},	//   _bætt_, kely, _сунц, _نژاد
  { {0x7b06003d,0x7c2901d7,0x2499289f,0x28df0065}},	//   _ērtī, _ecer, zism_, _पंखि
  { {0x6486002d,0xdca6018f,0x764128a0,0xc213000a}},	//   _móib, _бави, dely, זהו_
  { {0xe45f002e,0x3157000a,0x8c1a0015,0x1874006b}},	//   mlög_, ריקן_, _سيطر_, ргия
  { {0xb6060219,0x18330015,0x4c9b000a,0xf6e30033}},	//   лянк, صريح, _נשמע, йцэн
  { {0x764128a1,0x961e000b,0xa7370067,0x07370015}},	//   gely, पलेट_, اثير_, اسيب_
  { {0xfe9b0008,0x644d28a2,0x4edb004c,0x249928a3}},	//   תיימ, _paai, ײַזנ, tism_
  { {0x69c828a4,0xd327004a,0x7d7b004c,0x4614002b}},	//   _izde, льги, גנטו, دوگر
  { {0x660828a5,0xe6c4002e,0xa3d0005d,0x46f609ef}},	//   padk, þjóð, वेल_, _счет
  { {0x1b7b004c,0x644d0079,0x35d4004a,0x76410f4a}},	//   ײטלע, _waai, _колё, cely
  { {0x067b013a,0x867b0008,0x6d5a002c,0x6486002d}},	//   _אנגל, _ארגו, _štan, _dóib
  { {0xd5cb000f,0x6f0d059b,0xd5130067,0xc7e6000a}},	//   _אֶחָ, tsac, _ابوغ, רוּ֙_
  { {0x60dd0048,0x2f18004a,0xe7f7000b,0x657a0710}},	// [4df0] _vism, лоть_, ीरता_, lyth
  { {0x51870080,0x999c0046,0x6f0d28a6,0x6e2528a7}},	//   _бума, jevů_, rsac, ughb
  { {0x6f0d082d,0x657a0b58,0x60dd00d4,0x0000006a}},	//   ssac, nyth, _tism,
  { {0x6f0b0030,0x76410061,0xac191dd3,0x7c3507be}},	//   ágcs, zely, тоду_, редх
  { {0xeab10087,0xf41f008c,0x6b65134f,0xefc800af}},	//   يعت_, yhän_, ркла, _бурк_
  { {0x787504af,0xfaa70080,0xfbd00002,0xbf9a000a}},	//   _návr, ышен, ستن_, _יירש
  { {0xf2d40053,0xe96901b7,0x62850046,0x764128a8}},	//   זעס_, тайл_, _mlho, vely
  { {0x76410176,0x7af50036,0x69d50057,0xb066008c}},	//   wely, _взає, _územ, _itää
  { {0x6285001c,0x9a270115,0x78750030,0x76411547}},	//   _olho, _معان, _sávs, tely
  { {0xf1fb005d,0xbb840029,0xab740054,0xd6ce00c3}},	//   ्रफ़_, _الكي, _угуш, وقي_
  { {0x657a0026,0x18370029,0x661c1ac6,0x46380033}},	//   gyth, _مرشح, órka, учыя_
  { {0x764128a9,0x752f005c,0x9f59008c,0x628528aa}},	//   sely, ńczo, _kesä_, _alho
  { {0x386d010b,0xdc880008,0xa3d0000b,0x23b30015}},	//   mjer_, רְתָ, वें_, ْمُس
  { {0x471a0053,0x36690001,0x386d28ab,0xe595002b}},	//   _יונג, _јако_, ljer_, _پشتخ
  { {0x6285002c,0x3aeb00cb,0x40961161,0x61460148}},	//   _dlho, _løp_, арат, шева
  { {0xe0df04ed,0x64a30063,0x386d28ac,0x63b10030}},	//   _ciò_, _маща, njer_, ékné
  { {0x387f001a,0x4e0601e1,0x1f661b5d,0x6fd600ce}},	// [4e00] ikur_, изаб, шкам, рівц
  { {0x22930029,0x7c3d0061,0xa2cd000b,0x387f007c}},	//   _وليس, _ısra, _दीप्, hkur_
  { {0x387f0084,0x621b000a,0x859c000a,0xbd8a002b}},	//   kkur_, _בויק, ֲשׂו, خنان_
  { {0xe5360053,0xf5360053,0x718b000a,0xb40d000a}},	//   יטעט_, יטער_, _יְכַ, ֲלוֹ
  { {0xf4170053,0xddea0086,0xcb540015,0xab270054}},	//   בֿות_, _لرزه_, إنتظ, иоца_
  { {0x291c016f,0xd3570008,0x7bc90091,0x386d02de}},	//   trva_, ייני_, _dzeu, ejer_
  { {0x64962823,0xadba0015,0xbe3b000a,0x6da306da}},	//   ršij, _شهرا_, _שעלת, _дира
  { {0xb8660086,0x69c81ea8,0x38c8002b,0xd83a0033}},	//   شابو, _vzde, داتی_, тэк_
  { {0x657a0176,0xe6662152,0xc7c6004a,0xdceb0091}},	//   wyth, атно, шски, čiąj
  { {0x0f37000a,0x291c0f81,0x2ca628ad,0x7be701ec}},	//   סריט_, prva_, lnod_, āruš
  { {0x69c80024,0xd7ef28ae,0xae57000a,0x387f003d}},	//   _uzde, _му_, בסיס_, bkur_
  { {0x657a003e,0x397b0053,0x2ca60026,0xe97b000a}},	//   ryth, _שטאנ, nnod_, _שנאש
  { {0x92b70029,0x9cd7000a,0xa3b4000b,0x7d030030}},	//   لحسا, יוטה_, _जुआ_, ánsz
  { {0x877b0135,0xa01b00dc,0xf1a701c6,0x2ca60034}},	//   _באדי, _elöl, арбн, hnod_
  { {0x8007194a,0x90d70015,0x20d70015,0xa17400ce}},	//   ичае, لآرا, لترج, огрі
  { {0x27300092,0x61fa0064,0x55bb000a,0x44f3002b}},	//   oàn_, ıtla, _שמהו, _بسوز
  { {0x0eeb0036,0xa6f8000a,0xe45f0030,0x629c28af}},	// [4e10] тьби_, רִֽי, rlöd_, biro
  { {0xc7d70008,0x9f040015,0x787c0003,0x3678000a}},	//   שומי_, توكو, _dévi, נְּע
  { {0x2ca60176,0xab620064,0x6d5a00dc,0x387f001a}},	//   fnod_, _şüph, _átal, ykur_
  { {0xa5d900b2,0x8d280036,0xe5370053,0x661d0091}},	//   אַני, роїв_, שטאט_, ėski
  { {0x7bc00026,0x8b6400e6,0x6486016e,0x6d4a001a}},	//   _cymu, قاوم, _jóia, æfar
  { {0x8e850029,0x7bc00026,0x1df804ab,0x6f76000a}},	//   _السه, _dymu, _веры_, _התשמ_
  { {0x68e80026,0x3cf0002c,0x4238000a,0xb8090015}},	//   _cudd, ľové_, ינגל_, هيثم_
  { {0x7b000014,0xbca500e5,0x629c1c97,0x3cf00247}},	//   öztá, _امري, ziro, žové_
  { {0x387f002e,0x7bc00026,0x61e5002d,0x1bbb0015}},	//   rkur_, _gymu, _oghl, _شارع_
  { {0xba74003b,0xca740029,0x27140092,0x68e80026}},	//   _والت, _والغ, ình_, _fudd
  { {0x629c28b0,0x68e828b1,0xa92800ce,0x0000006a}},	//   viro, _gudd, _віче_,
  { {0x0708002b,0xdd3a000a,0x6d3a000a,0x64a62044}},	//   _چيني_, נערכ, נתרנ, сама
  { {0x888c0053,0x43930010,0xc8b40015,0x6b56000a}},	//   _בראַ, заўс, _بإلغ, ֖ישׁ_
  { {0x6d5a016f,0x26d90089,0x787c0152,0x412a03e7}},	//   _štam, ůsob_, _révi, лого_
  { {0x7ae9022d,0xd1790036,0x787c0003,0x7c3b002a}},	//   _luet, асті_, _sévi, _obur
  { {0x629c00df,0x997a004c,0x7ae900aa,0x69c101f9}},	//   siro, אָמפ, _ouet, _myle
  { {0x64460020,0xa01b00c0,0xee3a28ae,0x4ab9000b}},	// [4e20] meki, _glöm, лна_, ेताव
  { {0xdd8f0086,0xb2260080,0xcf250029,0xdfcf0031}},	//   کوم_, _умол, ترفي, ريل_
  { {0x7bc00176,0x42db000a,0x6277000a,0x27140016}},	//   _symu, _תקיע, _הגיא_, ành_
  { {0xe0460180,0xdcb9005e,0xedd30015,0x5c030033}},	//   _унми, ащі_, سيند, пяша
  { {0x20570008,0x68e828b2,0x2ca60d38,0x7d1e0085}},	//   _היכל_, _sudd, rnod_, srps
  { {0xbae50036,0xdd200089,0x60c428b3,0xcb070015}},	//   іцій, může, llim, حيون_
  { {0x5d86003b,0x644600f2,0xa9340010,0x60c428b4}},	//   _الأل, keki, цейш, olim
  { {0x69c10026,0xd90d0086,0x7c950010,0x91bb000b}},	//   _dyle, ئین_, _друц, _एडसै
  { {0x69c10064,0xc6f70139,0x501b000a,0x7bc00061}},	//   _eyle, бных_, אופו, _uymu
  { {0x7ae101d1,0x86980001,0x787c00dc,0x5694005e}},	//   _gilt, ркос_, _névv, іант
  { {0x245f022d,0xe72f0086,0x1e570053,0xd83a0033}},	//   _nämä_, وصی_, זשיר_, _бэл_
  { {0xab5d005c,0xf993000a,0x8d5b004c,0x99640046}},	//   _wyże, _צרף_, אכטי, _kůže_
  { {0xdc9b0008,0x97c6004a,0xc21b005e,0x47330067}},	//   ריכל, _уйде, лєв_, _فروز
  { {0x60c428b5,0x99640089,0x68e2002d,0x442d005c}},	//   elim, _může_, _hiod, że_
  { {0xc2c40015,0x8637000a,0xc918000a,0x04950015}},	//   سيفي, _הרוב_, יֵּר, _ولتح
  { {0x64a40cb9,0x9f49002d,0x60c428b6,0x644628b7}},	//   _наја, scaí_, glim, ceki
  { {0xc2c50015,0x6d5c08aa,0xa01b001a,0xd24e002b}},	// [4e30] _ويعي, _arra, _hlök, رچی_
  { {0x4439049c,0x60c428b8,0x96ab004f,0x0f1400ce}},	//   lfs_, alim, ְשׁ֔, ямую
  { {0x443900da,0x69dc002a,0x27e6002a,0x9f59001a}},	//   ofs_, _źren, _ogon_, _jesú_
  { {0x106b0029,0xcc0b0086,0x7ae12261,0xa3d0000b}},	//   _إحدى_, ازان_, _silt, वेक_
  { {0x7ae10005,0xcb6900d7,0x69c70046,0x6d5c28b9}},	//   _pilt, рале_, _újez, _erra
  { {0x6446005c,0x4aa8005e,0x539c000a,0x91fb000b}},	//   zeki, бкін_, ניגו, ्रिज_
  { {0x7ae128ba,0x68e228bb,0x7c3b02f2,0x9f59006f}},	//   _vilt, _biod, _tbur, _nesú_
  { {0x7ae900f2,0x47390010,0x69c10f1b,0x58d2023e}},	//   _tuet, ачоў_, _vyle, мојт
  { {0x7c24002d,0x7b670a61,0x68e228bc,0xc7ae0015}},	//   óire, _утве, _diod, َّى_
  { {0x5eec000a,0x69c128bd,0x24890337,0x44390106}},	//   נַחְ, _tyle, _alam_, efs_
  { {0x04460457,0x644628be,0x89e8000a,0x443928bf}},	//   оенн, teki, _הַנֵ, ffs_
  { {0xf9920008,0x2ee3158f,0x7c2b28c0,0x248928c1}},	//   _קרא_, _lijf_, nggr, _clam_
  { {0xe60e25ca,0x644628c2,0x9f400125,0x78bb28c3}},	//   _од_, reki, sciú_, mouv
  { {0x78bb0089,0x2b400064,0x78a903ff,0x7bda000a}},	//   louv, çici_, lnev, יקרו
  { {0x2cbf0089,0x55f6000a,0xc4c60015,0x60c406a8}},	//   _okud_, _ומצב_, _وتعو, tlim
  { {0x53a60036,0x200b0152,0x78bb0152,0xe4d60015}},	//   _майб, _ceci_, nouv, _بتتب
  { {0x60c400d9,0x200b14cc,0xf1b6000b,0x62d60015}},	// [4e40] rlim, _deci_, _आँकन, _وآخر
  { {0x245f022d,0x5d5a0001,0x66cf00cb,0x99640046}},	//   _tämä_, ијер_, bøke, _růže_
  { {0x0d86008f,0x60c404f9,0xbd46002b,0x7c390034}},	//   ўлен, plim, تناي, ffwr
  { {0x853a0053,0x0b1a0015,0xbbe90015,0x0000006a}},	//   יגעי, لقصة_, مرهم_,
  { {0x69c510cc,0xc43b000a,0x78a928c4,0x20550033}},	//   ühen, שתני, dnev, _этэр
  { {0xed5a0001,0x93b7000a,0x200b0045,0xba170021}},	//   _ког_, חלנו_, _zeci_, قيها_
  { {0x6d5c002f,0xed58006f,0x39140058,0x0000006a}},	//   _urra, _éľ_, أوبز,
  { {0xd8b7003b,0x787c00dc,0xacfb0008,0xc8d30015}},	//   يديا_, _névt, _כהלכ, وزيع
  { {0xa01b0084,0x920a005d,0x76aa0731,0xf897002b}},	//   _slök, वराज_, итов_, تخوش_
  { {0x8c490064,0xd6d000e6,0x68e2002a,0xd9460054}},	//   arşı, عقد_, _wiod, _мези
  { {0x994a0196,0xceb30053,0x286a0001,0x660a001a}},	//   _خلال_, ויז_, _врло_, _vefk
  { {0x78bb0152,0xe3b80064,0x66e6211a,0xe857005e}},	//   couv, ğın_, _дода, _маєш_
  { {0xe3b801e2,0xc87f00b8,0xc4580080,0x200b0cd0}},	//   şın_, öße_, циях_, _reci_
  { {0x628e003e,0x9f5904ed,0xfa6a000a,0x6594029f}},	//   ghbo, _gesù_, ׁכָּ, _налу
  { {0xd2580010,0xe9ce0010,0xf6b7000a,0xd5fb000a}},	//   цця_, нкi_, _והגש_, _דפור
  { {0x248900d9,0x38d4000a,0xda780107,0x764828c5}},	//   _ulam_, לֵּל_, _loď_, ledy
  { {0x66cf06f5,0x9f340036,0x64860125,0x200b28c6}},	// [4e50] søke, меті, _móil, _veci_
  { {0x764828c7,0x2cbf02de,0xa3b4000b,0x395e0012}},	//   nedy, _skud_, _जुट_, _orts_
  { {0x2ee30111,0x9cf5005e,0x92b40015,0x64a40085}},	//   _vijf_, їзді, _تحيا, rđiv
  { {0x91ba000a,0x6aaa0034,0x764802f2,0x7dd0001a}},	//   _למתי, enff, hedy, _sósí
  { {0xfb68003b,0xeaae0142,0xd5d1000b,0x395e0f4b}},	//   قصوى_, ей_, _हरभज, _arts_
  { {0x7648005c,0x3fda000a,0xa3d0000b,0x8f7a000a}},	//   jedy, _לקרב, वेट_, _הנשק
  { {0x787c0030,0x69dc001a,0x6ca728c8,0xec6b0aed}},	//   _névs, _úrel, _драж, _крак_
  { {0x08c50054,0x718c000a,0xb4b50065,0x0000006a}},	//   џбин, יְחַ, जको_,
  { {0x78bb0152,0x321128c9,0x649607c4,0xd90d002b}},	//   rouv, kazy_, išit, ئیچ_
  { {0x78bb28ca,0x78a928cb,0x26c502b9,0xdb26002b}},	//   souv, snev, ullo_, _رومی
  { {0xc8ab0063,0x6486002d,0xc329000a,0x4990002b}},	//   _къде_, _fóil, _תו_, _لیور
  { {0xfbc70086,0xc86400a4,0x8d76000a,0x1956000a}},	//   فت_, _отчи, לגתו_, _מבעל_
  { {0x69c700fb,0xd8b80029,0x75280024,0x628e14c0}},	//   _øjeb, _بدلا_, audz, thbo
  { {0x75280d55,0xdbe8000b,0x320c006f,0x7d180046}},	//   budz, _ओल्ड_, údy_, ávsk
  { {0x45d20001,0xd13200e6,0xd5b70015,0xa06a030e}},	//   _пољс, عمر_, _بإشع, бава_
  { {0xe45f00f2,0xdfd20029,0xd5b80024,0xf8cb000b}},	//   llön_, فيز_, rgāt_, ातिय
  { {0x1e860010,0x7ee60029,0xd0070080,0x8317006e}},	// [4e60] плам, سكان, яете_, _فقير_
  { {0xef1702e1,0x539b000a,0x64960091,0xdfcf0058}},	//   яму_, _ליפו, ršiu, ايك_
  { {0xf27b0008,0x3f860b7e,0xc27b000a,0x427b000a}},	//   _הריש, šou_, _הריי, _האיג
  { {0xf7670015,0x7db3002b,0xdee600c9,0xa0c6009a}},	//   _كا_, رمنص, _номи, _ژيگو
  { {0x6486002f,0x6f630010,0xddce00bf,0x7f1900e2}},	//   _nóim, _звяз, _dobš, _міру_
  { {0x753d005c,0x645600da,0x38720034,0x787c0324}},	//   łszy, _layi, _ŵyr_, _névr
  { {0xd90d0086,0xadc30016,0x64860125,0x6a1300c3}},	//   لیل_, _trạc, _póil, ربور
  { {0xd6010092,0x20120061,0x984a0238,0x645600aa}},	//   _đún, nayi_, сяка_, _nayi
  { {0x4908005d,0xe758005e,0xf7f3002b,0xa8170015}},	//   _सबको_, ципі_, رسيد, ستير_
  { {0x9f9701c8,0xbafb013a,0x8b030089,0x8afb000a}},	//   פדיה_, _להמש, ářen, _להמי
  { {0x2fc700a7,0xf76f0086,0xae5b000a,0xa01b0034}},	//   ́ng_, نای_, זכיר, _glöw
  { {0x386604f9,0xd3710015,0x764800cb,0x6f16002a}},	//   _unor_, نهج_, sedy, ksyc
  { {0x787c0152,0x321128cc,0x7528002c,0x764828cd}},	//   _févr, tazy_, sudz, pedy
  { {0xb7db000a,0xe7db000a,0x6b8202f2,0x356a0148}},	//   _הקדי, _הקדש, iyog, _грин_
  { {0xe63b013a,0xe2c80029,0xa63b0008,0x763b000a}},	//   _התוכ, سوفو_, _הגור, _העוג
  { {0xa2cd000b,0x2ec5000b,0x95530015,0x7415002b}},	//   _दीर्, वत्त, _أخوا, _کوکا
  { {0x34380086,0xddeb0086,0xde7901f3,0x22950015}},	// [4e70] _رسيد_, مراه_, обач_, _يلبس
  { {0xdd210007,0xb698000a,0x6456007f,0x0000006a}},	//   rįžt, קֹּת, _zayi,
  { {0x6496002c,0x7afb28ce,0xcd04005e,0x2d87006f}},	//   pšit, _stut, еччи, áne_
  { {0x317e00b8,0x2d8101f9,0x0000006a,0x0000006a}},	//   ätze_, ryhe_,   ,
  { {0x61ec00dc,0xc43c000a,0xaab9002b,0xfc30006e}},	//   _állá, מתאי, يدتر_, احم_
  { {0x6486002d,0x9f0400a2,0x5e450015,0x8027002b}},	//   _róim, _سوفو, _تَسْ, _برگم
  { {0x6d5a0085,0xfa56002b,0xa2a00157,0x0000006a}},	//   _štav, برنگ, _ऑगस्,
  { {0x08d40010,0xa765005e,0x9c65002b,0x8bb70015}},	//   нцыя, дкид, _تهرو, _فإذا
  { {0x6008000a,0x6605007c,0x999e0091,0xf7710058}},	//   הִתְ, _õhkk, _batų_, ئاب_
  { {0x645628cf,0x4585049d,0xfbd2000a,0x6496174f}},	//   _sayi, дгов, _יתן_, jšir
  { {0xe3b80064,0x6456003e,0x1fda000b,0x2df6000a}},	//   ğım_, _payi, _भण्ड, וצתך_
  { {0xe3b80064,0x19ba000a,0x03a6086e,0x6aa328d0}},	//   şım_, _ומעב, димо, linf
  { {0x79830026,0x67290adb,0x6aa3002a,0xc7b90030}},	//   lynw, quej, oinf, rgős_
  { {0xa509019c,0x23600111,0xcb88000a,0x3f8c003d}},	//   _дека_, _vrij_, פְרֹ, _ādu_
  { {0x15fa0008,0x2d1c005d,0x45fa000a,0xf5920015}},	//   _והצע, _पटेल_, _והצג, _للوج
  { {0x64b60015,0xf41f008c,0xa0671d8c,0x20550822}},	//   _تحتر, lkän_, маса_, нтур
  { {0x8fa30229,0xd6d9000a,0x6aa306c7,0xef1a107b}},	// [4e80] вате, ַחֲל, kinf, юма_
  { {0xe4f9000a,0x59dd000b,0xc3c9012c,0x752f002a}},	//   ַפְש, मधार, _عظيم_, ńczu
  { {0x6aa32040,0xfe79004a,0x1ea90058,0xb05b005b}},	//   dinf, чёты_, ساكي_, _ikän
  { {0x44f30023,0xc1730008,0xcea900a3,0x8c180015}},	//   _mã_, _סחר_, בי_, سيتر_
  { {0x4bda0086,0xcce50029,0x44f328d1,0xda65002b}},	//   آباد_, رسمي, _lã_, کاني
  { {0x394501d7,0x99d60015,0x7f750033,0x79830034}},	//   _bpls_, وتغا, _чуюц, fynw
  { {0xa96728d2,0x44f30016,0x63ba002a,0x9f4b001a}},	//   дија_, _nã_, ętny, élög_
  { {0x6496198d,0xd90d0086,0xa8a30033,0x1754009b}},	//   zšir, صیه_, крык, евия
  { {0xb05b00c0,0xab650024,0x6d5e00cb,0xec37000a}},	//   _okän, _peļņ, lvpa, _קאמר_
  { {0xda660070,0x4b7b000a,0x6aa300da,0x79830034}},	//   _تاري, _ואמו, cinf, bynw
  { {0x98a70046,0x15140033,0x7e7c0043,0x6fd50065}},	//   ntně_, эдня, _morp, _दरभं
  { {0x25fe014e,0x9f4028d3,0x44f30016,0x7ae802de}},	//   _श्री_, nció_, _dã_, _hidt
  { {0xbf9b00dd,0x69c80335,0xddce002a,0xf76f002b}},	//   _leêr, _hyde, _jabł, _ناو_
  { {0x44f3016e,0x98a70046,0x338400ce,0x7e7c28d4}},	//   _fã_, ktně_, туюв, _norp
  { {0x9f4000dc,0xba9b0008,0x7ae828d5,0xb609002b}},	//   kció_, קסלי, _midt, _ﻳﺎ_
  { {0x39570008,0x442f0134,0x753d002a,0x64a40030}},	//   ושלם_, _øg_, ńszc, lőin
  { {0xddd50046,0x6aa300aa,0x2484008c,0x69c828d6}},	// [4e90] _pozů, yinf, ömme_, _lyde
  { {0x7e550029,0x2348002b,0xc5f8003d,0xfe730067}},	//   عناص, _کلیپ_, ncē_, خدر_
  { {0x44f30023,0x7e7c016b,0xa6e2001a,0xf1a701c6}},	//   _xã_, _dorp, _íðus, _ірон
  { {0x6ab9005d,0x7e7c002d,0xf412000a,0x2bd30065}},	//   ेत्र, _eorp, ָ֤א_, _तरदा
  { {0x6d5a28d7,0x90980063,0x79830026,0xa03a0053}},	//   _štat, _цвят_, wynw, _צעשפ
  { {0x9f4008e0,0x765801c9,0x69c8119c,0xb9550054}},	//   ació_, _navy, _byde, етић
  { {0x09f60029,0xbc950054,0x6aa328d8,0xac950920}},	//   رفية_, _завј, rinf, _завш
  { {0x9f4008e0,0xc0520008,0x6aa328d9,0xec15002b}},	//   cció_, ָ֖ה_, sinf, _سوئد
  { {0xe7a905c4,0xf41f008c,0xb6cc0061,0x6aa328da}},	//   явил_, tkän_, ğünü, pinf
  { {0xb6cc01e2,0xe3b80064,0xa01b0012,0xddc70046}},	//   şünü, şık_, _klös, _mojž
  { {0x9f4004ed,0x89340015,0xddce002a,0xe579005e}},	//   nciò_, _لعنا, _zabł, їзм_
  { {0xb05b00c0,0xe7950004,0x44f328d1,0xa562002b}},	//   _skän, _пиењ, _vã_, اگون
  { {0xf745005f,0x7dee00dc,0xd8380033,0xa7870058}},	//   _чело, nősí, _цэх_, _تشاو
  { {0x877a000f,0xb77a000a,0x6d55002a,0xd919000a}},	//   _מאני, _מאנש, _osza, ּוּל
  { {0x64a6008f,0x614328db,0xc5080015,0x673b28dc}},	//   _пака, лера, _قتيل_, ltuj
  { {0xa0b50124,0x05740015,0x645a003d,0x7e7c28dd}},	//   вљуј, _جاهد, ētis, _sorp
  { {0x7bc9003f,0xa73a004c,0x3cff0085,0x442028de}},	// [4ea0] _nyeu, ּגעכ, _čuva_, _idi_
  { {0x673b28df,0x2caf001a,0x0357004f,0x2fd70369}},	//   ituj, engd_, _טיפש_, رولد_
  { {0xd29b004c,0x61460b1e,0x5cf5005e,0x442001d7}},	//   _זשיט, _џема, вячу, _kdi_
  { {0x673b28e0,0xcea9015b,0x44200046,0x7ae80123}},	//   ktuj, זי_, _jdi_, _sidt
  { {0x80630080,0x98a70089,0x9f402880,0x1bf30033}},	//   _свяж, stně_, rció_, упіў
  { {0xada628e1,0x6f0428e2,0x673b013b,0x0000006a}},	//   _загл, mpic, dtuj,
  { {0x9f4028e3,0x6ee90007,0x6d4b005c,0x7ae828e4}},	//   pció_, _užba, łgar, _vidt
  { {0x76580007,0xd7fa28e5,0xdb1f0030,0xfce6005e}},	//   _savy, чук_, ővár, _чобо
  { {0x765800df,0xf0930008,0x64a400dc,0xf6d30086}},	//   _pavy, טנה_, tőin, گزيد
  { {0x69c828e6,0x69960a0b,0xddc7002a,0x6444007c}},	//   _tyde, _прех, _najś, _abii
  { {0x34950054,0x765a28e7,0xba17006e,0x64a40030}},	//   ванр, rdty, _سينا_, rőin
  { {0xd5b70010,0x2ebe005d,0xc9b7000a,0x0000006a}},	//   эсы_, ्तुत, _אהבת_,
  { {0x366a0080,0x44200026,0x78a2016f,0xa88700a4}},	//   _надо_, _ddi_, _imov, _яйца_
  { {0xa6aa0086,0xeb91000a,0x442028e8,0x44f7009a}},	//   _عاشق_, בָל_, _edi_, بریج_
  { {0xe5f7013a,0x7c2000bd,0x865b000a,0x230b002b}},	//   _אזור_, _odmr, _מדגי, _کتبي_
  { {0x30a428e9,0xf8b20065,0xd3710058,0x442028ea}},	//   грув, ुकिय, _نهب_, _gdi_
  { {0x6d470084,0x7ff40086,0x752f005c,0x1408000a}},	// [4eb0] _spja, اسفا, ącze, _אִתּ
  { {0x644f28eb,0x44200820,0x9f540033,0x8f680015}},	//   leci, _zdi_, ывуч, عملك_
  { {0x44200176,0x6d5a1927,0x64ab0046,0x21270016}},	//   _ydi_, _štar, přid, _ính_
  { {0x9f4004ed,0x644f28ec,0x711a000a,0x7528003d}},	//   rciò_, neci, _קורפ, irdz
  { {0x60cd0064,0xc016000a,0x9f4002b9,0x6d55002a}},	//   mlam, _בקרו_, sciò_, _wsza
  { {0x7dee0014,0xe9a90086,0x20090007,0x8d770015}},	//   rősí, وگان_, lbai_, _كازا
  { {0xf2d40053,0x6d55002a,0xbdd40248,0x60cd28ed}},	//   װעק_, _usza, _борщ, olam
  { {0x673b022d,0xd5b10092,0x60cd117f,0x3158000a}},	//   ttuj, hác_, nlam, תיהן_
  { {0x75280050,0x37750033,0xd705006b,0x7d1c00bc}},	//   erdz, тыйс, ъзпи, _zvrs
  { {0x2d850005,0xf41f00c0,0xc7440015,0xb05b0123}},	//   _üles_, skäl_, اضيي, _skäl
  { {0x7a7a0053,0x673b28ee,0x45d5006b,0x442001d7}},	//   _קרעס, stuj, ъцит, _pdi_
  { {0x64a60010,0xe20a000b,0x27390144,0xe4e50033}},	//   тама, वर्ण_, pèn_, ліўн
  { {0x96b50001,0x289a0053,0x752828ef,0x60cd28f0}},	//   _искљ, _קינא, ardz, dlam
  { {0xcb120008,0x60cd13ff,0xb6a5004a,0x645d28f1}},	//   שלם_, elam, _шилл, adsi
  { {0xa564003b,0xc692000a,0xdff60033,0x67290030}},	//   _مدين, _דאג_, вязь, lrej
  { {0x68fc0014,0x4420003f,0xb5b6000a,0x60cd28f2}},	//   _érde, _udi_, _שלקח_, glam
  { {0xa2cd000b,0x13a8002b,0x7d1c0085,0xc0e31fdd}},	// [4ec0] _दीक्, _سندی_, _svrs, ротк
  { {0xaefb0092,0xe1fa03a9,0x20090091,0x764128f3}},	//   _trùn, _юго_, abai_, nfly
  { {0xe0da0124,0x32180556,0x60260345,0x6f041470}},	//   _ово_, mary_, _идна, spic
  { {0x60cd0440,0x68eb12e1,0x6aca000b,0x1d070054}},	//   clam, _nigd, ित्र, теци_
  { {0x60c400f2,0x2480005c,0x2ca628f4,0x26c71e25}},	//   moim, _moim_, riod_, _okno_
  { {0x644f0050,0x3218003e,0x49d80010,0x24920026}},	//   zeci, nary_, ндлю_, _llym_
  { {0x7d1c0796,0x76411639,0xac3a0342,0x69350046}},	//   _uvrs, dfly, _очах_, yřeš
  { {0x7d5700b2,0xf1b30008,0x60c4008c,0x75280816}},	//   _בילד_, יסו_, noim, vrdz
  { {0xf62a0036,0x98b7006b,0xb6cc0061,0x672928f5}},	//   міни_, ълът_, şümü, grej
  { {0x3aeb0086,0x60c4002d,0xba6a0015,0xe6660004}},	//   _قبلی_, hoim, _تحرك_, ттио
  { {0xd5b00029,0x60cd0064,0x245500e6,0xda11002a}},	//   صفح_, ylam, هندس, żącą_
  { {0x91690092,0x52bd000b,0x746b01b7,0x64ab0046}},	//   hực_, ोत्स, фров_, dřic
  { {0x645d094b,0x24840123,0x644f28f6,0x0000006a}},	//   rdsi, ömma_, reci,
  { {0xc7d70008,0x46a30063,0x644f28f7,0xd5660eaf}},	//   _סוגי_, _качв, seci, _атип
  { {0xb6d90053,0x60cd28f8,0x6114011a,0x644f28f9}},	//   _אַקט, tlam, идру, peci
  { {0x6486002d,0xf0b402e1,0x291c007c,0xf2df0034}},	//   _sóiv, айсь, isva_, gwâr_
  { {0x9ed9017a,0x6d5a0085,0x20090091,0xa4b8000a}},	// [4ed0] емат_, _štap, rbai_, _שלחה_
  { {0xd25104b6,0x60cd28fa,0x291c007c,0x3255004a}},	//   _اند_, slam, ksva_, _свор
  { {0x60cd28fb,0x6729006f,0xdcf40015,0xecf40015}},	//   plam, zrej, لأنب, لأنظ
  { {0xbb95006b,0x1b19004a,0xfd100015,0xf8dc000b}},	//   лаещ, ежды_, تجك_, मगोप
  { {0x76410026,0x0c24042b,0xa09a004c,0x9b450040}},	//   yfly, рмін, _נישט, انتو
  { {0xbbd3005d,0x6729016f,0xc9590054,0x8f9a000a}},	//   _तरीक, vrej, ешиц_, _טירי
  { {0xc27c0008,0x127c004c,0x3cf80015,0x3f890034}},	//   ורגי, ואגע, _لعقد_, lyau_
  { {0xc1740008,0x88c50089,0x32180bba,0x672928fc}},	//   שחק_, _ověř, zary_, trej
  { {0xf09400a3,0x67290ea4,0xd639005e,0x06e9011e}},	//   ינק_, urej, няні_, нмик_
  { {0x64ab0089,0x672928fd,0x67260030,0x25fa0065}},	//   yřic, rrej, ákja, ऊँगी_
  { {0x98a7003d,0x34aa030e,0x672902de,0xceb40643}},	//   aunā_, евно_, srej, ייץ_
  { {0x3218051e,0x672928fe,0x76410804,0xe611009a}},	//   wary_, prej, sfly, جشک_
  { {0x32180041,0x60c400f2,0x23de000b,0x4c9a000a}},	//   tary_, voim, नेंद, תברו
  { {0x78a90276,0xb60728ff,0x471a000a,0x64ab0046}},	//   liev, _рядк, _טונג, třic
  { {0x32180041,0x60c42900,0x00e4002b,0x26c52901}},	//   rary_, toim, لتری, molo_
  { {0x321800da,0xa0a30004,0x2ebe0065,0x0000006a}},	//   sary_, басд, ्त्त,
  { {0xddd50107,0x1f6608f0,0x60c42902,0x80b80065}},	// [4ee0] _rozš, ыкам, roim, ्कबे
  { {0x6ee90007,0xee371179,0x78a92903,0x35a8000b}},	//   _užbl, лну_, hiev, _छेड़
  { {0xcd360029,0x60c4001c,0x13a8002b,0x91690016}},	//   طراب, poim, _سنگی_, rực_
  { {0x317b0053,0x20562904,0x0000006a,0x0000006a}},	//   _נאכד, _стор,   ,
  { {0xa3aa000b,0xf236000a,0x8f75005e,0xcb670033}},	//   _गेम_, ָרֶץ_, _курі, лаце_
  { {0xc333011f,0xd357000a,0x628e2905,0xd9180058}},	//   מוד_, טיני_, nkbo, نيتش_
  { {0x26c52906,0x0000006a,0x0000006a,0x0000006a}},	//   dolo_,   ,   ,
  { {0x6b8d00dc,0x6cd60015,0x99470015,0xfb160015}},	//   öngé, _إقرا, اليل_, _مورج
  { {0x8c1b0c44,0xfa360040,0xc7c6004a,0x628e00cb}},	//   _רומי, _مراد, ыски, kkbo
  { {0x0f57013a,0x9b93003b,0x88bc0089,0xfb1b0008}},	//   ניים_, _الكت, _svěd, _נובמ
  { {0x64750127,0x29d30015,0x88c50046,0x09060555}},	//   агну, _هيكس, _svěř, _спен
  { {0xc9850054,0x199503ae,0x628e2907,0x26c52908}},	//   _туђи, _тјур, ekbo, aolo_
  { {0x752f005c,0x26c52909,0x2455002b,0x0000006a}},	//   ącza, bolo_, هنگس,
  { {0x26c50e68,0x7d19002a,0xb05b008c,0x6aaa290a}},	//   colo_, ąwsz, _ikäi, niff
  { {0xa194119f,0x1128005e,0x64400144,0xd5fb000a}},	//   барч, люти_, òmic, _אפור
  { {0xd5b10092,0x88bc0089,0x6aaa290b,0x98a70011}},	//   oán_, _uvěd, hiff, mună_
  { {0xb4c3005d,0x3f8f002e,0x9f35005e,0x88c50046}},	// [4ef0] ्ती_, águ_, резі, _uvěř
  { {0x661a0014,0xc7d70008,0x8e140033,0xe3b80061}},	//   natk, רומי_, йдуц, ğıt_
  { {0xf1ab0086,0x3ced003d,0x6aaa026e,0xb6bb000a}},	//   _ساده_, _piev_, diff, עצבי
  { {0x661a0375,0x2369290c,0xa17a000a,0xfd10012c}},	//   hatk, _kraj_, _סטרט, سجم_
  { {0x7e2b0010,0x501a000a,0x93fc004c,0x661a0b8f}},	//   _піва_, _בורו, גלדי, katk
  { {0xb4c3014e,0x44fa00aa,0x4a44005e,0x02fc0643}},	//   ्तु_, _oë_, йнів, עלומ
  { {0x78a90298,0x798a0026,0x26c504ed,0x661a1ae6}},	//   tiev, gyfw, volo_, datk
  { {0xf0920053,0x661a003d,0x29070046,0x64ab0046}},	//   ַני_, eatk, rpna_, yřia
  { {0x26c502d7,0x6c840029,0x661a00d9,0x78a9290d}},	//   tolo_, _القم, fatk, riev
  { {0x0f580053,0x26c502b9,0x69c50012,0x29070123}},	//   ריזם_, uolo_, ühes, ppna_
  { {0x78a90024,0xfe36000a,0xc9d3002b,0xbae40015}},	//   piev, ברתי_, _اماک, _اكلي
  { {0x66750086,0xe36607c1,0x397a000a,0xec35004c}},	//   ادکر, акми, _בטענ, סאָר_
  { {0x26c504ed,0x6486002d,0x21f60036,0x6c7a0053}},	//   polo_, _sóis, иївс, דארפ
  { {0x412a18a9,0x6486002d,0xee0f000b,0x98a70045}},	//   кого_, _cóir, िरोध_, bună_
  { {0xe5a20001,0x7c3b290e,0x6b8b290f,0x20ca0015}},	//   _миши, _ocur, hygg, نبري_
  { {0x7bcd0024,0x55ba009d,0xf992000a,0x6fb60015}},	//   ļauj, _שמקו, קרן_, لمزا
  { {0xb4d2005d,0xa3e5005d,0xee3a1305,0x6f630015}},	// [4f00] वती_, भेद_, кна_, يهِم
  { {0x531b004c,0x8e070342,0x9d46004a,0x7c3b2910}},	//   _שויצ, инув_, иезд, _acur
  { {0xc27b0008,0xed360010,0x0479002b,0x2b4d2911}},	//   _סרטי, рэзэ, _شلیک_, _apec_
  { {0xdd8f0002,0x91bb000a,0x71bb000a,0x8c462912}},	//   بوم_, _ימיי, _יציג, реде
  { {0x29050061,0x6aaa00da,0xd369000a,0xbb430165}},	//   _atla_, tiff, ָיו֙_, жечк
  { {0xa176000a,0xcb070015,0x3eb80085,0xdb090067}},	//   ֹעֵד_, جيون_, _ujrt_, ازنه_
  { {0x661a2913,0xe718002b,0x6e470030,0x6aaa2914}},	//   vatk, گيخت_, ésbő, riff
  { {0x8d5b000a,0x6d5c2915,0x6aaa0123,0x20002916}},	//   _בכלי, _isra, siff, ncii_
  { {0xd6da0f13,0x69c500b8,0x661a2917,0xdc9b004f}},	//   кто_, üher, tatk, _סימל
  { {0x752f005c,0x7afd02c1,0x06980015,0x5678006b}},	//   ączn, _ésta, اندة_, убоя_
  { {0x2000002c,0x661a2918,0xba9b000a,0xfdf7000a}},	//   kcii_, ratk, _שסבי, יצית_
  { {0xb4c3005d,0x20d70064,0xd7e60036,0x69da0192}},	//   ्ते_, eçin_, _кіло, _izte
  { {0x6486002d,0x661a0375,0x98a72919,0xd80b000a}},	//   _póir, patk, atnē_, _יִגָ
  { {0x98a70011,0x171b000f,0x0737000a,0x2369006f}},	//   pună_, _יודע, _כאדם_, _vraj_
  { {0x30a71cbe,0x067b000a,0xd6db000a,0xbbd3000b}},	//   арав, _בנגל, _שחול, _तर्क
  { {0xe3b80061,0x64a4012e,0x64c4006e,0x0000006a}},	//   ğır_, _маја, _ويول,
  { {0xe3b80064,0xa857000a,0x6d4e003d,0xb4b5000b}},	// [4f10] şır_, סימה_, _apba, ड़की_
  { {0x42550087,0x7c3b0939,0xde1900e5,0xa2d50015}},	//   _اندر, _scur, اقات_, _ديخت
  { {0xb2bc0008,0xc2120008,0xd657000a,0x3949002a}},	//   _במזר, _מהי_, שיבת_, łasz_
  { {0x31560053,0x4439291a,0x3a2501b3,0x6720003d}},	//   _פירן_, ngs_, _sdlp_, ksmj
  { {0xbb490015,0x6d5c0061,0x6b651028,0x6285291b}},	//   التن_, _esra, скла, _koho
  { {0x5a470010,0x6285291c,0xd358000a,0x6b8b291d}},	//   рэда, _joho, יידי_, rygg
  { {0x8d950029,0x69da005c,0x5d850029,0x6285291e}},	//   _الأش, _czte, _الزل, _moho
  { {0x9601005d,0xb4c3000b,0x27ff0003,0xab95005e}},	//   ोर्ट_, ्तो_, ucun_, _либі
  { {0xb8fe014e,0xd7060080,0x2019291f,0x9a270015}},	//   _दी_, бные_, _mesi_, _نعان
  { {0xf6690018,0x27ff1722,0x44392920,0x6285013f}},	//   احظه_, scun_, egs_, _noho
  { {0x752f005c,0xfe9a000a,0x79a72921,0x6c99000a}},	//   ączo, ריתמ, _трае, ָשָׂ
  { {0x6486002d,0x7c390a99,0xf992000a,0x38ba003d}},	//   _cóip, ngwr, _מרב_, pīra_
  { {0x26d908e0,0xc7f60008,0xd8d60135,0xe60e2922}},	//   ïsos_, _הזנת_, _פונט_, _нд_
  { {0xcb12013a,0xd2950036,0xf772000a,0xeb92000a}},	//   הלך_, орсь, _מקד_, פָר_
  { {0xdddc0011,0x20190509,0x40962923,0xcad6000a}},	//   _morţ, _besi_, брат, מושת_
  { {0x387f2924,0x66180061,0xb099005e,0x10a32925}},	//   njur_, _zevk, атує_, писн
  { {0xa067010f,0x3ed60015,0x20000d71,0x20b50033}},	// [4f20] щата_, مقرر, rcii_, цёрс
  { {0xdc10005d,0x1fb513ae,0xe45f0123,0xdd2c0091}},	//   ार्ड_, істр, slöt_, rėžt
  { {0x387f002e,0xcf890135,0x8cc40065,0x6df90138}},	//   kjur_, עט_, िकलो, рхус_
  { {0x2019003f,0x6ca5005e,0xa5da004c,0x0548004c}},	//   _gesi_, оріж, אַדי, שטאָ_
  { {0x387f00c0,0x38c8002b,0x64ab0046,0x629c0046}},	//   djur_, یابی_, dřil, ohro
  { {0x6e96003b,0x5e960029,0x2010005c,0x6d5c002d}},	//   _السا, _السط, łnić_, _tsra
  { {0xbad50010,0x3e850089,0x89630015,0x67222926}},	//   ціцы, _dítě_, كُون, _svoj
  { {0xc1730008,0x387f002e,0x66180064,0x8c432372}},	//   לחו_, gjur_, _sevk, _несе
  { {0xdddc0011,0x7f4404aa,0x67200085,0x66180e01}},	//   _forţ, ntiq, usmj, _pevk
  { {0x1f5b039e,0x2f5b000a,0x8f9b05bd,0x3ce620d4}},	//   נדיא, נדינ, טיפי, lmov_
  { {0x69960036,0x984a0063,0xd6d9002a,0x98c40061}},	//   _урах, _бяла_, atło_, ştım_
  { {0xc97701e4,0xc8650029,0xfbdc005d,0x58f7000a}},	//   _לגבי_, _وطني, _बराम, _הצאן_
  { {0xc5f80024,0x20192927,0x44392928,0x62852929}},	//   ldēm_, _resi_, rgs_, _poho
  { {0x1757000a,0xc513002b,0xc5940004,0x2019292a}},	//   _לסדר_, _کبوت, _милј, _sesi_
  { {0x41e40010,0x55060001,0xc69301ac,0xc10500a2}},	//   зіта, _учла, _מאס_, توزي
  { {0xb5b70008,0x3eaa0079,0x3ce6292b,0x5f450058}},	//   _ללוח_, _ambt_, jmov_, ينزل
  { {0x628501b2,0x20190209,0x4429292c,0xdde1002a}},	// [4f30] _toho, _vesi_, _ida_, łuże
  { {0x68fa292d,0xc332000a,0x43d40040,0x4155292e}},	//   _outd, _קוי_, _عزيز, _двос
  { {0x7f440003,0x27370046,0x7bf901c5,0xf2d4000a}},	//   atiq, ožná_, анер_, _מעץ_
  { {0xfc300074,0x3e850089,0x9cc8004a,0x9b950021}},	//   فحه_, _sítě_, быча_, يلات
  { {0xa03a00b2,0x644d002f,0x903a00b2,0xdddc0011}},	//   _דערפ, _mbai, _דערה, _porţ
  { {0x660d0085,0xd5b7004a,0x1989004a,0x7c390034}},	//   _đako, ́сь_, ибли_, sgwr
  { {0x644d002f,0x09e2000d,0x64ab0089,0xfce90015}},	//   _obai, мошн, třil, _نفسي_
  { {0x7afd02c1,0x6d45002d,0x4429292f,0xcb090015}},	//   _ésto, mtha, _nda_, _نيرن_
  { {0x66040064,0x6d452930,0x86790033,0x387f0045}},	//   _şika, ltha, аёну_, rjur_
  { {0xda02005d,0xab5d005c,0x2caf0111,0x6d45091f}},	//   रुआत_, _wyżs, ligd_, otha
  { {0xe4520029,0x7afb008c,0x20d70061,0x6d452931}},	//   وضح_, _huut, eçim_, ntha
  { {0x6d450176,0x2caf0111,0xc2090008,0x44292932}},	//   itha, nigd_, _יה_, _cda_
  { {0x44290176,0x43930010,0x7afb0604,0x6b56000a}},	//   _dda_, даўс, _juut, ֗ישׁ_
  { {0x7afb0e2b,0x2bdc000b,0x644d007c,0xf6e7096d}},	//   _muut, _बरसा, _ebai, _уцен
  { {0x0446010f,0xd175004a,0xf41f008c,0x70560021}},	//   _дейн, пыты, tkät_, ينسا
  { {0x629c0479,0x100a0015,0xdddc0046,0x838a005e}},	//   shro, شترى_, _norš, _вбив_
  { {0xdfcf003b,0x6d450176,0xa2d60029,0x3f670063}},	// [4f40] نيف_, etha, _ويعت, оито_
  { {0x44292933,0xcdd60001,0xdb0a0030,0xbd2a0015}},	//   _zda_, оцењ, önít, لأصل_
  { {0xbfa30023,0x22582514,0x7f4405d4,0xed5a05c4}},	//   _hiể, merk_, stiq, рое_
  { {0xbfa30023,0xa3be005d,0x82360086,0x9f060015}},	//   _kiể, _आशा_, _ارکا, _ووجو
  { {0x7c290176,0xdee60661,0x4ae60010,0x6d452934}},	//   _dder, _моми, оўка, atha
  { {0x7c2901e2,0x752f0050,0xada62935,0x6da60588}},	//   _eder, ńczy, _дагл, _дига
  { {0x7c24002d,0xfaa30004,0xc27b004c,0xb05b186f}},	//   óirs, ќајо, ירסי, _fjäd
  { {0xd90d0086,0x2c100065,0x6fde0065,0xa8ea0058}},	//   این_, ारओं_, _मरां, جعتك_
  { {0x8b660086,0xc6f70010,0xda0b021e,0xa09b000a}},	//   _بازم, оных_, _स्वत_, ייקט
  { {0xe7e0005d,0x09e60658,0xd6930015,0xd6da0b1e}},	//   खेगा_, _дозн, ِشَة, јти_
  { {0x7c2900fb,0xa8060010,0x5dfb000a,0xf5200033}},	//   _yder, _дзел, יפינ, эннi_
  { {0xbfa30092,0xe4a70036,0xaaa6000b,0xc87f0012}},	//   _biể, ірно, कोरक, ößt_
  { {0x443f0024,0x6d450030,0x68420046,0xa01b0416}},	//   ļu_, ztha, _vůdč, _glöy
  { {0x443f005c,0x02040010,0x6d4500e7,0xc7d7004f}},	//   żu_, дзён, ytha, _וודי_
  { {0x60d60026,0x8637000a,0x34952936,0x7ea00012}},	//   flym, _ורוב_, _накр, _köpf
  { {0xd5b90036,0x66cf003c,0x212d00bc,0x44292937}},	//   _усі_, søkt, čeh_, _uda_
  { {0x644100dc,0x68e20125,0xbdfb0040,0x6f0d2938}},	// [4f50] őlis, _mhod, لرضا_, upac
  { {0xa2b4005f,0x7d6b068e,0x7afb0201,0x64ab0046}},	//   _обыч, ишев_, _ruut, křik
  { {0x71270086,0x7afb0209,0x68e20264,0x2caf0079}},	//   _برخل, _suut, _ohod, tigd_
  { {0x6d45017e,0x7afb0044,0x55bb000a,0x6f0d1c73}},	//   rtha, _puut, סמאו, ppac
  { {0x0f7900b2,0x907a0008,0x8234002b,0x207a015b}},	//   _האָב, _הטרי, _عریا, _הארא
  { {0x53380008,0x4efa000a,0x9aa40015,0xdaa800fd}},	//   קנון_, _להשו, ومنو, овід_
  { {0x26cc0ef3,0x1c570015,0xdcff003d,0x929c000a}},	//   dodo_, _وخرج, ēvēt, שיות
  { {0x41bc0008,0xc1bc0008,0x77850063,0x60cd2939}},	//   יצוע, ימוש, злиз, noam
  { {0x64ab0089,0xe7310015,0xd706004a,0x907c000a}},	//   přij, رصة_, пные_, שטחי
  { {0x60cd293a,0x26cc039f,0x0000006a,0x0000006a}},	//   hoam, godo_,   ,
  { {0x2258293b,0x9e48000a,0xd46a098b,0xceb2000a}},	//   verk_, חֲרִ, бине_, תיי_
  { {0x22582707,0x60cd008c,0x2a651804,0xfde3000b}},	//   werk_, joam, _halb_, केएस_
  { {0x26cc00bd,0x68e9293c,0xb7fa000a,0xf8b2000a}},	//   bodo_, mmed, _הפנת, _אשא_
  { {0x68e213ce,0x98a00007,0x2cbf00c0,0x68e9293d}},	//   _zhod, čią_, _ljud_, lmed
  { {0x66cf003c,0x4096293e,0x5502000b,0xa696000a}},	//   søks, прат, _रूपए_, _מכסה_
  { {0xb05b01d1,0xbfa30092,0xe0da02bf,0x68e9293f}},	//   _skär, _tiể, ёва_, nmed
  { {0xdfd20029,0x22582514,0x44222940,0xc43b0008}},	// [4f60] ريط_, perk_, mak_, _התפי
  { {0x1ea90015,0x2216004a,0x2ec6000b,0x44222941}},	//   يالي_, _эфир, ववेत, lak_
  { {0x2cbf00c0,0xc194002b,0x81fb000a,0x01fb000a}},	//   _bjud_, _غیرع, _להיז, _לפיל
  { {0x44222942,0xb17b004f,0x0000006a,0x0000006a}},	//   nak_, _הטטר,   ,
  { {0x68e21ea9,0x44220030,0xf236004f,0x0000006a}},	//   _rhod, iak_, ֤רֶץ_,
  { {0x68e202d5,0x44220375,0xfaa3004a,0x2a650144}},	//   _shod, hak_, начо, _calb_
  { {0x20070050,0xda6500e5,0xceb3004c,0xfe9b0643}},	//   śnie_, باني, _טיש_, _פילמ
  { {0x7ce30020,0x4422119a,0xd8e30033,0xc0ad000a}},	//   võrg, jak_, нцып, ֙יהָ
  { {0x44220931,0x6c7b0053,0x68e22943,0x248900da}},	//   dak_, _פאמפ, _vhod, _roam_
  { {0x7bcd0048,0x60cd1cec,0x6b9b000a,0x24570016}},	//   ļaut, zoam, _השמד, _ầm_
  { {0x1dbe005d,0x26cc0007,0x68e9002c,0x68360061}},	//   ्थित, rodo_, bmed, güdü
  { {0x7c2216d3,0xcdb7000a,0x78fb000a,0x4422015a}},	//   naor, לפיה_, _הפאו, gak_
  { {0x6d5e0034,0x60cd074b,0xb4bd0065,0x2489059d}},	//   hwpa, voam, _आदी_, _voam_
  { {0x44220234,0x35b4005e,0x6d410123,0x7ce3007c}},	//   aak_, _облр, _ålag, põrg
  { {0x60cd0983,0xd0d5006b,0x31c41119,0x35d3004a}},	//   toam, довъ, еств, _пошё
  { {0x442201e2,0x7c22003f,0x55bb000a,0x753a0012}},	//   cak_, jaor, _למוו, mutz
  { {0xd3710029,0x289b004c,0x60cd2944,0x290c09ae}},	// [4f70] _شهد_, צימא, roam, _ltda_
  { {0xaa160033,0x765a2945,0x68e92946,0x60cd2947}},	//   _дзiц, nety, zmed, soam
  { {0x753a018b,0x68e90026,0x765a008c,0xaff90015}},	//   nutz, ymed, iety, _وفدا_
  { {0x765a00f2,0xdddc0535,0x0000006a,0x0000006a}},	//   hety, _barł,   ,
  { {0x753a00b8,0x7ce3007c,0x765a2948,0x68e92949}},	//   hutz, võrd, kety, vmed
  { {0x9f96013a,0x88bc0089,0xc334000a,0x68360061}},	//   _חדשה_, _dvěm, תוס_, yüdü
  { {0xbd4500a2,0x98e50015,0x4422294a,0xaa560054}},	//   _تنزي, وكتو, yak_, фију_
  { {0x38ca0074,0x219c000a,0xc19c004f,0x88350138}},	//   يايی_, מבוא, משוי, фэкц
  { {0xcb340063,0x44220c0a,0xccf2000a,0x7bcd003d}},	//   _петъ, vak_, _יכל_, ļaus
  { {0x4422294b,0xfaf30015,0xa3c3000b,0x765a294c}},	//   wak_, _أثر_, ्थन_, gety
  { {0x4422294d,0x228f0061,0x98a7002a,0xe5a5011a}},	//   tak_, _lüks_, erną_, фини
  { {0x19b80015,0x68360061,0xe9380058,0x7e670160}},	//   _عطلة_, rüdü, _رسمت_, _lajp
  { {0xd62907c1,0x442228f8,0xb383007a,0x0ebf000b}},	//   _доле_, rak_, влял, ्वाड
  { {0x7ea0294e,0x7e6705f2,0x4422294f,0x765a2950}},	//   _köpe, _najp, sak_, cety
  { {0xaca30092,0x2d47007c,0x614315f4,0x21670bdb}},	//   _chừn, jõe_, кера, мири_
  { {0x98a0016f,0xe0da02e1,0xc5f2000a,0x250a002b}},	//   čić_, іва_, _בדו_, _بروی_
  { {0x7ea00123,0x2484001a,0xf1fa0015,0x44200045}},	// [4f80] _löpe, ömmu_, _وعدت_, _iei_
  { {0xf7670074,0xfd9a0015,0x44202951,0x3f800144}},	//   _یا_, يئات_, _hei_, rxiu_
  { {0xf27b000a,0xdd920015,0x2294008c,0x656f0016}},	//   _וריש, خوض_, _näki_, ́chn
  { {0x44200780,0x2372002a,0x98a7005a,0x0000006a}},	//   _jei_, _kryj_, runě_,
  { {0x6b760015,0x765a00aa,0x7c222952,0xaae6006e}},	//   بطاط, yety, raor, وستو
  { {0x3866002f,0x34bb005d,0x44202953,0x7125009a}},	//   _saor_, _उद्द, _lei_, _تریل
  { {0xd90d0074,0x2f0400c0,0x38c30091,0x38660125}},	//   میل_, _hög_, kūrę_, _paor_
  { {0x2c760015,0x909b004c,0x44202954,0xdddc0535}},	//   _تُرس, ַסיק, _nei_, _tarł
  { {0x6f02017e,0x765a2955,0xb6f4049d,0x60d705bd}},	//   íoch, tety, нзиј, ווקא_
  { {0xfd8a000a,0xf76f0015,0x69960195,0x753a02ad}},	//   ַטָּ, شاً_, _орех, tutz
  { {0xf76f04b6,0x2f04002e,0x44202956,0x765a005c}},	//   های_, _lög_, _bei_, rety
  { {0x442004f9,0xf3ff016e,0x94ab00fd,0x6ba30061}},	//   _cei_, rdão_, ітна_, _övgü
  { {0xd7e2005d,0x4420124d,0x38cb002b,0xe7e2000b}},	//   _परिच, _dei_, _بالی_, _परिप
  { {0x7d032957,0x442012cf,0x753a02ad,0xddd50de4}},	//   ínsk, _eei_, putz, _rozž
  { {0xe63b0008,0xd4db0029,0xd5af0f09,0xd657000f}},	//   _ותוכ, _وبعض_, _рс_, _חיות_
  { {0x7c202958,0x83aa000b,0x629e003d,0x44200034}},	//   _nemr, _चेकआ, _elpo, _gei_
  { {0x645d2959,0x9e150033,0xb146002b,0x5e6b00af}},	// [4f90] mesi, едзі, وییم_, жјег_
  { {0x1e340033,0x4420295a,0x645d295b,0xc6d8000a}},	//   кнуў, _zei_, lesi, פַּר
  { {0x21270016,0x7d1c0034,0x752801ec,0x0000006a}},	//   _ình_, _cwrs, nsdz,
  { {0x8b6b0048,0x645d295c,0xd196004f,0x0000006a}},	//   ņēmē, nesi, _נכרי_,
  { {0xe452000f,0xcf270087,0x645d295d,0xeb98005e}},	//   רֶב_, _ترجي, iesi, миї_
  { {0x2d47001c,0x314b000a,0x645d0390,0x8f1a000a}},	//   põe_, ַתִּ, hesi, _מושת
  { {0x7d1c0026,0xac19226a,0x28f50004,0x645d295e}},	//   _gwrs, _нову_, нџис, kesi
  { {0xe3b80064,0xa7650775,0x645d295f,0x5fd9000a}},	//   ğız_, екид, jesi, ּחֻק
  { {0x59e1005d,0x44202960,0xd5b10092,0xfbd3002b}},	//   _फरवर, _rei_, hát_, _شتر_
  { {0x3964022d,0xe6110029,0x458508dc,0x44202961}},	//   ässä_, دشة_, егов, _sei_
  { {0x48150010,0xa5220010,0x04462962,0xa8150121}},	//   _змес, лмэд, ненн, _здеш
  { {0xf7710029,0x64ca000b,0xd46a0004,0xf916000a}},	//   _مات_, रवेश, чиме_, _נחנך_
  { {0xe72e2963,0x5695008f,0xaca30023,0x33d5005e}},	//   _ще_, _падт, _chứn, вірт
  { {0xa7640036,0xcb12000a,0x44202964,0xd6a80058}},	//   _шкід, רלם_, _wei_, _يدوم_
  { {0xe9c7002b,0x6729286f,0x11da0015,0x645d2965}},	//   اغ_, lsej, سورة_, besi
  { {0x645d2966,0xf41f008c,0x20e80012,0x9e66002b}},	//   cesi, ljän_, ißig_, کارن
  { {0x672902c1,0x96a6000b,0x8fa3009f,0x4425006e}},	// [4fa0] nsej, टोकॉ, гате, _شريف
  { {0x6da60cab,0x2fd90034,0x7c2001d7,0x76412967}},	//   низа, _dysg_, _semr, ngly
  { {0x06960053,0x2007005c,0xe0da05e6,0xfd120015}},	//   עדעם_, śnia_, _нво_, اجئ_
  { {0x0ca90029,0x99620089,0x61e118b8,0x67292968}},	//   وطني_, tíže_, ülle, ksej
  { {0xeb97005f,0xc5f80024,0xc053000a,0x6ffb000a}},	//   ниц_, ldēt_, _גזר_, _מהכפ
  { {0x29660001,0x645d0281,0xef11004c,0x672902de}},	//   ењив, zesi, _כּל_, dsej
  { {0xed570080,0x645d0064,0xc94f0010,0xdc34002c}},	//   _пор_, yesi, ыў_, lúči
  { {0xd90d002b,0x3157000a,0x49b70015,0x987400ce}},	//   زیه_, תיקן_, عاود_, тлиц
  { {0xb907005d,0xb8e8000b,0x645d2969,0xdca3105a}},	//   _मी_, _ईद_, vesi, _сати
  { {0x67530029,0x645d00dd,0x5574005e,0xa96a0180}},	//   اخير, wesi, вгот, _низа_
  { {0x7d0928cc,0xf99f000d,0x645d296a,0x7afa008c}},	//   _česk, _сè_, tesi, _iitt
  { {0x77920086,0x7afa02d2,0xddc7003d,0x63a2002a}},	//   _میبا, _hitt, _sajū, _żona
  { {0x92820053,0x08770053,0x645d296b,0xdc340057}},	//   אַטן_, _רעדט_, resi, júči
  { {0x877b00b2,0xf77300a3,0x645d296c,0xe3bf0077}},	//   _מאדי, _תקס_, sesi, gaña_
  { {0x7afa296d,0x81d5005e,0x753d002a,0xb5460015}},	//   _mitt, товх, ąszc, _أخته
  { {0x7bde0050,0x95530015,0x5577000a,0x7afa296e}},	//   ępuj, _إخوا, _טעון_, _litt
  { {0x9f34005e,0xa857004f,0xf0b8009a,0xe3bf039f}},	// [4fb0] леті, עימה_, رافش_, baña_
  { {0x1bf6000b,0x3f870085,0x7c24001a,0xa3aa000b}},	//   ेशनल_, ćnu_, ðirn, _गेट_
  { {0xeab1002b,0x2fd90034,0x69da0789,0xddab02ed}},	//   یعت_, _wysg_, _nyte, чтал_
  { {0xbc380015,0xc5f8003d,0x7c841372,0xd116000a}},	//   فسها_, ldēs_, луче, _שקרה_
  { {0x69da0035,0x5fe4017f,0x7afa296f,0xf41f008c}},	//   _ayte, _бірж, _bitt, yjän_
  { {0x7afa02d7,0x1ee70086,0xc5f8003d,0x68f90034}},	//   _citt, _سوزی_, ndēs_, _siwd
  { {0xba280029,0xa96601e5,0xfaa20c31,0xd942006b}},	//   رسوم_, вища_, ращо, аещи
  { {0x67290020,0xc1740008,0x7afa002e,0xa3c3005d}},	//   tsej, רחק_, _eitt, ्था_
  { {0x07a5000d,0x7afa2970,0xd6390033,0x67290046}},	//   тапн, _fitt, мяні_, usej
  { {0x7ea000c0,0xd6ce00e6,0x9732002b,0x79a70a32}},	//   _köpa, يقي_, شکها, _прее
  { {0x64a62971,0x89340002,0xe8550015,0xceb4004c}},	//   вана, _معنا, _لناد, טיץ_
  { {0xe7b2002b,0x7afa2972,0x04960033,0xf2c9000a}},	//   امید, _zitt, троў, _וע_
  { {0xccf20053,0xe3bf02c1,0x7ea00123,0x386d2973}},	//   יכט_, taña_, _löpa, mder_
  { {0x64410007,0xda0e0016,0x386d0ef2,0x0000006a}},	//   ėlia, hỏng_, lder_,
  { {0xaca300a7,0xe5a20036,0x0636000a,0xda48000a}},	//   _nhữn, _вищи, _סנקט_, עֲשָ
  { {0x9282004c,0x386d2974,0xafe600ce,0xd00f009a}},	//   אַכן_, nder_, вобл, قلف_
  { {0xb05b01d1,0xe3bf0467,0x02d60015,0x6fd6005e}},	// [4fc0] _tjän, paña_, _لتدخ, тівц
  { {0xb05b01d1,0x386d0026,0x9522002b,0x91d6000b}},	//   _hjäl, hder_, _حکیم, _मुथै
  { {0x44320089,0x2d9c002c,0xec4a0010,0x7afa25d0}},	//   _kdy_, áve_, дзел_, _ritt
  { {0x6aa10026,0x2ca0002d,0x7afa2975,0x386d2976}},	//   _allf, óid_, _sitt, jder_
  { {0xef17005f,0xcb540029,0xbb540015,0x7afa04a0}},	//   _имя_, انتظ, انتب, _pitt
  { {0x2a360010,0xdb1100dc,0x61e90046,0xab93005e}},	//   тэдр, ágáb, řele, риші
  { {0x7afa2977,0x58860033,0x89630015,0x0e57000a}},	//   _vitt, выпа, لُون, _ששלט_
  { {0xfce62978,0xac050015,0xa9670054,0x7afa2979}},	//   _робо, _مذكو, тића_, _witt
  { {0x47340124,0xc6f82031,0x7afa02d2,0xec37000a}},	//   ћнос, нних_, _titt, _שאמר_
  { {0x7afa0409,0x4de6000b,0xda660015,0xd5ba0004}},	//   _uitt, _कराई_, _جاري, дсм_
  { {0xceb3013a,0x22940020,0x7c2d001a,0xcad7000a}},	//   שית_, _läks_, ðarg, _יומת_
  { {0x79b7013a,0x6fb4005d,0xa923006f,0x649f00aa}},	//   _בלבד_, ूपां, ôžem, _eëin
  { {0xa3e8000b,0xf743005e,0x07a3006b,0xa8a50015}},	//   _भरण_, _вечо, _кацн, _حصلو
  { {0xf2c401c5,0xa2c40054,0x4432297a,0xaacb0065}},	//   ассн, аљск, _edy_, िवएक
  { {0xe2f80036,0xd9f4000b,0x94ab0015,0xf2df0045}},	//   тері_, ेखित_, _يطبق_, ntâi_
  { {0x44320050,0x30a4297b,0x61e50089,0x224d0046}},	//   _gdy_, арув, _vzhl, řek_
  { {0xe3bf02c1,0x26de18d8,0x1eab0015,0x2d8e0012}},	// [4fd0] maño_, olto_, وائي_, äfen_
  { {0xa01b0111,0x603e0045,0x64ab0046,0x78a20077}},	//   _coör, tămâ, přis, _llov
  { {0x44320026,0xe3b00086,0x386d297c,0x9e0400d0}},	//   _ydy_, _هری_, yder_, рчул
  { {0xe7e2005d,0x5ce40033,0x603e0045,0xcc140015}},	//   _परंप, аюча, rămâ, لذهب
  { {0xd5b10016,0x386d04d1,0x9056000a,0xfc64006b}},	//   háp_, vder_, _גברו_, ръхн
  { {0x386d003e,0xab7600c3,0x4a44005e,0x539c05bd}},	//   wder_, اموا_, инів, וידו
  { {0x79a70063,0x27e600dc,0x5a440010,0xb7bd0091}},	//   ърде, _azon_, рэча, taţo
  { {0x01fc0008,0xfc300015,0x2ca6297d,0x386d0602}},	//   ופול, _وحق_, chod_, uder_
  { {0xbc9401ca,0x386d297e,0xfb84009a,0x753a02ad}},	//   _татј, rder_, _نگوی, ertz
  { {0xb05b01d1,0xe7680015,0x78a20030,0x7ea00123}},	//   _själ, ئحين_, _elov, _löpn
  { {0x69c404f9,0xd6d9002a,0x998c0030,0x3915147f}},	//   şier, guła_, _fedő_, _смер
  { {0x79b6000a,0x3a25297f,0x79a40004,0x78a20aa0}},	//   _גלעד_, _help_, _труе, _glov
  { {0x20070089,0xc7a80015,0xaca30016,0xdcef0091}},	//   ěnil_, _لدول_, _nhửn, šdės
  { {0x2ebf005d,0x8bd6000a,0x3a2500cb,0xd6d9002a}},	//   ्वोत, רושו_, _jelp_, buła_
  { {0x2905016f,0xf652000a,0xe1950033,0x629c2980}},	//   _jula_, _הצו_, артэ, rkro
  { {0xa06717b7,0x29051636,0xf536000a,0xab5d002a}},	//   ласа_, _mula_, _ענפי_, _wyży
  { {0xbd8a0086,0x3fe60e44,0x29051e46,0x78be0030}},	// [4fe0] کنان_, ужав, _lula_, épvi
  { {0x7e230036,0x98a70089,0xa3c3000b,0x93fb000f}},	//   йдуж, trně_, ्थर_, _אלפי
  { {0x88bc0089,0x2ca60495,0x21762981,0xad5a0033}},	//   _květ, thod_, _супр, эрах_
  { {0xd4370053,0xb5fa0053,0xa3e8005d,0x64462982}},	//   ָרסק_, גלעכ, _भरा_, ngki
  { {0xda7a0033,0x60c4035f,0x6e390046,0x6ab82983}},	//   еяй_, mnim, _říší_, tivf
  { {0x6d260029,0xcb070029,0x60c42984,0x673b0a52}},	//   _معرك, ديون_, lnim, druj
  { {0x7d03002e,0x2480016f,0x89330015,0xada60054}},	//   ínst, _onim_, معيا, _савл
  { {0x7d7b000a,0x60c42985,0x4734249a,0x6d4e03e1}},	//   _אנלו, nnim, анис, _iqba
  { {0x7c93003b,0xf0930008,0xffb70053,0x86260449}},	//   _القص, מנה_, ָליש_, льне
  { {0x05b2005d,0x248002f2,0x7bcb000a,0x64461b8e}},	//   ुपलब, _anim_, _אֶבֶ, egki
  { {0x68460029,0x60c42986,0x24190256,0xe3bf0077}},	//   _مَال, knim, коны_, taño_
  { {0xa3c3005d,0x13f50036,0x6446003c,0x7e6e0024}},	//   ्थल_, изня, ggki, _labp
  { {0x60c42987,0x3eba001a,0x6eeb0475,0x91cd0065}},	//   dnim, kipt_, lübe, _दुजै
  { {0x2369018c,0x91d6000b,0x6d5c0c6d,0x24802988}},	//   _vsaj_, _मुहै, _opra, _enim_
  { {0x6eeb2989,0x86c30015,0x8934000a,0x60c40012}},	//   nübe, _ديون, יָּא_, fnim
  { {0x30150bdb,0xa01b0079,0x60c4298a,0x13a7009a}},	//   рдар, _coöp, gnim, _منعی_
  { {0xe4500029,0x6d5c1ce1,0x442b298b,0x0000006a}},	// [4ff0] _رضي_, _apra, mac_,
  { {0x88bc0089,0x4fc40010,0x442b298c,0x325509d3}},	//   _zvět, ёста, lac_, _твор
  { {0x60c400bd,0x12fa000a,0x1a65002b,0xec15006e}},	//   bnim, _שהתב, ییری_, لواد
  { {0xb19a013a,0x29050011,0x442b298d,0x711a004f}},	//   _ייתכ, _rula_, nac_, _שורפ
  { {0x2905002f,0xcb69298e,0x442b002c,0x76580107}},	//   _sula_, тале_, iac_, _obvy
  { {0x5fba0008,0x29050375,0x4f3a000a,0x7f3a000a}},	//   _יצרנ, _pula_, _בתשע, _בעשו
  { {0x0dc80191,0xe5090023,0xa2d6005d,0xaab6000b}},	//   _бути_, _mặc_, णवत्, _अगरक
  { {0x38ba138a,0xb8f20015,0x29190046,0x3cf80015}},	//   tūra_, يكوب, _čsad_, _معقد_
  { {0x6d5c02d5,0x8b5804c9,0x656a0125,0x442b298f}},	//   _zpra, _مجلس_, _asfh, dac_
  { {0x88bc0089,0x60c400bd,0xab940015,0x55f5004a}},	//   _svět, znim, _الْغ, ичну
  { {0xda7a0008,0xd5e5005e,0x60c41ed6,0x442b2990}},	//   _שנער, ржни, ynim, fac_
  { {0x2007005c,0x38ba003d,0x7c2b2991,0x0000006a}},	//   śnij_, pūra_, nagr,
  { {0x60c400bd,0x9cd60008,0x889a000a,0x78a900cb}},	//   vnim, שורה_, _שבני, mhev
  { {0x6e270089,0x7ea00061,0x9756000a,0x11d60058}},	//   _nejb, _röpo, _כינו_, لتأد
  { {0x76ba009d,0x6f06005c,0x00e40086,0x60c403df}},	//   _במספ, _sukc, متری, tnim
  { {0x661c0064,0x8066049d,0xa3b1000b,0x7c2b1523}},	//   ırke, јваж, _टेक_, jagr

  { {0xa0670403,0xb4c4000b,0x2e160015,0x6d5c2992}},	// [5000] шата_, ्वी_, لباح, _spra
  { {0xdddc002a,0xa6f9000a,0x60c42993,0x2d9a2994}},	//   _garś, דִ֣י, snim, type_
  { {0xd23b000a,0x823b000a,0xc0e60033,0x4d6602bb}},	//   _בגיל, _בעיצ, _вонк, ркев
  { {0xeb9a005f,0xfce30036,0x7c2b00dd,0x6d5c0ea5}},	//   кие_, оохо, gagr, _vpra
  { {0xa0c60086,0x6d5c002a,0x62050030,0x26c20030}},	//   _ميگو, _wpra, _átlá, ékok_
  { {0xba1700e6,0x442b2995,0x0377000a,0x3d28002b}},	//   ليها_, zac_, יתנת_, _متری_
  { {0x67220050,0x0076000a,0x2d87008c,0xba290015}},	//   _swoj, ֹתִי_, änet_, اسهم_
  { {0x2d680064,0x6eeb136c,0x67640015,0x8c43113a}},	//   _işe_, rübe, مُعل, _месе
  { {0x442b2996,0x57f3006b,0x6eeb0012,0x6009000a}},	//   vac_, опът, sübe, נִקְ
  { {0xf70800a7,0x7d000041,0x0f570008,0x64410007}},	//   _của_, _hims, סיים_, ėlim
  { {0x7d000064,0x75d40015,0x15aa006b,0x9e77000a}},	//   _kims, إيجا, тъпи_, בגיה_
  { {0x67220050,0xa4390010,0xa99b000a,0x08fa006e}},	//   _twoj, ызму_, _שבאר, _شراب_
  { {0xbf9b001c,0x32bb0015,0x2007002a,0x442b2997}},	//   _agên, ندسة_, śnik_, rac_
  { {0x673d00dc,0x442b2998,0x1bee000b,0x656f002a}},	//   ásje, sac_, _जरनल_, łcha
  { {0xc617000a,0x367b000a,0x361b000a,0x454400c3}},	//   _דחוי_, _שְׂע, _יוגד, _انعق
  { {0xd25104b6,0xd5fb0008,0x628e0844,0xffe70033}},	//   _کند_, _בפור, ajbo, аюзн
  { {0xc0f8005e,0xe5090016,0x7c2b0030,0x3f14006b}},	// [5010] ретє_, _tặc_, vagr, ждус
  { {0x7d00002f,0x44290005,0x4fc4078f,0xdd9b017c}},	//   _aims, _hea_, іста, кше_
  { {0x5dd50015,0xd167006b,0x5d551ac7,0x4ea401ca}},	//   حقائ, _тъпи, скет, црта
  { {0x5b250015,0x3211002a,0x5b3500c3,0x61e8007c}},	//   مفصل, lczy_, معتر, üdle
  { {0x44292999,0x7c2b299a,0xa3dd000b,0xcbc7002b}},	//   _mea_, ragr, _तुम_, جزاي
  { {0x3e570089,0x7d28002d,0x59550015,0xbbb7000b}},	//   _dětí_, úrsó, مخبأ, _अधीक
  { {0xb7bd0011,0xe50b005d,0x7c2b1634,0xec6b24f9}},	//   maţi, _संधि_, pagr, _ирак_
  { {0xb7bd04f9,0x6d45299b,0xf7080016,0x7d00299c}},	//   laţi, muha, _sủa_, _gims
  { {0x3c440029,0xaa67005e,0x6d451f85,0x78a920dd}},	//   _ذَلِ, _втек, luha, rhev
  { {0xb7bd04f9,0xf7080016,0x7d0001a3,0x7c29299d}},	//   naţi, _qủa_, _zims, _heer
  { {0xba740015,0x78a900cb,0x7c29299e,0x99870046}},	//   _باقت, phev, _keer, manů_
  { {0x442904f9,0x443e00b8,0xb4c4005d,0x1956000a}},	//   _cea_, ßt_, ्वे_, _לבעל_
  { {0x7ce30020,0x7c29299f,0x7c24001a,0x442929a0}},	//   tõrj, _meer, ðiri, _dea_
  { {0xb7bd0045,0x8bd6000a,0xf776000a,0x7c290653}},	//   jaţi, מורו_, _לעני_, _leer
  { {0xd24f0029,0x6d450020,0x44290ac5,0xb7bd0045}},	//   عنف_, juha, _fea_, daţi
  { {0x644d002d,0xdfd20029,0x6d450375,0x3eb80ea1}},	//   _gcai, كيز_, duha, _smrt_
  { {0x7f4a0029,0x7d0001a3,0xc4d3000a,0xbf650015}},	// [5020] طلاق_, _rims, _מגה_, يدكو
  { {0xb7bd0011,0xe45f00f2,0x7cea001a,0x7d0029a1}},	//   gaţi, nnön_, dýra, _sims
  { {0xf297000a,0x7dc50015,0x442900da,0x0ef90033}},	//   _הכיר_, يتمك, _yea_, рэты_
  { {0x30860029,0xf1c401b2,0xad250015,0x6c54005e}},	//   _الحف, alší_, تركو, іклу
  { {0xfb130029,0x7c2d001a,0x7c2929a2,0x6d4529a3}},	//   كونج, ðara, _deer, auha
  { {0xb7bd04f9,0xd3570008,0xdce80064,0x427a004c}},	//   caţi, מיני_, ılır, ראַג
  { {0xc27b000a,0xd90d002b,0x2d680045,0xfce608ad}},	//   טרסי, نیل_, _uşe_, _гово
  { {0x3ae9002f,0x89330015,0xf8af0015,0x3211002a}},	//   rúpa_, أعوا, ّةٌ_, zczy_
  { {0x4c350010,0xf62a005e,0x4fbb004c,0x3211002a}},	//   _фэст, ліни_, ָציא, yczy_
  { {0x6b7b013a,0x644d002d,0x44290c07,0xda0a0015}},	//   _גרמנ, _scai, _sea_, _إياه_
  { {0x2fc70023,0x44290020,0xa3ab000b,0x0000006a}},	//   ̃ng_, _pea_, कैन_,
  { {0xb7bd04f9,0xf1c00092,0x4d7b0053,0x7ce30020}},	//   zaţi, _ương_, ארטע, võrk
  { {0x442929a4,0x6d450bae,0x163406b9,0x67530058}},	//   _vea_, zuha, _деля, _فخور
  { {0x46f6005f,0x77f7000a,0x6d4502f2,0x4667006b}},	//   _учет, _המדד_, yuha, _гръм_
  { {0x3211005c,0xd6570008,0x44290100,0x30a71c0c}},	//   rczy_, _היות_, _tea_, брав
  { {0xfd4d0092,0x90550010,0xc5f30008,0x61e90046}},	//   _thoạ, ўвац, _צדק_, řelo
  { {0x59df014e,0xb7bd04f9,0xc2cb002b,0x141c000a}},	// [5030] _पुनर, taţi, _مبدل_, _עוזב
  { {0x2fc70023,0xaca30092,0x2aab0134,0xd2510086}},	//   ăng_, _khủn, _købe_, _کنگ_
  { {0xb7bd04f9,0x628509f2,0xa3c3000b,0x7c2929a5}},	//   raţi, _inho, ्थक_, _peer
  { {0x3c470029,0x6d4529a6,0xa3bd000b,0xb7bd0045}},	//   إضاف, ruha, _आधा_, saţi
  { {0xb7bd0011,0x2aab02de,0x7c290e8d,0x220b000a}},	//   paţi, _løbe_, _veer, ְפֵּ
  { {0x7c2929a7,0xab640010,0xfbd000c3,0x6d4529a8}},	//   _weer, явіл, رتن_, puha
  { {0x929c000a,0xa889006b,0x527a004c,0x9d18109b}},	//   ריות, ийка_, ינװא, _гост_
  { {0x6aa829a9,0x98bc01ec,0x0000006a,0x0000006a}},	//   _eldf, tuvā_,   ,
  { {0xdddc01e2,0xc9d30086,0x7a3400dc,0x62850546}},	//   _karş, _کماک, _sütő, _onho
  { {0x2bb80015,0x8f9c000a,0x628500cb,0xe7080015}},	//   _طاقة_, טיחי, _nnho, حتين_
  { {0xaca30092,0x25a300dc,0xf3e9000a,0x48390015}},	//   _chủn, ájl_, _סף_, _نكاح_
  { {0x39470341,0xe759005e,0x24f60033,0xe8f40015}},	//   muns_, _виді_, ўчор, _فسنخ
  { {0x8b99000a,0xcc56004f,0x0000006a,0x0000006a}},	//   ׁבֹת, חברי_,   ,
  { {0xe5a51dc9,0xcb12000a,0xe7160015,0x0000006a}},	//   _мили, ולך_, _بيوت_,
  { {0xc616000a,0xa2e31c4d,0x409620b9,0x0000006a}},	//   _וחצי_, форд, орат,
  { {0x6ab6005d,0x00e601f3,0x26c2006f,0x628521e8}},	//   _अग्र, іжан, ékov_, _enho
  { {0xdd010046,0x8afd0046,0xddc700bc,0xe0d701c6}},	// [5040] štěs, _zpře, _rajš, іву_
  { {0x1eaa0029,0x539b00a3,0x7ea00123,0x7c2d001a}},	//   جاري_, _כיפו, _köpi, ðarn
  { {0x5c06033d,0x394729aa,0x5d6a008a,0xac0a011e}},	//   ояла, juns_, рием_, анеа_
  { {0x23770086,0x7be6005e,0xb40d000a,0x7c831673}},	//   _امید_, ожеж, ְלוֹ, душе
  { {0x845b000a,0xbc6702be,0x0000006a,0x0000006a}},	//   שכנז, زمون_,   ,
  { {0xbab70010,0xeaf70015,0x5f27187f,0x3156000a}},	//   огіх_, يروت_, _форм_, ַיִן_
  { {0xda650029,0x394729ab,0xa2cd021e,0x48aa226a}},	//   ثاني, guns_, _सदस्, итим_
  { {0x290201d1,0x0b1a0029,0xb7f8000b,0x7cf10295}},	//   öka_, _نقرة_, ुशलम_, gård
  { {0xdb24002b,0x3947003d,0x69da29ac,0x7c2229ad}},	//   _روای, auns_, _पुरी, mbor
  { {0xb50b005d,0x7c2229ae,0x394729af,0xcaa60015}},	//   _संशय_, lbor, buns_, _بصري
  { {0x291a0107,0x7c2229b0,0x64480091,0x394729b1}},	//   ípad_, obor, ėdin, cuns_
  { {0xf1e4000b,0x8afd0046,0x6d430091,0x290c0045}},	//   _गरज़_, _vpře, šnag, _iuda_
  { {0x3ce6236a,0x7c2201f9,0x290c0081,0x0000006a}},	//   ilov_, ibor, _huda_,
  { {0xc1a70b1e,0xaca30016,0x290c2264,0x867300ce}},	//   ојби, _thủn, _kuda_, _оліє
  { {0x8afd0089,0x3ce60a3c,0x361b000a,0x7c2229b2}},	//   _upře, klov_, _דווד, kbor
  { {0x1f150010,0xe503000b,0x61e8007c,0x290c0d27}},	//   змаў, _रूचि_, üdla, _muda_
  { {0x23280001,0x9f590293,0xc49c000a,0x4abc000b}},	// [5050] _доњи_, _også_, _כשהת, ्चाव
  { {0xf3ff016e,0x57fb000a,0x51871fdd,0x02a70510}},	//   leão_, שלמו, _дума, _фрим
  { {0xbc190484,0x80270015,0xdddc29b3,0x290c29b4}},	//   білі_, _ورحم, _varş, _nuda_
  { {0x3ce600bd,0x7188000a,0xfbd300c3,0x7cf10795}},	//   glov_, _וְשַ, وتش_, kåre
  { {0x547c000a,0xf41f008c,0x7cf10123,0x4ea70099}},	//   יטאו, ljäs_, vård, _дрва
  { {0x8f9a0008,0xfd130029,0x220b000a,0x3ffa000a}},	//   _הישי, _يجز_, ׁפְּ, _לפרע
  { {0x6d43002d,0x2007002a,0xa3ab000b,0x7d0a001a}},	//   ánad, śniu_, कैत_, ífst
  { {0x290c29b5,0x6ef00012,0x9d1401f3,0xac380015}},	//   _duda_, räbe, _ідуч, _وسقط_
  { {0x96750033,0xbae50015,0x9b440015,0xb05b02dc}},	//   пыні, _فكري, _ينفو, _hjäs
  { {0xc9870015,0x39470045,0x16a90004,0x75450891}},	//   _وشاي, puns_, свои_, пноз
  { {0xceb2000a,0x99480015,0xf41f008c,0xd6ce0058}},	//   גיי_, _ولكل_, yjät_, اقٍ_
  { {0x895a0008,0x6908000a,0x3858005e,0x0d96004f}},	//   _לדעת, _וּסְ, _мрію_, לכתם_
  { {0x6b56000a,0xd763002b,0x44220091,0x629a0072}},	//   ֔ישׁ_, _آنتی, rbk_, ötoo
  { {0xb77a0008,0x7c2229b6,0x1dab000b,0x290c0077}},	//   _לאנש, zbor, चनात, _yuda_
  { {0xd179129a,0x703a005f,0x7c2200ba,0xddde002a}},	//   ості_, йчас_, ybor, zepł
  { {0x7c2d0084,0xa6e2002e,0xe53a000a,0x7c3b199a}},	//   ðarl, öðvu, _התקר, _ndur
  { {0x7c2200c0,0xa3d0000b,0x9abe0033,0xee3a29b7}},	// [5060] vbor, _शशि_, _пiша_, йна_
  { {0xee3a008f,0xd37b0008,0x9f4b00dc,0xe37b004c}},	//   ёне_, _פריט, émát_, _פריר
  { {0x929b013a,0xe29b013a,0x429b0008,0x729b0008}},	//   _היית, _השיר, _הסיב, _הסיס
  { {0xdcb90036,0xb53a004c,0x290c29b8,0xedd30058}},	//   ощі_, מגעש, _ruda_, ريند
  { {0x20070089,0x752f005c,0x290c29b9,0x7c2229ba}},	//   ěnit_, ączy, _suda_, rbor
  { {0x3ce60198,0xf41f0123,0x7e7529bb,0x7c2229bc}},	//   slov_, njär_, _gazp, sbor
  { {0x58d400fd,0x3ce606c0,0xe7450016,0x0000006a}},	//   мокт, plov_, ýõng_,
  { {0x6e2e0298,0xb05b00c0,0xc1730008,0xfd57000f}},	//   _hebb, _hjär, תחה_, _משלי_
  { {0xd6da010f,0xfbb6005d,0xe5090092,0xc5f6000b}},	//   йто_, _आइटम, _dặm_, ुख्य_
  { {0xcfb701ac,0xa3c2000b,0x95380004,0x2ca60123}},	//   פליי_, ्पन_, озот_, lkod_
  { {0x94d50180,0xa4d5008b,0x7d1b002a,0xc7b90030}},	//   донц, доні, _łusz, lből_
  { {0xc8b60015,0xd5b70033,0x2ca60123,0xe894005e}},	//   _عصاب, ясы_, nkod_, _іаль
  { {0x83870010,0xd7e30036,0xe45f00dc,0xf8b3000a}},	//   чыне, _пішо, lnök_, _אשף_
  { {0x27e600b6,0xc7b90030,0x6e2e29bd,0xd7fb004f}},	//   _iyon_, iből_, _nebb, _ההדל
  { {0x7e75018c,0x2ca60123,0xc2c400c3,0x9327002b}},	//   _razp, kkod_, ريفي, _کربن
  { {0x61e50f1b,0xc7b900dc,0x7f440003,0xf8c90016}},	//   _vyhl, kből_, friq, hẩn_
  { {0xc43c0008,0xb4d9005d,0x7c2d002e,0xf43c000a}},	// [5070] _התחי, ़की_, ðarm, _התחש
  { {0x42550086,0xc3320053,0x26de29be,0x2ca601c2}},	//   _کنگر, _שוי_, noto_, ekod_
  { {0x26cc001c,0x6ce7005e,0x27e629bf,0x6e2e29c0}},	//   indo_, піде, _lyon_, _debb
  { {0x106b0029,0x26de01b2,0x7f440291,0x644f00aa}},	//   _احدى_, hoto_, briq, ngci
  { {0x6e2e04ed,0xb05b00c0,0x907a000a,0xc7b90030}},	//   _febb, _fjär, _וטרי, gből_
  { {0xe9a90086,0x26de003f,0xc334000a,0x3b840033}},	//   يگان_, joto_, גוס_, эліг
  { {0x27e600b6,0x29160029,0xac190484,0x62950079}},	//   _ayon_, وقود_, _мову_, ijzo
  { {0x26cc29c1,0x645d0079,0xc7b90030,0xf7710015}},	//   endo_, jfsi, bből_, ناخ_
  { {0x60cd05be,0xaa070058,0x26de29c2,0xa806039f}},	//   inam, _فظاه, foto_, _riñó
  { {0x60cd29c3,0x6f0f2001,0x6d4529c4,0x26de29c5}},	//   hnam, _mucc, orha, goto_
  { {0x60cd29c6,0x04460c39,0x6d450034,0xaea50033}},	//   knam, менн, nrha, ягiч
  { {0x89340029,0x98bc0091,0x26cc29c7,0xc48300ce}},	//   _أعلا, tuvą_, ando_, влюк
  { {0x68e90595,0x68fb1788,0x6d450012,0x7ea00123}},	//   mled, mmud, hrha, _köpt
  { {0xda0d005d,0x2cad0026,0x68e929c8,0x645d12d3}},	//   िखित_, _lled_, lled, afsi
  { {0x35fb0086,0x2cad0020,0xf8b1000b,0x91e31088}},	//   _ارشد_, _oled_, _जताय, воре
  { {0x20fa005d,0x6e2e04ed,0x7f44028f,0xe4d60015}},	//   ्देश_, _sebb, triq, _تتتب
  { {0x68e929c9,0xc43b000a,0x6e2e00da,0x63a00123}},	// [5080] iled, _ותפי, _pebb, ämnd
  { {0x68e90089,0xee3a0010,0x2cad0026,0x24890211}},	//   hled, іне_, _aled_, _znam_
  { {0x602629ca,0xad3a005e,0xb13a0015,0x68e929cb}},	//   _одна, ючає_, _بأخذ_, kled
  { {0x68e90134,0xc7b900dc,0x60cd002d,0x6e2e29cc}},	//   jled, tből_, cnam, _webb
  { {0xeb97000d,0x33c90008,0x68e922fe,0xf236000a}},	//   миц_, ּהוּ_, dled, ֥רֶץ_
  { {0x6d43002f,0x2ca600c0,0x93b7000a,0xc7b90030}},	//   ánac, skod_, ולנו_, rből_
  { {0x6d450176,0x2cad003e,0xc7b900dc,0x68e929cd}},	//   crha, _fled_, sből_, fled
  { {0x88bc0089,0xbb4a0029,0x68e929ce,0xa77411b3}},	//   _hvěz, _ولأن_, gled, елич
  { {0x96460010,0xa7140033,0x26de29cf,0x69be0065}},	//   мэнд, эмпі, toto_, _वेरी
  { {0xd6d90050,0x61e90046,0x9781002b,0x60cd29d0}},	//   kułu_, řeli, ایوه, znam
  { {0x2cbf0026,0xe5270033,0xd5ba005e,0x68e929d1}},	//   _ymud_, міяй_, юси_, bled
  { {0xb4d9000b,0xad37004c,0xd6d9002a,0xf993000a}},	//   ़के_, ונטס_, dułu_, _שרף_
  { {0x43940080,0x80c1000b,0x78fb000a,0xf7540015}},	//   ваяс, रोफे, _ולאפ, _أنتج
  { {0x35d4004a,0x45d40c5b,0x6d450034,0x211b0015}},	//   _полё, _полс, yrha, قترب_
  { {0xe9ce008f,0xc1e803e7,0x2109000b,0x6f0f06ae}},	//   лкi_, дьте_, वदेश_, _succ
  { {0x60c402f2,0xd4c40033,0x68e029d2,0x60cd29d3}},	//   giim, _асьп, nomd, unam
  { {0xbfab0010,0x9f34005e,0x60cd29d4,0x44f80015}},	// [5090] цтве_, кеті, rnam, _تروج_
  { {0x63a00123,0x68e90061,0xf09f0016,0x60cd29d5}},	//   ämne, zled, _giàn_, snam
  { {0x60cd0111,0x201e0011,0x68fb0026,0x68e929d6}},	//   pnam, _ştie_, ymud, yled
  { {0x20c50024,0x61e10012,0x51fa000a,0x6d4514ab}},	//   rķis_, üllu, _מהתצ, rrha
  { {0x68e00024,0xab6b0015,0xfc300015,0xa4b8000a}},	//   domd, تحاق_, شحن_, ולאה_
  { {0xfaa7006d,0x68e929d7,0xdcef0061,0xb4ac000b}},	//   ьшен, wled, ıdır, _गत्_
  { {0x68e91bcb,0xc9a9004a,0xdcf5002a,0xaa560054}},	//   tled, явке_, _arzą, хију_
  { {0xd5b8003d,0x68fb02f2,0x0000006a,0x0000006a}},	//   abāk_, umud,   ,
  { {0x291e0123,0xd705067a,0x7b7400c3,0x68fb29d8}},	//   _etta_, нзии, _لطلا, rmud
  { {0xef1f0020,0x68fb007c,0x38ba003d,0x199512ae}},	//   _mtü_, smud, dūru_, _пазя
  { {0x7ea00064,0xe945002b,0x2cf9000a,0x85e9004a}},	//   _köpr, _سرای, ּלָא, ядов_
  { {0x7c2d0084,0x397a000a,0xa6e20052,0x0000006a}},	//   ðarh, _מטענ, öðru,
  { {0x60c40005,0x850b005d,0x7d0929d9,0xd5ae002b}},	//   viim, _संकट_, _mies, لفی_
  { {0xd6d9005c,0x386d09f2,0x479a000a,0x4939000a}},	//   tułu_, leer_, _מינס, ּגּו
  { {0x00e40086,0xf8c90092,0x60c40201,0x95550015}},	//   نتری, hẩm_, tiim, _أختا
  { {0x7d090050,0xf7080016,0x386d15fc,0x55ba000a}},	//   _nies, _rủi_, neer_, _ממצו
  { {0x60c41573,0x8f0a0015,0x1f660033,0x2d830123}},	// [50a0] riim, سياق_, экам, _arje_
  { {0x3fe30784,0x60c4122e,0x386d0161,0x3eae001a}},	//   ужув, siim, heer_, óft_
  { {0xe47a0008,0x69c50089,0x386d0409,0x443229da}},	//   ּרְכ, úhel, keer_, _key_
  { {0xfc3200e6,0x7d091332,0x0c760115,0x3d2b002b}},	//   احا_, _cies, عداد, ستمی_
  { {0x7d0929db,0xb09b0008,0x386d00dd,0xc4d30008}},	//   _dies, _זיכר, deer_, נגד_
  { {0xc3330008,0x443202c1,0xd337000a,0x2b460144}},	//   רוג_, _ley_, גרסה_, rroc_
  { {0x26c5116e,0x8cb0005d,0x7d0929dc,0xe917005e}},	//   dilo_, ंसदो, _fies, нощі_
  { {0x386d0409,0xa3c2021e,0x115b004c,0x7cea001a}},	//   geer_, ्पा_, לדצע, kýri
  { {0x26c504ed,0x56c60063,0xc6f81056,0x57f4006b}},	//   filo_, ещна, мних_, ъпит
  { {0xc6f71292,0x0f570008,0xbb3b000a,0x0a160015}},	//   нных_, עיים_, _מעמי, _أوضح
  { {0xceb304dc,0x386d049c,0x2f160134,0x291e008c}},	//   רית_, beer_, _læg_, _utta_
  { {0x38ba0024,0x386d0079,0xb865012c,0xdcf50535}},	//   tūru_, ceer_, _لاهو, _trzą
  { {0xdcf5005c,0x46a60010,0x7c2d002e,0x2f16001a}},	//   _urzą, _падв, ðari, _næg_
  { {0xda10005d,0xf5940015,0x171b004c,0x57f3005e}},	//   ाशित_, _للتج, _צווע, _спіт
  { {0x629e053e,0xa0c50015,0xd5af0170,0x49d4004f}},	//   _dopo, نيسو, _сс_, דֵּן_
  { {0x73c50015,0x98bc0091,0x0000006a,0x0000006a}},	//   _ليعم, tuvę_,   ,
  { {0x8464010f,0xa92300df,0x04dc000a,0x8c3d0061}},	// [50b0] _съще, ąžin, _מקהל, _hoşg
  { {0x9f6000dc,0x752d002a,0x386d0079,0xc7d7004f}},	//   ásán_, _łazi, zeer_, תומי_
  { {0x7d090a7e,0xb2bc000a,0xbd18005e,0x8e380015}},	//   _pies, _ממזר, еції_, عسكر_
  { {0xf537000a,0x7188000a,0xe571000a,0xef1f007c}},	//   תנאי_, _נְתַ, יַד_, _ttü_
  { {0x7e2b008f,0xa0360008,0x386d049c,0x10360008}},	//   _ніва_, _בארה_, veer_, _בטרם_
  { {0xf09f0092,0xaa940036,0x753a0024,0x4bd8002b}},	//   _hoà_, личч, kstz, ربند_
  { {0x7d091ce1,0x386d2514,0x63a6005c,0x26c529dd}},	//   _ties, teer_, zykn, vilo_
  { {0x48090063,0xc984002b,0x78a929de,0x378900af}},	//   мейн_, اشوي, ukev, дбио_
  { {0x25a50026,0x443229df,0x386d29e0,0x26c529e1}},	//   wyll_, _rey_, reer_, tilo_
  { {0x78a9022d,0xc7a80029,0x386d29e2,0xfaf30015}},	//   skev, عديل_, seer_, _إثر_
  { {0x188b000d,0x7ea0002e,0xf2df0045,0x26c529e3}},	//   _нсдп_, _möpp, trân_, rilo_
  { {0xf4b4002b,0x7cea001a,0x03a60296,0x26c514ba}},	//   اشدگ, týri, вимо, silo_
  { {0xcc3a0053,0x78a600c0,0xb2c60015,0x629e29e4}},	//   וערט, ökve, نغسو, _popo
  { {0xc7b900dc,0x69070030,0x7ae329e5,0x7cf829e6}},	//   mző_, _műem, nont, míre
  { {0xc7b900dc,0x205629e7,0x7ae3002d,0xe3b2002b}},	//   lző_, ктар, iont, _چرخ_
  { {0xe3b20086,0x20550718,0x0086006b,0x25d6000a}},	//   _نرخ_, лтур, ълбо, _שוקן_
  { {0x6d43002d,0xa4fb000a,0xb2260076,0x673b002a}},	// [50c0] ánan, _קלפט, _импл, nsuj
  { {0x6d4b005c,0x0e6a0015,0x673b008c,0x3f8029e8}},	//   ągan, بصري_, isuj, rviu_
  { {0xbd8a0115,0x1ea90015,0x7ae329e9,0xdb080052}},	//   بنان_, راكي_, dont, _ólét
  { {0x673b29ea,0xe5f6004c,0xdd8f0040,0x8c4603ae}},	//   ksuj, דזער_, توم_, теде
  { {0x7cf100c0,0x7b730015,0xfafe003d,0x7cf80046}},	//   pårn, لطوا, žīma_, jíre
  { {0xaa53005e,0x38c8002b,0x1af401b0,0xda63052b}},	//   ивіш, کاتی_, ыпля, ивчи
  { {0xa9670cb9,0xfaa30004,0xb9240015,0xc7b90030}},	//   вија_, рајо, دفعي, ező_
  { {0xd90d0074,0x1874006b,0xe45f008c,0x7e7c29eb}},	//   سیه_, угия, nnöt_, _harp
  { {0x2cd50010,0xb50c005d,0x7ae329ec,0xc7b90030}},	//   _сюрр, _संजय_, bont, gző_
  { {0x7c2d002e,0x41db000b,0xa3e6000b,0x7ae308aa}},	//   ðarv, _मुझस, _बुध_, cont
  { {0x24590036,0xdcf5002a,0x6d5e29ed,0x673b0535}},	//   нань_, _arzę, ntpa, asuj
  { {0x249f09f0,0x672b0030,0x7cf80046,0xdcf5002a}},	//   ðum_, öljá, bíre, _brzę
  { {0x18670054,0x6b821ffa,0x5347006b,0x6d5e2544}},	//   _јачи_, nvog, ъхна, htpa
  { {0x35dd005d,0x63a00123,0x6d5e02ad,0x0000006a}},	//   _नुक़, ämna, ktpa,
  { {0xd1300015,0xf1a40c1d,0x201e0045,0x62340c02}},	//   ْمِ_, артн, _ştia_, ресу
  { {0x55970008,0x397b000a,0xb97b000a,0xf0b80015}},	//   _ידוע_, וטלנ, ונלי, ناقش_
  { {0x443929ee,0x1ee7002b,0xdff50054,0x04c8009a}},	// [50d0] mas_, نوری_, упањ, _جويي_
  { {0xc2750001,0x717911f2,0xa3c2000b,0x7e7c0390}},	//   _слој, _збор_, ्पर_, _carp
  { {0x7e7c0026,0xf09f0092,0x7ae329ef,0x20d5012c}},	//   _darp, _toà_, vont, _مقدس
  { {0x443929f0,0xac191402,0xfbd90b1e,0x442b00da}},	//   nas_, ходу_, ндеј_, nbc_
  { {0xe504005d,0x443929f1,0x6d5e0079,0x7ae30905}},	//   रगति_, ias_, atpa, tont
  { {0xddce00dc,0xeb900015,0x7ae3008c,0x7cf8216b}},	//   _ebbő, تظم_, uont, víre
  { {0xdd94008f,0xceb20135,0x99850015,0x443929f2}},	//   _кары, _פיל_, البو, kas_
  { {0x443929f3,0x673b0604,0xac74002b,0x7ae329f4}},	//   jas_, tsuj, _پافش, sont
  { {0xe50a0023,0xe45f00f2,0xd7090080,0x7ae329f5}},	//   _mặt_, tiön_, нние_, pont
  { {0xc7b900dc,0x1ab7000b,0x4ab7000b,0xba770015}},	//   rző_, _अतिथ, _अतिव, _جارت
  { {0x443929f6,0xe45f008c,0xc7b90030,0x64a61e98}},	//   fas_, riön_, sző_, гана
  { {0x04460010,0xa9070086,0xf992000a,0xa3c2000b}},	//   ыемн, _شبان, _לרב_, ्पल_
  { {0x889a00a3,0x9cd6000a,0xf74529f7,0x387f29f8}},	//   _רבני, רורה_, _село, mdur_
  { {0x387f29f9,0x6e350107,0x80c1000b,0x38661658}},	//   ldur_, _nezb, रोसे, _zbor_
  { {0xa2c3005d,0x443929fa,0xa06a0c35,0xf9870015}},	//   रफ़्, bas_, нава_, حب_
  { {0x387f0084,0x2d5c0467,0xa0b50001,0x03960063}},	//   ndur_, víe_, аљуј, _броя
  { {0x387d0176,0xa4fb0008,0xdcf5005c,0x9f860010}},	// [50e0] _mawr_, _אלקט, _urzę, ыгад
  { {0x387d0176,0x9c85002b,0x74dc000b,0x6d5e08d9}},	//   _lawr_, یشنه, नवकृ, ttpa
  { {0x6e350011,0x06360053,0x725b000a,0x7dc6002b}},	//   _dezb, רנעט_, _אכיפ, دقان
  { {0x387d0176,0x6d5e29fb,0x9ce502a3,0xcea9000a}},	//   _nawr_, rtpa, аціл, הי_
  { {0xe4570053,0x7e7c1168,0x387f29fc,0xdddc0091}},	//   רינט_, _tarp, ddur_, _karū
  { {0x443929fd,0x38660046,0x9b87002b,0x6b8229fe}},	//   zas_, _sbor_, انول_, rvog
  { {0xcd780008,0x4d780008,0x5d780008,0x0076000a}},	//   _בְּכ, _בָּא, _בָּנ, ָתִי_
  { {0xacea0029,0x7c2d002e,0x443929ff,0x387d0034}},	//   _أرسل_, ðart, xas_, _cawr_
  { {0x3d18000b,0x7d022a00,0x44392a01,0x67d40e64}},	//   _बूते_, mmos, vas_, ропу
  { {0xba1a003b,0x387f1519,0xda650002,0x7d022a02}},	//   _أيضا_, adur_, _نامي, lmos
  { {0x387d0176,0xa9260229,0x8b030089,0xd6770015}},	//   _fawr_, _сдел, ířen, احًا_
  { {0xd5b70418,0x44392a03,0x387d0034,0x6aa102b9}},	//   усь_, uas_, _gawr_, _zolf
  { {0x44392a04,0x7d022a05,0x5694027c,0x0000006a}},	//   ras_, imos, _валт,
  { {0x56930033,0x7d02008c,0xaca30016,0x44392a06}},	//   _гашт, hmos, _kiển, sas_
  { {0x2b4004af,0x44392a07,0xc6930135,0x7cea0046}},	//   šich_, pas_, _לאס_, nýrs
  { {0x30a4000d,0xd4680001,0x2937004c,0x3d0e000b}},	//   брув, _биће_, טאלן_, िदों_
  { {0xb4b1005d,0x611c00bd,0x0e35007a,0xe50a0016}},	// [50f0] ओसी_, _včla, инаю, _vặt_
  { {0x7cea0084,0x78a20020,0xd2510018,0x387f0061}},	//   kýrs, _loov, _بند_, zdur_
  { {0xd0110029,0x463b0053,0xef1f00b8,0x5187070e}},	//   _ولد_, געבע, _grün_, _супа
  { {0x9b450015,0x611c0085,0x7d020030,0xcc140015}},	//   لنصو, _učla, gmos, مذهب
  { {0x2d9c079b,0x9056000a,0xfc64006b,0x6aa12a08}},	//   øver_, _דברו_, съхн, _polf
  { {0x6925287f,0xa9250033,0x387f0034,0xc9850015}},	//   амка, адкл, wdur_, لشعي
  { {0x7c2d002e,0x48b50286,0x9ed8049d,0x627c000a}},	//   ðars, ищит, _смрт_, גנונ
  { {0x6aa12a09,0x18a5011d,0x6eeb02ad,0x387f007f}},	//   _wolf, раим, rübu, udur_
  { {0x387f0064,0x6eeb0012,0x798802ad,0x6aa102dc}},	//   rdur_, sübu, _erdw, _tolf
  { {0x46f500d7,0xcf92000a,0xe7680015,0xb05b0123}},	//   јчит, קטי_, احين_, _smäl
  { {0xceb4000a,0x99620107,0x15b90033,0x7cf80030}},	//   מיץ_, píše_, тыпы_, líra
  { {0x6b890111,0x38580002,0x63860ef5,0x399a004f}},	//   _kreg, _مشهد_, агма, _ביעד
  { {0xa3e6014e,0xdddc18df,0x4c9a004f,0xa2e60058}},	//   _बुश_, _parū, דברו, لأسن
  { {0x6d4b005c,0x76430134,0xd24f0015,0x78a20079}},	//   ągaj, _udny, ونُ_, _zoov
  { {0x7d020091,0xe45f0123,0xe2a7001a,0xa284002b}},	//   ymos, rnör_, æðar_, لیکو
  { {0xdd2f0089,0x7f4d016e,0x6b892a0a,0xddc70535}},	//   _běžn, fraq, _oreg, _dajż
  { {0x6b890152,0xaec62a0b,0x6ef0007c,0x1fa72a0c}},	// [5100] _nreg, абал, läbi, акти_
  { {0x29f50092,0x27f200cb,0x333b000a,0x433b000a}},	//   _óa_, _øyne_, _שתימ, _שעיב
  { {0xed5a054f,0x1d0a07f7,0x6b892a0d,0x7d022a0e}},	//   тое_, вежи_, _areg, tmos
  { {0x8c3d0045,0x61e8007c,0xab2a2a0f,0x3b8601d2}},	//   _roşc, üdlu, вода_, илег
  { {0xda660029,0x61e90061,0x2bc0000b,0x7d022a10}},	//   لاثي, ğele, _शेखा, rmos
  { {0x78a20005,0x61e90064,0x4fd70008,0x7c2d002e}},	//   _soov, şele, _כוכב_, ðarr
  { {0x8c96008f,0xf8c90092,0x29570021,0x60d606ed}},	//   _краі, hẩu_, لشيخ_, onym
  { {0x58860010,0x7cf80089,0x7afd003d,0x48a7004a}},	//   рыка, bíra, _īste, итым_
  { {0x6b891647,0x290f21eb,0x0000006a,0x0000006a}},	//   _greg, _diga_,   ,
  { {0x290f05d8,0xeab4000a,0xf992002b,0x27ef0123}},	//   _eiga_, _פִּי_, _وبا_, _dygn_
  { {0xc4c70029,0x78a21de9,0x5924002b,0xdef7004f}},	//   لتحو, _toov, _اکتف, שמיט_
  { {0x60d6005c,0x8c3d0061,0xe7860099,0xd7c7002b}},	//   jnym, _koşa, _вуко, اویه_
  { {0xe8d7013a,0x889b0008,0x8c1b000a,0x88bb000a}},	//   _דואר_, _שבדי, כוכי, _במאז
  { {0x175701ac,0xa1592a11,0xa7bb004f,0xeb91004f}},	//   _כסדר_, лагу_, _שֶׁת, הָל_
  { {0x24800003,0xb2840033,0x26cc2a12,0x6ac4000b}},	//   _faim_, цыяк, mido_, _वगैर
  { {0x45b70008,0x6d4300bc,0x26cc29c7,0x743504bb}},	//   _כפול_, šnak, lido_, _униф
  { {0xc2eb0029,0x85040015,0x543c004c,0xc7a9000a}},	// [5110] _لعدم_, _بوين, _סעזא, ְׁעָ
  { {0x26cc0a49,0x7cf80089,0x9f660092,0x6e450015}},	//   nido_, víra, _đuôi_, إنضم
  { {0xa1840010,0x8027002b,0x60d6002a,0xafdb01d0}},	//   _дыял, _پرجم, bnym, _idøm
  { {0x4095040b,0xed580036,0xa1760053,0x2723002c}},	//   _الحر, рої_, _פערד_, nčný_
  { {0x290f04ed,0xfbd000e6,0xcb690015,0x8cb8000b}},	//   _riga_, وته_, امته_, ्फ़ो
  { {0xe50a0092,0xcae80010,0xdb4e0015,0x0ae8005e}},	//   _lặp_, аміж_, رَى_, адій_
  { {0x290f003f,0x26cc0e75,0xd9990086,0xd2b8000a}},	//   _piga_, dido_, انعت_, שלות_
  { {0x39492a13,0xf9900015,0x60cd2a14,0x71d8000a}},	//   čas_, ببه_, niam, יווד_
  { {0x290f2a15,0xf7710015,0x6f050125,0xd639005e}},	//   _viga_, ساة_, omhc, ляні_
  { {0x60cd04ed,0x60d6066f,0x26cc0a43,0x7a570015}},	//   hiam, znym, gido_, _خضرا
  { {0x60cd00df,0x85780063,0x290f0375,0xbae40015}},	//   kiam, асят_, _tiga_, _بكلي
  { {0xe50a0092,0x2bbe000b,0x69150046,0x67290601}},	//   _cặp_, ौपचा, _všed, ppej
  { {0x26cc0a49,0xd6d9005c,0xd7f50033,0x60d6006f}},	//   bido_, asła_, _узды, vnym
  { {0x68e915c4,0x26c700d9,0x26cc0e75,0x60d6002a}},	//   loed, _umno_, cido_, wnym
  { {0x78f9004c,0x1af6000a,0x60d60244,0x7c36001a}},	//   ָפּו, ממשל_, tnym, ðyrk
  { {0xe50a0023,0x60cd2a16,0x2480002d,0xd12f0015}},	//   _gặp_, giam, _uaim_, عمق_
  { {0xddd5018c,0x2e160015,0xf457000a,0x2d8a0085}},	// [5120] _razš, مباح, _היפר_, _srbe_
  { {0x68e90176,0xa6f9000a,0x60d6002a,0x1eaa00c3}},	//   hoed, אִ֣י, snym, داري_
  { {0x60cd02d7,0xc27b00a3,0xa63a0053,0x7206002b}},	//   biam, _גריי, רגער, _دودم
  { {0x26cc001c,0x20560054,0x7d1b00bc,0xcc290015}},	//   zido_, _утор, _čust, لأهم_
  { {0x68e90176,0x78bb0ca0,0x44222a17,0xc8790045}},	//   doed, dhuv, ick_, coşi_
  { {0xd37b000a,0xc333000a,0xba1700c3,0x6249000a}},	//   טרנט, לוד_, ميها_, ֑נוּ_
  { {0xae07005d,0x26cc2a18,0x68e90026,0x6e3e0111}},	//   वेदन_, vido_, foed, mapb
  { {0xa3b8021e,0xed350033,0x6e3e0030,0x8c3d0061}},	//   चना_, _фэрэ, lapb, _hoşn
  { {0xd7f00029,0x8f9a0053,0xf09f0092,0x2fc00765}},	//   بكة_, ריִי, _giàu_, nzig_
  { {0xda660086,0x87e30080,0x60cd104f,0x6e3e0a4d}},	//   _داري, яюще, ziam, napb
  { {0x26cc047e,0xa5f8017c,0x9986002b,0x8c3d0045}},	//   rido_, рену_, _دلاو, _moşn
  { {0x6d43002d,0xb97b039e,0x7aea1892,0x7c222429}},	//   ánai, _תנאי, loft, ncor
  { {0x2fc00111,0x9403000b,0x7c2202b9,0x6e3e2a19}},	//   jzig_, रेंच_, icor, kapb
  { {0x60cd002a,0xdddc0046,0xf7d7000a,0xc7d7000a}},	//   wiam, _narů, _פוגש_, _פוגי_
  { {0x60cd2a1a,0xe6040015,0xc1050015,0x3f8b06c0}},	//   tiam, _بِغَ, قوسي, _srcu_
  { {0x79ab000a,0x50f501c6,0xc8790045,0x7aea0546}},	//   אֹמַ, ізат, toşi_, hoft
  { {0x4034005f,0x2aab02de,0x60cd2a1b,0x8c3d0061}},	// [5130] яетс, _købt_, riam, _boşn
  { {0x765a2a1c,0x4255002b,0xc8790045,0x171b004c}},	//   ngty, _بندر, roşi_, טומע
  { {0xdd910029,0xec610010,0x9f040015,0x257a003d}},	//   بوا_, дзеi_, أولو, _jūl_
  { {0xaca30092,0xf55b004c,0xe7b8000b,0xddc80046}},	//   _miện, רדאמ, इनाप, álšt
  { {0xe9db0086,0xe47c0053,0xfaa50760,0x68e90234}},	//   گذشت_, טראכ, жало, voed
  { {0xd358000a,0x93fc004c,0xd5a60015,0x218b004f}},	//   מידי_, אלדי, _قف_, ָאֵ֣
  { {0xaa560124,0xce680036,0x442200c0,0xda640029}},	//   цију_, _уряд_, yck_, ساوي
  { {0xd0fb014e,0x9b450086,0xe8f900d0,0x7c222a1d}},	//   ्षिण_, _ونزو, јли_, ccor
  { {0xcb340063,0x68e91745,0x78bb0123,0xf651002b}},	//   _нетъ, roed, rhuv, وئد_
  { {0x7c3b038d,0x68e90f50,0x78bb2a1e,0x75450c9a}},	//   _heur, soed, shuv, оноз
  { {0xa2af000b,0x2126006f,0x68e90547,0xb9c50015}},	//   ुसन्, _čoho_, poed, _بقضي
  { {0x240a0063,0xbc19000a,0xed13008b,0x44222a1f}},	//   инни_, יוֹש, огiй_, uck_
  { {0x7c3b2a20,0xbec30024,0x7cf80030,0x43fa008b}},	//   _meur, _ķīni, zíro, рхня_
  { {0x7c3b038d,0xe716000a,0x0000006a,0x0000006a}},	//   _leur, _וחסר_,   ,
  { {0x9f8b0012,0x99870091,0x56920b1e,0x64a60763}},	//   tößt_, manų_, _цајт, _мака
  { {0x80660010,0x7aea0030,0x2fc003c1,0xf536000a}},	//   ўваж, zoft, tzig_, _ונקי_
  { {0x3eb801d7,0x60c100aa,0xee3a012b,0x60e702a3}},	// [5140] _plrt_, ëlma, ина_, імум_
  { {0x2fc00012,0xd00f0015,0x61e90045,0x7e770e06}},	//   rzig_, ئلك_, şela, gexp
  { {0x38b10030,0x6e3e2a21,0x7c3b0653,0xa06a1adc}},	//   _várj_, rapb, _beur, _кана_
  { {0x6ef000f2,0x61fe0192,0x01fb000a,0x7afd003d}},	//   väbu, _izpl, _כפיל, _īsta
  { {0x7c3b020a,0xbb43000d,0x6e290064,0xaae600e6}},	//   _deur, дечк, _şebe, يستو
  { {0x7cf80057,0x6e960015,0x8c3d0061,0x6249000a}},	//   píro, _بلسا, _hoşl, ֖נוּ_
  { {0x7c3b2a22,0xbdf4004f,0x929b004f,0x7c2201f9}},	//   _feur, _זֶּה_, ייסת, pcor
  { {0xc2130008,0x7c3b06a8,0xd90d002b,0x6e3c2a23}},	//   והו_, _geur, هیل_, _herb
  { {0xd6da010f,0xd7fa009e,0x57170033,0x6e3c2a24}},	//   ито_, шук_, ожыя_, _kerb
  { {0x19960054,0x99870091,0x7d1c2a25,0x443b2a26}},	//   _мјер, ganų_, _kurs, _seq_
  { {0x69150089,0x2419004a,0xd6d9002a,0x65940033}},	//   _všec, йоны_, asło_, чану
  { {0xef1f00b8,0x657a0034,0x7d7b000a,0x7d1c2a27}},	//   _früh_, rwth, בנטו, _murs
  { {0x97c60015,0xd794006b,0x99090015,0x99870091}},	//   _بتضم, _хилъ, _اغلق_, banų_
  { {0xd6d9005c,0x7d1c0bf5,0xe60f009a,0x6e3c2a28}},	//   kuły_, _ours, عشی_, _nerb
  { {0x8c3d0064,0x7d1c0ab0,0x27200016,0x6aa80034}},	//   _boşl, _nurs, _hòn_, _modf
  { {0x70940010,0xa3e6000b,0xf485002b,0xd6d9002a}},	//   масф, _बुक_, _رابی, duły_
  { {0x6e3c0849,0x200f0020,0xaadb000b,0x9f550033}},	// [5150] _berb, ägi_, _बदलक, явач
  { {0x7c3b022d,0xdef10029,0x6e3c2a29,0x27200016}},	//   _seur, رًا_, _cerb, _mòn_
  { {0x9c190029,0xd6d9005c,0x6e3c0495,0x427a000a}},	//   مياء_, guły_, _derb, _האתג
  { {0x317a0053,0x6aba2a2a,0x859b000a,0x4255002b}},	//   _פארד, _altf, ישבו, _بنگر
  { {0x7c3b08e0,0x628500b6,0xb09a000a,0x645d0091}},	//   _veur, _kaho, _הירר, igsi
  { {0x337c0008,0x237c000a,0xd6d9002a,0x63a00123}},	//   שְׁב, שָׁמ, buły_, ämni
  { {0xf2d400b2,0x201e0045,0xed58004a,0x99870091}},	//   ועס_, _ştii_, _моё_, vanų_
  { {0x764a0026,0x61dc000a,0x6e3c2a2b,0xfc3f001a}},	//   _adfy, יקוד, _zerb, _þí_
  { {0x27200023,0x6d452a2c,0x6e3c2a2d,0x6aa82a2e}},	//   _còn_, lsha, _yerb, _fodf
  { {0x645d231a,0x62850522,0x6d430091,0x6726001a}},	//   egsi, _naho, šnau, íkja
  { {0x6e2500b8,0xf3e901ac,0x99870091,0x05620033}},	//   ichb, _עף_, ranų_, нвэн
  { {0x7f440152,0xf2c90053,0x79810034,0x628502f2}},	//   ysiq, _גע_, _islw, _aaho
  { {0x27200092,0x99870007,0x5695022a,0xc87913cc}},	//   _gòn_, panų_, _надт, meş_
  { {0x0cb8005d,0x645d0fa9,0x0219005e,0xcb88000a}},	//   _आत्म, agsi, жіть_, קְרֹ
  { {0x69c300dc,0xa6e1002e,0xdddc0011,0xcad6000a}},	//   nzne, öðud, _marţ, לושת_
  { {0xe4c90029,0x6e3c2a2f,0x6f1d1243,0xb099005e}},	//   _وبين_, _serb, _busc, отує_
  { {0xe5050029,0x6e3c0849,0x7d1c028d,0xef172a30}},	// [5160] _تبوي, _perb, _surs, зму_
  { {0x1fb50191,0x7d1c003e,0xd6d9005c,0xc2c60015}},	//   єстр, _purs, tuły_, _ريجي
  { {0xc27b01e4,0x7f440152,0x127b0053,0xf237000a}},	//   _פרטי, ssiq, _פאטע, _מריץ_
  { {0x351a0008,0x628504c0,0x6e3c2a31,0x753c0045}},	//   צוננ, _zaho, _werb, ârzi
  { {0xd0f9014e,0x6e3c0d25,0x6d45003f,0x20550033}},	//   ंतरण_, _terb, asha, _ютэр
  { {0xff070010,0xdb2300dc,0x7d1c2a32,0x6283001a}},	//   _неяк_, írál, _turs, _ónot
  { {0x6f1d00b8,0x7641093b,0x6d430030,0xb6052a33}},	//   _zusc, daly, ánat, _jušč
  { {0x8ddb0008,0x4ddb0008,0xc173015b,0x98c30033}},	//   _הקלק, _החלו, גחה_, есьл
  { {0x9af60015,0xb09b004f,0x80c10065,0x998c0535}},	//   _فكرت, מיקר, रोटे, _jedź_
  { {0x35b408fc,0x6440001a,0x95d80004,0xdcee003d}},	//   дбор, ðmin, ждот_, _orbī
  { {0x69c30050,0x645a0007,0x62852a34,0x7a8b000a}},	//   czne, ėtin, _raho, _לָאַ
  { {0x79b70008,0x4dfb000a,0xa3d5005e,0x2eb9000b}},	//   _מלבד_, מפיא, домч, _इत्त
  { {0x9f590064,0x62850c66,0xd706004a,0x291e002a}},	//   üyük_, _paho, _езди, _huta_
  { {0x764a0134,0xb05b0012,0x88bc0046,0xf77f0061}},	//   _udfy, _kläg, _stěh, ççe_
  { {0x291e013c,0x645d02f2,0x6f1d2a35,0xa194009b}},	//   _juta_, pgsi, _susc, нарч
  { {0x62850176,0x55770053,0x61e90045,0x291e1b91}},	//   _waho, _זעהן_, şelo, _muta_
  { {0x291e2a36,0x44292a37,0x6e252a38,0x1f150033}},	// [5170] _luta_, _ifa_, tchb, дмаў
  { {0x4ed40036,0x7ed70029,0x6e2500b8,0x333c000a}},	//   нюєт, أزرا, uchb, _התזמ
  { {0x6e250ecc,0x8d790015,0x7c2d010d,0x6f152a39}},	//   rchb, تماء_, ñaro, _vizc
  { {0x6e250012,0x6d4527f4,0xe45f0123,0x6f1d2a3a}},	//   schb, rsha, ngö_, _tusc
  { {0x68e4032c,0x2d9c00c0,0x9f890111,0xdddc0011}},	//   čidl, äver_, _vóór_, _parţ
  { {0x1ee70086,0x28ca000b,0x8f9a000a,0xfe6e002b}},	//   _روزی_, ़ोसि, _וישי, _نگم_
  { {0x644d0946,0x0d8402bf,0x76412a3b,0xc8791d56}},	//   _odai, _плён, valy, teş_
  { {0xe9d0002b,0x7cf101f0,0x764102f2,0xfc33006e}},	//   دغه_, rårs, waly, _سحر_
  { {0xf7080092,0x69c306e7,0x7641043a,0x9b45002b}},	//   _hủy_, szne, taly, _آنطو
  { {0x291e000c,0x644d2a3c,0x85491092,0x44292a3d}},	//   _futa_, _adai, озов_, _afa_
  { {0xb05b00c0,0xceb2000a,0xc8790045,0x76412a3e}},	//   _kläd, דיי_, peş_, raly
  { {0xb60500bc,0x57b5023b,0x44292a3f,0x0000006a}},	//   _rušč, _обет, _cfa_,
  { {0xaca30023,0x43930010,0x7c292a40,0x672b02d2}},	//   _chỉn, ваўс, _mfer, _utgj
  { {0xb60500bd,0xc7b2000a,0xf772000a,0x07090021}},	//   _pušč, _בבד_, _סקו_, _بيتي_
  { {0xa1870001,0xe45f2a41,0x6d430045,0xf55600c3}},	//   мбра_, tiöt_, ânal, _قلوب_
  { {0xdddc00df,0xc5f20008,0xe53a000a,0x70f5005e}},	//   _narš, _שדה_, _ותקר, ечує
  { {0x4de6005d,0xa4850015,0x63f60015,0xe45f008c}},	// [5180] _जुड़े_, _سجين, _تأثر, riöt_
  { {0xb6050007,0x2d910085,0xc0030054,0x7c292a42}},	//   _tušč, _brze_, тпук, _afer
  { {0x64490084,0xb05b00c0,0x729b0008,0x201e0011}},	//   ðeig, _bläd, _וסיס, _ştiu_
  { {0x386d0079,0x77690123,0x291e2a43,0xadb70015}},	//   jfer_, ktex, _ruta_, بهما_
  { {0x291e0045,0x6d43001a,0x386d0034,0x8c432a44}},	//   _suta_, ánar, dfer_, тече
  { {0x291e016f,0xeb97004a,0x0e760015,0x77692a45}},	//   _puta_, ьич_, _تُسح, dtex
  { {0x7c290176,0xe2a7002e,0x2d91002a,0x89630015}},	//   _ffer, æðir_, _grze_, نُون
  { {0x2c860007,0xb05b00c0,0x52bb021e,0x4973006b}},	//   _būdų_, _gläd, _उत्स, тлъс
  { {0xc7c60080,0x44291baa,0xc7d8005e,0xcb6a0249}},	//   ьски, _rfa_, ямих_, _фазе_
  { {0xc6f7054f,0x291e2a46,0xa53400ce,0x0000006a}},	//   мных_, _tuta_, нноч,
  { {0x186a000d,0xa4d5005e,0x3ea716a1,0xafdb02de}},	//   _мажи_, еоні, önti_, _udøv
  { {0xb8930029,0x38b1001a,0x35b31111,0x0000006a}},	//   _للمع, _báru_, тбюр,
  { {0x5c370053,0xc7b600a2,0x1b7b004c,0xdc37004c}},	//   ורכן_, _تصاع, ֿטלע, ואכט_
  { {0x57fb000a,0xb05b0123,0x68e201ec,0x0000006a}},	//   _ולדו, _nmär, _hjod,
  { {0x29060023,0xa4d5005e,0xe2f8005e,0x22432a47}},	//   _khoa_, _покі, фері_, rajk_
  { {0xd7880023,0xaca30092,0x4429003f,0x54e70015}},	//   _kể_, _thỉn, _ufa_, _تستق
  { {0xa29502e1,0xc43c000a,0x26de2a48,0xf43c004f}},	// [5190] _запі, _ותחי, onto_, _ותחש
  { {0xa6f8000a,0xce6b0033,0x386d0030,0x2d91002a}},	//   פִּי, ўрад_, zfer_, _prze_
  { {0x7c2900b8,0x386d0026,0xb05b03c1,0x6d5a0123}},	//   _pfer, yfer_, _pläd, _åtal
  { {0xfc300087,0x81b6000a,0x38b10030,0xef1f0061}},	//   لحه_, _נהרג_, _járt_, _brüt_
  { {0x2258002b,0xd7880016,0xa036000a,0x4fd50c44}},	//   _عجیب_, _nể_, _ראשה_, _טוֹב_
  { {0xc334000a,0x93b8000a,0x8c3d0045,0x7b740015}},	//   דוס_, ולדו_, _moşi, ضطها
  { {0xd9400010,0x1c570015,0xa9e40046,0x8c6703ae}},	//   ацыi_, _يخرج, _přáé_, _отад
  { {0x08d40010,0xb04c0053,0x248909f2,0x69150264}},	//   кцыя, ֿעיִ, _naam_, _všeo
  { {0x386d2a49,0x63a9005b,0x0000006a,0x0000006a}},	//   rfer_, äenl,   ,
  { {0xd706005f,0x8aa70010,0xfaa70010,0x645a0007}},	//   нные_, _ўрад, _ўшан, ėtim
  { {0x386d00b8,0x77690b12,0x41cf0065,0x5bbc0065}},	//   pfer_, stex, _हेलस, ्ज़ीव
  { {0x19b60053,0x79b60643,0x2605000b,0x33200144}},	//   _אפער_, _אלעד_, हेगी_, _puix_
  { {0xa3f50010,0xe3b7004a,0x68fb0061,0xa3ba0015}},	//   вярш, ебя_, mlud, ساحر_
  { {0x5756000a,0xd705005e,0x290d2a4a,0x2cad007c}},	//   _נבצע_, _язли, lmea_, _loed_
  { {0x11d50036,0xf65200a3,0x76ba000a,0xda0f000b}},	//   вітр, _עצה_, _ממספ, ाधित_
  { {0x3ce9000b,0x25d6004c,0xb05b0123,0x68fb0061}},	//   टकों_, _רוקן_, _smär, nlud
  { {0x48fa0053,0x64460d25,0x4f6600c3,0xaf062a4b}},	// [51a0] פּלא, maki, عارف, епал
  { {0x64461b4a,0x97a8000a,0x6292006f,0x6a730061}},	//   laki, וֹעֵ, ákoľ, nıfı
  { {0xd23b039e,0x68fb28ac,0x56b6004c,0x2cad0034}},	//   _מגיל, klud, עפען_, _boed_
  { {0x2cad0026,0x0b460342,0xc5f2004c,0x64462a4c}},	//   _coed_, ендн, נדא_, naki
  { {0xfbd20086,0x501b0008,0x6915013f,0x68fb0542}},	//   دتا_, _מוכו, _všel, dlud
  { {0xe9860001,0xdb970033,0x59f80033,0x64461416}},	//   ећин, эвіч_, меля_, haki
  { {0x317a0053,0x6446200d,0xdef7000a,0x6e3f0030}},	//   לאַד, kaki, _נמלט_, özbő
  { {0x7d03049c,0x7e7e2a4d,0x38c8002b,0x2cad2a4e}},	//   ïnst, lepp, باتی_, _goed_
  { {0x24890409,0x6d5e2a4f,0x207b004c,0x64462a50}},	//   _raam_, lupa, לאקא, daki
  { {0x2489020a,0x8c3d0011,0x26de2a51,0xa49b0144}},	//   _saam_, _roşi, unto_, ològ
  { {0x38b100dc,0x6d5e2a52,0x04590015,0x49ba0015}},	//   _párt_, nupa, ولدة_, _عائد_
  { {0xa4d505d1,0x68fb1470,0x8ddb000a,0x7e7e158f}},	//   томі, clud, לקיק, hepp
  { {0x53470033,0x38b10030,0x988b000a,0x6b820034}},	//   эхна, _várt_, _מָגֵ, nwog
  { {0x6d5e2a53,0xaca30016,0xe737012e,0x8caa0065}},	//   kupa, _phịn, _џеј_, _झकझो
  { {0x64460b63,0x6466008c,0xd0d5006b,0x2bd2000b}},	//   baki, ätiö, вовъ, _देसा
  { {0xd5fb013a,0x6d5e0849,0xb5fb05bd,0x521401cf}},	//   _מפור, dupa, _מלוכ, удст
  { {0xf1b90048,0x44390708,0x867a000a,0x70580138}},	// [51b0] ņš_, mbs_, ּר֣ו, эатр_
  { {0xdd95005f,0xaca30092,0x44390334,0x93fc000a}},	//   казы, _thịn, lbs_, _צלזי
  { {0xe2a7002e,0xd6570008,0xfeb80015,0x6722008c}},	//   æður_, תיבת_, راكت_, _luoj
  { {0xec150074,0xc5f3004c,0x2bd2000b,0x60c42a54}},	//   نواد, אדע_, _देहा, chim
  { {0xeaae2a55,0x53b3000b,0xbc18005e,0x0c24005e}},	//   ай_, ुनिश, ніші_, умін
  { {0x6d5e2a56,0x69150089,0xb05b079c,0xeb960c7a}},	//   bupa, _všem, _fläc, тиш_
  { {0xb8650015,0x6d5e0fb7,0x6446015a,0x2cad01f9}},	//   ناظو, cupa, yaki, _toed_
  { {0x291900c0,0x319c000a,0x68fb007c,0x394c2a57}},	//   ösa_, לבונ, ulud, _dvds_
  { {0x69dc002e,0x7c390026,0xb6a5005e,0xd709004a}},	//   _þren, mbwr, випл, мние_
  { {0xa695009c,0x44392a58,0x6935007e,0x7d1b2a59}},	//   триј, ebs_, _анжу, _hius
  { {0x89370015,0xf09f0016,0x64462a5a,0x7d1b019a}},	//   _أعطا, _nhào_, taki, _kius
  { {0x8934003b,0x7c390026,0x7d09020d,0x7e7e0144}},	//   _إعلا, nbwr, _jhes, zepp
  { {0x94d30010,0x64462a5b,0x387f2285,0xe6950015}},	//   роўц, raki, meur_, _للإد
  { {0x48040191,0x387f2a5c,0xfbd20008,0xf6e70036}},	//   _спів, leur_, שתך_, _яцен
  { {0x644600b6,0xf09f0092,0xf9870029,0x7d0900f2}},	//   paki, _chào_, جب_, _ohes
  { {0x8c3d01e2,0xe0da0191,0x6d5e00f2,0x78a92a5d}},	//   _koşu, єва_, vupa, njev
  { {0x60c4163a,0x76432a5e,0x43930054,0x78a90085}},	// [51c0] rhim, _keny, _вањс, ijev
  { {0x387f16c3,0x68e4006f,0x78bb05ff,0x60c42a5f}},	//   heur_, čidi, hkuv, shim
  { {0x2b4d0b7a,0x387f0409,0x78bb0209,0x76432a60}},	//   _avec_, keur_, kkuv, _meny
  { {0xdb090089,0x6d5e2a61,0x7d092a62,0x7e7e1dab}},	//   ěnýc, rupa, _ches, sepp
  { {0x2bd2000b,0x7d1b0049,0x387f157a,0xc4d3000a}},	//   _देशा, _dius, deur_, סגד_
  { {0xda630001,0x092a0015,0x38660045,0x7d090f3f}},	//   ављи, وسبي_, _scor_, _ehes
  { {0x6722022d,0x6df60015,0x32db000a,0x2d8702de}},	//   _suoj, _شكرا, וחסנ, ænet_
  { {0x31570053,0x7d1b1dab,0x387f0003,0x442000cb}},	//   דיקן_, _gius, geur_, _ngi_
  { {0xaca30092,0x97a30010,0x6f1c2a63,0x76430293}},	//   _giốn, арэл, _kirc, _beny
  { {0xf76f0015,0x7cf8006f,0x38b80030,0x78bb0601}},	//   زاً_, ríru, _méri_, akuv
  { {0x6f1c0011,0x78a90089,0xceb30135,0xa4d90001}},	//   _mirc, bjev, ייז_, едну_
  { {0xb8650086,0x69b70053,0xb80a00e6,0x7cf80227}},	//   _ماهو, _שלאף_, _قيام_, píru
  { {0x76432a64,0xccf3000a,0x46580033,0x44392a65}},	//   _feny, שכר_, _залю_, rbs_
  { {0x752302d7,0x3f8f002e,0x26c501c9,0x76432a66}},	//   _funz, ægum_, chlo_, _geny
  { {0x171b0053,0xdcc2000b,0x8c3d1d56,0x764801d7}},	//   _קווע, लसाज़, _koşt, mady
  { {0x6f1c003e,0x7643003f,0xa6170008,0x999e0046}},	//   _airc, _zeny, _בקוד_, _letů_
  { {0x7d090176,0x7643000c,0x7d1b04ed,0x7ff40015}},	// [51d0] _rhes, _yeny, _rius, لسكا
  { {0xfe70003b,0x539a0008,0x9757000a,0x6f1c04a0}},	//   قدم_, _ניתו, כימו_, _circ
  { {0x5dd50029,0x387f0003,0x6f1c2a67,0xedd50058}},	//   دقائ, yeur_, _dirc, دياد
  { {0x8c3d0011,0xcd04005e,0xaf37002b,0xdfd10067}},	//   _noşt, аччи, _لرست, _هيج_
  { {0x387f0152,0x9ad500ce,0x0000006a,0x0000006a}},	//   veur_, люкі,   ,
  { {0xfa550086,0x69150a6f,0x6d580264,0xda65006b}},	//   ارشگ, _išei, ávac, увки
  { {0x7d090041,0x764300e8,0x387f2a68,0x78bb0044}},	//   _thes, _reny, teur_, tkuv
  { {0x76432a69,0xb05b005b,0x6f1c2a6a,0x0000006a}},	//   _seny, _yläa, _zirc,
  { {0x387f038d,0x78a900bd,0x76430d25,0x2bbb0015}},	//   reur_, rjev, _peny, _غارة_
  { {0xb7bd04f9,0x6b890020,0x05a90080,0x78bb0f7a}},	//   ncţi, _iseg, евой_, skuv
  { {0xd46a0001,0x04462a6b,0x387f0003,0x8c3d0045}},	//   нине_, ленн, peur_, _foşt
  { {0x7643000c,0x3f4f0048,0xc7950015,0x8d76000a}},	//   _weny, kļu_, _مشتب, נגרו_
  { {0x765c0050,0xe9180191,0x7e9b0024,0x7ae300b8}},	//   óryc, _році_, _kāpē, onnt
  { {0x7523003f,0x7bda000a,0x7eb202de,0xca33000a}},	//   _tunz, תקשו, _næpp, ים֮_
  { {0x27290084,0x41b50063,0x11da0029,0x7ae32a6c}},	//   _hún_, астт, رورة_, innt
  { {0xb7bd0011,0xdfd20115,0x291d0509,0x4466006b}},	//   ecţi, ميز_, _jiwa_, _свив
  { {0x3f4f0024,0xf8b20053,0x69150089,0x27291e7d}},	// [51e0] gļu_, זשן_, _všeh, _jún_
  { {0x441b000a,0x629e2a6d,0x6da605a7,0x6e460040}},	//   _אופס, _unpo, лиза, انام
  { {0x6b890467,0x2d960010,0x27292a6e,0x1317000a}},	//   _aseg, ырас, _lún_, _תחיל_
  { {0x10a6000d,0xcf260015,0x1b4a275e,0x7ae306cd}},	//   _симн, _مرسي, езди_, ennt
  { {0x9313002b,0x33c9000a,0x7cdc00bc,0x2d8702de}},	//   _خویش, ֻהוּ_, dčrt, æner_
  { {0xba2a002b,0xdb11001a,0x65610307,0x69342a6f}},	//   رستم_, æfðu, kulh, анку
  { {0x6b8902d7,0x8c3d04f9,0x3d34011f,0x272902c1}},	//   _eseg, _poşt, _כָּל_, _aún_
  { {0x01370053,0x7ae30a11,0x8c79004a,0x1754006b}},	//   אָזט_, annt, _ищут_, авия
  { {0x88810086,0xd90d002b,0xdb1e008c,0x291d02f2}},	//   زیون, ذیه_, öväe, _diwa_
  { {0x5b7b0053,0x65740001,0x2729002d,0x6b7b0008}},	//   _ארמא, агођ, _dún_, _ארמנ
  { {0xdef70053,0x7648005c,0x6561016e,0x998c0073}},	//   רמיט_, rady, gulh, _vedų_
  { {0x76480035,0xf8ad002b,0x26d90003,0x35e30138}},	//   sady, _يکي_, ésor_, сцьв
  { {0xf09f0092,0x9cd7000a,0xe7370054,0xb05b0123}},	//   _giày_, רוכה_, _беч_, _blän
  { {0x291d003f,0x248d05fb,0x24550016,0xa1590054}},	//   _ziwa_, žem_, ụm_, кагу_
  { {0x5a9b0053,0x62340036,0xba9b004c,0x61fe0034}},	//   עשלא, сесу, עסלי, _cypl
  { {0x61fe005c,0x95530087,0xb05b07c2,0xd5b801ec}},	//   _dypl, _اخوا, _elän, scās_
  { {0x1ee70074,0x7ae3001a,0x2d982a70,0x0000006a}},	// [51f0] هوری_, ynnt, _arre_,
  { {0xaca30092,0xb05b0dca,0x326701d2,0x16110065}},	//   _phỏn, _glän, _стив, डेवर_
  { {0x9e070c1d,0x61fe0034,0xff0404d5,0x9f040058}},	//   учал, _gypl, сятн, حولو
  { {0x3c4700a2,0x6fd0000b,0xfc190015,0x9c190015}},	//   اضاف, _सेकं, نقاب_, نياء_
  { {0x2d980014,0x20c70020,0x9098106d,0xfd100015}},	//   _erre_, _võid_, _свят_, أجل_
  { {0x395507c1,0x6b8900bc,0xa6e2001a,0xb9550054}},	//   ањит, _vseg, öðlu, атић
  { {0x611500df,0xd2b8000a,0x20c7007c,0xa966006b}},	//   _sąly, רלות_, _tõid_, аища_
  { {0x53c6000b,0x98a70091,0x5c480058,0x61fa0072}},	//   रैडश, rsnį_, _ملفّ_, ütli
  { {0x29030048,0x6a6703c4,0x7e9b0024,0x0000006a}},	//   ēja_, _مطال, _tāpē,
  { {0x681b0048,0x98a70007,0x6449002e,0x4905000b}},	//   _rādī, psnį_, ðein, _हीरो_
  { {0x27e00084,0xdb1f0020,0xe7080015,0x64a60033}},	//   _þinn_, övõt, دتين_, аана
  { {0xcdf6000a,0xb4c0000b,0x1956000a,0x656111f0}},	//   ימתי_, ंघे_, _כבעל_, rulh
  { {0xb05b00b8,0xf74516d7,0xb6a5131f,0x2aab04d1}},	//   _plän, _тело, _вилл, _søby_
  { {0xfc160008,0xe808008b,0xeb92000a,0xb1e60015}},	//   יקרי_, _снід_, קָר_, لأزه
  { {0xa3e2021e,0x614602b0,0xd132002b,0xe29701ca}},	//   _दशक_, реба, تمز_, јас_
  { {0x91e30036,0x61fe0264,0x21670054,0xa0b500af}},	//   іоте, _vypl, јити_, бљуј
  { {0x38b800dc,0x34fb0008,0xe3b20015,0x75130015}},	// [5200] _iért_, _בהקד, _ذرة_, _بويض
  { {0x539b000a,0xee372a71,0xb3bb000a,0xe29a1092}},	//   _ייפו, ину_, _סמיכ, _рао_
  { {0x72060086,0x38b800dc,0x5d6a0080,0x92e900e6}},	//   _خودم, _kért_, тием_, _حريق_
  { {0xcea90053,0x3393002b,0x8b66009a,0x0000006a}},	//   וי_, _الیز, لاتم,
  { {0xab94005e,0xc477000a,0x38b80030,0x60c30045}},	//   силі, שתנו_, _mért_, _înma
  { {0xd9540029,0xb05b00f2,0x5a330888,0x27e00091}},	//   منتخ, _yläo, оншт, _žino_
  { {0x27e00045,0xe9f80033,0x6d430045,0x38c6005e}},	//   _ţin_, ынкі_, ânat, ищив
  { {0x9997006b,0xfce601eb,0x25f90065,0x8b36009a}},	//   ркът_, _тобо, _उड़ी_, _نفرش
  { {0xc6f80001,0xdb24002b,0xc6a60317,0xab2a07d1}},	//   лних_, _طوای, арни, _роза_
  { {0x6d5e0125,0xd6d40174,0x597608f0,0xda650021}},	//   orpa, ёжны, _выду, _هامي
  { {0x7d020011,0x95ca0175,0x7aed0003,0x25d801b0}},	//   olos, тупа_, éate, умны_
  { {0x7d0205c7,0x89db000a,0xdb0d008c,0xa3b00046}},	//   nlos, _בחבי, äkök, lířů_
  { {0x82f70015,0xe758005e,0x66e603ca,0xd40719db}},	//   لأسئ, _силі_, _кода, ряни
  { {0x7d02018b,0x1dc6000b,0xc7d7000a,0xa5d7002b}},	//   hlos, लनात, _דודי_, ابیر_
  { {0x8546008f,0x225e002a,0x7d022a72,0x70590342}},	//   _тэле, ótka_, klos, лавр_
  { {0xcf27003b,0x30a4000d,0x361b000a,0x3d20000b}},	//   لرئي, орув, _בווד, यदों_
  { {0x6d5801c9,0x3ce600bd,0x9f0500c3,0x7d022a73}},	// [5210] ávan, dnov_, مورو, dlos
  { {0x93fc000a,0x7d0216ce,0x0000006a,0x0000006a}},	//   _בלחי, elos,   ,
  { {0x63bd1405,0x20c70005,0x51950029,0xdd910015}},	//   lysn, _võib_, _الجذ, ثوا_
  { {0xfbd300e6,0xc19a0008,0x9b4500a2,0xdd980033}},	//   يتش_, _עשרי, منصو, шшу_
  { {0x307a0053,0x69de25df,0x799a00da,0x9b880015}},	//   _גארנ, úpen, _artw, لخوف_
  { {0x7d021d5b,0x8338004f,0xc334004f,0x0000006a}},	//   alos, סאוס_, קוצ_,
  { {0xfc670063,0x7d022286,0xca740015,0x627c004c}},	//   _възн, blos, تانغ, דנונ
  { {0xfc300029,0xb05b00c0,0x7d021ee1,0x2f0f0030}},	//   _يحق_, _oläm, clos, függ_
  { {0x3f890026,0xcb34006b,0xb995002b,0xf09f00a1}},	//   nwau_, _метъ, _گلاب, _chài_
  { {0x38b8002e,0x20e80064,0xc8790064,0xaab40015}},	//   _sért_, eğil_, dişe_, _وصلت
  { {0x8afa0053,0x0000006a,0x0000006a,0x0000006a}},	//   _עפעק,   ,   ,
  { {0xf41f00f2,0x6b9b2a74,0xdd7a000a,0x39151635}},	//   ydät_, _krug, נטרל, _умер
  { {0xd7770029,0xf8b2000a,0x98f40015,0xb8cb000b}},	//   _خاضع, _משא_, _بثلا, खा_
  { {0x78a22a75,0x6b9b002a,0x3f9e0046,0x232720b9}},	//   _znov, _mrug, _čtu_, сори_
  { {0xb05b00f2,0xd4d60010,0x3ce6006f,0x38b80030}},	//   _eläm, _гіпэ, ynov_, _tért_
  { {0x25710084,0x26c20024,0xb05b02ad,0x010a0369}},	//   mál_, ūkot_, _fläm, اتسو_
  { {0x4fa30063,0x543b0053,0x257100dc,0xe043005e}},	// [5220] питв, _געפא, lál_, янти
  { {0x52860029,0x2eb7000b,0x394500da,0x2bdb000b}},	//   _الدك, _आकृत, _owls_, _मेधा
  { {0x02b70008,0x8c260015,0x25712a76,0x7d022a77}},	//   _הליך_, مفاه, nál_, tlos
  { {0x6b9b1405,0x7d0200f2,0xab2a071f,0xd5fa004c}},	//   _brug, ulos, года_, אפער
  { {0x4bda0067,0x6d430045,0x7d020009,0x3ce62a78}},	//   دباد_, ânar, rlos, rnov_
  { {0x78a20796,0x6da60658,0x6b9b1a5f,0x7d022a79}},	//   _snov, _лига, _drug, slos
  { {0x1c3a0033,0x6934002b,0xf41f0b12,0x7d022a7a}},	//   _бязь_, زکار, ndär_, plos
  { {0xacea0015,0x473415f7,0x257100bf,0x7d57000a}},	//   _إرسل_, онис, dál_, _לילד_
  { {0xf093000a,0xd794006b,0x78a200bc,0xeb970eaf}},	//   לנה_, ципъ, _vnov, _лит_
  { {0x8c3d0064,0xd6d40033,0x09e60912,0xdddc005a}},	//   _inşa, іжны, _лозн, _marž
  { {0xf76f0086,0x257100dc,0xba37000a,0xba9b000a}},	//   وای_, gál_, _הטבח_, _תסבי
  { {0x2419004a,0x94ab0004,0x63bd008c,0x89a50015}},	//   ионы_, утоа_, tysn, _بإكم
  { {0x38cb0074,0x6915002c,0xc8230015,0x27e0008c}},	//   _حالی_, _všet, _عفوً, _äin_
  { {0x7ae4002f,0x3817000a,0xfbd3000a,0xb5a6006b}},	//   éith, _הקדם_, לתר_, _грий
  { {0xf6770053,0xd6db000a,0x225f0061,0x26c2003d}},	//   _לײגט_, _תחול, ğuk_, ūkos_
  { {0x764a0176,0x3039002b,0x2937004c,0x69150227}},	//   _hefy, شترک_, מאלן_, _ušet
  { {0x29040e95,0xbed92a7b,0x9f55005e,0x2f380015}},	// [5230] ilma_, адах_, ювач, مثلة_
  { {0x59a8000b,0xdddc1c4e,0x644f28f9,0x6585001a}},	//   कमार, _darž, laci, _úthó
  { {0x60c30045,0x81c3003d,0xdd9b056d,0xa6e1001a}},	//   _înmo, ģēsi, ыша_, æðig
  { {0xd5fb00b2,0xe9a90086,0x764a0026,0xb47b000a}},	//   נפאר, یگان_, _lefy, רָ֑י
  { {0x1b190080,0x4478000a,0xfb85002b,0xcaf50015}},	//   ажды_, מעאל_, تدای, يستب
  { {0x41740086,0x13c80008,0x764a0034,0x60cd2a7c}},	//   _بایس, מּוֹ_, _nefy, lham
  { {0x644f2a7d,0x26de2a7e,0x6295003d,0x60cd2a7f}},	//   kaci, dito_, idzo, oham
  { {0x644f19d3,0x60cd2a80,0x28a9000b,0x26de016e}},	//   jaci, nham, काधि, eito_
  { {0x752a00b8,0x28d8005d,0xd00c000a,0x1a7a002b}},	//   _aufz, बोधि, ְּחֹ, _چشمک_
  { {0x62950111,0x25712a81,0xba770040,0x26de2a82}},	//   jdzo, tál_, _دارت, gito_
  { {0x20c9000b,0x95950054,0x34aa053b,0x6abe0012}},	//   रसाध, црпљ, авно_, öpfe
  { {0x62950024,0x52b4000b,0x673b008c,0xd46a0b1e}},	//   edzo, ुस्स, ppuj, шиме_
  { {0x60cd003f,0x98f400e5,0x26de2a83,0x225e002a}},	//   dham, _عثما, bito_, ótko_
  { {0x43750036,0x8c1a0008,0x68fb2a84,0x7996002a}},	//   чуют, יורי, loud, ływe
  { {0x90b60124,0xdd1c01b2,0x644f2a85,0xe0da0004}},	//   ољаш, vážn, baci, аќај_
  { {0x644f0a28,0x410602e1,0xe4d30015,0xf992000a}},	//   caci, ізав, _يقود, ורל_
  { {0x2f0f00b8,0x254700dc,0x727a006b,0x57f9004f}},	// [5240] züge_, lől_, _кснс_, ׁלֽו
  { {0x68fb0991,0xb05b00f2,0x9e650015,0xa6f9000a}},	//   houd, _yläk, كامن, בִ֣י
  { {0xf27b0008,0xc27b0135,0x2d9c0107,0x527b000f}},	//   _דריש, _דריי, íve_, _דניא
  { {0x60cd0445,0x8fa61c64,0x672302cd,0xfbdb000b}},	//   cham, _даме, _linj, _मेहम
  { {0x5f760015,0x5e460015,0x68e92a86,0x539b004f}},	//   _باجر, _وَحْ, dned, ֙ינו
  { {0x539b000f,0xaa570015,0xaa470054,0xead70033}},	//   יסנא, قلها_, опља_, оміі_
  { {0x765c005c,0x26de2a87,0x60c42a88,0xc86601ca}},	//   órym, vito_, okim, отпи
  { {0x764a0176,0x60c42a89,0xd9100086,0x644f0a33}},	//   _sefy, nkim, ریش_, xaci
  { {0xb05b00c0,0x60c40007,0xca760033,0x3eb82a8a}},	//   _släk, ikim, _мужы, _kort_
  { {0xddde0011,0x26de001c,0x98ab003d,0x9bb7000a}},	//   cepţ, uito_, ālām_, _והמה_
  { {0x68fb00dd,0x3eb81347,0x60c40209,0x644f2a8b}},	//   boud, _mort_, kkim, taci
  { {0x6295005c,0xdca60015,0x67230012,0x26de2a8c}},	//   wdzo, رى_, _einj, sito_
  { {0x6d580057,0xdc020046,0xe816000b,0x752401c2}},	//   ávaj, _očíc, देशा_, _diiz
  { {0x25470014,0xe5720031,0xf6d30015,0xa2270015}},	//   ből_, _قطع_, _يزود, ترحه
  { {0x644f03b0,0x660303ae,0xa1940098,0x62952a8d}},	//   paci, _опља, марч, rdzo
  { {0x62870e80,0x60cd12d3,0xffe700f4,0xb4270058}},	//   sejo, uham, оюзн, _بعثو
  { {0x44290005,0x3eb82a8e,0x60cd0e94,0x6d47086c}},	// [5250] _iga_, _bort_, rham, _swja
  { {0xdd9b2152,0x3eb82a8f,0x60cd2a90,0x9e072a91}},	//   ише_, _cort_, sham, очел
  { {0x68e90176,0x3eb8018b,0xbd880015,0x68e00061}},	//   yned, _dort_, ينكن_, kimd
  { {0x60c40647,0xe58b000a,0xeb9100c3,0x6ab80065}},	//   ckim, יָדָ, فظت_, _अवॉर
  { {0x442908e6,0x644d002d,0xfaa50afa,0x3eb80220}},	//   _mga_, _meai, зало, _fort_
  { {0x644d016e,0xda7b2003,0xb1ab000a,0x05ca000b}},	//   _leai, ряд_, ֹסֵ֖, ानाब
  { {0xceb200b2,0x20bf005d,0x69940010,0x527c0053}},	//   _אים_, _एकाध, дрых, ינגא
  { {0xa3cb005d,0x6603005c,0x44292a92,0x644d0cd4}},	//   लना_, _rynk, _nga_, _neai
  { {0x76410176,0xfa8b0080,0x66e50229,0x386200dc}},	//   tbly, _всей_, зопа, ókra_
  { {0x44290005,0x25470014,0xddde0f1b,0x68fb2a93}},	//   _aga_, től_, lepš, soud
  { {0x764100dd,0xb05b00f2,0x45d4005e,0x1d15000a}},	//   rbly, _eläi, дцят, ּקָר_
  { {0x25470014,0x397a000a,0xda08002b,0xf1d60065}},	//   ről_, _לטענ, _بيمه_, _डेगन
  { {0x67230375,0xd5ae002b,0x644d0125,0xe7840054}},	//   _tinj, نفی_, _deai, _жујо
  { {0xf67500b2,0x44290005,0x386d2a94,0x66031200}},	//   _זײַט_, _ega_, lger_, _tynk
  { {0x60c400f2,0x2f1400c0,0x20c70020,0x505a04ab}},	//   tkim, lägg_, _võin_, йшая_
  { {0xf99200b2,0x55ba013a,0x60c40007,0x386d2a95}},	//   ערן_, _למצו, ukim, nger_
  { {0x60c42a96,0x3eb82a97,0x1f6603ca,0x386d2a98}},	// [5260] rkim, _port_, якам, iger_
  { {0x26c500df,0xd00f0029,0x60c42a99,0x539b004c}},	//   nklo_, الك_, skim, _פייו
  { {0xa2bb0008,0xb2bb0008,0xccef0001,0x3f8f001a}},	//   _המיט, _המיר, ећ_, ægur_
  { {0x3eb800b8,0xf5360053,0x386d0079,0x0000006a}},	//   _wort_, לטער_, jger_,
  { {0x02b6000a,0x6e3b0061,0xb09b000a,0x6606002a}},	//   ּהֶם_, _şube, _היכר, ękki
  { {0xc3330135,0xd357000a,0x386d2a9a,0x68e00034}},	//   עוו_, ליני_, eger_, wimd
  { {0xbefa005d,0x68e00064,0x24800085,0x8c460a13}},	//   ्तीन_, timd, _obim_, _неве
  { {0x8d5b000a,0xa9570015,0xddde003d,0x200f0012}},	//   _לכלי, أجور_, cepš, ügig_
  { {0x7b090084,0x68e00064,0x644d016e,0xc7ba0033}},	//   ðstö, rimd, _reai, сёй_
  { {0x692a0089,0x68e00064,0xbb3b000a,0xa7370021}},	//   _před, simd, _לעמי, أثير_
  { {0xceb3013a,0x6aa80134,0x28a9000b,0x9a3b000a}},	//   תית_, _indf, काशि, _התבק
  { {0xc9850029,0x6aba01c2,0x0000006a,0x0000006a}},	//   _تشكي, _hotf,   ,
  { {0x28a9005d,0x46a62a9b,0xb865002b,0xf8a9000b}},	//   कारि, _надв, _زانو, कारय
  { {0x9713017f,0xd378005e,0xd5b00015,0x78a7003d}},	//   _зміц, ччю_, _لفت_, ējve
  { {0x867b0008,0xf67b0008,0x0697000a,0x27320016}},	//   _הרוו, _האומ, _מדגם_, _hân_
  { {0x116a0086,0x1bec000b,0xd5cb000a,0x44292a9c}},	//   تلفی_, जपाल_, _לֶחָ, _uga_
  { {0xc4f8000a,0xcd02002a,0xbefa0065,0x52a70058}},	// [5270] _מזהי_, _mość_, ्तून_, _فصدق
  { {0x27322a9d,0x798d002a,0x2007003d,0x7c290034}},	//   _mân_, ławi, āni_, _sger
  { {0xb2bc000a,0x627a000a,0x5c751356,0x1cd90033}},	//   _למזר, _ונתנ, длет, оджы_
  { {0xf045002b,0x3ea70030,0x8c9400ce,0x6aa802dc}},	//   _تعدی, űnt_, ерші, _andf
  { {0xa09a000a,0x109a000a,0x7aed0003,0x90540033}},	//   _וירט, _וברב, éato, _явяц
  { {0x07f20053,0xeab10015,0x2f140123,0xd939011e}},	//   _דאָס_, ضعت_, vägg_, очиш_
  { {0x28a9000b,0xcda90015,0x79a7005e,0x386d2a9e}},	//   कालि, _ظهره_, ярде, tger_
  { {0xb05b00f2,0xbca50002,0x27322a9f,0xf1c40046}},	//   _eläv, _تمري, _bân_, liší_
  { {0xcd02005c,0x27322aa0,0x386d0220,0x17f90015}},	//   _dość_, _cân_, rger_, غربة_
  { {0x27320023,0x7996005c,0xd7060080,0xbb840015}},	//   _dân_, ływa, мные_, _سلمي
  { {0xfe36000a,0x386d0123,0x58390033,0x7ae32aa1}},	//   ורתי_, pger_, _дзея_, mint
  { {0xfbc700e6,0x7ae32aa2,0xf9fa000a,0x69fa000a}},	//   نت_, lint, _והעמ, _ולעק
  { {0x1e0a014e,0x7e0a021e,0x2f1407fd,0x27322aa3}},	//   _वर्ष_, _वर्ग_, läge_, _gân_
  { {0xf6510015,0x6d580091,0xdb002aa4,0x7ae32aa5}},	//   _شئت_, švai, _armê, nint
  { {0xdfd2002b,0x91e6006b,0x75d2006e,0x7ae32aa6}},	//   چيز_, фове, _ليوا, iint
  { {0x7ae32aa7,0xdfd200c3,0x9fca2aa8,0x0000006a}},	//   hint, نيز_, огба_,
  { {0x7ae32aa9,0x3178005c,0xe0d7005e,0xd00705aa}},	// [5280] kint, strz_, єву_, дете_
  { {0x7ae300df,0x7f19005e,0x9d462aaa,0x64460091}},	//   jint, піху_, дежд, lbki
  { {0x7ae32aab,0xe4d7002b,0x6aba2aac,0x828b004f}},	//   dint, _رویت_, _rotf, _וְכֶ
  { {0x69c32aad,0x45b6000a,0x6c34002b,0x7c83004a}},	//   dyne, ופעל_, رفتا, вуше
  { {0x6d6700df,0x7ae300c0,0xfe70002b,0x692a0046}},	//   _įraš, fint, _مگا_, _ořec
  { {0x7ae32aae,0xead80033,0x19ba0015,0x69c30034}},	//   gint, ямлі_, قطعة_, fyne
  { {0x27320092,0xab66002a,0xfaa3011e,0x69c32aaf}},	//   _sân_, wożą, тајо, gyne
  { {0x692a0089,0xcc8703c5,0xc173000a,0x4ddb000a}},	//   _přeb, _обсе_, דחה_, _וחלו
  { {0xb05b0012,0x7ae32ab0,0xfce3144a,0x074302ed}},	//   _gläu, bint, _рото, кхэм
  { {0x27320092,0xcaa60115,0xc017000a,0xd6d000c3}},	//   _vân_, _تصري, וקפו_, اقد_
  { {0x27e90084,0x7e9b000a,0xcb13000a,0xb05b0123}},	//   _þann_, קסטו, _סלע_, _klät
  { {0x692a0089,0x27322ab1,0x88c60015,0x62972ab2}},	//   _třeb, _tân_, _تتطل, _saxo
  { {0xd91b0632,0x05de000b,0xe3c50015,0xa7d30058}},	//   _וואל, _फेरब, رْسَ, _لتوص
  { {0x057600e5,0x20c7007c,0x86c40058,0x0000006a}},	//   _قاعد, _võim_, _سيعن,
  { {0x41e4022a,0xe1640015,0x0000006a,0x0000006a}},	//   віта, َدِي,   ,
  { {0x7ae32ab3,0x70c9000b,0xd904002b,0x5064110c}},	//   zint, रसेल, شی_, ктуа
  { {0x3cf2000b,0x13f4004a,0x69c3002a,0x62972ab4}},	// [5290] ंचने_, _изъя, zyne, _taxo
  { {0x20c70005,0x44392ab5,0x71790004,0x333c000a}},	//   _kõik_, lcs_, _ебор_, _ותזמ
  { {0x7ae304f9,0x3d290086,0x257800dc,0xb05b00b8}},	//   vint, ستای_, nél_, _blät
  { {0x213e002d,0x44392ab6,0x621a000a,0x657a001a}},	//   íthe_, ncs_, _מותק, itth
  { {0x60d60008,0x69c30026,0x7ae32ab7,0xbc18005e}},	//   _נושא_, wyne, tint, міші_
  { {0xdb2500dc,0x499512bd,0x69c32ab8,0xe802000b}},	//   _épül, ешит, tyne, _लड़ा_
  { {0x6446005c,0x7ae32ab9,0xa3cf000b,0x225e002a}},	//   ybki, rint, वैत_, ótki_
  { {0x2f1400b8,0xa3c1000b,0xac380015,0x25780046}},	//   räge_, ूना_, _يسقط_, dél_
  { {0x692a0089,0x9b450015,0x99120015,0x7ae32aba}},	//   _přec, _أنطو, دِيث, pint
  { {0xcf920008,0xb659004a,0xda670058,0x69cc0065}},	//   נטי_, чших_, _زائي, तनशी
  { {0xb05b00f2,0xdeb6000a,0xceb2000a,0x060900fd}},	//   _ylät, תפתח_, איי_, янок_
  { {0xcdda00b2,0xbdda004c,0x61fb0061,0xdb000144}},	//   פֿיר, פֿיט, ğull, _armè
  { {0x61fb01e2,0xa8560008,0x9cd6000a,0x692a0046}},	//   şull, _ניסה_, תורה_, _třec
  { {0xf6790053,0xb05b00c0,0xfbd2000a,0xa3cf000b}},	//   _זאַמ, _oläs, רתך_, वैध_
  { {0xd13200e6,0x06960015,0x7c3b001a,0x016602ed}},	//   امر_, _سنية_, _ofur, экво
  { {0x05760015,0x7fd60033,0x60261305,0xc4c60015}},	//   _أمية_, нізі, едба, _ستعو
  { {0xd00f0029,0x6fd60036,0x6e3b0064,0xa77a004c}},	// [52a0] ملف_, хівц, _şuba, ּרעפ
  { {0x4df60080,0xc2c60015,0x33fb000a,0xb05b0dca}},	//   няет, _أيدي, _מהפנ, _slät
  { {0x63a4002e,0xb05b0012,0x628e2abb,0x9e730058}},	//   _hrin, _plät, mebo, اهمت
  { {0x629c0495,0xe45f0123,0x63a42abc,0x628e2abd}},	//   ldro, lhör_, _krin, lebo
  { {0xab94005e,0x2606000b,0x8c65005e,0xbbe90015}},	//   тилі, _सुनी_, ттєд, ورهم_
  { {0x387f0084,0x657a0034,0xed5a055f,0x7d0b2abe}},	//   efur_, ytth, _ног_, algs
  { {0x629c0048,0x7c3b0176,0x387f0026,0xb05b0012}},	//   idro, _ffur, ffur_, _gläs
  { {0xf1b30008,0x629c0026,0x25780097,0x89330015}},	//   רסה_, hdro, vél_, دعوا
  { {0x628e038b,0xb05b0012,0x67d406da,0xeb490058}},	//   kebo, _klär, топу, _يشكو_
  { {0x8f9b0008,0x2578050a,0x4b260015,0x629c2abf}},	//   ליפי, tél_, _أعرف, jdro
  { {0x4999005e,0x628e2ac0,0xa4d500e2,0x63a42ac1}},	//   _отця_, debo, воні, _arin
  { {0x58060029,0xe8560015,0x63a42ac2,0x629c2ac3}},	//   _كواك, _أنشد, _brin, edro
  { {0xdb002ac4,0xd90e002b,0x629c0079,0xe816000b}},	//   _armé, _پیک_, fdro, देखा_
  { {0x69a40372,0x236400dc,0x5693017c,0x63a40116}},	//   किपी, ámja_, _башт, _drin
  { {0x63a42ac5,0x7d020e95,0x30a72ac6,0x69d82ac7}},	//   _erin, koos, нрав, nzve
  { {0x629c1350,0x63a42ac8,0x69d82ac9,0xa98b004f}},	//   adro, _frin, izve, הָמִ
  { {0xe315000d,0x2906003f,0xf484004a,0x6d5c2aca}},	// [52b0] _имињ, _mkoa_, _сущн, _avra
  { {0xdef82acb,0x2bdb005d,0xd1350054,0x628e2acc}},	//   ных_, _मेगा, _иноћ, cebo
  { {0xf6530053,0x22dc000a,0x63a42acd,0xcd2b002b}},	//   רצע_, _מחזא, _zrin, سسان_
  { {0x91b6000a,0x23cb000a,0x69d820c0,0x6d07009a}},	//   _ספרא_, ּצַּ, dzve, رباق
  { {0x0056000a,0xa227002b,0x6d5c2ace,0x0000006a}},	//   _בשרת_, _ترکه, _evra,
  { {0x68e20026,0xda620a61,0xc334000f,0x5338000a}},	//   _amod, авши, אוס_, ענון_
  { {0xdef40010,0x6d580b7e,0x57c9000b,0x69ce0012}},	//   _спры, ávat, िन्ह, _übel
  { {0x212b0089,0x628e005c,0x718c000a,0x7785006b}},	//   _jich_, zebo, לְחַ, влиз
  { {0x212b00b8,0xb05b00f2,0x60c30045,0x53e0000b}},	//   _mich_, _ylär, _înmu, _पेंश
  { {0x2cad0089,0x2cbf0159,0x98b20024,0xf6510015}},	//   _hned_, _houd_, ādām_, جئة_
  { {0xb9b500e6,0x628e079b,0xd46a0076,0x2cbf0079}},	//   _جماع, vebo, мине_, _koud_
  { {0x628e29c9,0xf992000a,0x212b1f58,0x78ab2acf}},	//   webo, _כרב_, _nich_, _ungv
  { {0x628e2ad0,0x6b56000a,0xb8f5000b,0x656824ff}},	//   tebo, ֛ישׁ_, हस_, ardh
  { {0x68e2005c,0x2cbf0193,0x43430248,0xc7d60643}},	//   _zmod, _loud_, рерв, _בוני_
  { {0x42760086,0x20ca0015,0x628e2ad1,0x63a4055e}},	//   _یادآ, وبري_, rebo, _wrin
  { {0x55f60008,0x7c2d00bd,0xb099005e,0x63a42ad2}},	//   _במצב_, žarj, нтує_, _trin
  { {0x212b00b8,0x9f4f002e,0xe45f00c0,0xc7ac000a}},	// [52c0] _dich_, ægð_, phör_, ּׁבָ
  { {0x212b0b7c,0x69a4014e,0xa1c60010,0xc8ee0065}},	//   _eich_, किमी, _абод, _छद्म_
  { {0xb13a0029,0xed5700fd,0x22582ad3,0xc6920643}},	//   _تأخذ_, вох_, mark_, שאב_
  { {0x2258003c,0xbb4604f7,0xcb6a0254,0x91f7000a}},	//   lark_, ведк, даде_, _ימיו_
  { {0x6bd60002,0x6d451351,0x0b930015,0x7d022ad4}},	//   ختار, apha, لجود, roos
  { {0x212b0298,0x6e430e88,0xdd920086,0x291f0509}},	//   _zich_, _верз, _پور_, emua_
  { {0x610c00b8,0xd91a0080,0xf2d3000a,0x399c0030}},	//   eßli, мьи_, שעו_, dásá_
  { {0x58860010,0x07980001,0x98c3004a,0x2cbf016b}},	//   тыка, евић_, исыл, _goud_
  { {0x6c7b00b2,0x1634009b,0x0000006a,0x0000006a}},	//   _קאמפ, лепя,   ,
  { {0x2b460251,0x291f0573,0x4992002b,0xdc290015}},	//   mpoc_, amua_, _نیتر, _أسفه_
  { {0xd5b70191,0x1e57000f,0xaa37004c,0xfad7000a}},	//   вся_, כשיר_, _סטאק_, _שובך_
  { {0x77ca0c71,0xa3c1000b,0x3f4f002a,0x290d2ad5}},	//   _олег_, ूनल_, yżu_, clea_
  { {0x212b2ad6,0x212000bc,0x290400bc,0xc34b02ed}},	//   _rich_, dmih_, moma_, ьяне_
  { {0x212b0bcf,0xd6d00086,0x66e32ad7,0x27d7000a}},	//   _sich_, _دقت_, _коча, _שֵׁם_
  { {0x7aed038d,0xc1e80080,0xe7170008,0x31c403ad}},	//   éati, вьте_, _שחור_, аств
  { {0xe4d90086,0x299b0008,0x60d60026,0x29042ad8}},	//   _سوخت_, וסלמ, ghym, noma_
  { {0x30152ad9,0x22580a5d,0x7c2d00bc,0x40340ac9}},	// [52d0] удар, bark_, žark, реус
  { {0x6e450029,0x2cbf0089,0x61ee00dc,0x877b000a}},	//   انضم, _soud_, ánlá, ואמי
  { {0x752d003f,0x29042ada,0xd1310015,0xce94006b}},	//   _kiaz, koma_, _دمج_, рахъ
  { {0xbc190010,0xed580036,0x399c00dc,0x29042adb}},	//   нілі_, тої_, zásá_, joma_
  { {0x692a0089,0xdb850036,0xfbd000e5,0x2904158a}},	//   _přen, угли, يته_, doma_
  { {0x499903fc,0x3f990003,0xc87929b3,0xaf090015}},	//   етия_, _issu_, mişi_, _أقسم_
  { {0x49bb0086,0xb05b00f2,0xc8790061,0x6d582adc}},	//   باشد_, _yläp, lişi_, švar
  { {0x2cad0026,0x60cd2a14,0xf9900115,0x29042add}},	//   _uned_, nkam, تبه_, goma_
  { {0x2fc90035,0x7d1b003f,0x1bf50033,0x399c0030}},	//   nyag_, _ihus, _спаў, tásá_
  { {0x60cd0213,0x96950054,0x0f58000a,0xa6950099}},	//   hkam, уриш, דיזם_, уриј
  { {0xf87503c4,0x7d1b0849,0x60cd0209,0x290d2ade}},	//   _مهاج, _khus, kkam, plea_
  { {0xc329013a,0x69da0053,0xaca30016,0x22582adf}},	//   _זו_, _אַדו, _khốn, wark_
  { {0xe81f000b,0x60cd2ae0,0x935a0033,0x68e92ae1}},	//   मेशा_, dkam, эрну_, mied
  { {0x320c005c,0xb05b00c0,0xdb20002c,0x68e92ae2}},	//   żdym_, _släp, _štúd, lied
  { {0x7d1b0020,0xf6560008,0x2bdb000b,0x7d090091}},	//   _ohus, _עסקי_, _मेघा, _okes
  { {0x60cd0035,0x68e92ae3,0xc5f2000a,0xc0e30e4d}},	//   gkam, nied, _לדו_, боск
  { {0x0eaa0010,0x10a303ad,0x03aa0015,0xef1a2ae4}},	// [52e0] нкай_, щитн, _أدعو_, ема_
  { {0xdfcf003b,0x93b70008,0x539b0008,0xaf0a0029}},	//   أيك_, _עליו_, _טיפו, رقام_
  { {0xc27b00b2,0xfc66006b,0xf656004c,0x4d6601b0}},	//   _אריי, гълн, רסעי_, укев
  { {0x629e0035,0x68e9003d,0x7d1b2ae5,0x60cd01f9}},	//   _hapo, jied, _chus, ckam
  { {0xaca30023,0x59b6005d,0x629e24a6,0xc477000a}},	//   _chốn, _अपहर, _kapo, רתנו_
  { {0x67210085,0x629e2ae6,0x2904002a,0x692a005a}},	//   jmlj, _japo, woma_, _přeo
  { {0xc986002b,0xca750033,0x29042ae7,0x3f800144}},	//   اشتي, ручы, toma_, ltiu_
  { {0x672101a3,0x6d8b000a,0x64560061,0x8157004c}},	//   emlj, _אָמְ, _neyi, אסקע_
  { {0x59b6005d,0x473400d0,0x29042ae8,0x2c08002b}},	//   _अपवर, јнос, roma_, _شعری_
  { {0x29040a9e,0x7fd7000a,0xf76f0015,0x8f7b000a}},	//   soma_, טופס_, ساً_, עניק
  { {0xa9670063,0x99650036,0x752d2ae9,0x5f05000b}},	//   _биха_, _втіл, _piaz, ववत्_
  { {0x2ec1005d,0xe73a005e,0x68e92aea,0xc8790061}},	//   _शक्त, _зед_, cied, yişi_
  { {0x64560064,0x5335005e,0x26130016,0x69ca0034}},	//   _deyi, регт, _ẹo_, lyfe
  { {0x60cd005c,0x05d60015,0x629e2aeb,0x02450015}},	//   wkam, _مزعج, _capo, شَرَ
  { {0x765a2aec,0x160b000b,0xa63b000a,0xc1050015}},	//   maty, _सुपर_, _אגור, لوسي
  { {0x64560061,0xc8790061,0x6d5e2aed,0x765a2aee}},	//   _geyi, tişi_, dspa, laty
  { {0x7e550036,0x69ca0026,0xce6b03e7,0xc7e6000a}},	// [52f0] иває, hyfe, еред_, אוּ֙_
  { {0x9e15008f,0xc879062c,0x57fb000a,0xaaa4000b}},	//   адзі, rişi_, תלמו, _गोलक
  { {0x999e00df,0x692a0089,0x3f800251,0x3d95017a}},	//   _metų_, _přel, atiu_, риер
  { {0x9b750029,0x1df5000b,0x629e2aef,0xdd98055f}},	//   لاتص, _आशीष_, _zapo, ышу_
  { {0x6d5e00df,0x3f8008e0,0x68e92af0,0x765a2af1}},	//   aspa, ctiu_, vied, katy
  { {0x68e90050,0x7aea02d2,0xa9690c5b,0x765a2af2}},	//   wied, gift, вика_, jaty
  { {0x68e9191a,0x08d503fc,0x1a68002b,0x69ca28ad}},	//   tied, иция, طینی_, gyfe
  { {0xaca30023,0x7d1b000c,0xe9a80021,0x08c5153d}},	//   _thốn, _uhus, ادون_, рбин
  { {0xf048000a,0x68e92af3,0x78bb2af4,0x0000006a}},	//   נָה֙_, ried, rjuv,
  { {0xfaf300b0,0x765a1501,0x64560061,0xd6290249}},	//   _اثر_, gaty, _seyi, копе_
  { {0x89370015,0x7aed0003,0x248901c2,0x68e92af5}},	//   _إعطا, éatu, _bbam_, pied
  { {0x2d81017e,0x493a0008,0x03a609ef,0x19ba000a}},	//   ithe_, _סגנו, аимо, _במעב
  { {0x200f007c,0x4904002b,0x07471127,0x629e2af6}},	//   ügil_, _اونق, _схем, _papo
  { {0xe5a52af7,0xdb00001c,0xd2520015,0x52760004}},	//   _вики, _irmã, تنس_, шуму
  { {0xc3230010,0xb5a80015,0x8989000a,0x64560061}},	//   імск, _مايك_, כָּ֔, _teyi
  { {0x15fa0008,0x45fa000a,0x66150046,0x2d810125}},	//   _בהצע, _בהצג, ýzku, dthe_
  { {0x41030036,0x6d5e1df8,0x41270254,0x44260016}},	// [5300] ізув, wspa, рото_, _ào_
  { {0x3f8012b3,0xf8d2000b,0x735b000a,0x7996002a}},	//   rtiu_, _तत्प, _שכיח, ływi
  { {0x273b0023,0x6c360015,0x6d5e09e2,0x8c96005e}},	//   _lên_, لفضا, uspa, ирді
  { {0x692a0089,0x113b000a,0x3f800144,0xdde00030}},	//   _přem, _שתכל, ptiu_, ítőe
  { {0x273b0023,0xcf260086,0xba760015,0x2d812af8}},	//   _nên_, _نرسي, لاغت, athe_
  { {0x4ed5008f,0x2bb7000b,0x29660054,0x20070045}},	//   _люст, _आपरा, ањив, şnic_
  { {0xaca30092,0x2d81002d,0xbae30015,0x39770015}},	//   _chồn, cthe_, تكوي, لصيد_
  { {0x273b0023,0x692a2af9,0xec160086,0x765a005c}},	//   _bên_, _zřej, _نوزد, waty
  { {0x69d50014,0xd90d0086,0x765a0b53,0xbb432afa}},	//   _üzen, ریه_, taty, _метк
  { {0x24890176,0xee310008,0xcdd40008,0x4b7b000a}},	//   _sbam_, ּֽי_, ֶךָ_, _באמו
  { {0xfaa3005e,0xaadb000a,0x2459005e,0xdcfc0c85}},	//   _фахо, _שחבר, лань_, _sprę
  { {0xf4850086,0xdb000011,0x24e7013e,0xd837056d}},	//   حادی, _urmâ, рцог, _кэш_
  { {0x765a0c89,0x6b8201fc,0xd7e300ce,0x0000006a}},	//   paty, ntog, _мішо,
  { {0x24550092,0x2d812239,0xc7db004f,0x0000006a}},	//   ấm_, ythe_, _שַׁכ,
  { {0x171b00b2,0x95ca0001,0x60e70033,0xf1a40de5}},	//   _שווע, _јула_, ацаз, ортн
  { {0x6b8228a1,0x273b0092,0x40340080,0x25d7000a}},	//   ktog, _yên_, жетс, _כוון_
  { {0x692a0089,0x200f002e,0xc058005e,0x61fe2462}},	// [5310] _přej, ægi_, ріс_, _expl
  { {0x539c0008,0x22950029,0xfda70001,0x6b820ffd}},	//   _ייחו, _الدس, ијем, dtog
  { {0x2007005c,0xf296000a,0x66cd001a,0xf1a4024f}},	//   łni_, _הכתר_, _súkk, _дрян
  { {0x765800f2,0x8c190029,0xfc67006b,0x20c7007c}},	//   _levy, هيار_, ръжн, _võis_
  { {0xb0b6000a,0xe47a004c,0x645d01c2,0xaa450b9b}},	//   _הפרס_, טרײכ, iasi, белл
  { {0xff040063,0x61fb1252,0x62952afb,0x645d2afc}},	//   _дясн, şulu, nezo, hasi
  { {0x49930086,0x2d9c0134,0xceb20053,0xe8d2000b}},	//   تیار, ævet_, _ציל_, तसूच
  { {0xa9040015,0x98ac0045,0x645d2afd,0xc1f8004f}},	//   يبين, _rudă_, jasi, ימוץ_
  { {0x6b822afe,0x6d410003,0x692a0046,0x6a670015}},	//   ctog, _élab, _zřek, _نطال
  { {0xab280001,0x6008000a,0x7fd8000a,0x645d210e}},	//   _вођа_, יִתְ, יוחס_, easi
  { {0xdb260074,0x76580091,0x273b0034,0x99d40021}},	//   _اولی, _devy, _wên_, _وتما
  { {0x273b0023,0x18a40036,0xf2c9000a,0x39810144}},	//   _tên_, _маєм, _אע_, mós_
  { {0x889a0008,0xb05b00c0,0x398119fb,0xb38315f4}},	//   _תבני, _poän, lós_, плял
  { {0x8c1a013a,0xf6390053,0x62950b8e,0x87040015}},	//   טורי, _גײַל, gezo, _وبول
  { {0xf8db014e,0x98db005d,0x39812aff,0xcb12000a}},	//   _बताय, _बताए, nós_, פלל_
  { {0x29d30092,0xaca30092,0xc0e3000d,0x54e50015}},	//   ịa_, _khổn, поск, _وسيق
  { {0x6d470048,0x10160010,0xdb090079,0x6441002a}},	// [5320] _atja, сьвя, _creë, ślic
  { {0x692a0089,0xe45f001a,0xe29a0788,0xdb0021e5}},	//   _přek, gjöf_, _сао_, _ormá
  { {0x93250021,0x0d860a13,0x39812b00,0x0000006a}},	//   _برين, слен, jós_,
  { {0x3eaf0024,0xdd8f00e6,0x6b822b01,0x7fb60033}},	//   ēgta_, عون_, ttog, _лёгі
  { {0x6b740036,0x8c3d0064,0xfe94002b,0x2cb70046}},	//   ілку, _başb, _ویرج, _šedé_
  { {0x2d9c0134,0x539b000a,0x5dd60256,0x0eba0033}},	//   æves_, טינו, _любу, _сумы_
  { {0xf98a0086,0x69d50061,0x644f002a,0x8c461faf}},	//   اخته_, _üzel, ybci, _гебе
  { {0x1d0a0001,0x0f56000a,0x6b822b02,0x9997006b}},	//   _себи_, ֖יִם_, ptog, скът_
  { {0x853c0091,0x645d2b03,0x3866013b,0x0000006a}},	//   avėl, vasi, _vdor_,
  { {0x645d000c,0xceb30008,0x9f9b000a,0x60c60061}},	//   wasi, ִיר_, נסיפ, _lokm
  { {0x62950844,0xe7b6002b,0xdebb015b,0xb866002b}},	//   vezo, _گمشد, אמיל, _هاشو
  { {0x76430026,0xf79a00e6,0xb937000a,0xa9261e60}},	//   _efny, _منصب_, _הנאו_, _удел
  { {0x31d1000b,0x645d232e,0x2cb2008c,0x442d01be}},	//   सन्ध, rasi, öydy_, äe_
  { {0xadfa005d,0x877b000a,0x4dfa000b,0x2f0f0012}},	//   ्थान_, _תאגי, ्थाई_, nügt_
  { {0x692a0089,0x36330086,0x78a2007c,0x60c62b04}},	//   _přeh, _عروس, _kaov, _bokm
  { {0x957c0050,0x316c002c,0x62872b05,0x645d01c2}},	//   rząd, ádza_, sfjo, qasi
  { {0xcf270015,0xe45f0030,0xa0c40015,0x6d471db6}},	// [5330] مرئي, khöz_, أيقو, _stja
  { {0xd2510086,0x03d8000a,0x7ff4006e,0x78a22b06}},	//   _تند_, _לוחם_, أسفا, _laov
  { {0x4035008f,0x63ad0768,0x8d95009a,0x5d640058}},	//   _менс, _hran, تلاش, كُلْ
  { {0x63ad2b07,0xddc7002a,0x6aa10710,0xab6601ec}},	//   _kran, _zejś, _salf, kaļē
  { {0x2d9c0134,0x2f0f00b8,0xab640036,0x25630061}},	//   æver_, fügt_, звіл, zıl_
  { {0x39812b08,0xd35c004f,0x8c3d00d4,0x2563007f}},	//   tós_, נדול, _başc, yıl_
  { {0x6aa11de6,0xfd130002,0xa925004a,0x127c004c}},	//   _valf, _فجر_, одкл, טאגע
  { {0x69d500dc,0x63ad08a4,0x88c9067a,0x98e50015}},	//   _üzem, _oran, рлив_, تكبو
  { {0x6aa10034,0xbcb40046,0x4c170067,0xe73900af}},	//   _talf, šším, _طبرس, јео_
  { {0x66e50191,0x8f9c0053,0x3981001c,0xcb88000a}},	//   іона, ריזי, pós_, _לְעֹ
  { {0xceb40c44,0x7d0b03f8,0x63ad2b09,0x0000006a}},	//   ליץ_, oogs, _aran,
  { {0xdd7a0008,0x6c790053,0xa50a176f,0x63ad2b0a}},	//   סטרל, סאָפ, рема_, _bran
  { {0x256301e2,0x2bac000b,0x63ad2b0b,0xa3d30033}},	//   sıl_, चिया, _cran, доўч
  { {0xe5710087,0x82360015,0x60c60061,0x8c1a000a}},	//   _قطب_, ترحا, _sokm, שושי
  { {0x63ad2b0c,0xdbd8001a,0x614314b5,0xdb0903a0}},	//   _eran, hæða, деса, _creé
  { {0xddc7005c,0x2f14007c,0x20e80045,0x63ad2b0d}},	//   _wejś, mägi_, oşii_, _fran
  { {0x543b0053,0xceea0010,0x63ad0aff,0x20e80045}},	// [5340] _דעפא, адае_, _gran, nşii_
  { {0xafdb2b0e,0x853c0091,0x26c72b0f,0x0000006a}},	//   _iføl, dvėj, _jono_,
  { {0x63ad1827,0xdc3c006f,0xe45f0123,0x26c72b10}},	//   _zran, ráľo, bjöd_, _mono_
  { {0xadb70029,0xcea9000a,0xe588000a,0xe60c004c}},	//   تهما_, כי_, מָנָ, נפאָ
  { {0x7ed60036,0x69c50607,0xa2c1000b,0xd0f9000b}},	//   _дівч, ähen, रॉक्, ्करण_
  { {0x4402005d,0x29000007,0x7eb60015,0xe9460054}},	//   _लखनऊ_, čiam_, _بمسؤ, охио
  { {0xe6070067,0x58d4004a,0x853c0091,0x7d0b02de}},	//   _آش_, зойт, avėj, bogs
  { {0x6cd60015,0xec77006b,0x98a30054,0xbce50015}},	//   _بقرا, _мпс_, диће, _فأقو
  { {0xd6d00029,0x29180024,0x9f4400f2,0x27e90085}},	//   فقة_, ēra_, _ämä_, _žanr_
  { {0x3178006f,0x8574030c,0x2ca6007c,0x26d8002a}},	//   kurz_, плох, ldod_, óro_
  { {0xd6d70191,0x957c0050,0x48660063,0xa2be000b}},	//   іть_, dząc, _дълб, शान्
  { {0x2ca60026,0x63ad1a37,0x97c60015,0x394e0f3f}},	//   ndod_, _pran, _وتشم, mpfs_
  { {0x26c70007,0x1818002b,0xf7f6002b,0x4614009a}},	//   _fono_, _اراک_, _بساد, توگر
  { {0x8c1b000a,0x8434005e,0xe45f0030,0x63ad2b11}},	//   יוכי, ьняє, gkör_, _vran
  { {0x692a0089,0x63ad0335,0xe0d3006e,0x51842b12}},	//   _dřev, _wran, وزر_, мута
  { {0x63ad2b13,0x3ea32b14,0x50670033,0x0000006a}},	//   _tran, _sajt_, ўтва,
  { {0xe452011f,0x26de002c,0x289b000a,0x389b000a}},	// [5350] _אֶת_, ohto_, סימא, סימנ
  { {0x957c0050,0xddab0b9c,0xdbd8002e,0x3eaf0024}},	//   cząc, ител_, væða, ēgto_
  { {0x429a000a,0xf2d2004c,0xe29a000a,0x26de008c}},	//   _הסתב, _נעט_, _השתר, ihto_
  { {0x8c3d01e2,0xd49800b2,0xd5fb0053,0xd2510086}},	//   _başa, ַכות_, ספאר, _تنگ_
  { {0xfc30006e,0xaa45131f,0x7d0b2b15,0x00ba004f}},	//   نحه_, пелл, rogs, _המרמ
  { {0x7f3a013a,0x2bb80015,0x0ae8005e,0x539c000a}},	//   _לעשו, تامة_, одій_, יידו
  { {0x3258000a,0x7c970015,0x35ae000b,0x6c970058}},	//   חסום_, _وشرا, टिफ़, _وشرط
  { {0x26c702d7,0x26de00f2,0x01fc000a,0x2f14007c}},	//   _sono_, ehto_, יפול, vägi_
  { {0xf7710029,0xacda004c,0x26c70535,0xfaa4005b}},	//   راة_, _פֿלי, _pono_, öään_
  { {0xd7e6004a,0x8f9a000a,0xeab5000a,0x212901c2}},	//   ямые_, ציתי, _מִ֣י_, hmah_
  { {0x5afa0053,0xbae40015,0x85780a32,0xf40905bd}},	//   _פלעצ, _تكلي, осят_, _עפ_
  { {0x8c3d01e2,0x6441005c,0x656e002d,0xdb000012}},	//   _yaşa, ślin, ábha, _ermä
  { {0xf749040b,0x69ce018b,0x883a000a,0x692a0089}},	//   _التي_, _über, _התנו, _přev
  { {0x26de04af,0x31780012,0x68fb007c,0x07a20138}},	//   chto_, turz_, lnud, _чашн
  { {0x76ba0008,0x957c005c,0xc692000a,0xe45f0123}},	//   _למספ, rząc, _נאה_, rkör_
  { {0xa5070063,0x957c005c,0x68fb002e,0xcf4601e5}},	//   _неща_, sząc, nnud, знай
  { {0x8e3a00e6,0xd47b000a,0x747b000a,0x9e3a0015}},	// [5360] مسار_, _האפל, _הנפג, مساء_
  { {0x6fb30029,0x62070030,0x44200061,0xbea32b16}},	//   عملا, érlé, _izi_, наук
  { {0x823b000a,0xd23b000a,0x3257000a,0xdb090045}},	//   _לעיצ, _לגיל, _מסים_, _preî
  { {0x644620f3,0xfd120015,0xed4f002b,0x91bb000a}},	//   ncki, رجا_, اپن_, _המטי
  { {0x3cdd005d,0x2ca62b17,0x6d410003,0xdb090144}},	//   _खतरे_, rdod_, _élan, _creï
  { {0x60c4016f,0x05cb000b,0xaa572b18,0xdb0002de}},	//   ljim, ाहाब, كلها_, _ormå
  { {0xc333000a,0x60d60091,0xa3bf013f,0x60c42b19}},	//   גוג_, okym, ižší_, ojim
  { {0x60d60a6f,0x60c42b1a,0x5dfb000a,0xc7aa0015}},	//   nkym, njim, _הפלנ, مدخل_
  { {0x4cbb000a,0x60d60091,0xfa36006e,0xf8aa009a}},	//   _פזמו, ikym, _فراد, لدکه_
  { {0x6446005c,0xfa6703e7,0x661d002a,0xa3c20065}},	//   ecki, _наук_, ęskn, ूहन_
  { {0xceb30008,0x44200011,0x9956002b,0x4499004a}},	//   גית_, _azi_, _رضاش, овню_
  { {0x493b000f,0xc4c70087,0xa93b000a,0x993b000a}},	//   _הגאו, ستجو, _התאפ, _התאה
  { {0xa2ab000b,0x5347006b,0x8bb5004f,0x61050073}},	//   फ़ाल्, яхна, ֵּשׁ_, nėle
  { {0xa1950010,0x236d00bd,0xeb91000f,0x27f70264}},	//   магч, šejo_, כָל_, šená_
  { {0x2f14007c,0x44202b1b,0x954a0058,0x86e90058}},	//   nägu_, _ezi_, _اشتق_, _بعنف_
  { {0x3d06005d,0xd5fb000a,0x21290049,0x15fb000a}},	//   षकों_, _לפור, umah_, _להוע
  { {0x657a2b1c,0x1017002b,0x2129013b,0x0000006a}},	// [5370] luth, سبرد, rmah_,
  { {0x692a2af9,0x42550087,0x3f1402a7,0xddc5006f}},	//   _křes, _تندر, едус, zahŕ
  { {0xdb19005c,0xe1670015,0x657a00a1,0x0000006a}},	//   zywó, _عددي, nuth,
  { {0x69c50209,0x3cf7000b,0xd5a6002b,0x5577004c}},	//   ähem, ंचें_, _یف_, לעבן_
  { {0x0b440127,0x6f020003,0x657a0125,0x0ba80015}},	//   енін, éocc, huth, كاوى_
  { {0x4fd60008,0xbae50015,0xf8ae002b,0x84080030}},	//   _חושב_, بكتي, یکن_, lsőé
  { {0xdd940010,0x6446005c,0xceb2000a,0xda640021}},	//   _пары, ycki, _בים_, راوي
  { {0x2369010b,0x26dc001c,0xd83e00bc,0xdb19002a}},	//   _ovaj_, _alvo_, ščno_, tywó
  { {0xd7c90086,0xb8f5000b,0x64410046,0x96750033}},	//   زوده_, _सक_, ělil, мыні
  { {0x68fb0077,0x75242b1d,0x44200160,0x64410535}},	//   snud, _shiz, _rzi_, ślil
  { {0x692a0089,0xf7710086,0x99d50015,0x290d0079}},	//   _přet, راک_, _تقات, poea_
  { {0xd7d50001,0x661d0089,0xb4ca000b,0xb8670015}},	//   _ожењ, řsko, ोसे_, _راؤو
  { {0x78a90024,0x94d30010,0x240a005e,0x6d4301c0}},	//   mdev, тоўц, інги_, ínaj
  { {0xc7240191,0x60dd0079,0xe8e00016,0x78a92b1e}},	//   _здій, _alsm, ượt_, ldev
  { {0x692a0089,0x60c400bc,0x71760015,0x78a9003d}},	//   _třet, tjim, ظهرا, odev
  { {0x387f2b1f,0x1288002b,0x2b4d0107,0x50650015}},	//   ngur_, _کمدی_, _otec_, ّالِ
  { {0x4420003f,0x33660010,0x60d60007,0x8c3d0045}},	// [5380] _uzi_, _ўвог, rkym, _paşn
  { {0x29000007,0x63a42b20,0x78a9008c,0x60d62b21}},	//   čiai_, _isin, hdev, skym
  { {0xc0e60010,0xd47a0053,0xdb0902c1,0xed5a005e}},	//   _жонк, ַאַל, _creí, іод_
  { {0xdb000014,0xddd5002a,0x629c2b22,0x0000006a}},	//   _ismé, _bezł, lero,
  { {0x3f890026,0xab9a0018,0xbb432921,0x543b004c}},	//   ctau_, تخار_, вечк, קעסא
  { {0x63a4003f,0x78a902b9,0xf992006e,0x387f0144}},	//   _msin, edev, نبع_, egur_
  { {0xcb070029,0xedd6002b,0xc9860004,0xadba0015}},	//   بيون_, _غيرد, фули, _ظهرا_
  { {0x387f0ac1,0x61e30061,0xdb090045,0x629c2b23}},	//   ggur_, _ünle, _creâ, hero
  { {0x47340080,0x629c2b24,0x36d41092,0xca8601c5}},	//   ннис, kero, еопр, _огай
  { {0x692a0089,0x66cd002c,0x629c2b25,0x4fbb004c}},	//   _přes, _súkr, jero, קציא
  { {0x9e770008,0x78a9100e,0x63a42b26,0x7e9b000a}},	//   וגיה_, bdev, _asin, חסיו
  { {0x657a002f,0x628e00dd,0x6aa80034,0x291a0015}},	//   ruth, efbo, _hadf, _بقصد_
  { {0x97c60029,0x63a400dc,0x690b000a,0x17530033}},	//   _تتضم, _csin, _וּגְ, _авія
  { {0xf7930010,0xe6930015,0x692a0046,0x629c2b27}},	//   _рашэ, _للهد, _třes, gero
  { {0x8c3d0482,0x63a40005,0x95c40029,0xf67b0008}},	//   _başl, _esin, _سيظه, _ואומ
  { {0x84e80015,0xe7d2000b,0x64480046,0xf52b0058}},	//   _يفوق_, _तथाप, ědic, _بثته_
  { {0x6d4e0024,0x6aba0079,0x629c2209,0x7ff40058}},	// [5390] _atba, _ontf, bero, نسكا
  { {0x78a90024,0xdef80802,0xbf150015,0xfe700021}},	//   zdev, мых_, رواب, لدم_
  { {0x2d870152,0x3f892b28,0x63a40030,0x84e8002b}},	//   îne_, stau_, _zsin, _رفیق_
  { {0x200f007c,0x3f890045,0x6d4101f6,0x0000006a}},	//   ügis_, ptau_, _élam,
  { {0xdcfc0048,0x00760008,0x20e813cc,0x7cf1006f}},	//   _aprē, _אתרי_, rşit_, sťro
  { {0xde740015,0xeab10015,0x6aa80034,0xadbd0033}},	//   _لدفع, طعت_, _cadf, _лагi
  { {0x6d5c0026,0xf9910087,0x8c3d0064,0x2f140012}},	//   _gwra, ابت_, _yaşl, rägt_
  { {0x6aba018b,0x3238000a,0xb9920015,0x764a02de}},	//   _entf, וטון_, اليب, _affy
  { {0x692a0089,0x6d5c005c,0xf7190010,0x629c2b29}},	//   _přer, _zwra, зіны_, yero
  { {0xf6510015,0x78a90144,0x3ffa000a,0x3a74027c}},	//   دئة_, sdev, לִיא, _алфр
  { {0x85b90029,0xa2be000b,0x6675002b,0x673800bc}},	//   سادس_, शास्, ودگر, _divj
  { {0x62852b2a,0x02a8000b,0xfbc7002b,0x629c2b2b}},	//   _acho, _छोड़न, هت_, wero
  { {0x93430080,0xdcf50024,0x9cd6000a,0x36d52b2c}},	//   лняе, _apzī, גורה_, _подр
  { {0xc7d6000a,0x629c0077,0xe5690015,0x0000006a}},	//   _רוסי_, uero, _فمتى_,
  { {0x02190036,0x2b890016,0x7e6501c2,0x412a1305}},	//   діть_, húc_, dahp, зово_
  { {0x63a42b2d,0xe4c90015,0xe45f0db2,0xdfd2006e}},	//   _tsin, _يبين_, ljön_, هيز_
  { {0x2b89002c,0x63a41864,0x213904a9,0x6aaa0034}},	// [53a0] júc_, _usin, _dish_, ydff
  { {0x5ea60029,0xef172b2e,0xc357004f,0x0000006a}},	//   عمال, ему_, _רביז_,
  { {0x2139003e,0x8c3d0061,0x6aa82b2f,0xc692004f}},	//   _fish_, _taşl, _radf, ראב_
  { {0x71a30010,0x5d16002b,0x7ae30012,0x7c8319a5}},	//   _саюз, رباز, ehnt, гуше
  { {0x8236002b,0xa429000a,0xbc670040,0x0000006a}},	//   _ترکا, ֵֽנִ, رمون_,
  { {0x61050007,0x8f8b000a,0xe45f0030,0x39a60ac9}},	//   mėla, _מְלֵ, jjön_, ешив
  { {0x6ee00014,0x7c9605fc,0x8c960010,0xdb25002d}},	//   _több, _прац, _праі, úpái
  { {0xada30036,0xe876002b,0x3eaa0012,0x69dc0061}},	//   _щасл, راعظ, _habt_, _ürem
  { {0x77920086,0xa09b0135,0x0b1a0015,0x9b0602a3}},	//   ایتا, ליקט, _فقرة_, _ззад
  { {0x07d70015,0xc66a004a,0x8aa90015,0x6a160015}},	//   عذيب_, чшие_, _يدلّ_, _كبار
  { {0xb95a0021,0x4a57000a,0x8e3000af,0x0000006a}},	//   _رجاء_, _נשאל_, _сaдa_,
  { {0x3eaf0024,0x5dfb000a,0xf7460004,0x62852b30}},	//   ēgti_, לפינ, _зедо, _scho
  { {0x9cd7000a,0x0000006a,0x0000006a,0x0000006a}},	//   תוכה_,   ,   ,
  { {0x290000df,0x24710092,0xf7bb000a,0x0000006a}},	//   čiau_, ễm_, _מזדמ,
  { {0xd6270001,0x59a6005d,0x667300c3,0x628501c0}},	//   _поље_, _कैमर, _صدور, _vcho
  { {0x6285005c,0x361b000a,0x69c5008c,0xf48701e9}},	//   _wcho, _מווד, ähei, _чукн
  { {0xd2510074,0x2d9804ed,0x644d0034,0x62852b31}},	// [53b0] _پنج_, _apre_, _ifai, _tcho
  { {0x2139003e,0x93fc0008,0x4ed40036,0xc7f7000a}},	//   _wish_, _מלחי, люєт, גזמת_
  { {0x5336000a,0x8e840015,0x3135000a,0x0000006a}},	//   _שנתן_, المه, _ֹנָם_,
  { {0xbc190010,0x2b49026a,0x8c3d007f,0x0000006a}},	//   мілі_, íaco_, _taşm,
  { {0x2ca9006f,0x5c140666,0xdb092b32,0xfb86002b}},	//   ľad_, льшу, _areá, ندوی
  { {0xbb52003b,0xcff6000a,0xdb26002b,0x49950923}},	//   جنوب, _יצרה_, نونی, вшит
  { {0x692a02d5,0xe9a80015,0xbb180015,0xd2b8000a}},	//   _přep, فدين_, رزها_, תלות_
  { {0x0c720086,0xd944002b,0xf1b405bd,0x77692b33}},	//   _نگهد, دئوي, רסק_, tsex
  { {0x2d04008f,0x0b940021,0x32d4008c,0xe84800c3}},	//   _сярг, _مجلد, _käyt_, رجين_
  { {0xf1b3005d,0x81c30024,0xcf920008,0x8f9c0008}},	//   ुमान, ģēji, סטי_, ליחי
  { {0xb8950029,0xceb2000a,0x97c4002b,0x7769134b}},	//   _للاع, ביי_, نتیم, ssex
  { {0x2722002e,0x4346017a,0xe45f0123,0x8e36004f}},	//   rðna_, кемв, sjön_, כנתא_
  { {0xe72e0083,0xe6c50029,0xa8780015,0xa8a8004f}},	//   _ве_, _لتغي, _أحمر_, _רֹעִ
  { {0x8c3d01e2,0xf1aa0086,0xfbd2000a,0x644d0034}},	//   _başk, وازه_, סתם_, _efai
  { {0x9f40002c,0x644d0026,0x45d20431,0xcb120008}},	//   rzií_, _ffai, _војс, ילך_
  { {0x91030004,0xdd1c0091,0x61050073,0x0000006a}},	//   апсе, ršūn, tėla,
  { {0x2d982b34,0x7fd50484,0x0eaa0033,0x7ae10125}},	// [53c0] _spre_, ліфі, мкай_, _ollt
  { {0xdfcf003b,0x2fcf00c0,0xd37b00f3,0x321a1827}},	//   غيل_, ägga_, _קריט, _typy_
  { {0xdca60760,0x781e000b,0x43050015,0x254c0046}},	//   кажи, _पर्क_, _حذيف, _těle_
  { {0x7ae12b35,0x63b62b36,0x0000006a,0x0000006a}},	//   _allt, _kryn,   ,
  { {0x3eab00f2,0x28c5000b,0x3eaa02de,0x0000006a}},	//   öitä_, वानि, _tabt_,
  { {0x5b1302e1,0x600b000a,0x63b60034,0xca760033}},	//   аміт, _חִלְ, _mryn, туды
  { {0xa9c30063,0xe9f80010,0x1e97000a,0x3f80016e}},	//   исък, энкі_, _שכלל_, luiu_
  { {0xb05b0012,0xe8ea012c,0x7ae10416,0x0000006a}},	//   _gnäd, برتو_, _ellt,
  { {0xbb4605c4,0x3f80016e,0x7d020480,0x78ab0547}},	//   _резк, nuiu_, mnos, _dagv
  { {0xb996003b,0x7d0209df,0x9a6a00c3,0x0000006a}},	//   _للطب, lnos, _آمال_,
  { {0xeab1011f,0xa4d505d1,0x7e7b000a,0x3a99005e}},	//   _לֹא_, гоні, ואיז, _яттю_
  { {0x29000007,0x63b60d75,0x97c60015,0xe7b60015}},	//   čias_, _bryn, _لتتم, _لمصد
  { {0x69d501e2,0x63b60026,0x7d021550,0x69c5007c}},	//   _üzer, _cryn, inos, ähev
  { {0x3f800144,0x78a00030,0x68e21cb2,0x7d022b37}},	//   duiu_, lemv, _hlod, hnos
  { {0xd7c6002b,0x69d80030,0xa69b000a,0x95c30021}},	//   _سوژه_, nyve, _חשופ, _نيوه
  { {0x86370008,0xff530015,0xb637000a,0x7d020dd9}},	//   _ברוב_, لخط_, _ברוס_, jnos
  { {0x31340001,0x3f800ade,0xb4df000b,0x7d02174f}},	// [53d0] ретр, guiu_, णसी_, dnos
  { {0x64490007,0x657a2b38,0x9f040015,0xfbd3002b}},	//   žeid, orth, لوقو, یتش_
  { {0x60cf0011,0x28c5000b,0xed58005e,0x63ba003d}},	//   _tocm, वामि, воє_, ātne
  { {0x657a1740,0x3d0d000b,0x3f80016e,0x7d022b39}},	//   irth, िकें_, buiu_, gnos
  { {0xbc380074,0x3af50010,0x6441005c,0x7ba40015}},	//   نسها_, лякс, śliw, لصوم
  { {0xa927002c,0x8c3d0011,0x7d022b3a,0x7af82b3b}},	//   _obľú, _maşi, anos, givt
  { {0x69d82b3c,0xc334000a,0x7d020f5d,0x661c0061}},	//   gyve, בוס_, bnos, ürkl
  { {0x3ea10005,0x3eaf0024,0x68e22b3d,0xe7a907f7}},	//   leht_, ēgtu_, _clod, евил_
  { {0x657a0313,0x17f90015,0xdcfc0091,0x7c34131f}},	//   erth, عربة_, _aprė, _ветх
  { {0xd706004a,0x501c000a,0x98c4003d,0xeb0e000b}},	//   лные_, ווחו, ātām_, ाकृत_
  { {0xb9550063,0x9989005c,0x3ea10012,0x2cbf0013}},	//   _свещ, łał_, ieht_, _knud_
  { {0x63b60026,0xb6030091,0x68e22b3e,0x78a001f6}},	//   _pryn, ššok, _glod, cemv
  { {0x2d8100b8,0x657a2b3f,0xd6a8002b,0xa4430015}},	//   huhe_, arth, ردیم_, صَّو
  { {0xa6b40063,0x877a00a3,0xdb090144,0xe739012e}},	//   _всъщ, _נאצי, _dreç, _џек_
  { {0xc6920008,0xdc20005d,0x7d02002a,0x91e30419}},	//   _האו_, _बर्ड_, ynos, боре
  { {0x3d0d005d,0xc48603f1,0x69da0053,0xe45f2b40}},	//   िकों_, _слик, ײַלו, zköz_
  { {0xd36f0029,0x93960015,0x291f008c,0x7d0205e3}},	// [53e0] _فهي_, _إجبا, ilua_, vnos
  { {0xc2c60015,0xbe66002b,0x3ea10012,0x3f80016e}},	//   _إيدي, اهاي, geht_, ruiu_
  { {0xd83e0007,0x01660015,0xc1060015,0xa06a2b41}},	//   ščio_, _حُجَ, _مودي, _пана_
  { {0x0b8a0b44,0x8d1a002b,0x317b000a,0x00da0015}},	//   ески_, رزار_, _ארטמ, _أبدت_
  { {0x7af802d5,0x254c0089,0x62810c98,0x7517004c}},	//   tivt, _měla_, ólog, אַגע_
  { {0x1a66002b,0x4ed5006b,0x657a0034,0xbb470015}},	//   ایای_, _кюст, yrth, دلون_
  { {0xbea30001,0x3ce600c0,0xc27b000a,0xdb000046}},	//   _ћаск, phov_, גרצי, _usmí
  { {0xd90d0086,0x58d4250c,0x52d1000b,0x6fc8000b}},	//   ویل_, роит, _सक्स, रमपं
  { {0x657a0026,0xd6d00015,0x212001c2,0x0000006a}},	//   wrth, ققة_, ilih_,
  { {0xe7970015,0x2a650012,0x291f008c,0x248900da}},	//   اخيص_, _gelb_, alua_, _scam_
  { {0xf76f0086,0x69c50197,0x68e20026,0x6b822b42}},	//   يای_, ähet, _tlod, luog
  { {0xdb09001c,0x291f001c,0x2db70053,0x657a002d}},	//   _preç, clua_, אלטן_, rrth
  { {0x8c3d0011,0x6b820091,0xf3ff016e,0x254c005a}},	//   _paşi, nuog, raão_, _děla_
  { {0x315b0015,0x212000bc,0xf41f02dc,0x0000006a}},	//   فجرة_, elih_, ffär_,
  { {0x31c40404,0xe45f007f,0x0000006a,0x0000006a}},	//   бств, zköy_,   ,
  { {0x10e7002b,0x21200085,0xf51b000a,0x90552b43}},	//   اژدی_, glih_, _אֵ֖ל, рвац
  { {0x42550086,0x3ea100b8,0x70c5000b,0x386601c2}},	// [53f0] _پنجر, teht_, _लचील, _meor_
  { {0xc7d70008,0x4429016f,0x3866002d,0x26de0007}},	//   אומי_, _iza_, _leor_, nkto_
  { {0x7095008f,0x71270031,0x867b000a,0xa697000a}},	//   _канф, _مرحل, תרבו, רכבה_
  { {0x7bd9005c,0x4c9502b0,0xd5fb004c,0x2d810012}},	//   tywu, ридс, עפאר, ruhe_
  { {0xfb350010,0x8c48005e,0x2d81007c,0xeaae2b44}},	//   андэ, упів_, suhe_, ой_
  { {0x3eaf0024,0x60cd1e8f,0x2cad0034,0xe45f0061}},	//   ēgts_, ljam, _waed_, rköy_
  { {0x60cd00df,0xbdd5005e,0xa2bc000a,0x09e52b45}},	//   ojam, _товщ, תמוט, ройн
  { {0x39590089,0x3b550063,0x28c5000b,0xe7b50021}},	//   _čssd_, _вкар, वाधि, لمعد
  { {0x38ca002b,0x60cd008c,0x9f6301f3,0x6d472b46}},	//   ضايی_, ijam, афiк, _huja
  { {0x5967010f,0x8c3d01e2,0x6d472b47,0xca480015}},	//   _бъда, _başv, _kuja, _ملكه_
  { {0x28c5005d,0xf6250848,0x3aba000a,0xe4c60235}},	//   वादि, рдно, _שמענ, айни
  { {0x38690084,0x628700dc,0x895a000a,0x5dc8000a}},	//   _þar_, egjo, _ידעת, אֶשְ
  { {0x7d09010b,0x7d1b000c,0x89340806,0x68e92b48}},	//   _mjes, _mkus, _اعلا, mhed
  { {0x60cd0048,0x7e670089,0x644f094c,0x6aa30645}},	//   ejam, _nejp, acci, nenf
  { {0x70f60036,0xe0460080,0x254c0089,0x4429003f}},	//   ачає, инви, _těla_, _eza_
  { {0xe3ba0036,0x6aa300b8,0x7790002b,0x68e92b49}},	//   _аби_, henf, _بییا, nhed

  { {0x27ed08e1,0x6d552b4a,0x6d470091,0xf41f0123}},	// [5400] nzen_, _atza, _auja, sfär_
  { {0x63a901e2,0x442001e2,0x9e3a0029,0x27ed0186}},	//   çene, _iyi_, نساء_, izen_
  { {0x68e900dd,0x6aa30293,0xc27b00a3,0xf27b000a}},	//   khed, denf, _בריי, _בריש
  { {0x60cd005c,0xdd8f0015,0xdddc002a,0x44202b4b}},	//   cjam, ظون_, _perł, _kyi_
  { {0x7c290050,0x27ed0111,0x8236002b,0x6aa3233f}},	//   _czer, jzen_, _حرکا, fenf
  { {0x427a004c,0x957c002a,0x4420008c,0x6aa32b4c}},	//   דאַג, cząw, _myi_, genf
  { {0x27ed0111,0x3a3a00c0,0x386602c1,0x7c292b4d}},	//   ezen_, äpp_, _peor_, _ezer
  { {0xa3e6014e,0x7d09003c,0x68e92b4e,0x68fb02b9}},	//   पना_, _gjes, ghed, giud
  { {0x6aa32b4f,0x9cb30015,0x69c50012,0x442001d7}},	//   benf, _بمقت, äher, _nyi_
  { {0x7d1b02d5,0xf76f0015,0x501b000a,0x39a70030}},	//   _zkus, ذاً_, כופו, _fős_
  { {0x6d40000c,0x4b37000a,0x442001d7,0x27ed2b50}},	//   _kima, _כרמל_, _ayi_, azen_
  { {0x6d4001c2,0x4d77000a,0x7c20008c,0x5883004a}},	//   _jima, סתכל_, _kymr, _дыша
  { {0xdcfc0024,0x692a0046,0x6d402b51,0x645d2b52}},	//   _aprī, _ořez, _mima, rbsi
  { {0x35f70086,0x6d402b53,0xc2070054,0x46a30054}},	//   ارید_, _lima, аџби, _мачв
  { {0xc1050029,0x60cd0251,0x104b004a,0x50670004}},	//   موسي, tjam, вязи_, итаа
  { {0xe63b0008,0x95530086,0x60cd0007,0x23b50086}},	//   _בתוכ, _بخوا, ujam, _همبس
  { {0x4395000d,0xe1040010,0x692a0089,0x33950029}},	// [5410] _уапс, цярп, _břez, _الخز
  { {0x63ad025c,0x539a0008,0x33fc0008,0x51870076}},	//   _isan, _עיתו, _שהזנ, _кума
  { {0x7c292b54,0x27ed0014,0x254c0089,0x7d0928b4}},	//   _szer, zzen_, _mělo_, _pjes
  { {0xbd180191,0x6d470085,0x8d7400c3,0x6d402b55}},	//   ації_, _vuja, زاما, _cima
  { {0x7c200b7c,0x8c3d0011,0x28c5005d,0x6d40013c}},	//   _cymr, _naşt, वासि, _dima
  { {0xa3b8005d,0xa036000a,0x6d40001a,0x79830034}},	//   छित_, _לארה_, _eima, tunw
  { {0xa3a9005d,0x1a68002b,0x98a6006f,0x6ec4000b}},	//   _गैस_, شینی_, _choď_, रारु
  { {0x27ed2b56,0x8c3d0064,0x63540089,0x63ad0607}},	//   tzen_, _başt, něný, _osan
  { {0x7c200176,0x68e92b57,0xa088000a,0x8aa71797}},	//   _gymr, rhed, בְתִ, _вред
  { {0x39b50048,0x06c90802,0x28c5005d,0x27ed2b58}},	//   _tās_, угой_, वाहि, rzen_
  { {0x442603eb,0x27ed00dc,0x89d90029,0xe5a50063}},	//   _šo_, szen_, _حوار_, щини
  { {0x7d192029,0x33d6005e,0x385b002b,0xb8b40015}},	//   nows, бігт, _ششصد_, _وإنت
  { {0x386d079b,0x7d1a000a,0x53fa0015,0xdcfc003d}},	//   maer_, רֵיה, ارجح_, _sprī
  { {0x8c1a0008,0x7d19002a,0x59bd0065,0x3669009b}},	//   רושי, hows, ्मपर, _сако_
  { {0x41b5010f,0x63ad00df,0x69dc0064,0x8b05005c}},	//   остт, _esan, _üret, częł
  { {0x7d19005c,0xe3b2002b,0x70560015,0x8c3d0061}},	//   jows, _فرخ_, إنذا, _yaşt
  { {0x6d402b59,0x44260092,0x7d19005c,0x692a0089}},	// [5420] _rima, _áo_, dows, _přez
  { {0x52aa0001,0xdcfe0046,0x6d402212,0x386d0034}},	//   _свом_, rupč, _sima, haer_
  { {0x610c01e2,0xdd8f012c,0xa0a603a7,0x10a602ed}},	//   ağla, فول_, _ланд, _линн
  { {0x661c08f5,0xd36f002b,0x447b004c,0x98be0045}},	//   ürki, _تهی_, ָנסע, _mută_
  { {0x3b960054,0xc053004f,0x0000006a,0x0000006a}},	//   сјет, _מזר_,   ,
  { {0x9e760086,0xa39b0053,0x539b000a,0xdc29002b}},	//   _دهست, רױסז, ריסו, جسمه_
  { {0xa9670e88,0x9da50015,0x8c3d0061,0x6d402b5a}},	//   бија_, _وصفه, _başs, _tima
  { {0x175403fc,0x8c3d0011,0xf8aa002b,0xb9970033}},	//   овия, _paşt, ادثه_, ёвых_
  { {0x7b07002f,0x6b850015,0x27e2001a,0xe6c60015}},	//   órtá, _وشكل, ákn_, متدي
  { {0xb6c6005f,0x67530029,0x37a7006b,0x6d410003}},	//   ссий, أخير, стън_, _élar
  { {0x79530015,0x7e9b000a,0x7abb000a,0x0a160058}},	//   _فَلا, נסטו, _תצבו, _اوضح
  { {0x6fc8005d,0x63ad0089,0x2722002e,0x28130086}},	//   रमां, _psan, iðni_, _کوهس
  { {0x28c5005d,0x254c0046,0x938b0033,0x63540046}},	//   वारि, _tělo_, ысна_, věný
  { {0x78250029,0x248d005c,0x656e002d,0x7d19002a}},	//   _بعمل, żem_, ábhs, zows
  { {0x610500df,0xa3a9005d,0x31c40e88,0x89780008}},	//   lėli, _गैर_, пств, יָּה
  { {0xd1300015,0x63ad2b5b,0x0000006a,0x0000006a}},	//   ّمِ_, _tsan,   ,
  { {0xa49b0251,0x61050007,0x63ad2b5c,0x4f580015}},	// [5430] riòd, nėli, _usan, مجلد_
  { {0x7f74005e,0x7d19002a,0x7c26013f,0x9757004f}},	//   ягує, wows, _úkry, ציבו_
  { {0x957c0050,0xfe700029,0x7d192b5d,0x5e440015}},	//   cząt, عدك_, tows, أَمْ
  { {0x61050007,0xf532000a,0x3f801702,0x5bb9024f}},	//   kėli, ֵ֥א_, briu_, илея_
  { {0x3f800251,0xdfdb006b,0xb0b6000a,0x39c00045}},	//   criu_, _сън_, _ופרס_, _lăsă_
  { {0x386d0026,0x61050091,0x7d19002a,0x539c000a}},	//   waer_, dėli, sows, טסדא
  { {0x28c5000b,0xfaa6002b,0x7d19002a,0x386d0013}},	//   वालि, زجوی, pows, taer_
  { {0xa3a9005d,0x61fa002e,0x98be0045,0xd942004a}},	//   _गईं_, útli, _rută_, мещи
  { {0xdb230086,0x98be0011,0x9aa50015,0x61050091}},	//   _فوری, _sută_, _ومرو, gėli
  { {0xf5490016,0x0a6802d9,0xb6a5226f,0xfc300058}},	//   _dấn_, _грци_, циол, _سحق_
  { {0x4af6002b,0xca480015,0x7ac4004a,0x64a62003}},	//   _بکند_, _المه_, _эсте, оана
  { {0xf2c90008,0x2d8100f2,0x3993016e,0xc952000a}},	//   _בע_, irhe_, mãs_, _חמא_
  { {0xd5b80024,0xad1a000a,0x06f50015,0xd8a8002b}},	//   avā_, שורר, _وستج, _دهنو_
  { {0x55e50785,0x7b1f016e,0x979a000a,0xe7560040}},	//   _молб, cêut, _כשנק, _بلوغ_
  { {0xc5d502e5,0x99e9000a,0xd6440015,0xf6f6009a}},	//   _філь, בַּ֥, _عضوً, _بزنگ
  { {0xe45200c3,0x3f802b5e,0x55ba000a,0x957c002a}},	//   _غضب_, triu_, _כמצו, rząt
  { {0x2545003d,0x3f800091,0xb4e60065,0x0000006a}},	// [5440] _vēlu_, uriu_, फसी_,
  { {0x9e5a01c5,0x3f80016e,0xe1fa00ce,0x957c0535}},	//   рраф_, rriu_, _вго_, cząs
  { {0x412a0036,0x6da60029,0x667a0053,0x8d66005e}},	//   _воно_, تمام, שטעק, івде
  { {0xc7b900dc,0x3f800011,0x0c262b5f,0xad650015}},	//   kvő_, priu_, омен, سامه
  { {0xc8bd0065,0x8aca00af,0x0000006a,0x0000006a}},	//   _ऍफ़ट, ићка_,   ,
  { {0xe81d005d,0x61050091,0x1af40033,0x8f6700ce}},	//   _पड़ा_, vėli, япля, _фарб_
  { {0xc7b90030,0x9203003d,0x5d78000a,0xc8c5000b}},	//   evő_, šāvi, _לָּנ, वांट
  { {0x6d5e022d,0x39422b60,0xb9970033,0xfe43005e}},	//   mppa, öks_, івых_, _інто
  { {0xc6f80191,0x6d5e0149,0xc6a61411,0x8a7a0058}},	//   йних_, lppa, орни, _نحاس_
  { {0xf5490023,0x35f40956,0xec130015,0xda650067}},	//   _vấn_, зпор, _غولد, _فامي
  { {0xbb3b0053,0x47d40086,0xa3b0000b,0x6b822b61}},	//   _כעמי, زيگر, _टैब_, lrog
  { {0xf5490023,0x9c830069,0xd7e602a3,0x29010046}},	//   _tấn_, _účtu, _міло, éhat_
  { {0xb4270015,0xc6d3002b,0x7b1f016e,0x93270015}},	//   تعدو, ستیت, pêut, قرآن
  { {0xdb0000b8,0x75d60015,0x0000006a,0x0000006a}},	//   _ermö, _ويشا,   ,
  { {0x306b009c,0x957c002a,0x2545003d,0x356a02bb}},	//   ијан_, rząs, _dēls_, _трлн_
  { {0xb97b015b,0x893405bd,0x6b822b62,0x397b004f}},	//   ינלי, לָּא_, krog, יטלנ
  { {0xd8d70053,0xff500015,0x6e3a001a,0x0000006a}},	// [5450] קומט_, نخل_, _útbj,
  { {0x6b822b63,0x623515be,0x0000006a,0x0000006a}},	//   drog, _непу,   ,
  { {0x4338002b,0xde190015,0x8d770058,0x0000006a}},	//   _بسيج_, حقات_, تاذا,
  { {0x6ce4005e,0x272b00cb,0xe0870015,0x3cd50a32}},	//   міче, jønn_, _بجدي, яжес
  { {0xef930086,0x0056000a,0x69de00cb,0x6d5e2b64}},	//   _زیاد, _משרת_, øpen, appa
  { {0xed5b0029,0x0ac70080,0xe80e000b,0xdcfe003d}},	//   _نشرت_, ющем, ापना_, rupā
  { {0x627c000a,0x26c90016,0xe9a80015,0xc27c0643}},	//   בנונ, _đao_, قدين_, ברוי
  { {0xab95000d,0x88c90a23,0x6b822b65,0xc8c50065}},	//   _набљ, слив_, brog, वाइट
  { {0x8bb70029,0x96b90054,0x6b822889,0x3d170065}},	//   _بإزا, буну_, crog, तवीं_
  { {0xb05b00c0,0x2ed6000a,0x06e90033,0x95850c31}},	//   _snäl, ִֽים_, смок_, плое
  { {0xd7c90086,0xf9900015,0x394c0295,0xad35004f}},	//   _گوشه_, _لبن_, _guds_, ּנָס_
  { {0x499a0008,0xa50a000d,0x399a000a,0xfc270058}},	//   _לשעב, сема_, _ליעד, فح_
  { {0xddd50014,0x7d0b2758,0xb8ef000b,0xeb91004f}},	//   _mező, ings, शा_, ךָ֜_
  { {0x8c1a0008,0xfbd20008,0x2369002a,0x78a92b66}},	//   מורי, עתם_, _dwaj_, leev
  { {0x52b90010,0x26c71434,0xd24f006e,0xdb1b016e}},	//   цыяў_, _inno_, انف_, _crué
  { {0xaac7005d,0x55f6000a,0x61050091,0x404a00af}},	//   लाँक, _ממצב_, kėlu, спао_
  { {0x8fa31673,0x0000006a,0x0000006a,0x0000006a}},	// [5460] нате,   ,   ,
  { {0x63a403ac,0x8cc1005d,0x33fb000a,0x59bd000b}},	//   _ipin, _रोबो, _להפנ, ्मार
  { {0x32db0008,0x6b820026,0xc333000f,0x57a8000b}},	//   _החינ, wrog, _רות_, _कन्ह
  { {0x315700b2,0xdc980036,0x9989002a,0xf5490016}},	//   _מיטן_, івлі_, łaś_, _nấm_
  { {0xaac7005d,0xbbe90029,0x628e0079,0x78a902de}},	//   लांक, يرهم_, ogbo, deev
  { {0x539b0008,0xf96a005e,0x629c0901,0x68eb007c}},	//   מינו, брий_, nfro, _algd
  { {0xf5490023,0xa96700d7,0x6da3053b,0xada304d7}},	//   _bấm_, пија_, _пира, _парл
  { {0xacea003b,0x26c702d7,0xf5490092,0xd9100086}},	//   _ارسل_, _anno_, _cấm_, خیص_
  { {0x272b00cb,0x3ce6292b,0x6d4e2b67,0x7d022b68}},	//   rønn_, mkov_, _huba, mios
  { {0x6d4e000c,0x3ce60559,0xcff7000a,0x657c0030}},	//   _kuba, lkov_, פציה_, árho
  { {0x18a6005f,0xba1a0029,0x1e97000a,0x3ce6006f}},	//   _нажм, _ايضا_, הכיל_, okov_
  { {0x3ce612d7,0x7d021481,0x6d4e1801,0x26c72b69}},	//   nkov_, nios, _muba, _enno_
  { {0xa8470070,0x254c0089,0x61330064,0x6d4e2b6a}},	//   _علوم_, _měli_, nçle, _luba
  { {0xa77b0008,0x6d5c2b6b,0x5693050e,0x877b0053}},	//   _פרופ, _otra, _зашт, _פאוי
  { {0x569b013a,0xa69b0008,0x869b000a,0x95530015}},	//   _היוצ, _השופ, _היוז, _كخيا
  { {0xc5eb000a,0xd0d4006b,0x6aaa120d,0x7bc02b6c}},	//   _לַחֹ, носъ, heff, _ormu
  { {0x3ce60cbd,0x84980806,0x64400091,0x6d5c2b6d}},	// [5470] dkov_, _رئيس_, žmir, _atra
  { {0xa6f8000a,0x6d4e2b6e,0xd5b0000b,0x93940015}},	//   קִּי, _buba, _जनाज, _أجيا
  { {0x2b4d0144,0x6d4e2b6f,0x8d740067,0x3f890034}},	//   _suec_, _cuba, فانا, suau_
  { {0x3946002d,0xc212000a,0x16a9000b,0xc5f3000a}},	//   _nios_, _יהי_, _कस्ब, עדף_
  { {0x21290849,0x6d5c2b70,0x5ba70033,0x78a9007c}},	//   mlah_, _etra, яржз, veev
  { {0x99d40086,0x21292b71,0x5ba80033,0xf5490016}},	//   کتها, llah_, якім_, _sấm_
  { {0x7bc009b9,0x3ce610a5,0x6d4e2b72,0x7d03001a}},	//   _ermu, bkov_, _guba, énss
  { {0x212908c0,0xac19059c,0xd7c9002b,0x5e440015}},	//   nlah_, _добу_, قوبه_, _أَفْ
  { {0x394602c1,0x6d5c0089,0x9a47002b,0x629c1138}},	//   _dios_, _ztra, _فضاه, yfro
  { {0x21290509,0xe5e10033,0x999f0030,0x78a90072}},	//   hlah_, вымi_, űrők_, seev
  { {0xf5490092,0x212908c0,0x6b8b002e,0x39460c24}},	//   _tấm_, klah_, lugg, _fios_
  { {0x59a6000b,0x0000006a,0x0000006a,0x0000006a}},	//   _कैटर,   ,   ,
  { {0x4c9a0008,0xcc76000a,0x629c2b73,0x0000006a}},	//   חברו, וגרת_, tfro,
  { {0x6d5a0152,0x3ce61927,0x7d021a41,0x21290509}},	//   _étag, zkov_, zios, elah_
  { {0xa0220064,0x3ced0020,0xda0d000b,0x3ce6006f}},	//   _çözm, _olev_, िपित_, ykov_
  { {0x74f70029,0x6d4e2b74,0x629c1490,0xa01b02dc}},	//   _يفوز_, _ruba, sfro, _odöd
  { {0x23360191,0x63a4003f,0x6d5c2b75,0x3ce612d7}},	// [5480] _охор, _upin, _stra, vkov_
  { {0x21290509,0x61f50012,0x69c12b76,0xe80e0065}},	//   alah_, ßflä, _orle, ापता_
  { {0x3ce61eae,0x5502005d,0x7d020604,0x3ced2b77}},	//   tkov_, _लगाए_, tios, _blev_
  { {0x25d600b2,0x447b0053,0xdd8f0015,0x547b004c}},	//   ווען_, ַנצע, ؤون_, ַנצײ
  { {0x7d020541,0x69c10633,0xe6f20016,0xdb1b0144}},	//   rios, _arle, hườ, _cruï
  { {0x5e460015,0xda660015,0x3ce62b78,0x7d022b79}},	//   _يَحْ, ذاتي, skov_, sios
  { {0xf98f0029,0x8884002b,0xa9230046,0x3ce6147b}},	//   لبي_, فیان, ěžno, pkov_
  { {0x57b42b7a,0x7afd0007,0xba290015,0xd7e6005e}},	//   ебит, _įste, أسهم_, діоо
  { {0x69c11611,0x37aa005e,0x387d0034,0x3eb82b7b}},	//   _erle, ітин_, _ddwr_, _kart_
  { {0x98a30048,0xddce1cdb,0x6a832b7c,0x7eeb004f}},	//   ējā_, _nebū, _алфа, ַ֗יִ
  { {0xceb30008,0xe6f20092,0x1818002b,0x88c60015}},	//   דית_, gườ, _کراک_, _يتصل
  { {0xa4d50036,0x291f0003,0xe7860a15,0x67230160}},	//   хомі, coua_, _жуко, _eknj
  { {0x44320050,0x29042b7d,0xd6da1377,0x493b000a}},	//   _czy_, mima_, _мтк_, _וגאו
  { {0x29042b7e,0x0000006a,0x0000006a,0x0000006a}},	//   lima_,   ,   ,
  { {0x98a6005c,0x21290509,0x4af9004c,0xf2040c1d}},	//   _choć_, tlah_, פּשײ, вято
  { {0xdfd5008f,0xe4a7000d,0x43950001,0x3d18000b}},	//   нобы, _црко, _заис, धकों_
  { {0x26dc0007,0x78a2003f,0x6d580107,0x21290375}},	// [5490] _kovo_, _mbov, ívan, rlah_
  { {0x21290509,0x3eb82b7f,0x44292b80,0x753d0030}},	//   slah_, _cart_, _iya_, lmsz
  { {0x61e100c0,0xfbd00086,0x33180029,0xd634000a}},	//   älld, یته_, _تزيد_, תָּח_
  { {0xd2510074,0x2904010b,0x3156004c,0x8cb40033}},	//   _جنگ_, jima_, _רירן_, ксіч
  { {0xcb690080,0xf0440080,0x00f60008,0x29042b81}},	//   чале_, _аэро, _נמשך_, dima_
  { {0x78a20041,0xb0620020,0x6b8b0106,0x26dc2b82}},	//   _abov, _äärm, rugg, _novo_
  { {0x6e940004,0xdb020012,0x60dd2b83,0x6b8b0079}},	//   _ширу, stoß, _kosm, sugg
  { {0x290d04f9,0x29042b84,0x644d0125,0x0000006a}},	//   unea_, gima_, _ngai,
  { {0x44292b85,0xd7c9002b,0x5745004a,0x290d2b86}},	//   _nya_, سوده_, нниб, rnea_
  { {0x0ab80029,0x644d0541,0x75240012,0x96950054}},	//   _يطلب_, _agai, _skiz, хриш
  { {0xead40063,0xf5062516,0x672300bc,0xe8f30016}},	//   _шофь, езно, _vknj, _đươc_
  { {0x29042b87,0xd7560086,0xc329000a,0xe6f20016}},	//   cima_, بلیت_, _הו_, rườ
  { {0x7d0a001a,0xd7c80015,0x0000006a,0x0000006a}},	//   éfsi, _يومه_,   ,
  { {0x78bb2b88,0x68e92b89,0x2b5f01c2,0xb7da000a}},	//   lduv, lked, _mtuc_, _מקני
  { {0x28d3014e,0x56920e88,0x81360033,0xa49b0144}},	//   थापि, _сајт, ехац, gnòs
  { {0x78bb0020,0x69dc0251,0x6d49005c,0x7524003f}},	//   nduv, _àree, _niea, _ukiz
  { {0x13b60029,0x3eb82b8a,0x1fa7005e,0x321f0061}},	// [54a0] _أصبح, _part_, нкти_, ğuya_
  { {0x29042b8b,0x441b000a,0xa6f9000a,0x139b000a}},	//   zima_, _מופס, הִ֣י, _צביע
  { {0x68e90bfa,0x6e930115,0x3eb82b8c,0xbc6a0015}},	//   kked, الما, _vart_, كمان_
  { {0x61e12b8d,0x29042b8e,0x60dd0034,0x67210085}},	//   älle, xima_, _gosm, holj
  { {0x2904010b,0x0a940484,0x5b262b8f,0xa509000a}},	//   vima_, валю, нька, וּסִ
  { {0x6f79004f,0x0000006a,0x0000006a,0x0000006a}},	//   _קְרו,   ,   ,
  { {0xee2a0029,0x523a004c,0x49b70015,0x8c430061}},	//   _رأسه_, הײַנ, فايد_, ışan
  { {0x63b60123,0x68e901d3,0x0000006a,0x0000006a}},	//   _osyn, gked,   ,
  { {0x6d5a0152,0x26dc001c,0x61330064,0x28570015}},	//   _étab, _povo_, nçla, رؤية_
  { {0x4c350010,0x29042b90,0xf1e0000b,0xd6d7005e}},	//   _рэст, sima_, नहान, етю_
  { {0xfe9b000a,0x7ae50012,0x44291d46,0x29042b91}},	//   היימ, öhte, _sya_, pima_
  { {0x4429003f,0x68e91f63,0x753d0030,0x6aba2b92}},	//   _pya_, cked, umsz, _hatf
  { {0x24800176,0x6721065d,0x60dd2b93,0xf8b300f3}},	//   _ddim_, bolj, _rosm, _תשנ_
  { {0x44290f4d,0xd5b00074,0x26dc02b9,0xf7170015}},	//   _vya_, _نفت_, _uovo_, _كينغ_
  { {0x28c5014e,0xd6570008,0x6d580247,0x60dd2b94}},	//   वाचि, _איות_, íval, _posm
  { {0x88bd0050,0x644d0026,0x6aba2b95,0xc446002b}},	//   mośc, _ugai, _latf, عیین_
  { {0xdb070064,0xff530031,0x60dd016e,0x88bd002a}},	// [54b0] _ölçe, اخر_, _vosm, lośc
  { {0x68e900dc,0x2229002b,0xfe70009a,0x0000006a}},	//   zked, _يزدی_, مدم_,
  { {0x88bd0050,0x6d490024,0xbd4b0029,0x63b6002a}},	//   nośc, _piea, سؤال_, _zsyn
  { {0x307900b2,0x672100dc,0x317a01ac,0x0000006a}},	//   _קאָנ, zolj, _קארד,
  { {0x68e90061,0xeb991411,0x0076004f,0x6ef201d0}},	//   vked, фил_, _בתרי_, _sæbe
  { {0x88bd0050,0x8afd0046,0x820b000a,0x6aba00da}},	//   kośc, _otře, ּהֵ֖, _catf
  { {0x6721065d,0x6ca704f7,0xd2b8000a,0xab5d002a}},	//   volj, _праж, גלות_, _drża
  { {0x88bd005c,0x9f33005e,0x8883002b,0x2d570061}},	//   dośc, _реґі, ایشن, _içe_
  { {0x75eb0014,0x78bb0020,0x657a003e,0x67210694}},	//   közö, rduv, esth, tolj
  { {0x2caf0111,0x0ab40087,0x68e92b96,0x24800034}},	//   legd_, _محمد, sked, _sdim_
  { {0x88bd0712,0xd9e5005d,0x95850063,0xa2d0000b}},	//   gośc, _कथित_, ълне, दास्
  { {0xe9450086,0x67212b97,0xda04006b,0xa7d50015}},	//   _شرای, solj, _счуп, _لتتص
  { {0x9cd60008,0x6721044c,0x6c7a004c,0xa6c90015}},	//   דורה_, polj, וארפ, _يوصل_
  { {0x8b88000a,0x88bd002a,0x3f890034,0xeb92004f}},	//   עָרֶ, bośc, drau_, סָר_
  { {0xa822002b,0x321a002b,0xdb09007c,0x75d20067}},	//   _مکین, ذيرد_, _iseä, _نيوا
  { {0x3f8906ad,0xc616000a,0xc952000a,0x2fc001d0}},	//   frau_, _בחצי_, שמן_, tvig_
  { {0x41270254,0xd0070a21,0xdfcf0015,0xe3b70033}},	// [54c0] тото_, вете_, ييف_, _абы_
  { {0x61330064,0x1eaa0029,0x8fa30033,0x9e6319a5}},	//   rçla, باري_, рафе, ивуд
  { {0xdd8f003b,0x9d46010f,0xb15a0015,0x127b004c}},	//   قول_, вежд, _تؤخذ_, _קאטע
  { {0xb63600b2,0x7afd00df,0x3f890026,0x1636004c}},	//   דרעס_, _įsta, brau_, דנער_
  { {0x8b960080,0xe4570053,0x88bd005c,0x7c2d002a}},	//   треч, דינט_, zośc, żarn
  { {0x9f400014,0x63a90064,0x93fb0008,0x6e960002}},	//   rzió_, çeni, ולני, _جلسا
  { {0xbb470015,0x02a40065,0xbb29009a,0xcd020535}},	//   خلون_, ख्यभ, رسهٔ_, _paść_
  { {0xb9e30036,0x98c30010,0x52df005d,0xc213039e}},	//   ріши, асьл, _नक्स, יהו_
  { {0x88bd0050,0xf7720070,0x8afd0089,0xe6662b98}},	//   wośc, جاع_, _stře, ктно
  { {0x88bd005c,0x95d8000d,0x9b46002b,0x657a02f7}},	//   tośc, едот_, _شناو, tsth
  { {0x75eb00dc,0x7bc22b99,0x0000006a,0x0000006a}},	//   vözö, lvou,   ,
  { {0x8893005e,0x88bd002a,0x5d7b004c,0xda4b000a}},	//   _виїх, rośc, ואטק, _חֲדָ
  { {0x244b0029,0x7bc20384,0x6d5801b2,0xd7ef0015}},	//   بجدي_, nvou, ívaj, _وكم_
  { {0x2caf0111,0xf777000a,0x65940b27,0xc2c50058}},	//   zegd_, _יעדי_, _баку, ديسي
  { {0x8cd5000b,0x26ce2b9a,0x4127005e,0x0000006a}},	//   णामो, _info_, вфаб,
  { {0x25d70008,0xa0880b1e,0xd0110015,0x50641b12}},	//   _יוון_, ксуз_, ملأ_, итуа
  { {0xf54a0092,0xd3a40033,0xdddc1d56,0xd045009a}},	// [54d0] _cấu_, _крэп, _perş, اپذي
  { {0xf54a0023,0xc3b8000a,0xe2aa0046,0x9e750067}},	//   _dấu_, _ילחץ_, áčtí_, اهات
  { {0x71d50008,0xdd9b0342,0xa2d0000b,0x645d0034}},	//   _עוֹד_, ьша_, दार्, ocsi
  { {0x50640036,0x27390152,0x645d2b9b,0x106b0058}},	//   _втра, mène_, ncsi, _تحدى_
  { {0xceeb0086,0x6281005c,0x4c8402e1,0xb4fc000a}},	//   _قرآن_, ólow, рлів, ופאי
  { {0x8f9a013a,0xfbd00015,0x3e7c0046,0xfb340033}},	//   _אישי, تتم_, rátí_, анчэ
  { {0xf2d400b2,0xd338000a,0xb9c50015,0xeaf3000b}},	//   יעס_, דרגה_, اقبي, _अतीत_
  { {0xc7b10058,0x0000006a,0x0000006a,0x0000006a}},	//   مّع_,   ,   ,
  { {0xf54a2b9c,0x96750010,0xf77100e6,0x6e3a001a}},	//   _mất_, лыні, حاب_, _útbr
  { {0x6d55003f,0x752f002a,0xc98713d0,0x8b35009a}},	//   _kuza, elcz, _ауди, _صفاش
  { {0x46490010,0x66052b9d,0xb89500c3,0x7546009b}},	//   эзон_, упна, _ملاع, лноз
  { {0x9a990024,0xedb6000a,0xa879004c,0x645d0030}},	//   žādā, נִית_, _װאַר, gcsi
  { {0x6cfa0008,0xa87a000a,0xf7940033,0xe6c500c3}},	//   תפרס, _נאסר, _вачэ, _متغي
  { {0xc7b20008,0x43750036,0x201c0064,0x7ae100f2}},	//   _לבד_, шуют, şvik_, _jolt
  { {0xf54a1881,0x273911a7,0x7ae12b9e,0xd179005e}},	//   _bất_, gène_, _molt, ксті_
  { {0xb4db0251,0xf54a0092,0xe6100086,0x61e10b24}},	//   rmàc, _cất_, _بشه_, älla
  { {0x17560053,0x251b000a,0x30752b9f,0x80260040}},	// [54e0] ָסער_, _רופא, русс, ارزم
  { {0x4df6005f,0x1c17000b,0xe164002b,0x7ae101e0}},	//   ляет, _दख़ल_, _نگري, _nolt
  { {0x329b000a,0x27390003,0xd2b7000a,0xdbd60012}},	//   _אביד, cène_, _גלית_, fäße
  { {0x2d8702c1,0x7bc20079,0x0c76002b,0xf54a0016}},	//   ánea_, tvou, اداد, _tấu_
  { {0xc8790064,0x7f750033,0x69c3063b,0x0ffa0015}},	//   daş_, _вусц, evne, _أعجب_
  { {0x7ae12ba0,0x93b7000a,0x7bc200ed,0xd357004f}},	//   _colt, טלנו_, rvou, איסי_
  { {0xea950010,0xee3702c5,0x3db8000a,0x9e77000a}},	//   ршчэ, _бнр_, _בֶּא, _תגלה_
  { {0x8c460254,0x7ae10125,0xbb76002b,0x237f0046}},	//   _бебе, _eolt, _مهرع, šuji_
  { {0x3f920064,0xb6f4009c,0x69c32ba1,0x7ae12ba2}},	//   nuyu_, изиј, avne, _folt
  { {0x6d860008,0xaa570015,0x62880030,0xdb0e008c}},	//   ְתָּ_, _ملكا_, ódol, ökäy
  { {0xd8840086,0x645a0089,0xc96600ce,0x163402da}},	//   _نهای, ětin, _свей, реня
  { {0x69c80548,0xf8b8000b,0xc8790045,0x27390003}},	//   _irde, _आसिय, caş_, vène_
  { {0xf54a0023,0x2bc7005d,0xfbc7000b,0x987b004c}},	//   _rất_, लिया, लियम, _טראק
  { {0x88bd005c,0xf7830015,0x3f920061,0xb35403ae}},	//   nośn, _الوَ, duyu_, скрш
  { {0x68e20c8d,0xd13b2246,0x09f4000a,0xa1590db7}},	//   _kood, еха_, בֶּר_, табу_
  { {0x2a3b000a,0x27390003,0x68e22ba3,0x657c1ad6}},	//   תעלמ, rène_, _jood, árhu
  { {0x68e22ba4,0x7f95006b,0x50640033,0xf54a0016}},	// [54f0] _mood, разх, стса, _vất_
  { {0x200d0084,0x68e20005,0x3f87010b,0x69c3002c}},	//   _þeim_, _lood, čnu_, yvne
  { {0xf54a0023,0x0dc80001,0xdc550004,0x69de008c}},	//   _tất_, луци_, авењ, äpel
  { {0x68e21126,0xcd2b006e,0xf54a0016,0xc537000a}},	//   _nood, رسان_, _uất_, נָ֑ה_
  { {0x6d5a0152,0x3f790053,0xc8790064,0x307a000a}},	//   _étan, _באָס, vaş_, _בארנ
  { {0xdefb008f,0x63ad000c,0x2bc7005d,0x8d770087}},	//   _чым_, _mpan, लिबा, _مارا
  { {0x68e20f75,0xdb000134,0x19b90010,0x6d55003f}},	//   _bood, _opmæ, туль_, _uuza
  { {0x63ad2ba5,0x69c310cd,0x778500c9,0x7ae12ba6}},	//   _opan, rvne, ализ, _wolt
  { {0xccf2013a,0xa8c80029,0x212b006f,0x68e22ba7}},	//   _וכן_, طبيق_, _mkch_, _dood
  { {0xe7390001,0xa3b0005d,0x7d0b2ba8,0x628502de}},	//   ђен_, _टैग_, ligs, _ndho
  { {0xa2d9014e,0x68e219a8,0x27300016,0xceb2000a}},	//   मान्, _food, iành_, חיי_
  { {0x27300092,0x7bc92ba9,0x68e20116,0x7d0b15f6}},	//   hành_, _kreu, _good, nigs
  { {0x61e101d1,0x543601b0,0x386d2baa,0x64990033}},	//   älln, рхну, mber_, ытэр_
  { {0xf7700074,0x877a0053,0x44f60086,0x386d0ecc}},	//   _راه_, _סאצי, اسگز, lber_
  { {0x11d505d1,0xc692000a,0x65920054,0x386d007c}},	//   бітр, _ואו_, _дају, ober_
  { {0x3f920064,0x3d1f005d,0x659a000a,0x53ca0004}},	//   tuyu_, यकों_, _סיפק, _агим_
  { {0x8f760036,0xaf06277d,0x386d2bab,0x63a90061}},	// [5500] рубі, апал, iber_, çent
  { {0x543b0053,0x3f920064,0xc43b000a,0xe37b000a}},	//   _בעפא, ruyu_, _בתפי, _שריר
  { {0x610c0064,0xdcff0089,0x1ea90029,0x7d0b00b8}},	//   aşla, _úvěr, طالي_, figs
  { {0x7b660010,0x0b8a0b97,0x2377002b,0x5ca60850}},	//   атке, вски_, _حمید_, ридб
  { {0x9409000a,0x33c9000a,0x7bc92bac,0x68e22bad}},	//   ְּנֵ, ָהוּ_, _creu, _rood
  { {0x68e20020,0xee3a0010,0x2ba7005d,0xe9860001}},	//   _sood, _анг_, _गहरा, аћин
  { {0xf2890053,0xc27b000a,0x88bd002a,0x68e22bae}},	//   אָפֿ, דרצי, rośn, _pood
  { {0x7bc92baf,0xa7741b04,0x6df30015,0x98c6027a}},	//   _freu, блич, _بكفا, рскл
  { {0x6fc9000b,0x3f800144,0x68e22bb0,0x994700c3}},	//   रियं, nsiu_, _vood, جليل_
  { {0x68e22bb1,0x1a78000a,0x56f40004,0x69c800bc}},	//   _wood, _תְּמ, споѓ, _trde
  { {0x68e20005,0x8afb0008,0xd5b72bb2,0xd6d70139}},	//   _tood, _שהבי, ася_, рты_
  { {0x2ca60176,0x6fc9005d,0x186a1f39,0x394f0335}},	//   nfod_, रिमं, _ради_, _gigs_
  { {0xda78002c,0x79150053,0x938b006b,0x07a30033}},	//   _keď_, _פֿעב_, ъсна_, _мацн
  { {0x61e100c0,0x4733005e,0xb7fb004f,0x7d0b02ad}},	//   ällo, _дніс, _שִׁט, zigs
  { {0x21270086,0x31c4277d,0xdb110030,0xe0d300c3}},	//   ليسی_, оств, ófét, يزر_
  { {0x90550033,0xa98b000a,0x30680054,0x67280e01}},	//   свац, כָמִ, ијун_, lodj
  { {0x63ad0fd1,0x60390010,0xa2950010,0x2cbf2bb3}},	// [5510] _upan, упаў_, _лапі, _raud_
  { {0x28a6005d,0xf54a0092,0xc7d70008,0x2d8702c1}},	//   क्ति, _hấp_, בומי_, áneo_
  { {0x7d0b285a,0x6d5a0003,0x9f950012,0x2cbf01d7}},	//   tigs, _étal, _füße_, _paud_
  { {0xbc190010,0x28a6000b,0x7c872bb4,0x237f0085}},	//   лілі_, _कॉलि, руже, šuju_
  { {0x3ff90053,0x67282bb5,0xdb090046,0xc052000a}},	//   _עפֿע, kodj, řníc, _מזכ_
  { {0x99850015,0x7bc92bb6,0xf54a0016,0x7d0b0012}},	//   ملتو, _vreu, _lấp_, sigs
  { {0xceb20008,0x752d005c,0xc334000a,0x7db40015}},	//   _מים_, _okaz, חוס_, _وصفا
  { {0x26de002c,0x4c940080,0xac94034e,0xe218000a}},	//   ejto_, _мисс, _масш, יקוח_
  { {0x69de003c,0x7d092bb7,0x3dcf002a,0x386d2bb8}},	//   øper, _imes, łowę_, rber_
  { {0x0f58000a,0x67280085,0x501c000a,0xcff8000a}},	//   ביזם_, godj, כוחו, יצחה_
  { {0xb4db0251,0xc9f40015,0xa5941092,0xa52600ce}},	//   rmàn, _وسمع, орящ, ймод
  { {0xf54a0023,0xc4fa0015,0xca36000a,0xb4db0144}},	//   _cấp_, اعدا_, _הנעה_, smàn
  { {0xa8560008,0x43930033,0x67282bb9,0x38350054}},	//   _הינה_, паўс, bodj, _ундр
  { {0xcc3a0053,0x7d1b2bba,0x62632bbb,0x9f950012}},	//   טערט, _ljus, звра, _süße_
  { {0xf5950029,0x27ed00dc,0x61050091,0x7d091953}},	//   _العج, lyen_, lėly, _omes
  { {0x7a4200dc,0xf54a0092,0x2bb8000b,0x27ed0003}},	//   líté, _gấp_, _इनला, oyen_
  { {0x7c3b003f,0x27ed2bbc,0xfe720015,0x0eaa0033}},	// [5520] _nzur, nyen_, كدا_, лкай_
  { {0x7a420014,0x7e562bbd,0xdfcf0115,0x7d092bbe}},	//   níté, стац, عيل_, _ames
  { {0xe1f20074,0x3f800251,0x27ed008c,0xee3a0054}},	//   _رسد_, ssiu_, hyen_, ћне_
  { {0x3d8b0086,0xa1360086,0x8d85002b,0xf54a0016}},	//   احلی_, _درخش, زشمن, _xấp_
  { {0x2ca60176,0x88bd002a,0x7a420030,0x7d1b2bbf}},	//   rfod_, rośl, kíté, _djus
  { {0xaa570029,0xe39b000a,0xab27005e,0x443201be}},	//   ملها_, רֹאש, боча_, _myy_
  { {0xcaa50029,0x91bb0053,0xa2d9005d,0x2dd8000a}},	//   تصني, ָמפי, मात्, _דַּב
  { {0x4e17000a,0xf98f0015,0x60c42bc0,0xdca31068}},	//   _החלב_, ربى_, ndim, _наси
  { {0xda780089,0x20000011,0xfbb5000b,0xd7e6005e}},	//   _teď_, nzii_, _आईएम, сійо
  { {0x8b26008f,0xf76f00e6,0x7a4200dc,0xc6f704ab}},	//   _удзе, راً_, gíté, йных_
  { {0x9aeb0008,0x7d090026,0x67281414,0xb9c6002b}},	//   _עַמִ, _ymes, rodj, _دقاي
  { {0xce370008,0x7e7e0f43,0x67282bc1,0x68fb2bc2}},	//   מאית_, happ, sodj, chud
  { {0x7e7e0f75,0x27ed003c,0xf54a0016,0x765c006f}},	//   kapp, cyen_, _vấp_, ľryb
  { {0xd7650086,0xf66a0015,0x64560030,0xe7b7000a}},	//   _بنوی, _صحته_, _egyi, _להדר_
  { {0xeab10008,0xf67b000a,0x0737000a,0x61ee0034}},	//   וֹן_, _גאומ, _האגם_, gybl
  { {0xa617000a,0x2d870046,0xf617000a,0x752d0d57}},	//   _לקוד_, ánem_, _לחוש_, _ukaz
  { {0x61330064,0x14d6000b,0x82f8002b,0xb7f1000b}},	// [5530] nçli, धारण, _گريز_, आईएम_
  { {0x9e15008f,0x2d8700bd,0x6d40013c,0x74d1000b}},	//   одзі, šnem_, _ahma, धाकृ
  { {0xd6570008,0xa2c6000b,0x68fb0034,0xa49b0144}},	//   ציאת_, ायर्, yhud, biòt
  { {0x7a4200dc,0x859b000a,0x8d740015,0xc058005e}},	//   zíté, רשאו, ساما, _гір_
  { {0x7d0900bd,0xde590033,0x44202bc3,0x27ed0723}},	//   _vmes, _вагі_, _xxi_, xyen_
  { {0x09b900a2,0x28a6000b,0xa8a70061,0xc8a6000b}},	//   لطبع_, क्सि, şmüş_, क्सट
  { {0x6d58032c,0x314b0008,0x7a4200dc,0xf7710086}},	//   ívat, ְתִּ, víté, ژاد_
  { {0xcb69002b,0x7d092bc4,0x6ab4000b,0xd9400033}},	//   _نمره_, _umes, ूयॉर, нцыi_
  { {0x69ce002e,0x7a4200dc,0x61ee005c,0xe8f6017f}},	//   _áben, títé, zybl, іль_
  { {0xd7050036,0xd7090080,0x3dc6005c,0x05a90139}},	//   ізни, рное_, łowe_, авой_
  { {0x7a420014,0x27ed00d9,0x443200f2,0x0a150015}},	//   ríté, syen_, _syy_, _بواح
  { {0x7a420014,0x03a60080,0x89370002,0xa3b80065}},	//   síté, оимо, _اعطا, ज़िल_
  { {0xdd0c0050,0x7ccd0048,0x7a4200dc,0x4375005e}},	//   _późn, mērķ, píté, зуст
  { {0x36690124,0xddd50046,0x0000006a,0x0000006a}},	//   _тако_, _nezů,   ,
  { {0x2d87002c,0x76ba000a,0x9989000a,0x8989000a}},	//   šnej_, _כמספ, יָּ֤, יָּ֔
  { {0x60c400df,0x463a0053,0x61ee028a,0x7e7e02ad}},	//   udim, _דעצע, rybl, wapp
  { {0xf8b2000a,0x7e7e1263,0x2ee60033,0x60c42bc5}},	// [5540] ושן_, tapp, ожаг, rdim
  { {0x23b30086,0x20002bc6,0xa3e7000b,0x1719000a}},	//   _کمیس, rzii_, पहर_, ׁוּע
  { {0xbc6a00e5,0x4d6602e1,0xad650015,0x6da3005e}},	//   لمان_, цкев, كانه, диха
  { {0x2bca000d,0x7e7e04a0,0x629c1717,0x9b6a15be}},	//   илеп_, sapp, lgro, ашка_
  { {0x8bb60115,0x8b26011d,0xfbd2012c,0xac070174}},	//   تصاص, одде, بتا_, онца_
  { {0x2fcf0134,0x3e6b002b,0x298a0054,0x99660fe4}},	//   ægge_, _نجفی_, асио_, отил
  { {0x14ca000b,0xc4ca000b,0xcb07012c,0x32db004f}},	//   ियाण, ियाओ, تيون_, יחסנ
  { {0x6d5c01d7,0x272a0046,0x629c233f,0x99470015}},	//   _iura, zóně_, hgro, يلول_
  { {0x28a6005d,0x8b650029,0xfa540086,0xc7b00015}},	//   क्षि, _فالم, _فراگ, رّد_
  { {0x6d5c2bc7,0x629c0535,0xdb24005b,0x61e102dc}},	//   _kura, jgro, ösäh, ällk
  { {0xe5350010,0xa01b00b8,0x248901d7,0x629c2bc8}},	//   зень, _geöf, _pdam_, dgro
  { {0x5507008f,0x629c0991,0x7e7c0026,0x6d5c2bc9}},	//   ічна, egro, _lerp, _mura
  { {0x38cb0086,0x38660034,0x6d5c2bca,0xe8230214}},	//   _خالی_, _ifor_, _lura, _офшо
  { {0x28a6014e,0x2d870089,0x54540010,0x04440033}},	//   क्रि, ánek_, ьвят, ьеўн
  { {0x7ae800fb,0x53341032,0xe729002b,0xd5a5002b}},	//   _modt, ферт, _اسنو_, _فلوی
  { {0x629c002a,0x23a40123,0xc5f8003d,0xd0d4006b}},	//   agro, böj_, ncēm_, мосъ
  { {0x7e7c0d25,0x6d5c2bcb,0xf8bd000b,0x629c055e}},	// [5550] _berp, _aura, ्यतय, bgro
  { {0xde970029,0x539a0008,0x6d5c2bcc,0x7e7c0273}},	//   تجرب, _פיתו, _bura, _cerp
  { {0xcddb0001,0x7bc00007,0xb2ba000a,0x8c590015}},	//   шња_, _asmu, _המתר, ملاء_
  { {0xd7bc005d,0x628800bf,0x6d5c2bcd,0x7afa2bce}},	//   ्टाच, ódov, _dura, _altt
  { {0x60da0008,0x3af50139,0xd0f6000a,0x50da000a}},	//   _הקרנ, зяйс, _זמרת_, _הקרא
  { {0x9b680010,0x6d5c2bcf,0x9aa50015,0x13bc004f}},	//   ішча_, _fura, سمبو, שֶׁמ
  { {0x02fc0008,0x254d005c,0x99850015,0x6d5c2bd0}},	//   שלומ, _eśli_, ألبو, _gura
  { {0x28bd005d,0x721c0008,0x99d4002b,0x28a6000b}},	//   ्यधि, יווח, بتها, क्लि
  { {0x7f5d038d,0xfbbf000b,0xa088000a,0x2d9e0123}},	//   _jusq, _एनिम, חְתִ, _äter_
  { {0x7ae802df,0x6d5c2bd1,0x387f2bd2,0xdb58006b}},	//   _godt, _yura, saur_, _фют_
  { {0x99d40015,0xe8550015,0x9732002b,0x2bbf000b}},	//   _يتما, _فناد, رکها, _शैता
  { {0x26c300bd,0x9a3a000a,0x69c12bd3,0x2ec8000b}},	//   žjo_, _התעק, _isle, _रफ्त
  { {0x08760053,0x98e40029,0x185a000a,0x07d80015}},	//   _זענט_, _تكنو, _הכנע, _وذهب_
  { {0x254d0089,0x36c40036,0x2914002a,0x853d0091}},	//   _měly_, _обіг, ądał_, ltėl
  { {0x867a0008,0xbbb8005d,0x442c002a,0x91e60aed}},	//   _הרצו, _इन्क, łd_, чове
  { {0x6d5a038d,0x629c0150,0xe45f0030,0x7f5d2602}},	//   _étai, sgro, ldön_, _busq
  { {0x34fb000a,0x6d5c2bd4,0x649b000a,0x7e7c2bd5}},	// [5560] _להקד, _sura, _היפה, _perp
  { {0x9756013a,0xdfcf0029,0xcf250015,0x6d5c2bd6}},	//   פיעו_, ديك_, ورلي, _pura
  { {0xfc66010f,0x256100dc,0x98bd005d,0x6d5c1180}},	//   пълн, _jól_, ्याए, _qura
  { {0xfd95005e,0x6d5c080d,0x7e7c158f,0x4096056d}},	//   ьшую, _vura, _werp, _эрот
  { {0x92e90086,0x7e7c0d25,0x98a40024,0x69c12bd7}},	//   _طریق_, _terp, jomā_, _asle
  { {0xfaa3006b,0x6d5c2bd8,0x0216000a,0x98a4003d}},	//   ешън, _tura, ּחֵם_, domā_
  { {0x2bb8005d,0x88bd002a,0xe2a7001a,0x0136004f}},	//   _इनका, nośw, áðir_, ֔רֶת_
  { {0x60c60089,0xae1b0008,0xa3be000b,0xe9cf0015}},	//   _jakm, _הולכ, ीटा_, اغو_
  { {0x0f56000a,0x7ae80012,0x387d0034,0xd90d002b}},	//   ֔יִם_, _todt, _dewr_, جین_
  { {0xabfb013a,0xa8230086,0x6c330029,0x256106e7}},	//   _ההמר, رکنن, _أفكا, _ból_
  { {0x2fc700a7,0x7c2d0535,0x387d02ad,0x0000006a}},	//   ̉ng_, żart, _fewr_,
  { {0x394a0054,0x89db000a,0x98a603ae,0x3eba0079}},	//   _узео_, _לחבי, _хиде, hept_
  { {0x395e00da,0x53470238,0x0000006a,0x0000006a}},	//   _huts_, зхва,   ,
  { {0x66e3243b,0x28da005d,0x8c1b0008,0x6700000b}},	//   _поча, भावि, מוכי, _ऋतिक_
  { {0xc56a0015,0x7f5d219f,0x60c62bd9,0x3135144a}},	//   _احتل_, _susq, _bakm, девр
  { {0x361b0008,0x6ab9021e,0x8637000a,0xa3e8000b}},	//   _לווד, _इस्र, _מרוב_, _मॅक_
  { {0x853d0007,0x752f002a,0x7e651623,0x75d4009a}},	// [5570] ntėm, mocz, tchp, _ريکا
  { {0xaf33002b,0x62880030,0x93fc000a,0x62750015}},	//   رواژ, ódot, _ללחי, _تهدئ
  { {0x395e2bda,0x2d872bdb,0x4d880015,0x645a0046}},	//   _nuts_, éne_, كَلُ_, ětiv
  { {0xbd180036,0x752f002a,0x8c3d0045,0x7e650028}},	//   пції_, nocz, _obşt, schp
  { {0xfbab034e,0xdd310535,0x6133007f,0x0000006a}},	//   стей_, mężn, uçlu,
  { {0x3dc6005c,0x395e0152,0x3eba2bdc,0x539c000a}},	//   łowa_, _buts_, cept_, מידו
  { {0xa9c4003b,0x2d9a0152,0x395e00da,0x0b42006b}},	//   فزيو, cupe_, _cuts_, ъншн
  { {0x28da014e,0x6ca413f1,0x7a420046,0x25612bdd}},	//   भाषि, _пруж, _sítí, _ról_
  { {0x752f005c,0x29030007,0x2561002a,0x0000006a}},	//   docz, ėja_, _sól_,
  { {0xb0c9005d,0xca480086,0xe619006b,0x25612bde}},	//   ाएँग, _کلمه_, ждо_, _pól_
  { {0x69c1016f,0xf212000b,0x26cb0046,0xa9f50015}},	//   _usle, _डेढ़_, ěco_, _تكاث
  { {0xb4c8000b,0x3eba0012,0x0000006a,0x0000006a}},	//   ईये_, zept_,   ,
  { {0xb9010231,0x46a5009b,0xe72e2bdf,0x0000006a}},	//   दा_, _жалв, _ае_,
  { {0x853d0007,0xe7bc005d,0xdcfe0024,0x25611dc0}},	//   ntėj, ्टरप, ispā, _tól_
  { {0x752f005c,0xb0c9000b,0x950a0015,0x0000006a}},	//   bocz, ाएंग, _وقتك_,
  { {0x316c0024,0x6b8900bc,0xa0220061,0xe0d7005e}},	//   īdz_, _oveg, _çökm, мвс_
  { {0x628800dc,0xaec602e1,0x032619b2,0x3eba0045}},	// [5580] ódos, мбал, _один, tept_
  { {0x24802061,0xd5b1000b,0xe283004a,0x2d9a04b2}},	//   _heim_, _जहाज, _ильи, tupe_
  { {0x80a6014e,0x82fa0086,0x26c72be0,0x32db000a}},	//   _छापे, _هرگز_, _mano_, _וחינ
  { {0xcea90632,0xc173000a,0x2d871194,0x2d9a2be1}},	//   יי_, _שחר_, ânea_, rupe_
  { {0xc0030033,0x1ab401c5,0x1b2a0015,0x3f6a2be2}},	//   _апяк, ебля, يأتي_, _фиго_
  { {0x2aaa005e,0x395e2be3,0xf96a0818,0x26c72be4}},	//   ітло_, _puts_, орий_, _nano_
  { {0x200d0084,0x80a5005d,0x79a60004,0xe9f80033}},	//   _þeir_, ङ्के, фрле, янкі_
  { {0x26c700b6,0x98a30054,0xf8af0015,0x7c930015}},	//   _aano_, виће, لةً_, _للفص
  { {0xea8a006b,0x80a6000b,0xfb690015,0x2b91002b}},	//   _мбал_, _छाने, _فصلى_, _مینس
  { {0x752f005c,0xe9da0015,0x6f7b000a,0xfb1a0015}},	//   wocz, _وذات_, קְחו, _بقطع_
  { {0x2480018b,0x75d40029,0x8e970008,0x151505c4}},	//   _beim_, ريحا, ודיו_, едня
  { {0x68460029,0x2ebb000b,0x7d022be5,0x43952be6}},	//   _قَال, _उस्त, nhos, намс
  { {0xb7d70029,0x27e00064,0x752f005c,0x3c77000a}},	//   _يوما_, _çin_, rocz, ותכם_
  { {0xe60f0086,0xf54a0092,0x2fc02be7,0x752f002a}},	//   اشی_, _mấy_, dwig_, socz
  { {0x5757013a,0xf54a0023,0x752f005c,0x7d02003f}},	//   _קבוע_, _lấy_, pocz, khos
  { {0xd25802e1,0x673a0c4e,0x0000006a,0x0000006a}},	//   ьця_, lltj,   ,
  { {0x74150002,0x545510a0,0x853d0091,0xf54a0016}},	// [5590] _سودا, _явит, ytėj, _nấy_
  { {0xa3be000b,0xf3ff016e,0xddc7002a,0x7d022be8}},	//   ीटर_, lcão_, _tejż, ehos
  { {0x6b892be9,0x4ea4006b,0xe2a7001a,0xc7c80016}},	//   _sveg, ърта, áður_, _lố_
  { {0xdd98005e,0xbd45002b,0x2615004c,0xf54a0016}},	//   ьшу_, رنشي, ײַעם_, _bấy_
  { {0xf54a0016,0xe7030016,0xe53c004f,0x4fc402ed}},	//   _cấy_, hướ, קתדר, _исра
  { {0xb33b0061,0xf1a3000b,0x539c05bd,0x99a90015}},	//   ftçi, _ओमान, קסוא, كُتْ_
  { {0xfe540010,0xc27c000a,0xa96601b7,0x853d0091}},	//   _акрэ, חרוי, нища_, rtėj
  { {0xc7c80023,0x853d0007,0x6b892bea,0xdd03003d}},	//   _bố_, stėj, _tveg, ērēj
  { {0xc7c80023,0x78bb2beb,0x69de008c,0x24800012}},	//   _cố_, reuv, äper, _reim_
  { {0xeab00029,0xd706004a,0x9a470015,0x7945002a}},	//   _نعم_, енье_, _قضاه, dówe
  { {0x6d5a038d,0x64a60010,0x3ea1069b,0xceb200a3}},	//   _état, нана, ight_, ניט_
  { {0xed590089,0xc976000a,0x64ca0065,0x673a0546}},	//   _již_, _נגני_, ियेश, altj
  { {0xdd0c0050,0x26c7003f,0x394d2bec,0xb9080033}},	//   _różn, _tano_, mmes_, _ўніз_
  { {0xa6c9002b,0x394d2bed,0x0ece0065,0xed59005a}},	//   _روبل_, lmes_, _होंड, _liž_
  { {0x394d2bee,0x28a6000b,0xb23a0015,0x3f890034}},	//   omes_, क्कि, سكرا_, esau_
  { {0x7d0200dd,0xf1c0006f,0x656e0125,0xed590046}},	//   xhos, ššou_, íbhe, _niž_
  { {0x291f00f2,0x1e960142,0xc95200a3,0x4e96002b}},	// [55a0] inua_, ерер, רמן_, فشار
  { {0x3377000a,0x2fc02bef,0x394d2bf0,0x0000006a}},	//   _רעים_, rwig_, hmes_,
  { {0x61e100c0,0x394d121a,0xe0da0004,0x76f6004c}},	//   ällt, kmes_, _евн_, עמענ_
  { {0xa6de0023,0x91360036,0x3dc6002a,0xfd660016}},	//   _nhưn, _їхні, łowo_, _khuấ
  { {0x28c3005d,0x212001a3,0x98a40091,0x39460034}},	//   वजनि, mnih_, nomą_, _rhos_
  { {0xada60010,0x2120065d,0xda660031,0x539b000a}},	//   _пагл, lnih_, راتي, פיצו
  { {0xc7c800a7,0x7d02002f,0x533700b2,0x7945005c}},	//   _số_, phos, ענצן_, zówe
  { {0x98a40007,0x99d3002b,0xe80c000b,0x394d0f24}},	//   komą_, اتوا, िछला_, gmes_
  { {0xd6d00029,0xf76f0086,0x7d000020,0x8b260010}},	//   لقة_, یای_, _ilms, _здае
  { {0x98a40007,0xcb0a0021,0x76060030,0x394d2ad6}},	//   domą_, _عيان_, _nézé, ames_
  { {0xceb30008,0x2499002b,0xda6500c3,0x2120013b}},	//   אית_, وندد_, _شالي, knih_
  { {0xc7c80092,0xdcfe0007,0x24190010,0x3f890026}},	//   _tố_, rupė, домы_, ysau_
  { {0xb8f4014e,0x2120065d,0xf7f30015,0x99090015}},	//   िए_, dnih_, _مسود, _تغلق_
  { {0xb7db0008,0xb4db0251,0xe7db000a,0x14180015}},	//   _מקדי, emàt, _מקדש, ريّة_
  { {0xbb3b00b2,0x7228005e,0xcad7000a,0x50670015}},	//   פעלי, ецтв_, עולת_, ّائِ
  { {0xe63b0008,0xa63b0008,0x763b000a,0x89db000a}},	//   _מתוכ, _מגור, _מעוג, החלי
  { {0x10170086,0x8cb6000b,0x69170045,0x90551886}},	// [55b0] ربرد, ोजनो, nţea, твац
  { {0x3ea10041,0x26cc0026,0x2d87001c,0x61e100c0}},	//   ught_, nddo_, âneo_, älls
  { {0x212002c6,0x6f24005e,0xfc3f0247,0x26cc0034}},	//   bnih_, уєте, _ší_, iddo_
  { {0x5ce42bf1,0x6ce400fd,0x8c19002b,0x212006c0}},	//   люча, ліче, ويار_, cnih_
  { {0x60cd16d6,0xbbe80015,0x28d1000b,0xfaa52bf2}},	//   mdam, فروم_, _दोषि, вало
  { {0x60cd0005,0xe3b40053,0x2bb80015,0x8c420054}},	//   ldam, רױס_, عانة_, јеше
  { {0x60cd0007,0x12fc000a,0x9d19005e,0x69170045}},	//   odam, ההגב, _жовт_, eţea
  { {0x60cd0100,0xde58005e,0x5fc6000b,0x753d0030}},	//   ndam, _часі_, _रैडल, jlsz
  { {0x62871798,0x394d2bf3,0xf7710115,0x60cd2bf4}},	//   kajo, rmes_, جاب_, idam
  { {0x753d00dc,0x628700bd,0xf7450001,0x212002c6}},	//   elsz, jajo, ђено, znih_
  { {0x60cd00df,0xb4cd000b,0x62871ea3,0x44292bf5}},	//   kdam, रयू_, dajo, _axa_
  { {0xc32900a3,0xb815049d,0x98a40091,0x98c40045}},	//   _וו_, _идеј, tomą_, ătăm_
  { {0x2120065d,0x6d49002d,0x6608005c,0x68e90085}},	//   vnih_, _mhea, azdk, mjed
  { {0xe6110086,0x68e92bf6,0x753d002a,0x83c30054}},	//   _پشت_, ljed, alsz, јбрж
  { {0x21200198,0xe716000a,0xddc50046,0x715a0033}},	//   tnih_, _בחסר_, dchů, драс_
  { {0xf55a0015,0x2f040012,0xf992000a,0xb4db0144}},	//   _تلعب_, _möge_, ירל_, umàt
  { {0x628702c1,0xb4db0251,0xd12f0015,0xfe720021}},	// [55c0] bajo, rmàt, زمك_, لدا_
  { {0x139b0008,0x21200a00,0x6d490a99,0x68fb007c}},	//   _קביע, snih_, _ahea, hkud
  { {0x6d49002f,0x6563001c,0xac86000d,0x68fb0020}},	//   _bhea, _junh, вгел, kkud
  { {0xdb1f0152,0x26ee005d,0x69c30026,0x61e100c0}},	//   _évêq, _चक्र_, dwne, ålle
  { {0x26cc0176,0x6d49002d,0xc4d30053,0xcb670001}},	//   yddo_, _dhea, יגא_, ваче_
  { {0xbb570010,0x68e90d46,0xfe461c4d,0x7bc20546}},	//   ваіх_, ejed, _анго, rwou
  { {0x6d49002f,0xe5670225,0xcec30089,0x8d562044}},	//   _fhea, _خط_, ářů_, _атач
  { {0x6d491227,0x6287002a,0x2004001a,0x7c650015}},	//   _ghea, zajo, _ýmis_, _ماكل
  { {0xaae2005d,0x87060063,0x6a860054,0x5838004a}},	//   पादक, вяне, _алза, эзия_
  { {0x68e906e6,0x60cd182f,0x691700d4,0x0000006a}},	//   ajed, zdam, rţea,
  { {0xdb1b2bf7,0x68e9016f,0xfe9b0008,0x60cd2bf8}},	//   _usuá, bjed, ויימ, ydam
  { {0xdddc010b,0x26ca00bd,0x6a150015,0x320a006f}},	//   _održ, žbo_, _إبْر, dzby_
  { {0x88bd005c,0x62872bf9,0xfbd4000a,0x60cd007c}},	//   pośr, tajo, אתָ_, vdam
  { {0xd5b00086,0x75d400c3,0x77f7004f,0x0000006a}},	//   _هفت_, _ميتا, _במדד_,
  { {0x30a7017f,0xbbbf000b,0x3633002b,0x62872bfa}},	//   крав, _एन्क, _پروس, rajo
  { {0x62872bfb,0x2492002a,0xdbca007c,0x7d03003d}},	//   sajo, _gdym_, _hõõr, īnsk
  { {0x14190015,0x40840033,0x62872bfc,0x6ffa003d}},	// [55d0] _سيدة_, русб, pajo, _nācā
  { {0xdf390029,0x60cd14b6,0x6d490541,0x69c3002a}},	//   ركات_, sdam, _shea, ywne
  { {0x6d49002f,0x320a005c,0x24920026,0x5c75006b}},	//   _phea, czby_, _ydym_, глет
  { {0xdd94008f,0xada40036,0x5f770015,0xbc69002b}},	//   рацы, раїл, _لاسر, رمتن_
  { {0xeab90063,0x68e9016f,0x109a000a,0x5bc40015}},	//   ейл_, vjed, _אברב, لتوف
  { {0x93fc01ac,0x6d492bfd,0x5d650015,0x62852bfe}},	//   ולדי, _whea, _مُسْ, _jeho
  { {0x443e0023,0x3c930086,0x19b50029,0x6d490541}},	//   ́t_, _نیاز, احتج, _thea
  { {0x6d5a0152,0x08c50731,0x28da000b,0x62852bff}},	//   _étap, убин, भागि, _leho
  { {0x69c808e0,0x68e900dc,0xa81900e6,0x68fb048c}},	//   _esde, rjed, عتبر_, rkud
  { {0x68e9016f,0x98b80024,0xf1c001c9,0x6563016e}},	//   sjed, ērā_, ášku_, _punh
  { {0x5ee8000a,0x4975112c,0x0000006a,0x0000006a}},	//   דַרְ, _слес,   ,
  { {0x5a0c00b2,0xf2c9103d,0x98f40010,0x97c50115}},	//   _קלאַ, _מע_, _вяшч, _مقصو
  { {0x9cd60008,0x7d1a000a,0x62850592,0xb8f7000b}},	//   אורה_, תֵיה, _beho, ाय_
  { {0x179a000a,0xd295005e,0xa836000a,0xc5f5012c}},	//   _ניצב, ирсь, _גרנד_, _مثبت
  { {0x02190191,0x2c1a005d,0x62852c00,0xcb120447}},	//   віть_, _मेनू_, _deho, מלך_
  { {0x386d0838,0x2600000b,0x361a004f,0xb09900ce}},	//   ncer_, शनरी_, _רוקד, ктує_
  { {0x386d2c01,0x61430076,0xbf6600c3,0xafe3023b}},	// [55e0] icer_, сета, ادرو, ботл
  { {0x6fb30015,0x6d430003,0x28da000b,0x8236006e}},	//   إملا, înan, _मोनि, _مرجا
  { {0xdd8f0015,0x1d1a004a,0xad6500c3,0x5cf600ce}},	//   كول_, нюдь_, لانه, ляду
  { {0x163600b2,0x0000006a,0x0000006a,0x0000006a}},	//   אנער_,   ,   ,
  { {0x3b960001,0x925a0086,0x75370053,0xdddc0107}},	//   ујет, _تشکر_, נאנד_, _udrž
  { {0xb6a30016,0xbb830015,0x6e3c0034,0xe453004f}},	//   _quầ, حلوي, _tyrb, צֶף_
  { {0x79810034,0x7bc90045,0x5f031368,0x0000006a}},	//   _cwlw, _eseu, _узра,
  { {0x7d19002a,0x853d0091,0xdbca007c,0x6b440144}},	//   ciws, ntėt, _sõõr, cògn
  { {0x1d07005f,0xb6a30092,0x99850007,0x99470029}},	//   _сети_, _tuầ, _bylų_, دليل_
  { {0xf7b70015,0xb6c6006b,0x386d04a5,0xcb480054}},	//   اديش_, усий, acer_, _кoсo
  { {0xdbca0020,0x7e9b004c,0x8f37004c,0xc985002b}},	//   _võõr, עסטו, רטיג_, _نشني
  { {0x691704f9,0x7945002a,0xe535004a,0x386d0fda}},	//   nţel, lówn, ремь, ccer_
  { {0x628500bd,0xf7f6002b,0x3eb8036d,0x8afc0535}},	//   _peho, _حساد, _obrt_, _cięg
  { {0x853d0091,0xf53f220e,0x0000006a,0x0000006a}},	//   etėt, slå_,   ,
  { {0x85040086,0x41e401f3,0xd5a2002b,0x8717004f}},	//   _گوين, біта, _العی, _תקוע_
  { {0xd904002b,0x2eff0003,0x212d14a7,0xa2d9000b}},	//   سی_, _œuf_, čeho_, माङ्
  { {0x6285022d,0x3f150010,0x351c0008,0xa295017f}},	// [55f0] _teho, адас, _רוחנ, _капі
  { {0x69170045,0xde950054,0x6e950004,0x7d19002a}},	//   eţel, ражњ, рижу, wiws
  { {0x8afc0050,0xfe700015,0x7e470033,0xd251002b}},	//   _międ, سدل_, ухае, _گنگ_
  { {0x7db40029,0x3079004c,0x31c40033,0x7bc92c02}},	//   إصلا, _שאָנ, _усьв, _pseu
  { {0xcaa50015,0x69de00cb,0x4c8400e2,0xd251009a}},	//   لصغي, åpen, слів, _دنگ_
  { {0x8f9a0008,0xff040010,0x501a000a,0x60cf0061}},	//   _בישי, _лясн, _יורו, _hacm
  { {0x53380053,0x3b06006b,0x2fd90012,0x1a29006b}},	//   אנגן_, рещо_, _hrsg_, ъжки_
  { {0x60c8000a,0x97c50015,0x386d2b92,0xed58009a}},	//   ָּהּ_, لقبو, ucer_, _مشقت_
  { {0xdddc0011,0x28da005d,0x39430024,0x2f0400c0}},	//   _terţ, भाजि, ējs_, _höga_
  { {0xf1c0002c,0x386d064d,0xc9871b07,0x46f50238}},	//   ššiu_, scer_, _буди, рчит
  { {0x8afc005c,0xa50a23e4,0xd6292c03,0xa5260e4d}},	//   _sięg, вена_, тоне_, имод
  { {0x7dd000dc,0x69dc047e,0x64a60033,0xfe36000a}},	//   lósá, _área, шама, ירתי_
  { {0x888c0053,0x69ce001a,0xa6c90296,0x26150157}},	//   _טראַ, _áber, _алла_, _फेरी_
  { {0x3dc6005c,0xcc56000a,0x95c50015,0x8bd6004f}},	//   łowi_, יברי_, _نيته, בושו_
  { {0x2ca60034,0xcb12004f,0xa187009b,0x35a504c5}},	//   ygod_, קלל_, ибра_, _тайг
  { {0x61e100c0,0xd1320015,0x4223005e,0x602627ee}},	//   ålla, آمر_, ідтв, адба
  { {0x8e860731,0x8fa625e0,0xde760015,0xe53b0447}},	// [5600] игае, разе, لداع, _שתפר
  { {0xbe85003b,0xd0590036,0x93130015,0xdd920021}},	//   مجمو, урсі_, _وويش, قوط_
  { {0x729b0008,0xe29b0008,0xd29b0008,0xbc660210}},	//   _בסיס, _בשיר, _בשיט, авек
  { {0x7e550937,0x8fa62c04,0x0000006a,0x0000006a}},	//   стуц, _каме,   ,
  { {0x69170011,0x8f7501f3,0x5c970033,0x2ca60547}},	//   rţel, _гусі, ркія_, rgod_
  { {0x5b130036,0x99d60029,0xa9c60029,0x2ca60026}},	//   оміт, لتعا, لزبو, sgod_
  { {0x79450050,0xb9e6005e,0x2eb50033,0xdddc00bc}},	//   równ, ріли, _усяс, _ferš
  { {0x893300c3,0xdca31ad3,0x60c42c05,0x0000006a}},	//   يعيا, _маси, neim,
  { {0x082a006b,0x4c9b000a,0x28bd000b,0xcb6a0033}},	//   ъцки_, _שבמו, ्यजि, _разе_
  { {0x60c42c06,0x4b7b0643,0xc6f7004a,0xe6660004}},	//   heim, _סאבו, иных_, штио
  { {0x3ed900b2,0x5ed90053,0x60c41f26,0x6d422a4a}},	//   אַרא, אַרװ, keim, oloa
  { {0x25090086,0x79fb0008,0xa98b000a,0x9f4f0030}},	//   اردی_, _שלאח, _יָדִ, ágú_
  { {0xc8650086,0xb90a000b,0xb4470033,0x60c42c07}},	//   _اطمي, मा_, рэнк, deim
  { {0x81c30048,0x65660001,0x57fb000a,0xc4540015}},	//   ņēmu, _књиж, _בלדו, زَّب
  { {0xf1940063,0x3168000d,0xf5940015,0x28bd000b}},	//   жись, ишто_, _البج, ्यचि
  { {0x463b0053,0x6d420045,0x365b000a,0x865b000a}},	//   _שעהע, jloa, _בכונ, _בדוי
  { {0xb33b0064,0x6e67054c,0x7eb90033,0x7c2d002a}},	// [5610] erçe, атеж, лгас_, żarz
  { {0xc43c0008,0xa857000f,0xa6f8000a,0xd6f8000a}},	//   _בתחי, שימה_, נִּי, נִּש
  { {0xdc75008f,0xdddc1f07,0x22640046,0xb33b196b}},	//   быль, _perš, ňské_, luço
  { {0xd657000a,0xcdd80054,0x98a40046,0x657a0125}},	//   ביבת_, шњу_, romě_, ipth
  { {0xee87005f,0x7dd000dc,0xb47a004c,0x69da2c08}},	//   _выбо, tósá, אָצי, _arte
  { {0x0056013a,0x4af90074,0x68e20026,0x8d770018}},	//   _לשרת_, دکرد_, _anod, _نارا
  { {0x6ef302d5,0xdd940010,0x853d0007,0x6d420011}},	//   _výbě, _мары, orėd, bloa
  { {0xa7d50015,0x24890045,0x77850f5c,0xad19004f}},	//   متخص, _neam_, близ, _עוּר
  { {0x69da2c09,0xe739008a,0x2bc800ce,0x2cad01f9}},	//   _erte, леи_, _вухо_, _iced_
  { {0xd706004a,0x8f9a000a,0x06e9005e,0x68e200bc}},	//   йные_, ניתי, умок_, _enod
  { {0x2489003e,0x19ab0054,0x0000006a,0x0000006a}},	//   _beam_, _штап_,   ,
  { {0xb8d40015,0x7bdb0bb5,0xb9550a32,0xd9980058}},	//   _وتنش, _kruu, _увещ, _ضخما_
  { {0xb4c8005d,0x61e100c0,0x387f013c,0xd5ae002b}},	//   _उसी_, ålln, mbur_, وفی_
  { {0xa856000a,0x78a92c0a,0x387f00da,0x8afc0535}},	//   _פיסה_, lgev, lbur_, _zięb
  { {0xa22a006b,0x6d420a46,0x60c406cd,0x26c52c0b}},	//   ужва_, yloa, teim, melo_
  { {0x55f60008,0xf0662c0c,0x78a913c8,0x26c52c0d}},	//   _למצב_, скап, ngev, lelo_
  { {0x93960018,0x404a0054,0xd3360033,0x60c42c0e}},	// [5620] _اجبا, упао_, _гэны, reim
  { {0xb33b01e2,0xd6d2000a,0xb4db0144,0x2fa50015}},	//   nuçl, ּׂא_, nlàn, تصفّ
  { {0xc1060015,0x22f7000a,0x82f7000a,0x628e0c78}},	//   _هودي, _הזין_, _הציב_, mabo
  { {0x2f04002e,0x78a90111,0x7c8307be,0x6d421b09}},	//   _gögn_, jgev, пуше, uloa
  { {0x6bd30015,0x26c500aa,0x7f4a006e,0xab94005e}},	//   كتور, kelo_, _ملحق_, цилі
  { {0x628e0026,0x6d420020,0x26c5044c,0x78a92c0f}},	//   nabo, sloa, jelo_, egev
  { {0xcd78000a,0x4d78000a,0x26c52c10,0xc27b0643}},	//   _כְּכ, _כָּא, delo_, ארצי
  { {0x3ec50007,0xab660210,0xb9240015,0x69da2c11}},	//   įstų_, _гвал, تفعي, _vrte
  { {0x7d020134,0xbb75006b,0x63a601c2,0x8afc002a}},	//   mkos, _духъ, jukn, _cięc
  { {0x7d020084,0x45b8005e,0x63a6013c,0x4b260015}},	//   lkos, агою_, dukn, _اعرف
  { {0xd6d7044e,0x69da2c12,0xea77000a,0x7f3b000a}},	//   сты_, _urte, _הגבר_, רעיו
  { {0x07a607be,0xa3b5005e,0x387f0061,0xe0df0016}},	//   _гадн, обмі, cbur_, _thòi_
  { {0x14aa005d,0xe8d7000a,0x29d80016,0x63a60030}},	//   _कारण, _לואר_, _hĩa_, gukn
  { {0x26c52c13,0x54540088,0x2509002b,0x52850015}},	//   celo_, явят, ارگی_, تلسك
  { {0x171b0053,0x25a50251,0x8afb0008,0x41e4017f}},	//   _גוגע, cull_, נהלי, піта
  { {0x673a0251,0x9477002b,0xa2d9000b,0xd577000a}},	//   lotj, _ادغا, _फोर्, _פתחה_
  { {0x2fc90035,0x752d00d9,0x673a007c,0x67280030}},	// [5630] uwag_, _ijaz, ootj, ondj
  { {0x5678000a,0x9327002b,0x7d0216f3,0x2fc900aa}},	//   שְּׂ, _دربن, ekos, rwag_
  { {0x41b50029,0xd2b6000a,0xbe640015,0x8d740015}},	//   _بمجر, _ולתת_, أهمي, كانا
  { {0x30a70080,0x7bdb0020,0xa63b0053,0x8bd90004}},	//   _уров, _pruu, נגאר, имес_
  { {0x673a0030,0xa4b8000a,0x5b35002b,0xdf390058}},	//   kotj, מלאה_, يعتر, _نكحت_
  { {0x38660176,0x49990f13,0x7d022108,0x2a9b0015}},	//   _agor_, атия_, akos, ائشة_
  { {0x78a90384,0x19860063,0x26c5044c,0xf298000a}},	//   tgev, общи_, velo_, זכור_
  { {0xb4c8005d,0x8afc005c,0x628e1773,0x48e0000b}},	//   _उसे_, _pięc, zabo, कागो_
  { {0x78a90298,0x656a00b8,0xab740015,0x38ca002b}},	//   rgev, _aufh, _فالإ, شايی_
  { {0x78a90159,0x1bb80015,0x26c50077,0xa3bf000b}},	//   sgev, _دافع_, uelo_, ीबन_
  { {0x8afc0050,0x24ea0785,0x78a90079,0x7d092c14}},	//   _więc, амни_, pgev, _kles
  { {0x67280020,0xfbc7012c,0xf9900015,0x21292c15}},	//   andj, وت_, _أبل_, jnah_
  { {0x26c50844,0xb33b0061,0xb38300e2,0xa34a15d5}},	//   pelo_, puçl, млял, изма_
  { {0xa856000a,0x7d022c16,0x7d091fc3,0x7bda000a}},	//   _וינה_, zkos, _lles, בקשו
  { {0x27ff2c17,0x7945002a,0x628e2c18,0x29d80016}},	//   lyun_, jówk, rabo, _xĩa_
  { {0xb14606b4,0xdfd20087,0xa0670608,0xf652000a}},	//   інал, ويز_, жата_, _קצה_
  { {0xef1a05a6,0x4fea0aed,0xe29a2c19,0x76430034}},	// [5640] ама_, шман_, _кап_, _hyny
  { {0x27ed08e0,0x3eae00b8,0x93fb000a,0x7d1b0b62}},	//   ixen_, üft_, _כלפי, _amus
  { {0x6f1e2c1a,0x6564008c,0x7d022c1b,0x7d092c1c}},	//   ripc, _kiih, tkos, _bles
  { {0xf7670225,0x76430026,0xd83e00bf,0x1d0a0054}},	//   _يا_, _myny, íčko_, једи_
  { {0x6b440251,0xa09b0053,0x7d022c1d,0x8236002b}},	//   lògi, _דיכט, rkos, _درکا
  { {0x60d600df,0x1af30010,0x7d022c1e,0x8b650015}},	//   ldym, мпія, skos, ساهم
  { {0xf98f003b,0xd90d0086,0x7945005c,0x60d60007}},	//   نبي_, گین_, cówk, odym
  { {0xd7c80074,0x60d600df,0x656400f2,0x57f40758}},	//   موعه_, ndym, _niih, зпит
  { {0xd90d0074,0x99e3006f,0x4a760033,0x6d402c1f}},	//   دین_, ĺňal, _дыет, _ikma
  { {0x7d1b005c,0x60d6008c,0xba970058,0x28da0065}},	//   _zmus, hdym, _ونقص_, _मोरि
  { {0x76430026,0x60d60007,0x673a00bc,0x79ca002b}},	//   _cyny, kdym, rotj, _خواف_
  { {0x37e60080,0x657500dc,0xdb0a002e,0xe9ff0092}},	//   _моег, ízha, ðnæt, _hiếm_
  { {0xe9ff0023,0x8d5b0053,0x7945005c,0x60d60026}},	//   _kiếm_, יכטי, zówk, ddym
  { {0x76430026,0x752d005c,0x99430061,0x0000006a}},	//   _fyny, _wjaz, _kış_,
  { {0x64b30089,0x82370086,0x32050057,0x21290375}},	//   _přič, زرسا, ály_, tnah_
  { {0x752d003f,0xf8bc000b,0x60d60091,0x399b004f}},	//   _ujaz, ्जिय, gdym, יילד
  { {0xc05b0191,0x21290d25,0x644d2c20,0x32050089}},	// [5650] рів_, rnah_, _uzai, šly_
  { {0xcddb0001,0xc7d70008,0x753d014f,0xaad9000b}},	//   иње_, חומי_, losz, _योंक
  { {0x2d870152,0x44a4002b,0x60d60091,0x2ef82c21}},	//   ène_, _عمیق, bdym, _dorf_
  { {0xc5f30008,0x753d0eba,0xbd18005e,0xd256000a}},	//   ודע_, nosz, оції_, _משתה_
  { {0x69c12bd7,0x35cc000b,0xab94005e,0x999e0046}},	//   _sple, ़बड़, дичі, _bytů_
  { {0x7945002a,0x6ffa000a,0x6ec70015,0x5ff40033}},	//   mówi, _ההשפ, _بتحق, _ўзру
  { {0x1a68002b,0x753d1506,0x290d2c22,0xe29c004f}},	//   زینی_, kosz, thea_, בשור
  { {0x99430064,0x3ea90011,0x61e100f2,0x7d0900cb}},	//   _dış_, şită_, älly, _ules
  { {0x47c20080,0xf8ae002b,0xe8f6005e,0x28bc000b}},	//   ебыв, اکم_, їль_, ्ज़ि
  { {0x656400f2,0x290d003f,0x2eab000a,0xa9e70015}},	//   _siih, shea_, ׁשִּ, _وثان
  { {0xed550008,0x60d60034,0x99d90015,0x753d0e8c}},	//   ּבָר_, ydym, _دواء_, fosz
  { {0x753d014f,0x19ba000a,0xd886002b,0xb4c8000b}},	//   gosz, _למעב, _فهمی, ैये_
  { {0x656400f2,0x6d5900aa,0x4375011a,0x78270015}},	//   _viih, imwa, дуст, _بعال
  { {0x877a0008,0xb7da000a,0x7d180030,0x217602ed}},	//   _האסי, _לקני, évsz, зуар
  { {0x753d2c23,0x67212c24,0xa2ad000b,0x91e304e5}},	//   bosz, milj, _जार्, норе
  { {0x15fa0008,0x45fa0008,0x6b89051e,0xb4d600c3}},	//   _להצע, _להצג, _oweg, _رغبت
  { {0x4426001c,0x9406002b,0x6f660058,0x60d62c25}},	// [5660] _ão_, _روده, سهام, rdym
  { {0x91f60015,0xc294002b,0xdfcf0015,0x9f5f001a}},	//   _فأجا, _زیرب, طيم_, órða_
  { {0x42fb0008,0x02fb0008,0xcf89000a,0xc692004c}},	//   _ההיס, _הלימ, רט_, גאב_
  { {0xccf9005c,0x61e10134,0xc8da000b,0x4cb800ce}},	//   _coś_, ælle, _मोंट, іллю_
  { {0x672113f0,0xd24f002b,0x7be60033,0xead40c1d}},	//   kilj, _لنی_, яждж, доль
  { {0x69dc001a,0x753d0e8c,0x6d592511,0x6b4d0052}},	//   _árek, zosz, amwa, túga
  { {0xf2d3000a,0x99d30015,0xe9f80033,0x672106c0}},	//   געו_, فتيا, юнкі_, dilj
  { {0x8b660002,0x2d680045,0x2d980003,0x38c8002b}},	//   _فاطم, _eşec_, _ivre_, زابی_
  { {0x672100dc,0x6b850015,0x6b890034,0xed5706da}},	//   filj, _يشكل, _gweg, _хот_
  { {0x4b7b0008,0x95ca0f09,0x8cb6000b,0x9f9b0012}},	//   _לאמו, бума_, ोजको, _läßt_
  { {0x7ae800fb,0xd90f008f,0xceb7000a,0xe53500f4}},	//   _indt, _зь_, הפיק_, день
  { {0x29020ca0,0x7afa2c26,0xa925001a,0x79530058}},	//   ökad_, _hott, rkþá, _كَلا
  { {0x6721016f,0x753d0eba,0x69d50046,0x97c50015}},	//   bilj, rosz, _ázer, _يتهم
  { {0x7afa022d,0x079b0008,0x23650123,0x63a00030}},	//   _jott, _פסול, ölj_, ámna
  { {0x2d9c03af,0x76bb0008,0x7afa2c27,0x753d0e8c}},	//   ável_, _המופ, _mott, posz
  { {0x7afa153a,0xa0c50015,0xd5b8003d,0xd258005e}},	//   _lott, بيرو, mtā_, яця_
  { {0x88bd005c,0x40340080,0xd5b8003d,0x3e870015}},	// [5670] liśc, еетс, ltā_, كشاف
  { {0x7afa16e4,0xa283002b,0xfe70012c,0x427504e5}},	//   _nott, _سیرو, هدم_, _югос
  { {0xd5b80048,0x6b89005c,0x4ea40010,0xb2ba000a}},	//   ntā_, _sweg, эрта, _ומתר
  { {0xd5b80024,0x7188000a,0xb1b7002a,0xfd470033}},	//   itā_, _מְשַ, ążęc, чэзн
  { {0x50da000a,0x7afa0e81,0x3c470015,0x6d591852}},	//   _וקרא, _bott, أضاف, rmwa
  { {0xd5b80024,0xaa880029,0xb33b0061,0x7afa0fb7}},	//   ktā_, كنهم_, irço, _cott
  { {0x68f900ea,0x7afa2c28,0x67212c29,0x929c000a}},	//   _powd, _dott, vilj, זיות
  { {0x290b002d,0x6b89002a,0x98dd0033,0x08f90015}},	//   óca_, _tweg, рскi, ترتب_
  { {0x57e90036,0x2d9e00c0,0x67210085,0x3cf00264}},	//   ідом_, _åter_, tilj, ťové_
  { {0x66730086,0x7afa0271,0x88040015,0x2d680061}},	//   رگتر, _gott, عظيم, _iğer_
  { {0xcb120008,0x64a62c2a,0xddd50030,0x67212c2b}},	//   _שלב_, мана, _kezű, rilj
  { {0xda080015,0xc51a0033,0xb9250021,0x36180033}},	//   _عينه_, іўні_, _تفصي, яцыю_
  { {0x06f50015,0x224d0046,0x37c70054,0xd5b8003d}},	//   _يستج, řekl_, _хљеб, atā_
  { {0xf62500d7,0x2bc0000b,0x88bd002a,0x200c003d}},	//   _одло, _एहसा, biśc, _ādi_
  { {0xc5d50036,0xc7b900dc,0x443e005c,0x324310cb}},	//   _ціль, ltő_, łt_, верг
  { {0xc5f20008,0x2d9c0046,0xdb021d5e,0x0000006a}},	//   _ידו_, ávem_, troë,
  { {0xc7b900dc,0x210e000b,0xcf260015,0xb33b0061}},	// [5680] ntő_, _सतीश_, ورطي, orçl
  { {0x3f800007,0xc579000a,0x1eaa0015,0x8fa31ece}},	//   rpiu_, ַרְת, تاري_, тафе
  { {0xdd8f0115,0x69170045,0xc333000a,0x82360040}},	//   لول_, nţes, _בוז_, _زردا
  { {0x7afa02d7,0x0c260a61,0x69dc001a,0x1cba0015}},	//   _sott, ммен, _árei, تائب_
  { {0x7afa2c2c,0x7cd70015,0xad6500c3,0xc7b90030}},	//   _pott, بونز_, رامه, jtő_
  { {0xa3df000b,0x63a6001a,0x2417000a,0x0000006a}},	//   णित_, irkn, וחנן_,
  { {0x2d6801e2,0x7afa001a,0xb4db0144,0x1d0a009b}},	//   _eğer_, _vott, noàc, _деви_
  { {0xa0220064,0xf1b30008,0xb9e3005e,0xa3a9000b}},	//   _şöyl, דסה_, тіши, खूँ_
  { {0x9992005c,0x88bd005c,0xb8d6021e,0x629e0e6f}},	//   ódło_, wiśc, _जा_, _odpo
  { {0x7ae80134,0xabfb000a,0x9bfb000a,0x17f70015}},	//   _undt, _והמר, _והמט, ظرية_
  { {0xda650015,0x1833002b,0xfb170058,0x63a62c2d}},	//   _كامي, فریح, _تقلع_, erkn
  { {0xd5b80024,0x97c60015,0xa8061ebd,0xdb020003}},	//   rtā_, _يقاو, _озел, droé
  { {0xd5b80024,0x9405002b,0x80a8000b,0x53470195}},	//   stā_, روسه, गलैं, дхва
  { {0x175405cb,0xd7030063,0xd5b8003d,0x65941ecc}},	//   _явля, _изчи, ptā_, _заку
  { {0xd5b00015,0x399a003d,0x2caf0123,0xa1670054}},	//   _صفة_, nīs_, yggd_, дњак
  { {0xa2bf000b,0x859b000a,0x2258004a,0x26cc2c2e}},	//   _लॉर्, _ושהו, фисы_, ledo_
  { {0x6b820844,0xd164006b,0x75360030,0x9f551923}},	// [5690] jpog, търи, ézze, евач
  { {0xbdfb0086,0x9e150010,0x3ed50015,0x6b8200bc}},	//   يرضا_, ндзі, عقار, dpog
  { {0x62952c2f,0xdbf90065,0xdb0201f6,0x0000006a}},	//   mazo, ्न्ड_, croé,
  { {0x399a0024,0xe0870031,0x2d812c30,0x62952c31}},	//   dīs_, _تجدي, rphe_, lazo
  { {0x0f7900b2,0xdcfe0048,0x907a0008,0x3f79004c}},	//   _מאָב, espē, _מטרי, _מאָס
  { {0x6295000c,0x60cd002d,0xba75009a,0x26cc2c32}},	//   nazo, leam, راتت, jedo_
  { {0x8d740015,0x0000006a,0x0000006a,0x0000006a}},	//   _لاقا,   ,   ,
  { {0x35a8005d,0xc7b900dc,0x629524ac,0x5d650015}},	//   _कमज़, ttő_, hazo, _أُرْ
  { {0x7d0400f2,0x62952c33,0x20040061,0xc158000a}},	//   öise, kazo, _ümit_, ושהו_
  { {0x60cd002d,0xdb2500f2,0xc7b900dc,0xe6190146}},	//   heam, äpäi, rtő_, здо_
  { {0x6ec1000b,0x60cd008c,0x69de0123,0xc7b90030}},	//   र्यु, keam, åpet, stő_
  { {0x58b80015,0x03a62c34,0x17fb0015,0xa988004f}},	//   _يانج_, нимо, _ورشة_, _חָסִ
  { {0xe72e0491,0xc9520008,0x6d4b2c35,0x26cc2373}},	//   _бе_, _עמד_, ilga, bedo_
  { {0xb6060092,0x629500dc,0x2d9c0046,0x5999000a}},	//   _khở, gazo, ávek_, ּשּׁ
  { {0xa18a010f,0xa50a0c45,0xc15600af,0x0000006a}},	//   ябва_, _нека_, ењањ,
  { {0x644100b8,0xf992000a,0xe5060015,0x6440007c}},	//   ßlic, טרל_, _سبعي, ümis
  { {0x44660286,0xb4be000b,0x399a003d,0xb4cc000b}},	// [56a0] _явив, ीजी_, zīs_, रजी_
  { {0x64410064,0xf43b000a,0x5f460067,0xc43b000a}},	//   şlic, _מתפש, رنال, _מתפי
  { {0x02b70008,0x93250029,0x7bde0024,0x5d6a004a}},	//   _אליך_, _جرين, āpum, чием_
  { {0xe5720053,0xc8ae000b,0x60cd0cb4,0x0000006a}},	//   אַס_, _टाइट, ceam,
  { {0x1016003b,0x33c9000a,0x1bd4062f,0x26cc2c36}},	//   _أبجد, ֥הוּ_, толя, yedo_
  { {0x399a0024,0x6d4b2c37,0x539b000a,0xdcfe003d}},	//   tīs_, alga, לינו, tspē
  { {0x6b822c38,0x58d4056d,0x7db5004a,0x99660c02}},	//   spog, войт, _истц, нтил
  { {0xa9670657,0xb9c30029,0xdb020003,0x399a003d}},	//   нија_, اقيي, croî, rīs_
  { {0xeab20029,0x399a0024,0xdca3006b,0x62952c39}},	//   _معا_, sīs_, _щати, yazo
  { {0xb33b0064,0x501b0008,0x68e70024,0x7b97000a}},	//   nuçt, פויו, ējda, _נכבד_
  { {0x99e90029,0x1a9b004c,0x48e6005e,0x6295117d}},	//   _يعمق_, _זיבע, _пожв, vazo
  { {0x26cc018c,0x2ca0002d,0xc985002b,0xa3cd000b}},	//   sedo_, óidh_, _ششمي, रबल_
  { {0x04670080,0x60cd007c,0xb05b0012,0x62951fa5}},	//   этом, veam, _abän, tazo
  { {0xa5c60030,0x6d42007c,0x66e30054,0x0000006a}},	//   _adóű, hooa, _боља,
  { {0x62950c5d,0x6d4b1f9f,0x60cd2c3a,0x0000006a}},	//   razo, ylga, team,
  { {0x62950089,0xd0d4006b,0xdddc1c4e,0x74150369}},	//   sazo, лосъ, _berž, _لوبا
  { {0x60cd1bea,0x62952c3b,0x4ea702ed,0x0000006a}},	// [56b0] ream, pazo, ереа,
  { {0xdb1b0064,0xdb2300dc,0x69c82c3c,0x60cd2c3d}},	//   _ipuç, érül, _opde, seam
  { {0x60cd2c3e,0x39460030,0xb2550054,0xddab009b}},	//   peam, _okos_, _шкољ, ятал_
  { {0x764a0026,0xc19a0008,0xeb09000b,0xdb810033}},	//   _myfy, _קשרי, वस्त_, аркi_
  { {0x4ea70180,0xd498004c,0x9098006b,0x63bd2c3f}},	//   _прва, ײכות_, _явят_, ntsn
  { {0x9f350191,0xfe7003c4,0x5d850029,0x4ea70142}},	//   _регі, _هدف_, _للسل, _ярма
  { {0x9f340036,0x8f340036,0xa2a8000b,0x127c004c}},	//   _сері, _серц, फ़्ट्, לאגע
  { {0x69a20065,0x47c500ce,0x0000006a,0x0000006a}},	//   _गिरी, вбив,   ,
  { {0xe7b20029,0x63af0085,0xb33b0061,0x7c342c40}},	//   لميد, jucn, nuçs, _бетх
  { {0x88bd005c,0x97c40015,0x63af0085,0xb8e8000b}},	//   ciśn, اتيم, ducn, _लॉ_
  { {0x764a0026,0xc8b3002b,0xc984067a,0xceb2004f}},	//   _cyfy, _ملاک, _бучи, סיט_
  { {0x764a0026,0xb4be005d,0x2f0400c0,0xfc27002b}},	//   _dyfy, ीजे_, _högt_, لح_
  { {0x63af016f,0x4c9a000a,0x2d47016e,0x394d0723}},	//   gucn, וברו, lões_, mles_
  { {0x764a0026,0xc7b20008,0x394d2c41,0x9343004a}},	//   _fyfy, _כבד_, lles_, иняе
  { {0x764a0026,0x320c0107,0xb10a0015,0x63bd0079}},	//   _gyfy, ády_, وآرك_, atsn
  { {0xdddc00df,0x8afc005c,0x63af0045,0x0000006a}},	//   _perž, _pięk, bucn,
  { {0x75240064,0x2d47016e,0x394d2c42,0xf0660033}},	// [56c0] _imiz, hões_, iles_, ткап
  { {0xceea0033,0x394d0012,0x395f0d34,0xdddc1289}},	//   ьдзе_, hles_, hmus_, _verž
  { {0x8afc0050,0x394d09f6,0x2d9c0030,0x81460040}},	//   _więk, kles_, éve_, _لندن
  { {0x60260010,0xd36f0086,0x6da32077,0x2d47016e}},	//   _адма, _دهی_, рица, dões_
  { {0xdd0c005c,0x2f04002e,0x8c430033,0xfc320015}},	//   _półn, _sögu_, аеце, جحا_
  { {0xf9c60142,0xda340010,0x394d2c43,0xf236000a}},	//   вщин, лелы, eles_, ֣רֶץ_
  { {0x6c860029,0xbcaa0015,0xada603ae,0x2d47016e}},	//   _للأم, _يدرك_, _јабл, gões_
  { {0x28c2000b,0xc7d8005e,0xd8e30033,0x394d11ef}},	//   _वॉशि, емих_, ацьп, gles_
  { {0x29180007,0x99470021,0x5bc50015,0xab662c44}},	//   ėra_, خليل_, _متلف, _авал
  { {0x394d2c45,0x7524001c,0x9bb700a3,0x7d002c46}},	//   ales_, _amiz, _בהמה_, _homs
  { {0xe5b4008f,0xceb301e4,0x2d47016e,0x394d16c8}},	//   ыйны, בית_, cões_, bles_
  { {0xb81d000b,0xa8870033,0x394d0f4b,0x63bd0c2e}},	//   _बेकम_, _айца_, cles_, ttsn
  { {0x39440007,0x7d001661,0xb8f60157,0x64560535}},	//   moms_, _moms, ाज_, _czyi
  { {0x27e610df,0xc105002b,0xd7a9002b,0x75240061}},	//   _iron_, گوري, _سدهٔ_, _emiz
  { {0x57570008,0xa3e3005d,0xa2940210,0x4ac4000b}},	//   _שבוע_, _नज़र_, расі, ल्यव
  { {0xc60e000b,0xc1050015,0x39442c47,0x25ef0065}},	//   ानीय_, دوري, noms_, इमरी_
  { {0x93470029,0x2d47001c,0x3f9b0152,0x7538000a}},	// [56d0] _لخدم, zões_, usqu_, _שאחד_
  { {0x3f9b0152,0xb7e3000b,0x539c000a,0x61e10123}},	//   rsqu_, कटतम_, _חיזו, ålls
  { {0x8d74040b,0x395f00df,0x78a2002c,0x2d47001c}},	//   لانا, ymus_, _odov, xões_
  { {0x39442233,0x7c870054,0xbca40015,0x7d002c48}},	//   joms_, туже, لممي, _coms
  { {0x351c0135,0xcac90004,0x39442c49,0x212928bb}},	//   וואנ, егле_, doms_, miah_
  { {0x2d47001c,0x2bd4000b,0xab760015,0x501a000a}},	//   tões_, _धनरा, دموا_, _טורו
  { {0xceb20008,0x394d2c4a,0x60dd2c4b,0x395f2c4c}},	//   _לים_, tles_, _kasm, tmus_
  { {0xdb02002e,0x2d47001c,0x39440091,0x394d2c4d}},	//   stoð, rões_, goms_, ules_
  { {0x2d47001c,0x7cd4005c,0x20090d25,0xa825002b}},	//   sões_, _wśró, nyai_, دکان
  { {0x395f2c4e,0x26dc04ed,0x79a72c4f,0xdbd1007c}},	//   smus_, _cavo_, _арде, _müüa
  { {0x88bd0050,0x394d0f4b,0x6d5b01c2,0xbd15000a}},	//   liśm, ples_, _khua, ָחָז_
  { {0x27e60034,0x9f4000aa,0x60dd0c5d,0xfe36004f}},	//   _fron_, tvië_, _nasm, טרתי_
  { {0x673200dc,0x21290509,0xef280061,0x27e60034}},	//   ódjá, diah_, lmüş_, _gron_
  { {0x26dc0007,0x290d00f2,0x68fb2c50,0x9f400079}},	//   _gavo_, lkea_, ljud, rvië_
  { {0x66f60008,0x71760002,0xef280061,0x10a62c51}},	//   _תמצא_, اهرا, nmüş_, ливн
  { {0xdd000024,0xf1a9006e,0xdff60033,0x80a60369}},	//   ītīb, ضافه_, лязь, طمئن
  { {0xdd000024,0x68fb003f,0xd12f0015,0x290d008c}},	// [56e0] ūtīb, ijud, سمك_, ikea_
  { {0xd00f0015,0xf0632c52,0x68fb007c,0x1fb5012e}},	//   ألك_, скуп, hjud, јстр
  { {0x6d5b002f,0x290d00f2,0xf2d30008,0x127b0053}},	//   _bhua, kkea_, _העת_, _ראטע
  { {0x6d5b017e,0xae59005e,0x672800bc,0x6fcf000b}},	//   _chua, трує_, zidj, _सैकं
  { {0x5b26008f,0xda7a008f,0xac9703c4,0xb09b000a}},	//   лька, няй_, انها_, _איכר
  { {0xb9b40029,0x9e66002b,0xe457000a,0xbb430099}},	//   لمتع, _مازن, ניסט_, бечк
  { {0x2fc01893,0x2dd80008,0x6d5b002d,0x39442c53}},	//   ltig_, _בַּב, _fhua, toms_
  { {0x26dc0780,0x3eb20011,0x47d40015,0xd7c80067}},	//   _savo_, şată_, ليبر, نوعه_
  { {0x0ab60029,0xabaa0086,0x872a0033,0x2fc02c54}},	//   _محاد, _سهام_, еўна_, ntig_
  { {0x2fc000b8,0x4c350010,0x394414bd,0x21291613}},	//   itig_, _тэст, soms_, ziah_
  { {0x68fb01d1,0xceb30008,0x27220092,0x2fc004de}},	//   bjud, זית_, hưng_, htig_
  { {0x2ed1005d,0xdcfe0007,0xa84a0029,0x69da2c55}},	//   _हस्त, rspė, _كلام_, _iste
  { {0x26dc0007,0x60dd0553,0x661a1116,0x69ba0065}},	//   _tavo_, _rasm, sztk, _एमडी
  { {0x3dc6005c,0x59b8005d,0x45f80015,0xe81d000b}},	//   łowy_, _इमार, _لفتح_, _बेटा_
  { {0x2fc000dd,0x867b0447,0x656d2c56,0xc693000a}},	//   etig_, _ארוו, _tiah, _האצ_
  { {0xdbd10020,0xdb0b0134,0xf1540015,0x94050015}},	//   _püüa, stgø, مَّد, _نوعه
  { {0x2eab0124,0x200f0014,0x2fc02c57,0x21292afc}},	// [56f0] ењен_, ági_, gtig_, riah_
  { {0xa857000a,0x69da2c58,0x21292c59,0x6d5b2c5a}},	//   רימה_, _oste, siah_, _shua
  { {0x212900e8,0x74bc000b,0x69da0079,0x9757000a}},	//   piah_, ष्कृ, _nste, ניבו_
  { {0xdd940010,0x6e6401b0,0x01fa004f,0xa15900af}},	//   сацы, стуж, _ספרל, _јаму_
  { {0x5bc40029,0xec780036,0xb09a000a,0x2ba70054}},	//   متوف, упі_, _שישר, ујев
  { {0x637c0008,0x3f892c5b,0x8a052143,0xe37c004f}},	//   תנגד, mpau_, изле, ערור
  { {0xf2d400b2,0x6d5b002f,0xd2b80008,0x5f38006b}},	//   מעס_, _thua, אלות_, _спря_
  { {0xef280061,0x290d008c,0xb90503ae,0xdce90091}},	//   rmüş_, ukea_, рзик, _kieč
  { {0xf719008f,0x290d00f2,0x69da1103,0x320a002a}},	//   віны_, rkea_, _este, zyby_
  { {0xd7090080,0x290d00f2,0xfbd00021,0xb7c80015}},	//   тное_, skea_, _عتق_, ابيك_
  { {0x5ee80008,0x6994005e,0xdce914c4,0x79c8002b}},	//   אַרְ, _гріх, _lieč, _مولف_
  { {0xcdb6000a,0xa87b0058,0x0000006a,0x0000006a}},	//   ספרה_, _أحضر_,   ,
  { {0x9cd60008,0xb909005d,0xd4560063,0xdce9002c}},	//   בורה_, मय_, ртнь, _nieč
  { {0x69da2c5c,0x0000006a,0x0000006a,0x0000006a}},	//   _yste,   ,   ,
  { {0xd5e800e5,0xe2971c44,0xa2a2000b,0xd5a3002b}},	//   _معين_, рас_, कृष्, _البی
  { {0x7bdb00f2,0xdcfc003d,0x387f25d2,0x2fc02c5d}},	//   _osuu, _otrā, ncur_, ttig_
  { {0x2fc000b8,0x4f260010,0x21672c5e,0x60c403d9}},	// [5700] utig_, адаб, рити_, rfim
  { {0xbda60029,0xef172c5f,0x27220016,0x387f0125}},	//   لحصو, аму_, rưng_, hcur_
  { {0x2fc02c60,0x629c2c61,0x6c860058,0x8afc0535}},	//   stig_, maro, للام, _mięt
  { {0xad650087,0x6df30015,0xbc6a002b,0x69da0012}},	//   مانه, تكما, نمان_, _rste
  { {0xab770015,0x4f660015,0x1d070054,0xdff602ed}},	//   لمنا_, _ناسف, јечи_, _тянь
  { {0x39a612d2,0x2d9c01c9,0x629c2c62,0x79a62c63}},	//   ашив, áves_, naro, арие
  { {0x6b4d001a,0xc9a70004,0x19b70015,0x49b70040}},	//   júgu, авје_, لطية_, لايد_
  { {0x4ddb0008,0x27c6005e,0x7d19002a,0x58d81111}},	//   _בחלו, ащог, chws, удия_
  { {0xc60e005d,0x629c2c64,0x69da005c,0xa9670054}},	//   ान्य_, karo, _wste, шића_
  { {0xa9a6010f,0x636000dc,0x629c2c65,0x7b32002a}},	//   _вижд, lönf, jaro, dług
  { {0x0f57013a,0x69da2c66,0xcf57000a,0x9e77000a}},	//   שיים_, _uste, שבית_, יגיה_
  { {0xd7e60036,0xa98b0008,0x4866006b,0x798a00d5}},	//   _віко, _סָבִ, _кълб, mpfw
  { {0x629c003f,0x93b40033,0x3cfe000b,0x7bc22c67}},	//   faro, обяц, _रचने_, ntou
  { {0xd81b000a,0xe6940015,0x629c2c68,0xdce90816}},	//   _שֵׁש, _الثد, garo, _rieč
  { {0x01270004,0xa75b000a,0x53340ae6,0x0000006a}},	//   аќам, _שדור, церт,
  { {0x20750010,0x629c0161,0xd5fb000a,0x7bc2050b}},	//   слаў, aaro, _יפור, ktou
  { {0x3e870029,0x25de000b,0x7b32002a,0x629c2c69}},	// [5710] لشاف, गिकी_, ołud, baro
  { {0x8afc005c,0x629c2c6a,0x02a72c6b,0x1df9004a}},	//   _mięs, caro, _трим, лезы_
  { {0xdcfc0024,0xa3df000b,0x5d670033,0x333c000a}},	//   _strā, णिक_, атдз, _בתזמ
  { {0xc57900b2,0xee38005e,0x71d6000a,0xdb0b0077}},	//   אָסט, шнє_, _פורד_, rugí
  { {0x2bda021e,0xd0f6000a,0x00f6000a,0xfc300058}},	//   _मैदा, _המרת_, _הזרם_, وحه_
  { {0x73d8000a,0xdf440138,0x0000006a,0x0000006a}},	//   שֵׁב_, _дэсп,   ,
  { {0x49980033,0x09f90015,0x4dd40015,0x29d80016}},	//   атыя_, افعة_, _وتفس, _cũa_
  { {0x97c50029,0x3238000a,0xf238000a,0x629c2c6c}},	//   مقبو, יטון_, ירוץ_, zaro
  { {0x8afc005c,0x7c240125,0x629c19fe,0xfb840138}},	//   _pięt, úirt, yaro, _дыхн
  { {0x46f50080,0x69170045,0x387f2c6d,0xa37b007c}},	//   счит, nţez, scur_, rvõl
  { {0x160e000b,0x6d5e002a,0xa37b007c,0x629c2c6e}},	//   ानगर_, łzał, svõl, varo
  { {0x94060015,0x7ae12c6f,0xd3ba0033,0x25aa1793}},	//   موجه, _halt, лугі_, ábla_
  { {0x629c09f0,0x44240092,0x08760053,0xf7850029}},	//   taro, àm_, _הענט_, _التَ
  { {0x44630063,0xf6790053,0x66100030,0x2af00065}},	//   явяв, _גאַמ, ökké, चाएँ_
  { {0x7b320050,0x629c2c70,0xd179005e,0x69c32c71}},	//   sług, raro, исті_, ntne
  { {0xd1320029,0x69ba000b,0x6fac000b,0xdcfe003d}},	//   أمر_, _एमसी, _चिदं, rspī
  { {0x29c10092,0x787a000a,0xdce00091,0x351b000a}},	// [5720] hóa_, אָבו, _gimę, _תופנ
  { {0x1ea90029,0x93fb0008,0xcf250015,0xdcfc0045}},	//   لامي_, _עליי, يرلي, _otră
  { {0x61460a8c,0x83650021,0x4e460015,0x9756000a}},	//   _гена, _بديل, حَاق, ציעו_
  { {0xdcb9005e,0x7bc2008c,0x6360001a,0x63a42b04}},	//   ищі_, ttou, föng, _kvin
  { {0x5c97008f,0x2d08005d,0xcce50015,0xdcfc0045}},	//   скія_, _वकील_, تسلي, _atră
  { {0x7bc22c72,0x0057000a,0x5f060329,0x99d600c3}},	//   rtou, _לשכת_, _узга, متعا
  { {0xf2d30008,0x853d0007,0x7bc22c73,0xfaa30004}},	//   פעה_, orėt, stou, чајо
  { {0xb7d80015,0x61e102de,0x7c240125,0x6360171f}},	//   لوبا_, ælli, úirs, böng
  { {0xaaba0002,0x17fa0015,0x7d0d008c,0x9d2b000a}},	//   _مدار_, ارعة_, öase, _עֵלִ
  { {0xd6da2c5e,0xdb24002b,0x64410061,0x7ae12c74}},	//   ути_, _بوئی, şlik, _galt
  { {0x8626008f,0x69c300da,0x4efb004c,0x1efb004c}},	//   сьпе, ctne, אליג, אליע
  { {0x7b32002a,0x2d730085,0xe7b6002b,0xf48404d7}},	//   słud, _kćer_, _همصد, зурн
  { {0x443f016e,0x8434005e,0xf7462c75,0x7856009a}},	//   çu_, зняє, _ледо, _اخاذ
  { {0x6594008f,0xdc3700b2,0x67bb000a,0x63a906db}},	//   _даку, מאכט_, _עמוק, šeno
  { {0x63a42c76,0x1757004f,0x2bda0065,0x0000006a}},	//   _evin, _הסגר_, _मैसा,
  { {0x86370008,0x41550010,0x21550033,0x115502a3}},	//   _לרוב_, івас, ікаў, ікаю
  { {0x752f005c,0x6e99000d,0x63a42c77,0xa1580b9b}},	// [5730] micz, ивар_, _gvin, сату_
  { {0x752f0050,0x69c30227,0xa6f8000a,0x1eab0015}},	//   licz, ytne, סִּי, طائي_
  { {0xf3cb0074,0xedd50021,0x69c30123,0x2d870079}},	//   _شبکه_, تياد, xtne, ëne_
  { {0x752f0050,0xe611000a,0x25d7000a,0xe057002b}},	//   nicz, וִד_, מובן_, _هیأت_
  { {0xdcfc0011,0x853c000a,0x7b32002a,0x6360001a}},	//   _stră, נגדי, dłub, bönd
  { {0x539c0135,0x752f002a,0x853d0091,0x69c32c78}},	//   ניוו, hicz, orės, ttne
  { {0x2012002c,0x7ae12c79,0xe9a80015,0xb2bc000a}},	//   čniť_, _valt, مدين_, אמור
  { {0x2bd90086,0x98bf0045,0xe7a910b7,0x8d74012c}},	//   _پارک_, două_, авил_, _رافا
  { {0x6d4b2c7a,0x69c312d7,0xb7e20033,0x177a004a}},	//   moga, stne, джык, и́ть_
  { {0x59c50015,0x6d4b2c7b,0x6f7a000a,0x5fac000b}},	//   _ويذك, loga, סְפו, _चिसल
  { {0x752f0050,0xceb2103d,0xf6510015,0x853d0091}},	//   ficz, ויי_, بئة_, yrėt
  { {0x752f005c,0x3d07000b,0x671d000b,0x6d4b2c7c}},	//   gicz, _शवों_, योजक_, noga
  { {0xe72e05cb,0x78bb0024,0x636000b8,0x39a5003d}},	//   _же_, mguv, höne, lēs_
  { {0x6d4b2c7d,0xe297070f,0xdb02016e,0x9af9004f}},	//   hoga, жар_, rroç, ׁפָח
  { {0x60d6002e,0x99a9000a,0x7d04008c,0x39a5003d}},	//   teym, יֹּ֗, öisk, nēs_
  { {0x853d0007,0x78bb1f59,0xf8d9000b,0x63a40295}},	//   urėt, nguv, ढ़िय, _tvin
  { {0x10160010,0x63a40045,0x60d62c7e,0x795e0034}},	// [5740] цьвя, _uvin, reym, lëwc
  { {0x27e2002e,0x2f560033,0x7e560117,0x0000006a}},	//   ækni_, ітас, отец,
  { {0x6d4b26cf,0x98a40011,0x98d9000b,0xcc8a0015}},	//   foga, nimă_, ढ़ाए, لناه_
  { {0xf09f0023,0xa3ce005d,0x92b60086,0xb64c004c}},	//   _hoàn_, _रहा_, _احکا, נגאָ
  { {0x653b0053,0xe45f0030,0x5c030a32,0xdb1b12cf}},	//   סענד, jföl_, дяща, _equí
  { {0x63600014,0x7f19005e,0xf767002b,0x752f002a}},	//   lönb, _лісу_, _زا_, zicz
  { {0xddc30124,0x8ad50010,0x9cb60029,0x66df0091}},	//   _обри, яюцц, _ومست, iškė
  { {0x2cba0086,0x984f0064,0x97a62c7f,0xf8af0015}},	//   _خُرد_, _ağır_, орол, نةً_
  { {0x8afc005c,0x3958003d,0xdce60091,0x2d980034}},	//   _chęc, ērs_, _ūmėd, _hwre_
  { {0xe5c6005f,0x15ea0036,0xcff70008,0x752f005c}},	//   осмо, аємо_, קציה_, wicz
  { {0x8e7b0008,0x6d432c80,0xd5b704f0,0x80ba000b}},	//   יניה, énag, ося_, इलाइ
  { {0x6eca000b,0x7d022c81,0x3ce6193f,0x7c222c82}},	//   स्तु, njos, ndov_, ozor
  { {0xe947002b,0x18360067,0x63600030,0xdce200bc}},	//   _برلی, _براح, zöne, jmoč
  { {0x672a002e,0x78a02c83,0x7c15004c,0xc34b0238}},	//   _umfj, lamv, פֿרע_, ряме_
  { {0x7d020048,0x398301e2,0x31c42c84,0xa646002b}},	//   kjos, _kısa_, мств, _بخشن
  { {0x2eed0011,0xa98b000a,0x98a600bc,0xa0c50058}},	//   _şef_, יָמִ, _omoč_, ثيرو
  { {0x6d4b001c,0x39a50024,0xb7ed000b,0xe7ed000b}},	// [5750] voga, zēs_, जियम_, जिया_
  { {0x7c2210a4,0xdd910015,0x6d4b0034,0x7d020091}},	//   dzor, ّوا_, woga, ejos
  { {0x6d4b2c85,0x0dc8005e,0x2d94005e,0x6b8916a9}},	//   toga, жучи_, дріс, _steg
  { {0x6f07005c,0xdce200bc,0x7bf91cd9,0x6d4b0073}},	//   _wojc, bmoč, йнер_, uoga
  { {0x2bbb0029,0x8c450004,0xfb870033,0x70fa000a}},	//   شاشة_, џеле, цыен, _ההרח
  { {0x31690e4a,0x39a50024,0xfbd00015,0x4995005e}},	//   lmaz_, tēs_, ضته_, пшит
  { {0x98a40011,0xdd910031,0x3ea1007c,0x6d4b2c86}},	//   ximă_, _سوء_, maht_, poga
  { {0x39a50024,0x31690064,0xe8f90df0,0x710b000a}},	//   rēs_, nmaz_, сли_, יהֶ֗
  { {0x63a9052c,0x39a50024,0x7c22005c,0x9a871eca}},	//   šenj, sēs_, czor, _дуел
  { {0x1dd2005d,0x98a40045,0x7d1b001a,0x752d2c87}},	//   _सहमत, timă_, _hlus, _amaz
  { {0xceb20053,0x7b32005c,0xdcfc002a,0xa6e2001a}},	//   עיט_, słuc, _wtrą, óðau
  { {0x4a5a000a,0xc329000a,0x04462003,0x36180033}},	//   _הדעו, _גו_, земн, юцыю_
  { {0x43930010,0x27e9002d,0x987a000f,0x7d092c88}},	//   наўс, _éan_, _האנט, _moes
  { {0x7d1b0026,0xe796002b,0x877a004c,0x3ce600bc}},	//   _llus, _راهک, _פאצי, zdov_
  { {0xf7700018,0x60cf02c1,0x6263014d,0xe2a7001a}},	//   _شاه_, _bbcm, евра, íðar_
  { {0x04460063,0x6443005c,0x394d01b6,0x9f862c89}},	//   _нейн, _śnie, noes_, згад
  { {0x94bb013a,0xf09f0023,0x0eaa0010,0x65640035}},	// [5760] _המפת, _toàn_, йкай_, _ihih
  { {0x7d1b041c,0x8c3d0064,0x752d2c8a,0x63b9006f}},	//   _alus, _keşf, _zmaz, ňaný
  { {0xee3a0001,0x71a30010,0xf2970008,0x627b000a}},	//   љне_, _паэз, _מכיר_, _לנינ
  { {0xc2130008,0xdd8f0031,0x4c6a0004,0xdb1b0144}},	//   _נהר_, اون_, биен_, _aquà
  { {0x98a400df,0x7d09069b,0x63a601a7,0x629e013c}},	//   nimą_, _does, nskn, _kepo
  { {0xd90d002b,0x7d1b2c8b,0x63a62c8c,0x7c222c8d}},	//   ییل_, _elus, iskn, rzor
  { {0x7c2200dc,0x394d0026,0x7d1b037e,0x656401d7}},	//   szor, foes_, _flus, _ohih
  { {0x5886008f,0xa37b0020,0x98a40007,0xb1cd000a}},	//   чыка, svõi, kimą_, ׁמוֹ
  { {0x98a400df,0x5f00000b,0xeb9706da,0xd6d00015}},	//   jimą_, राप्_, _нит_, نقة_
  { {0x752d0089,0x98a40007,0x629e1e01,0xba3c0091}},	//   _smaz, dimą_, _nepo, _neįg
  { {0xa4d90124,0x27200023,0x31690061,0x0000006a}},	//   одну_, _lòng_, ymaz_,
  { {0xe9950086,0xe97b000a,0xce37000a,0xae5b000a}},	//   _آهنگ, _הנאש, לאית_, מכיר
  { {0x399a0007,0x98a40007,0x27200016,0x18740138}},	//   lūs_, gimą_, _nòng_, _ўгля
  { {0xcb8b000a,0x7c2d0052,0x26c20073,0x0000006a}},	//   מְלֹ, úari, đkos_,
  { {0x65880089,0x629e2c8e,0x2d5c0077,0x31690061}},	//   _běhe, _depo, víen_, tmaz_
  { {0xe63b0008,0x55bb0008,0x25d70053,0xa63b000a}},	//   _לתוכ, _המהו, _זוהן_, _לגור
  { {0xc05b0191,0x224d005c,0xdfd10021,0x78830030}},	// [5770] сів_, łek_, ضيا_, _hívó
  { {0x31690048,0x27200023,0x629e0009,0xd4380447}},	//   smaz_, _dòng_, _gepo, _מרחק_
  { {0x7d1b2c8f,0x753d2c90,0x7d092c91,0x3ea10012}},	//   _plus, onsz, _poes, raht_
  { {0x31350033,0x399a0091,0x753d06cd,0x6ec10065}},	//   _цемр, dūs_, nnsz, र्जु
  { {0xaf370074,0xed580036,0x3b84005e,0xcf27002b}},	//   _فرست, чої_, еліг, _فرآي
  { {0x82340086,0x6ffa000a,0x6287002a,0x7d0908cf}},	//   _آریا, _והשפ, ncjo, _woes
  { {0xe9d90191,0x7d0900f6,0x7d1b0046,0x394d2c92}},	//   іки_, _toes, _tlus, toes_
  { {0x7d1b01e2,0x9be70010,0x64b60046,0x37890054}},	//   _ulus, _нізк, _křiž, обио_
  { {0xb8d5000b,0xab39005e,0x6287002a,0x394d2c93}},	//   _जय_, _дпау_, kcjo, roes_
  { {0x05a9005f,0x98a400df,0x399a0024,0x394d0026}},	//   овой_, vimą_, būs_, soes_
  { {0xdb260086,0xdbd7008c,0x3e7c0046,0x629e2c94}},	//   _تولی, säät, lští_, _repo
  { {0x98a40007,0x6aa30026,0xdbd700f2,0xe3c60015}},	//   timą_, lanf, päät, وْجَ
  { {0xe3b20029,0x3e7c0089,0xf8b2000a,0x629e2c95}},	//   خرج_, nští_, _ישא_, _pepo
  { {0x98a40007,0x2fc90134,0x877a000a,0x6443002a}},	//   rimą_, dtag_, _ואסי, _śnic
  { {0xa50a0a0b,0x27200016,0x98a40091,0x6721001a}},	//   _мека_, _sòng_, simą_, mhlj
  { {0x4f96000d,0x98a40007,0x260a000b,0xa5760015}},	//   држу, pimą_, ाहरी_, _تُعت
  { {0x8fa304b9,0x3e7c0046,0x127a0058,0xcefa0058}},	// [5780] кате, jští_, _وحدث_, يّرت_
  { {0x27200023,0xfe720115,0xdfcf0087,0xbe360015}},	//   _vòng_, ندا_, شيم_, وراث
  { {0x6ce60036,0x02fb000a,0xa3e6000b,0x42fb000a}},	//   діле, _ולימ, फिक_, _והיס
  { {0x399a0007,0x68e902de,0x27200016,0x2fc92c96}},	//   vūs_, jded, _tòng_, btag_
  { {0x27ed0298,0x68e92c97,0x9b6a2354,0x3f6a1114}},	//   jven_, dded, ошка_, _мимо_
  { {0x6aa30313,0x399a0091,0xdd9200c3,0x298a0054}},	//   ganf, tūs_, _لوس_, осио_
  { {0x27ed0111,0x999e0007,0xf2d3000a,0xbb470015}},	//   even_, _rytų_, דעו_, بلون_
  { {0xa96700d7,0x63a92c98,0x399a0091,0x68e902f2}},	//   мија_, šeni, rūs_, gded
  { {0xa714005e,0x399a0091,0x0000006a,0x0000006a}},	//   емпі, sūs_,   ,
  { {0x97810074,0x291d0026,0x8b650029,0xcdd4000a}},	//   دیوه, _elwa_, _كالم, ֲךָ_
  { {0x290200c0,0x60cd29d6,0x99f50010,0xa2a5000b}},	//   ökas_, yfam, _пяці, _क़ब्
  { {0x9f40008c,0x249f001a,0x7ae80030,0x60cd01cc}},	//   lviä_, úum_, _hadt, xfam
  { {0x7a130089,0x88160015,0x69ca1036,0x0000006a}},	//   _větš, _تباط, ltfe,
  { {0xbcfd0092,0x2d5502de,0xdb0b0123,0x0000006a}},	//   _nhũn, lået_, stgö,
  { {0x6d590b90,0x76bb000a,0x6287002a,0x9f40008c}},	//   ylwa, _ומופ, rcjo, iviä_
  { {0x2d550134,0xd0d4006b,0x2fc90dca,0x24890535}},	//   nået_, косъ, ttag_, _ufam_
  { {0x403415ed,0x7afa0409,0x6287002a,0x6360001a}},	// [5790] ветс, _ontt, pcjo, mönn
  { {0x6d590079,0x7658008c,0x63bd2c99,0x3e7c0046}},	//   wlwa, _kyvy, musn, vští_
  { {0x68e92c9a,0x200f0020,0x7cd903ad,0x2fc9149f}},	//   yded, ägib_, змер_, stag_
  { {0xdd940010,0x2fc90134,0x3e7c0046,0xf53f00cb}},	//   тацы, ptag_, tští_, nnå_
  { {0x3e7c0046,0xeb992372,0xcbc40015,0x68e902de}},	//   uští_, чил_, نزوي, vded
  { {0x317900dc,0x8f9a000a,0x3e7c0046,0x6360001a}},	//   _hisz_, _מישי, rští_, hönn
  { {0xfaa6002b,0x929c000a,0xe9d10067,0x6aa32c9b}},	//   رجوی, חיות, اغت_, ranf
  { {0x7d0400f2,0x6aa30012,0x7afa00d5,0xd5b8003d}},	//   öist, sanf, _entt, azāk_
  { {0xbb840029,0xc7b90030,0x68e92c9c,0x6b8002f2}},	//   _للقي, mzők_, rded, _gumg
  { {0x63bd01bc,0x29020123,0xc7b90030,0x27ed2c9d}},	//   dusn, ökar_, lzők_, rven_
  { {0x8c3d0045,0xd8790015,0x0e9a000a,0x59c50015}},	//   _deşe, _فمات_, השתל, _سيشك
  { {0x89960008,0x6443002a,0x6aa1288f,0x636006cd}},	//   _נכנס_, _śnia, _helf, gönn
  { {0x97d8003b,0xe7080086,0x74550063,0x74160002}},	//   _يظهر_, ستین_, върх, روسا
  { {0xe9ff0023,0xaa81001a,0x91e62b12,0x6612005a}},	//   _giảm_, _þýdd, ноге, ídká
  { {0xe4eb000b,0xc5d5005e,0x76580091,0x31790030}},	//   _जोकि_, _чіль, _gyvy, _bisz_
  { {0xc57a0008,0xdbd701be,0xc0e32c9e,0x0000006a}},	//   _צרפת, _kääp, лоск,
  { {0x9f4000f2,0xc56900e5,0xe53b000a,0x6eb60015}},	// [57a0] yviä_, _تحول_, _מתקר, فصائ
  { {0xe9e50023,0xceea0010,0x6fb30002,0x2d5c0144}},	//   _đúng_, ядзе_, املا, ríem_
  { {0x2d9c0152,0x429b0008,0xdd8f0070,0x160f005d}},	//   ève_, _מסיב, مول_, ाहिर_
  { {0xcea9000a,0x659a004c,0x8d930015,0xc237000a}},	//   מי_, פינק, النش, _טריו_
  { {0x2d55003c,0xfb85002b,0xeb97004a,0xa37b007c}},	//   vået_, نگلی, еич_, lvõr
  { {0x6aa10176,0x853d0007,0xab27005e,0xc43b000a}},	//   _celf, gsėj, ноча_, התני
  { {0x3f82003f,0xdbd20020,0x2d550f47,0x0ae90015}},	//   _huku_, lüüt, tået_, برني_
  { {0x2c570050,0x61230020,0xad66002b,0x2df7000a}},	//   _będą_, _võlg, _سازه, _אצלך_
  { {0x6aa100dc,0xc7d70892,0xca4a002b,0x7658008c}},	//   _felf, емых_, _کلاه_, _syvy
  { {0x61230020,0x6aa10026,0xbbd7000a,0x8b260033}},	//   _tõlg, _gelf, _אומץ_, _ядзе
  { {0x9b170008,0x613b00f2,0x3f822857,0x7d6a000a}},	//   _רחבה_, nälä, _luku_, ּדָ֖
  { {0x6aa10298,0xdb0d002e,0x58960015,0x63bd2c9f}},	//   _zelf, ákök, _أجاز, tusn
  { {0x8c3d01e2,0x80ba000b,0xa9070015,0x938b2ca0}},	//   _teşe, इलैं, _سيول_, ясна_
  { {0x61230020,0x29aa000a,0x63bd2ca1,0x27e6008c}},	//   _mõle, ּיּ֣, rusn, _ison_
  { {0x15f30031,0x63bd0049,0xf09f0016,0x3179002a}},	//   _مسيح, susn, _hoài_, _pisz_
  { {0x865b0008,0x365b0008,0x3f82064e,0x636000dc}},	//   _מדוי, _מכונ, _buku_, lönl
  { {0xb4dd005d,0x64a40054,0xf51a000a,0x31790030}},	// [57b0] ड़ी_, _сања, _חֵיל, _visz_
  { {0xc43c0008,0x3f8f0024,0x2007016f,0xf43c000a}},	//   _מתחי, īgu_, ćni_, _מתחש
  { {0xf09f0092,0x26de0b6f,0x6123007c,0x24eb004f}},	//   _loài_, ieto_, _põld, ּקְּ
  { {0x6aa1020a,0xbd180036,0x7db400a2,0xab95005e}},	//   _self, нції_, اصلا, виді
  { {0xac84005e,0xcc080067,0xc7b90030,0x26de2ca2}},	//   угіл, فزون_, rzők_, keto_
  { {0x3ce900bd,0x50180180,0x853d0091,0x63ad0123}},	//   žav_, _џорџ_, usėj, _mvan
  { {0x2d85211c,0x7c950015,0x48e50033,0xc7b90030}},	//   _île_, _للأص, войв, mzői_
  { {0x98750001,0x63ad02ce,0x6123007c,0x6aa12ca3}},	//   купљ, _ovan, _hõlb, _welf
  { {0x61230020,0x3ce0007c,0xdc550054,0x96b90054}},	//   _kõlb, õive_, _рвањ, муну_
  { {0x7b770029,0xdbd7008c,0x46f5006b,0x38ba0061}},	//   _أطرا, _vääp, тчит, türü_
  { {0x8804002b,0x1af6000a,0xd5ae0015,0x63ad1478}},	//   نظیم, _שמעל_, يفٌ_, _avan
  { {0x5a0a0053,0xf9880015,0x2f16001a,0x3835105a}},	//   _קלײַ, _أنني_, _vægi_, _инер
  { {0x77840010,0x8bac000a,0x26de2ca4,0x4535004a}},	//   _бліз, ּׁלִ, beto_, ухэт
  { {0xe7330015,0x86c4002b,0x26de2ca5,0x9f4000aa}},	//   _حصص_, _ميهن, ceto_, rwië_
  { {0x290f0263,0x8cd2000b,0x3f822ca6,0xf2a30342}},	//   _koga_, ण्डो, _suku_, рисп
  { {0xddc7005c,0x21760001,0x68eb2ca7,0x216705a7}},	//   _wyjś, ђувр, _jagd, виси_
  { {0x68eb00b6,0xf2e7002b,0x63ad0085,0x3fe6006b}},	// [57c0] _magd, رکیه_, _gvan, ъжав
  { {0x8afc005c,0xf3c90029,0x7b32005c,0xa37b007c}},	//   _więz, _أبيه_, tłum, svõr
  { {0x63ad2ca8,0x2d550bfd,0xdee30b27,0xf297004f}},	//   _zvan, våer_, рохи, _שכטר_
  { {0xad260029,0xe9ff0092,0x61230020,0x68eb0035}},	//   خرطو, _nhằm_, _põle, _nagd
  { {0x9941005c,0x5c970010,0x78a2007c,0xdc970033}},	//   kół_, ткія_, _reov, твіі_
  { {0x3b530010,0xa9c60021,0x60c42ca9,0xdd03003d}},	//   акір, نزبو, lgim, ārām
  { {0x26de00f2,0xcb070015,0x656f0034,0xc7b90030}},	//   veto_, ضيين_, ymch, erő_
  { {0xc2130008,0x60c42caa,0x23b2000b,0xdb0b016e}},	//   שהה_, ngim, _जिंद, nsgê
  { {0x68eb00b6,0xf8030010,0xec13002b,0x26de2cab}},	//   _dagd, ачэн, _پولد, teto_
  { {0xd5b80024,0x67260024,0xaae50115,0x0aea005e}},	//   trā_, īkjo, _مسمو, _ідей_
  { {0x5ebb0008,0x8b570008,0x2fc0002d,0xc9d50086}},	//   וזיק, _יימס_, huig_, _مملک
  { {0xb4dd005d,0x69da01d7,0x63600012,0x4395153d}},	//   ड़े_, _ipte, sönl, ламс
  { {0x6d4200f2,0xe72f002b,0x63e80015,0x38600125}},	//   inoa, صصی_, نَّف_, _áir_
  { {0x68e00064,0x2d872cac,0x59c6000b,0xa493002b}},	//   lemd, ínek_, रंपर, دیکت
  { {0xa77b000a,0x8c3d0061,0x20c716cf,0x290f2cad}},	//   _קרופ, _meşa, ксаг, _yoga_
  { {0x74150086,0x68e00064,0x60c402b9,0x63ad2cae}},	//   _موبا, nemd, ggim, _tvan
  { {0x691c0152,0x4fc70063,0x30140010,0xbea7004a}},	// [57d0] _réel, ъсва, адтр, вшей
  { {0x4fc4049d,0x5fb7000b,0x9a99003d,0x63a90d7e}},	//   јста, ेंबल, ļākā, šens
  { {0x394602c1,0x02a40010,0xc7b900dc,0x4cb900ce}},	//   _ojos_, _трым, rzői_, елею_
  { {0xa3c7000b,0x463b004c,0x2fc00144,0x6440002a}},	//   _उमा_, ועבע, buig_, źmie
  { {0x8bc7000d,0x62800089,0x10ba000a,0xebc70054}},	//   тсед, ěmov, _אזרב, тљен
  { {0x6b65008f,0x68eb0bfa,0xa2d6000b,0x65880046}},	//   ыкла, _sagd, म्प्, _něho
  { {0x68eb00b6,0x290f0024,0x8cbb0015,0x39e80015}},	//   _pagd, _poga_, _يدرس_, َّهُ_
  { {0x89d60086,0x7c8700d0,0xa96617bd,0x88e5004a}},	//   اوير_, _јуве, лища_, ужие
  { {0x9b880015,0x6eca000b,0xb8050058,0x290f1dc4}},	//   _لنقل_, स्कु, ابعه, _voga_
  { {0x8f9a000a,0x0609004a,0x245d0030,0x09f70015}},	//   עיתי, енок_, zámú_, _لأصد
  { {0x290f010b,0xb9c40067,0x64a62caf,0x7c2b0012}},	//   _toga_, _نقلي, лана, lzgr
  { {0x2f160084,0xdcfc0048,0x3d21000b,0x04960033}},	//   _hægt_, _kurā, _मतों_, ыроў
  { {0x9941005c,0xad1a000a,0xf7f4002b,0xd5ae002b}},	//   pół_, גורר, _پسند, يفی_
  { {0x78a90020,0x883a000a,0x3ced007c,0x63832cb0}},	//   laev, _אתנו, _laev_, сгра
  { {0x395f0020,0x321e0057,0x6360008c,0x200f007c}},	//   olus_, áty_, lönk, ägin_
  { {0xd1320015,0xc2430033,0xc0950054,0x60c40091}},	//   حمر_, ёнтк, ишућ, ugim
  { {0x6fa50029,0x7524003f,0x80660805,0x321e0057}},	// [57e0] لإلك, _iliz, уваж, šty_
  { {0xa2e6000d,0x139b0008,0x636000dc,0x26c52bd1}},	//   _соод, _רביע, zönj, nglo_
  { {0x8f750036,0x75240085,0x78a9007c,0x629c2cb1}},	//   руті, _kliz, kaev, mbro
  { {0xe45f00c0,0xd00a0004,0x6d420045,0x629c0b17}},	//   mför_, _земе_, unoa, lbro
  { {0x395f0020,0xdb5a0127,0x653b004c,0x6bd30015}},	//   dlus_, нюк_, עענד, متور
  { {0xbda60087,0x600b000a,0x395f04f6,0x629c2cb2}},	//   _محرو, _נִכְ, elus_, nbro
  { {0xfc3f0084,0xe6070074,0xe45f00c0,0x527a000a}},	//   _þín_, _اش_, nför_, ׂנְא
  { {0x61230020,0x395f1519,0xdce20085,0x39140317}},	//   _kõla, glus_, dmoć, рмир
  { {0x6d3b000a,0x58d70033,0xed350033,0xdb160030}},	//   _נתמנ, удыя_, _тэрэ, ácók
  { {0x68e0002e,0x395f0007,0x7524003f,0x473409fe}},	//   semd, alus_, _aliz, рнос
  { {0xcf570008,0x0f5701e4,0xd6d704ab,0x7524136b}},	//   רבית_, ריים_, уты_, _bliz
  { {0x9e77000a,0xe45f0123,0xd5b8003d,0xdb0b0123}},	//   טגיה_, dför_, dzāt_, rrgå
  { {0x7bc2003e,0xb7960001,0x65880046,0x07b70015}},	//   nuou, _срећ, _těho, _مهنة_
  { {0xa01b00c0,0x5693005e,0xd6930054,0x75242cb3}},	//   _oför, _лашт, _лишћ, _eliz
  { {0x2259004a,0xc693004c,0x316b0054,0x2d5c0144}},	//   тивы_, _פאק_, ешао_, líeu_
  { {0x6aaa2cb4,0x01340015,0x63600012,0xaffd005e}},	//   haff, معقد, hönh, мобi
  { {0xcebb0001,0xdd010024,0x6aaa2cb5,0x2d5c0144}},	// [57f0] еље_, ūtīs, kaff, níeu_
  { {0x7bc200da,0x78a90061,0xaa9e0033,0x2d8501d3}},	//   duou, zaev, _дзiў, _élek_
  { {0x5b35002b,0x6aaa01d7,0x395f2cb6,0xc7b90030}},	//   یعتر, daff, ylus_, lzőt_
  { {0x219a000a,0x2cd5004a,0x8d74006e,0x1d090054}},	//   _שברא, рждё, مانا, ђели_
  { {0xd7e6003b,0xaca80086,0x7bc200da,0x3ced0072}},	//   _بك_, اههٔ_, guou, _vaev_
  { {0x645a04f9,0xff070010,0x661a008c,0x59c50058}},	//   ştig, _сямн, kytk, ليتك
  { {0x395f0005,0xaa490063,0x780d005d,0x6d4a0003}},	//   tlus_, ъпка_, ाङ्क_, éfac
  { {0x63bd016f,0xc27c0053,0xe97200a2,0x395f01d7}},	//   krsn, ערהי, يهود, ulus_
  { {0x31580053,0xe7310021,0x7bc200da,0x395f2cb7}},	//   װיזן_, قصد_, cuou, rlus_
  { {0xaa880015,0x9b7b0015,0x395f2cb8,0xdb190012}},	//   _منكم_, _أحرز_, slus_, ntwü
  { {0x49b80086,0xd5b80024,0x8afa0c44,0x629c03e6}},	//   _ماند_, dzās_, _שהעי, vbro
  { {0x95820010,0x7ae32cb9,0x69c32cba,0x25b80125}},	//   ўляе, lent, mune, árla_
  { {0x656d003f,0x7b0400dc,0x289a004c,0x69c310fd}},	//   _dhah, _átté, _סיסא, lune
  { {0xe45f00c0,0x68440036,0x0b680008,0xa3c7000b}},	//   tför_, _уніа, ָׁלָ_, _उमर_
  { {0xf9870015,0x629c2cbb,0x7ae31ecb,0xdcfc0045}},	//   تب_, rbro, ient, _jură
  { {0xe45f01d1,0x7524003f,0xdfd20115,0x74160015}},	//   rför_, _uliz, ييز_, _نوعا

  { {0x93250074,0x7ae32cbc,0x42d60010,0x5577004c}},	// [5800] _گرين, kent, _кіну, _דעקן_
  { {0x1303008f,0x61230020,0x7ae32cbd,0x8f75005e}},	//   _дзьм, _võla, jent, бухі
  { {0x69c30020,0x929b000a,0xa2bb000a,0x7ae30d2d}},	//   june, _שיטת, _במיט, dent
  { {0xdbd20020,0x64890008,0x6aaa2cbe,0x7bc200da}},	//   _tüüp, ְעוּ_, waff, tuou
  { {0xeb060431,0xb92a0092,0xccb70036,0xaab3000b}},	//   ичко, _thuế_, ргії_, ीलंक
  { {0x63a4003f,0x212000bd,0x69c300dd,0xbb43000d}},	//   _mwin, lkih_, fune, оечк
  { {0x88840086,0xdcfc0011,0x69c32cbf,0x6edb000a}},	//   میان, _cură, gune, _שחלפ
  { {0xb4cb005d,0x63a40a5d,0x0e63005e,0x212007c4}},	//   र्फ़_, _owin, _єктн, nkih_
  { {0x09330015,0xd117000a,0x36d40a1f,0x7ae32cc0}},	//   تروج, שקפה_, бопр, bent
  { {0x89d60036,0x2d5c0251,0x63bd016f,0xef11000f}},	//   _відш, ríeu_, vrsn, ִּי_
  { {0xceb30008,0x48e60080,0x2a360010,0x6ed8000b}},	//   חית_, _воев, _тэар, न्यु
  { {0x74150029,0x673a0251,0x6aa80026,0x2fd200c0}},	//   موجا, sitj, _hedf, ktyg_
  { {0xd7940029,0x2d5c02c1,0x212000bc,0x673a0144}},	//   _التخ, líes_, dkih_, pitj
  { {0x18670ea6,0x6ed8000b,0x23e4005e,0x3cfd000b}},	//   _тачи_, न्मु, ціюв, _रोने_
  { {0x27290092,0xa6fb000a,0x2d5c0077,0x6aa8153c}},	//   _súng_, _שִׂי, níes_, _medf
  { {0xa5080001,0x767b0008,0xba3c0007,0xf67b000a}},	//   _већа_, _בטוח, _neįm, _באומ
  { {0xc05b0191,0x115405d1,0x7ae32cc1,0x69c30012}},	// [5810] тів_, ікую, yent, zune
  { {0xff530029,0x34a7005d,0x64a7005d,0x6d5b0213}},	//   آخر_, _ख़ुद, _ख़ुश, _skua
  { {0xe2a70084,0x9e070010,0xddcb0089,0x7ae32cc2}},	//   íður_, шчал, řižk, vent
  { {0x0d840010,0x98ad005c,0x753d06e7,0xd0110067}},	//   ілін, mieć_, nisz, _فلج_
  { {0x4ea703ae,0x6aa82cc3,0x7ae3268d,0xdcfc003d}},	//   _врба, _bedf, tent, _atrē
  { {0x7ae302c1,0x8ccc005d,0xcb690015,0x99d50015}},	//   uent, _हाथो, دمته_, متبا
  { {0xd2b80008,0x6aa80026,0x753d00dc,0xc9f50015}},	//   בלות_, _dedf, kisz, إستع
  { {0x6d5b003f,0x7ae30901,0x69c32cc4,0x61fa0123}},	//   _ukua, sent, rune, åtli
  { {0x6d590050,0x17f90029,0x2bda0086,0x9b94005e}},	//   mowa, اربة_, _مالک_, _митц
  { {0x69c32cc5,0x62850026,0x6d5907e9,0x212000bc}},	//   pune, _ngho, lowa, zkih_
  { {0x9985003b,0x63a427fc,0x8506002b,0x5ee8000a}},	//   _الصو, _swin, مودن, בַרְ
  { {0x753d0014,0x6d592cc6,0x49750063,0x6b89003f}},	//   gisz, nowa, _улес, _kueg
  { {0xdcf50048,0x6b8902c1,0x04430010,0xb97a000a}},	//   _atzī, _jueg, зеян, _ענני
  { {0x6d59005c,0xe6950015,0xf6290015,0x179a000a}},	//   howa, _الغد, _مسعى_, _עיצב
  { {0x6d590050,0x6b890467,0x21200796,0x71660015}},	//   kowa, _lueg, tkih_, مارك
  { {0xc616000a,0x6d59002a,0x753d1022,0x63a42cc7}},	//   _לחצי_, jowa, cisz, _twin
  { {0x6d590050,0x612a002e,0x216714f4,0x13b60015}},	// [5820] dowa, _nýle, сити_, _اصبح
  { {0xbeaa0086,0x212001a3,0x6ae1000b,0x2fd20123}},	//   اهان_, skih_, फ़ोर, rtyg_
  { {0xc3330053,0x248d0156,0x1317000a,0x6d59002a}},	//   _מוז_, žeme_, _החיל_, fowa
  { {0x6d590050,0x6b810026,0xbc6a0018,0x365a004c}},	//   gowa, _ailg, همان_, אכענ
  { {0x6b810482,0x4c560029,0x455b004f,0x31330138}},	//   _bilg, حضار, נכנס, _хеўр
  { {0x270c000b,0x2fc00034,0x753d0e8c,0x9f96007c}},	//   ाउज़र_, mrig_, zisz, _müüt_
  { {0x6d59005c,0xbea30063,0x49b70067,0xdb022cc8}},	//   bowa, _хаск, مايد_, kroö
  { {0x3eaa0298,0x6d590050,0x6b8902c1,0x2bba0029}},	//   _hebt_, cowa, _fueg, _مائة_
  { {0xbb86002b,0x98ad002a,0x7e870030,0x753d06cd}},	//   _طلاي, zieć_, _árpá, visz
  { {0x95d8000d,0x753d005c,0x8afc005c,0x35b4245b}},	//   адот_, wisz, _chęt, обор
  { {0x753d0014,0x38c80086,0x9f4002c1,0x2f5b00f3}},	//   tisz, _ناشی_, lvió_, רדינ
  { {0x6ed8005d,0x38cb0086,0x55590010,0x3eaa00b8}},	//   न्तु, _ماهی_, рамя_, _lebt_
  { {0x6d430152,0x48e3000b,0x753d0e8c,0xc7b90030}},	//   énai, _फ़ोटो_, risz, szőr_
  { {0x6d590050,0xa5f82cc9,0x1877000a,0x2d980003}},	//   zowa, _веку_, _העדר_, _otre_
  { {0x6d59003f,0x798219f4,0x753d002a,0x6f152cca}},	//   yowa, _kiow, pisz, _rozc
  { {0x61fa002e,0x90992ccb,0xd904002b,0x2fc02ccc}},	//   ætla, рват_, ری_, frig_
  { {0xbe870029,0x3f150342,0x3ce600bc,0xe0d00015}},	// [5830] مجاو, одас, deov_, عزف_
  { {0x6d59005c,0x6b8904a5,0x6d4a2ccd,0x2d8a2cce}},	//   wowa, _rueg, éfan, _bube_
  { {0x6d590050,0xe7ea005d,0x61230020,0xf41f00f2}},	//   towa, _जैसा_, _hõlm, lyä_
  { {0x20c7000d,0x7188000a,0x6ae1000b,0x672100bc}},	//   _усог, _לְשַ, फ़्र, zklj
  { {0x6d590f9a,0x0c750086,0x14d8000a,0x6b812ccf}},	//   rowa, زگرد, מואל_, _pilg
  { {0x6d590050,0x6ed8000b,0xcb03000b,0x9f050015}},	//   sowa, न्दु, लाइड_, _بوسو
  { {0x6d59005c,0x672100bc,0x2d8a0085,0x8c3d0061}},	//   powa, vklj, _gube_, _keşk
  { {0xf41f00f2,0x6b8106ed,0xe9a80015,0x7d250015}},	//   kyä_, _wilg, حدون_, _بفرن
  { {0x6b812cd0,0x37750033,0x480501f3,0x2bb80015}},	//   _tilg, жынс, іпов, _هالة_
  { {0x3c440015,0x8f9c000a,0x2d9800cb,0x2caf0123}},	//   _عَلِ, איזי, _ytre_, lagd_
  { {0x61230005,0x5ee8000a,0xf625005e,0xa50a2cd1}},	//   _põll, זַרְ, ідмо, аена_
  { {0x27e00011,0x6721016f,0xd874002b,0xc8c8002b}},	//   _ţine_, sklj, _کامب, _هومن_
  { {0xe4570036,0x44240107,0x9cd6000a,0x43930033}},	//   жжя_, ám_, חורה_, маўс
  { {0x59dd005d,0x934600fd,0xe5a5076f,0x2fc02215}},	//   _महार, інве, _дики, vrig_
  { {0x63720134,0x63600030,0x613a00af,0x0000006a}},	//   hæng, dönt, ачар_,
  { {0x60260ea6,0x2fc02cd2,0x6123007c,0x15fa004f}},	//   одба, trig_, _hõlj, _כהצע
  { {0x78ab0014,0x2d8a0077,0x2fc00651,0x614315ec}},	// [5840] _megv, _sube_, urig_, фета
  { {0xe6b7005d,0xdfcf0806,0x42560015,0x91e60004}},	//   _आयोज, ئيل_, _ونظر, _доое
  { {0xee3a0001,0x216a0fea,0x7ccd0030,0x0caa006b}},	//   јне_, _вини_, zőrő, атли_
  { {0xdca30124,0xed5a0080,0xf48d000a,0xbc6601da}},	//   даци, шое_, ְאוּ, овек
  { {0x0b930029,0x63720134,0x0a94005e,0xdb0a013f}},	//   وجود, gæng, палю, žnít
  { {0x0efa0010,0x2d8a0493,0xada611ea,0x9f400077}},	//   _тэмы_, _tube_, _магл, rvió_
  { {0xdd920086,0xcebf0089,0x91ba000a,0xcce60015}},	//   _آور_, _úřad_, ׁמַי, _وسري
  { {0x257200dc,0xf1e2000b,0x481402b0,0x637202de}},	//   náld_, _पहनन, змис, lænd
  { {0xc1730008,0x2bd1005d,0xbaba0015,0x78ab003d}},	//   וחה_, _समया, _نداء_, _degv
  { {0x4b260029,0xf41f008c,0x661c04d1,0xea5a0054}},	//   _بعرف, vyä_, ørko, _креј_
  { {0x61230005,0x4b7b0008,0x2d8500dc,0x4af5002b}},	//   _sõlm, _כאמו, _élet_, _رکود_
  { {0xe4e70191,0xf41f00f2,0x2bb1000b,0x63600030}},	//   ціон, tyä_, ुंचा, zönt
  { {0x7d7b0008,0x4d7b0053,0x636000f2,0x7d04008c}},	//   ינטו, ירטע, yönt, öisy
  { {0x7c2f01e2,0x2b03000b,0x2d842cd3,0x98a30091}},	//   _ücre, लाएँ_, _lime_, ėją_
  { {0xd13b2cd4,0x217b0029,0x7bc20556,0xf41f00f2}},	//   аха_, لحرب_, hrou, syä_
  { {0x2d840020,0xbdfb002b,0xd49b0850,0x63600123}},	//   _nime_, یرضا_, _трк_, föns
  { {0x63600a64,0xc5740015,0x351c000a,0x61fe0079}},	// [5850] tönt, _تطوع, _כוהנ, _erpl
  { {0x2d840152,0xdef10015,0x1048005e,0x4ada000b}},	//   _aime_, عًا_, іяти_, _मॉलव
  { {0x8c3d19a0,0x0cd6000b,0x2729006f,0x88bd002a}},	//   _ieşi, ठभूम, _júna_, chśw
  { {0x6295005c,0x7bc20034,0xadbc01c6,0x2d842cd5}},	//   lczo, frou, рацi, _cime_
  { {0xb4fc0053,0xe53c000a,0x8c3d0061,0x6360001a}},	//   יפאי, סתדר, _keşi, pönt
  { {0xdefb008f,0x7dc70015,0x539c015b,0x78ab003d}},	//   _тым_, _وتأك, סיוו, _segv
  { {0x27290084,0x8a020063,0x4ea400ce,0xbd450058}},	//   _núna_, езще, _ірра, _فنسي
  { {0x637200fb,0xd9400033,0x60cd2cd6,0xdc3a0061}},	//   mæne, кцыi_, ngam, açır
  { {0xccf20008,0x853d0007,0x25720264,0xd90c002b}},	//   _אכן_, ipėd, nále_, شیو_
  { {0x2489002d,0x2cad00da,0x6615006f,0x9f40001a}},	//   _agam_, _heed_, äzko, nvið_
  { {0xf9f90074,0x636000dc,0x2d850030,0x20cb000b}},	//   _دفاع_, zöns, _éles_, िलाध
  { {0x691c0003,0x6295002a,0x6d4b2cd7,0xa3b70065}},	//   _dées, eczo, nnga, _चटख_
  { {0x68e90020,0x9d1a004c,0xad1a004c,0x8c3d0061}},	//   meed, צושט, צושר, _beşi
  { {0x39910084,0x25720089,0x987a0643,0x2cad158f}},	//   _kás_, dále_, _פאסט, _leed_
  { {0xc69200b2,0xd004005d,0x11d50010,0xcb12004c}},	//   _טאג_, रम्भ_, мітр, ײלן_
  { {0x55ba01c8,0x60cd00b6,0x752f005c,0x8c3d0064}},	//   _המקו, ggam, chcz, _teşh
  { {0x69c32cd8,0xc952000a,0x48dd000b,0x6372063b}},	// [5860] hrne, גמן_, क्यो_, tænd
  { {0x6d4b0849,0x93fb00a3,0xc3fb000a,0xc43b000a}},	//   enga, _פליי, _פליש, _לתפי
  { {0x39910156,0x44220177,0x0d862cd9,0xcc8a0015}},	//   _nás_, lyk_, член, مناه_
  { {0x637202de,0x6360001a,0x7bc22cda,0x27ed01d7}},	//   sænd, pöns, trou, kwen_
  { {0x8c3d0064,0x2cad05d6,0x9c5a0015,0x637202de}},	//   _yeşi, _deed_, حجاز_, pænd
  { {0x6b9b002f,0x3991002d,0x7bc20493,0x79a618dc}},	//   _dtug, _bás_, rrou, прие
  { {0x3991002d,0x2d842cdb,0xbb470015,0x2cad2cdc}},	//   _cás_, _time_, ثلون_, _feed_
  { {0x4422020a,0x691c0152,0x07980001,0x7bc20152}},	//   kyk_, _rées, овић_, prou
  { {0xba3c0007,0xb8d4000b,0xdcfc0091,0x8b36004a}},	//   _neįv, _जज_, _strė, _ена́_
  { {0x3991002d,0x8b8b0008,0x1037000f,0x6d4220e4}},	//   _fás_, _הָאֶ, פטים_, lioa
  { {0xba9b0008,0x39912cdd,0xf76f0015,0x60cd0061}},	//   _הסבי, _gás_, داي_, ygam
  { {0x68e9003e,0xdd860002,0x6d420045,0x7aea0085}},	//   ceed, ضو_, nioa, left
  { {0xf76f0074,0x645a15e4,0x6ecc000b,0x8c3d0061}},	//   ضای_, ştin, ालाँ, _peşi
  { {0x61230020,0xa87b0008,0xdce200bd,0x7aea0123}},	//   _tõlk, _האדר, dloč, neft
  { {0xe9ff0023,0xd6db0008,0x26db0008,0x6d4b0026}},	//   _phẩm_, _החול, _הקומ, ynga
  { {0x60cd0007,0xe1640054,0x61310c6b,0x257201c0}},	//   ugam, еђун, _målg, tále_
  { {0x94bc000a,0x61fc0085,0x69ca0012,0x2cad2cde}},	// [5870] _המחת, avrl, hufe, _reed_
  { {0x5187008f,0x2cad003e,0x2ef42cdf,0x2572013f}},	//   _нума, _seed_, нзур, rále_
  { {0xe9ff0092,0xadab0015,0x9757000a,0x2cad01c2}},	//   _thẩm_, صداق_, לימו_, _peed_
  { {0x69c300bd,0x6d420011,0x39910462,0xfe700015}},	//   vrne, gioa, _rás_, ادك_
  { {0x68e902c1,0x69d80024,0x69c30026,0x70fa000a}},	//   veed, etve, wrne, _והרח
  { {0x09e507c1,0xc6860015,0xfbd00015,0x69d82ce0}},	//   докн, _لِ_, طته_, ftve
  { {0x68e90005,0xdb0b002e,0x2cad0020,0xb2bc0008}},	//   teed, gsgá, _teed_, זמור
  { {0x6d420011,0x39910107,0x7b32002a,0x59cf000b}},	//   cioa, _vás_, słup, संबर
  { {0x68e91786,0x27ed0111,0xf0940053,0xa2ce005d}},	//   reed, uwen_, ענץ_, _ताल्
  { {0x7d1b003e,0x27ed2ce1,0xa3d7000b,0x9b740015}},	//   _hous, rwen_, _सहज_, _كالص
  { {0x69070010,0x8e960008,0x4ad2000b,0x68e904f6}},	//   _нядз, ודתו_, _सातव, peed
  { {0xc329039e,0xd46a0860,0x44222ce2,0x46380033}},	//   _דו_, жиме_, tyk_, ячыя_
  { {0xa9360008,0x395f2ce3,0x394d2ce4,0x7bd90028}},	//   _קטנה_, mous_, mnes_, ntwu
  { {0x2b49002d,0x395f2ce5,0x394d2ce6,0x987a000a}},	//   éach_, lous_, lnes_, _ואנט
  { {0x394d0467,0x7bcb002e,0x442208ce,0xa5460015}},	//   ones_, hugu, syk_, _يضعو
  { {0x95560029,0x7d1b00f2,0x395f0b77,0x752d2ce7}},	//   _تختا, _nous, nous_, _glaz
  { {0xdb0b0014,0x1eaa0029,0xa4460036,0xa0670b97}},	// [5880] zsgá, قاضي_, _інод, дата_
  { {0xe7e5014e,0xe9ff0023,0x98a30007,0x9f4b02b9}},	//   _कहना_, _nhắm_, ėję_, _uscì_
  { {0xbf9b0003,0x395f10fd,0x69d82ce8,0x7d1b2ce9}},	//   _prêc, kous_, xtve, _bous
  { {0x6da30001,0x2d9c003d,0x395f1e23,0xc213000a}},	//   тица, īve_, jous_, _סהר_
  { {0x6d4204f9,0x7d090046,0x394d2cea,0x7ec80030}},	//   rioa, _dnes, dnes_, gépü
  { {0x69d806f5,0x6d430152,0x394d2ceb,0x7d092cec}},	//   ttve, énar, enes_, _enes
  { {0xba3c0007,0x7bcb121a,0x386600d9,0x7aea2ced}},	//   _neįt, augu, _syor_, reft
  { {0x2ef80064,0x69ca08e9,0xa2be000b,0x395f00da}},	//   _harf_, rufe, वृत्, gous_
  { {0x6d402cee,0x9b930015,0x18670054,0x9cd7000a}},	//   _imma, _للقت, маћи_, _קומה_
  { {0x7d09018c,0x0077000a,0xba970015,0xa3cd000b}},	//   _znes, ותפי_, _ينقص_, शंस_
  { {0x645a0011,0x752d0c07,0x6f1c2cef,0xd6d701b0}},	//   ştil, _plaz, _morc, фты_
  { {0x65760026,0x7ada000b,0x2db7000a,0xc7a6004a}},	//   _chyh, प्रॅ, ולטן_, _жидк
  { {0x27320023,0x248d052c,0x6123007c,0xb97b004f}},	//   _nâng_, žemo_, _kõlv, _וראז
  { {0xd7a90086,0x57f30010,0x27e60035,0x8c3d0064}},	//   _ردهٔ_, _шпіт, _ipon_, _teşv
  { {0x92940010,0xe5e8008c,0x6d402cf0,0xc6d30015}},	//   тасц, ömää, _omma, _شتوت
  { {0x752d016f,0x55bb000a,0xcfab0015,0x39442cf1}},	//   _ulaz, _ומהו, قائم_, nims_
  { {0xdfd10015,0xa29501c6,0xb33b0144,0x51842b43}},	// [5890] طيا_, _папі, apça, тура
  { {0x2572002e,0x394d1164,0xce6b23e4,0x6d401bbf}},	//   mála_, znes_, оред_, _amma
  { {0x2ef800b8,0x257200dc,0x7d1b2cf2,0xd5b8003d}},	//   _darf_, lála_, _pous, nsā_
  { {0x63ad000c,0x6d5a002e,0xd5b8003d,0x867b000a}},	//   _kwan, _ítal, isā_, קראו
  { {0x7d09018c,0x409a01ac,0xbbeb0031,0x25720264}},	//   _vnes, _מברס, ترام_, nála_
  { {0x63ad000c,0xd5b80048,0x6f1c0b90,0x6d402070}},	//   _mwan, ksā_, _gorc, _emma
  { {0x394d0048,0x2572002f,0x7bcb2cf3,0xc334000a}},	//   tnes_, hála_, sugu, כוס_
  { {0x7d092cf4,0x8c3d0061,0x6b880c0c,0x21292cf5}},	//   _unes, _beşt, _eidg, nkah_
  { {0x8b67003b,0xd7e60080,0x395f1a89,0xb809002b}},	//   _قائم, емые_, rous_, سيدم_
  { {0x2572002d,0x21290375,0x395f0003,0x394d2cf6}},	//   dála_, hkah_, sous_, snes_
  { {0x63ad2cf7,0x4d79000a,0x99d40015,0x394d2cf8}},	//   _awan, ּרָע, _لتنا, pnes_
  { {0xaa5b0053,0xf9fa000a,0x661c060a,0x67b9006e}},	//   _װאָרט_, _מהעמ, ärka, _فاتح_
  { {0x782700e6,0x53fa0015,0xdcfc003d,0x63ad0034}},	//   _تعال, أرجح_, _strī, _cwan
  { {0x273204f9,0x68f90026,0x68fb0020,0x3d06000b}},	//   _când_, _hawd, ldud, _सोने_
  { {0xc7b90014,0x2ca60176,0x27320011,0x63ad005c}},	//   lső_, ybod_, _dând_, _ewan
  { {0xaadf005d,0x4f960036,0x52830029,0xe9ff0016}},	//   प्तक, ержу, الِك, _nhậm_
  { {0x63ad0026,0xd6d9000a,0xaf06005e,0x291d002a}},	// [58a0] _gwan, ּחֲל, нпал, _mowa_
  { {0x6292032c,0x27ff00f2,0x6f660015,0x27322cf9}},	//   ékoľ, ivun_, رهام, _gând_
  { {0xf1bf002c,0x82d70053,0xecea09ef,0x4ac90231}},	//   ýšte_, _אויג_, здел_, _राजव
  { {0x291d005c,0xe9ff0092,0x68f90026,0x3944027d}},	//   _nowa_, _chậm_, _nawd, xims_
  { {0xdb97008f,0x61230020,0x4af80080,0xba3c0091}},	//   евіч_, _põlv, делю_, _neįr
  { {0xdd92006e,0x68fb01c2,0x6ec50058,0x2ca60546}},	//   _موس_, edud, _لتفق, sbod_
  { {0x39442cfa,0x3958001a,0x68f900e7,0x6b8804d6}},	//   tims_, _írsk_, _bawd, _vidg
  { {0xdbd600f2,0x68fb0035,0x4ddb00f3,0x6d400375}},	//   _pääa, gdud, _מחלו, _umma
  { {0xc7b900dc,0x7791002b,0x18970015,0xd90d002b}},	//   gső_, لینا, رضية_, غیه_
  { {0x3f8a000c,0xccf9005c,0x8c3d0045,0x103b000a}},	//   _jibu_, _zaś_, _veşt, פגיע
  { {0x27320011,0x18a60608,0x1f37000a,0xdce90045}},	//   _rând_, _заем, גריר_, _înăb
  { {0x63ad003f,0x2572049a,0x7afa2cfb,0x3f8a02f2}},	//   _pwan, tála_, _hatt, _libu_
  { {0x7afa03c0,0x27e6003e,0x07a30010,0xa9250015}},	//   _katt, _upon_, _бачн, _جعله
  { {0x93880080,0xe7e5000b,0x68f9002a,0x25721549}},	//   есса_, _कहता_, _zawd, rála_
  { {0x31c40403,0x06970008,0x7afa153a,0x27320045}},	//   лств, _אדום_, _matt, _vând_
  { {0x7afa2ba0,0x35b3006b,0x8c3d0061,0xdb1e001a}},	//   _latt, _сбър, _meşr, _óvæn
  { {0xe4a8000f,0x63ad003f,0x40340180,0xb4ad000b}},	// [58b0] _אֹתָ, _uwan, гетс, गरी_
  { {0x238a002c,0xa857000a,0x2556003d,0x21292cfc}},	//   ľujú_, תימה_, māla_, skah_
  { {0x7e280010,0x238a002c,0x4439003d,0x8c3d0061}},	//   ніца_, žujú_, lzs_, _neşr
  { {0x865b000a,0xbe64002b,0xdd940033,0x7afa008c}},	//   הדבי, دهمي, уацы, _aatt
  { {0x25560024,0xb0b60008,0x7afa04a0,0xc058005e}},	//   nāla_, _בפרס_, _batt, _зір_
  { {0xbbd1014e,0x0c240010,0x29030024,0x2ea70086}},	//   _समीक, ымін, ējam_, _سپری_
  { {0x0dc80080,0xe9ff0092,0xbe650115,0x0f56000a}},	//   _пути_, _thậm_, _شهري, _יישם_
  { {0x09f60015,0x8d77002b,0x2556003d,0x7d16008c}},	//   ئفية_, _سازا, kāla_, öyst
  { {0x7afa0ede,0x290b0064,0x69ce02de,0x661c0123}},	//   _fatt, ıca_, _åben, ärkn
  { {0xbc680015,0x7afa2cfd,0x645a0061,0x44390030}},	//   _أمكن_, _gatt, ştik, dzs_
  { {0x64a62cfe,0x65c5006b,0xdb26002b,0xb6590248}},	//   кана, ъбна, _جولی, ьших_
  { {0xe894008f,0xda48000a,0xc7b90030,0x2fc900aa}},	//   _баць, _אֲנָ, pső_, krag_
  { {0x4cba000a,0x7afa0f0a,0x78a92cff,0xa3cd0065}},	//   וזרו, _yatt, mbev, शूल_
  { {0x03a326ca,0x2fc92d00,0xfbd2000a,0x7bc8000a}},	//   риро, drag_, בתך_, עֶרֶ
  { {0x3f8a0665,0xe1660021,0xe2972d01,0xa2be0065}},	//   _ribu_, ندري, тас_, वृष्
  { {0x78a90161,0x853d0091,0xa2ce0065,0xf992004f}},	//   nbev, lpėn, _ताक्, שרן_
  { {0xf8b200b2,0x54a50029,0x1f6626ca,0x21672d02}},	// [58c0] ישן_, _صحيف, вкам, тити_
  { {0x61230005,0xbea600ce,0x3715004f,0xafe302ed}},	//   _sõlt, тажк, כַ֣ל_, рофл
  { {0x4256049d,0x6123007c,0xba3c0091,0x78a900aa}},	//   _штит, _põlt, _neįp, kbev
  { {0x7afa2d03,0x361a000a,0xdfd2009a,0xddc30d3c}},	//   _satt, וועד, _پيس_, рбци
  { {0xe44d0008,0x7afa052a,0xd497000a,0x6123007c}},	//   ּתוֹ, _patt, דכנת_, _võlt
  { {0x70b2000b,0x7dc60015,0xc43b000a,0x69dc0123}},	//   _ज़ुल, _لترك, ותני, _ärek
  { {0x7afa2808,0x3cfd000b,0x99d30015,0x78a9042f}},	//   _vatt, _रोके_, لتيا, fbev
  { {0xacea0029,0x7afa20e3,0x1bea0b1e,0x78a92d04}},	//   _ترسل_, _watt, _одби_, gbev
  { {0x798b0176,0x2bc9005d,0x57b304f7,0x0d65004a}},	//   _digw, _रिया, абыт, _съём
  { {0xa2d7000b,0x17f70015,0xb7d9002b,0x61310bfd}},	//   _बाध्, ئرية_, روپا_, _måla
  { {0x99d30015,0x75d4006e,0x29d300c3,0x2d8c0030}},	//   _نقلت, ديجا, _نيلس, _édes_
  { {0xc4bf005d,0x25560024,0x7792002b,0xdccf0016}},	//   ्लेख, tāla_, _پیدا, hỉnh_
  { {0xd6d20074,0xe9ff0092,0x254f005c,0x443f0016}},	//   _نقش_, _thảm_, nęli_, àu_
  { {0x56930010,0x70cb000b,0x2d871279,0x7837000a}},	//   _кашт, िल्ल, ínez_, _שָׁב_
  { {0x442d2d05,0x96170015,0x32050046,0xe45f0123}},	//   še_, _لغير_, íly_, ggör_
  { {0x39980b4c,0x257900dc,0x30a40784,0x69ca1f22}},	//   _més_, féle_, ирув, irfe
  { {0xa0750001,0x254f002a,0xbf9b0003,0x2d9c0030}},	// [58d0] угач, jęli_, _grêl, íven_
  { {0xa2f50036,0x61f90010,0xb7db000a,0xd3a4006b}},	//   _споч, _зноў_, וקמי, _тръп
  { {0x39980003,0x63bd001a,0xe8df0016,0x656f2d06}},	//   _nés_, lssn, hiền_, olch
  { {0xf6530008,0x5d550138,0xccef00af,0x0000006a}},	//   בצע_, ыкет, ећa_,
  { {0x69ca0084,0xc05b0036,0x63bd00c0,0xfc300087}},	//   erfe, _цін_, nssn, يحه_
  { {0xab64008f,0x8f690058,0x0000006a,0x0000006a}},	//   авіл, _أمسك_,   ,
  { {0xa9691067,0xee8401b0,0xf991006e,0x2b4701ce}},	//   ника_, _выто, حبت_, rinc_
  { {0x645a0011,0xe9ff0092,0x6c850015,0x39980003}},	//   ştii, _chạm_, _ملزم, _dés_
  { {0x2b49002f,0x09020033,0x7e7a001a,0x78a92d07}},	//   éacs_, спын, _útpr, rbev
  { {0x656f0ecc,0x86c5002b,0xd6390033,0xa088000a}},	//   elch, ديدن, еямі_, כְתִ
  { {0x09e4005e,0x2729006f,0x78a90789,0x8f36000a}},	//   _воєн, _júni_, pbev, ראתו_
  { {0xaadf000b,0x799a004c,0xf992000a,0x7bcb2d08}},	//   प्रक, _טשעס, _הרא_, orgu
  { {0x290f01d1,0xc3d60010,0x44240092,0xe3b10029}},	//   _inga_, ыўны, âm_, ْرِ_
  { {0xcc3a00b2,0xdc3a0053,0xa3e5000b,0xd81a000a}},	//   געשט, געשר, _नहर_, _רֵאש
  { {0x11da0015,0x629c0688,0xb716004f,0x254f0535}},	//   عورة_, rcro, _תקצג_, zęli_
  { {0x25560048,0x2176000d,0xd24f0015,0x4159004a}},	//   mālo_, ѓувр, أنف_, вшую_
  { {0x6fb60015,0xf537004f,0xe29a066a,0x0000006a}},	// [58e0] امطا, _תרפז_, _пап_,
  { {0xd2aa0010,0x32460029,0x63a42d09,0xaad2000b}},	//   _якое_, _منخف, _itin, _साइक
  { {0x25560024,0x9858003d,0x6e46002b,0x32db000a}},	//   nālo_, iņām_, دنام, _אחינ
  { {0xac970074,0x61fa0084,0x721b0008,0x613100c0}},	//   هنما_, ætlu, _נוכח, _tåla
  { {0x77f2005d,0xa37b001c,0x6fb50010,0x60d60026}},	//   _अनेक_, stõe, _вёсц, mgym
  { {0x7bc40007,0x3998001c,0x63a4003f,0x290f2d0a}},	//   šiuo, _pés_, _mtin, _anga_
  { {0xe9ff0023,0xf2d30008,0x656f0026,0xa3d6005d}},	//   _phạm_, צעה_, ylch, ांड_
  { {0x39980251,0xa96700d7,0x98a30054,0x7e530021}},	//   _vés_, лија_, биће, _انفص
  { {0xfaa60361,0x47340459,0x981600c3,0x63a41992}},	//   _базо, инис, ابعا, _ntin
  { {0x4ff70053,0x58370080,0x290f002e,0xcff7000a}},	//   נזיע_, узья_, _enga_, נציה_
  { {0xca560124,0xaa9300a2,0x15150151,0x49ca121e}},	//   _стањ, _المث, адня, _член_
  { {0x9f49002e,0xa2d7000b,0x58960015,0x63a40144}},	//   hvað_, _बाह्, _إجاز, _btin
  { {0xbf9b001c,0xccf30008,0x78bd0052,0x3eba2d0b}},	//   _prêm, זכר_, ðsve, kapt_
  { {0x21270074,0x25720030,0x57fb000a,0xcb14000a}},	//   گيری_, nálj_, _נלוו, ׁלָ_
  { {0x2d9c03af,0xd49b0342,0x5bd1000b,0x9258096d}},	//   ível_, _прп_, _सम्व, гарт_
  { {0x7bcb001a,0xc446002b,0xc177012c,0x74150058}},	//   yrgu, ایین_, ادست, _نوبا
  { {0x3ecb0001,0xbf9b016e,0x4ea7011e,0xdfd50138}},	// [58f0] ећем_, _trêm, греа, розы
  { {0x543c0053,0x29030024,0xdb210061,0x63600030}},	//   _רעזא, ējai_, ütüp, köny
  { {0x9e070033,0x628801c0,0x4cb9005e,0x3e550058}},	//   ычал, ždor, влею_, جَاز
  { {0x621a000a,0x1ad2000b,0x0000006a,0x0000006a}},	//   _סורק, _साउथ,   ,
  { {0x8d740029,0x00ba009d,0x6e95005e,0x7bcb0061}},	//   حالا, _שמשמ, _вигу, urgu
  { {0xa3d6005d,0xc9f50015,0xeb960477,0x25720030}},	//   ांत_, لسبع, шиш_, gálj_
  { {0x52d8004c,0x19f90033,0x7f580004,0x2bd1000b}},	//   אווע_, тэль_, _сарс_, _समका
  { {0x6bd70015,0x1a68002b,0xa9252374,0x61310295}},	//   _متطر, دیمی_, рдил, _målo
  { {0x64c80007,0x6d4b2d0c,0xead508f0,0x25720030}},	//   nčių, miga, _возь, bálj_
  { {0x5745078f,0xe9ff0092,0x636000dc,0xd706004a}},	//   рноб, _nhầm_, sönz, анье_
  { {0xbb840029,0x91780092,0x656606e7,0xa92b005e}},	//   _اللي, _lớn_, tokh, _піде_
  { {0xa4f80086,0x69330086,0x399a00a3,0xe9d000e5}},	//   اکثر_, _دکتر, _סינד, _رغم_
  { {0xf9880015,0x7c2b0034,0x97a70054,0xe72e0a3f}},	//   _إنني_, nygr, _срел, _де_
  { {0x656600dc,0x883a000a,0x6138002d,0x46a500d7}},	//   sokh, _בתנו, _míle, _такв
  { {0x51860029,0xa2d7000b,0x65660030,0x99e9004f}},	//   لشرق, _बार्, pokh, כַּ֥
  { {0x10a60229,0x057a0015,0x6d4b2d0d,0xa0a61186}},	//   риан, _جمعة_, jiga, раад
  { {0xdfa50029,0x6d4b2d0e,0x67232d0f,0x69dc007c}},	// [5900] محلي, diga, _konj, _ärev
  { {0x613101d1,0xdfcf0015,0x3f8e001a,0xd47b000a}},	//   _håll, بيك_, öfu_, _באפל
  { {0x46dd000b,0x67232d10,0x9dba0033,0x75242d11}},	//   _मानह, _monj, тызу_, _koiz
  { {0xb64c00b2,0x4d66008f,0xd6560008,0x4d4a006b}},	//   עגאָ, шкев, ביעת_, ъпен_
  { {0x61380089,0x5f760086,0x2ca902c1,0x7d060030}},	//   _cíle, _ناآر, ñada_, jérő
  { {0xf7670029,0x05c5000b,0x61380046,0xf9c60fea}},	//   _ذا_, _विंब, _díle, ащин
  { {0x6d4b025c,0xab270001,0xd90d002b,0xda660015}},	//   biga, роја_, کین_, جاشي
  { {0x99830015,0x7c2b0034,0x6b830123,0x6d4b2d12}},	//   يلوو, bygr, amng, ciga
  { {0x67230152,0x69c10064,0xa2d7000b,0x14a7000b}},	//   _bonj, _evle, _बाल्, _क्षण
  { {0xf1bf002c,0x7d0213d4,0xdcfc003d,0x8ab8000a}},	//   žšie_, ldos, _turē, _תֶּח
  { {0x3eb80014,0x8b3b0008,0x67232d13,0x8e97000a}},	//   _mert_, _שתבצ, _donj, ידיו_
  { {0xe8df0092,0x37e60010,0x35471310,0x7d022d14}},	//   riển_, _водг, рхов, ndos
  { {0xb7960001,0xc5580036,0x493b000a,0x2d981104}},	//   _трећ, рияє_, _בגאו, _lure_
  { {0x613106f5,0x7d0200f2,0xa5d7002b,0x6d4b2d15}},	//   _pålo, hdos, دبیر_, ziga
  { {0x35f70029,0xda09000b,0xb77b000a,0x637b0045}},	//   _نريد_, वियत_, _שאוש, eînc
  { {0x44b500d7,0x6848003d,0x7d002d16,0x8637000a}},	//   _убис, pīdī, _nams, _כרוב_
  { {0xcebb0001,0x656d003f,0xe9ff0016,0x7ff40015}},	// [5910] вље_, _ikah, _thầm_, يسكا
  { {0x2d98000c,0x6d4b2d17,0x4fc40010,0x7d0224f8}},	//   _bure_, wiga, ўста, edos
  { {0x2bc9005d,0xfe700086,0x6d4b2d18,0x645a0045}},	//   _रिहा, ودم_, tiga, ştit
  { {0xe1f00074,0x7d060030,0x2d982d19,0x7d000702}},	//   _کسی_, yérő, _dure_, _cams
  { {0x6d4b2d1a,0xf092000a,0xd114000b,0x90e6002b}},	//   riga, _מנכ_, डारण_, _اسپن
  { {0x3eb80084,0x3da70083,0x0b4400fd,0x6d4b271a}},	//   _gert_, _враб, онін, siga
  { {0xdef80010,0x6d4b003f,0x9e15005e,0x2bc9000b}},	//   _тыя_, piga, _удві, _रिवा
  { {0x7d0600dc,0x853d0007,0xe9a80015,0x637202de}},	//   térő, spėj, جدون_, tænk
  { {0x3ea1091f,0x6d492d1b,0xb8ff000b,0x6bd40015}},	//   ocht_, _imea, _ता_, _وتكر
  { {0xa3d6005d,0x2572234c,0xaea50033,0x637202de}},	//   ांस_, máli_, агiч, rænk
  { {0x7524018c,0x3ea1018b,0x1e3a0053,0x7d0600dc}},	//   _poiz, icht_, ָגרא, sérő
  { {0xc32901c8,0xb895003b,0xe9ff0092,0x2fc01f8d}},	//   _או_, _الإع, _chấm_, ysig_
  { {0x3f99003f,0x394d2d1c,0xc448002b,0x691c0003}},	//   _nusu_, mies_, شیدن_, _réex
  { {0xc4830010,0x673a0ec2,0x394d2d1d,0x3f9106c0}},	//   яляк, chtj, lies_, _nizu_
  { {0x2bd1000b,0x43432d1e,0x6d410091,0x2fc00034}},	//   _समझा, черв, _įlan, wsig_
  { {0x3f4f0024,0x9743002a,0x394d2d1f,0x3eb82d20}},	//   kļus_, śćdz, nies_, _sert_
  { {0x4e96003b,0xf3f10023,0x2d98003e,0x600a0010}},	// [5920] مشار, ặc_, _sure_, ынам_
  { {0x6d49001c,0x2fc000dd,0x99870089,0xdee3009c}},	//   _amea, rsig_, kynů_, зофи
  { {0x6e930029,0xddb60029,0x1dda0015,0x63b60034}},	//   ألما, صحاب, طباع_, _hwyn
  { {0x3ea1002f,0x3eb800b8,0x661c0020,0x61fe016f}},	//   acht_, _wert_, ärki, _ispl
  { {0x5cb70010,0xac180001,0x394d2d21,0xe607002b}},	//   сліў_, ролу_, dies_, _کش_
  { {0x63b60176,0x8fa30063,0xcb67006b,0x21200796}},	//   _mwyn, _харе, баче_, ljih_
  { {0x79a3008f,0xc333000a,0x212006c0,0x8f37000a}},	//   прые, הוג_, ojih_, _פאלו_
  { {0x21200796,0x394d2d22,0xc213000a,0xfce32658}},	//   njih_, gies_, להו_, _носо
  { {0x8d4b0008,0x98a30001,0x78bd001a,0x4c9b000a}},	//   _עֲלֵ, чиње, ðsva, _תשמע
  { {0x19ba0191,0xef11000a,0x5c37000a,0x6ffb004c}},	//   _будь_, ֵּי_, _הרמן_, נפיג
  { {0xb9960029,0xceb3000a,0x394d2d23,0xd94612d9}},	//   _الصب, הית_, bies_, _лежи
  { {0x63b60026,0x394d2d24,0x5e77000a,0x7bc20046}},	//   _bwyn, cies_, מתין_, osou
  { {0xb97b0053,0x29030024,0xdb09002e,0x7d7b0008}},	//   _ענדי, ējat_, _kveð, טרטג
  { {0x63b60034,0x16340138,0x29040072,0x6aba0103}},	//   _dwyn, _меля, ldma_, _jetf
  { {0x5a9b0053,0x315b0029,0x95ca0010,0xa6c700a2}},	//   רשלא, هجرة_, _сула_, _طويل_
  { {0xa3d6005d,0x63b60026,0x29042d25,0x2bc9000b}},	//   ांश_, _fwyn, ndma_, _रिला
  { {0x645a0482,0x63b60176,0x6018006b,0x61fe2d26}},	// [5930] ştir, _gwyn, ботя_, _espl
  { {0x3ea100b8,0xff530029,0x6aba0ab5,0x799a0a99}},	//   ucht_, أخر_, _netf, _outw
  { {0x2ca902c1,0x212000bc,0x8c950033,0x5e59006e}},	//   ñado_, bjih_, орлі, جلاس_
  { {0x3ea100b8,0xfce50036,0x61312d27,0x200b0085}},	//   scht_, іоло, _målk, _trci_
  { {0xed580036,0xeab902c8,0x5bcb0054,0x394d2d28}},	//   щої_, айл_, ућег_, vies_
  { {0x447c0053,0xc9a90175,0x2cbd0034,0x3b090432}},	//   אנדע, авке_, sawd_, реко_
  { {0xf2d40053,0x394d2d29,0x291f008c,0x4da9000a}},	//   לעס_, ties_, tjua_, _כֹּ֣
  { {0x6d49003f,0x321e008c,0x5d540cab,0x25720030}},	//   _umea, ätyi_, _екст, páli_
  { {0xf719008f,0xe8df0092,0x394d0c90,0x88c40015}},	//   аіны_, hiện_, ries_, ستيل
  { {0x394d2d2a,0x25560024,0x6d5a002e,0xa6990001}},	//   sies_, māli_, _ítar, шњих_
  { {0xab840010,0x63b60034,0x394d2d2b,0xf409000a}},	//   _хутк, _swyn, pies_, _שפ_
  { {0x29030048,0x63b60026,0x6b9b007c,0x6d590012}},	//   ējas_, _pwyn, _kuug, nnwa
  { {0x25560024,0xaae0000b,0x37ab0ac9,0x947a0432}},	//   nāli_, _नामक, _стен_, рсну_
  { {0xf6290015,0xcb9a004c,0x6b9b007c,0x68e92d2c}},	//   _نسعى_, יסשט, _muug, lfed
  { {0xcb12011f,0x212000bd,0x320c0046,0x0219005e}},	//   ולם_, tjih_, ídy_, біть_
  { {0x6138002e,0x25560024,0x00e60033,0xb5b6000a}},	//   _bíla, kāli_, ўжан, _ולקח_
  { {0xfe7800df,0x212000bd,0x25a00089,0x28dc000b}},	// [5940] _šį_, rjih_, _čili_, _यासि
  { {0xef170a47,0x4910005d,0x67210085,0x6d592d2d}},	//   ому_, _दोनो_, njlj, enwa
  { {0xe4d30086,0x2009003d,0x273b0003,0x6aba02de}},	//   _عقید, avai_, _gêne_, _retf
  { {0xa06a0001,0x859c000a,0xf652000a,0xc27b000a}},	//   _вама_, אשׁו, וצב_, _כריי
  { {0x68e90026,0x7c830850,0x6fc7000b,0x2d8600aa}},	//   dfed, муше, _लिएं, rmoe_
  { {0xaff900b2,0xa01b0030,0x39a606b3,0x3ed8000a}},	//   _פּרי, _szög, ошив, _לַֽא
  { {0xbb470015,0x7bc21873,0xdca6006b,0x68e92d2e}},	//   تلون_, ssou, _мави, ffed
  { {0x63a90011,0x2007005c,0x2bd2000b,0xf9870015}},	//   ţeni, łnie_, _सिपा, ينوي_
  { {0xd83a0010,0x2902002c,0x25720107,0x69c32d2f}},	//   рэй_, ľka_, nálu_, asne
  { {0xf7720115,0x8c170015,0x6a1600c3,0xbf9b0003}},	//   باع_, _بيكر_, _وبار, _trêv
  { {0x7e9b0008,0xff7b0053,0x65190002,0xa5f8005e}},	//   יסיו, שטימ, مقدس_, щену_
  { {0x20090091,0x2572005a,0x0000006a,0x0000006a}},	//   yvai_, kálu_,   ,
  { {0x26350023,0x69330010,0xf993000a,0x2bd2000b}},	//   áo_, _іншу, _חרף_, _सिफा
  { {0xdcfc00df,0x69d8038d,0x7aea0012,0x99510091}},	//   _turė, ouve, nfft, _išš_
  { {0x92942d30,0xf5b300c3,0xa294005e,0x05770015}},	//   дарц, _قصيد, дарі, _واعد
  { {0x90990063,0xd4b9004a,0xa2d7000b,0x6138001a}},	//   сват_, _улиц_, _बाक्, _píla
  { {0xe57200b2,0x2602005d,0x03b70015,0x7fb90015}},	// [5950] _אַז_, षिकी_, _بإعد, صهار_
  { {0x61310595,0x6d5900da,0x62d90033,0x69d801be}},	//   _måli, wnwa, _умоў_, kuve
  { {0x68e90026,0xfeb80029,0x20090007,0xbf9b0003}},	//   yfed, زالت_, svai_, _arêt
  { {0xc4f80053,0x2556003d,0x61d6000a,0x9ccb0138}},	//   ַזוי_, tāli_, _צורף_, рыжа_
  { {0x69c30026,0xeb9903a9,0x69d80003,0xbf9b0003}},	//   wsne, щил_, euve, _crêt
  { {0x257200dc,0x73fc0008,0xe7b70024,0xf3fc000a}},	//   lált_, שּׁו, ūtīš, שִׁל
  { {0x69c32860,0xd2b8000a,0xdcf70015,0xfe57002b}},	//   usne, חלות_, _وأرب, _بیاب_
  { {0x257200dc,0x98dd0033,0xc9840015,0x79821209}},	//   nált_, ускi, وشيي, _chow
  { {0x1bd50080,0x2bd2000b,0xc174000a,0x6716000b}},	//   _хозя, _सिया, וחק_, तांक_
  { {0x613100c0,0x28ab000b,0x1e95000a,0x7af800bc}},	//   _dåli, _ट्रि, ּכֹל_, cevt
  { {0xb9e70036,0x69070010,0x915e0016,0x25720030}},	//   _фізи, _мядз, hắn_, kált_
  { {0xf3f10092,0x46380010,0xda7a000a,0x99d4002b}},	//   ặn_, ючыя_, _הנער, _آتلا
  { {0x889a0008,0xc952000a,0x897a000a,0x9cd6000a}},	//   _הבני, _אמא_, _פרנצ, הורה_
  { {0x443e005c,0x0339005e,0x6b56004f,0x765d02ad}},	//   ąt_, оїсь_, ֜ישׁ_, ßsys
  { {0x798900da,0x76ba000a,0x61380046,0x661c0b14}},	//   omew, _המצפ, _díln, ärkt
  { {0x25aa0077,0x25721fc2,0x613100cb,0x25a80015}},	//   íble_, gált_, _målw, _بدوي_
  { {0xe53b000a,0x69d80012,0x04db000a,0x915e00a1}},	// [5960] _לתקר, zuve, _הקפל, gắn_
  { {0xdfcf03c4,0xf413000a,0x4f65002b,0xbf9b0003}},	//   ايل_, _נפת_, والف, _rrêt
  { {0xe29b0008,0xd29b000a,0x429b000a,0x2d9c0003}},	//   _לשיר, _לשיט, _לסיב, êve_
  { {0xbf9b0152,0xdd8f00a2,0x25722d31,0xdca32925}},	//   _prêt, هول_, máls_, еаци
  { {0x79820176,0x62830089,0xc50d004c,0x30761377}},	//   _rhow, _únor, ילאָ, _хунс
  { {0x79822d32,0x69d80024,0x25560024,0x637202de}},	//   _show, tuve, mālu_, mæns
  { {0x7d7a0086,0x1d0a01e1,0x7aea02ad,0x79820416}},	//   _همسر_, _леви_, rfft, _phow
  { {0x69d800c0,0x6e930015,0xd90e002b,0xac9a0015}},	//   ruve, _ألفا, طیت_, _طنطا_
  { {0x25560024,0x7af800bc,0xda0a002b,0x69d82d33}},	//   nālu_, pevt, _گياه_, suve
  { {0x9b4606e4,0x257200dc,0x290a005c,0x6b6604ab}},	//   _عناو, zált_, śba_, _экза
  { {0x7ec700dc,0xa4d5017f,0x2572001a,0x24f901b0}},	//   lépí, моні, jáls_, онны_
  { {0x4a7b00b2,0x8e570053,0xa99b000a,0xda650015}},	//   _פראב, לייג_, _הבאר, _غالي
  { {0x257200dc,0xe26e005a,0x0000006a,0x0000006a}},	//   vált_, éčné_,   ,
  { {0x3817000a,0xd7fb000a,0x61380046,0x661c2d34}},	//   _מקדם_, _להדל, _bílo, ärks
  { {0x61382d35,0xbb77000a,0xd5b70033,0x25720030}},	//   _cílo, פעלו_, _есы_, tált_
  { {0xdce90024,0xd677000a,0x92581377,0x365b004f}},	//   _okeā, _מתוק_, част_, _לכונ
  { {0x257200dc,0xb4d9021e,0x656f1212,0xe51a000b}},	// [5970] rált_, ाली_, moch, धारि_
  { {0xb3bc000a,0xc43c000a,0xd24e002b,0x656f2d36}},	//   _המזכ, _לתחי, اچی_, loch
  { {0x200201e2,0x321e008c,0xf2d2015b,0x7ec70030}},	//   _eski_, ätyt_, _בעי_, eépí
  { {0x656f2d37,0x0000006a,0x0000006a,0x0000006a}},	//   noch,   ,   ,
  { {0x22070089,0x69c802d2,0xc172002b,0x656f2d38}},	//   bíhá_, _avde, _شگفت, ioch
  { {0x63ad0f4d,0x212b00b8,0xddca0011,0x4c840033}},	//   _mtan, _hoch_, _înşt, хлів
  { {0x1989006d,0x2bc9000b,0xa3df000b,0xe9a9002b}},	//   обки_, _रिका, दंड_, زگان_
  { {0xf1c00089,0x26de0024,0xe218000a,0xce94006b}},	//   ýšit_, egto_, לקוח_, _часъ
  { {0xf6d50036,0x1bd40142,0x212b0034,0x69c80061}},	//   міня, _потя, _moch_, _evde
  { {0x2bd2000b,0xfbd2000b,0x7c3600cb,0x6f0702d8}},	//   _सिता, _सितम, øyre, _jajc
  { {0x7a350029,0xb4d9000b,0xb51a000b,0x63ad2d39}},	//   _تفاص, ालू_, धालय_, _atan
  { {0x212b018b,0x957d0091,0xb8090015,0x0000006a}},	//   _noch_, ltąj, _ويضم_,
  { {0xad1a013a,0x69ce0123,0xa2b20065,0x0000006a}},	//   קושר, _åber, _अभद्,
  { {0x6f071b84,0xf7940033,0x68fb233f,0xf79a004f}},	//   _najc, _зачэ, leud, _ובסמ
  { {0xfd640092,0x249f003d,0x656f2d3a,0xe2972d3b}},	//   _chuộ, žuma_, boch, дар_
  { {0x212b0026,0x55ba0008,0x25560024,0xc6920008}},	//   _coch_, _ומקו, tālu_, _באו_
  { {0xa4940074,0x212b08e1,0xc952000a,0x853d0091}},	// [5980] _سیست, _doch_, דמן_, rpėt
  { {0x63860010,0x63720134,0x42760086,0x8e3a0015}},	//   _ігна, ræns, _يادآ, يسار_
  { {0x68fb022d,0xa3d6005d,0x831b0053,0x7bc90152}},	//   keud, ांक_, _וויז, _aveu
  { {0x2007005c,0x212b0026,0x6372001a,0x7ec70030}},	//   łnia_, _goch_, pæns, tépí
  { {0x749b0008,0xe0fb000a,0x0b8a0162,0x2cbf0034}},	//   קיספ, _ולכל, оски_, _deud_
  { {0x8f750010,0x656f2d3c,0x60c42d3d,0x2d9c0030}},	//   _зусі, zoch, laim, íves_
  { {0x25560024,0x656f003f,0xaa5700e6,0x62980057}},	//   nāls_, yoch, ولها_, _úvod
  { {0x68fb0134,0x60c401b3,0xa37b007c,0x6f07036d}},	//   geud, naim, atõh, _zajc
  { {0xc173000a,0x656f2d3e,0x0000006a,0x0000006a}},	//   כחה_, voch,   ,
  { {0x6446005c,0xc9f60029,0xd7870015,0x2556003d}},	//   dzki, _يساع, ونيو_, kāls_
  { {0xd5b70139,0x8b8b000f,0xba9b000a,0xcb8b000a}},	//   мся_, _וָאֶ, _וסבי, _וְאֹ
  { {0xb4d9005d,0x60c42d3f,0xa925013f,0x68fb01d0}},	//   ाले_, jaim, tožň, ceud
  { {0x87260029,0xf76f0086,0x57b30484,0xa3d6000b}},	//   _يعتم, طای_, _абіт, ांग_
  { {0xf64f0086,0xc87f0012,0x656f2d40,0xa87b004f}},	//   ائی_, üße_, soch, _ואדר
  { {0x4394268f,0xc8080016,0x31c40054,0x60c401a8}},	//   тарс, _hở_, кств, faim
  { {0x60c42d41,0x5214006b,0x0000006a,0x0000006a}},	//   gaim, ъдст,   ,
  { {0xe811005d,0x83670015,0xbfd9005e,0x0574002b}},	// [5990] ़िया_, _يدخل, ядає_, _جاود
  { {0x63ad0048,0xc8080023,0xfd640023,0xf5aa000a}},	//   ķinā, _mở_, _thuộ, ַבְּ
  { {0x212b0111,0x7bc9016f,0x61310123,0xc8080016}},	//   _toch_, _sveu, _sålu, _lở_
  { {0x27ff0026,0xd657000a,0x71f8002b,0xdb0b0052}},	//   ywun_, ויבת_, _کریس_, nsgö
  { {0x68ed0077,0xc8080016,0xbb75006b,0x3981001a}},	//   _ñadi, _nở_, нукъ, jósa_
  { {0xfbd004b6,0xc6860015,0x6b650033,0x2cbf0034}},	//   شته_, _مِ_, экла, _weud_
  { {0x69950e3f,0x18a5008b,0x68fb005b,0x0000006a}},	//   нрих, найм, teud,
  { {0x6d4209e6,0x2572002e,0x8298000a,0xad19000a}},	//   choa, jálp_, ודוס_, _צוּר
  { {0x69dc0293,0x2bc9000b,0x7b08008c,0x29190061}},	//   _åren, _रिटा, östä, ısa_
  { {0xc8080016,0x68fb2d42,0x7c842d43,0xdb190012}},	//   _dở_, seud, _русе, uswä
  { {0x65c50010,0x68fb00f2,0xd5ae002b,0x6a9a004c}},	//   эбна, peud, یفی_, _זשענ
  { {0xd46a023e,0x0446004a,0x3a36004c,0xdb0a0030}},	//   зиме_, еемн, _ארעם_, önös
  { {0x8afc002a,0x395f2d44,0x7d092d45,0x60c42d46}},	//   _ujęc, mnus_, _maes, vaim
  { {0xa856013a,0x4393008f,0x1836000a,0x2556003d}},	//   _אינה_, лаўс, _ראסל_, tāls_
  { {0x64462c23,0x60c42d47,0x6383029f,0x395f2d48}},	//   szki, taim, угра, onus_
  { {0x2000003f,0x395f2d49,0x78a92245,0x6faa008b}},	//   twii_, nnus_, ncev, зваг_
  { {0x87ac0053,0xf8b20053,0x78a904ed,0x016301e3}},	// [59a0] ַשאַ, טשן_, icev, укто
  { {0x61310123,0x60c42d4a,0x26c52d4b,0xc6b9004f}},	//   _sålt, saim, nalo_, לֶ֣כ
  { {0xdddc0046,0xdb0900aa,0x8f75005e,0x60c42d4c}},	//   _vzrů, _ateï, туті, paim
  { {0xfd760086,0x9f400251,0xad660015,0xcbe60eaf}},	//   رداخ, stià_, راضه, ецки
  { {0x3f9801c2,0x26c52d4d,0xc4d3004f,0xe5210065}},	//   _tiru_, kalo_, רגד_, याति_
  { {0x23a6002c,0xee3a0054,0x26c52d4e,0xc8080016}},	//   _môj_, _енг_, jalo_, _rở_
  { {0xc8080023,0xbda50029,0x2bd2000b,0x6f630004}},	//   _sở_, _لحقو, _सिवा, _сврз
  { {0x6564060b,0xfbc9000b,0x395f2d4f,0x7d1b0160}},	//   _njih, _रिचम, gnus_, _gnus
  { {0x6d400c8d,0x9a6a0086,0xb6e6006b,0x6d580003}},	//   _ilma, _کمال_, нюнк, évau
  { {0xc8080016,0x78a902b9,0x6369006f,0x47342ae4}},	//   _vở_, acev, oľne, тнос
  { {0x0f57013a,0x613102e9,0xf5210484,0xdb0b001a}},	//   תיים_, _målr, аннi_, tsgö
  { {0x9a3b000a,0xc8b60015,0x0e5b000a,0x07a60b44}},	//   _מתבק, _أصاب, לדיב, _задн
  { {0x295700b2,0x26c52d50,0x18330015,0x18a7000a}},	//   _אסאך_, balo_, _مروح, _א֣וֹ_
  { {0xdb0000c0,0x69d82d51,0x26c52d52,0x1dd10065}},	//   _utmä, orve, calo_, _हिलत
  { {0x6d400482,0x6b9a018b,0x8237002b,0x92681c31}},	//   _olma, _mitg, ررسا, ерта_
  { {0xab66005c,0x867b0008,0xf67b000a,0x84390015}},	//   leżą, _מרוו, _מאומ, _يكثر_
  { {0xdfd4004a,0xdfd10021,0xd4680054,0x14d8000a}},	// [59b0] лоты, شيا_, _пиће_, _נוזל_
  { {0x7d090176,0x7bcd00df,0xa3d6000b,0x6d402d53}},	//   _saes, šauk, _हित_, _alma
  { {0x7d0902d7,0xab66005c,0x2455002b,0xdd950033}},	//   _paes, ieżą, _سنگس, важы
  { {0x628500bd,0x7c590115,0x8c590015,0xa3d6000b}},	//   _izho, ولار_, ولاء_, ांच_
  { {0x7d090020,0xe4ac000a,0x75f60061,0xaf370015}},	//   _vaes, הֹוָ, _yüzö, _كرست
  { {0xdf470010,0xadbd0033,0x657d0012,0x395f0034}},	//   _чэмп, _магi, hlsh, wnus_
  { {0xbca50029,0x314b000a,0xf9890015,0x78a90045}},	//   _لمزي, ּתִּ, ونتي_, tcev
  { {0x7d1b0100,0xdd910015,0x1a68002b,0xf9910015}},	//   _unus, _ضوء_, رینی_, جبت_
  { {0xfbd00086,0x78a92d54,0x47c201b0,0xfce80015}},	//   _هتل_, rcev, абыв, _سفلي_
  { {0x9783002b,0x78a902b9,0xdb000144,0xfbc7002b}},	//   دیته, scev, _numè, یت_
  { {0x9665005e,0x99d400e5,0x2a390015,0x69d80085}},	//   ткне, _متنا, _تكاد_, crve
  { {0xf09f0016,0x53a60033,0xe852002b,0x03a61d9e}},	//   _ngà_, камб, انید, кимо
  { {0x263c0092,0x25b6002b,0x7bcb2d55,0x21292d56}},	//   ảo_, _یهود_, nsgu, djah_
  { {0x27ed2d57,0xc7d6039e,0x43752d58,0x7bda004f}},	//   mten_, _יוני_, густ, וקשו
  { {0x27ed195d,0x11da0015,0xe796002b,0xf675004c}},	//   lten_, ظورة_, _شاهک, _בײַט_
  { {0xf8b3005d,0x867a000a,0x290d1539,0xb05b0012}},	//   ीरिय, _קרקו, ndea_, _adäq
  { {0x27ed2d59,0x290d2d5a,0xc5090058,0xdb0912cf}},	// [59c0] nten_, idea_, _ستيل_, _ateí
  { {0x127a0029,0x27ed2d5b,0x61380125,0xdfcf012c}},	//   _يحدث_, iten_, _míli, زيم_
  { {0x200d0048,0x333b0008,0xee150010,0x27ed2d5c}},	//   _šeit_, _חתימ, льцэ, hten_
  { {0x63a42018,0x9e750001,0x6dac0061,0x6b9a0144}},	//   _kuin, ућуј, _ağac, _sitg
  { {0x6b9a0144,0x61380125,0x27ed2d5d,0xead42d5e}},	//   _pitg, _níli, jten_, голь
  { {0x680f00dc,0x290d0011,0xe453000a,0x49ba0015}},	//   ződö, edea_, סֶף_, واعد_
  { {0xf2d30008,0x394400da,0x27ed2d5f,0x9e76012c}},	//   בעו_, thms_, eten_, _شهرت
  { {0x9e4b0008,0x27ed2d60,0x38c8002b,0x69d82d61}},	//   _חֲמִ, ften_, رابی_, rrve
  { {0xd7c70074,0x27ed2d62,0x61380089,0x1be7004a}},	//   نويه_, gten_, _cíli, _идти_
  { {0x6b9a09f2,0x77910086,0xcdd40008,0x7792002b}},	//   _uitg, مینا, ְךָ_, جیتا
  { {0xdb002d63,0x2cad0026,0x27ed2d64,0x680f0030}},	//   _numé, _yfed_, aten_, tődö
  { {0xa9270007,0x27ed059b,0xca37000a,0xaa37004c}},	//   gužė, bten_, _שנאה_, _שטאק_
  { {0x27ed2d65,0x0ee2005d,0x63a4108c,0x67d402b0}},	//   cten_, _पांड, _cuin, _солу
  { {0x63a4002f,0x9f4000f2,0x4614002b,0xf76f006e}},	//   _duin, ntiä_, _موتر, _واو_
  { {0x671f000b,0xe6780033,0x1a78004f,0xf1a4144a}},	//   बारक_, _яйкі_, גְּמ, иртн
  { {0x63a4002f,0x628500bd,0xc56b0015,0x9f40008c}},	//   _fuin, _vzho, _تحتل_, htiä_
  { {0x4034005f,0xc05b0036,0x61ee0728,0x2129172e}},	// [59d0] аетс, фів_, atbl, rjah_
  { {0xdb000003,0x02b7000b,0xc7d7000a,0x2ee70012}},	//   _fumé, _अभिभ, כומי_, ünf_
  { {0xb05b00b8,0xc3320008,0x27ed00b8,0xa3df000b}},	//   _geän, _הוי_, zten_, दूर_
  { {0x753d0014,0xc5f304dc,0x44390326,0x27ed2d66}},	//   nksz, ידע_, oys_, yten_
  { {0x50da013a,0x44392d67,0x27ed2d68,0xcb35006b}},	//   _אקרא, nys_, xten_, ледъ
  { {0x54760053,0xc43c0053,0x4dd70015,0x1c4401c6}},	//   נגװע_, ותדי, _لترس, шнім
  { {0x2b89032c,0xc9f50029,0x0b160015,0xf8b1002b}},	//   júce_, استع, طقية_, مکش_
  { {0x09f6003b,0x2b89002c,0x443914bd,0x0905059c}},	//   افية_, dúce_, kys_, упин
  { {0x8c190053,0xa904002b,0x2d870144,0x27ed2d69}},	//   _אוּי, شبين, ïneu_, uten_
  { {0x443900df,0x6d592d6a,0x63a41915,0x07090015}},	//   dys_, liwa, _ruin, ريجي_
  { {0xa01b00f2,0x28dc005d,0x61ee0400,0x63a42d6b}},	//   _hyöd, _याचि, xtbl, _suin
  { {0x6d5900b6,0x6e210251,0xca48002b,0x44390034}},	//   niwa, _àlbu, _جلمه_, fys_
  { {0xd4560036,0xe7080086,0x2007005c,0x42d601f3}},	//   утнь, رتین_, łnij_, ліву
  { {0x6d590035,0x03a326f6,0x61ee01b8,0x91e62ae4}},	//   hiwa, сиро, ttbl, логе
  { {0x6d590050,0xc5d50191,0x44392d6c,0x52860015}},	//   kiwa, _сіль, ays_, الأك
  { {0x867a013a,0x66820086,0xe1650015,0x63a42d6d}},	//   _ארצו, _دیپل, لدقي, _tuin
  { {0x1f660033,0xe816000b,0xd9d0000b,0x61ee2d6e}},	// [59e0] гкам, तिया_, _सट्ट, stbl
  { {0x73061c0b,0x4f962d6f,0x61ee2d70,0x0000006a}},	//   _споз, урбу, ptbl,
  { {0x733b0053,0x2bc6000b,0x1756004c,0x4da50015}},	//   _נעטס, रीना, נסער_, لإنف
  { {0xcea90008,0xd7d4005d,0x869a0053,0xa37b0020}},	//   לי_, _दिलच, גיעז, stõt
  { {0x9f40008c,0x4bd7002b,0xafe30a13,0x0000006a}},	//   ttiä_, هبود_, _лоял,
  { {0xdceb0024,0x69c10026,0x78bb0007,0xc1ba000a}},	//   rogā, _bwle, ebuv, ֲמִש
  { {0x59d30015,0x7ec8003d,0x99d3012c,0x753d002a}},	//   مغير, rūpē, متيا, yksz
  { {0x9f4000f2,0xaea10064,0x443900f2,0xda650015}},	//   stiä_, ğışl, yys_, جاهي
  { {0xbc660124,0x6b460084,0x273b0023,0xd90d002b}},	//   _свак, _aðge, _kênh_, بین_
  { {0x17f7003b,0x7d020020,0x07f70029,0xbb760080}},	//   ارية_, leos, اريع_, _субъ
  { {0xab93003b,0x69c10176,0x44390c54,0xb521005d}},	//   _اللغ, _gwle, wys_, यालय_
  { {0xdce00024,0x44392d71,0xe663005e,0xda4b000a}},	//   _ikmē, tys_, стьо, _אֲדָ
  { {0xf993000a,0x443f0016,0x88130015,0xe73a00fd}},	//   _הרף_, áu_, _هبوط, _пед_
  { {0x44392d72,0x6138001a,0x2bc6000b,0xc7b3000a}},	//   rys_, _mílu, रीया, _הבס_
  { {0x7c39005c,0xa2950484,0x443f2d73,0x877b000a}},	//   zywr, раві, šu_, _ראוי
  { {0x80b50499,0x44392d74,0x637b00d4,0x0000006a}},	//   рбах, pys_, eînt,
  { {0x90990063,0xd3710015,0x35da000b,0x273b0016}},	// [59f0] тват_, _وهب_, _भिड़, _bênh_
  { {0xd5b80024,0x3e6b0063,0x6d590535,0x0000006a}},	//   opā_, ншен_, wiwa,
  { {0x6d5900b6,0x539a0008,0x9b450086,0x9cb500e6}},	//   tiwa, _שיתו, ینصو, لمات
  { {0x55bb0008,0x2dd80029,0x91ba000a,0x7a1c0045}},	//   גמאו, ابلة_, _שמרי, _mătă
  { {0x9f49002f,0x50f40484,0x6d590ad4,0xdbc70030}},	//   ltaí_, _узят, riwa, _köét
  { {0x6ee2005d,0x6d59198e,0xe00b000b,0xe1f0002b}},	//   _पाएँ, siwa, _सैयद_, _بسی_
  { {0xdea40074,0x44240092,0x8338000a,0x692515f9}},	//   _ایمی, ̣m_, ראוס_, имка
  { {0x8cc80086,0xe9a80015,0xa3d6000b,0x61380144}},	//   _موفق_, ددون_, _हिल_, _fílu
  { {0x9f49002f,0xaae70002,0x78a202d8,0xa2ba0065}},	//   htaí_, _مساو, _dgov, ्रम्
  { {0x7a1c0011,0xef12000a,0x6d5e002a,0xdceb0045}},	//   _bătă, ַּת_, ązał, bogă
  { {0xcf56000a,0x2489172e,0x7a1c0045,0xaa671cf3}},	//   שבתת_, _azam_, _cătă, _стак
  { {0x98750033,0xd7f5004a,0x201901e0,0x0000006a}},	//   _клец, _взды, _orsi_,
  { {0xd5b80024,0x6138002d,0x03a6153d,0x442400a1}},	//   apā_, _mílt, риго, ãm_
  { {0x290f0467,0x2b1e005d,0x66e20001,0x60c62d75}},	//   _haga_, पाएँ_, _доша, _sekm
  { {0xf67900b2,0xd756002b,0xc1560054,0x9f490125}},	//   _באַמ, _خلوت_, ањањ, gtaí_
  { {0x26c70034,0xc616000a,0x290f0801,0x41060004}},	//   _heno_, _כחצי_, _jaga_, јзав
  { {0x290f17f7,0x60970015,0xa49b0144,0xaec6076f}},	// [5a00] _maga_, لنفس_, leòn, ибал
  { {0xdce9002c,0xf3f10092,0x441b000a,0x26c7002a}},	//   _cieľ, ặt_, _יופס, _jeno_
  { {0x38690084,0x60c600bd,0xb2bb0008,0x200b04ed}},	//   _þarf_, _tekm, _שמטר, _esci_
  { {0xe5f60053,0xce890015,0x6138016e,0x2d8d2d76}},	//   יזער_, ائكم_, _pílu, _chee_
  { {0x3ceb0046,0x1be7029f,0x7d022d77,0xe573004f}},	//   _živá_, идци_, reos, קַע_
  { {0x26c7000c,0x96a7000b,0x7d1d2d78,0x7d022d79}},	//   _neno_, _फ़्लॉ, _ĳsse, seos
  { {0xf2d30008,0xe607002b,0xa3e8000b,0x4efb000a}},	//   קעה_, _بش_, मंड_, _שהלו
  { {0xdceb0011,0xf98f00e6,0x98b70063,0x2d95004a}},	//   rogă, وبي_, алът_, _грус
  { {0x1ae6005f,0x8ad6003b,0x290f0084,0xb8fe005d}},	//   _возм, _نتائ, _daga_, _तय_
  { {0x61fe06f5,0x26c7018c,0x66180227,0xaae0000b}},	//   _oppl, _ceno_, _prvk, _नाटक
  { {0x63b60026,0xff17000a,0x24890030,0x4b7b004f}},	//   _atyn, בקית_, _szam_, _יאמו
  { {0x78a2016f,0xd5b8003d,0xda5b004f,0x7a1c00d4}},	//   _ugov, rpā_, _בכבל, _vătă
  { {0x25720227,0xe7b40115,0x8cc7000b,0x61fe1061}},	//   nály_, _امتد, ारतो, _appl
  { {0x957d002a,0x29042d7a,0x57fb000a,0x26c701f9}},	//   krąg, lema_, _סלוו, _geno_
  { {0x26cc0a49,0x27e42d7b,0xeb91000a,0xc6b7000a}},	//   mado_, lumn_, לָל_, _דהוי_
  { {0xa37b001c,0x869b000a,0xa69b000a,0x95540015}},	//   drõe, _ביוז, _בשופ, _وخيا
  { {0x9f49002d,0x351c000a,0x30140033,0x838704ab}},	// [5a10] staí_, _יוהנ, одтр, _выне
  { {0x26cc0e75,0x87b7004c,0xdb000045,0x547c05bd}},	//   nado_, ילמס_, _lumâ, _בטחו
  { {0x2b89002c,0xe215004a,0x26cc016e,0xadf506c3}},	//   júca_, _умны, iado_, спеш
  { {0x6138002d,0x2bd2000b,0x7055002b,0x6db4005e}},	//   _díls, _सिखा, _هنجا, ійчу
  { {0xed580191,0x290f00e8,0x60cd00f2,0x2cbd0034}},	//   шої_, _raga_, maam, rbwd_
  { {0x26cc0656,0x60cd0044,0xa036000a,0x0ae8005e}},	//   jado_, laam, _האשה_, идій_
  { {0xa2ba005d,0xd20a0053,0x2d8d069b,0x26cc047e}},	//   ्रत्, ָלפֿ, _thee_, dado_
  { {0x29040020,0x370f000b,0x39462d7c,0x60cd2d7d}},	//   gema_, _थोड़ी_, _clos_, naam
  { {0x25a000e8,0xc1580008,0x2bc6000b,0x26cc00e1}},	//   _riil_, ישהו_, रीदा, fado_
  { {0xbb850029,0x26cc2d7e,0xf7490015,0x290f002a}},	//   _الطي, gado_, الدي_, _waga_
  { {0x60cd0607,0xfaf00015,0x290f2d7f,0xf409000a}},	//   kaam, _تثق_, _taga_, _רפ_
  { {0x60cd0044,0x4a5a000a,0xb4e2000b,0x3946028a}},	//   jaam, _גדעו, दले_, _glos_
  { {0xe72e005f,0xc9740029,0xc952000a,0x6831004c}},	//   _ее_, _بالث, _צמד_, _באַגר
  { {0x0ca4000b,0x752f002a,0x68e92d80,0x26cc08aa}},	//   _ओल्म, ajcz, lged, cado_
  { {0x60cd2d81,0x91860015,0x32432c75,0x51860058}},	//   faam, مجرم, перг, مشرق
  { {0x661c00fb,0xa3e8000b,0x68e92d82,0x20ca0058}},	//   ærke, मंद_, nged, طبري_
  { {0x75242d83,0xe3d60015,0x644f002a,0xdfaa0067}},	// [5a20] _iniz, _اتبع, czci, اطره_
  { {0x2bab005d,0x290417b8,0x324608ad,0x0000006a}},	//   _चढ़ा, zema_, _геог,
  { {0xa75a00b2,0x61fe2d84,0x139b0008,0x75240046}},	//   נדער, _uppl, _תביע, _kniz
  { {0x26cc0e75,0x0c26042b,0xa3df000b,0x067a004c}},	//   zado_, ймен, दूक_, אנעל
  { {0x6b460084,0xd57b0053,0x10160015,0xdb5a01c6}},	//   _aðga, אָגר, _ابجد, люк_
  { {0xf76704b6,0x3ebe002e,0x26cc0f14,0x749b000a}},	//   _را_, _ýtt_, xado_, אינפ
  { {0x26cc0e57,0xdce20a05,0x752f002a,0x68e902f7}},	//   vado_, lnoč, yjcz, fged
  { {0x57b4170d,0x27e400da,0x37d80004,0x02660016}},	//   обит, tumn_, адиќ_, _đền_
  { {0x7bcd0024,0x26cc2d85,0x0d77002b,0xdb01016e}},	//   šaur, tado_, _اینک_, _milê
  { {0x3ae80074,0x17540036,0x60cd0111,0x6d42008c}},	//   _خبری_, івня, zaam, lkoa
  { {0x60cd003f,0x26cc2d86,0x16340238,0x9f7b000a}},	//   yaam, rado_, ценя, רניח
  { {0x394600f2,0x26cc2d87,0x0e9b0643,0x354701c6}},	//   _ulos_, sado_, טשיל, схов
  { {0xb896003b,0x60cd00f2,0x26cc047e,0xf485002b}},	//   _الشع, vaam, pado_, تادی
  { {0x1659002b,0x644f002a,0x0000006a,0x0000006a}},	//   اسیک_, rzci,   ,
  { {0x60cd00f2,0xdce90024,0x644f0fce,0xb1a4005e}},	//   taam, _pieļ, szci, зшук
  { {0xf9b70008,0x2509009a,0xa0b902ed,0xa1582d88}},	//   מהלך_, _ضربی_, ргау_, басу_
  { {0xa3e8005d,0x8ea70015,0xdde1002a,0x60cd2d89}},	// [5a30] मूद_, مصان, łużb, raam
  { {0xc7f900b2,0x60cd1928,0x1ee7002b,0xf2c72d8a}},	//   יִער, saam, صوصی_, _усин
  { {0x6d4b0026,0x60cd00f2,0x68e92c07,0xa2270058}},	//   thga, paam, yged, _طرده
  { {0x667b0053,0x249f0024,0x6fb50015,0x0000006a}},	//   נטאק, žumu_, _ومجا,
  { {0xd59c004c,0xffe40a16,0x0000006a,0x0000006a}},	//   אבאל, _нюрн,   ,
  { {0x63bd0007,0x7ae7022a,0x207a004c,0xac760015}},	//   ipsn, сюдж, _כארא, غموض_
  { {0xdb000077,0xe37c004c,0x6ebf000b,0xeb90002b}},	//   _atmó, ארגר, _ल्यु, ءظن_
  { {0x31692d8b,0xe10c004f,0xd9960058,0x68e92d8c}},	//   nnaz_, ָּהָ, ينوت_, uged
  { {0xfbe0014e,0x2be0000b,0xdd940033,0x68e92d8d}},	//   _नियम, _निया, _хаты, rged
  { {0xa3e8005d,0xf7710115,0x75240085,0x68e92d8e}},	//   मंस_, باب_, _sniz, sged
  { {0xa2ba005d,0x63bd0079,0xf5060a13,0x4b32009a}},	//   ्रस्, epsn, озно, _تکنس
  { {0xc329013a,0x2bc6000b,0x3cf9004c,0x2f0a002a}},	//   _בו_, रीवा, ױפֿב, mógł_
  { {0xe3b20021,0xd3fa0033,0xd38a005e,0xc7bb0033}},	//   برج_, шэні_, ийме_, _сёе_
  { {0x957d0050,0x394d03af,0xdb01001c,0x395f2d8f}},	//   stąp, lhes_, _silê, lius_
  { {0x2be0005d,0xd6e8000a,0xe29a2d90,0x05760015}},	//   _निभा, _הַפָ, рав_, _وابد
  { {0x395f0472,0xc5f2000a,0x2bcf000b,0x73e60190}},	//   nius_, _חדה_, _सौभा, _доиз
  { {0xa284002b,0x2b89006f,0x0000006a,0x0000006a}},	// [5a40] تیگو, júco_,   ,
  { {0x6d492d91,0x25e0000b,0xdb010034,0xdee30658}},	//   _alea, _किमी_, _dilë, дофи
  { {0x395f0007,0xdddc0046,0x6d490ff7,0x6d42008c}},	//   kius_, _vyrů, _blea, tkoa
  { {0x6d492d92,0xd5fa004c,0x6ab4000b,0x25ae0030}},	//   _clea, יפער, ुर्र, _állő_
  { {0xa01b2d93,0x6d490125,0xeb9a0b1e,0x6d421839}},	//   _szöv, _dlea, аид_, rkoa
  { {0x3f78000a,0x2be0000b,0xaae60015,0xc477000a}},	//   _הָֽע, _निठा, زستو, חתנו_
  { {0xc3330008,0x6d492d94,0x8fa31191,0x4e1900fd}},	//   ווג_, _flea, _царе, _літр_
  { {0xa01b00f2,0x6840002d,0x394d2d95,0xa9930040}},	//   _myön, _nádú, ghes_, وشيت
  { {0x872a0010,0xb8070015,0x8706006b,0x48130033}},	//   аўна_, قييم_, ояне, дмыс
  { {0xec37000a,0x394d007c,0x656d2d96,0xf1bf006f}},	//   _ואמר_, ahes_, _sjah, ýške_
  { {0xceb30008,0x2bc6000b,0x6b9b000a,0x395f2d97}},	//   וית_, रीरा, _כשמד, bius_
  { {0xd90e0086,0xda650115,0x394d0043,0xe72a002b}},	//   _شیخ_, _عالي, ches_, اسکو_
  { {0xd7ef003b,0xd11b000b,0xa91d00bc,0xb71817b6}},	//   _لكن_, _पोषण_, olžn, _голф_
  { {0x75d40015,0x97240015,0x31c70033,0x63bd2d98}},	//   _فيتا, _رفعو, жсав, rpsn
  { {0x656d01d7,0x5398005e,0xa19500ce,0x95ca2d99}},	//   _tjah, івся_, завч, _тула_
  { {0xa3e8005d,0x63bd0123,0x25d7000a,0xcfab00c3}},	//   मूह_, ppsn, _ווהן_, لائم_
  { {0xb2a70029,0x2eab0001,0xa2ba005d,0x90550010}},	// [5a50] _وحده, ањен_, ्रश्, чвац
  { {0x6d49002d,0xa2950484,0x249f003d,0x2f150033}},	//   _slea, _напі, žums_, ядзё
  { {0x98af0024,0x6d4917ce,0xa2ba000b,0x6d480091}},	//   _logā_, _plea, ्रर्, _įdar
  { {0x63ad0f4d,0x395f0251,0xd5fb004c,0xb147002b}},	//   _kuan, xius_, שפאר, _بیرم_
  { {0x7c070029,0x395f2d9a,0x63a5007c,0x408402a3}},	//   تباك, vius_, _kihn, _журб
  { {0xdb0100dc,0xaa35006b,0xeab1012c,0xb3bc004f}},	//   _kilé, зхищ, رعت_, סמוכ
  { {0x395f2d9b,0xeaf806e4,0xa9b40086,0x2bd7005d}},	//   tius_, ترنت_, ولوژ, _ठिका
  { {0x3981001a,0x21391bd0,0xd8b90015,0x61310789}},	//   jóst_, _josh_, حدثا_, _påly
  { {0x395f2d9c,0x63ad2d9d,0xf7190033,0xab87008b}},	//   rius_, _nuan, біны_, _дужк
  { {0x394d0a99,0x99870007,0xe5e10010,0x395f2d9e}},	//   shes_, tynų_, нымi_, sius_
  { {0x395f00df,0x673c00c0,0x394d1151,0xcd95004f}},	//   pius_, örja, phes_, ּדָת_
  { {0xa3d7014e,0x661c0134,0xf9fa000a,0x63ad2d9f}},	//   ाओं_, ærka, _להעמ, _buan
  { {0x63ad0467,0xdb0101f6,0x0000006a,0x0000006a}},	//   _cuan, _ailé,   ,
  { {0x77ba0008,0x68fb0026,0x98ad016f,0x289a0135}},	//   _המסח, lfud, iječ_, _פיסא
  { {0x62850176,0x3cff0069,0x63ad0012,0x412a0c68}},	//   _cyho, _obuv_, _euan, бово_
  { {0x55da00b2,0x3d15000b,0x68fb0034,0xf0aa016a}},	//   _פֿונ, णयों_, nfud, скал_
  { {0xb4d8000b,0xa3d6000b,0x63ad2da0,0x75d00046}},	// [5a60] ाणी_, _हिट_, _guan, _vězň
  { {0xa01b00f2,0x1e960d22,0xdce90085,0x8236006e}},	//   _työn, прер, _dječ, _فرجا
  { {0xf7720008,0x62850026,0x200f002e,0x433b000a}},	//   עקב_, _gyho, ægir_, _העיב
  { {0x2be0005d,0xdd920087,0xfd120015,0xa06a17b6}},	//   _निदा, روش_, عجا_, _гама_
  { {0x7c2600bd,0x2bcf000b,0x0eba0088,0x60c42326}},	//   _škrb, _सौदा, _губы_, mbim
  { {0x60c40780,0x7bc90176,0xb4d8000b,0x44202da1}},	//   lbim, _dweu, ाणु_, _mri_
  { {0x68fb0026,0x657d2da2,0x67380085,0x6d69001a}},	//   ffud, yosh, _rovj, ðsað
  { {0x4ddb0008,0x23dc005d,0x44202da3,0x97c40015}},	//   _לחלו, _बिंद, _ori_, وقعو
  { {0x6738016f,0xebe3050e,0x7c2d008c,0xdb0002de}},	//   _povj, _потп, äart, _rumæ
  { {0x44270023,0x00570008,0x95d8000d,0x63ad2da4}},	//   _ăn_, פשית_, одот_, _ruan
  { {0x3abb0008,0x44202b20,0x657d2da5,0xe8fa0054}},	//   _המבנ, _ari_, tosh, _гле_
  { {0x442000e8,0x63ad0064,0x6dac0061,0x3eaa2da6}},	//   _bri_, _puan, _işad, _lgbt_
  { {0x9f400077,0x63ad0d2d,0x07f700c3,0x44202da7}},	//   ntió_, _quan, _فروع_, _cri_
  { {0x889b0008,0x44200026,0x657d003f,0xa3a4049d}},	//   _הבדי, _dri_, sosh, ејск
  { {0x39810084,0xb9090092,0xa37b0020,0x44202da8}},	//   póst_, _nghề_, nuõi, _eri_
  { {0x60f9008f,0x26ce0026,0x62850057,0xd6270054}},	//   ўная_, _hefo_, _vyho, _хоће_
  { {0xf4850086,0xe81f005d,0x7fb90015,0x44202da9}},	// [5a70] _تاثی, बिया_, زهار_, _gri_
  { {0xeeab0010,0xdce90085,0xc8850012,0xa37b007c}},	//   стак_, _vječ, ößig_, kuõi
  { {0x8cf5008f,0xc5f80024,0x12fa000a,0x213900e7}},	//   дзец, ntē_, _והתב, _tosh_
  { {0xc5f8003d,0xe7dd000b,0x3f9a088a,0x0000006a}},	//   itē_, _मिलप, ampu_,
  { {0xfc460023,0x1be90036,0x6dac0011,0x10040033}},	//   _đích_, ідки_, _aşad, _пярм
  { {0xdb090064,0xac74002b,0xc5f8003d,0xda090015}},	//   _önün, رانش, ktē_, قيته_
  { {0xa3b4021e,0xd2b8000a,0x6b4f02de,0xceb2004f}},	//   _जून_, הלות_, _nøge, _יים_
  { {0x3a3a0123,0xa01b008c,0x673c0123,0xda640058}},	//   äppa_, _lyöm, örjn, عاوي
  { {0xd7ee0029,0x661c02de,0xeb090015,0x7d0b0030}},	//   لكي_, ærkn, _وقرى_, megs
  { {0xb4e6014e,0x6b4f00fb,0x9b450015,0xdb23008c}},	//   कल्प_, _bøge, _تنطو, äräm
  { {0x5ee8000a,0x44202daa,0xa50a1068,0x23cb0065}},	//   הַרְ, _sri_, оена_, ़ीसद
  { {0x44201658,0x52c6000b,0xda7a000a,0x02c6000b}},	//   _pri_, वर्स, _ונער, वर्न
  { {0xe8940033,0x97550054,0xb8e3000b,0xb8d40015}},	//   _заць, _откљ, ्र_, _ستنش
  { {0x79890026,0x889a0008,0x43930010,0x7d0b00dd}},	//   llew, _ובני, каўс, hegs
  { {0x03a305c4,0xe7300015,0x26c50034,0x201c003d}},	//   тиро, _حصن_, mblo_, āvim_
  { {0x61e100dc,0xd1320015,0xa01b008c,0x44202dab}},	//   álla, خمر_, _työl, _tri_
  { {0x44202dac,0x60c42dad,0xa01b0030,0x0000006a}},	// [5a80] _uri_, rbim, _ször,
  { {0x42560015,0xd1ba0058,0x2fc00546,0x0000006a}},	//   _ينظر, _واجا_, rpig_,
  { {0x7cf10030,0x2be0000b,0xe29a2dae,0x0000006a}},	//   zűrő, _निहा, _фан_,
  { {0x25e0005d,0xe8df0016,0x2bcf000b,0x60cf0061}},	//   _किसी_, _trộm_, _सौहा, _gecm
  { {0xdca31635,0x79892daf,0x0000006a,0x0000006a}},	//   ваци, dlew,   ,
  { {0x9f4002c1,0xe4570053,0x7d0b0020,0x0a9400fd}},	//   rtió_, וינט_, aegs, налю
  { {0x2be0005d,0x9f401eeb,0xe813000b,0xdee3049d}},	//   _निवा, stió_, _तैबा_, _јоси
  { {0xb8140292,0xa81420ed,0x79892db0,0xd846008b}},	//   едиј, едиш, glew, дхоп
  { {0x6b4f1405,0x36d40e71,0x9cb30058,0x99830058}},	//   _søge, нопр, _شملت, خليو
  { {0xeeeb0092,0x7bc21e0f,0x3b260015,0x4b260040}},	//   _đừng_, mpou, _تعرّ, _تعرف
  { {0x9a6a0015,0xa01b008c,0x798901f9,0x6d4a2db1}},	//   _بمال_, _ryöm, blew, ūfau
  { {0xc5f80024,0xc86609ef,0xa01b008c,0xd5b8003d}},	//   rtē_, _отли, _syöm, evāc_
  { {0x2492005c,0x443f0092,0xc5f80024,0xa99b000a}},	//   _czym_, âu_, stē_, _ובאר
  { {0x1dae000b,0xdb190012,0xc5f8003d,0x69d80b28}},	//   टदात, sswö, ptē_, osve
  { {0x442d0011,0xe816000b,0x46140015,0xd13b03fb}},	//   ţe_, तिका_, _أوبر, оха_
  { {0xf194005e,0x69d82db2,0x8a17004f,0x6fb90132}},	//   вись, isve, וחלו_, згар_
  { {0x657600dc,0x25a9007c,0xa01b008c,0xb4eb000b}},	// [5a90] ézhe, _iial_, _työm, मली_
  { {0xa01b00f2,0xbe4b0029,0x644008b1,0xc7f7000a}},	//   _hyök, يشام_, ämie, וזמת_
  { {0x637f0089,0x463b0053,0x7d0b00dc,0x656f14ce}},	//   ráně, ֿעדע, tegs, onch
  { {0x2be0005d,0xe29a000a,0xbc190033,0x429a000a}},	//   _निशा, _משתר, зікі_, _מסתב
  { {0x7bc404f9,0x212b2652,0x636900bc,0xa91d2db3}},	//   ţiun, _inch_, ažne, nože
  { {0x98af0050,0x2be0005d,0x547c000a,0x7dc70015}},	//   _mogą_, _निरा, קטגו, _يتأك
  { {0x53380053,0x3f810089,0xa91d006f,0xee780015}},	//   ונגן_, mohu_, hože, _قصفت_
  { {0x9f40001a,0x6e94086e,0x2d780085,0x3859005e}},	//   ltið_, _рису, včeg_, зрою_
  { {0x9941005c,0xa0e3003d,0xb9020174,0x98af002a}},	//   móż_, dēļā_, узык, _nogą_
  { {0xe731003b,0x656f001c,0xba2b0015,0x2492002a}},	//   اصة_, ench, _وسام_, _rzym_
  { {0x2b89032c,0x24890049,0xcb34006b,0xa5c3002a}},	//   júci_, _ayam_, _шефъ, _ogół
  { {0x2b89006f,0xdb012db4,0x79b6000a,0x99a80015}},	//   dúci_, _milí, _טלעד_, _قُلْ_
  { {0x66e50010,0xb9360053,0xf9920135,0x61e10030}},	//   _зола, _רננו_, _ערד_, álln
  { {0x212b04ed,0x883a000a,0xc7d6000a,0x35f9002b}},	//   _anch_, _מתנו, _טוני_, _فربد_
  { {0x7bc20046,0x412a1977,0xa91d0046,0x2b89006f}},	//   zpou, пово_, požd, rúch_
  { {0xa91d0cbc,0xfbe0000b,0x9f40001a,0x290d00d4}},	//   bože, _निलम, etið_, neea_
  { {0xdfd20086,0x65660035,0xdb01002d,0x27ed2db5}},	// [5aa0] ايط_, mikh, _ailí, nuen_
  { {0xe1fa005f,0xa01b022d,0x2cad003e,0xf457000a}},	//   _его_, _myöh, _aged_, _נייר_
  { {0x82f7000a,0x64462db6,0x9afe0016,0x82360058}},	//   _אציב_, lyki, _nitơ_, _أرخا
  { {0x41bb0008,0xa2ba005d,0xa3e4000b,0x251b000a}},	//   _מצטע, ्रक्, _कटाप_, ּ֥אמ
  { {0xad650015,0xdb01001a,0x6cd3002b,0x64460091}},	//   خاله, _eilí, اقها, nyki
  { {0xbc670015,0x69d82db7,0x27ed0db6,0xdb012db8}},	//   عمون_, tsve, duen_, _filí
  { {0x9998002b,0x69d8008c,0x5b230015,0x7bc21eb4}},	//   وپتر_, usve, طفيل, spou
  { {0xeeeb0092,0xf41f00f2,0x64460007,0x69d82db9}},	//   _đứng_, yvä_, kyki, rsve
  { {0x27ed07dd,0xd117000a,0x69d82dba,0x25a92dbb}},	//   guen_, תקפה_, ssve, _rial_
  { {0x644600df,0x7980003f,0xd6da03ad,0x501b000a}},	//   dyki, somw, чти_, לופו
  { {0x0f570008,0xa3d3000b,0x61ee036d,0xbb77000a}},	//   גיים_, हीन_, jubl, _טעמו_
  { {0xb4eb014e,0xf9920086,0xa91d07c4,0x290d0045}},	//   मले_, _صبا_, tože, ceea_
  { {0xa93b000a,0xf76f002b,0x656f01f1,0x64460091}},	//   _מתאפ, شای_, rnch, gyki
  { {0x61e100dc,0x7528003d,0xa91d2dbc,0xe73701b0}},	//   állo, ēdza, rože, _печ_
  { {0xa01b022d,0x41e4022a,0x61ee0263,0xa1290015}},	//   _työk, літа, gubl, وكسل_
  { {0xf8b2014e,0xfc460092,0xa91d0085,0xd6170015}},	//   ीडिय, _đính_, pože, _أتوا_
  { {0xb4bf005d,0xa91d0089,0x752d003f,0x212b0016}},	// [5ab0] ेरी_, ložc, _inaz, _vnch_
  { {0x20e10092,0xdb012dbd,0xe3f80015,0x6281007c}},	//   ỗi_, _milã, _أعيش_, ülos
  { {0x9f400084,0x877b000a,0x02bf000b,0x7bc40045}},	//   rtið_, לאמי, ्रीन, ţiul
  { {0x40950015,0xf42a006f,0xe2ab002b,0x9f40001a}},	//   _للجر, späť_, _واگن_, stið_
  { {0x4d880015,0x60d6000a,0x9f40001a,0x8d740040}},	//   رَهُ_, _בורא_, ptið_, دالا
  { {0x1610005d,0xaf090015,0xfbd00015,0x656600aa}},	//   ़बार_, _تقسم_, صته_, zikh
  { {0x7ceb0064,0x6446005c,0xddcb0007,0xdb010125}},	//   görü, zyki, čiųj, _uilí
  { {0xa91d00bc,0x49980033,0x9d18165a,0x27ed2dbe}},	//   olži, нтыя_, _пост_, tuen_
  { {0xa91d00bd,0x5b1509fe,0x290d0045,0x78890015}},	//   tožb, _имат, reea_, بَةِ_
  { {0x64460007,0x7c840329,0x7d1b2dbf,0xa01b008c}},	//   vyki, _сусе, _haus, _vyöh
  { {0x6b832dc0,0xa92b005e,0xd5e5006b,0x89d70015}},	//   mong, _ніде_, ъжни, _ستضط
  { {0x6446086a,0xd46a000d,0x7d1b00c5,0x98c70015}},	//   tyki, диме_, _jaus, _أغان
  { {0x656600dd,0x27ed1eeb,0x8366002b,0x44242dc1}},	//   rikh, quen_, ندسل, ím_
  { {0x64460007,0x66e52dc2,0xa856000a,0xfbd2000a}},	//   ryki, _рока, _בינה_, שתם_
  { {0xd6ce0015,0x6b830573,0x64460a85,0x6263012a}},	//   _بقى_, iong, syki, авра
  { {0x9f40008c,0x64460091,0xc0e30004,0x6b832dc3}},	//   ntiö_, pyki, иоск, hong
  { {0xef1a0080,0xdb080152,0x10a605c4,0x6b832dc4}},	// [5ac0] мма_, _fidè, тиан, kong
  { {0x03aa0029,0xc3e50015,0xdfcf0015,0xaec30098}},	//   _تدعو_, _إثيو, تيك_, ибул
  { {0xf2d3000f,0x60d624d5,0x9f650030,0x7d1b2dc5}},	//   _דעת_, paym, ótát_, _baus
  { {0x98ad0089,0xbca60086,0x216a0036,0x69de1927}},	//   ěněn_, نماي, _цими_, špek
  { {0x4c130015,0x69c12dc6,0xa4b7004f,0x1034009a}},	//   لبوس, _atle, דלנה_, _صبحگ
  { {0x7ceb0064,0xef1f002a,0xe9f80033,0x6b832dc7}},	//   törü, ążce_, енкі_, gong
  { {0x2b89002c,0x6f1c002d,0x09f30015,0x2bc6000b}},	//   júcu_, _iarc, لأيد, रीजा
  { {0x7d1b00df,0xc27b000a,0x6f1c2dc8,0xb9240021}},	//   _gaus, ורצי, _harc, افظي
  { {0x6d40002d,0x6f1c2dc9,0x3cfb000a,0x7ceb0061}},	//   _ioma, _karc, _קלמנ, sörü
  { {0x98af005c,0x47340001,0x752d04c6,0x7d1b01a3}},	//   _mogę_, унос, _snaz, _zaus
  { {0xa4d5017f,0x6d402dca,0xba170040,0x25d80033}},	//   лоні, _koma, _ليلا_, эмны_
  { {0x4e350053,0xb4bf005d,0xfe37000a,0x6d400990}},	//   אָשן_, ेरे_, דרטי_, _joma
  { {0x18360002,0x98af002a,0xdb080003,0x6d400ff2}},	//   _جراح, _nogę_, _aidé, _moma
  { {0x6d401f90,0x36d42791,0x52bf000b,0xe76a0067}},	//   _loma, _сокр, ्रेस, _تحصن_
  { {0xa91d0198,0xd3540015,0x2259004a,0xe2980033}},	//   loža, جَّة, хивы_, ваё_
  { {0x6d400048,0x752d0962,0xf5950015,0x6b4f02de}},	//   _noma, _unaz, _حلبج, _nøgn
  { {0xdfd10015,0xa91d0085,0x63690091,0xdefb0088}},	// [5ad0] صيا_, noža, ažna, дые_
  { {0xa8570008,0x7d1b2dcb,0x57fb000a,0x9f54223b}},	//   דימה_, _saus, ולמו, авуч
  { {0x3ea700c0,0xfe700086,0x7db40015,0x7c222dcc}},	//   änt_, يدم_, لصنا, evor
  { {0xbd180191,0x3cff005d,0xa1590010,0x6b83003f}},	//   кції_, ोजें_, _чаму_, wong
  { {0x20060152,0x6f1c2750,0x957d0091,0x7eb90125}},	//   çoit_, _farc, trąj, _cúpó
  { {0x6b83003f,0x9b450015,0xfc300015,0x7afc0012}},	//   uong, طنبو, تحم_, _örtl
  { {0xc3340008,0x7d1b2dcd,0x6a850256,0x2d870003}},	//   יוס_, _taus, ылка, înes_
  { {0x6f1c2dce,0x6b8309a1,0x7c222dcf,0xe8f91453}},	//   _zarc, song, bvor, хли_
  { {0x5c750684,0xc19c000a,0x7785004a,0x6b832dd0}},	//   _слат, ושהי, ллиз, pong
  { {0xaa0b0029,0x52bf005d,0x7aca000b,0x9b950015}},	//   _يزال_, ्रोस, _स्पॅ, _صلات
  { {0x8c4201e2,0x50d3005d,0x2ca9002c,0x0f56000a}},	//   _öğre, तराष, ľadu_, ריתם_
  { {0x7528003d,0xa91d06c0,0x67d52be2,0x20190062}},	//   ēdzo, boža, _боду, _ossi_
  { {0x2d8f002f,0xc9160008,0xf8da000a,0x2cfa004c}},	//   ilge_, _תחנת_, _נחסמ, עלשא
  { {0xe7330015,0x6d5a0091,0x4734002b,0x43752dd1}},	//   _خصص_, _įtam, _پرهز, ауст
  { {0xc0e6007a,0xc5b9000a,0x20191dbc,0x291d247b}},	//   ловк, _אֶ֥ר, _assi_, _kawa_
  { {0x291f000c,0x291d00e8,0xdb081f05,0x02bf000b}},	//   ndua_, _jawa_, _vidé, ्रॉन
  { {0xd0260033,0x600a0033,0x27ff2dd2,0x6d402dd3}},	// [5ae0] ымай, энам_, ntun_, _roma
  { {0x6b4f00fb,0xdfcf0031,0xdee50015,0x0ccc000b}},	//   _søgn, سيم_, لأمي, ार्म
  { {0x201904ed,0xbe660086,0x394d0293,0x02fb000f}},	//   _essi_, دهاي, kkes_, _אלימ
  { {0x7c220c1a,0x6f1c2dd4,0xe2ca002b,0x291d1d0d}},	//   tvor, _warc, _توگو_, _nawa_
  { {0x6f1c005c,0x7fd50127,0x3cff000b,0x0b8a1972}},	//   _tarc, _вісі, ोड़ें_, нски_
  { {0x8c430124,0x6d40003e,0x2d870003,0x7c222dd5}},	//   сеље, _woma, îner_, rvor
  { {0x2be0014e,0xbae50036,0x2d960010,0x27410089}},	//   _निका, рцій, _брас, _méně_
  { {0xdb010014,0x6d4000f2,0xa3e5005d,0xda070086}},	//   _vilá, _uoma, _पटल_, اييه_
  { {0xcaf600b0,0xed570268,0x291d003f,0x20002dd6}},	//   _مساب, _сот_, _dawa_, ntii_
  { {0x394d003e,0xa01b008c,0x7bdb000a,0xa91d0b28}},	//   akes_, _työv, _נקבו, roža
  { {0xd5b7005f,0x6440022d,0xa37b2dd7,0x5f370053}},	//   лся_, ämin, nsõe, אטיע_
  { {0xc8b60029,0x291d1a5d,0x1a9b004c,0x9f52008c}},	//   _إصاب, _gawa_, _װידע, ltyä_
  { {0x4992002b,0x765a002a,0x6fb00065,0x0000006a}},	//   _پیکر, szty, _अंगू,
  { {0x77f7013a,0x6b4f0134,0x07080029,0xa01b00f2}},	//   _עמוד_, _nøgl, _شيعي_, _myöt
  { {0x31c42dd8,0x65950731,0xf3640142,0x0d04000b}},	//   йств, _каку, стян, रभाष_
  { {0x2619000b,0x9f52008c,0x6d5808cf,0x0000006a}},	//   _बनती_, htyä_, ëval,
  { {0xc05b0191,0x2be0000b,0x05740067,0xceeb012c}},	// [5af0] хів_, _निगा, _داود, فران_
  { {0x7ed4002b,0x44292dd9,0x394d01d3,0x0000006a}},	//   مزما, _ira_, zkes_,
  { {0xc33200b2,0xb7c30011,0x7e280010,0x636900bd}},	//   _ווי_, ăţil, ліца_, lžno
  { {0x2be0000b,0xa37b007c,0xdb26002b,0x2d8f007c}},	//   _निखा, ssõd, یونی, ulge_
  { {0x60cd2dda,0x20000045,0x291d2ddb,0x645d0012}},	//   mbam, ctii_, _rawa_, nzsi
  { {0x291d000c,0x60cd2ddc,0xbec3003d,0x4dd7009a}},	//   _sawa_, lbam, čūse, _مترس
  { {0xba770086,0x2614000b,0x61e10030,0x39a70030}},	//   داشت, _फैली_, állh, _hősi_
  { {0x27ff002e,0x7d040020,0x44292ddd,0x394501c5}},	//   ttun_, õist, _ora_, рниг
  { {0xcd280015,0x27ff0061,0x394d2dde,0x3cf00046}},	//   _حسّن_, utun_, rkes_, šové_
  { {0x753d0050,0x2d780820,0x27ff2ddf,0x645d0030}},	//   ejsz, nčen_, rtun_, dzsi
  { {0x27ff1878,0xda080086,0x394d01d7,0x44292de0}},	//   stun_, _ميله_, pkes_, _ara_
  { {0x6d5a0007,0x44290cbf,0x6e210656,0x98af0091}},	//   _įtak, _bra_, _álbu, _ilgį_
  { {0x9984003b,0xa01b00f2,0xf770002b,0x60cd1c97}},	//   _النو, _myös, _کان_, dbam
  { {0x3319008f,0xfbb6000a,0x44292de1,0x46a5027c}},	//   ліся_, יפשת_, _dra_, _калв
  { {0x29d304f9,0xc5d50191,0x82a60036,0x63690085}},	//   nţa_, _тіль, равж, ažno
  { {0x867a013a,0x44290b3f,0x20002de2,0x33d6005e}},	//   _ברצו, _fra_, ttii_, _кіот
  { {0x657d0014,0x44292de3,0x1f66021a,0x9f52008c}},	// [5b00] érhe, _gra_, акам, ytyä_
  { {0xc49b000a,0xdd1f006f,0x20002de4,0xdee62de5}},	//   _בשפת, _ríšs, rtii_, рожи
  { {0x27ed018b,0x2fc900b6,0xa01b022d,0x8cc60029}},	//   hren_, apag_, _syöt, لقاه
  { {0x44290780,0xa37b03af,0x6d59003e,0x91bb0008}},	//   _yra_, rsõe, ghwa, _שמכי
  { {0xa37b03af,0x9f52022d,0x27ed02de,0x201c003d}},	//   ssõe, ttyä_, jren_, āvis_
  { {0x6b46002e,0x8af7005e,0xe9e62de6,0x69dc0723}},	//   _aðgr, иніс_, ацио, _ærek
  { {0x12e900b2,0x9f5200f2,0x27ed2de7,0xd337000a}},	//   אַפּ, rtyä_, eren_, ירסה_
  { {0xa01b00f2,0x9f5200f2,0xd90d002b,0xd9430054}},	//   _työt, styä_, فیم_, жећи
  { {0xdce90085,0x57b30088,0x6440008c,0x29d30045}},	//   _sjeć, обыт, ämil, aţa_
  { {0xf8030010,0xa91d00bd,0xeb760010,0xabfb000a}},	//   ічын, ložl, _тыбэ, _בהמר
  { {0xe8fa05fc,0x27ed2de8,0x9f400061,0xceb7000a}},	//   _але_, aren_, ariç_, יפיק_
  { {0x9975005f,0x69ca00b8,0xd5670674,0x7d010030}},	//   _лучш, mpfe, ртоп, máró
  { {0x7d0100dc,0x53471c0c,0x63690085,0xa93b000a}},	//   láró, ахва, užno, _שתדפ
  { {0x4429020a,0x389b0135,0x35f7002b,0x83870033}},	//   _vra_, _סיגנ, درید_, рыме
  { {0xe1670001,0x6dac0064,0x179b000a,0x21670033}},	//   ађан, _aşam, _שיוב, атаг
  { {0x7657000f,0x44292de9,0x0467005e,0x60cd007c}},	//   _כבוד_, _tra_, _втом, ubam
  { {0x90990661,0xa01b008c,0x2d780046,0x44292dea}},	// [5b10] уват_, _ryös, tčen_, _ura_
  { {0xbf02000b,0x9e150033,0x7d010030,0x441c000a}},	//   र्लभ_, йдзі, káró, _יוחס
  { {0x7d0100dc,0xa3d3000b,0x1ef80015,0x6d590495}},	//   járó, हीर_, شعلة_, thwa
  { {0xdd980010,0x27ed0026,0x61f50061,0x7c292deb}},	//   ашч_, yren_, muzl, _prer
  { {0x8cc6000b,0xf1a4056d,0xd8260015,0x73fb004f}},	//   ाड़ो, _фрэн, _ةٍ_, דּ֔ו
  { {0x1b7b0029,0xab640127,0x6d592dec,0x9e350088}},	//   خصصة_, овіл, shwa, _легч
  { {0xa01b00f2,0x61f50064,0x7d010030,0xa9692ded}},	//   _työs, nuzl, gáró, лика_
  { {0x99150191,0x29d30045,0xa91d0046,0x7d090723}},	//   ські, rţa_, rožo, _ubes
  { {0xccf2013a,0x27ed2dee,0x3d2a002b,0xc052004f}},	//   _מכן_, uren_, _حتّی_, ּ֖ח_
  { {0x6d5a0091,0x7d010030,0x27ed2def,0x0000006a}},	//   _įtai, báró, rren_,
  { {0xaa950029,0xe81c000b,0x7a540015,0xc7440015}},	//   _الاث, _बैठा_, _وضما, تضيي
  { {0x6e360008,0x05560b18,0x7c2617e5,0x27ed2df0}},	//   צטרף_, стоя, _škri, pren_
  { {0x6c790053,0x321a002b,0xd8b80015,0xe3d50058}},	//   ראָפ, گيزد_, _ضدنا_, ْتِع
  { {0xdc9a0053,0xe3b10015,0xf668002b,0x4c9a000a}},	//   טירל, ِرِ_, احیه_, טברו
  { {0x661c00fb,0x61ee042f,0x15461215,0xe81f0065}},	//   ærkt, urbl, _гейм, बिका_
  { {0x21670345,0x31bc02e6,0xa5650015,0x41590033}},	//   биси_, _víz_, _ودين, ашую_
  { {0x4127010f,0x937a0029,0x7d0100dc,0x25ab0144}},	// [5b20] щото_, _مصدر_, záró, ïble_
  { {0x66f9005d,0xa01b00f2,0x20e80092,0x79890234}},	//   ्भिक_, _pyör, ởi_, hoew
  { {0xa2b7000a,0x02b7000a,0x257200bc,0xdce001ec}},	//   _לפיד_, _להים_, ašle_, _ammā
  { {0xb5fa0053,0xddb70010,0xd5fa0053,0xdb080057}},	//   טלעכ, ёгіі_, טפער, _vidí
  { {0x9f4000f2,0xdd8f0002,0x1ab42c51,0xaab40033}},	//   triä_, روه_, обля, ойлі
  { {0x7d0100dc,0xa01b008c,0xdfcf00c3,0x441b000a}},	//   táró, _työr, _سيف_, טונס
  { {0x0f570053,0x46db000b,0xcb070058,0x0000006a}},	//   _פילם_, _मज़ह, صيين_,
  { {0xbce50015,0xa3d80157,0x69ca0012,0xed57257f}},	//   _وأقو, ाठा_, rpfe, _лос_
  { {0xeafa0029,0x7d0100dc,0x4cbb0008,0xa3b4000b}},	//   _مرات_, sáró, _תזמו, _जंग_
  { {0x501b0008,0x9f49002e,0xab960015,0x25a016ad}},	//   נויו, ntað_, _الطغ, _ahil_
  { {0x151502bf,0x2f3b004f,0x0000006a,0x0000006a}},	//   одня, אגיד,   ,
  { {0x9f4704af,0x61f50061,0xd10a000b,0x1e97000a}},	//   čné_, vuzl, ह्मण_, מכיל_
  { {0xa3d3014e,0x58960074,0x1c1e000b,0x9f49001a}},	//   हीं_, _اجاز, पिटल_, ktað_
  { {0x661c00fb,0x96ba2df1,0x3817000a,0x9f40016e}},	//   ærks, _суду_, _לקדם_, ssiê_
  { {0x39460005,0x1797000a,0x26de2df2,0xe5c61119}},	//   _koos_, _הדגל_, mato_, _усло
  { {0x26de2df3,0xda4b004f,0xc5170058,0x905500ce}},	//   lato_, אֲמָ, _طبعت, овбц
  { {0x656f2df4,0xdbf10046,0x61f50061,0xa0c40067}},	// [5b30] mich, _příh, suzl, سيلو
  { {0x656f2df5,0x26de2a83,0x13b5000b,0x644f00e0}},	//   lich, nato_, ंदीभ, myci
  { {0x656f02b9,0x2ddb0015,0x6288002a,0x5cb90138}},	//   oich, ابطة_, żdor, алеў_
  { {0xd5fb004c,0x656f2df6,0x6ad10065,0x0000006a}},	//   רפאר, nich, हर्र,
  { {0x69c80024,0x1b19004a,0x9f490125,0x0708000b}},	//   _atde, ижды_, lraí_, वभाव_
  { {0x656f018b,0x75280024,0xdea4002b,0x26de0046}},	//   hich, ēdzi, _کیمی, jato_
  { {0x9f49002d,0x656f005c,0x644f0026,0x998500a2}},	//   nraí_, kich, hyci, يلتو
  { {0x656f0089,0x7bcb0123,0x3ebb0091,0x47c5118f}},	//   jich, ppgu, šytą_, обив
  { {0xf8ae0074,0x5fe2005d,0xa91d04af,0x798900aa}},	//   نکه_, _पिछल, ložk, roew
  { {0x656f00b8,0x26de2df7,0x7b770087,0x501c000a}},	//   eich, gato_, _اطرا, רוזו
  { {0xe57a0063,0x656f2df8,0x69de0046,0x25a01042}},	//   изо_, fich, šper, _phil_
  { {0x656f2df9,0x34aa2dfa,0xf2c9004f,0x957d0073}},	//   gich, ивно_, _יע_, drąs
  { {0xf4960015,0xf9880015,0x33d50033,0x26de2dfb}},	//   تشدد, _انني_, зіст, bato_
  { {0x26de02d7,0x1639003b,0x9f49002d,0xf7730015}},	//   cato_, _نسبة_, fraí_, _عاش_
  { {0x9f49002f,0x99e9000a,0x171a004c,0x68fb007c}},	//   graí_, יַּ֥, _כוסע, ogud
  { {0x644f005c,0x68fb2dfc,0x7de00030,0x656f0535}},	//   byci, ngud, _lásá, cich
  { {0x92b60029,0x0fda0080,0x3942008c,0x9f49001a}},	// [5b40] _وحدا, рьбы_, öksi_, ttað_
  { {0x44202dfd,0xfe720115,0x67232dfe,0x752401c2}},	//   _isi_, ودا_, _janj, _haiz
  { {0x61460083,0x8d660036,0x672314bc,0xa2b9000b}},	//   _дена, овже, _manj, ्डर्
  { {0x568c00b2,0x629e018c,0xa01b00f2,0x9f49002e}},	//   נטאַ, _izpo, _työp, stað_
  { {0x44200089,0x68fb0034,0x5c16012c,0x60c40847}},	//   _jsi_, dgud, تظار, mcim
  { {0x3946020a,0x5c970010,0xb2ba0008,0xf9c6005e}},	//   _soos_, цкія_, ׁמְר, ощин
  { {0x644f0050,0x26de02d7,0xde030036,0xaa5700e6}},	//   zyci, vato_, _опри, يلها_
  { {0x7968002a,0x75240085,0x60c42dff,0x26de002a}},	//   oświ, _naiz, ncim, wato_
  { {0x656f0db0,0x26de052a,0x8c170015,0x6d980077}},	//   vich, tato_, _ويفر_, níam
  { {0xfa360029,0x8c1b0008,0xf0930008,0x10370008}},	//   _وراد, _דומי, ונח_, קטים_
  { {0x5ebb0008,0x644f005c,0x26de2a83,0x656f2e00}},	//   יזיק, wyci, rato_, tich
  { {0x26de2e01,0x89a50015,0x60c40085,0x6d420045}},	//   sato_, _فإنم, jcim, njoa
  { {0x656f2e02,0x7968002a,0xb4470033,0x26de2e03}},	//   rich, jświ, цэнк, pato_
  { {0x9f49002d,0x0f14005d,0x656f2e04,0x7968002a}},	//   traí_, ड़ोस_, sich, dświ
  { {0x9f40002d,0x75240c76,0x316b0001,0x7228005e}},	//   briú_, _faiz, ашао_, оцтв_
  { {0xd138008f,0x9f49002f,0x67232e05,0xc1050015}},	//   оху_, rraí_, _zanj, ثوري
  { {0x656d00b6,0xcebb0001,0x1004006b,0xdfdb006b}},	// [5b50] _imah, аље_, дяхм, ръб_
  { {0x3dd80026,0x68e00375,0x2fc60125,0xf4140c44}},	//   _bwrw_, hamd, íoga_, _חפץ_
  { {0x3dd80034,0x7bc9288f,0x3228005e,0xa1952e06}},	//   _cwrw_, _steu, _діям_, _наоч
  { {0x9ce70010,0x621a000a,0x6d9816ee,0x26dc2e07}},	//   іцел, _פורק, bíam, _levo_
  { {0x9f4002c1,0x31cf0053,0xbef70015,0xbb95005e}},	//   guió_, _אָנפֿר, _وأست, падщ
  { {0x8b220457,0x4fd6000a,0x6440008c,0x3dd80034}},	//   едше, _מושב_, ämii, _fwrw_
  { {0x7de000dc,0x60dd0064,0xcf92000a,0x7c260de8}},	//   _vásá, _kesm, _נטל_, _škrt
  { {0xad270086,0xf27c0008,0xceb20008,0x627c0135}},	//   _برآو, ירוש, _טים_, ינונ
  { {0x60dd03af,0xa3b4005d,0x636900f0,0x6bd40015}},	//   _mesm, _जूझ_, ažni, _يتكر
  { {0xdc880008,0x70b8000b,0x7d19002a,0x75242e08}},	//   _וְעָ, _अल्ल, lews, _saiz
  { {0x9f40002d,0x6b7a0053,0xa37b0020,0x67230263}},	//   triú_, _פרענ, tsõn, _vanj
  { {0x7968005c,0x68e00011,0xba9a000a,0x60dd2e09}},	//   yświ, camd, _הסעי, _nesm
  { {0x752400df,0x629e06e7,0x58ba000a,0x88ba0447}},	//   _vaiz, _szpo, _המנצ, _המנז
  { {0x44202026,0xa37b007c,0xa7870015,0x6d98059d}},	//   _vsi_, ssõn, _بشؤو, víam
  { {0x4420005c,0xe29a1017,0x79c9000a,0x60c40085}},	//   _wsi_, сав_, מֶּ֔, tcim
  { {0xdfd20029,0x216729ca,0x44201695,0x629e017b}},	//   فير_, писи_, _tsi_, _vzpo
  { {0xb4d8005d,0x44202e0a,0xf992000a,0xb4fb000a}},	// [5b60] िरी_, _usi_, תרן_, _הלפר
  { {0x60dd0005,0x1eaa003b,0xc2ea0018,0x6d980a40}},	//   _eesm, ماضي_, _اعظم_, ríam
  { {0xddcb0064,0xa2bb0008,0xddb60015,0x60c40085}},	//   ğişk, _למיט, سحاب, pcim
  { {0xcf8900b2,0xeeeb0092,0x6d5b002d,0xad65012c}},	//   אט_, _đụng_, _clua, وانه
  { {0x6d42022d,0x5bc60015,0xeb9a0004,0xf53f00cb}},	//   rjoa, ستشف, бид_, dmål_
  { {0x6d5b0020,0xac970029,0x3b53008b,0x20070045}},	//   _elua, أنها_, нкір, ănit_
  { {0x8e830004,0x68e00061,0xc8790061,0x7c2b0123}},	//   _згре, tamd, vaşa_, avgr
  { {0x8b660086,0xd91a0036,0x4e7b0053,0x6d5b002d}},	//   _کارم, ськ_, _האלצ, _glua
  { {0xf8030010,0x68e00035,0x4814005e,0x98a30054}},	//   нчэн, ramd, ємос, ниће
  { {0x23a40123,0x68e02e0b,0x395f0072,0x0000006a}},	//   nöjd_, samd, ahus_,
  { {0xd6d7005f,0xf5e3008b,0xd9f00065,0xa3da0065}},	//   чты_, ніям, _घटित_, डीस_
  { {0xd5b70080,0x19bb000a,0x49bb000a,0x9e77000a}},	//   ясь_, _המאב, _המאס, לגיה_
  { {0x545404f7,0x60dd0943,0xe3b30015,0xe4a4004a}},	//   евят, _resm, فرس_, ерро
  { {0x7bcb000a,0x18530033,0x2fcb0085,0x7d190d24}},	//   מֶלֶ, _явіў, _rtcg_, zews
  { {0xa1950036,0x5693070e,0x60dd01a3,0xa79b0643}},	//   давч, _пашт, _pesm, _השגח
  { {0xf67b0008,0x9f470089,0x867b000a,0xd347002b}},	//   _לאומ, ční_, _לרוו, _کیسه_
  { {0x60dd0264,0xd0110015,0x0000006a,0x0000006a}},	// [5b70] _vesm, ضلا_,   ,
  { {0xdef10015,0xa91d2e0c,0x6d5b0125,0x61f20061}},	//   ئًا_, roži, _slua, üklü
  { {0x7d19005c,0x6d5a0007,0x657d2e0d,0xc334004c}},	//   tews, _įtar, onsh, _טוץ_
  { {0xaffd005e,0xbc750015,0xa91d04b2,0x8c590015}},	//   _комi, وهاب, poži, يلاء_
  { {0xa4b80008,0xd59c000a,0x2bdd000b,0xc5f8003d}},	//   פלגה_, זבאל, _नौशा, dzēm_
  { {0x20090007,0x60c2006f,0xfbd000c3,0x657d02ad}},	//   mtai_, ľome, اتن_, hnsh
  { {0xc9a90080,0xd358000a,0xf9890015,0xde740015}},	//   овке_, היגי_, ينتي_, _كدفع
  { {0x32380008,0x212908c0,0xdce900bc,0x17c91119}},	//   לטון_, ndah_, _kmeč, огии_
  { {0x98bd005c,0xe731002b,0xf53f05bf,0x2129172e}},	//   _nową_, نصد_, rmål_, idah_
  { {0x200900df,0xf53f2e0e,0x85e9009f,0xb6070107}},	//   itai_, smål_, одов_, _naší
  { {0xab8402e1,0xdb03002d,0x7ae32e0f,0xbae40015}},	//   _чутк, nmní, mant, _سكني
  { {0x20090007,0xdb03002d,0x7ae32e10,0x657d1cd4}},	//   ktai_, imní, lant, gnsh
  { {0x05630063,0xc9740115,0x21292e11,0xb607005a}},	//   твян, _ثالث, ddah_, _baší
  { {0x7ae30032,0x07a400fd,0x212901c2,0x77ba000a}},	//   nant, _заін, edah_, _ומסח
  { {0x6dbe002c,0x45460029,0xe56a0015,0xdb010046}},	//   _vďak, _ينتق, _ومتى_, _chlé
  { {0x7ae32e12,0x2d78036d,0xc692000a,0xa1160058}},	//   hant, lčev_, _שאה_, بورت
  { {0x75c80089,0xdee6024f,0xd007080e,0x63b70247}},	// [5b80] _věze, дози, мете_, _fixn
  { {0xef170080,0x7ae32e13,0x212901c2,0xaf9a00fd}},	//   мму_, jant, adah_, ітах_
  { {0x9d460063,0x44320227,0xdd92002b,0x433b000a}},	//   межд, _hry_, پوش_, _ועיב
  { {0x4432020a,0x61fc1d56,0x2d8f2e14,0x60c204b2}},	//   _kry_, murl, goge_, žomb
  { {0x6b540251,0x6c1a0031,0x7ae31915,0xdb010046}},	//   _hàgi, تتاح_, fant, _zhlé
  { {0xa9c60015,0x8c430054,0x60d60034,0x7ae32e15}},	//   وزبو, теље, lbym, gant
  { {0x6e96002b,0x61fc0ff8,0x539b004f,0x0000006a}},	//   _آلزا, nurl, חיסו,
  { {0x6b4f0134,0xf70e0092,0x2d8f0077,0x6d360015}},	//   _søgt, _củng_, coge_, _تفرض
  { {0xdb0800f2,0x79a30063,0xfce30054,0xb906000b}},	//   _pidä, ърше, _шото, _बज_
  { {0x657d003e,0xddc90011,0x8c170029,0xbb560029}},	//   wnsh, _înţe, _تيكر_, _تنطب
  { {0xdceb0024,0xcad7000a,0x3abb000a,0x61fc01c2}},	//   ligā, _חובת_, _ומבנ, jurl
  { {0xceb30008,0x7bc02e16,0x20091855,0x61fc2e17}},	//   כית_, _kumu, ytai_, durl
  { {0x7bc0000c,0x44322e18,0xdb010046,0xed5f006f}},	//   _jumu, _cry_, _shlé, úžia_
  { {0x289b0008,0x4432003e,0x889b000a,0x9f5f0061}},	//   _וידא, _dry_, _ובדי, örün_
  { {0xa2940036,0xb6070057,0xa2cb000b,0x268a002b}},	//   варі, _vaší, तुष्, _بخشي_
  { {0xc17b0036,0x21290049,0xdbc60061,0x44321a4e}},	//   іїв_, udah_, _göçe, _fry_
  { {0x7bc00048,0xc05b0191,0x4432005c,0xf1940a61}},	// [5b90] _numu, ців_, _gry_, тить
  { {0x20092e19,0x7ae32e1a,0xdce90085,0xa91d01c0}},	//   rtai_, xant, _rjeđ, ložt
  { {0x20092e1b,0x7ae32e1c,0xdceb003d,0x9f490061}},	//   stai_, vant, eigā, hraç_
  { {0x7bc00035,0xe5100092,0x1677000a,0xdfd5004a}},	//   _bumu, _lặng_, וגבל_, _помы
  { {0x0c750086,0x1600000b,0x8d740015,0x7ee7006b}},	//   رگرد, लंडर_, خالا, _оцве
  { {0xe5100092,0xcef40015,0x7bc002f2,0x220b000a}},	//   _nặng_, _لأفغ, _dumu, ַפִּ
  { {0xdeb40010,0xa91d0046,0x9e150033,0x7ae32e1d}},	//   _абры, kožt, _ядві, rant
  { {0xd2b8013a,0xaa560029,0x7ae32e1e,0xe9a80021}},	//   ולות_, عليا_, sant, ودين_
  { {0x6d5900aa,0xd7ee0015,0xa37b007c,0x7bc00c99}},	//   mkwa, مكي_, rsõj, _gumu
  { {0xd7090afa,0x8ca4000b,0x5b340015,0xa37b007c}},	//   чное_, _औरतो, _لعمر, ssõj
  { {0x6dac01e2,0xcf920008,0x395d0034,0x7bc00012}},	//   _işar, רטי_, _tlws_, _zumu
  { {0xab5d005c,0x7bc0117f,0x7cea0030,0x7ae12e1f}},	//   _duże, _yumu, mörí, _helt
  { {0x44240092,0xf992000a,0x6cfa000a,0x649a0121}},	//   ìm_, _גרא_, הפרס, ятор_
  { {0x6b540b4c,0xfbd20008,0x69c12e20,0xa2cb000b}},	//   _pàgi, רתם_, _kule, तुल्
  { {0x2d780227,0x7ae12e21,0x03a3004a,0xf679004c}},	//   očet_, _melt, уиро, _מאַמ
  { {0x64400197,0xdb0102c1,0x443208b8,0xfc470089}},	//   ämis, _kiló, _try_, _klíč_
  { {0xe7cc0053,0xe43300e6,0x2087007a,0xb0aa000b}},	// [5ba0] ַצאָ, _مفيد, ейти_, चेंग
  { {0xdceb0024,0x03d7004c,0x6d590079,0x9fb50046}},	//   vigā, _רוים_, ekwa, _přál_
  { {0x7bc02e22,0x17560053,0x6d5900aa,0x69c12e23}},	//   _sumu, עסער_, fkwa, _nule
  { {0xedd30074,0x7bc00035,0x9f470264,0x6dac0061}},	//   ايند, _pumu, čná_, _aşar
  { {0xe505014e,0xdca310b9,0x7ae12e24,0x957d0091}},	//   ष्टि_, гаци, _belt, fsąj
  { {0x600b0008,0x7ae102e7,0x93fb000a,0xf1cb001a}},	//   _מִלְ, _celt, פלצי, _óáð_
  { {0x78a200dc,0x443f0092,0xf2d3000a,0x7ae12e25}},	//   _szov, ̣u_, נעה_, _delt
  { {0x7bc000b6,0xd90e0086,0x7ae10020,0x4814005e}},	//   _tumu, صیت_, _eelt, вмис
  { {0xd90d0086,0x7c240064,0x7ae12e26,0x3b8600fd}},	//   تین_, çird, _felt, _злаг
  { {0x999c0007,0x96340342,0x7c2e003d,0x7ae12e27}},	//   tyvų_, вноц, ķirī, _gelt
  { {0xa4d50036,0x5eeb000a,0x7d022e28,0x5daa000a}},	//   коні, הַכְ, ogos, ּבָ֔
  { {0x7d022e29,0x58d3005e,0x7ae12e2a,0xdb010e51}},	//   ngos, _боїт, _zelt, _filó
  { {0x69c100b8,0x99470086,0xe5100092,0x53e70033}},	//   _zule, _سلول_, _tặng_, эцна
  { {0xdbc70005,0xb4bb0086,0x28b7000a,0xc3480033}},	//   _tööt, _کاغذ_, _נפגש_, нясе_
  { {0x22580089,0xa2950010,0x661301b2,0xb1a70054}},	//   _čeká_, таві, čeká, ешак
  { {0xa69b0008,0x569b000a,0x869b000a,0x1637000a}},	//   _משופ, _מיוצ, _מיוז, _טנור_
  { {0x442f0084,0xa98b000a,0x7d02002a,0xdb0a001a}},	// [5bb0] _ég_, לָמִ, dgos, amfé
  { {0x7d022e2b,0x7c222e2c,0x3255011e,0xa06800af}},	//   egos, dwor, _авор, хађа_
  { {0xf7730053,0x66a9000a,0xddde002a,0x6d590079}},	//   נקע_, ֵינֶ, ezpł, tkwa
  { {0x7ae12e2d,0x69c12e2e,0x9f400077,0xdb030046}},	//   _selt, _rule, frió_, dmná
  { {0x6fb50029,0x212b0026,0xa37b0020,0x6281001a}},	//   _لمحا, _iach_, esõi, úlof
  { {0x6f1e2e2f,0xf414004f,0x69c12e30,0x212b03a0}},	//   cepc, רפס_, _pule, _hach_
  { {0xc334000f,0xda62007a,0x8d770015,0xee84004a}},	//   טוס_, ивши, _كارا, _быто
  { {0x7ae1018b,0x99150036,0xd23c000a,0x9f40010d}},	//   _welt, тькі, לגול, brió_
  { {0x7c870001,0xd8b6002b,0xe7b40091,0x68e22e31}},	//   _чуве, نگها_, _šešė, _deod
  { {0x69c12e32,0x7c240064,0x501c000a,0xd763002b}},	//   _tule, çire, לוחו, اندی
  { {0x3b64006b,0xdb010144,0x39150067,0x799b02f2}},	//   _сътв, _filò, _لواز, pluw
  { {0x212b2e33,0x201900e8,0x99d40015,0x68e22e34}},	//   _nach_, _opsi_, _إتلا, _geod
  { {0x9cd6000a,0xa01b008c,0xf8690058,0xc48300ce}},	//   כורה_, _työy, _تمشي_, илюк
  { {0x987a0053,0x8e270033,0x1bfa000a,0x394f04a9}},	//   _קאסט, аiмi_, ולשב, _hogs_
  { {0x27ff022d,0x02190036,0xf79604c9,0x212b2e35}},	//   luun_, ніть_, _جنوب_, _bach_
  { {0x7c222e36,0xf1a90015,0xc1060015,0x8afc002a}},	//   ywor, فاقه_, ضوئي, _klęc
  { {0xf577003b,0x6b5d0152,0x27ff00f2,0x70b30015}},	// [5bc0] _جميع_, _règn, nuun_, لمفض
  { {0x212b0041,0xd36f003b,0x54570008,0x93fb0632}},	//   _each_, _وهي_, _סביב_, _קליי
  { {0x212b0313,0x0000006a,0x0000006a,0x0000006a}},	//   _fach_,   ,   ,
  { {0x212b002f,0x27ff00f2,0x202700f2,0xed57170d}},	//   _gach_, kuun_, äviä_, кох_
  { {0x6e3500b8,0xbd43002b,0xf1b4000b,0x0b8a0317}},	//   _erzb, شنوي, ंगठन, мски_
  { {0x6713005d,0x9f400fc9,0xa3da000b,0xab270054}},	//   त्मक_, rrió_, डीए_, воља_
  { {0x7db60010,0x6e35002a,0x8b650021,0x212b0cc1}},	//   _асац, _grzb, دانم, _yach_
  { {0xdb0902c1,0xf98f00a2,0xa37b007c,0x6da62b98}},	//   _dueñ, يبي_, rsõi, _риба
  { {0xc173013a,0x19b70029,0x59630063,0x4b26000d}},	//   יחה_, خطوة_, ръща, _имав
  { {0x95d8000d,0x02be000b,0x47330323,0x0000006a}},	//   ндот_, ्डोन, аньс,
  { {0x0f570008,0x6b7b00a3,0x4efb000a,0x090609d9}},	//   דיים_, _קרבנ, וליג, _апен
  { {0x8a790053,0xa5d7002b,0xd7fa15f4,0xd5b809b1}},	//   _אָנק, کبیر_, _жук_, кся_
  { {0x385a0015,0x161e000b,0x99980030,0x0000006a}},	//   _تشاد_, _बनकर_, _érő_,
  { {0xa857000a,0x27f9006f,0x212b2e37,0xb6340058}},	//   _בידה_, ásne_, _sach_, _مفتع
  { {0x53340001,0x92b40015,0xa022008c,0x31c402b0}},	//   јест, لحفا, ööno, иств
  { {0xc6b7000a,0xf1a70b1e,0xc8b4004f,0x50f42e38}},	//   _בלוז_, тргн, ָּֽה_, изст
  { {0x67330046,0xf8b4000b,0x290402f2,0x4fc402bb}},	// [5bd0] řejš, ुशिय, igma_, асха
  { {0x44292e39,0xd7b8000a,0x212b0012,0xc43a004f}},	//   _isa_, תֶֽך, _wach_, _נתתי
  { {0x733a00b2,0x212b0026,0x752f005c,0xe3b00021}},	//   _װערס, _tach_, odcz, _بري_
  { {0x867b000a,0xeea8006b,0xff5f0045,0x752f002a}},	//   ורבו, ттук_, _atît_, ndcz
  { {0xed59016f,0xdb0902c1,0x7188000a,0x75c1003d}},	//   _niže_, _sueñ, _יְשַ, _vēzi
  { {0x27ff00f2,0x6c520054,0xaed40033,0xc6860015}},	//   vuun_, скљу, _ворш, _هِ_
  { {0xdb0101c9,0xc8790045,0x6b120015,0x9f400052}},	//   _uhlí, maşi_, صِيص, mrið_
  { {0xc8790011,0x442909e7,0x27ff00f2,0xb2bc000a}},	//   laşi_, _osa_, tuun_, ומור
  { {0x38ca0086,0x957d002a,0x7c840004,0x60cd2e3a}},	//   رايی_, brąz, _куфе, icam
  { {0x75c80089,0xed590085,0xf8ae002b,0x464902da}},	//   _vězn, _diže_, سکن_, езон_
  { {0x394f00c0,0x27ff008c,0xc8790045,0xa50a2e3b}},	//   _togs_, suun_, iaşi_, нена_
  { {0xd7630086,0xc3290008,0x27ff008c,0x44292e3c}},	//   انگی, _מו_, puun_, _bsa_
  { {0x19940010,0xe72e00d8,0xf992000a,0x60cd2e3d}},	//   _таця, _ле_, _פרד_, dcam
  { {0x752f005c,0xdce20024,0xf8b2000a,0xf7490015}},	//   adcz, bloķ, _השד_, _سلبي_
  { {0x6b5d038d,0xf77000e5,0x44292e3e,0x27ed02cd}},	//   _règl, _بان_, _esa_, lsen_
  { {0xc8790011,0x9f40002e,0x2fda0115,0x3f9800cb}},	//   eaşi_, erið_, فورد_, _skru_
  { {0xc9520008,0x8fe50015,0x27ed2e3f,0x43761f02}},	// [5be0] זמן_, لألم, nsen_, _бунт
  { {0x32460124,0x7d092e40,0x27ed25f9,0x68e90034}},	//   _беог, _aces, isen_, haed
  { {0x277600b4,0x6706000b,0x02460015,0xa75a004c}},	//   נגען_, _शासक_, _صَحَ, עדער
  { {0x27ed2e41,0x7c29001c,0xc27b00a3,0x60cd02b9}},	//   ksen_, _bser, _טריי, ccam
  { {0x7c2900dc,0xc7c80016,0x629e010c,0x3bf6049d}},	//   _cser, _mốc_, _hypo, уџет
  { {0x6be3003b,0x6721016f,0x27ed2e42,0xcb34006b}},	//   حكوم, jelj, dsen_, рекъ
  { {0x7c292e43,0x672101a3,0xc5f8003d,0x27ed2e44}},	//   _eser, delj, nzēt_, esen_
  { {0x6b83002d,0x8938009c,0x290402f2,0x61ee042f}},	//   anng, тпис_, ugma_, isbl
  { {0x31570053,0x672100dc,0xb6e60484,0x7b09008c}},	//   טיקן_, felj, люнк, ästö
  { {0xa8170029,0x6ac60029,0x256200dc,0x6564055a}},	//   اتير_, _إقام, _róla_, _alih
  { {0x4906003b,0x3f7b000a,0x1efb004c,0xc7c80016}},	//   _مواق, תאיס, עלטע, _bốc_
  { {0xc5f80048,0x659500fd,0xc7c80016,0x61ee0fe0}},	//   dzēt_, раму, _cốc_, dsbl
  { {0xc993003b,0xb993003b,0xc7c80016,0x60cd006f}},	//   _النظ, _النب, _dốc_, vcam
  { {0x44292e45,0x66012e46,0x13a7002b,0x60cd002a}},	//   _vsa_, bulk, انسی_, wcam
  { {0xd6270001,0x471b0008,0x9f4000f2,0xdb1a2e47}},	//   _боје_, _נוהג, isiä_, _cité
  { {0x7aea018b,0xc7c80092,0x29ca0092,0x41c40033}},	//   haft, _gốc_, _mùa_, сёра
  { {0x9f402e48,0x765a00f2,0xdfd100a2,0x343b0015}},	// [5bf0] ksiä_, lyty, زيا_, _أسعد_
  { {0xa8570008,0x7d090363,0x88bd002a,0x2b09000b}},	//   אימה_, _sces, leśc, _साधु_
  { {0x539c0008,0x139c004c,0xc8790045,0xc5f8003d}},	//   _איזו, _אבזע, raşi_, mzēs_
  { {0xeb1d014e,0xcce70086,0xad670015,0x31350342}},	//   फ़्त_, اساي, دائه, _темр
  { {0x3b0907fe,0x88bd002a,0x69d800aa,0xb1140033}},	//   вело_, ieśc, epve, _умяш
  { {0x6ffa000a,0x4bd8002b,0xdb010125,0x3b8400fd}},	//   _בהשפ, ابند_, _bhlá, бліг
  { {0xdb01002f,0x672126e4,0xf8e0000b,0xcb66005e}},	//   _chlá, velj, नरूप, раще_
  { {0x0a18002b,0x765a26a6,0x8e840040,0x27ed2e49}},	//   افيک_, dyty, _الفه, tsen_
  { {0xc0520053,0x68e92e4a,0x67212e4b,0x7c292e4c}},	//   ַזט_, raed, telj, _user
  { {0xf7710002,0x27ed2e4d,0xb8fc000b,0x9f40008c}},	//   تاب_, rsen_, _त्_, csiä_
  { {0xcb680074,0xc5f80048,0x27ed2e4e,0x46a5006b}},	//   _حمله_, dzēs_, ssen_, ранв
  { {0x67210a00,0x8e96000a,0x27ed2e4f,0xdb1a0794}},	//   selj, ידתו_, psen_, _rité
  { {0x67212e50,0x61ee0034,0x66012e51,0xd619002b}},	//   pelj, wsbl, sulk, رتگا_
  { {0x394d0014,0x8caa000b,0x765a002a,0x6c1a000a}},	//   ljes_, जेटो, byty, כֵלו
  { {0xc7c80092,0x877a000a,0xdb010123,0x91e6023b}},	//   _tốc_, _באסי, _filö, робе
  { {0x395f0007,0xc5f80024,0x6564003f,0x629e0057}},	//   nkus_, rzēt_, _ulih, _vypo

  { {0x629e005c,0x6fb60029,0x3fc8002b,0x386d2e52}},	// [5c00] _wypo, لمرا, ادری_, nzer_
  { {0x395f0020,0x629e2e53,0x386d2e54,0x1ee8002b}},	//   hkus_, _typo, izer_, اوای_
  { {0x395f0020,0x394d0111,0x42fb0008,0x26e3005d}},	//   kkus_, kjes_, _בהיס, _ग़ैर_
  { {0xf1bf0023,0xdd8f0018,0x29ca0016,0x0000006a}},	//   _giá_, وول_, _rùa_,
  { {0xd24f0086,0x765a005c,0x386d0c08,0x394d0c08}},	//   _فنی_, zyty, jzer_, djes_
  { {0xdce60064,0xdb970010,0x88bd002a,0x765a008c}},	//   ımın, авіч_, ześc, yyty
  { {0xca480086,0x636b00b8,0x99660054,0x5a460033}},	//   العه_, _fünf, итил, рэла
  { {0x765a008c,0x6713000b,0x6d402e55,0x7aea063b}},	//   vyty, त्सक_, _unma, saft
  { {0xed570080,0x2012014a,0x765a002a,0xacfb004f}},	//   _тот_, ntyi_, wyty, _שהמכ
  { {0x394d0077,0xab5c003d,0x636b2e56,0x8b02002a}},	//   ajes_, _biļe, _zünf, łębo
  { {0xd6860080,0x386d001c,0x68fd0007,0x2012008c}},	//   рупп, azer_, ųsda, htyi_
  { {0x79530029,0x765a005c,0x8623002b,0xda5b000a}},	//   _وَلا, ryty, تکهل, _שכאל
  { {0x9f47032c,0xda02005d,0x765a00f2,0x88bd005c}},	//   čnú_, रूरत_, syty, reśc
  { {0x93880080,0x765a002a,0x31600061,0x69c82e57}},	//   асса_, pyty, ekiz_, _kude
  { {0x22b80029,0x7ae82e58,0x96b70054,0xc5f8003d}},	//   لدفع_, _medt, _кућу_, rzēs_
  { {0x69c81f27,0xeeeb0092,0x76bb000a,0x9f650061}},	//   _mude, _đựng_, _במופ, ştür_
  { {0x657d2e59,0xb4e3005d,0x7f07005e,0xdb010016}},	// [5c10] mish, धरी_, иїжд, _kilô
  { {0xc7d70008,0x657d0705,0x69c80161,0x395f00bc}},	//   יומי_, lish, _oude, zkus_
  { {0x75d30011,0xa1950afb,0xd338000a,0x03b40015}},	//   _găzd, _ганч, _כרזה_, _بإيد
  { {0x657d0705,0xbbf50015,0xf296000a,0xf532000a}},	//   nish, مستث, _לכתר_, ּ֥א_
  { {0x3d08005d,0xf5380135,0xdc980036,0x0136039e}},	//   _हारे_, יטאר_, авці_, _פרשת_
  { {0x657d000c,0x69c827ef,0xb0b6000a,0x636b0012}},	//   hish, _bude, _לפרס_, _düng
  { {0x657d000c,0x0a6b0063,0x9f49002d,0x394d2e5a}},	//   kish, ърди_, nsaí_, tjes_
  { {0xdd94008f,0x248d0050,0x386d04b0,0x2919002e}},	//   _дасы, żemy_, tzer_, ýsa_
  { {0x25620467,0x657d000c,0xb4e5000b,0xa904002b}},	//   _sólo_, dish, _पड़े_, زبين
  { {0x645d0007,0x386d00b8,0x2562016e,0xdd11003d}},	//   dysi, rzer_, _pólo_, kļūd
  { {0x386d0014,0x657d06e8,0x636b1d96,0x394d0079}},	//   szer_, fish, _münd, pjes_
  { {0x7a7a00b2,0x201200f2,0xf2c90053,0xa0220020}},	//   _גרעס, ytyi_, _טע_, ööko
  { {0x69c800b8,0x7bc90144,0x7bc12e5b,0xdb0a0030}},	//   _zude, _jueu, _kilu, lmfá
  { {0x289a0008,0x657d003f,0x80d5000b,0x69c8050b}},	//   _גינא, aish, युसे, _yude
  { {0x657d244d,0x7d1b12da,0x7bc90003,0x95d50015}},	//   bish, _obus, _lueu, _اغتص
  { {0x201200f2,0x6713000b,0x98a20091,0xc4fa0015}},	//   ttyi_, त्रक_, žką_, _صعبا_
  { {0x9f40002f,0x80aa09a7,0x636b00b8,0x321e0046}},	// [5c20] msiú_, ував_, _bünd, ůty_
  { {0x73060124,0x9f40002d,0x201200f2,0x7d1b08aa}},	//   _упоз, lsiú_, rtyi_, _abus
  { {0xb3bb0008,0x201200f2,0x9f49002d,0xe357000a}},	//   _תמיכ, styi_, csaí_, _השיח_
  { {0x23640024,0xdb1b002e,0xdd990036,0x7413002b}},	//   īmju_, _stuð, аші_, _بویا
  { {0xad650086,0x3137000a,0x69c82e5c,0x7bc12e5d}},	//   غامه, _הנכם_, _sude, _bilu
  { {0x657d000c,0x636b0064,0xc7c80092,0xf8e0000b}},	//   zish, _günd, _bốn_, नर्प
  { {0x6a130029,0x645d005c,0x3aeb0086,0x7ae80293}},	//   كبير, zysi, ابهی_, _vedt
  { {0x7bc100df,0x636b00b8,0x823b004c,0x645d008c}},	//   _eilu, _zünd, רעקצ, yysi
  { {0x7bc911a7,0xdce9016f,0x96ea2e5e,0xa8340054}},	//   _gueu, _smeć, льна_, цепљ
  { {0xfe0c005d,0x657d0a72,0x69c82e5f,0x96f80054}},	//   _हमास_, wish, _tude, јент_
  { {0x69c8022d,0x657d000c,0xa3be005d,0xf76f0115}},	//   _uude, tish, ेदन_, عاً_
  { {0xc4e3005d,0x645d0007,0x6b5d0251,0xd5670840}},	//   परेख, tysi, _règi, стоп
  { {0x657d244d,0x3f9a0024,0x5347006b,0x88bd002a}},	//   rish, kopu_, бхва, leśn
  { {0x657d000c,0xa2d4000b,0x645d2e60,0x200000d4}},	//   sish, बुल्, rysi, drii_
  { {0x657d000c,0xa9f80008,0xa77b0008,0x20002283}},	//   pish, יִּת, _תרופ, erii_
  { {0x9f49002f,0xc10500a2,0x636b1804,0xdb0d006f}},	//   rsaí_, توري, _sünd, ľkéh
  { {0x2d870089,0x9f551f8c,0xd3710058,0xd32700ce}},	// [5c30] énem_, овач, _يهب_, _льни
  { {0x80d9021e,0xc7d7004f,0x3ec702ed,0xdb1a03a0}},	//   _फ्रे, צובי_, ссаб, _bití
  { {0xbfa807be,0x5ed400c3,0x7bc90006,0xeeab0969}},	//   стте_, ستلز, _sueu, утак_
  { {0xa69b0053,0x7127002b,0xbfd50015,0x20002e61}},	//   נשאפ, _اردل, _ويجع, brii_
  { {0x6aa10026,0xfbd3002b,0x8c420061,0x636b0030}},	//   _sylf, ستش_, _öğle, _tünd
  { {0x7645002e,0x2418000a,0xacf7002b,0xda090015}},	//   _áhyg, צחון_, _گسست, ليته_
  { {0x636b0064,0x6d4d007c,0xda7b0033,0xab760015}},	//   _güne, öaas, ыяд_, تموا_
  { {0xc7c80092,0x7bc90003,0xc27c0643,0x5d650015}},	//   _vốn_, _tueu, טרוי, _بُرْ
  { {0x7d04002d,0x6aa10034,0xd7ee0015,0x69c22e62}},	//   óise, _wylf, نكي_, _dioe
  { {0xd7750029,0x75d30011,0xc7c80092,0xe6190e91}},	//   تابع, _răzb, _tốn_, адо_
  { {0xda02005d,0xaa6707c1,0x6d79000a,0xc7c80016}},	//   रूआत_, _утак, ֹאָח, _uốn_
  { {0x18cb0015,0x857a0004,0xdb1a0034,0x80d9000b}},	//   _إذاً_, рсот_, _gitâ, _फ्ले
  { {0x6fa9000b,0xa3d30033,0x09b80015,0x3d0e0065}},	//   कतां, моўч, _اطلع_, ण्टे_
  { {0xfbd20008,0x8bac000a,0x86c50015,0x43752e63}},	//   ותך_, ָׁלִ, _بيثن, пуст
  { {0x6b84002d,0x442001c2,0x44392e64,0x53a300e2}},	//   éigi, _wpi_, avs_, фарб
  { {0x98aa002a,0xe0da080e,0x61430076,0x44202160}},	//   śbą_, рва_, меса, _tpi_
  { {0x88bd0050,0x291d003f,0x44202e65,0x8eea005e}},	// [5c40] ześn, _mbwa_, _upi_, имав_
  { {0x799b0111,0x7c240064,0x20fa0092,0x11d60015}},	//   houw, çirm, ỏi_, _وتجد
  { {0x64410048,0xc3330008,0x4e2a0acc,0x3f9a0ff3}},	//   ālie, _חות_, роен_, ropu_
  { {0x361a0008,0xafdb0293,0x0316000b,0x68eb0085}},	//   יועד, _brød, द्रह_, _negd
  { {0xead41292,0x79892e66,0x6bd3006e,0x69c20034}},	//   поль, dnew, وتور, _rioe
  { {0xc43b000a,0x69c20034,0x7989055e,0x636b2e67}},	//   יתני, _sioe, enew, _tüne
  { {0x79890034,0xcb070015,0x6b8d0125,0x5e460015}},	//   fnew, زيين_, éaga, _بَأْ
  { {0xfafa0086,0x298a07c1,0xa37b016e,0x799b0079}},	//   _چراغ_, јско_, mpõe, gouw
  { {0xf74a0191,0xe7260036,0xf1b30008,0x98b70063}},	//   аїни_, оєнн, וסה_, олът_
  { {0x2562002e,0x78a2003f,0x636b264f,0x7c2d0527}},	//   _fólk_, _vyov, _münc, çare
  { {0x799b0111,0x7f3b000a,0xe5350174,0xd7730058}},	//   bouw, בעיו, пень, بايع
  { {0x68460029,0xdb1a0045,0xe45f008c,0xba9b000a}},	//   _وَال, _uitâ, työ_, _דסבי
  { {0xccf30008,0xd5b8007a,0x94ab2e68,0x66010052}},	//   וכר_, юсь_, ртна_, arlk
  { {0xb8650058,0x44390ee6,0x25a0007f,0x0000006a}},	//   _عانو, rvs_, _ekil_,
  { {0x2d872c85,0x6728016f,0xd1bb00a2,0x81d4005e}},	//   ének_, medj, لارا_, досх
  { {0x67281474,0x34950a31,0x8881002b,0x4fd5004a}},	//   ledj, _найр, _آیین, зжат
  { {0x656f002d,0x50670210,0xb4d7000b,0x3ecb00af}},	// [5c50] mhch, цтва, िडी_, аћем_
  { {0x69da2e69,0x67280085,0x644002de,0x320702dc}},	//   _otte, nedj, æmie, _ånyo_
  { {0x5f740015,0x6608007c,0xe235002b,0x80e70058}},	//   ذاكر, nudk, _عکسب, _وأحل
  { {0xf6530008,0x8d740031,0xd2b6004f,0x70550369}},	//   וצע_, وانا, _מלתת_, _فنجا
  { {0x636b01e2,0x60d60053,0x69da2e6a,0x799b0079}},	//   _günc, _מורא_, _atte, vouw
  { {0x394603af,0x3c1e0024,0x67280085,0x79890034}},	//   _anos_, dāvā_, jedj, wnew
  { {0xaa560001,0x63a70844,0x66080509,0x1df8054f}},	//   зију_, iljn, judk, _меры_
  { {0x2bcb000b,0x3cf80015,0x850a0065,0x5e440058}},	//   ाददा, _وعقد_, _वाइट_, _تَفْ
  { {0x799b0111,0x2d9d005c,0xfc300029,0x25b20026}},	//   rouw, mowe_, _لحل_, _rhyl_
  { {0x79890026,0x2d9d2e6b,0x67280030,0x25a02e6c}},	//   snew, lowe_, gedj, _skil_
  { {0x86740010,0x637007fd,0xdb030030,0x7aea0030}},	//   дыяц, _häng, jlné, öltő
  { {0x2d9d005c,0x656f0541,0xca36000a,0xe57700e2}},	//   nowe_, ghch, _מנעה_, ззю_
  { {0x33d50036,0xe469004a,0xc3d60033,0x29d1001a}},	//   діст, ошёл_, яўны, _háa_
  { {0x63702e6d,0x69da2e6e,0x883a000a,0xa856000a}},	//   _mäng, _ytte, _לתנו, _מינה_
  { {0x88bd0050,0x63702e6f,0x2d9d005c,0x62650115}},	//   ześl, _läng, kowe_, وافق
  { {0xc6920008,0x41b50036,0x2d9d005c,0x9f470264}},	//   _ראה_, дсут, jowe_, čný_
  { {0x2d9d005c,0x10090029,0xb6010046,0x63c60046}},	// [5c60] dowe_, قتلى_, žáde, írně
  { {0x7e9a0015,0x161f000b,0x747b004f,0x2ca402dc}},	//   منذر_, _बहार_, _לנפג, _rymd_
  { {0x3f8f016e,0xdd8f1293,0x2d9d0535,0x0000006a}},	//   égua_, еш_, fowe_,
  { {0xed590089,0x568c0053,0xd5fa0053,0x2d9d005c}},	//   _což_, סטאַ, מפער, gowe_
  { {0xc173000a,0xcb34006b,0x113b000a,0x4356000a}},	//   _נחש_, делъ, _התכל, ּסֶל_
  { {0x88bd0050,0x6c83003b,0xe9e60aed,0x5c970138}},	//   reśl, علوم, пцио, чкія_
  { {0x321804d0,0x2d9d005c,0xfa330021,0xc986005e}},	//   ntry_, bowe_, فريد, зупи
  { {0x63702e70,0xc7d8005e,0x2d9d002a,0x443208d0}},	//   _händ, омих_, cowe_, _osy_
  { {0x63702e71,0x394600bd,0xbc66055f,0x67280085}},	//   _känd, _vnos_, _эвак, tedj
  { {0xa7730a31,0x45d40c30,0x6608007c,0xa91d0046}},	//   ельч, моос, tudk, viže
  { {0xaadb013a,0x656f002d,0x69da148e,0x9f520077}},	//   _החבר, thch, _utte, luyó_
  { {0x2c20005d,0x39462b25,0x63700b1c,0xa4d5005e}},	//   _यहां_, _unos_, _länd, ьомі
  { {0xb4470010,0x9d1b0053,0xa7fd00dc,0x660801b2}},	//   чэнк, זוכט, szűr, sudk
  { {0x2d9d002a,0xe77a000a,0xa91d07c4,0x656f2e72}},	//   zowe_, _לָ֔ך, riže, shch
  { {0x171b0008,0x35f700e6,0xa91d0091,0x43942332}},	//   _הווע, _فريد_, siže, харс
  { {0xc5eb0008,0x20090375,0x636b007c,0x88bd0535}},	//   _הַזֹ, tuai_, _düna, ześm
  { {0xb4fc000a,0x63702e73,0x656d2560,0xd0100058}},	// [5c70] _הפחי, _bänd, _ilah, ُلِ_
  { {0x29030007,0x2d9d005c,0x41c70033,0x30140033}},	//   ėjai_, wowe_, _нёма, эдур
  { {0x2d9d0050,0x7bdb049c,0x20090849,0xa159226a}},	//   towe_, _stuu, suai_, _дану_
  { {0x98aa005c,0x6b5d0003,0x2fd90015,0x0000006a}},	//   śbę_, _nègr, _ووجد_,
  { {0x2d9d005c,0xac090127,0xa156039e,0xfd100031}},	//   rowe_, інка_, _חברה_, اجم_
  { {0x7c940074,0x2d9d005c,0x99d5002b,0x637004d6}},	//   رشنا, sowe_, وتبا, _väng
  { {0x656d0273,0x2d9d002a,0xbb280033,0x9a690015}},	//   _olah, powe_, яцце_, تمثل_
  { {0x7d550010,0xdb1a00dc,0x9f520077,0x2562001a}},	//   _ўвах, _vitá, buyó_, _tóli_
  { {0x6370022d,0xdd94008f,0x7bdb008c,0x290d2e74}},	//   _häne, _чаты, _utuu, rgea_
  { {0x57790015,0x316c003d,0x656d2e75,0x6362059d}},	//   تصبح_, īdzi_, _alah, _tôni
  { {0x6370007c,0x656d0107,0x6b832e76,0xaa67004a}},	//   _jäne, _blah, ming, _этак
  { {0x6d5b0003,0xf53f0123,0x44322e77,0x6b832e78}},	//   _joua, slån_, _psy_, ling
  { {0x2eaa000b,0xc448002b,0x8883002b,0x67550015}},	//   _कर्त, سیدن_, _سیدن, _يختر
  { {0x7c2401e2,0x6d5b1671,0xa3ba0021,0x36692e79}},	//   çiri, _loua, تاجر_, _мало_
  { {0xc7b2013a,0x21a60004,0xb602001a,0xd295030c}},	//   _שבו_, дивм, þátt, ерть
  { {0x637000c0,0x6b832e7a,0x41590033,0xc243006b}},	//   _sänd, hing, пшую_, ънск
  { {0x88ba0053,0x32182e7b,0xb4ea000b,0xb4fb000a}},	// [5c80] ַמעז, stry_, यरी_, _ולפר
  { {0x6d49002d,0x7f4a0015,0x656d00bc,0x6b832e7c}},	//   _anea, غلاق_, _zlah, jing
  { {0xf2d3013a,0x6370012d,0x11d50033,0x6b8319d9}},	//   _בעת_, _vänd, _піяр, ding
  { {0xbc6a0115,0x9f520077,0x63700012,0xc10600c3}},	//   يمان_, tuyó_, _däne, _توحي
  { {0x637000c0,0x51f6002b,0x6489000a,0xf1a7000b}},	//   _tänd, _عسگر, ּעוּ_, _कीटन
  { {0x7c2d1749,0x6b832e7d,0xc477000a,0x9f520077}},	//   çara, ging, ותנו_, ruyó_
  { {0x7f5c016e,0xbe160058,0x0000006a,0x0000006a}},	//   _iorq, _توزع,   ,
  { {0xc7c80092,0x6b830b63,0xed430719,0xa3b5000b}},	//   _hối_, aing, _инсп, _छीन_
  { {0x872a0010,0x3ce62e7e,0x87062e7f,0x26ca0085}},	//   оўна_, mbov_, мяне, žbom_
  { {0x3ae8002b,0xb905000b,0x6b830bbc,0xfb6a0058}},	//   _ربطی_, _ब्_, cing, _بصرى_
  { {0xc7c80092,0xaa8a0086,0xc956004a,0x86f5002b}},	//   _mối_, _بنام_, _отды, رکوس_
  { {0xc7c80092,0xcdf70008,0x7bc80375,0xe5c7005e}},	//   _lối_, ומטי_, _hidu, ьспо
  { {0x9f400251,0x636b00b8,0x7bc80ef3,0xd7ef0015}},	//   nsió_, _dünn, _kidu, _نكن_
  { {0x926b0763,0x56942b43,0xb4af0065,0xe60f009a}},	//   орба_, _палт, _करी_, دشی_
  { {0xc7c80092,0x1b7b0053,0x3d0f000b,0xa91d036d}},	//   _nối_, קטלע, _डाले_, liža
  { {0x45fb0008,0x6b832e80,0xb5fb000a,0x2562002a}},	//   _וההג, zing, _ולהכ, _bólu_
  { {0xf0bb0086,0x46d2005d,0x6b830705,0xd0110015}},	// [5c90] زارش_, _सलाह, ying, طلا_
  { {0x2fc7002e,0xbfab0010,0xc7c80092,0x23650123}},	//   öng_, ітае_, _bối_, öljd_
  { {0xdb1a00f2,0xc3320135,0xc7c80016,0xbdf80015}},	//   _mitä, _גוי_, _cối_, ِرها_
  { {0x6b832e81,0xc7c80016,0xac9502ed,0x0000006a}},	//   wing, _dối_, наеш,
  { {0x50da0008,0x8b25004a,0x711a004c,0x7bc801d7}},	//   _מקרא, едле, _צושפ, _bidu
  { {0x6b83003f,0xe1f0002b,0xc5f8003d,0x67380085}},	//   uing, _حسی_, ksē_, _navj
  { {0xaa880015,0x7bc80776,0x6aa80034,0xc7c80016}},	//   ونهم_, _didu, _cydf, _gối_
  { {0x26180152,0xdb1a0020,0x6d490939,0x6b832e82}},	//   déo_, _aitä, _unea, sing
  { {0x6b832bb3,0x511a000a,0x07f90015,0xed590085}},	//   ping, הֵינ, أربع_, _niži_
  { {0x9a270029,0x636b1bcb,0xe5e10033,0xdce90b28}},	//   _يعان, _sünn, лымi_, _mleč
  { {0x6aa80034,0xd7c9009a,0x0000006a,0x0000006a}},	//   _gydf, _کوته_,   ,
  { {0xe9190036,0xb4ea005d,0xad19000a,0x7bc80045}},	//   _ході_, यरे_, הוֹר, _zidu
  { {0xe806005d,0x31690227,0xda0b000b,0xd5cf000b}},	//   _शिया_, dkaz_, सूरत_, _सूरज
  { {0x4b79004c,0xd8740015,0xb4fb0065,0x395d01f9}},	//   לאָו, _جامب, ्लॉप_, _hows_
  { {0x0219005e,0x4758002b,0x8883002b,0x41b60923}},	//   міть_, _تشنج_, _سیگن, есат
  { {0xc7c80092,0x2139065b,0x067a000a,0x867a000a}},	//   _rối_, _cash_, _מנצל, _מרצו
  { {0x7f5c06d4,0x600a1402,0x21392e83,0xe0860015}},	// [5ca0] _porq, янам_, _dash_, رجري
  { {0xe3b20029,0x2d8f2e84,0xcb0e0065,0x5477004f}},	//   _حرب_, enge_, _साइड_, _נגיע_
  { {0x7bc804ed,0xe8ac021e,0xe53a000a,0x23650030}},	//   _ridu, _चर्च, ּתְר, ölje_
  { {0x7bc80020,0x22450134,0x64440607,0xad260015}},	//   _sidu, ælke_, _krii, عرضو
  { {0x7bc80020,0xb143004a,0xa4fb000a,0xdd8f00c3}},	//   _pidu, _снял, פלסט, حون_
  { {0xc7c80023,0x9f4008e0,0xbad60033,0xafdb04d1}},	//   _tối_, rsió_, хіды, _krøn
  { {0x9f4008e0,0x316c0048,0xf9c6007a,0x996600d7}},	//   ssió_, ūdzu_, нщин, етпл
  { {0x9a670029,0x6738016f,0x395d00da,0x2d870030}},	//   عميل_, _savj, _cows_, énet_
  { {0xdb1a022d,0xb4af005d,0xc1730008,0x76430026}},	//   _pitä, _करे_, טחה_, _arny
  { {0x907b000a,0x26180003,0xabfb000a,0x9bfb000a}},	//   פטיי, téo_, _מהמר, _מהמט
  { {0xe6940080,0x673a0123,0xc5f8003d,0xa91d0091}},	//   тины, rdtj, usē_, siža
  { {0xe4a72003,0x6444007c,0xa91d0b28,0x0000006a}},	//   ерго, _brii, ližn,
  { {0xe786023e,0xf993000a,0x213900da,0x31692db3}},	//   _пуко, _גרף_, _rash_, vkaz_
  { {0x636b01e2,0x65b60089,0xa91d10a5,0xafdb0723}},	//   _günl, váhe, nižn, _brøn
  { {0xb5a70191,0xa5d70029,0xf204006d,0xdcfb00bc}},	//   _прий, _كبير_, лято, _smuč
  { {0x8afc002a,0xa1580033,0xd1b80040,0xdce92e85}},	//   _klęs, насу_, فاقا_, _pleč
  { {0xc05b0036,0xaf07000d,0x859c000a,0x55bc000a}},	// [5cb0] чів_, ечек, _משהו, _צמחו
  { {0xa91d0796,0x213900da,0x752f002a,0xcebb0054}},	//   jižn, _wash_, lecz, пље_
  { {0x64480024,0xafdb0293,0xdce90085,0x81f90015}},	//   ādie, _grøn, _smeđ, _تفجر_
  { {0x753d0014,0x752f005c,0x2d8f04ed,0x22440015}},	//   ndsz, necz, unge_, _إنَّ
  { {0xb4af000b,0x14d8000a,0x5bcb000b,0x752f002a}},	//   _करो_, גודל_, ादेव, iecz
  { {0x996c0089,0x1ee70086,0x6f15002a,0x201c0045}},	//   měř_, _سوری_, _uczc, ăvit_
  { {0x53380008,0x2d8702c1,0x69950063,0xf2d4004c}},	//   גנון_, énes_, крих, נעק_
  { {0x44292e86,0x752f002a,0x4238000a,0x3978004a}},	//   _opa_, jecz, תנהל_, есью_
  { {0x395d00da,0x20090125,0x44292e87,0x752f0535}},	//   _vows_, nrai_, _npa_, decz
  { {0xe6450063,0xab620064,0x7c292a05,0x88bd002a}},	//   веоп, şürm, _iper, ześw
  { {0x4429013c,0xcb080015,0x6605006b,0xa50a2e88}},	//   _apa_, _أيمن_, ъпна, мена_
  { {0x200900df,0x29030007,0x64442e89,0x44292e8a}},	//   krai_, ėjas_, _prii, _bpa_
  { {0xe72e05e6,0x68e92e8b,0x65840030,0x4429036c}},	//   _ке_, mbed, sőho, _cpa_
  { {0xf6250033,0x20092e8c,0x68e92e8d,0x0000006a}},	//   _адко, drai_, lbed,
  { {0xcb120632,0x44292e8e,0x20092e8f,0x68e90aa2}},	//   ילם_, _epa_, erai_, obed
  { {0x644420bf,0x68e92e90,0x7c2923eb,0x23d6009b}},	//   _trii, nbed, _oper, _ицор
  { {0x64a60001,0x6444166f,0x41d2000b,0x2fca01c2}},	// [5cc0] _јапа, _urii, _दूरस, _pibg_
  { {0xdee6013e,0x68e90012,0xafdb04d1,0x69cb2e91}},	//   тожи, hbed, _trøn, _lige
  { {0x25b100dc,0xd35700f3,0x6df30015,0x68e90547}},	//   _álló_, _סיטי_, لكلا, kbed
  { {0xf652000a,0x865a000a,0x365a004c,0xc7c80016}},	//   יצב_, ודעי, וכענ, _hốt_
  { {0x0ffa0002,0x62a3002a,0xed590085,0xf48d000a}},	//   _تعجب_, ętoś, _nižu_, ּאוּ
  { {0x752f0050,0xdb03001c,0x5b130036,0x5c730036}},	//   zecz, lonê, иміт, шліт
  { {0xf9f70015,0x6a130015,0xc7c80016,0xa91d036d}},	//   نريث_, لبير, _mốt_, rižn
  { {0x79a60063,0x583801b7,0xd90e002b,0x98c62a4b}},	//   ърле, езия_, زیت_, кспл
  { {0xdb012e92,0x9997006b,0xa5c7001a,0x57f30033}},	//   _chló, ъкът_, _ljóð, апыт
  { {0x61fe002c,0x69cb2e93,0xc7c80016,0x752f002a}},	//   _ovpl, _eige, _nốt_, wecz
  { {0x752f0050,0x68e92e94,0x442925ec,0xaaa90065}},	//   tecz, bbed, _spa_, _चुपक
  { {0x7982005c,0x291213e1,0x20090091,0xeeeb0016}},	//   _umow, _øya_, yrai_, _đọng_
  { {0xc4580080,0x94a8006d,0xc7c80016,0x752f002a}},	//   виях_, втра_, _bốt_, recz
  { {0xa5c70084,0xc7c80092,0x2009151c,0xa7730033}},	//   _bjóð, _cốt_, vrai_, _кліч
  { {0xc7c80016,0x2d842e95,0x69c02e96,0xf6570058}},	//   _dốt_, _omme_, omme, _لجيش_
  { {0x656900f2,0x0eeb000b,0xbeeb000b,0x44292e97}},	//   öehd, टर्स_, टर्न_, _tpa_
  { {0xa0c40029,0x7ff400e6,0x6ff400a2,0xaaa9000b}},	// [5cd0] ليفو, لسلا, لسلط, _चुनक
  { {0x63702e98,0x68e9016f,0x65b60057,0x7de7005e}},	//   _täna, zbed, máha, відд
  { {0xf41f022d,0x9f340036,0x68e90064,0x637003a4}},	//   ltä_, рехі, ybed, _känn
  { {0x5bcb000b,0x5c7509c3,0x63701f26,0x1bd50248}},	//   ाद्व, ллет, _jänn, годя
  { {0xf41f022d,0x317a0008,0x8c2500a2,0x8d77002b}},	//   ntä_, _נרשמ, افته, _یارا
  { {0xf41f022d,0x2d84022d,0x69cb271c,0x69c02e99}},	//   itä_, _emme_, _sige, emme
  { {0x69cb2e9a,0xf41f008c,0x68e92e9b,0x25a919dc}},	//   _pige, htä_, tbed, _okal_
  { {0xe9a90086,0xd2b80008,0x64410024,0x92b8000a}},	//   رگان_, כלות_, ālij, כפוף_
  { {0xccf20008,0x9c640086,0xc174000a,0xf7190033}},	//   _לכן_, _پهلو, יחק_, ніны_
  { {0x25a90049,0x6be8000a,0x68e9186c,0x636b0405}},	//   _akal_, _יַעַ, sbed, _dünk
  { {0xcb680074,0x8f9c01d8,0x39150087,0x5ee8000a}},	//   _جمله_, ויזי, _مواز, כַרְ
  { {0xceb201ac,0xc7c80016,0xc9840b1e,0x94aa0015}},	//   מיי_, _sốt_, _кучи, ّاسِ_
  { {0x973c016f,0xa5c7002e,0x9583004a,0x7d36004c}},	//   moćn, _sjóð, сляе, נטשנ_
  { {0x31be000b,0xdb1a0077,0x7584002b,0x66e200a5}},	//   ्द्ध, _sitú, _چیدم, _лоша
  { {0x679a0053,0x412a120f,0x5756000a,0x379a004c}},	//   _אױסג, ново_, _תבצע_, _אױסע
  { {0x79890050,0x00e40086,0xc692000f,0xe058002b}},	//   niew, شتری, _לאו_, پیست_
  { {0xc7c80023,0xceea0010,0x90a50015,0xd0070a0b}},	// [5ce0] _tốt_, едзе_, لحكم, лете_
  { {0xef170001,0xdb03001a,0x62090061,0x547b000a}},	//   лму_, llnæ, üslü, _נטיו
  { {0x6fb30029,0x9d460063,0x1eaa0029,0xedf50086}},	//   حملا, лежд, راطي_, ليلگ
  { {0xacf60029,0xc237000a,0xdb030144,0xbcf6009a}},	//   اسات, _ערכו_, lonè, اساغ
  { {0x1af4042b,0x7af82e9c,0x001a0138,0x2d9e04e6}},	//   апля, tavt, _яўны_, _ítem_
  { {0xdfcf0021,0x33c9000a,0x2cad00da,0x5bb700e2}},	//   _ريف_, ֣הוּ_, _dyed_, глія_
  { {0xda0b000b,0xbf10000b,0x39a6006b,0x2cad2e9d}},	//   संगत_, ालीन_, лшив, _eyed_
  { {0xf41f022d,0x6e93003b,0x798900dd,0x5e930015}},	//   ytä_, _الفا, giew, _الفط
  { {0xd6d0003b,0x1d07006b,0x3157004c,0xd37f0085}},	//   يقة_, _щети_, ריפן_, šćih_
  { {0x10370008,0x501b0008,0x65b6163c,0x25a92e9e}},	//   נטים_, עויו, váha, _skal_
  { {0x0f570008,0x98a40091,0xdb030144,0xcf57000a}},	//   איים_, demą_, donè, אבית_
  { {0x1a9b00b4,0xf41f022d,0x8673005e,0x4a9b004f}},	//   _איבע, ttä_, слює, _איבג
  { {0x637001d1,0xf76f0086,0xdceb0091,0x0000006a}},	//   _vänn, زای_, aigė,
  { {0xa6660087,0x636b0012,0x083b05bd,0xf41f008c}},	//   _مطبو, _küni, _רעגל, rtä_
  { {0xf41f0945,0x637000f2,0x06b10046,0x26db004f}},	//   stä_, _tänn, čící_, _אקומ
  { {0x65b6002e,0x810f000b,0x39810091,0x38d6000a}},	//   páha, िलेख_, tųsi_, אֵ֑ל_
  { {0x2ef5000d,0x26ca006f,0x94ab00fd,0x90550033}},	// [5cf0] изар, ľbou_, _ятка_, швац
  { {0x2007065d,0x26ca0107,0x7989002a,0xdb030144}},	//   čni_, žbou_, ziew, conè
  { {0x2cad1613,0xc7b3000a,0xecf90923,0x75d30045}},	//   _syed_, צבע_, вееш_, _păzi
  { {0xd2580138,0x0000006a,0x0000006a,0x0000006a}},	//   _сць_,   ,   ,
  { {0x9c870086,0x798907cc,0xdca500d7,0xc0ab0031}},	//   دشاه, view, јали, _ساحل_
  { {0xfbd000b0,0xda650063,0xaed40323,0xab290170}},	//   سته_, ивли, _горш, тока_
  { {0xdd9b008f,0x79892514,0xc334000a,0x0000006a}},	//   _зша_, tiew, מוס_,
  { {0x7c3e005c,0x8e840015,0x7afd003d,0xa80501e8}},	//   łpra, _طلقه, _ēstu, азил
  { {0x23a5005d,0xae0d005d,0xda09002b,0x38ca002b}},	//   ओवाद, ांकन_, ريکه_, پايی_
  { {0x386200c0,0xa7b50054,0x79892e9f,0x9f63005e}},	//   äkra_, јсиј, siew, ифiк
  { {0x0f580135,0xf1b5000b,0x7989002a,0x957d0091}},	//   טיזם_, ंतान, piew, mpąj
  { {0x0446119f,0xe4c6006b,0xd46a0004,0x7bc3007c}},	//   аемн, ийни, виме_, lmnu
  { {0x37750010,0x7d04002d,0xa116002b,0xdc35004c}},	//   _выйс, óisi, یوست, באָט_
  { {0xf1aa002b,0x987a0447,0xa87a000a,0xe29a008b}},	//   چاره_, _באנט, _באנר, ваг_
  { {0x0cb2021e,0x62630877,0x27ff0061,0x01660912}},	//   _जर्म, овра, lsun_, акво
  { {0x68fb00df,0x7a4000dc,0x96040018,0x00e62ea0}},	//   naud, látá, _ابوم, ржан
  { {0x65b600dc,0xdb030251,0x9f862103,0x2616000b}},	// [5d00] láho, ponè, агад, पंथी_
  { {0xc3fb0008,0x27ff00f2,0x7a4000dc,0xfe720115}},	//   _שליש, isun_, nátá, يدا_
  { {0x6cd60029,0x3eae193d,0x68fb0201,0xdfa90015}},	//   لقضا, æft_, kaud, اطقه_
  { {0xe29b0008,0x656400f2,0x27ff2ea1,0x68fb09e2}},	//   _ישיר, _joih, ksun_, jaud
  { {0x68fb0024,0xaa57002b,0xbc370058,0x7c3b01d3}},	//   daud, یلها_, لسوا_, _csur
  { {0xf4130008,0xf53f00c0,0x6c330015,0xa4b7000a}},	//   קפו_, llåt_, تفها, בלנה_
  { {0x65b600dc,0x65bd00dc,0x8f9b00a3,0x3f8f0003}},	//   jáho, léhe, _סילי, ègue_
  { {0xada3008f,0x7d1b0125,0x4938004a,0x6da307f7}},	//   _дасл, _gcus, узию_, _диса
  { {0x49730191,0x65b60089,0x39730010,0xa3b6021e}},	//   ільс, táhn, ільё, जता_
  { {0xe56800b4,0xec37000a,0x2509002b,0x68fb007c}},	//   _אַ_, _דאמר_, گردی_, aaud
  { {0x637001d1,0xa4d50036,0x2d9e0152,0x68fb2ea2}},	//   _vänl, йоні, _êtes_, baud
  { {0x65b60089,0x2509002b,0x7bcf0003,0x6d420d89}},	//   sáhn, دردی_, _écur, ndoa
  { {0x38570086,0x6d402ea3,0xb97b004c,0x65bd0030}},	//   _نشود_, _mama, _בראז, jéhe
  { {0xf87b0008,0x6d401636,0xd6d000e5,0x57fb000a}},	//   _שְׁל, _lama, _عقب_, _ילדו
  { {0xe2f8005e,0x7c220201,0xd7bb000a,0x67bb000a}},	//   ресі_, htor, _שצור, _שמוק
  { {0x65b6002c,0x44f5023e,0x75d30045,0x30e80b1e}},	//   náhl, _упис, _căzu, ифун_
  { {0xdefb005f,0xdfd10029,0x9f5200f2,0x65bd00dc}},	// [5d10] вые_, سيا_, ksyä_, géhe
  { {0xc43c0008,0x6576002c,0x7d1b04ed,0xdb0302c1}},	//   _יתחי, _zlyh, _scus, poné
  { {0x5cd50029,0x6d402ea4,0x765c008c,0x5f28005e}},	//   مقاط, _bama, äryh, роєм_
  { {0xbd180191,0xa5d90053,0x2906003f,0xd657000a}},	//   иції_, אַסי, _ndoa_, ייבת_
  { {0x91ba000a,0x6d402664,0x515a000a,0x44390034}},	//   _תמרי, _dama, _עכשו, nws_
  { {0xa03a0053,0xdf470010,0x5ba80033,0x0c24008b}},	//   _געשפ, _тэмп, акім_, юмін
  { {0xf1bf0092,0x03780008,0x7c222ea5,0x6d402ea6}},	//   _khá_, שתות_, ator, _fama
  { {0xa37b0020,0x27ff0604,0xa3d7000b,0x2d8e0003}},	//   spõh, tsun_, िदा_, éfet_
  { {0x67550015,0x6c850015,0x7c2203b0,0x68fb14b3}},	//   مخدر, _الذم, ctor, raud
  { {0x65b600dc,0xe7390001,0xfbd00225,0x6d4028f8}},	//   táho, ћен_, _قتل_, _zama
  { {0x27ff04ed,0x68fb2ea7,0xc4c9000a,0xba740015}},	//   ssun_, paud, _נג_, _وامت
  { {0x29020014,0x65b60030,0x6d402ea8,0xf1bf2ea9}},	//   ókat_, ráho, _xama, _nhá_
  { {0x65b60014,0xc8da0053,0xd8d6004c,0x764a0034}},	//   sáho, _עקסט, _הונט_, _erfy
  { {0x65bd0030,0x43750e71,0x395f2eaa,0x0000006a}},	//   véhe, оуст, ljus_,
  { {0x11da0029,0x7c220e8c,0x44392eab,0x91e607d1}},	//   اورة_, ztor, aws_, собе
  { {0xdfd20029,0x7c22005c,0x65bd00dc,0x659300d7}},	//   كير_, ytor, téhe, _нају
  { {0x75d30011,0xf1bf002d,0xe571000a,0x44390034}},	// [5d20] _văzu, _dhá_, _חַי_, cws_
  { {0x395f0005,0x20002660,0x7c222eac,0xa34a0033}},	//   hjus_, rsii_, vtor, _ёзна_
  { {0x637001d1,0x65bd0014,0xdfcf03c4,0x6d402ead}},	//   _länk, séhe, ريم_, _pama
  { {0x2ef8020a,0xa136002b,0x7c222eae,0x7c060015}},	//   _werf_, _اردش, ttor, مبتك
  { {0xdb0101cb,0x6d400045,0x6d42255e,0x251b000a}},	//   _sklá, _vama, rdoa, רונא
  { {0x6d400573,0x395f0091,0x7c222eaf,0x0000006a}},	//   _wama, ejus_, rtor,
  { {0x5a340036,0xba2a002b,0x65b60046,0x8a460015}},	//   інит, استم_, táhl, إئتم
  { {0xdb010089,0x7d960029,0x8d9600a2,0x1e97000a}},	//   _vklá, _الرؤ, _الرش, _הכלל_
  { {0xd90d0086,0xdb1a0030,0x6d8b000a,0xa71400ce}},	//   ئیه_, _kitü, _עָלְ, омпі
  { {0x8b65003b,0x65b60089,0xfafe0024,0xdce00085}},	//   _والم, sáhl, šība_, _momč
  { {0x4a9a0010,0xdb010089,0xc7b90030,0xa92a005e}},	//   _стаў_, _uklá, mtől_, _біле_
  { {0x44390026,0xc7b900dc,0xd5b80449,0xe4e401f3}},	//   tws_, ltől_, йся_, зірн
  { {0x69da003f,0x386d00c0,0x44392716,0xb48b0015}},	//   _hute, cyer_, uws_, ائجك_
  { {0x69da2018,0x44390026,0x325503de,0x7afa2eb0}},	//   _kute, rws_, овгр, _jett
  { {0xa7850086,0xf1bf0092,0x5693119f,0x7afa2eb1}},	//   _بشنو, _phá_, _нашт, _mett
  { {0x92940010,0xc05b0127,0x0718000b,0xdcfb0085}},	//   часц, ліз_, _दाँव_, _imuć
  { {0x7ff7003b,0x657d002f,0xc7b900dc,0x1fdb0015}},	// [5d30] إسرا, mhsh, ktől_, اظرة_
  { {0x69da014c,0x7afa1475,0xd5b9003d,0x644d0003}},	//   _oute, _nett, itām_, _irai
  { {0xdea1002b,0x2eff0003,0x69da1db1,0x3a3e01c2}},	//   ذیری, _œufs_, _nute, _nstp_
  { {0xd5b90024,0x61e80107,0xbcb5004a,0x644d2eb2}},	//   ktām_, ídle, обещ, _krai
  { {0x7afa2eb3,0xe3b0002b,0x628804b2,0x395f003d}},	//   _bett, _زری_, údov, vjus_
  { {0x7afa0b7a,0x661d0050,0x7ee50029,0xc7b90030}},	//   _cett, ński, _ذكرن, gtől_
  { {0xd90f0086,0x637000c0,0x2e480063,0x386d2eb4}},	//   فیا_, _sänk, _лято_, wyer_
  { {0x644d002f,0x636b00b8,0xadbd0033,0xdb1a002a}},	//   _orai, _küns, _рабi, _bitó
  { {0xb901014e,0x395f007c,0xd5b20016,0xb8650015}},	//   _दल_, rjus_, húc_, تاغو
  { {0x69da001c,0x752d003f,0x2d8f1aa2,0x7afa2eb5}},	//   _fute, _abaz, lige_, _gett
  { {0x06550010,0x69da2eb6,0xdb030030,0xdb58006b}},	//   ітоў, _gute, noní, _уют_
  { {0x637000c0,0x94260080,0x7afa2eb7,0x2d8f11a6}},	//   _tänk, омме, _zett, nige_
  { {0x3211005c,0x644d2eb8,0x2d8f007c,0x6aab000b}},	//   erzy_, _crai, iige_, _ज़रुर
  { {0x2d8f0012,0xdb030046,0xe4090046,0xd6db0033}},	//   hige_, koní, énář, _стд_
  { {0x7d0902d5,0x644d2eb9,0xd3480086,0x27ed2eba}},	//   _odes, _erai, لیکه_, lpen_
  { {0xa1160029,0x2d8f02c6,0xe4d60015,0xe297005e}},	//   تورت, jige_, _بتثب, іат_
  { {0x42d602e1,0x6f6601f3,0x644d2ebb,0x2d8f0592}},	// [5d40] _міну, оваз, _grai, dige_
  { {0x6aab005d,0xdb030077,0x7d092ebc,0xde760015}},	//   _ज़रूर, foní, _ades, يداع
  { {0x6721005d,0x0721005d,0x0d8615e6,0x2d8f0012}},	//   _मानक_, _मानव_, олжн, fige_
  { {0x0dc90015,0xc692000a,0x69da2ebd,0x7bc12ebe}},	//   مبنى_, ואב_, _rute, _ahlu
  { {0x69da00df,0x27ed0111,0x636b2ebf,0x61ee00dd}},	//   _sute, jpen_, _tünt, lpbl
  { {0xd9b4005d,0x69da046c,0x7d092ec0,0x7bc12ec1}},	//   ुष्ट, _pute, _edes, _chlu
  { {0xfe420074,0xfce60036,0x27ed0111,0x7e230e88}},	//   _تکذی, _мово, epen_, _одрж
  { {0xf2d3000a,0x63700012,0xd9430054,0xc7b90030}},	//   ועו_, _däni, дећи, stől_
  { {0xd8b70015,0x77b40144,0x99830015,0x7afa2ec2}},	//   يدًا_, làxi, بليو, _tett
  { {0xdb1a001c,0x7bc1002d,0x9f49001a,0x7afa008c}},	//   _vitó, _ghlu, nsað_, _uett
  { {0x3218003e,0x9f4000f2,0x69da0044,0x644d2ec3}},	//   jury_, mpiä_, _uute, _srai
  { {0x758b05c4,0x3218037c,0x644d2ec4,0xada1001a}},	//   рсов_, dury_, _prai, _óútf
  { {0xf74627e3,0x5faa0065,0x399b004f,0x534702ed}},	//   _медо, कवाल, _דיאד, охва
  { {0x644d0152,0x3211002a,0x80b4000b,0xe7372ec5}},	//   _vrai, trzy_, _आरजे, _меч_
  { {0xf3640080,0x644d0335,0x236c0123,0xe1670054}},	//   фтян, _wrai, ödja_, ођан
  { {0xab5d005c,0xa91d0007,0x644d04a8,0xc1b90033}},	//   _duży, sižv, _trai, ёлах_
  { {0x64410048,0xb0c5005d,0x43950063,0x644d12ea}},	// [5d50] ālis, लेंग, _наис, _urai
  { {0xb1e70015,0x2d9c01ce,0x2d8f0547,0xdb032ec6}},	//   _وأجه, éven_, wige_, toní
  { {0xdb1a0089,0x636b00b8,0x14c7000b,0xdd950033}},	//   _chtí, _wüns, रेरण, пажы
  { {0xb23a00b2,0xe2920053,0xf5380053,0x31590029}},	//   _פערז, _טװי_, ַטור_, _الحج_
  { {0xdb0a0134,0x515a000a,0x415a000a,0xab5d002a}},	//   ilfæ, _הכרו, _הדרג, _zuży
  { {0xda090040,0x2d8f2ec7,0xdb032ec8,0xfc300058}},	//   ميته_, sige_, poní, ضحه_
  { {0x09e20063,0xef230024,0x220b000a,0x3cf5000b}},	//   нощн, _ceļš_, ׁפַּ, आरआइ_
  { {0xe29c0008,0xe9a80029,0x7d0922fc,0x329c000a}},	//   ישור, يدين_, _udes, יבוד
  { {0xf1b40008,0xdbc60020,0x32180bba,0x69e10085}},	//   וסק_, vöön, zury_, _šveđ
  { {0x63702ec9,0x27ed2eca,0x2ed6000a,0x1b770015}},	//   _hänv, rpen_, ּֽים_, _بدرج
  { {0xdbc60f7a,0x321800da,0x44320c12,0x29d10085}},	//   töön, xury_, _spy_, _ušao_
  { {0x7aba013a,0x3aba000a,0xb925002b,0x27ed2ecb}},	//   _הצעו, _המענ, _رفتي, ppen_
  { {0x44240026,0xc8da000a,0x38580015,0xdce0003d}},	//   îm_, _הקנט, _وشهد_, _jomā
  { {0xe820000b,0xc7a80015,0x32182ecc,0x69c92ecd}},	//   _ममता_, _ودول_, tury_, lmee
  { {0xaacb005d,0xc7b2000a,0x8708000a,0x69c20034}},	//   ाधिक, _רבו_, _וּפֶ, _yhoe
  { {0xe0da0063,0xc24301b0,0x6440001a,0xa5650015}},	//   сва_, энск, æmis, _يدين
  { {0x351b0008,0x21670809,0x69c9008c,0xdce0003d}},	// [5d60] _הופנ, чити_, imee, _nomā
  { {0xa3bf000b,0x6fb60015,0x22570046,0x02460015}},	//   ेषण_, أمطا, ácký_, _فَخَ
  { {0x32db000a,0x22f7004f,0x82f7004f,0x0000006a}},	//   _לחינ, _מזין_, _מציב_,
  { {0x44760008,0xed890033,0x5476000a,0x71a606da}},	//   ּעַל_, осік_, ּגַע_, _хамз
  { {0x69c91de9,0x69c20034,0x76020030,0xad650058}},	//   dmee, _rhoe, _kízá, باله
  { {0xdce00024,0x69c22ece,0x69c903f8,0x600b004f}},	//   _domā, _shoe, emee, _לִלְ
  { {0xcb070029,0x69c22ecf,0xbea3123e,0x0f57004f}},	//   سيين_, _phoe, _зарк, _צילם_
  { {0x7e9b0008,0xd90d0086,0x5e9b000a,0x69c91de9}},	//   _הסלו, لیم_, _הבלק, gmee
  { {0xd8230124,0xeafa0086,0x3ce6002c,0xec7a0286}},	//   едњи, _هرات_, mcov_, _упа_
  { {0x7d022ed0,0xbb86002b,0x69c200da,0x6c7b000a}},	//   laos, _علاي, _whoe, _האמפ
  { {0x69c900dd,0xcdd4000a,0xa2b1000b,0x63ae2ed1}},	//   bmee, ֽךָ_, _आँध्, dobn
  { {0x3ce6002c,0x8e97000a,0xb4950054,0xea77000a}},	//   ncov_, לדיו_, димљ, _מגבר_
  { {0x94ab2ed2,0xdb032ed3,0x0000006a,0x0000006a}},	//   стна_, loná,   ,
  { {0xa8570008,0xe60f002b,0xc7d7000a,0x1ddc000b}},	//   _מידה_, خشی_, _זוגי_, यदात
  { {0x82a40431,0x9989002c,0xf8ad002b,0xa29502a3}},	//   еште, ňať_, _مکی_, фаві
  { {0x2d9c0014,0xdb0a01d1,0xb5a40010,0x673a2ed4}},	//   ével_, llfä, _прый, letj
  { {0xa068000d,0x3ce6006f,0x4fd50c31,0xe4530015}},	// [5d70] паѓа_, dcov_, джат, _أضع_
  { {0xdb030264,0x83190015,0x23fc000a,0x33fc000a}},	//   koná, _بقدر_, _הפזמ, _ההזנ
  { {0x661a01a3,0x8d74002b,0x5475002b,0xf773004c}},	//   nutk, کالا, _رهگذ, עקע_
  { {0x6fd8005d,0x5cb90033,0x673a2ed5,0x9f490125}},	//   _भूकं, олеў_, hetj, mpaí_
  { {0xcb6900d0,0x673a2739,0x7a470030,0xeb8e09c2}},	//   жале_, ketj, kétá, ви_
  { {0x673a00bd,0x65bd01b2,0xe0d2004c,0xf414000a}},	//   jetj, kého, _שײך_, תפס_
  { {0xaa560001,0x661a0375,0xaa45006b,0x3ce6006f}},	//   дију_, jutk, фейл, bcov_
  { {0xeeeb00a7,0x637000f2,0x661a01d7,0x28c9000b}},	//   _động_, _hänt, dutk, ाइलि
  { {0xfc3003c4,0x799b00dd,0xa3dd000b,0x69c91f3b}},	//   _محل_, rnuw, _तूल_, rmee
  { {0x37890036,0x06090a61,0x69c92ed6,0xeaf8002b}},	//   ібно_, онок_, smee, _فرمت_
  { {0xb4e9000b,0x69c9007c,0xe5a62b2c,0x63700a94}},	//   यडू_, pmee, дини, _mänt
  { {0x6abe0012,0x6370008c,0xe8590033,0xe5770033}},	//   üpfe, _länt, _маеш_, дзю_
  { {0x63ae032c,0x18690004,0xd5dd000b,0x95830033}},	//   tobn, _фали_, _नूरज, тляе
  { {0x661a013c,0xd36f0015,0x3ce608a9,0xd7c9002b}},	//   butk, لهُ_, zcov_, _بوته_
  { {0x2327006b,0xcb88000a,0x661a01c2,0x9343006b}},	//   ьори_, פְשֹ, cutk, ънре
  { {0x291f2ed7,0x41b5005e,0x63ae2ed8,0x0000006a}},	//   ngua_, есут, sobn,
  { {0x3ce6002c,0xdb0300dc,0xf992000a,0xdb0a0123}},	// [5d80] vcov_, zoná, דרן_, llfå
  { {0xe3b20029,0x2be1005d,0x4f0a0033,0x27f9006f}},	//   _جرب_, _पढ़ा, інен_, ásny_
  { {0xdb1a00dc,0xcdf50033,0x3ce6006f,0xa3ab000b}},	//   _kitö, еччы, tcov_, गकर_
  { {0xdb0300dc,0x6d910057,0x673a0030,0x80a90065}},	//   voná, sťan, zetj, _झुके
  { {0xdd8f0029,0x3ce6006f,0x113b000a,0x7d022ed9}},	//   جون_, rcov_, _ותכל, raos
  { {0xa08b0008,0x63702eda,0xdb03275d,0xcb670054}},	//   _וְלִ, _tänu, toná, даље_
  { {0x637000c0,0xf9c6005e,0x3ce6006f,0x7bca2edb}},	//   _häns, мщин, pcov_, rmfu
  { {0xd9100074,0x637000c0,0xd80a006b,0xb17b004c}},	//   ایش_, _käns, охол_, ַטיר
  { {0xf1b3000a,0xb4bd000b,0xc0a9000a,0xdb03001a}},	//   כסה_, _अरे_, ּיתָ, llný
  { {0x7d0000c0,0x637000c0,0x661a2edc,0x75241358}},	//   _hems, _mäns, tutk, _aciz
  { {0xaadb0008,0x7d00002e,0x63701b45,0xff17000a}},	//   _וחבר, _kems, _läns, וקית_
  { {0x858b0033,0x65bd01c0,0x661a2edd,0x673a2ede}},	//   іёна_, rého, rutk, setj
  { {0x29042edf,0xb5a40033,0xc7b90030,0xd78a0058}},	//   mama_, трэй, ztői_, _وختم_
  { {0x29042ee0,0xe8d7000a,0x661a2ee1,0x0000006a}},	//   lama_, _חודר_, putk,
  { {0xd8480023,0x6595008f,0x6444022d,0xc7d70008}},	//   _họ_, _паку, _esii, _קווי_
  { {0x7d0000dc,0x200f016e,0xda4b000a,0xe5c70033}},	//   _nems, ágio_, חֲמָ, _ўско
  { {0x03c7000d,0x2fd90040,0x34fc004f,0x112802ed}},	// [5d90] _осом, سواد_, _והחד, ьюри_
  { {0x753d0014,0xcebb0001,0x29042ee2,0x0f1b0015}},	//   lesz, оље_, hama_, تغرب_
  { {0x637001d1,0x29042ee3,0x229500ce,0xd84800a1}},	//   _vänt, kama_, _чиня, _lọ_
  { {0x753d00dc,0x29d10107,0x29042ee4,0x55d9004c}},	//   nesz, _však_, jama_, פֿענ
  { {0x5eeb008f,0xed580036,0x753d005c,0xdb030152}},	//   _мфвг_, ьої_, iesz, nonç
  { {0x6ffa000a,0x6008000a,0xd6c60015,0xce95006b}},	//   _מהשפ, _קִרְ, _مق_, _загъ
  { {0x2d870152,0x753d0030,0x3208000a,0xba75009a}},	//   ènes_, kesz, ֵ֖הּ_, عاتت
  { {0x29042ee5,0x7d002ee6,0xd8480016,0xc9840054}},	//   gama_, _gems, _bọ_, куњи
  { {0xc7950256,0x20090472,0xdd940033,0xec15006e}},	//   ерны, nsai_, _раты, _سواد
  { {0x1665007a,0x6d490034,0x200913b3,0x7c2b0012}},	//   евом, _haea, isai_, mtgr
  { {0xda090086,0x29042ee7,0x753d0030,0x99150033}},	//   _ريشه_, bama_, fesz, _зьлі
  { {0xc329013a,0x2904010b,0x753d0c19,0x20090cd4}},	//   _לו_, cama_, gesz, ksai_
  { {0x200f026a,0x7c2b2ee8,0x5cac004f,0x0000006a}},	//   ágil_, ntgr, ַׁלַ,
  { {0xa3d30033,0x7c2b0012,0x324601c5,0x68e92ee9}},	//   лоўч, itgr, негг, lced
  { {0x69d9003f,0x7c2b007c,0x753d0030,0x877a000a}},	//   _kiwe, htgr, besz, _מאסי
  { {0x4fea0350,0xdb03008c,0x68e90d29,0xc5f2004f}},	//   зман_, lonä, nced, _גדה_
  { {0x6d4b0026,0xbfc60033,0xf537000a,0x859b000a}},	// [5da0] ddga, ебак, _טנקי_, _משקו
  { {0x637001d1,0x29040f58,0xa6f9000a,0x6d5b2eea}},	//   _väns, zama_, לִ֣י, _anua
  { {0x27760053,0x20090509,0x42fb000a,0x7bcf0003}},	//   עגען_, asai_, _מהיס, _écuy
  { {0xd5b90024,0xfce62eeb,0x69d92eec,0x447a000a}},	//   stāv_, ходо, _niwe, ּנַע
  { {0x6d490026,0xdb0300f2,0x29042b7d,0x41bf000b}},	//   _daea, konä, vama_, ्षरस
  { {0x753d0050,0xcb34006b,0x6d4b02de,0xaae600c3}},	//   zesz, текъ, adga, رستو
  { {0x7d000064,0x3ebe002e,0x423a0053,0xd8480016}},	//   _tems, _átt_, לײַא, _sọ_
  { {0x7e0b0008,0x6d490026,0xedd60015,0xb4db0144}},	//   _מִמֶ, _gaea, _أيرد, ldàv
  { {0x69d90176,0x753d00dc,0xc7ba0010,0x98a30054}},	//   _diwe, vesz, зён_, лиће
  { {0x29042eed,0x6d620085,0x69d90012,0xeb97004a}},	//   sama_, štač, _eiwe, _зиу_
  { {0x753d00dc,0x6a160015,0x29042eee,0x6721000b}},	//   tesz, _سبار, pama_, _मारक_
  { {0x29c100dc,0x7bda2eef,0x5e9b004c,0x68e90682}},	//   lóan_, _hitu, לביק, cced
  { {0x753d2ef0,0x7bda2ef1,0xdb180030,0x32182ef2}},	//   resz, _kitu, elvé, erry_
  { {0x0000006a,0x0000006a,0x0000006a,0x0000006a}},	//     ,   ,   ,
  { {0x47890010,0x81c70080,0x61fe0034,0x753d1022}},	//   _ўсім_, ещае, _cwpl, pesz
  { {0xb6bb0008,0x61d80139,0x05770021,0x7bda2ef3}},	//   _מצוי, емся_, _ساعد, _litu
  { {0x20090007,0xbfd9005e,0x6370008c,0x23650123}},	// [5db0] usai_, ддає_, _vänr, öljs_
  { {0x7bda003f,0xf53f0123,0xc49c000a,0xc27503ae}},	//   _nitu, leå_, _משחת, _алој
  { {0xe7170008,0x6d91002c,0xcfa40004,0x29c10030}},	//   תחבר_, sťam, ушти, dóan_
  { {0xd5b3000b,0x63bf0046,0x91f6000a,0xd5b9003d}},	//   ीतिज, ůzně, _שמרו_, mtās_
  { {0x69da005d,0x7bda11ac,0x8c45054c,0xf36b000a}},	//   _पंजी, _bitu, теле, ּדֶּ
  { {0x9f9400b8,0x2601005d,0xfaa9002b,0x9be40033}},	//   mäß_, वीडी_, وهشي_, уіцк
  { {0x3da7008f,0xfebb0086,0xdce2016f,0x7bda0849}},	//   _зраб, _راست_, akođ, _ditu
  { {0x9f4200f2,0xb4e0000b,0xaffb000a,0xd5b9003d}},	//   _etkä_, _तले_, ִּ֖י, itās_
  { {0xf7710115,0x69d9003f,0xf7190033,0x68e90a2f}},	//   لاد_, _viwe, міны_, rced
  { {0xd5b90024,0x7bda01d7,0xf048004f,0x0000006a}},	//   ktās_, _gitu, תָה֙_,
  { {0xab8408f0,0x0000006a,0x0000006a,0x0000006a}},	//   _сутк,   ,   ,
  { {0xa3e6014e,0xf5060063,0x7bda003f,0x316901c2}},	//   _बंद_, ъзмо, _zitu, jjaz_
  { {0xe818005d,0x394d2ef4,0xa4430138,0x7de50073}},	//   _दिया_, mdes_, аняд, _sėsl
  { {0xc88301e2,0x97240002,0x394d2ef5,0x66e202b0}},	//   ığı_, _مفهو, ldes_, _коша
  { {0xd5b9003d,0x69dc0030,0x412a1977,0x394d2ef6}},	//   gtās_, _éret, мово_, odes_
  { {0x29c100dc,0x9f940012,0x394d2ef7,0xa3e60065}},	//   zóan_, fäß_, ndes_, _बूथ_
  { {0xdb1a00f2,0xdfd20021,0x614307f7,0x00e301f3}},	// [5dc0] _yhtä, لير_, шета, ржун
  { {0xef17000d,0xd5b90024,0x13a8002b,0xc477000a}},	//   кму_, stāt_, _سنجی_, _סתיו_
  { {0x11d60029,0x1317000a,0x7bda2ef8,0xfe432ef9}},	//   _لتحد, _בחיל_, _ritu, инфо
  { {0xdb0a06f5,0x6b810940,0xdd8f0021,0x5cf6005e}},	//   llfø, _allg, يول_, тяжу
  { {0x7bda00f2,0xc7b900dc,0xdb0a02c1,0x29c100dc}},	//   _pitu, ntős_, sofí, tóan_
  { {0x1bb30033,0x394d2efa,0xbc670015,0xdee602d9}},	//   абіў, edes_, ئمون_, _јови
  { {0xdb0a0134,0x79a60254,0xbae5005e,0x8f37000a}},	//   ilfø, крие, уцій, _שאלו_
  { {0x29021faa,0x3c92002b,0xbce50015,0xcce50015}},	//   úka_, _پیتز, _مأكو, _مسكي
  { {0xebe60191,0xa3b2000b,0x57b405b3,0x91bb000a}},	//   _розп, टका_, лбит, ומקי
  { {0x394d2efb,0xc7ba004a,0x8b450058,0x0000006a}},	//   ades_, ьёй_, _مضمن,
  { {0xb7630010,0xf53f0123,0x8f1b000a,0xf76f0015}},	//   ртый, teå_, ווית, تاي_
  { {0xd9460124,0xceb3011f,0x661501c9,0xb866012c}},	//   _једи, יית_, ázka, _لاتو
  { {0x661d00df,0x48130036,0x89d7002b,0x645600da}},	//   ąska, _вміс, _شوهر_, _cryi
  { {0xa2950010,0x645600da,0xa3a40099,0x0000006a}},	//   гагі, _dryi, ајск,
  { {0xdcfb010b,0xe1f30015,0xd5b9003d,0xc7b90030}},	//   _sluč, ؤسس_, utās_, rtőt_
  { {0xc6d90053,0x7d04001a,0xd5b9003d,0x645600da}},	//   _אַפר, ðisl, rtās_, _fryi
  { {0x90550010,0xd5b90024,0x636b00b8,0xb44701b0}},	// [5dd0] ывац, stās_, _münz, _рэйк
  { {0xb433032c,0xd3db0015,0x1ef80015,0x2ef40bb1}},	//   ľúčo, _تبعا_, نعمة_, изур
  { {0x645a0048,0xe731000a,0x394d2efc,0x9df9004a}},	//   ātie, מֵא_, ydes_, хнет_
  { {0x7db40010,0xd256000f,0x657d1abc,0x2b4c01d7}},	//   асіц, _עשרה_, nksh, _aadc_
  { {0x711a000a,0x394d2efd,0x0000006a,0x0000006a}},	//   _אורפ, vdes_,   ,
  { {0x447c00b2,0x539c000a,0x6721000b,0x399a003d}},	//   ונדע, ֽיהו, _माइक_, zīst_
  { {0x7982003e,0x61e500f2,0xaa080015,0x8338004f}},	//   _blow, _juhl, نزيل_, דאוס_
  { {0x63b500dc,0x394d2efe,0xca740033,0x4a740033}},	//   hozn, udes_, рушы, рышт
  { {0x63b506e7,0x8c19006e,0x394d2eff,0x66e5110c}},	//   kozn, _سيار_, rdes_, лопа
  { {0xf7450054,0x394d01d7,0x9cc80033,0xd7c900c3}},	//   ћено, sdes_, _рыса_, عوده_
  { {0xf7710086,0x79822ad6,0x98b8003d,0x63b52f00}},	//   لاگ_, _flow, īzāk_, dozn
  { {0x7a7a0053,0x79820495,0xda7a004c,0x59740033}},	//   _ארעס, _glow, _אנער, _вышу
  { {0xedb6000a,0xf773002b,0x68fb2cc0,0x7c8c004f}},	//   רִית_, _پاش_, mbud, ֵאלִ
  { {0xade3014e,0x389a0008,0x289a0053,0x489a0053}},	//   गदान_, _איננ, _אינא, _אינװ
  { {0xf6390053,0x7dca002e,0xafdb00cb,0x443b01cc}},	//   _טײַל, lýse, _esøk, _epq_
  { {0x6456003e,0xd5b200e6,0x6569008c,0x657d2f01}},	//   _tryi, _دفع_, öeht, cksh
  { {0x7dda0089,0x7d04002e,0xefca0080,0x28c9000b}},	// [5de0] _důsl, ðism, елал_, ाइटि
  { {0x7dda0089,0x65bd0030,0x44222f02,0x224d0535}},	//   _půso, véhi, muk_, łeka_
  { {0x7e560010,0x03570053,0x1eb50033,0x7c3b2f03}},	//   ытац, _עיטש_, асцё, _apur
  { {0x56b6004c,0x9dba002b,0xac0a2f04,0x2c08009a}},	//   אפען_, رداز_, енда_, نعتی_
  { {0xdca314b7,0xe0d2002b,0x68fb2f05,0x6b980012}},	//   баци, _دزد_, dbud, tivg
  { {0xcefa002b,0x636b0061,0x68fb2f06,0x29190030}},	//   _سفرش_, _büny, ebud, ósan_
  { {0x7ed50036,0xb4db0251,0xd3570008,0x6e960015}},	//   _вітч, ndàr, טיסי_, _إلزا
  { {0x636b01e2,0x68fb0111,0xd7fa0001,0x63b5002c}},	//   _düny, gbud, нуо_, zozn
  { {0xba180074,0xc173000f,0x44222f07,0xa3b6000b}},	//   ريکا_, מחה_, juk_, ड़ता_
  { {0x4422013c,0x7c22007c,0x9634012e,0x661a00bc}},	//   duk_, muor, аноц, trtk
  { {0xbf9b0008,0x3ce9065d,0x68fb01c2,0xe8fa023d}},	//   תייש, žave_, bbud, _зле_
  { {0xdb18001a,0x61e503f4,0xd5670c91,0x2509009a}},	//   ilví, _ruhl, утоп, خردی_
  { {0xa8770002,0x63b50030,0x657d2f08,0x44222f09}},	//   _محور_, tozn, rksh, guk_
  { {0xb8650086,0xfbd4000a,0xf60a0015,0x69c02f0a}},	//   _خامو, יתָ_, _كتبه_, llme
  { {0x63b52f0b,0x3633002b,0x46570021,0xd5bb0c91}},	//   rozn, _هريس, _مؤيد_, _пси_
  { {0x50f50ea6,0xeeeb0016,0x7c2201be,0x365b000a}},	//   рзат, _đống_, kuor, _טכונ
  { {0x200f0014,0xb7bd0011,0x44222f0c,0x69c02f0d}},	// [5df0] égi_, suţe, cuk_, ilme
  { {0x68fb1ed9,0x2906016e,0xeeab006b,0x61e52f0e}},	//   zbud, _leoa_, нтек_, _tuhl
  { {0x68fb0026,0x4fc40892,0x7c3b0ab5,0xa3b2000b}},	//   ybud, сста, _spur, टकर_
  { {0x69c01e86,0x71470142,0xbc190033,0x66cf0030}},	//   jlme, _схож, вікі_, lóké
  { {0x55780053,0x6ee70115,0x50b9002b,0xf3ff016e}},	//   װעגן_, _مسأل, _شگرد_, ixão_
  { {0xaa150431,0x447c0053,0xab620064,0x5c0402bf}},	//   афиј, ענגע, şünm, сяца
  { {0x44222f0f,0xab8400af,0x69c0007f,0xdb060052}},	//   zuk_, ључк, flme, ðmál
  { {0x27e62191,0x3208000a,0x6e940015,0xdb0a013f}},	//   _buon_, נ֖וּ_, _الِا, rofá
  { {0xac380067,0x77850e91,0x7d0b2f10,0xd90c002b}},	//   _مسلط_, илиз, mags, ریو_
  { {0xe7b2003b,0x25a90005,0x6c840029,0xe7390001}},	//   يميد, _ajal_, _الكم, њен_
  { {0x39150086,0x47380033,0x66cf0030,0x27e60034}},	//   _نواز, учыў_, dóké, _euon_
  { {0x442223ad,0x7d0b0035,0xa50a004a,0x85960004}},	//   tuk_, nags, ъема_, ршоц
  { {0x99d4012c,0xc5f8003d,0x660b0073,0x0000006a}},	//   _اتلا, apē_, _šokė,
  { {0x88c80036,0x68e22f11,0x799b003f,0x6f070046}},	//   _слів_, _zgod, liuw, _nejc
  { {0xd1960083,0x02190036,0x03a30080,0x44222f12}},	//   ашањ, літь_, циро, suk_
  { {0x9d370010,0x44221177,0x79890034,0x659300af}},	//   _афiц, puk_, nhew, _мају
  { {0x55bb0008,0x90a50029,0x7d0b18af,0x20d60036}},	// [5e00] _במקו, محكم, dags, рівс
  { {0x6fc2002c,0xa3ba00e6,0x7c22008c,0x747b000a}},	//   môck, _جابر_, vuor, _סניג
  { {0x5ea60015,0xf557002b,0x6e46004a,0x9965003d}},	//   جمال, _صلیب_, реез, zēš_
  { {0x163600b2,0x3dcd2f13,0xbce50058,0x7c2201f6}},	//   ינער_, _chew_, مأهو, tuor
  { {0xa5d900b2,0xcb6a0ea6,0xdca60bbe,0x6c540658}},	//   אַװי, каде_, шади, склу
  { {0xe45701ac,0xf457000a,0x1eca0099,0x5bb701c6}},	//   יינט_, יינר_, _алги_, алія_
  { {0x7c2200f2,0x7f3b000a,0x5e78000f,0x7d0b0505}},	//   suor, _שעלו, _גָּד, bags
  { {0x66cf00dc,0xfe710015,0xda77006b,0xada61111}},	//   zóké, _عدّ_, ряш_, _табл
  { {0xdb030020,0xad1b039e,0x2177000a,0xe872002b}},	//   elnõ, _שומר, שתפר_, زندگ
  { {0x10370008,0x0000006a,0x0000006a,0x0000006a}},	//   סטים_,   ,   ,
  { {0x0f570008,0x9a6a00e5,0x5a960df0,0x97a30033}},	//   ביים_, _جمال_, _траф, ўрыл
  { {0xd5b80191,0xd6d70010,0xba9b0008,0xdb06002e}},	//   ися_, шты_, _בסבי, ðmæl
  { {0x28d2005d,0xf76f0086,0x98aa003d,0x66cf0030}},	//   देशि, سای_, īmēm_, tóké
  { {0xf7432f14,0xa87b000a,0x92a7012e,0x39442f15}},	//   _мечо, _באדר, ајбл, lems_
  { {0x41e70036,0xdce00089,0x56932f16,0x66cf0030}},	//   ріга, _pomě, _машт, róké
  { {0xdb0a00dc,0x26db000a,0xd6db000a,0x3f9801c2}},	//   elfü, _בקומ, _בחול, _amru_
  { {0x0f15022a,0x1f150033,0xc1080033,0x2eaf000b}},	// [5e10] ймаю, ймаў, рэсе_, _जुड़त
  { {0x7d1d03c0,0xeeeb0023,0x29c100dc,0xb778000a}},	//   _össz, _đồng_, tóak_, נָּת
  { {0xdfd8010f,0xc7b30008,0x7d0b0c77,0x628e002a}},	//   рът_, קבע_, tags, czbo
  { {0xb6d90053,0x8d7400e6,0x2d94005e,0x3cf80015}},	//   אַנט, يانا, оріс, لعهد_
  { {0xa3ae014e,0x7c840001,0x3211002a,0x394f00da}},	//   _कदम_, жује, lszy_, _rags_
  { {0x7f85003b,0xdb030152,0xbef80015,0xdb18016e}},	//   _السن, onné, _نرفض_, lovê
  { {0x09f90029,0x752d0011,0x7d0b0035,0xfbd00015}},	//   دفعة_, _ocaz, pags, ذته_
  { {0xe818005d,0x2129013c,0x78a41af9,0xdb030125}},	//   _दिशा_, ngah_, _živa, inné
  { {0x3c440015,0x79890fd6,0xa3b70065,0x1cbb0058}},	//   _وَفِ, rhew, जवा_, _شارب_
  { {0x9b74003b,0xab740029,0xf0920008,0x2d9d12d1}},	//   _والص, _والإ, פני_, liwe_
  { {0x644d002d,0x3211005c,0x7dca001a,0x9f4c0030}},	//   _asai, jszy_, lýsa, ölés_
  { {0xaca30092,0x7d090201,0x3211002a,0x63a90003}},	//   _ngừn, _jees, dszy_, éenn
  { {0x7d04002e,0xe7392f17,0x43860015,0x7d092f18}},	//   ðisi, _бел_, ملحق, _mees
  { {0xd8d6000a,0x7d0910e4,0xa856000a,0xecb6000a}},	//   _פוסט_, _lees, _לינה_, מפרץ_
  { {0xf7700086,0xa2bb021e,0x15f50115,0x47940058}},	//   _تان_, _शुद्, _استح, _بجنس
  { {0x7d090048,0xd1320015,0x628e2f19,0xf1a90040}},	//   _nees, ثمر_, rzbo, لاقه_
  { {0xa3d8005d,0xa0670549,0x74130029,0x3d0b005d}},	// [5e20] िषद_, бата_, _فويا, ारने_
  { {0xdfcf0115,0xf457000a,0x3211002a,0xe1fa0138}},	//   فيق_, _פייר_, bszy_, _йго_
  { {0x65640f1b,0xa91d0007,0x5ce60015,0x7377000a}},	//   _knih, sižy, مكال, _הגיד_
  { {0xe818000b,0xce050015,0xf2d305bd,0x10a620f0}},	//   _दिला_, تذكي, _מעת_, _гимн
  { {0x7d0d0084,0x31570008,0x3d2b002b,0xe3bf0077}},	//   ðasa, _היכן_, اتمی_, luña_
  { {0xdd92002b,0xbf160015,0xe9f80033,0x543b004c}},	//   _کور_, _دوسب, анкі_, רעסא
  { {0x8e860029,0x3ce90a00,0x7d090159,0xed630046}},	//   _الأه, žava_, _fees, áží_
  { {0xd7f00015,0x6564001a,0x7d092f1a,0x57f41cd9}},	//   وكب_, _nnih, _gees, опит
  { {0x4973005e,0x201201c2,0x4c8624cc,0x2caa0004}},	//   їльс, nsyi_, _улав, _скап_
  { {0xa6140a61,0x2bf7000a,0x274a0054,0x3211002a}},	//   омоч, _לממן_, учио_, yszy_
  { {0x0f570008,0x6ac60002,0x4fbb004c,0x6f4b000a}},	//   זיים_, _اقام, רזיצ, אֲכַ
  { {0x26c20024,0x63700012,0x61fc00bc,0x2012008c}},	//   āko_, _gänz, dprl, ksyi_
  { {0x3211005c,0xe995002b,0xdb1a0046,0x443f0144}},	//   wszy_, _بهنگ, _akté, ïu_
  { {0xf41f00f2,0x47d40015,0x2d9d002a,0x18a7000a}},	//   rrä_, _بيتر, ziwe_, _ל֣וֹ_
  { {0x1b7b0053,0x979b000a,0xe6040015,0xf76f00c3}},	//   נטלע, _תשוק, _بِعَ, _ساو_
  { {0x35a40083,0xf1940080,0x3211005c,0x60f90139}},	//   _најг, пись, rszy_, рная_
  { {0x644d2f1b,0x73c50015,0xb387002b,0xc1040015}},	// [5e30] _usai, _ويعم, _هجده, ثوقي
  { {0x3211005c,0x3f872f1c,0x7d092f1d,0xe3f80058}},	//   pszy_, ónu_, _sees, _اعيش_
  { {0xdcf90115,0x5336000a,0x91e40004,0x2d9d00aa}},	//   لفات_, _ונתן_, _ноќе, tiwe_
  { {0x05c9005d,0xa1592f1e,0xdb180781,0xeeeb0016}},	//   रतिब, _таму_, lovè, _đổng_
  { {0x2d9d003f,0x0c250036,0x7d092f1f,0x78a401c0}},	//   riwe_, імкн, _vees, _živn
  { {0x7d09158f,0x09f5004a,0x8234002b,0xa3bb0065}},	//   _wees, очия, _بریا, ॄति_
  { {0x4a45005e,0xc334000a,0x7d091b51,0x28db0065}},	//   інив, פוק_, _tees, मेनि
  { {0xceb20008,0xa3e9021e,0x09e203ad,0x929c000a}},	//   _חיל_, यदा_, мощн, טיות
  { {0x17f90015,0xd7e6004a,0xe8f60033,0x786500ce}},	//   جربة_, омые_, ўль_, ікоз
  { {0xbca40070,0x4cc8000a,0xd709004a,0xdb03007c}},	//   _عملي, _הֶעֱ, шное_, nonü
  { {0xef120008,0x9ae8000a,0x05aa004a,0xc4c9000a}},	//   וּר_, _הַנִ, ивой_, _סג_
  { {0x9596022a,0xfe830091,0xba470091,0x2b472f20}},	//   ішні, _grįš_, grįš, lenc_
  { {0x2ec6014e,0xd7f8023e,0x69c6000b,0x98c70015}},	//   _वर्त, _луј_, ातरी, _اغان
  { {0xd3ba0036,0x7e7e00f2,0xf1bf002c,0x2b470144}},	//   румі_, yypp, _aká_, nenc_
  { {0xe7960086,0xe16600c3,0x72060015,0x31760004}},	//   _بانک, يدري, توأم, оѓат
  { {0x649a0083,0x65c309ef,0xe3bf1279,0x00860a86}},	//   _втор_, _обща, ruña_, олбо
  { {0x2fda0015,0x387f01d7,0x10a600eb,0x0000006a}},	// [5e40] لورد_, nyur_, циан,
  { {0xbc6a0086,0x7fd5005e,0x03a60004,0x91f60015}},	//   یمان_, піхі, _фиоо, _وأجا
  { {0x6e460002,0x2b470144,0x75490030,0x63bc2f21}},	//   تنام, denc_, _észü, morn
  { {0x302a0036,0x4d660010,0xa8020064,0xa63a0053}},	//   _комп_, юкев, çıkl, יגער
  { {0xfc2f0015,0xa3ae000b,0x63bc0079,0x973c0085}},	//   نحو_, _कदा_, oorn, liće
  { {0xdb97008f,0x7de50007,0x63bc03e6,0x78a42f22}},	//   овіч_, _pėst, norn, _živo
  { {0x63bc04ed,0x973c0085,0xdb182f23,0xdd92012c}},	//   iorn, niće, nové, _قوس_
  { {0x1e97000a,0x8d27006b,0xec7a0033,0xdb03172d}},	//   _וכלל_, _мосв_, _кпб_, fonó
  { {0xd90d0086,0xa8470015,0xdb0325d8,0xdb18013f}},	//   ایه_, قليم_, gonó, hové
  { {0x3dc627d7,0xdb180107,0x5aba0054,0x973c0085}},	//   llow_, kové, _кћер_, kiće
  { {0xcdd40008,0x29560063,0x63bc2f24,0x44220cc6}},	//   ּךָ_, _мъдр, dorn, erk_
  { {0x973c0085,0xdb18013f,0x7d022f25,0x9f8f0030}},	//   diće, dové, nbos, rüé_
  { {0x27f80086,0xdb030533,0x63bc258f,0x3d0b0065}},	//   _افتد_, conó, forn, ारते_
  { {0x46140015,0x27f9006f,0xdc8b000a,0x97c60015}},	//   _فوتر, ísne_, בְלָ, _بتصم
  { {0x66b3005e,0xc2c50015,0xdb182f26,0x44222f27}},	//   _обшу, سيري, gové, ark_
  { {0x35f70086,0xdb1800c0,0x3f8a2f28,0xc5f70015}},	//   _برود_, llvä, _albu_, _بعوض_
  { {0x05d40015,0x12e70033,0xa0680004,0x63bc2f29}},	// [5e50] _تزوج, _мінг, оаѓа_, born
  { {0x3dc6003e,0x973c016f,0xa857000a,0xdb180057}},	//   elow_, biće, חימה_, bové
  { {0x78a40844,0xc3320135,0x22590015,0x2b470030}},	//   _živl, _אוי_, _الجد_, venc_
  { {0x82d6000a,0x3ce9006f,0xd13b006b,0x7c220b14}},	//   _מותג_, ľavo_, _тхо_, fror
  { {0xdfdb010f,0xe3b00086,0x3ce900bd,0xdc980036}},	//   _във_, _سری_, žavo_, овці_
  { {0x50da0008,0xf2d5000a,0x2f280138,0x0000006a}},	//   _לקרא, ֔עַ_, _мюсо_,
  { {0xaa880015,0x2b472f2a,0x3179002a,0x4ea40054}},	//   ينهم_, renc_, _kosz_, _жрта
  { {0x386d08e0,0x63bc2f2b,0xceb2000a,0x7d04001a}},	//   txer_, zorn, _נין_, ðist
  { {0xbab5002b,0xdb1801c0,0x7c222f2c,0x973c0160}},	//   _کماب, zové, cror, ziće
  { {0x1b78003b,0x6a670029,0xbb840015,0xdb032f2d}},	//   _وصلة_, _وطال, _قلقي, ronó
  { {0xa2bb014e,0x98ab0064,0x63bc060b,0xb4b4000b}},	//   _शुल्, ıcı_, vorn, _जुड़_
  { {0xdb032f2e,0x973c016f,0x7c24002d,0x86980033}},	//   inní, viće, áirg, ітэт_
  { {0xb7d6002b,0x19b80015,0x63bc2f2f,0x0000006a}},	//   تویا_, _بطلة_, torn,
  { {0xdb180227,0x973c0085,0x97c4002b,0x27ff1cd7}},	//   tové, tiće, _ققنو, mpun_
  { {0x7d1b016f,0x63bc00c0,0xeb92000a,0xfbd2000a}},	//   _odus, rorn, תָר_, גתם_
  { {0x66ed00dc,0x867a000a,0x3166010d,0x98a2002a}},	//   _főké, _לרצו, ñoz_, żką_
  { {0x53a60080,0x14230010,0x64a60210,0xdb180057}},	// [5e60] _наиб, _здым, _хапа, sové
  { {0xdb0a00c0,0x7d1b0011,0xe437000a,0xdb1800bf}},	//   llfö, _adus, _צריח_, pové
  { {0xdd8f0086,0x27ff00d9,0x8a590024,0xee3a2f30}},	//   گون_, hpun_, šējā, сне_
  { {0xdd990036,0x25a20089,0x361a000a,0xe5f6004c}},	//   оші_, nikl_, מועד, לזער_
  { {0xdd8f0115,0x7d022f31,0xecba0015,0x7376000a}},	//   دون_, rbos, حطات_, ּגֶד_
  { {0x543b0053,0x7d1b0604,0xa3b2000b,0x69dc0030}},	//   מענא, _edus, टकट_, _érez
  { {0x61e60962,0xed5a1c35,0x7d04001a,0xdb030144}},	//   _kikl, _лов_, ðiss, tonò
  { {0x645a003d,0x7c222f32,0x20002f33,0x7bc12f34}},	//   ātij, pror, opii_, _eklu
  { {0x7dda0089,0x61e62f35,0x7c240125,0x0f56004f}},	//   _důst, _mikl, áird, ֜יִם_
  { {0x907b000a,0xabfb000a,0xec130015,0xb8e4000b}},	//   צטיי, _להמר, _أولد, _एड_
  { {0xc7b900dc,0x7c240007,0x78ad002c,0x7bdf0003}},	//   mről_, šird, _ľave, ïque
  { {0xc7b900dc,0x29d30015,0x758b004a,0x78ad0091}},	//   lről_, _كيلس, ссов_, _žave
  { {0x6fbe000b,0x5fbe000b,0x31b6000b,0x0000006a}},	//   ्तां, ्ताल, ंवैध,
  { {0x7dda0089,0xe2f8005e,0x466a01b7,0xc7b90030}},	//   _zůst, зері_, _грим_, nről_
  { {0xc73b000a,0x20070085,0xc7b90030,0x6d402886}},	//   _התות, ćnim_, iről_, _obma
  { {0x31c4000d,0xd6a9002b,0x25a20085,0x66ed0030}},	//   есув, _بدهم_, cikl_, _tőké
  { {0xc7b90014,0xdb1a163c,0x78a40b6c,0x30180015}},	// [5e70] kről_, _aktí, _živj, كتلة_
  { {0x44390024,0x7dca001a,0x6d400012,0x3e6b005e}},	//   mts_, sýsl, _abma, йшен_
  { {0xa195008f,0x44392f36,0x8f0802a3,0xa3e6000b}},	//   _жанч, lts_, яхта_, _बूट_
  { {0x443925ed,0x0000006a,0x0000006a,0x0000006a}},	//   ots_,   ,   ,
  { {0x44390c90,0x7dda0046,0x0000006a,0x0000006a}},	//   nts_, _růst,   ,
  { {0xbb420063,0xfbd30087,0xf458000a,0x44392f37}},	//   вешк, رتش_, פיור_, its_
  { {0x443927fc,0xdce80061,0x442b0144,0x6295166c}},	//   hts_, _çoğa, huc_, nzzo
  { {0xe818005d,0x44392f38,0x2b400085,0x7d1b2f39}},	//   _दिखा_, kts_, đica_, _udus
  { {0xdce00048,0x27ff0049,0x3158000a,0xc158000a}},	//   _domē, upun_, ליהן_, לשהו_
  { {0xe6190036,0x27ff0375,0x3c440015,0x442b2f3a}},	//   одо_, rpun_, _سَمِ, duc_
  { {0x6d4b016b,0x150a0015,0xbef6000a,0x443915fc}},	//   oega, يْدٍ_, וצתו_, ets_
  { {0x9a880029,0x7c24016f,0x64a604c2,0x3aba000a}},	//   _عَنْ_, šire, дама, _ומענ
  { {0xf992000a,0x3958003d,0x44392f3b,0x7c2b2f3c}},	//   _ברא_, ērst_, gts_, nugr
  { {0x69c92f3d,0xdc88000a,0xf745006b,0x73e3004a}},	//   llee, פְרָ, _цеко, кояз
  { {0x0caa014e,0x645d0064,0xf7700015,0x44392f3e}},	//   _कश्म, avsi, _حان_, ats_
  { {0x27e7002e,0x44390b00,0x056608e8,0xc7b90030}},	//   _hinn_, bts_, _цвин, zről_
  { {0xd12f0029,0x44390c16,0x6d4b2f3f,0x200b0034}},	// [5e80] شمل_, cts_, dega, _cwci_
  { {0xef1a02e1,0xe3d60015,0xb5f9000a,0x78a40085}},	//   іме_, _تتبع, ַלְכ, _živk
  { {0x27e70084,0xf7ba0053,0x61e60fc5,0x69c92f40}},	//   _minn_, קזעמ, _tikl, klee
  { {0x27e7052e,0x3ea7002d,0x6f0e0838,0xcc8a0015}},	//   _linn_, únta_, _webc, يناه_
  { {0xc7b900dc,0x6aa6000b,0x7c2b0030,0xab5c01ec}},	//   tről_, गप्र, gugr, _akļa
  { {0x290f0020,0x399100dc,0x39a50024,0xd4970008}},	//   _aega_, _lásd_, zēst_, וכנת_
  { {0xcf570008,0xc7b900dc,0x6d4b2823,0x2d8d00da}},	//   _קבלת_, rről_, bega, _flee_
  { {0xd90d0086,0xc7b900dc,0x69c9043c,0xcd6a0015}},	//   میم_, sről_, glee, _بإسم_
  { {0x274a009f,0xab5c003d,0xd5b9003d,0xd83a0033}},	//   очно_, _ekļa, urām_, цэй_
  { {0x27e7002d,0xf69800d7,0x5c7b015b,0x61fe0085}},	//   _cinn_, звој_, _ואמה, _otpl
  { {0xdce00048,0xe5350010,0x466a0036,0x69c92f41}},	//   _tomē, нень, іром_, blee
  { {0x27e70084,0xd5670805,0x44392838,0x753d0012}},	//   _einn_, фтоп, tts_, ufsz
  { {0x1cbb0053,0x27e713e1,0x20070085,0x44392f42}},	//   ַמלע, _finn_, ćnik_, uts_
  { {0x44390f4b,0x6d4b002a,0xa6aa0015,0xf8ad002b}},	//   rts_, zega, _واثق_, _چکی_
  { {0xeb910053,0x7c2b00b8,0x44392f43,0x47330015}},	//   אָן_, zugr, sts_, _شروز
  { {0xd5b90024,0x69c02f44,0xdb1804b2,0x44392f37}},	//   irāk_, nome, doví, pts_
  { {0x90990063,0xc2eb0029,0x629a002c,0x6d4b2f45}},	// [5e90] чват_, _وعدم_, útor, vega
  { {0x32550809,0x6e950175,0x33fc000a,0x8fa40054}},	//   _звор, низу, _והזנ, вађе
  { {0x4fc416d7,0x6fcb0012,0x03d6000a,0x6d4b2f46}},	//   тста, lück, _רותם_, tega
  { {0x69c0002a,0x98a2002a,0x7d080058,0xdbed00af}},	//   jome, żkę_, ِينِ_, бскe_
  { {0x6d5d002e,0x69c90079,0x6d59059f,0xcb692f47}},	//   _ósam, vlee, rdwa, зале_
  { {0x686d0053,0xcaf5002b,0xcf270021,0xca5503ae}},	//   _באַזו, رستب, _ترحي, етињ
  { {0x27e72f48,0xd5b9003d,0x6d4b2f49,0xba77006e}},	//   _rinn_, grāk_, pega, باشت
  { {0xeab00018,0x3cf80015,0x8de50015,0x69c02f4a}},	//   جعه_, _يعقد_, _أكره, gome
  { {0xb7bd0011,0x1bb50033,0xdd0d002a,0xe8c6006b}},	//   luţi, _збаў, półz, нгъл_
  { {0xe7390001,0xc052000a,0x8b580015,0x20070085}},	//   чео_, נזי_, _يجلس_, ćnih_
  { {0x290f018c,0xaa95003b,0x69d0005d,0xa2bb000b}},	//   _tega_, _ثلاث, _डीवी, _एडग्
  { {0xceb200f3,0xda08002b,0x69c02f4b,0xf8bf0030}},	//   ריט_, _آينه_, come, üés_
  { {0x394d2f4c,0x27e72f4d,0xd5a4002b,0x186916db}},	//   mees_, _tinn_, فلگی, _хали_
  { {0x394d020a,0x987a0053,0x33d5042b,0xc6490015}},	//   lees_, _מאנט, віст, _فجعل_
  { {0x28db005d,0xdb030034,0x32431114,0x61460a15}},	//   मेरि, einë, лерг, нева
  { {0x394d2f4e,0x6fcb0012,0xf8a5002b,0x78a42f4f}},	//   nees_, lüch, لک_, _živi
  { {0xf99200b4,0xe3b20086,0x8c9f005d,0x20ca0015}},	// [5ea0] ארן_, _مرد_, _खेलो, سبري_
  { {0xa2bb014e,0x996c0046,0xdb1819ae,0x16060065}},	//   _शुक्, měť_, toví, वीकर_
  { {0x7dca09f0,0xdfcf0029,0xd337039e,0xf55a000a}},	//   lýsi, حيل_, _אריה_, ּדְמ
  { {0xfd120029,0x99800091,0x6f030061,0x6e230030}},	//   اجا_, čiū_, ınca, ánba
  { {0x8ba60063,0x8cf30033,0x5a5a002b,0x3d2500ce}},	//   нидж, узіц, اﻳﺠﺎ, тьєв
  { {0xdb180089,0xb7bd0011,0xd5b9003d,0xeb971977}},	//   poví, buţi, trāk_, нич_
  { {0xc3330053,0x1c1c005d,0xb7bd0011,0xe9e62ccb}},	//   אוו_, _निकल_, cuţi, нцио
  { {0xf992003b,0x69c01a91,0x394d2f50,0x9f49001a}},	//   طبع_, uome, gees_, lpað_
  { {0xdcef0085,0x57a62f51,0x69c02f52,0x0000006a}},	//   _šeće, ешна, rome,
  { {0x69c0000c,0x80370053,0x5a9622e3,0x1037000a}},	//   some, עניע_, _преф, עטים_
  { {0xcf93000a,0x6456013c,0x65950033,0x69c00d0e}},	//   רטת_, _asyi, вану, pome
  { {0xceb3013a,0x6fcb00b8,0x399a003d,0x8ab7000a}},	//   טית_, tück, gūst_, _אהבו_
  { {0xa3bd005d,0x6fcb0012,0xf53f0123,0xb923009a}},	//   इकल_, büch, rfå_, _صفوي
  { {0x6fcb018b,0xa857000a,0x2768002b,0x07b70058}},	//   rück, _ריגה_, _زشتی_, _كهنة_
  { {0x25ea000b,0xeab4000a,0xe1670054,0xc68f0004}},	//   _घंटी_, דִּי_, нђан, _сѐ_
  { {0x04950029,0x661a00c0,0x3ce902c6,0x8637000a}},	//   _للبح, mstk, žavi_, _נרחב_
  { {0x656d003f,0xb507005d,0xd6df002a,0x93470015}},	// [5eb0] _inah, _व्यय_, ąłem_, _كخدم
  { {0xb7bd0011,0x34380015,0x90540033,0x10640058}},	//   tuţi, _أسيد_, ывуц, دُكُ
  { {0x4e180086,0x394d003e,0xa295042b,0x539c00a3}},	//   فتند_, yees_, _рані, _מיזו
  { {0xe821005d,0xdb030152,0xfc310018,0x63a72f53}},	//   _मिला_, miné, لحت_, lijn
  { {0x2fd90029,0xd2590024,0xd116000a,0xdb032f54}},	//   _يوجد_, āņu_, _בקרה_, liné
  { {0xc4d40632,0x539c000a,0x8b22004a,0x22ab000a}},	//   נגס_, ּיהו, адше, ּבֵ֣
  { {0xbd050152,0x29020061,0x0a6b005e,0x394d2f55}},	//   _créé, ıkan_, ярди_, tees_
  { {0x63a70111,0x4998004a,0xadd50054,0x7c240dba}},	//   hijn, етья_, _робљ, šira
  { {0x0c390015,0xc8db000b,0x394d2f56,0xdd940033}},	//   _زكاة_, मेंट, rees_, _саты
  { {0x656d0482,0xfd4d0023,0xf7450054,0x80d9000b}},	//   _anah, _ngoạ, њено, _मरने
  { {0x6fcb00b8,0x6b7a0053,0xdb7a0053,0x6d5b0201}},	//   rüch, _קרענ, _קנעכ, _kaua
  { {0xdb180089,0x6287002a,0x6d91006f,0xe5a62b2c}},	//   mová, dyjo, eťaz, тими
  { {0x399a00b2,0xdb182918,0x9d1a000a,0x999e0091}},	//   _קינד, lová, וורט, _estų_
  { {0xfbc70086,0x63a723c0,0xc355006b,0xdb032f57}},	//   شت_, gijn, лъсъ, conô
  { {0xdb180089,0x69c6000b,0x25aa0015,0x10f60033}},	//   nová, ातची, _يدعي_, вязя
  { {0xfe720086,0x41590033,0x386006c0,0x7dca001a}},	//   یدا_, ншую_, _širi_, pýsi
  { {0xdb180057,0x7bc32f58,0x008301f3,0xf1a90015}},	// [5ec0] hová, konu, алто, رافه_
  { {0xdb1802d5,0xdfcf0196,0xd00f0029,0x6fb300e6}},	//   ková, قيق_, تلك_, لمقا
  { {0xe3b20074,0xa22a0063,0xdb180089,0x6d5b2f59}},	//   _مرگ_, _южна_, jová, _baua
  { {0xdb1802d5,0x6d930064,0x7e550010,0x867a000a}},	//   dová, _açab, ытуц, ורעו
  { {0x6cc30033,0x7bc32f5a,0xdb0a0695,0xeb9a2143}},	//   айца, fonu, xofó, мид_
  { {0x661a005c,0x5e260015,0x2bc7006b,0x0b180015}},	//   ystk, _لعرق, кущо_, رقبة_
  { {0xcb670001,0xdb180046,0x1ea90015,0x8fa319a5}},	//   таје_, gová, _كافي_, _таре
  { {0x69d90176,0xea950033,0xc213004f,0x63a72f5b}},	//   _chwe, ышчэ, בהה_, zijn
  { {0xdb340074,0x48130010,0x8c460001,0xc7ba004a}},	//   _مذاک, амыс, _језе, дён_
  { {0x7c650015,0x5c37000a,0xdb180247,0x656d2e09}},	//   _حافل, _ברמן_, bová, _snah
  { {0xdb1828cc,0xdce00007,0x2d89007c,0xeb97000a}},	//   cová, _pomė, öaeg_, _שדבר_
  { {0x891a0074,0x64480011,0x63a70079,0x78a40085}},	//   _آغاز_, ădin, wijn, _živu
  { {0xd8730074,0x4876002b,0x63a70079,0x26c2002a}},	//   _ناوب, _جداس, tijn, łko_
  { {0x623521ec,0xdb030003,0xdbcf006f,0xc652002b}},	//   легу, tiné, _sľúb, _نفتک
  { {0x91c70001,0xc7d7000a,0x248d09cb,0x63a72f5c}},	//   вљал, _שווי_, šem_, rijn
  { {0xe5c40036,0x656d0358,0xda5b000a,0xf8c90030}},	//   _всьо, _unah, וכלל, _íéé_
  { {0xdb1802d5,0x7bc30064,0x10140015,0x7bda007c}},	// [5ed0] zová, yonu, لبلد, _ohtu
  { {0x2fc700a7,0x24842f5d,0x3e07006b,0x29da0034}},	//   ông_, ämme_, вядв, lëad_
  { {0x200201e2,0xdb180089,0x7bc315dc,0x99870045}},	//   _etki_, xová, vonu, nunţ_
  { {0xdb1802d5,0x442b0034,0xac95033d,0x4c95009b}},	//   vová, orc_, лаеш, лиес
  { {0xa3b80086,0x7bc32f5e,0xdb03008c,0x6d930061}},	//   _سایر_, tonu, ynnä, _açac
  { {0x764a0134,0xdb1827b8,0x442b0125,0xbb850015}},	//   _opfy, tová, irc_, طلبي
  { {0xa9a528ff,0xda650015,0x69d90034,0xde46002b}},	//   ликд, طاغي, _phwe, _میلو_
  { {0xdb180089,0xceb20135,0xe10c000a,0x7f5c2f5f}},	//   rová, _היל_, ֵּחָ, _zarq
  { {0xdb180089,0xf77100e5,0x7bc32f60,0x2f59000a}},	//   sová, ماد_, ponu, ֲדֹנ
  { {0xdb180089,0x7dd8001a,0xcb080015,0x68fb2f61}},	//   pová, ríse, _ليكن_, scud
  { {0x6f1502c1,0x8f7a000a,0x99350015,0x47580033}},	//   _mezc, תנתק, _مفات, трыя_
  { {0x3ce9016f,0x6b812f62,0x7d190535,0xd5b901ec}},	//   žavu_, _holg, naws, zrāv_
  { {0x28f80080,0xf745062a,0xa87b0015,0x54360138}},	//   _речь_, _бело, _تحضر_, ыхну
  { {0x395d0026,0x395f2180,0x9cd60008,0xf7730031}},	//   _haws_, ldus_, טורה_, _خاص_
  { {0xe29a0a31,0x7d19002a,0x321e00bf,0x442b2f63}},	//   хав_, kaws, éty_, arc_
  { {0x395f2f64,0x7d192f65,0x395d00da,0x200201d7}},	//   ndus_, jaws, _jaws_, _ptki_
  { {0xdb0100dc,0xd1750010,0xdfd20115,0x7d19002a}},	// [5ee0] _emlé, шыры, مير_, daws
  { {0x395d003e,0xd00f00e6,0x6b81096b,0x44202f66}},	//   _laws_, سلم_, _nolg, _ivi_
  { {0x11d603c4,0x6fd00123,0xe8150065,0x7c2b1f6e}},	//   _متحد, läck, _दौसा_, ergr
  { {0x427b0053,0xf652000a,0x127b004c,0x395d0034}},	//   _נאכג, מצב_, _נאכע, _naws_
  { {0x395f0176,0x251b0008,0xbd870015,0x307509d3}},	//   ddus_, תונא, طنون_, _курс
  { {0x8f760036,0x395f0091,0x6b812f67,0xbc67012c}},	//   _сумі, edus_, _colg, امون_
  { {0x8a460029,0x261100bd,0x2d9c0152,0xc333000a}},	//   ائتم, jšo_, èves_, צוה_
  { {0x7d0d0084,0x44200263,0xec160087,0xc213000a}},	//   ðast, _ovi_, _مورد, זהה_
  { {0x6b81018b,0x5b360115,0x6fba000b,0x58d8006b}},	//   _folg, _معار, ्वपू, ъдия_
  { {0x6c830029,0x2ca70001,0xf62a0036,0x395f2f68}},	//   _الْم, _скуп_, німи_, adus_
  { {0x9f4a002d,0xd6d00070,0xd5b90024,0x35b503a8}},	//   _cibé_, تقد_, krāt_, ибор
  { {0x6d4600c0,0xd6d704ab,0x2abb004c,0x4a57000a}},	//   _ökad, ыты_, _אמבא, _תשאל_
  { {0x261100bd,0xb8650086,0x98a31b04,0xd327004a}},	//   ašo_, _پانو, _лице, льви
  { {0x752404ed,0x7d19005c,0x44200007,0x289b000a}},	//   _ediz, zaws, _dvi_, _אידא
  { {0xb5950036,0xdcfb0089,0x86260010,0x32b80015}},	//   _вийш, _souč, _сьле, هدفة_
  { {0x6fd02f69,0x442b0030,0xa1582f6a,0xdcfb2f6b}},	//   läch, prc_, ласу_, _pouč
  { {0x7ff70029,0x0f15007a,0x69dc000b,0xe0d00015}},	// [5ef0] اسرا, имаю, _पठनी, كزك_
  { {0x6fd000b8,0x395f0007,0x2ba9000b,0x8504002b}},	//   näch, zdus_, _औषधा, _پوین
  { {0x644e00bd,0x12fa0008,0xa283002b,0x7d19002a}},	//   čniš, _בהתב, _ایزو, taws
  { {0x6b810293,0x6fd00012,0xa1940138,0x25ab0416}},	//   _solg, häch, _гаюч, nicl_
  { {0xf41f022d,0x6b811afb,0xe6d1000b,0x7d192f6c}},	//   nsä_, _polg, _हर्ज, raws
  { {0x2009064e,0x3f8f0024,0x93fc000a,0xda650067}},	//   mpai_, īgus_, עלוי, لاعي
  { {0x6b8100f6,0x83380053,0xd35c000a,0x9a240015}},	//   _volg, טאגס_, גדול, معين
  { {0x395f2f6d,0x2ba6000b,0x2009003d,0xdb032f6e}},	//   udus_, कोबा, opai_, miní
  { {0x395f0048,0x3f8306b0,0x5d840029,0xc174000a}},	//   rdus_, _koju_, _القل, מחק_
  { {0xe8480015,0xdb030125,0x9cc80033,0x6fd00123}},	//   اجين_, oiní, _сыса_, väck
  { {0x4420010b,0x59750010,0x2d850152,0xe815021e}},	//   _svi_, _вылу, _îles_, _दौरा_
  { {0xca2c0053,0x629c00bd,0x8e270010,0x8afc005c}},	//   _טובֿ, vzro, нiкi_, _wnęt
  { {0x6d49002f,0x290d003f,0x53a60015,0xd46a0054}},	//   _mbea, mbea_, لمحك, њиге_
  { {0x6fd000c0,0x889a009d,0xd6a90015,0x289a000a}},	//   räck, _בבני, _لدعم_, _בינא
  { {0xf53f0134,0x629c016f,0x6d490123,0x527500ce}},	//   rnår_, uzro, _obea, буту
  { {0xd132003b,0x60260036,0x6fd00012,0x4106135f}},	//   تمر_, идба, päck, рзав
  { {0x2087006d,0xcef6049d,0xf53f02df,0xc483006b}},	// [5f00] айти_, ачењ, pnår_, _млък
  { {0x8fa60033,0xdb032f6f,0xcf260015,0x644100d4}},	//   шазе, finí, شرطي, ălit
  { {0xed5a0191,0xd5b90024,0xee3a2f70,0xdd920015}},	//   кож_, prāt_, тне_, يوط_
  { {0x3d10005d,0x5c060033,0x9d46005e,0x22470123}},	//   ारें_, аяка, редд, _änka_
  { {0x3ad50092,0xb4fb000a,0xedd3002b,0x61e42f71}},	//   _áp_, דפני, آيند, mmil
  { {0xca26067a,0x61f1001a,0xab382f72,0x61e42f73}},	//   афии, _óklá, упку_, lmil
  { {0x5f79000a,0x34d3000b,0x8a030004,0x69aa0058}},	//   _עָשׂ, _सर्द, озје, َابُ_
  { {0x6e930029,0x6fd00012,0x23ad00bc,0x99770045}},	//   _بلفا, wäch, ižja_, văţ_
  { {0x58170010,0x57f30892,0x973c0085,0xa967012e}},	//   ажыў_, опыт, lići, риња_
  { {0x2d842f74,0xfaa6005e,0x61e40a94,0x6009004f}},	//   _home_, _казо, hmil, נִפְ
  { {0x61e40089,0x6fd000b8,0x644d14e6,0x2d842f75}},	//   kmil, räch, _spai, _kome_
  { {0x6fd000b8,0x9a3b000a,0xf41f008c,0x60210046}},	//   säch, _יתבק, tsä_, námý
  { {0xb447008f,0x8434005e,0x94a8125d,0xb8930015}},	//   шэнк, оняє, атра_, _ولمع
  { {0x248400c0,0xa5c7001a,0x989b000a,0x0324004a}},	//   ämma_, _blóð, _שֹׁפ, ждён
  { {0xf41f0945,0xb06200f2,0xd5b90024,0xf1a7127b}},	//   ssä_, äänn, urās_, аран
  { {0x3d10014e,0x2d842f76,0xd1b80015,0xf41f008c}},	//   ारों_, _nome_, لاقا_, psä_
  { {0xc1040029,0x75d50086,0x55bc000a,0x7c24036d}},	// [5f10] توقي, _پيکا, _שמחו, širj
  { {0x6e670063,0x68f50089,0x53a40015,0x7dd8001a}},	//   итеж, ězdi, _وميك, vísa
  { {0xede70010,0x9757000a,0x80a7000b,0x4ea401b0}},	//   аўдн, שיבו_, _घेरे, орца
  { {0x2d84052a,0xdb0a001a,0x91e40004,0xbc190033}},	//   _come_, nnfæ, _моќе, гікі_
  { {0x9951099c,0x2d842f77,0x1bd5006b,0x7c94002b}},	//   _náš_, _dome_, бодя, يشها
  { {0x2bbb003b,0xf458000a,0xebc70054,0xecb8000b}},	//   خاصة_, יידר_, шљен, _अशरफ
  { {0xb2220084,0x5e950029,0x2d84001c,0x8e8500e6}},	//   _áætl, _الأط, _fome_, _الزه
  { {0xd2b8011f,0x7dd8002c,0x7e62002a,0x61fa001a}},	//   ילות_, písa, łopc, ítli
  { {0xf8a90074,0xf7190010,0x290d2f78,0x4c94005e}},	//   دگاه_, ліны_, rbea_, _дитс
  { {0x25a90509,0xda67002b,0x0000006a,0x0000006a}},	//   _amal_, _پائي,   ,
  { {0x61e42f79,0x8aa70ef5,0x6f7a004f,0x8f9a004f}},	//   ymil, _трад, רְפו, ריתי
  { {0x857a000d,0xceb200a3,0x764100aa,0xba740015}},	//   усот_, ליי_, rtly, _باكت
  { {0xa5c7002e,0xe821005d,0xa3bc0065,0x58f6004f}},	//   _slóð, _मिटा_, _अदद_, _המנע_
  { {0x61e400da,0xd6a8002b,0x25a92f7a,0x0000006a}},	//   wmil, ادیم_, _emal_,
  { {0xe2972f7b,0xe716000a,0x91960054,0x412a0a13}},	//   бар_, _החצר_, бјаш, лово_
  { {0x61e41b37,0xc2432f7c,0x21a301ca,0x973c0160}},	//   umil, янск, писм, vići
  { {0xe0da2f7d,0xa3ba0086,0xbeaa002b,0x03a6004a}},	// [5f20] ува_, _مادر_, گهان_, _гипо
  { {0xe47b01c8,0x2d84003e,0xdf290029,0x50b50033}},	//   _עריכ, _some_, لأمن_, істу
  { {0xc7d60008,0xd35b000a,0xdb030144,0x44222e0e}},	//   צועי_, _גדיל, dinà, lsk_
  { {0xc6da0053,0x80a60086,0x628e0091,0x8d1a0067}},	//   אַדר, _همجن, mybo, ازار_
  { {0x653b0053,0xdb0100dc,0x853b0008,0xa3bc000b}},	//   רענד, _emlí, רגני, _अदा_
  { {0xdb030144,0x7f860015,0xd00f00c3,0x5bb700e2}},	//   ginà, _الآن, _سلف_, блія_
  { {0x2d842f7e,0x5b230015,0xbb4700c3,0x628e2f7f}},	//   _tome_, سفيل, صلين_, nybo
  { {0xed5a0191,0xd90d0086,0xc27b000a,0x6f1e01c0}},	//   _щоб_, نیم_, טרצי, lapc
  { {0xf8af0015,0xe872002b,0x44221400,0x628e01c0}},	//   ّةٍ_, سندگ, jsk_, hybo
  { {0x17f70029,0x995104af,0x628e0007,0x7d0204ed}},	//   حرية_, _váš_, kybo, lcos
  { {0x9f9400f2,0x7c222f80,0x45b9005e,0xf1c8000b}},	//   mää_, lsor, игою_, लवान
  { {0x799b0111,0x7d0200bd,0x628e0007,0x69da00e6}},	//   chuw, ncos, dybo, _صباح_
  { {0x6f1e0014,0x94ab0684,0xe4c7004a,0x442202de}},	//   kapc, утна_, сённ, gsk_
  { {0xa8570008,0xccab0008,0x9f9400f2,0xe694004a}},	//   _לידה_, אֱלֹ, nää_, _милы
  { {0x92940033,0xf7d7000a,0xdb0a2f81,0x11d70015}},	//   парц, _הוגש_, rifè, مترد
  { {0x16370008,0x7a8b0008,0xd904002b,0x78ad0091}},	//   _הנהר_, אָמַ, عی_, _žavi
  { {0x9f9400f2,0xc10400c3,0x628e0061,0x0000006a}},	// [5f30] kää_, سولي, aybo,
  { {0x9f9400f2,0x673a02de,0xbef5000b,0x7c222f82}},	//   jää_, ngtj, ेडेन_, dsor
  { {0xdfd80063,0x9e150036,0xdb030264,0xf5ab000a}},	//   сът_, ідді, jiná, ְבְּ
  { {0xfe700029,0x25b9002e,0x3cf80015,0x3cd50acc}},	//   عدل_, nnsl_, معهد_, ожес
  { {0x913a0053,0x7c840001,0x0c2400fd,0x46cf000b}},	//   _דערק, зује, змін, _सुनह
  { {0xcb690001,0x7e62002a,0x60dd003d,0xba75002b}},	//   раке_, łopa, _izsm, قابت
  { {0xfbd00029,0x499909ef,0xc334000f,0xb9c50015}},	//   رته_, ития_, לוס_, يقتي
  { {0x99150036,0x38290001,0xe9d905e6,0x1989004a}},	//   цькі, ажио_, јки_, рбии_
  { {0x2eb9000b,0x628e002a,0x718c000a,0xb8560015}},	//   _आशुत, zybo, רְוַ, قليص_
  { {0x76252f83,0x6dbc2f84,0xf6250296,0xcb680054}},	//   омоз, nčan, одоо, _лађе_
  { {0x98b901e2,0xcb120008,0x7d1b2f85,0x36c5056d}},	//   ısı_, _חלב_, _keus, юбог
  { {0x3cf0005d,0x1dc9000b,0xf8750015,0xfe11000b}},	//   ुँचे_, िकित, _وهاج, डीएस_
  { {0x628e0026,0x44240425,0x7b02008c,0x6b680030}},	//   wybo, ém_, _äytö, ségű
  { {0x7c24002d,0x628e0007,0x6dbc0085,0x44220cbb}},	//   áiri, tybo, jčan, rsk_
  { {0x6d930061,0xa18a006b,0x46150015,0x23d50033}},	//   _açam, абва_, _بوعر, яцюр
  { {0xb1460010,0x7c220026,0x7c240263,0x7bca2f86}},	//   ўнал, ysor, širi, zofu
  { {0xef1a2f87,0x7bca003f,0xdb0301b2,0xc952000f}},	// [5f40] има_, yofu, ziná, ומן_
  { {0x3fe30036,0xafdb02e9,0x65641437,0xde960015}},	//   джув, _spør, _haih, يجاب
  { {0x9f94022d,0x291f007c,0x2eee0123,0xdb1c0046}},	//   vää_, kaua_, äff_, ázím
  { {0xdb030107,0xb6ba000a,0x216a005e,0x6446008c}},	//   viná, בצעי, _тими_, otki
  { {0x9f94022d,0x7c830080,0x4c560015,0x38c30091}},	//   tää_, дуще, تضار, _jūrą_
  { {0x7d022f88,0x7c222f89,0x7d1b00aa,0x6564008c}},	//   scos, rsor, _eeus, _laih
  { {0x9f9400f2,0x7c222f8a,0x6446007c,0xda7a0195}},	//   rää_, ssor, htki, рял_
  { {0x9f94022d,0x6f1c2f8b,0x2d952cd1,0xc986002b}},	//   sää_, _herc, _ерус, تشتي
  { {0xa3da005d,0xc19b0053,0xdb032f8c,0xb902000b}},	//   ़ता_, ישקי, siná, _धर_
  { {0x478a006b,0xdb030264,0x6281008c,0x24440123}},	//   рсим_, piná, älok, döm_
  { {0x4efb0053,0x0f570008,0xf76f0029,0x64460727}},	//   יליג, חיים_, ئاً_, etki
  { {0xd49b005e,0xe60f002b,0x65ab007e,0x6b882f8d}},	//   арг_, کشی_, ртог_, _hodg
  { {0xf3ff016e,0x65642f8e,0x6d400bbc,0xe7860e41}},	//   rvão_, _daih, _mcma, _муко
  { {0xb8070015,0x8c480061,0x0000006a,0x0000006a}},	//   _بيوم_, mağı,   ,
  { {0x6dbc2996,0xb5950054,0x926810b3,0xd6cf1886}},	//   včan, _никш, орта_, _цт_
  { {0x65c42f8f,0x60f9054f,0x6b882f90,0x569b000a}},	//   _обја, сная_, _lodg, _כיוצ
  { {0x7dd8002c,0xc05b005e,0x212a002b,0x8c480061}},	// [5f50] rísl, шів_, صيلی_, nağı
  { {0xdfd10196,0x3f87002e,0x5e6b0001,0x6f1c2f91}},	//   ريا_, ðnu_, ијег_, _cerc
  { {0x44392f92,0xdb030061,0xdef10015,0x6dbc2f93}},	//   lus_, linç, ءًا_, rčan
  { {0xdce00064,0xd5b90024,0x44392f94,0x1dc40015}},	//   _almı, ksām_, ous_, وْلِ
  { {0x6f1c0026,0x317a000a,0x3d0a000b,0xdde10030}},	//   _ferc, _הארד, ाड़े_, ótőr
  { {0xf1bf0084,0x2d9d003f,0x6ffa0008,0x5ffa000a}},	//   _hjá_, shwe_, _להשפ, _להשה
  { {0x44392f95,0x3a57002b,0x6fba000b,0x139c000a}},	//   hus_, تیاج_, ्वरू, שבוע
  { {0x6dbc0844,0xb2bc00a3,0x8d77012c,0x64462af2}},	//   nčal, ימור, _باسا, ytki
  { {0x44392f96,0xe9a80015,0xbd440015,0x6d590fda}},	//   jus_, تدون_, _تنقي, mewa
  { {0xe7390001,0x753d2f97,0x87250015,0x6d592f98}},	//   љен_, egsz, أعظم, lewa
  { {0xc4c9000a,0x6f48000a,0x44392f99,0x9bc80058}},	//   _עג_, חֲרַ, eus_, _بولك_
  { {0x44392f9a,0x200b0046,0x9ae8000a,0x6d5926c9}},	//   fus_, _otci_, _וַנִ, newa
  { {0x6564022d,0x8c4801e2,0x644600f2,0xf99000e6}},	//   _vaih, cağı, utki, _جبل_
  { {0x291d003f,0x24442f9b,0xd7590021,0x6d590348}},	//   _hewa_, röm_, _طلعت_, hewa
  { {0x64460050,0xf77000b0,0x6721016f,0x471a0008}},	//   stki, _جان_, malj, _הוצג
  { {0x44392f9c,0x6f1c1138,0x30060033,0xdb032f9d}},	//   bus_, _serc, ззаг, ennü
  { {0xe53b0008,0xe58b0008,0x859b0008,0x2fda0002}},	// [5f60] _התפר, _הָיָ, _לשקו, مورد_
  { {0xdb030601,0x6dbc01c0,0x8fc5006e,0x291d2f9e}},	//   ninä, ačal, وزلن, _lewa_
  { {0x02fb0008,0x42fb000a,0x12fb000a,0x1fb50033}},	//   _ללימ, _להיס, _להיב, фстр
  { {0x0d860010,0x7e62005c,0x34b3002b,0x6d59186c}},	//   ялен, łopo, _آمیز, gewa
  { {0x0b8a010f,0x25fd005d,0x6b8812df,0x6f1c2f9f}},	//   йски_, _रूसी_, _podg, _terc
  { {0xa1360086,0xab270054,0xead42fa0,0xdcfc0061}},	//   _برگش, поља_, моль, ızıl
  { {0x9ea70cb9,0x4bd90010,0x67212fa1,0x8f9b039e}},	//   _евра_, цьця_, dalj, _פילי
  { {0x3ebb000a,0x79a3004a,0xa8a60054,0x8c480061}},	//   _הצלב, ерье, зрок, tağı
  { {0x31570053,0xdca307fe,0x291d00e8,0xdb0a002d}},	//   ליקן_, _зати, _dewa_, lifí
  { {0xdc9b1c6f,0x4c9b000a,0xdce00263,0x44392fa2}},	//   _הסמכ, _השמע, _jamč, vus_
  { {0x443900dd,0xe53504ab,0x8c480061,0xd758009a}},	//   wus_, мень, sağı, ملکت_
  { {0xa2cd000b,0xdb03016e,0x7c240085,0x39ea0054}},	//   _दुष्, tinç, širu, _удео_
  { {0x6f05002a,0x44392fa3,0x753d02ad,0x67210160}},	//   ychc, uus_, rgsz, balj
  { {0xf1bf0084,0x6d59005c,0x44392fa4,0x7dd8001a}},	//   _sjá_, zewa, rus_, físk
  { {0xa2cd000b,0xf2c412bd,0x44392fa5,0x66e303ae}},	//   _दुश्, естн, sus_, _поља
  { {0x44392fa6,0x76bb000a,0x20190034,0x61fe2fa7}},	//   pus_, _למופ, _pwsi_, _dupl
  { {0xa2cd005d,0xf53f02e9,0x20d70029,0x74280029}},	// [5f70] _दुर्, mgå_, سترج, _فكيف_
  { {0x6e950054,0x39b70045,0x4fd401c5,0x7dd8001a}},	//   мизу, răsi_, ежут, bísk
  { {0xb81e014e,0x4429003c,0x6d930064,0x6d592fa8}},	//   _मौसम_, _hva_, _uçak, tewa
  { {0xf53f003c,0x88bd005c,0xdb1a163c,0x9cb50115}},	//   ngå_, naśc, _októ, ومات
  { {0x50670010,0x6b652fa9,0x61e10079,0x6d592faa}},	//   _этна, дкла, ïllu, rewa
  { {0x9f4700f2,0x291d013c,0x9f8f007c,0x6dbc07c4}},	//   önä_, _sewa_, nüü_, nčaj
  { {0x291d003f,0x6721044c,0x0b160015,0x752d0085}},	//   _pewa_, valj, ذقية_, _odaz
  { {0x4429052c,0xceb20008,0xdb180107,0x329c000a}},	//   _ova_, _סין_, mový, מבוד
  { {0x7c24002f,0xf53f0134,0xdb180057,0xf7710002}},	//   áirt, dgå_, lový, ناد_
  { {0xa088000a,0x7c292fab,0x25e3000b,0x6605006b}},	//   לְתִ, _iver, _टीबी_, мпоа
  { {0x7c29158b,0xdb180057,0x9bc4004a,0x4ec8000a}},	//   _hver, nový, _чётк, ּ֖תַ
  { {0xc3290dab,0x6721016f,0xe8550015,0x9e48000a}},	//   _כו_, salj, _يناد, הֲשִ
  { {0x89340029,0x7aed0089,0xdb180057,0x61fe2fac}},	//   _أعما, žitě, hový, _supl
  { {0x9980032c,0x7ae40089,0xdb180057,0x7dd8001a}},	//   čiť_, řite, kový, tísk
  { {0xfbd2000a,0x386d0dd3,0x614602d9,0x47d20015}},	//   דתם_, lver_, мева, _جيور
  { {0x7dd8002e,0xdb180107,0x3f8a0085,0xdce000bf}},	//   rísk, dový, _sobu_, _samč
  { {0xdfd20021,0x7dd8001a,0xb17b0123,0x386d2ecf}},	// [5f80] نير_, sísk, _ihål, nver_
  { {0x02d60015,0x31790030,0xd437015b,0x7d092fad}},	//   _يتدخ, _ensz_, _קריק_, _afes
  { {0xdfcf003b,0x386d0293,0x7dd80ab3,0xa3bd000b}},	//   جيل_, hver_, lísi, ेकर_
  { {0xfbcf002b,0x7c2902ad,0x0000006a,0x0000006a}},	//   یتو_, _bver,   ,
  { {0x386d0111,0x9c5a0015,0xfb860033,0x4197002b}},	//   jver_, تجاز_, дыйн, _آشپز
  { {0xdb180107,0x6dbc00bc,0x7c292fae,0xba0a004a}},	//   bový, očak, _dver, охие_
  { {0x7c29003e,0x7d090026,0x386d1fb7,0x394d2faf}},	//   _ever, _ffes, ever_, ffes_
  { {0xd91a0036,0x39420020,0xdce2006f,0xa9670054}},	//   цьк_, üks_, mkoľ, дића_
  { {0x6dbc002c,0x660d0cca,0x59ad000b,0x7c292fb0}},	//   yčaj, _čaka, टफ़र, _gver
  { {0x9f41002d,0x26d8007c,0x7dd80077,0x16140033}},	//   omhá_, üroo_, dísi, ндоў
  { {0x7c29002c,0x8afb0008,0x4429044c,0x5afb000a}},	//   _zver, _והבי, _sva_, _ולבצ
  { {0x9a250029,0x569303e7,0xdab7002b,0x7dd82fb1}},	//   _أعلن, тают, _تهمت_, físi
  { {0xf8e2005d,0xf53f00c0,0x2edb005d,0xdce2006f}},	//   _परिय, rgå_, _भर्त, hkoľ
  { {0xf53f0123,0xb17b0123,0xdc8b004f,0x75fe01ec}},	//   sgå_, _ehål, חְלָ, _līzi
  { {0xdce2002c,0xa757000a,0x88bd002a,0x07a30099}},	//   jkoľ, _חשוד_, paśc, _јајн
  { {0x64480011,0x3f8e001a,0x23ad00bc,0xdb1801c0}},	//   ădir, öfun_, ižji_, vový
  { {0x2d8601d7,0x44292fb2,0x0000006a,0x0000006a}},	// [5f90] djoe_, _uva_,   ,
  { {0xdb180227,0xc7d8004f,0x0000006a,0x0000006a}},	//   tový, פַּכ,   ,
  { {0xee38005e,0x7c291b28,0x9df9004a,0x63b500bc}},	//   днє_, _sver, чнет_, mizn
  { {0xdb180057,0x63b508c1,0x60e80061,0x290b0061}},	//   rový, lizn, örmü, ıcak_
  { {0xac270080,0x80270002,0x399100dc,0xfd440033}},	//   ффек, _ترجم, _mást_, тэхн
  { {0xf414000a,0xd9b9000b,0x61ed2fb3,0x2484007c}},	//   דפס_, ॉक्ट, lmal, ämmi_
  { {0xd90f0086,0x6d5b0029,0x19f50004,0x8e380015}},	//   لیا_, _وجرح_, нџир, _يسفر_
  { {0x386d0024,0x9f590107,0xa2d6000b,0x7c292fb4}},	//   tver_, _musí_, _मुफ्, _tver
  { {0xa3df005d,0x7c290e9f,0x386d2730,0xa2d6000b}},	//   तता_, _uver, uver_, _मुन्
  { {0xbf1d005d,0x11d9004c,0x61ed2fb5,0xa6850bdb}},	//   _फ़ोन_, פּראַכ, hmal, елод
  { {0x9a14017f,0x394d0012,0xf6280015,0xc7a80040}},	//   _афіш, pfes_, وسَى_, بديل_
  { {0x9734002b,0x7dd80077,0x39910046,0x9958016d}},	//   _یکپا, tísi, _pásu_, _téš_
  { {0xcd960008,0x38580015,0xdd3a000a,0x5d3a004f}},	//   גדרת_, _يشهد_, הערכ, התרא
  { {0xf7450076,0xdce2006f,0x7dd80077,0xe6050015}},	//   _чеко, ykoľ, rísi, _كِتَ
  { {0x0cdc005d,0xe692002b,0x9f510046,0x3991001a}},	//   _बर्म, _ملود, _cizí_, _fást_
  { {0x69db008c,0x645a0045,0x61ed2fb6,0x600a0763}},	//   nlue, ătib, gmal, знам_
  { {0x55bb0008,0x10150015,0xbf360015,0xe8d5000a}},	// [5fa0] _ממקו, َبْد, فراغ, גוּר_
  { {0x2d9f00f2,0x61ed2fb7,0xf6790135,0x63b52fb8}},	//   _alue_, amal, ּאֱמ, cizn
  { {0xdee60a61,0x2d9f2fb9,0x6295002a,0x7e560033}},	//   хожи, _blue_, cyzo, этац
  { {0xbd670036,0x7413002b,0x2d9f00da,0x61bd000b}},	//   ерше_, _جویا, _clue_, ्कृष
  { {0x7f1a008f,0x20040011,0x6ab8000b,0x6dbc0073}},	//   _ніву_, _îmi_, इप्र, nčai
  { {0x6281003c,0x80af000b,0xaa581dd3,0xaa6608a0}},	//   ålog, ूपरे, дику_, етик
  { {0xcb070029,0xa2d6000b,0xada62246,0x69db07ee}},	//   ريين_, _मुम्, _завл, flue
  { {0x6df60015,0x6d930003,0x63b50030,0x2d9f2fba}},	//   _أكرا, _sçav, zizn, _glue_
  { {0x2c0b0086,0xd83a0010,0xa3c00231,0x7cf60061}},	//   _فعلی_, чэй_, ंचा_, _dürü
  { {0x999f0048,0x69db00f2,0x8ad60015,0x61ed06d1}},	//   ārši_, alue, _كتائ, zmal
  { {0x61ed0050,0xcb8b0008,0x63b50fde,0x9f650030}},	//   ymal, _מְאֹ, vizn, ötés_
  { {0xba9b0008,0x69db06be,0x7cf60061,0xf6e30033}},	//   _מסבי, clue, _gürü, ыцын
  { {0x19b70053,0x5893002b,0xf9870058,0x0000006a}},	//   _אפאר_, _مجوز, _سنوي_,
  { {0xb364006b,0x6295002a,0xa87b004c,0x25a00072}},	//   лъск, tyzo, _מאדר, _elil_
  { {0x7cf60064,0x63b50694,0x66730031,0x2002168d}},	//   _yürü, rizn, _مدير, _auki_
  { {0x26db01e4,0x25090086,0xd6db0008,0x6295005c}},	//   _מקומ, _غربی_, _מחול, ryzo
  { {0x69c0108e,0x40340b27,0x61ed2fbb,0xd1b80058}},	// [5fb0] inme, летс, rmal, رافا_
  { {0x200f0048,0x83190015,0x8fa40054,0xdb0a001a}},	//   īgi_, _تقدر_, гађе, lifæ
  { {0x88bd005c,0x61ed0064,0x25b20026,0x4fc40add}},	//   jaśn, pmal, _ymyl_, уста
  { {0x4cb90342,0x56b7004c,0x8cf50015,0xa63b000a}},	//   млею_, עפאן_, نكاش, לגבר
  { {0xc058005e,0xdce0003d,0xcb691971,0x443901ec}},	//   _пір_, _pamā, дале_, nrs_
  { {0x7cf601e2,0x6d11000b,0x44392fbc,0x69c02fbd}},	//   _sürü, _ड्रग_, irs_, enme
  { {0xdddc00dc,0xdb0a002e,0xab280029,0x539c000a}},	//   _errő, kifæ, رسول_, היגו
  { {0x69c0003e,0x69db008c,0x3208000a,0xa3e3000b}},	//   gnme, ulue, ע֖וּ_, _फीस_
  { {0x442b005c,0x88e5006b,0x98a52fbe,0x0000006a}},	//   jsc_, ъжие, типе,
  { {0x69db00f2,0x93e0005d,0x69c00159,0x4439003d}},	//   slue, _खींच_, anme, drs_
  { {0x7cf60064,0x442b0011,0x44392fbf,0xaa890015}},	//   _türü, esc_, ers_, _تنضم_
  { {0xa596005e,0x3835045c,0xb9250058,0x44390052}},	//   трощ, _андр, _شفتي, frs_
  { {0x7c2b2a8e,0x7dd80089,0x5fd1000b,0x4463006b}},	//   nsgr, míst, तकाल, авяв
  { {0x33d5078f,0xd7c80015,0x7e62002a,0x7c2b2fc0}},	//   гіст, _كونه_, łopi, isgr
  { {0x3f8e002e,0x442b002d,0x25e3005d,0x799b003f}},	//   öfum_, asc_, _टीवी_, okuw
  { {0xf8a50086,0x25a000e8,0x99870091,0x798900cb}},	//   مک_, _ulil_, munų_, njew
  { {0x20d6005e,0x41030004,0xf5930015,0xf992000a}},	// [5fc0] тівс, рзув, _خليج, ברן_
  { {0x6603160f,0x67232fc1,0x395f2fc2,0x75240012}},	//   _kunk, _jenj, heus_, _heiz
  { {0x672323ad,0x395f00f2,0x75242fc3,0x5337000a}},	//   _menj, keus_, _keiz, _בנין_
  { {0x200200f2,0xdd990036,0x66030832,0x672316c2}},	//   _tuki_, нші_, _munk, _lenj
  { {0x7dd82c1a,0x395f2fc4,0xa2d6000b,0xcfaa012c}},	//   díst, deus_, _मुत्, _قاسم_
  { {0xf4130008,0xdff50010,0x7dd8002e,0x39460045}},	//   ספו_, _бясь, vísu, _scos_
  { {0xdb0300f2,0xa9c61208,0x0f57004f,0xe607009a}},	//   ynnö, ксик, _שילם_, _خش_
  { {0x75242fc5,0x2d9c003d,0x4420002a,0x395f2230}},	//   _neiz, īves_, _owi_, geus_
  { {0xf1b3013a,0x69c00041,0x8b260010,0x6603001a}},	//   יסה_, rnme, _адзе, _aunk
  { {0x799b003f,0x2509002b,0x6723036d,0x66032fc6}},	//   akuw, کردی_, _cenj, _bunk
  { {0x44390176,0xd5b90048,0xa3d6000b,0x75240012}},	//   wrs_, ksāt_, िकन_, _beiz
  { {0x44390024,0x7dd8001c,0x66030745,0xba290015}},	//   trs_, míss, _dunk, _أسلم_
  { {0x44392fc7,0x442d0152,0x442b02b9,0xf904003d}},	//   urs_, ée_, usc_, āšās_
  { {0x44200176,0xccf30008,0xf7480015,0x61bd000b}},	//   _dwi_, יכר_, _ألغي_, ्क्ष
  { {0xa2d6014e,0x57fb000a,0xe1f30015,0x645a0045}},	//   _मुद्, _קלוו, لسر_, ătia
  { {0x92940010,0x7c2b0026,0xf1a40210,0x67282fc8}},	//   шасц, ysgr, арун, ladj
  { {0x10750256,0xcfab0015,0x20750033,0x9f55009b}},	// [5fd0] ылаю, وائم_, ылаў, лвач
  { {0xcebb0001,0x6728016f,0xf0e3005d,0x0f14005e}},	//   мље_, nadj, _खरीद_, имую
  { {0xdfd8010f,0xf3f00029,0xb0620020,0xa295017f}},	//   тът_, _بأي_, äärn, _сані
  { {0xf6530135,0x6d930064,0x6e44005e,0xb6bb000a}},	//   יצע_, _açar, реїз, וצבי
  { {0x21290049,0x7c640015,0xa156000a,0x656d2fc9}},	//   maah_, لاول, _גברה_, _maah
  { {0xdd0301e2,0x7d160064,0x7c2b17e9,0x2129058a}},	//   ırıl, ıysa, rsgr, laah_
  { {0xdb120030,0x61fd2fca,0x7dd82fcb,0x7c2b03c1}},	//   ágár, _kisl, tíst, ssgr
  { {0xaa5600e5,0x02fc000a,0x6603008c,0xc214000a}},	//   اليا_, ולומ, _runk, בהק_
  { {0x66032758,0x75242fcc,0x67232a61,0x3d94013e}},	//   _sunk, _reiz, _penj, _титр
  { {0x67282c7a,0xd6390010,0xf0920008,0x6dbc016f}},	//   gadj, нямі_, צני_, učav
  { {0x67230084,0xcb120008,0x78a900dc,0x395f2fcd}},	//   _venj, _הלב_, szev, peus_
  { {0xe81e005d,0x1e3a0053,0xc99b0015,0x8aa40734}},	//   _मौका_, עגרא, _تخطط_, _труд
  { {0xa3c0000b,0x69d90573,0xe739067a,0x67280d85}},	//   ंचल_, _ikwe, _зел_, badj
  { {0x5b7901e4,0x9cd60008,0x61fd2fce,0x9f580003}},	//   ׂרָא, רושה_, _aisl, _tiré_
  { {0xdb03002d,0x61fd2fcf,0x31be0046,0x7bc32fd0}},	//   ghné, _bisl, hůze_, innu
  { {0x6dbc2fd1,0xbf9b016e,0xd2e4000b,0x75462fd2}},	//   nčat, _quên, _गरीब_, _сниз
  { {0x31600048,0xf9920053,0xd5b90024,0xa5db004c}},	// [5fe0] reiz_, זרן_, rsāt_, _אַזי
  { {0x6d490440,0xb81b005d,0x141b0053,0x33660809}},	//   _acea, पीएम_, _רויב, _свог
  { {0x52760036,0xe7f6000b,0x6146006b,0x3f9122cd}},	//   _супу, ीदता_, _йена, _dozu_
  { {0xf2d3000f,0xad45005e,0x9e750054,0x6d260033}},	//   _לעת_, ихік, шћуј, уддз
  { {0x55ad004c,0x351b004f,0x0000006a,0x0000006a}},	//   ויאַ, גוננ,   ,
  { {0x437600b2,0x69c50003,0xf457000a,0x7dd80527}},	//   רײַן_, éhen, ריסר_, tíss
  { {0x5fdb000a,0xad5a09fd,0x02fa004f,0xc333004f}},	//   _נחלק, _прах_, ׂלְמ, מוג_
  { {0x6d49002f,0x7bc30026,0xb81b000b,0x8e97000a}},	//   _gcea, annu, पीऍम_, _גדלו_
  { {0xa2d6005d,0xf0b70053,0x8d930015,0xdb0a007c}},	//   _मुस्, ָליר_, _القش, tifä
  { {0x6dbc006f,0x57b4008b,0x3857012c,0x3cf1006f}},	//   ačat, рбот, اشيد_, ňovú_
  { {0x7fd70053,0x67282fd3,0x656d0312,0x0000006a}},	//   רויס_, radj, _paah,
  { {0xceb3013a,0x04f5005e,0xdb010003,0x645a0045}},	//   מית_, изню, _allè, ătin
  { {0x29d3002b,0xdb18016e,0x249f001a,0x656f031a}},	//   _اينس, vivê, áum_, rdch
  { {0x76410091,0xd80b000a,0x644f2fd4,0x6dbc2a33}},	//   buly, _נִדָ, rtci, očas
  { {0x5b7b0053,0xc6770002,0x7792002b,0xdb97004c}},	//   ערלא, _محيط_, _نیکا, נדלט_
  { {0xdb08002e,0xf2040010,0xdb030107,0xb1152331}},	//   _umdæ, сяро, diný, рмаш
  { {0x61fd0024,0x7bda0035,0x60f9054f,0xdb18007c}},	// [5ff0] _visl, _oktu, тная_, lovõ
  { {0xb4c3005d,0x6ee7002b,0x6d492fd5,0xdecb0302}},	//   ्थी_, هسال, _scea, нуел_
  { {0x6dbc0227,0x33fa000a,0x62670002,0x23fa000a}},	//   jčas, _שהתנ, _صادق, _שהתא
  { {0x53140086,0x61fd003f,0x7bda2fd6,0xdb010003}},	//   _پذیر, _uisl, _aktu, _illé
  { {0x8b2509ef,0x7a11003d,0xbd440058,0x41540138}},	//   адле, _māte, إنهي, _увяс
  { {0x7bc32985,0xaa35005e,0xda5900ce,0x69d90535}},	//   unnu, ахищ, вриш_, _skwe
  { {0xf9910029,0xc334000a,0xfaa50296,0x8cb10065}},	//   قبة_, צוק_, райо, _आइको
  { {0xf9910015,0x7c15005e,0x7a0a002a,0xd2b8000a}},	//   تبت_, _вдає, _tętn, טלות_
  { {0xf09200b2,0x290d0011,0x4805012e,0x6dbc2fd7}},	//   ַנט_, rcea_, јпов, ačas
  { {0xd7ee0015,0x22a0008c,0xe1ff0144,0x6dbc10cd}},	//   وكي_, näkö_, _lió_, bčas
  { {0xda09002b,0xcfb6000a,0x6dbc0085,0x66e524e9}},	//   _شيشه_, שלתי_, mčar, рона
  { {0x58d5010f,0x287502bf,0x68ee0061,0x69d900aa}},	//   _коет, _выкр, öndü, _ukwe
  { {0xdb012fd8,0xdd14006f,0x76412fd9,0x645a00d4}},	//   _allé, núši, suly, ătio
  { {0xa6950001,0xa856000a,0x6dbc036d,0x98a21791}},	//   _вриј, _כינה_, nčar, _фише
  { {0xa2d6005d,0x412a01e5,0x23270461,0x77ba000a}},	//   _मुश्, ково_, роси_, _במסח
  { {0x75d30015,0x25fe0065,0x0000006a,0x0000006a}},	//   _ويوا, _रूची_,   ,

  { {0x02db005d,0xff260001,0xd0070661,0xa2d6000b}},	// [6000] _मुठभ, имао, иете_, _मुर्
  { {0x2d800048,0xef171017,0x44322fda,0x0000006a}},	//   ķiem_, иму_, _ivy_,
  { {0xe8e2005d,0xcd060010,0x733b0135,0x433b000f}},	//   _पर्च, апей, _בעיס, _בעיב
  { {0xdc2a0086,0xcf890053,0xe1ff0092,0xd656000a}},	//   نسته_, וט_, _gió_, ייעת_
  { {0x2ca0017e,0xef0a0015,0xbc23005e,0x3137004f}},	//   áid_, _لغزو_, оєщи, _דרכך_
  { {0x649b0008,0xba760029,0xc4770008,0x3998001a}},	//   כסנד, لاعت, יתנו_, _lést_
  { {0xead80010,0xc333000a,0x29020091,0xeb9701ca}},	//   ымкі_, קוה_, žkam_, риј_
  { {0x7c660074,0x0c3a0029,0x63bc1cc8,0x7e62002a}},	//   _پارل, _لكرة_, hirn, łops
  { {0xa3d6014e,0xdb032fdb,0x27c6005e,0x63bc01d7}},	//   िका_, chnï, ищог, kirn
  { {0x8c1b0008,0x473403fc,0xdb18007c,0x86740015}},	//   _סובי, щнос, tovõ, مُخص
  { {0xc9860036,0xeb970001,0x3f790053,0xa2d6005d}},	//   _вули, _њих_, אָרע, _मुल्
  { {0x998000df,0x3abb0008,0xb8660086,0xe4a7017d}},	//   čių_, _במבנ, _ناتو, арго
  { {0xe4e70036,0xe3d70015,0x7982002a,0xa93b000a}},	//   рінн, لتسع, _inow, _יתאפ
  { {0x9989002c,0xa3a4023e,0x889b000a,0xa7d30015}},	//   čať_, ојск, _בבדי, _وتوص
  { {0x79820041,0xe5c70080,0x91f70015,0x03c80033}},	//   _know, _вспо, لأرا, рыяй_
  { {0x7bd80227,0x200f016e,0x6615006f,0xa427009b}},	//   hovu, ígio_, ízke, _кьол
  { {0xb607002c,0x629c0035,0x209804ab,0x63bc2fdc}},	// [6010] _teší, ayro, акты_, birn
  { {0x7a0a005c,0xdb180123,0x0000006a,0x0000006a}},	//   _pętl, nnvä,   ,
  { {0xdb182fdd,0x60c90091,0xe731000a,0x7bd80091}},	//   invä, _žemd, לֵא_, dovu
  { {0x7db40010,0xd657004f,0x75ff0073,0x0000006a}},	//   осіц, שיאת_, _mūzo,
  { {0xd1fa0053,0x7dd8006f,0x65a6001a,0x1cd80033}},	//   _תּיכ, rísp, _jóha, адцы_
  { {0x1b490080,0x3e170086,0xda6500e5,0x00f6000a}},	//   узки_, _نظرس, ماعي, _לזרם_
  { {0x53380008,0xaa560015,0xda640021,0x0000006a}},	//   בנון_, ملوا_, قايي,
  { {0x63bc0b28,0xdb182fde,0x0000006a,0x0000006a}},	//   zirn, envä,   ,
  { {0xe8f90080,0x629c005c,0x0000006a,0x0000006a}},	//   ыли_, zyro,   ,
  { {0xf7450124,0x3998002e,0xf7710015,0xbe39000a}},	//   љено, _sést_, ساخ_, ְעָת
  { {0x63bc00bd,0xdce00085,0x69c4006f,0x9f98004f}},	//   virn, _pamć, čier, ידזה_
  { {0xdeb60008,0xbae40015,0x629c2fdf,0x0e5a004f}},	//   מפתח_, _بكمي, vyro, נדרב
  { {0x291f000c,0x39980089,0x629c0034,0x6d5b0125}},	//   mbua_, _vést_, wyro, _mbua
  { {0xa01b002e,0x7982005c,0x9cd60008,0xb4e8005d}},	//   _kröf, _znow, מורה_, _भरी_
  { {0xd2990191,0x1db7000b,0xbee60065,0xc7b40058}},	//   атті_, _आगंत, _करेन_, _بصنع
  { {0xdb180152,0x98a4003d,0xd54a0004,0xc4861adc}},	//   rivé, lamā_, _спие_, _глик
  { {0x7bd8003f,0x351b000a,0x90290015,0x900a0015}},	// [6020] yovu, _גופנ, لألف_, ازرق_
  { {0x44770008,0x656600dc,0x64461839,0xe5700061}},	//   _פעיל_, lekh, muki, _işığ
  { {0xc7ba004c,0xd7ba004c,0xdb030125,0xee3a0add}},	//   נצעט, נצער, ghní, уне_
  { {0x60c90007,0xa3c0000b,0x6131001a,0xdce0002a}},	//   _žeme, ंचक_, rðlí, _zamę
  { {0x98a40024,0x64462fe0,0x61e40061,0xdb0a001a}},	//   kamā_, nuki, mlil, infö
  { {0x98a40024,0x79822fe1,0x61e42fe2,0x2a6c016e}},	//   jamā_, _snow, llil, _psdb_
  { {0x6e960115,0xdb03013f,0x65660030,0xd37b004f}},	//   _الزا, chní, kekh, טרסט
  { {0xd90e0086,0x48142fe3,0x61e41dc1,0xfe9b000a}},	//   ریت_, омис, nlil, _גילמ
  { {0xa01b00b8,0xc173039e,0x644600bc,0xd7860015}},	//   _eröf, לחה_, juki, مؤدي
  { {0x6446187b,0xa097000a,0xe7b80054,0x98130015}},	//   duki, צדיק_, ргош_, أبيا
  { {0xdb1800c0,0x61e4093f,0x6f7b000a,0xa01b001a}},	//   rnvä, klil, רְחו, _gröf
  { {0x758b131f,0x65660030,0x4efb004f,0x79820535}},	//   усов_, gekh, טליג, _unow
  { {0xe89408f7,0x889401e1,0x61e408c6,0x0000006a}},	//   _фаль, _филх, dlil,
  { {0x98a40024,0x21200049,0x58f7000a,0x1837000a}},	//   camā_, ebih_, _המדע_, _פאול_
  { {0xb284005f,0x64460007,0xd7bb000a,0x9757000a}},	//   пытк, auki, _תצור, _היוו_
  { {0x672a002e,0x61e40035,0x64460035,0x0f21000b}},	//   _hefj, glil, buki, यर्स_
  { {0x752f005c,0xf1940a61,0x7538000a,0x2538000a}},	// [6030] macz, чить, _האחד_, _הנחש_
  { {0xb17b00c0,0xdb03002d,0x752f005c,0xceeb012c}},	//   _skåd, thní, lacz, هران_
  { {0xc332000a,0x9f581953,0xa1590912,0xa1952fe4}},	//   _קוט_, _dirà_, _кану_, _данч
  { {0x752f0050,0xcd2b0018,0x98a4003d,0xbdf80015}},	//   nacz, اسان_, zamā_, مرنا_
  { {0x67380085,0x853c000a,0x7bf90418,0x0000006a}},	//   _odvj, רגדי, андр_,
  { {0x7ae100dd,0x752f002a,0x65660030,0xaa150099}},	//   _pylt, hacz, zekh, офиј
  { {0x19890080,0x1ee70086,0x53380008,0x64462e6b}},	//   ибки_, _طوری_, זנון_, zuki
  { {0x4859008f,0xad270086,0xc859005e,0xf8690015}},	//   ароў_, _درآو, ашої_, لمبي_
  { {0x660a00b8,0xb4e8005d,0xa01b002e,0x752f005c}},	//   _aufk, _भरे_, _drög, dacz
  { {0x61e401e2,0x6d4a0064,0x25a90020,0x30560008}},	//   zlil, ılaş, _alal_, קשתך_
  { {0x8b080008,0x2003003f,0x8aa72fe5,0xfaa701f3}},	//   _הִנֵ, _miji_, _урад, _ушан
  { {0x6446000c,0x20190020,0x7c240011,0x6d4b2fe6}},	//   tuki, _otsi_, ţire, ngga
  { {0x80c8005d,0x61e40064,0xa3d6000b,0xd6ce002b}},	//   _रखें, vlil, िकल_, فقی_
  { {0xb6a50080,0xdc880008,0x67ef0134,0x65662fe7}},	//   _милл, צְרָ, føje, sekh
  { {0x752f005c,0x61e42fe8,0x92e90015,0x65660030}},	//   bacz, tlil, مرفق_, pekh
  { {0x867a000a,0x69c92fe9,0xa3ba002b,0x69db0618}},	//   _כרצו, nnee, _چادر_, noue
  { {0xb886002e,0x61e40064,0x63f60015,0x2003013c}},	// [6040] mtíð, rlil, _وأخر, _biji_
  { {0xceea0418,0x98a40045,0x7a300030,0x69db2fea}},	//   адзе_, lamă_, _jótá, houe
  { {0x2019022d,0x8236002b,0xbe66002b,0xa3e30065}},	//   _etsi_, _برخا, تهاي, _फीट_
  { {0x365a0053,0xa01b00c0,0xbca60086,0x7c660015}},	//   יכענ, _bröd, يماي, قاتل
  { {0x0b8a2feb,0x0469000a,0x4c13002b,0x3d2b002b}},	//   иски_, ֶיהָ_, وبوس, شتنی_
  { {0x660409e7,0xdce00089,0x6d4b2fec,0x5bb7008b}},	//   _liik, _zamě, agga, олія_
  { {0xada60080,0xee370004,0x387d0034,0xad660067}},	//   _давл, _мнр_, _arwr_, _واره
  { {0xa9c30036,0xd90d0086,0x6604007c,0x8c460579}},	//   дськ, هیم_, _niik, _мебе
  { {0x99580089,0xdb080bfa,0xf8af0015,0x20040003}},	//   _též_, _omdø, َةً_, _émis_
  { {0x752f002a,0x7c65012c,0x69c90072,0x0000006a}},	//   wacz, _عاقل, anee,
  { {0xf09f0092,0x7a110024,0x6bd70015,0x3f980b23}},	//   _ngàn_, _tāta, _بولس_, _moru_
  { {0xdd86002b,0x628107a3,0x69db0003,0x672100bc}},	//   رو_, ålom, coue, ablj
  { {0xf76f0074,0x66040509,0x752f002a,0xdb030125}},	//   رای_, _diik, racz, mhná
  { {0x67ef00fb,0xfbbc005d,0x69c02fed,0xd7580015}},	//   tøje, ्चिम, lime, _طلبت_
  { {0xdce00089,0x200b013c,0x9bb7000a,0x6d4b0123}},	//   _pamě, _suci_, קהלה_, ygga
  { {0xdb182fee,0x30151dc5,0xd7f80045,0x64400077}},	//   diví, здар, lmă_, ámic
  { {0x3cf6005d,0x859c0008,0x69c000f2,0xc3070021}},	// [6050] ेशों_, _כשהו, iime, _وبدو
  { {0xa2d6005d,0x75d20024,0x69c021b3,0xdb0302ad}},	//   _मुक्, rāze, hime, minö
  { {0x69c900f2,0x212b2fef,0x752d01c2,0xd7f80045}},	//   ynee, _tech_, _keaz, imă_
  { {0x44290f4d,0x3f8e002e,0x8e080036,0x2c5e0024}},	//   _kwa_, öfur_, інів_, kādā_
  { {0x0c24192f,0xd1160008,0x7c840001,0x69db0003}},	//   дмін, _מקרה_, дује, voue
  { {0x70fa0008,0xb09a0008,0x4429003f,0xc0b60016}},	//   _להרח, _הישר, _mwa_, _lưỡi_
  { {0xfb120015,0x8cbb000b,0x4429002a,0x69db2ff0}},	//   رويج, _शेरो, _lwa_, toue
  { {0x8e140010,0xa2ce000b,0x69c016c8,0x4429002a}},	//   _ідуц, _सशस्, gime, _owa_
  { {0x66040005,0x2c5e0024,0xac77002b,0x69c92ff1}},	//   _riik, gādā_, _بازش, rnee
  { {0x7c290026,0xd7f80045,0x69c90079,0xca770015}},	//   _iwer, gmă_, snee, _واضغ
  { {0x7a30002d,0x69c00e80,0x6721036d,0x66040601}},	//   _vótá, bime, rblj, _piik
  { {0x69c02ff2,0x8e96000a,0xd46a0004,0xd7f80045}},	//   cime, לדתו_, биме_, amă_
  { {0x660400f2,0xd4da0010,0xb886001a,0x98a40045}},	//   _viik, сьні_, rtíð, ramă_
  { {0xa3b6005d,0x4429005c,0xe3c60015,0xa87a000a}},	//   चों_, _dwa_, سْأَ, _לאנר
  { {0x66e20c94,0xa6b40063,0xd6d70029,0xa2d6021e}},	//   _поша, _осъщ, _بتشغ, _मुख्
  { {0x463a0053,0x60c90007,0x3f980064,0x386d19a8}},	//   _העקע, _žema, _soru_, ower_
  { {0x8afc002a,0x6ed40065,0x515500ce,0xdb030072}},	// [6060] _zbęd, _बुजु, ьтру, minõ
  { {0xe45700b2,0xe3b20086,0xf457000a,0x94bb000a}},	//   _צייט_, _سرخ_, _צייר_, _למפת
  { {0x3f980084,0xdfcf0070,0x639b0008,0x386d00b8}},	//   _voru_, ديل_, _הסינ, hwer_
  { {0x21020007,0x7bca0026,0xdb03007c,0xdd8f0015}},	//   _ačiū_, wnfu, ninõ, ُول_
  { {0x394d1965,0xdd99006f,0xdca30719,0x7c13005e}},	//   dges_, _doň_, наци, едіє
  { {0x98a40007,0x7fd6042b,0x394d164b,0xdb03007c}},	//   namą_, _хімі, eges_, hinõ
  { {0xe9f8008f,0x03ad0008,0x89d80115,0xdee60015}},	//   онкі_, שׁוּ, يوتر_, _رأسي
  { {0x394d0293,0xdd920040,0x3eae0061,0xed57213b}},	//   gges_, _ثور_, ıktı_, _нос_
  { {0x7c290176,0x98a40007,0x752d1c0d,0x8c432c7f}},	//   _gwer, kamą_, _reaz, _пете
  { {0xec370008,0x98a40007,0x6c330029,0x2c5e0024}},	//   _מאמר_, jamą_, _أفلا, rādā_
  { {0x45d50083,0xd7f804f9,0x6b880134,0x7c2923c7}},	//   донс, rmă_, _indg, _zwer
  { {0x65ab0054,0xd7f80045,0x248001f9,0x0000006a}},	//   стог_, smă_, _brim_,
  { {0x89eb000a,0x764800cb,0x24801e0b,0xe97b000a}},	//   _הַגֵ, sudy, _crim_, _לנאש
  { {0x083b013a,0x75ff0024,0xb4bd000b,0x883b004f}},	//   _פעול, _mūzi, _आधी_, _פתוו
  { {0xa75b0008,0xd6cf01e5,0xdb0a2cdd,0xdb03019a}},	//   _הדור, _чт_, lifó, binõ
  { {0xf41f008c,0xa2ce0065,0xe5f50058,0xf19400ce}},	//   ppä_, _सशर्, _تكبد, нись
  { {0xe53c0008,0x90550033,0x24802ff3,0x212a002b}},	// [6070] _התחר, ьвац, _grim_, زيلی_
  { {0xdefb0080,0x06fd0046,0xf2070151,0x6b9a02ad}},	//   бые_, čívá_, _нямо, _notg
  { {0x3ea700dc,0xc7d7000a,0xdd950033,0x539c000a}},	//   ánt_, לומי_, мажы, _ליזו
  { {0x93270086,0x2349002b,0x7c292ff4,0x386d00aa}},	//   _برکن, _اسکی_, _pwer, ywer_
  { {0xe5380053,0xf538000a,0xeb991eb8,0x3b090004}},	//   לטאט_, לנאי_, жил_, оело_
  { {0x4478000a,0x2bdd000b,0xe452000a,0x8234002b}},	//   פעול_, यवधा, דֶה_, _تریا
  { {0x394d08e0,0x0000006a,0x0000006a,0x0000006a}},	//   tges_,   ,   ,
  { {0xcda90086,0x6b880ecc,0xdb030030,0x7d092ff5}},	//   _بهره_, _endg, nkné, _uges
  { {0x7c970029,0x2d80003d,0x386d2ff6,0x394d027b}},	//   _عشرا, ķiet_, uwer_, rges_
  { {0x386d005c,0xdb0100dc,0x87b80080,0x2456002e}},	//   rwer_, _ellá, зуют_, væm_
  { {0x7bc32ff7,0xc9872ff8,0x0f580c44,0x386d2ff9}},	//   minu, _нуди, ליזם_, swer_
  { {0xf1bf0125,0x24802ffa,0xb9c5012c,0xdce20061}},	//   _nmá_, _prim_, _تقصي, ndoğ
  { {0xe739092d,0xc7950015,0xf992000a,0xdb03007c}},	//   _дел_, _يشتب, _שרד_, rinõ
  { {0x98140029,0xe7310086,0x68fa000a,0xdb0a0144}},	//   _أبنا, _شصت_, _ולנה, lifò
  { {0xe796002b,0x96750033,0x91e625e0,0xd19a0054}},	//   _تانک, _цылі, дове, отач_
  { {0x25b700c3,0x24802ffb,0x7bc32ffc,0x661c03bc}},	//   _يهود_, _trim_, hinu, írke
  { {0x91e32152,0x7bc32ffd,0xe3ba0004,0xdb180030}},	// [6080] тоте, kinu, _мби_, hivá
  { {0x249f00b8,0x0fda0010,0xdfcf00e5,0x7bc303f3}},	//   äume_, цьбы_, ليق_, jinu
  { {0x7bc32ffe,0x7e560a96,0x6b9a0028,0xe1262fff}},	//   dinu, ьтац, _rotg, _омни
  { {0x2613001c,0x98ad000b,0x644600da,0x7bc313aa}},	//   _mão_, टनाए, orki, einu
  { {0x3ea60024,0x26130016,0xb4db0144,0x6b9a0875}},	//   ņot_, _lão_, lgàr, _potg
  { {0x6ac9005d,0xbf9b0003,0xdca30054,0x7bc33000}},	//   िपूर, _quêt, ђаји, ginu
  { {0x261311e0,0x7f170015,0xdb230030,0x0000006a}},	//   _não_, _آيفز_, úráj,
  { {0x28a6005e,0xdb0a0125,0xa9c30033,0xc8080016}},	//   дшог, mhfí, ксык, _hởi_
  { {0x7bc33001,0xb4bd000b,0xa8c7009a,0x6b9a02ad}},	//   binu, _आधे_, وژهٔ_, _totg
  { {0x6b880134,0x26130092,0x8b960010,0x4c9b000a}},	//   _undg, _bão_, _ўрач, _ובמו
  { {0xae0e005d,0x2613016e,0x64463002,0x64400b31}},	//   िदिन_, _cão_, erki, ámin
  { {0xf64f002b,0x2613016e,0xda650015,0xfe37000a}},	//   گئی_, _dão_, _سامي, ורטי_
  { {0x79fb0008,0xe4e40036,0xf9fb000a,0x644013b3}},	//   _ולאח, вірн, _והאמ, šmin
  { {0x29020007,0xae0e000b,0xf1bf001a,0x60c90091}},	//   žkas_, िदान_, _smá_, _žemo
  { {0x644600f2,0xa2780054,0xdce20061,0xdd14006f}},	//   arki, мбру_, ydoğ, dĺži
  { {0x2607014e,0x25090086,0x06fd0089,0x7bc33003}},	//   _सूची_, _عربی_, čítá_, zinu
  { {0x399b0008,0x765a008c,0xdb18005a,0x6aa30535}},	// [6090] קימד, ltty, zivá, zynf
  { {0xc8080023,0x645a0011,0x7c223004,0x7bc31691}},	//   _bởi_, ătit, dpor, xinu
  { {0x2f380029,0x2bdd005d,0x44390024,0x7bc33005}},	//   بثقة_, यवसा, lss_, vinu
  { {0x765a00f2,0x12fa000a,0xf532000a,0x4439206b}},	//   itty, _מהתב, ָ֥א_, oss_
  { {0xe2a6002e,0xc1050087,0x711a000a,0x7bc33006}},	//   öðva_, _سوسي, _מורפ, tinu
  { {0xdb183007,0x44393008,0xe452000a,0x2fe50015}},	//   tivá, iss_, רֶא_, _أكسف
  { {0x0b160029,0xc8080092,0xbed50001,0x7bc33009}},	//   رقية_, _gởi_, _човј, rinu
  { {0x2bdd005d,0x44390024,0xc1720008,0xceb2000f}},	//   यवहा, kss_, ָ֗ה_, _עין_
  { {0x261303af,0x31790050,0xcc170086,0xf77103c4}},	//   _são_, _masz_, _آذرب, هاد_
  { {0x6a670029,0xbc680029,0x765a0bfa,0x2613016e}},	//   _يطال, _تمكن_, ftty, _pão_
  { {0x75f60089,0xc4c90008,0xcf92000a,0x06e9005e}},	//   háze, _פג_, אטי_, ямок_
  { {0x99840029,0x2613001c,0x3179005c,0xd46a0004}},	//   _للمو, _vão_, _nasz_, пиме_
  { {0xa8a70074,0x09b80015,0x6446300a,0x0000006a}},	//   _تصاو, _تطلع_, urki,
  { {0x2613001c,0x889a0008,0x64460012,0x289a000a}},	//   _tão_, _מבני, rrki, _מינא
  { {0x3666010f,0x44390ecc,0xe29a0142,0x387f300b}},	//   _защо_, ass_, чав_, lvur_
  { {0x395f0003,0xdb010123,0xb4db0144,0x7a0a002a}},	//   nfus_, _illä, rgàr, _kętr
  { {0xa06724b3,0x25d70053,0x94760015,0xdfd20021}},	// [60a0] ната_, _רופן_, _أدبا, هير_
  { {0x4420300c,0x7d1b0144,0x7c220123,0x0000006a}},	//   _iti_, _afus, vpor,
  { {0x6ac9005d,0x2f1500dc,0xe1f20029,0xc57a000a}},	//   िपोर, _súgó_, _مسح_, ּרְת
  { {0x7c22300d,0x44200091,0xe2970fa5,0xac97009a}},	//   tpor, _kti_, _чаю_, کنها_
  { {0x7e750030,0x237a0030,0x7c22300e,0xcbe6011e}},	//   _eszp, _kapj_, upor, нцки
  { {0x765a00f2,0x4420003f,0xa3d6000b,0xa01b0b12}},	//   ytty, _mti_, िकट_, _krön
  { {0x91ba0008,0xed6301b2,0xc1ba000a,0x3a3a0030}},	//   ּמִי, íží_, ּמִש, épp_
  { {0xfce60036,0xdbd20020,0x219b000a,0x75f60030}},	//   _зобо, lüüs, ִׁיע, házb
  { {0x399800dc,0x3ce7000b,0x7ae800aa,0xc7c61797}},	//   _kész_, _छुपे_, _wydt, есни
  { {0x0057000a,0xdbd2007c,0x67e6001a,0x316001c2}},	//   עשית_, nüüs, yðju, hfiz_
  { {0xffb700b2,0xa9260004,0xa96a0054,0x4420300f}},	//   גליש_, _здел, _нижа_, _ati_
  { {0x7bc1002c,0xd6d702bf,0xfe37000a,0xf41f0123}},	//   _zmlu, эты_, ערכי_, nväg_
  { {0x499b0008,0x938b0063,0xe3b30015,0x7bc10034}},	//   _משאב, псва_, هرس_, _ymlu
  { {0x4420002d,0x44393010,0xe6940015,0x75f60046}},	//   _dti_, rss_, _للتد, váze
  { {0xa7850086,0x6d403011,0xdce00024,0xf41f00c0}},	//   _جشنو, _odma, _kamē, kväg_
  { {0xdb180604,0xd5b9003d,0x82340021,0x64c50015}},	//   livä, opām_, طرفا, _ليعل
  { {0x656f3012,0x9f6b01b7,0xdbd2007c,0xe4d90015}},	// [60b0] mech, зрез_, füüs, _زودت_
  { {0x75f60089,0xdb0100f2,0xa01b0843,0xa2d50021}},	//   ráze, _yllä, _frön, _ليخت
  { {0xa01b043b,0x6e67004a,0x65680030,0x645d2abe}},	//   _grön, этаж, ődhe, ltsi
  { {0x7bc10089,0x656f0264,0xfd100015,0xdb18007c}},	//   _smlu, nech, مجه_, hivä
  { {0x645d0005,0xdb1800f2,0xade80015,0x21293013}},	//   ntsi, kivä, رفهم_, mbah_
  { {0x200a01e2,0xf09f0092,0x9b680001,0xcb660254}},	//   _gibi_, _ngài_, ешћа_, ваше_
  { {0x9e350286,0x4fd60008,0x645d007c,0xd90f002b}},	//   _шевч, _יושב_, htsi, میا_
  { {0x645d0005,0xd8750029,0xa9220063,0x656f1e79}},	//   ktsi, ناخب, адъл, jech
  { {0x61ed0035,0xf8ae0086,0x76480026,0x395f00a9}},	//   ilal, يکه_, erdy, rfus_
  { {0x644f0c07,0xeafb0015,0x5ae70015,0x4420007c}},	//   duci, _فرضت_, _كثاف, _rti_
  { {0x44200134,0x61ed0007,0x46f50063,0xd5b90024}},	//   _sti_, klal, ъчит, apām_
  { {0xe011005d,0x798b003f,0x2d9f0152,0x442001d7}},	//   ़दाद_, _ungw, _joue_, _pti_
  { {0xe4e50010,0x62850026,0x212900bd,0xf770002b}},	//   гіён, _arho, dbah_, _گان_
  { {0xf8b60008,0x61ed013c,0xe6c50015,0xc7a23014}},	//   _בפני_, elal, _لتعي, _вишк
  { {0x399800dc,0xf1aa0087,0x644f0024,0xf770006e}},	//   _rész_, واره_, auci, _دان_
  { {0x61ed3015,0x045a0029,0x7aec00dc,0x44200c48}},	//   glal, _قلعة_, _öntő, _tti_
  { {0x628500b8,0x644f07dd,0xa2ce000b,0x44203016}},	// [60c0] _erho, cuci, _सशक्, _uti_
  { {0x61ed3017,0x212901c2,0x0000006a,0x0000006a}},	//   alal, abah_,   ,
  { {0x290f00c0,0xdb1802d2,0x2d9f0003,0xde170015}},	//   _ogga_, nivå, _boue_, نقلت_
  { {0x90c6008f,0xbd670054,0x290f01d7,0x7a030030}},	//   _абме, врше_, _ngga_, _főti
  { {0xdb1800f2,0xf41f00c0,0xdb0a0123,0x61e42645}},	//   yivä, rväg_, nifö, moil
  { {0x656f0050,0x61e4008c,0xf41f0123,0xdce0003d}},	//   zech, loil, sväg_, _samē
  { {0x644f005c,0xdce00024,0xdb180bb5,0x73fb004f}},	//   zuci, _pamē, vivä, וּהו
  { {0xf2d30008,0x61e400f2,0x7c660015,0x6934002b}},	//   יעו_, noil, _لاطل, اکار
  { {0xa9670001,0xdb180604,0x656f3018,0xd8230054}},	//   тиња_, tivä, vech, адњи
  { {0x61e42193,0x656f2c21,0x27ec00da,0x644f0085}},	//   hoil, wech, uldn_, vuci
  { {0x61e400f2,0xe5350f54,0xd6da005e,0x8f37004c}},	//   koil, лень, ьти_, כטיג_
  { {0x61e400f2,0xdb180f7a,0xb5a72dd8,0x645d0b56}},	//   joil, sivä, трой, ttsi
  { {0x61e400f2,0xb8570015,0x656f3019,0x645d301a}},	//   doil, _للنص_, rech, utsi
  { {0x656f301b,0x644f301c,0x645d301d,0xb8e80065}},	//   sech, ruci, rtsi, ोप_
  { {0x764f0050,0x13940036,0x2129013c,0xe2c90015}},	//   ącyc, ширю, tbah_, رورو_
  { {0x645d0020,0x62850263,0x11d40015,0xdb0102dc}},	//   ptsi, _vrho, لتقد, _ullå
  { {0x7e990086,0x61ed013c,0x2d9f0003,0xc1040015}},	// [60d0] کنار_, rlal, _roue_, لوفي
  { {0x3375033d,0xdb03006f,0x628504b2,0xc2eb0015}},	//   _сгор, rhnú, _trho, _يعدم_
  { {0xe45f00f2,0xa6f80008,0x75f61043,0x660d0410}},	//   ltö_, תִּי, láza, _kiak
  { {0x61e41740,0x9c59301e,0x1c39056d,0xbd4500c3}},	//   coil, ешку_, езды_, انشي
  { {0x660d000c,0xfeb80086,0xe45f00f2,0x91ba000a}},	//   _miak, _یافت_, ntö_, _נמשי
  { {0x8bc7006b,0xdb010030,0xbbdd0065,0x660d005b}},	//   ъсед, _illú, यवेक, _liak
  { {0xaa560001,0x68eb02de,0xe45f008c,0x75f60030}},	//   гију_, _sygd, htö_, háza
  { {0x1619005d,0x99f50010,0x75f6099c,0x0000006a}},	//   _नंबर_, ыялі, káza,
  { {0x2d0f000b,0xf1b405bd,0xa2ca0065,0x9bc90058}},	//   िशील_, יסק_, _हेन्, _كورك_
  { {0x25a0003e,0xe8f60033,0x660d007c,0x2aab00af}},	//   _soil_, ылы_, _aiak, _отео_
  { {0xadc30092,0xd7a4000b,0x25a00003,0x5fdc000a}},	//   _giản, _ओवरच, _poil_, וחזק
  { {0x857a02db,0xdb1802dc,0x0000006a,0x0000006a}},	//   хсот_, rivå,   ,
  { {0xb607002e,0xa7850087,0x399a004c,0x660d301f}},	//   _sjáð, _مشغو, _רינד, _diak
  { {0xb8820107,0x33d50033,0x69c93020,0xd7590058}},	//   čítk, аіст, liee, _ألغت_
  { {0x61e40df4,0xb7da0135,0xa01b0123,0x25a000da}},	//   toil, _אקסי, _dröm, _toil_
  { {0x04960010,0x69c90161,0xc5d6005e,0x75f6006f}},	//   _броў, niee, _щіль, báza
  { {0xc5fb0008,0xe0da0063,0x20ca00c3,0x61e43021}},	// [60e0] _אפקט, хва_, ربري_, roil
  { {0x660d003f,0x6497000a,0xd47b004c,0x69c904d2}},	//   _ziak, _עדיף_, _טאפל, hiee
  { {0x33770053,0x44320026,0x7e9a0029,0x4d4a080e}},	//   _געים_, _hwy_, عنصر_, епен_
  { {0xcd360074,0xad260015,0xbd360015,0xcdf50033}},	//   اراب, ارضو, اءات, аччы
  { {0xac9401ca,0xcfaa0015,0x4c94016a,0xe573004f}},	//   ралш, _كاسم_, рилс, מַס_
  { {0x44320176,0xab770015,0xbe160015,0xcc870054}},	//   _mwy_, ُمنا_, _موسع, убље_
  { {0xae780008,0x75f600dc,0x3f670036,0x69c90161}},	//   _בְּת, záza, _щиро_, fiee
  { {0x60c900df,0x69c90020,0xdb080123,0x6df60015}},	//   _žemi, giee, _omdö, _إكرا
  { {0x44320026,0x4c78000a,0x57b40296,0x0d17004f}},	//   _nwy_, _שָֽׁ, ибит, _תקמט_
  { {0x75f63022,0x47343023,0xdc3b0643,0x8b65002b}},	//   váza, шнос, _נעבר, _نامم
  { {0x17f70029,0x80cb000b,0x660d008c,0xc6a6096d}},	//   درية_, _सेने, _piak, урпи
  { {0xe9da0036,0x88860029,0xe45f00f2,0x69c90111}},	//   _яке_, _مؤتم, ttö_, ciee
  { {0xe9730086,0x638400dc,0x7bca003f,0x443f3024}},	//   _دهند, zínű, oifu, éu_
  { {0x44320026,0xa87b000a,0xa01b0123,0x75f60030}},	//   _dwy_, _נאור, _fröj, ráza
  { {0x171b00b2,0xe45f00f2,0x6235135d,0xe1f3002b}},	//   _אווע, stö_, ребу, مسر_
  { {0x44320176,0x8afb000a,0x6440016e,0x865b000a}},	//   _fwy_, תהלי, âmic, _נדחי
  { {0x7bca003f,0x2f19004a,0x50670033,0x6aaa0034}},	// [60f0] kifu, возь_, ытва, hyff
  { {0xd101005d,0x7bca003f,0x23e9002b,0x673a03a0}},	//   लेषण_, jifu, _جذبی_, natj
  { {0x0dcb0180,0xaac3000b,0x7bca3025,0x24890085}},	//   нуди_, _वेंक, difu, _hram_
  { {0x673a00dc,0xd657000a,0x3d0f000b,0x329a004f}},	//   hatj, ריאת_, िशें_, _סברד
  { {0x113a0008,0x55bc000a,0xa91d3026,0x69c9007c}},	//   _שתשל, עמדו, ndže, viee
  { {0xba750015,0xfaa5033d,0xd438000a,0x0438000a}},	//   لابت, иало, רטגי_, נטוש_
  { {0x2bb80015,0x69c9053a,0x673a0030,0x9f8402ad}},	//   دانة_, tiee, datj, _höß_
  { {0x4c570021,0x629a008c,0x7bca01c2,0x1cbb0015}},	//   _مضطر, ätoi, aifu, _كاذب_
  { {0xc795054f,0x5fb9000b,0xa91d0085,0x9b95002b}},	//   арны, _इताल, jdže, _پلات
  { {0xf0920008,0x44320026,0x673a00dc,0x69c92c46}},	//   קני_, _rwy_, gatj, siee
  { {0x7bfa00b2,0x69c93027,0x96b93028,0x0f56000a}},	//   _ספעצ, piee, тупу_, ביתם_
  { {0x69330086,0x44320026,0xba9a0008,0xd5e6005e}},	//   _اکثر, _pwy_, _בסעי, ржми
  { {0xe3c60015,0x27e500bc,0x67d5005e,0x53e60015}},	//   لْحَ, poln_, _коду, لأسف
  { {0xf771003b,0xd3480086,0xa01b0123,0x4424003d}},	//   _ذات_, دیده_, _tröj, īm_
  { {0x24891224,0xa01b0123,0xe78a004f,0x1db50065}},	//   _eram_, _frök, _שְׂ֝, ंसात
  { {0xdb010dc4,0x7c240045,0x24893029,0x75d201ec}},	//   _polê, ţiri, _fram_, kāzi
  { {0x75f60030,0x3d0f000b,0x2489302a,0xbfc6302b}},	// [6100] lázo, िशों_, _gram_, абак
  { {0xc43b0008,0xee0e005d,0x7f46005e,0x7413002b}},	//   _שתיי, िद्ध_, режж, _گویا
  { {0x539b000a,0xdff50342,0x52760e7c,0x7d2600c3}},	//   _סיטו, сять, _тупу, لفان
  { {0x9325002b,0x22db05bd,0x75f600bf,0x27220046}},	//   _پرین, _יחיא, zázn, oční_
  { {0x27220089,0xed570010,0x6c060033,0x6e2900bc}},	//   nční_, роч_, аздз, _čebe
  { {0x6d5b302c,0x212000bc,0x7fb50138,0x99870073}},	//   _ecua, lcih_, _лёсі, ksnų_
  { {0x7bca302d,0x2d96302e,0x1d9601b0,0x600b000a}},	//   rifu, _крас, _краё, _יִלְ
  { {0x6d5b002f,0x38690011,0xdb010251,0x27220046}},	//   _gcua, _ţara_, _molè, kční_
  { {0x673a00dc,0xb9970080,0x75fd00dc,0x1d070004}},	//   tatj, рвых_, néze, _вети_
  { {0x07b80029,0xaa460a32,0xda660058,0x8706009b}},	//   اهدة_, _вежл, _ناصي, ияне
  { {0xdce00007,0xceb3004c,0xff17000a,0xa3c9000b}},	//   _pamė, ַיש_, יקית_, लोफ_
  { {0x5886008f,0xa3c9000b,0xc8c7002b,0xdceb003d}},	//   _выка, लोन_, اوین_, legā
  { {0xa91d18e1,0x19bb000a,0xa99b000a,0x5454004a}},	//   udže, _במאב, _שבדר, овят
  { {0x75fd0030,0x9f581279,0x533415df,0xe5030065}},	//   déze, _miró_, жерт, रेषि_
  { {0x31c7008f,0xdceb0024,0xdb010152,0xb7fb000a}},	//   асав, iegā, _colè, _שפות
  { {0xa5350080,0xdb210030,0x2489302f,0x4e1d0065}},	//   _унич, _ütöt, _tram_, _बंबई_
  { {0x40590018,0x24890030,0xe6040015,0x753d1116}},	// [6110] طلاح_, _uram_, _بِيَ, masz
  { {0x753d0014,0x2fc70023,0xdf390029,0xff53006e}},	//   lasz, òng_, اكات_, تخر_
  { {0x3ea70011,0x41b5002b,0xb2840033,0x39463030}},	//   ânt_, _همدر, _дыяк, _odos_
  { {0x51950029,0x753d014f,0x60c90091,0x3cd90033}},	//   _الحذ, nasz, _žemu, льлю_
  { {0x629a002c,0xbc480004,0x0d840033,0xf04402ed}},	//   ätov, ачје_, ўлін, _мэро
  { {0x753d0014,0xfbc4005e,0x673820f6,0x63a52889}},	//   hasz, обіо, _nevj, _john
  { {0xe1ff0023,0xf9910029,0x753d12e0,0xde740015}},	//   _khó_, كبة_, kasz, _ودفع
  { {0x2011000c,0x52d80053,0x82d8000a,0x63a50012}},	//   _hizi_, יווע_, יווג_, _lohn
  { {0xe1ff002d,0x2019003f,0x75fd0030,0x0dc809ba}},	//   _mhó_, _jusi_, kézb, _тури_
  { {0x2795005f,0x20190050,0x9b440015,0xdcfb0091}},	//   сшир, _musi_, _ونقو, _jauč
  { {0x6be40029,0x6b9c0144,0x644f3031,0x20113032}},	//   _بكلم, _òrga, erci, _mizi_
  { {0x3942002e,0x753d12e0,0x75f63033,0x6b810125}},	//   ókst_, gasz, rázo, _halg
  { {0xe6110086,0xb0c7000b,0x59c40015,0xdd7a004c}},	//   _کشت_, _रेलग, _بينك, נטשל
  { {0x20110064,0x27220089,0x6b810020,0x02d60015}},	//   _nizi_, rční_, _jalg, متأخ
  { {0x6b813034,0xcb12000a,0x25b30030,0x644f3035}},	//   _malg, ללם_, ánló_, arci
  { {0x66240029,0xe1ff0092,0xa3c9000b,0x27ed002a}},	//   _بروك, _chó_, लोब_, ślną_
  { {0x25b70086,0x21200064,0x20110064,0xe1ff002d}},	// [6120] _دهيد_, rcih_, _bizi_, _dhó_
  { {0x2a69005c,0xc49b000a,0xbf650015,0xcfaa002b}},	//   łaby_, _עשית, قدمو, دارم_
  { {0x20110064,0x9e6611d2,0xcf250015,0x63060015}},	//   _dizi_, свед, ترقي, _دودل
  { {0xc27b013a,0xddd4006f,0x201902b9,0x6444007c}},	//   _ערכי, ťaži, _fusi_, _kvii
  { {0xeb10000b,0x9f5802b9,0x201101c2,0x201901c2}},	//   ाश्त_, _dirò_, _fizi_, _gusi_
  { {0x6fb60086,0x6b813036,0x753d13c3,0x2d8000bf}},	//   _امسا, _calg, zasz, žie_
  { {0x7f3b000a,0x9b430015,0x6b813037,0xdceb003d}},	//   _תעלו, سنيو, _dalg, regā
  { {0x764100dd,0x6444007c,0x7ae40045,0x9f582e30}},	//   dsly, _ovii, şito, _girò_
  { {0xa3c9005d,0x764100dd,0x189a0015,0xc19b004c}},	//   लोड_, esly, اضعة_, רשפי
  { {0x907b0008,0x7bc80061,0x8c1b000a,0xc07b05bd}},	//   נטיי, _umdu, _עובי, נטיש
  { {0x7bdf038d,0x753d06e7,0x6f79000a,0x95d90b1e}},	//   éque, tasz, בְרו, идот_
  { {0xd6d718a9,0xceb300a3,0x63a50012,0xc88a0067}},	//   сть_, פיר_, _sohn, _مختل_
  { {0x8b030089,0xe4e70127,0x753d062e,0xb0c7000b}},	//   ěřen, сінн, rasz, _रेंग
  { {0x38cb0086,0x9f58002d,0x9cd7000a,0x75240030}},	//   _حامی_, _bhrí_, מוכה_, _efiz
  { {0xe1ff0092,0x753d00dc,0x66260029,0xd90e002b}},	//   _phó_, pasz, _ارتك, _تیک_
  { {0x201101e2,0x63a500b8,0xc2c400e6,0xf207005e}},	//   _sizi_, _wohn, سيقي, сяго
  { {0x656d0035,0x9099006b,0xdb010003,0xc01400eb}},	// [6130] _ibah, шват_, _volé, змущ
  { {0x44290ef3,0x1004006b,0xc5f9003d,0xa91d0d91}},	//   _ita_, пяхм, itēm_, idža
  { {0xa3b8002b,0xdb010003,0x20113038,0x0000006a}},	//   _داير_, _tolé, _vizi_,
  { {0x6d590026,0x6b813039,0x8d65005e,0x2bdb000b}},	//   ugwa, _salg, івле, _बदहा
  { {0x6b810005,0x20190c58,0xa3bd005d,0x7ae40064}},	//   _palg, _uusi_, _आता_, şitl
  { {0xf41f00f2,0x8a790015,0xd6d7004a,0x1a29004a}},	//   yvän_, لحبس_, ́ть_, ажки_
  { {0xb16e002e,0x6b81303a,0xfaa2006b,0x4429008c}},	//   _þýði, _valg, дащо, _lta_
  { {0x4429303b,0xd2b8000a,0x7bd80079,0x7c2b303c}},	//   _ota_, מלות_, anvu, ppgr
  { {0x764f005c,0xa01b0123,0x6d49303d,0xdb180046}},	//   ącym, _eröv, _idea, livý
  { {0x2cb200cb,0xa3ab000b,0xdb1f008c,0xa01b0123}},	//   øyde_, कॉम_, ävät, _fröv
  { {0x69e7008f,0x366905e6,0x3ad5002b,0x8f9c004c}},	//   _людз, шано_, _بياز, טיזי
  { {0x7c290089,0xa50a000d,0x5ee80008,0x8e270010}},	//   _kter, иена_, מַרְ, лiкi_
  { {0x764100c0,0xb3ea0015,0x34fa008b,0xf7451797}},	//   ssly, لعسل_, рхню_, _дело
  { {0xe6c50015,0x7982002a,0xd6a90015,0x04430004}},	//   _وتغي, _zaow, _ندعم_, ќерн
  { {0x613a009c,0x95c60015,0xe7fe000b,0x7c29303e}},	//   ичар_, _ويته, _उठता_, _lter
  { {0x6d49002d,0x4429172e,0x7c29303f,0x0000006a}},	//   _ndea, _fta_, _oter,
  { {0xd5b90024,0x2087007a,0x3f830509,0xdb01007c}},	// [6140] apās_, ойти_, _baju_, _allü
  { {0x24800064,0x75f60046,0xcef601ca,0xdd01005a}},	//   _isim_, kázk, очењ, štěr
  { {0xfe720029,0x3f83016f,0x6306002b,0xdfcf0021}},	//   بدء_, _daju_, _گوگل, خيل_
  { {0xf53f01ab,0x44290123,0x3ea70123,0xf41f0123}},	//   lkår_, _yta_, änta_, kväl_
  { {0x6d490026,0x0c760015,0xdca30680,0xac0a012a}},	//   _ddea, تداد, маци, анда_
  { {0xa01b00c0,0x7b660036,0xdb18002c,0x1c39042b}},	//   _pröv, ітле, bivý, сяць_
  { {0x0ef9008f,0x2258007c,0x7c291139,0x9d560015}},	//   _гэты_, nurk_, _eter, _ونست
  { {0x6e930086,0x2480016f,0x2caf3040,0xdd92002b}},	//   _تلفا, _osim_, bygd_, _تور_
  { {0x91bb004c,0x718b000a,0x22580546,0x2d840073}},	//   ימקי, בְיַ, hurk_, _iame_
  { {0xc5f9003d,0x75f60030,0x57a60033,0x37aa07d1}},	//   rtēm_, lázh, ішпа, ртин_
  { {0x44293041,0x3ffb000a,0x6f79000a,0xa2ca000b}},	//   _sta_, שפיע, זְרו, _हेल्
  { {0xe5c70036,0x3ebe002e,0x2d84004b,0x999f0045}},	//   існо, _ýttu_, _jame_, ărţi_
  { {0xf9d900b2,0x97c60015,0x248d0144,0x94a80888}},	//   _פֿעל, _وتتم, íem_, отра_
  { {0x98a30001,0xa7fd00dc,0x2d843042,0x4429007c}},	//   _циље, ltűn, _lame_, _vta_
  { {0x69cb0026,0xd13b3043,0x24800706,0xc6a60004}},	//   _ymge, иха_, _esim_, _фрли
  { {0x61f90010,0x656d0ef3,0x224d3044,0x66bb000a}},	//   ёнаў_, _ubah, ček_, _כמוה
  { {0x2bdb005d,0x316902c1,0x90550010,0x7538000a}},	// [6150] _बदला, rfaz_, явац, _ואחד_
  { {0x59ca000b,0x4e8b0248,0x3169059d,0xdb18005a}},	//   ़ोतर, ищем_, sfaz_, tivý
  { {0x877b000a,0xdb073045,0x80cb000b,0x7c293046}},	//   שאבי, ülün, _सेरे, _ster
  { {0x2d840041,0x427a00b2,0x127a0053,0x8d77002b}},	//   _came_, _פארג, _פארע, تاطا
  { {0xfd100086,0xc19a0008,0x506403ad,0x2d843047}},	//   نجه_, _השרי, _отра, _dame_
  { {0x447c214b,0x4c840010,0x547c0008,0xd0fa005d}},	//   ינדע, ьлів, שְׁנ, ्धरण_
  { {0xee780015,0x2d8404a0,0x8d7702be,0x0000006a}},	//   _وصفت_, _fame_, _وارا,
  { {0x2d84003e,0xd90f0086,0x48590010,0x75f604af}},	//   _game_, نیا_, броў_, rázk
  { {0x8c250015,0x8c190015,0x7c290d36,0x0000006a}},	//   _رفضه, _طيار_, _uter,
  { {0x2d8407c4,0x3b5401b7,0x8bb70015,0xf41f0123}},	//   _zame_, _окур, _بإرا, rväl_
  { {0xf8a8002b,0x61ed3048,0xf6280015,0x60090091}},	//   مدیه_, koal, يسَى_, _užmu
  { {0x67ef00fb,0x69cb018b,0x25a9003e,0xa3c9000b}},	//   tøjs, _umge, _coal_, लोस_
  { {0x29160029,0x60021baf,0x69fa000a,0x80cb000b}},	//   _عقود_, lôme, _פלנק, _सेले
  { {0xdc880008,0xf7e80015,0x232704d7,0x0000006a}},	//   קְרָ, _وروى_, зори_,
  { {0xf7720008,0x41b60063,0x179a000a,0x11da0015}},	//   _נקה_, псат, _ליסב, موسة_
  { {0x25a9259c,0x69db3049,0xc692000a,0x320902f2}},	//   _goal_, nnue, _טאו_, gmay_
  { {0x55bb0008,0x7f760033,0x248001c2,0x661c0046}},	// [6160] _למקו, зуец, _usim_, írkv
  { {0x2d84304a,0x75fd0030,0x833a004a,0x6446304b}},	//   _same_, nézn, _учит_, mski
  { {0x2746002d,0xc33300f3,0x6446304c,0xd337000a}},	//   líní_, _אות_, lski, _מריה_
  { {0x86360053,0x361a004c,0xa06a2cd9,0xb636000a}},	//   פאנג_, צונד, _лама_, פרנס_
  { {0x6446304d,0x859d000a,0x27460125,0x2d86304e}},	//   nski, ישׁו, níní_, rdoe_
  { {0x70fb000a,0x6446304f,0x1af43050,0x6c470058}},	//   _להכח, iski, мпля, ألوف_
  { {0xd3570053,0x2d840472,0x5b230015,0x7bdf0003}},	//   ליסי_, _tame_, رفيل, équa
  { {0xa9c30036,0x6edb000a,0x64463051,0xa01b0b14}},	//   еськ, _החלפ, kski, _grös
  { {0xe8720086,0xf98f0015,0x64463052,0x9d2b000a}},	//   رندگ, طبي_, jski, _הֵבִ
  { {0x6002001c,0x25a9013c,0x9cbb000a,0x0ba90015}},	//   lômb, _soal_, _הצמח, _والى_
  { {0x8b950010,0xb8f3021e,0x4667005e,0xcb8b000a}},	//   _ўруч, _हे_, прям_, _לְאֹ
  { {0x1a9b0053,0x18a600a4,0xba9b000a,0xf76f002b}},	//   _ליבע, _наем, _לסבי, پای_
  { {0x296b000a,0x44b40033,0xafdb01de,0x64463053}},	//   _ה֣וּ, ебяс, _svøm, gski
  { {0x07a30010,0xf3f10092,0x60c43054,0xabe7000a}},	//   _пачн, ộ_, dzim, ּֽךְ_
  { {0xd3780036,0xa2940036,0x629a006f,0x64463055}},	//   ччя_, нарі, ätop, aski
  { {0x61f90010,0x644617eb,0x365b000a,0xd6db000a}},	//   інаў_, bski, _הכהנ, _לחול
  { {0xe45f00dc,0x765a3056,0x32090061,0x64460030}},	// [6170] szöb_, luty, rmay_, cski
  { {0x14d800b2,0xdb013057,0x320900da,0xc10400c3}},	//   _מוחל_, _solí, smay_, رولي
  { {0x60c41480,0xdb03001a,0x4fc40a93,0xf3ff016e}},	//   azim, lhnö, хста, ltão_
  { {0xf3ff016e,0xa3c9000b,0x2245013f,0xfcd50058}},	//   otão_, लोर_, álku_, وياج
  { {0x69c0002f,0x8ccd005d,0xf3ff001c,0x8e08005e}},	//   dhme, _देशो, ntão_, їнів_
  { {0x765a00f2,0xb09a000a,0x69de0003,0xdfd10015}},	//   kuty, _וישר, épen, _شيأ_
  { {0x1e350033,0x75f60030,0xa01b3058,0xdb1800bf}},	//   _інаў, mázv, _trös, chví
  { {0xdb080152,0x3eae00b8,0x64463059,0x38290054}},	//   _modè, äfte_, yski, ожио_
  { {0x9f640064,0x8755006b,0xd7f80045,0x75fd0030}},	//   ütçe_, мънц, flă_, tézn
  { {0x69c00359,0x6d5d0061,0x6604305a,0x644610fa}},	//   ahme, _ısay, _shik, vski
  { {0x64460050,0x9be40036,0x05760029,0x6d5a0045}},	//   wski, _чітк, واحد, şcaţ
  { {0xd7f80011,0xf8750015,0xe945002b,0x79a40004}},	//   ală_, _يهاج, _آرای, _прче
  { {0x644600df,0xb4b8005d,0xe8940010,0xd7f80045}},	//   uski, चने_, _паць, blă_
  { {0x395f0020,0x031a0015,0xb17b0123,0xd7f80045}},	//   lgus_, تتحت_, _skåp, clă_
  { {0x27460125,0xa18a006b,0x6446305b,0x395f305c}},	//   síní_, обва_, sski, ogus_
  { {0x395f305d,0xe1fa0210,0xd5af0015,0x6446305e}},	//   ngus_, іга_, _نفى_, pski
  { {0xa0670403,0x60c4016f,0xa7c6002b,0xc5690015}},	// [6180] мата_, uzim, _رژیم_, _رحيل_
  { {0xa2b6000b,0x7d1b305f,0xd00a0054,0x60c40012}},	//   _उथप्, _agus, цезе_, rzim
  { {0xf4130008,0xa2060036,0x763a0053,0x44203060}},	//   _שפת_, _опод, ַעסג, _hui_
  { {0x44201c23,0x6026009c,0x01360015,0x315a0058}},	//   _kui_, _одма, _تعدد, _بجدة_
  { {0x75e80064,0x0c7a0002,0x79890034,0x7c83004a}},	//   mızd, تصاب_, ddew, вуще
  { {0x442003a2,0xdca30054,0x6fc00061,0xe453000a}},	//   _mui_, таљи, _böce, דֶק_
  { {0x44203061,0x0e55006b,0x75f60030,0x2018019a}},	//   _lui_, _пътя, lázu, _iiri_
  { {0x75e801e2,0x44200152,0x621b000a,0x7e97002b}},	//   nızd, _oui_, חוקק, _تنفر_
  { {0xdb080152,0xb81400d7,0x20183062,0x6d403063}},	//   _modé, ндиј, _kiri_, _iema
  { {0x69c0003e,0xa09b0053,0x909b00a3,0xb807002b}},	//   shme, קייט, קסיק, وييم_
  { {0xbbd7013a,0x0f57013a,0x6d400849,0xcf570008}},	//   _קובץ_, ויים_, _kema, ובית_
  { {0xb9930015,0xadc30016,0x75f60030,0xb886001a}},	//   _للمب, _miến, kázu, gríð
  { {0x442002d7,0x39440c80,0xf9c70086,0x6d400849}},	//   _cui_, mams_, _تحلی, _mema
  { {0xa3c9014e,0xf3ff001c,0xdb0a002e,0x442000dd}},	//   लों_, rtão_, rkfæ, _dui_
  { {0xf3ff03af,0x6627002c,0x7a270061,0xdb010247}},	//   stão_, ľské, _kıta, _kolá
  { {0x39440007,0x662701b2,0xdb080003,0x2018007c}},	//   nams_, žské, _codé, _airi_
  { {0x201801e2,0xdbd60197,0xdb1a00dc,0x24920026}},	// [6190] _biri_, _kään, _elté, _grym_
  { {0xdbd60209,0x20180509,0x2245001a,0x657d3064}},	//   _jään, _ciri_, álks_, lesh
  { {0x9ee90029,0x20180375,0x39440f28,0xdfd8006b}},	//   أفضل_, _diri_, kams_, фът_
  { {0x394402fd,0xa2b60008,0x3f871c1e,0xdbd60209}},	//   jams_, _נפרד_, žnu_, _lään
  { {0x7c20002d,0x91ba000a,0x6d400287,0x7c640015}},	//   _cumr, _זמרי, _dema, ناول
  { {0x6d400020,0x657d003f,0xe452000a,0xa4b8000a}},	//   _eema, hesh, אֶה_, ולדה_
  { {0x645d000c,0x6d40003e,0x657d0705,0xdb0a0012}},	//   husi, _fema, kesh, chfü
  { {0x6b9a00b8,0xceb20008,0x657d003f,0x395f0095}},	//   _entg, _גיל_, jesh, ugus_
  { {0xa2d1014e,0x645d18a6,0xdb01002c,0x395f3065}},	//   _डेस्, jusi, _dolá, rgus_
  { {0x09020010,0x8f19000a,0x6d403066,0x5ba70033}},	//   ыпын, ּוֹת, _zema, _ўраз
  { {0x442002d7,0xf1bf001c,0xdb01002d,0xdce00046}},	//   _sui_, _olá_, _folá, _obmě
  { {0x39440024,0x657d0a72,0x645d3067,0x442011ff}},	//   cams_, gesh, fusi, _pui_
  { {0x44203068,0x26ca002c,0x88c40029,0xd4f50010}},	//   _qui_, úbor_, _لتول, вяры
  { {0x442000a7,0xf1bf00dc,0xa3ab000b,0x437505a7}},	//   _vui_, _alá_, कॉल_, куст
  { {0x645d00df,0xf7700002,0x96750033,0x657d3069}},	//   ausi, _خان_, _чылі, besh
  { {0x2018306a,0x645d1035,0xa0a6018d,0x4420306b}},	//   _siri_, busi, набд, _tui_
  { {0x645d25d7,0x2f56007a,0xc059005e,0x6d402195}},	// [61a0] cusi, етес, діє_, _rema
  { {0x7f86003b,0x04790074,0x6d40306c,0x1f630004}},	//   علان, _کلیک_, _sema, лкум
  { {0x87b60053,0x201800bd,0xdb1a0152,0x4e1a0018}},	//   עלעס_, _viri_, _ulté, ستاد_
  { {0xadc30092,0xccf9002a,0x80cb000b,0xc692015b}},	//   _viến, _byś_, _सेके, טאב_
  { {0x5316002b,0x39440091,0x2018306d,0x711b000a}},	//   _تذکر, vams_, _tiri_, _מוכפ
  { {0xf09f0023,0xadc30023,0x657d000c,0x84570008}},	//   _ngày_, _tiến, zesh, תבסס_
  { {0x657d000c,0x39440f28,0xbf9b004c,0x6d40306e}},	//   yesh, tams_, _צילש, _tema
  { {0xdbd6022d,0x7bc3002c,0xc5f90024,0x6e930015}},	//   _sään, ahnu, ntēt_, _حلفا
  { {0xdb01306f,0xa3c2000b,0xdbd6008c,0xfce30477}},	//   _volá, ्फा_, _pään, _бото
  { {0x7bc3018b,0x645d0095,0xd7f00015,0x95fb000b}},	//   chnu, vusi, ؤكد_, ृष्ट_
  { {0xd6da0f22,0xab6900e5,0xda650015,0x394413b3}},	//   яти_, _تحقق_, _لاني, pams_
  { {0x3f8a2c20,0xdb180057,0x7abb000a,0x09360015}},	//   _labu_, chvá, _מצבו, _أراج
  { {0xdb0700dc,0xc8b30086,0x657d0705,0x8cd6000b}},	//   ülön, _مصوب, resh, _मेमो
  { {0xf1bf0084,0x7ae40011,0x889b000a,0xc2c5002b}},	//   _slá_, şitu, _מבדי, پيري
  { {0xa3c2005d,0x645d3070,0xd1b1002b,0x656f0012}},	//   ्फ़_, susi, لیدک, pfch
  { {0x7afa00cb,0x657d00aa,0x61e90a3c,0x645d3071}},	//   _mytt, qesh, čelo, pusi
  { {0x3f8a0a72,0xdbd1007c,0x7afa2ecb,0x89eb004f}},	// [61b0] _babu_, tüüb, _lytt, לַמֵ
  { {0x2a72002a,0x6002016e,0xdb18007c,0xce95006b}},	//   łyby_, tôma, livõ, казъ
  { {0x8e990029,0x7afa0cbb,0x0000006a,0x0000006a}},	//   بناء_, _nytt,   ,
  { {0x3eae01d1,0xdb18007c,0x3236000a,0x644d0091}},	//   äfta_, nivõ, _שטרן_, _kvai
  { {0x7bc3002d,0x5067005e,0x4d880015,0x628a001a}},	//   thnu, _ятна, عَهُ_, _áfor
  { {0x82340086,0xfd1000a2,0xdb18007c,0x7afa0a3a}},	//   _جریا, حجم_, hivõ, _bytt
  { {0xa91d0007,0xf9910029,0xda62007a,0x75e80061}},	//   ldži, لبة_, авщи, nızc
  { {0xa91d00df,0x5975008f,0xca74002b,0xccf9002a}},	//   odži, тыку, انيک, _tyś_
  { {0xa91d0007,0x7bc30003,0xf1b4004f,0x09f60058}},	//   ndži, phnu, טסק_, خفية_
  { {0xd7ee0029,0xa91d0007,0xeb930029,0xcc170015}},	//   يكي_, idži, _حظر_, _أذرب
  { {0xd709005f,0xcf92000a,0x644d1433,0xa2d1000b}},	//   ьное_, בטי_, _avai, _डेल्
  { {0xdb183072,0x75fd0030,0xa91d0091,0xf8690015}},	//   givõ, nézh, kdži, _يمضي_
  { {0xd7950015,0xc4830033,0x45d30033,0xf9b6000a}},	//   _للإخ, аляк, роўс, _שהנך_
  { {0x07a50b1e,0xa6950099,0x69e30085,0x090402a3}},	//   _јакн, _ариј, šteđ, _спін
  { {0x43430758,0x3f8a013c,0xfbd2000a,0xdb010144}},	//   ресв, _rabu_, בתם_, _dolç
  { {0x75f600dc,0x3f8a01c2,0x386d059f,0x64c60058}},	//   rázs, _sabu_, oter_, _ليبل
  { {0x7bc100f2,0xc5f90024,0xa3c2005d,0x386d0aa0}},	// [61c0] _ollu, rtēt_, ंसद_, nter_
  { {0xe29a0001,0x386d3073,0xc5f9003d,0x4226011e}},	//   _жао_, iter_, stēt_, _идов
  { {0x386d3074,0x644d0024,0x69de00dc,0xc5f9003d}},	//   hter_, _zvai, épek, ptēt_
  { {0xf2d3013a,0x06960053,0x386d1f43,0x6c360015}},	//   _כעת_, כדעם_, kter_, نفصا
  { {0x0137000a,0xc0e3005e,0x55ab004c,0x7afa3075}},	//   _ברכת_, _вояк, ויײַ, _sytt
  { {0x1bf30033,0x75fd0030,0x80cb0065,0xda660369}},	//   апіў, tézk, _सेटे, نابي
  { {0x29000007,0x0a6a000d,0xee3a0033,0x386d27fc}},	//   _šia_, фрли_, _іна_, eter_
  { {0x7bc10020,0xa9670001,0x6f030064,0x386d3076}},	//   _ellu, вића_, ünce, fter_
  { {0xbc6a0074,0xa3c2005d,0xa8a30033,0xdb18007c}},	//   _زمان_, ंसा_, арэк, vivõ
  { {0xdb08002c,0xf41f00f2,0x2cc40064,0x7afa00f2}},	//   _hodí, ivät_, ırdı_, _tytt
  { {0xa91d00df,0x9f58002d,0x386d0b9d,0x2f5b000a}},	//   zdži, _bhrú_, ater_, ודינ
  { {0xa91d0091,0x386d3077,0xf4350033,0xdb18007c}},	//   ydži, bter_, лемэ, uivõ
  { {0x386d3078,0xdb18007c,0xe4e7005e,0x75fd3079}},	//   cter_, rivõ, тінн, nézi
  { {0x9f9a0020,0xdb1803ff,0x798b002a,0xdb080046}},	//   _jääb_, sivõ, _zagw, _lodí
  { {0x26da0020,0xfc480092,0x24180139,0x237e007c}},	//   _äpo_, hử_, торы_, õtja_
  { {0xf207005e,0xe717000a,0xc5f9003d,0x82340015}},	//   тяго, _בחור_, rtēs_, شرفا
  { {0x3495008f,0xa91d0007,0xf4870127,0x5067006b}},	// [61d0] _сапр, udži, _руйн, ътва
  { {0x69c20176,0xa2830086,0x7bd8003f,0xa91d307a}},	//   _lloe, _پیرو, jivu, rdži
  { {0x7e280010,0xdef10015,0x4ed50015,0xbe880033}},	//   віча_, حًا_, دقاء, ксце_
  { {0xc6d90053,0xdb0300b8,0x1eea0086,0x386d307b}},	//   ײַער, rknü, رونی_, yter_
  { {0x115a00b2,0xf1a40010,0x386d307c,0xc212000a}},	//   _אדרע, _трэн, xter_, _להט_
  { {0xadc30092,0xab640036,0xac9600e6,0xaf34002b}},	//   _thắn, ивіл, انوا_, _نرفت
  { {0x798b0035,0x2bb80015,0x69c21fe5,0xda640015}},	//   _pagw, خانة_, _bloe, لايي
  { {0x2489016f,0xf985000d,0x60c90007,0xceb2000a}},	//   _osam_, угио, _žemy, _פין_
  { {0x5c99008f,0x386d038d,0x7bd80020,0xdbd10020}},	//   _якая_, uter_, bivu, _küün
  { {0x798b020a,0x28090015,0xa91d00bc,0x44320046}},	//   _wagw, عْدَ_, deže, _rty_
  { {0x61e9010b,0xb8fa000b,0x2489013c,0x2bb8000b}},	//   čelj, _डे_, _asam_, _अवता
  { {0xf41f022d,0x600b0061,0x75e80061,0x386d307d}},	//   yvät_, lümd, fıza, pter_
  { {0x3a2500f6,0xa01b00dc,0xb4c0000b,0xf8690015}},	//   _hulp_, _csök, ूछे_, _أمتي_
  { {0xf7450083,0x4852002b,0x9f840030,0x600b0061}},	//   _секо, _اپوز, _töé_, nümd
  { {0x24890048,0xf6790053,0xf7720008,0xfbd2000a}},	//   _esam_, _טאַמ, _הקו_, מתך_
  { {0x05660e71,0xc48601da,0xf1aa02be,0x0000006a}},	//   _свин, _блик, رازه_,
  { {0x91060892,0xcf5a005e,0x41060033,0x600b0061}},	// [61e0] упае, ереч_, узав, kümd
  { {0x728a0124,0x351b0008,0xdb0a0030,0x9f960030}},	//   _због_, _אופנ, űnés, _küés_
  { {0xdb08307e,0xc7d6000a,0xae7a0033,0xee3a307f}},	//   _podí, נועי_, эсах_, хне_
  { {0x21a6004a,0x224c0247,0x65663080,0x75fd0030}},	//   _симм, ádku_, ngkh, tézi
  { {0x61e43081,0xdb080264,0x653b004c,0x91f7000a}},	//   mnil, _vodí, גענד, _תמכו_
  { {0xab94005e,0x69c20079,0x0fda0015,0xec1300c3}},	//   рикі, _sloe, _أبحث_, موند
  { {0xed5a0036,0x53370053,0x61e43082,0xfe45002b}},	//   _пов_, אנצן_, onil, _نکنی
  { {0x7bd8022d,0xdd000064,0xb9980054,0xde1a0015}},	//   sivu, ştın, твих_, _أقرت_
  { {0x69c20150,0x7bd8008c,0x600b0061,0xed57006b}},	//   _vloe, pivu, bümd, _щот_
  { {0x2bf6008f,0x06fd0089,0x61e41255,0x2b91002b}},	//   _сябр, číná_, hnil, _وینس
  { {0xa91d0796,0xcff7000a,0x3a9a005e,0x2bd9000b}},	//   veže, רציה_, _ятаю_, _भगता
  { {0x61e401c0,0x9f5f0052,0x0000006a,0x0000006a}},	//   jnil, ðrún_,   ,
  { {0xcbb8000b,0x75fd0030,0x61e40d64,0xa91d06c0}},	//   _अवाञ, kézv, dnil, teže
  { {0xccf3000a,0xd235006b,0xb357002b,0x61e43083}},	//   מכר_, ингъ, دیدا_, enil
  { {0x57fb0008,0x9bb7000a,0xc7d7000a,0xe610002b}},	//   _רלוו, נהלה_, _תווי_, تشی_
  { {0x11d40029,0xa91d00bd,0x61e43084,0xaa4a0046}},	//   متقد, seže, gnil, jžíš_
  { {0x2489001c,0x361c000a,0x4fd50fe4,0x753d0030}},	// [61f0] _usam_, _אוהד, ажат, mbsz
  { {0x600b01e2,0x61e40019,0x44390f4b,0xfe71009a}},	//   küme, anil, mps_, يگز_
  { {0x443916ac,0xa3c2005d,0x5d350015,0x3eba3085}},	//   lps_, ंसर_, لفائ, gypt_
  { {0xf6530008,0x44390b00,0x80d0000b,0xce580015}},	//   מצע_, ops_, _ठेके, اؤلا_
  { {0xcb6900d7,0xeb8e0c5b,0x644f0aff,0x6ed5000b}},	//   вале_, ои_, nsci, _येरु
  { {0x644f002d,0xfd100029,0x645d1a28,0xd018006b}},	//   isci, سجن_, irsi, _бфс_
  { {0xdce9016f,0x9e15005e,0x4e89000a,0x600b0061}},	//   _obeć, _вдві, _בָּ֣, rümd
  { {0x0000006a,0x0000006a,0x0000006a,0x0000006a}},	//     ,   ,   ,
  { {0xc9a60080,0x6d4b3086,0x29190123,0x317c000a}},	//   рвые_, maga, äsa_, תאחד
  { {0x7c390026,0x6d4b1636,0xa7b5023e,0x49da002b}},	//   mpwr, laga, рсиј, _یانگ_
  { {0x98aa0024,0x2bc8005e,0x36690054,0xd705012e}},	//   ēmām_, _суто_, њамо_, рзни
  { {0x660d000c,0x6d4b2b20,0x58d903fc,0xb9e4005e}},	//   _chak, naga, _идея_, _лічи
  { {0xdb08002d,0x44630063,0xe72e11bd,0x1869006b}},	//   _iodá, овяв, _ме_, _рали_
  { {0x60cd0048,0x3e51002a,0x98ca000a,0x6b830754}},	//   dzam, kąt_, _שֶׁ֥, neng
  { {0x6d4b0035,0x753d00dc,0x2bb8000b,0x96940033}},	//   kaga, bbsz, _अवसा, _грыш
  { {0x61e404f9,0x6b831033,0x6d4b3087,0x45d302d9}},	//   unil, heng, jaga, _мојс
  { {0x69c900f2,0xcf460805,0x15fb000a,0x6b833088}},	// [6200] ihee, инай, _שהפע, keng
  { {0xe80b014e,0x6b833089,0xf41f00c0,0x6d4b308a}},	//   _सीमा_, jeng, svär_, eaga
  { {0xdd8f0001,0x60cd003f,0x0377000a,0x8e8608f0}},	//   ош_, azam, _דתית_, ргее
  { {0x3e6e0089,0x6d4b1645,0x3eba308b,0x644400aa}},	//   rýt_, gaga, rypt_, _kwii
  { {0xd5770008,0x60cd005c,0x7d09005c,0xdd8f00e6}},	//   שתנה_, czam, _czes, بون_
  { {0x69c90111,0x6b83308c,0x3946014b,0x6d4b042c}},	//   ehee, geng, _seos_, aaga
  { {0x6d4b013c,0x9a870015,0x753d002a,0xa3ab000b}},	//   baga, لَوْ_, ybsz, कॉट_
  { {0x645d0176,0x6d4b002d,0x6c360086,0x75fd0030}},	//   yrsi, caga, _نفرا, nézt
  { {0x6e200035,0xdce200bd,0x6b830586,0xdb080264}},	//   _iimb, ogoč, beng, _dodá
  { {0xdb1a0014,0x7524003f,0xa7730142,0x660d308d}},	//   _eltá, _agiz, ольч, _shak
  { {0x645d0176,0x9f97000a,0x2b2b002b,0x60cd02b9}},	//   wrsi, בדיה_, _شغلی_, zzam
  { {0xaadb0008,0x6e20003f,0x69c90111,0x4439308e}},	//   _בחבר, _jimb, chee, tps_
  { {0xb4c1005d,0x75e80064,0x3e51005c,0x4439308f}},	//   ंने_, mızl, ząt_, ups_
  { {0x6e200939,0x44393090,0xeda3000b,0x752402b9}},	//   _limb, rps_, _ऐच्छ, _egiz
  { {0xd6270124,0x6d4b00b6,0x7228005e,0x69c000cb}},	//   _које_, yaga, ицтв_, okme
  { {0x75e801e2,0x660d003f,0xb1a40484,0x171b000a}},	//   nızl, _uhak, ошук, _בווע
  { {0x6b83003f,0x8cd6000b,0xf8b8000b,0x69c0007c}},	// [6210] yeng, _मेलो, ेनिय, ikme
  { {0x66710086,0x60cd3091,0x7d09005c,0xbf38005e}},	//   _بگیر, rzam, _rzes, изує_
  { {0x22950029,0x3ed90086,0x60cd005c,0x6e203092}},	//   _الجس, دواج_, szam, _bimb
  { {0xde580036,0x6b830375,0xad670015,0x225e006f}},	//   раці_, weng, شاؤه, átke_
  { {0x0c870010,0xed580010,0x6d4b013c,0x44290553}},	//   рыем, роі_, raga, _jua_
  { {0x44290023,0x3ea700c0,0x6d4b0035,0x44210820}},	//   _mua_, änts_, saga, _jih_
  { {0x0d67010f,0x6b833093,0xdb080057,0x69c90079}},	//   _възм, reng, _podá, thee
  { {0x4998005f,0x2bd9000b,0x0e440033,0x69c9008c}},	//   атья_, _भगवा, _фэрм, uhee
  { {0x4429002f,0x75fd00dc,0x6b830278,0x69c93094}},	//   _nua_, hézs, peng, rhee
  { {0xeb900015,0xd6390033,0xdb030030,0x38bc0125}},	//   _يظل_, лямі_, ajná, _sárú_
  { {0x7c293095,0x66f20046,0x3f913096,0x8f88000a}},	//   _huer, věké, _mazu_, בְרֵ
  { {0xc3290dab,0x69de0030,0x44293097,0xaa76000a}},	//   _טו_, épet, _bua_, _לתעד_
  { {0x4421016f,0x44293098,0xa91d3099,0x394d309a}},	//   _bih_, _cua_, beža, maes_
  { {0xfbc70074,0x7c290467,0x44290375,0xe8f8005e}},	//   ست_, _muer, _dua_, _тлі_
  { {0x442911dd,0x21a60004,0x46350058,0x75fd01d3}},	//   _eua_, бивм, _ارتأ, tézt
  { {0x7c2900dd,0x7546123a,0xe80b0065,0x0000006a}},	//   _ouer, _униз, _सीता_,
  { {0x10a30608,0xf9920135,0xdfea16d7,0x6e20309b}},	// [6220] питн, הרן_, гдад_, _rimb
  { {0x43860029,0x33660010,0xaf960054,0x6e20309c}},	//   _الدق, _увог, љшај, _simb
  { {0x3f91018b,0x6002001c,0x7e6500d9,0x539b000a}},	//   _dazu_, nômi, guhp, _עיטו
  { {0x237f016f,0xa2d1000b,0x44290034,0x7c29026c}},	//   đuje_, _डेट्, _yua_, _buer
  { {0x7c2902c1,0x7bca003e,0x89d80086,0xdd8f0015}},	//   _cuer, thfu, یوتر_, عوه_
  { {0xac25042b,0x3f910e61,0x7c29309d,0x6e20309e}},	//   іфік, _gazu_, _duer, _wimb
  { {0x69a4014e,0xc3330008,0xe80b005d,0x6e20309f}},	//   काली, לוג_, _सीधा_, _timb
  { {0x7c290467,0x28d9000b,0x7a530015,0x383408b0}},	//   _fuer, _बेहि, أضوا, онир
  { {0x7c210b56,0x600b0061,0x98b7006b,0x7c2905ed}},	//   _filr, lüma, йлът_, _guer
  { {0x7c2f0152,0x4429001c,0xec370008,0x75e80064}},	//   _écra, _rua_, _לאמר_, sızl
  { {0x442930a0,0x7c2900b8,0x69de00dc,0x6ffb004c}},	//   _sua_, _zuer, épes, רהיפ
  { {0x6fc001d1,0xceb301e4,0x442100e8,0x65ab0054}},	//   _böck, לית_, _sih_, утог_
  { {0x44290023,0x65600125,0xdffa000b,0xa91d036d}},	//   _qua_, ómha, ्ताद_, ležn
  { {0x44290092,0x600b0064,0xb8de021e,0xf8a90067}},	//   _vua_, küma, ीन_, _خدمه_
  { {0x69d90176,0xd5bb0063,0x3f91005c,0xb5c8002b}},	//   _ymwe, _бсп_, _razu_, _گويم_
  { {0x6fc000b8,0x463b0053,0x442930a1,0x22510030}},	//   _höch, _געהע, _tua_, rszk_
  { {0xc605014e,0x7bc801e2,0xb3eb0029,0xbfd90036}},	// [6230] रतीय_, _oldu, _معدل_, адає_
  { {0x2fc70023,0x6aa8000b,0x6d4902ad,0x0000006a}},	//   óng_, _कपूर, _seea,
  { {0x6fc0018b,0x7c2902c1,0xa91d0085,0xf3ff016e}},	//   _möch, _suer, ježn, stãs_
  { {0x29d30011,0x7c2930a2,0x6fc00012,0xa91d07c4}},	//   nţat_, _puer, _löch, dežn
  { {0x7bc60007,0x2c720034,0x8b252c75,0x6d4930a3}},	//   _įkur, gâd_, одле, _veea
  { {0x40340142,0x5274002b,0x7b670c31,0xeb990fdc}},	//   _херс, _بایز, стде, рик_
  { {0x03bc004c,0xdb0a0012,0x7c290012,0xeb90009a}},	//   רצול, ckfü, _wuer, عظه_
  { {0x08c51dfa,0x32dc000a,0x98bd002a,0x7bc8001a}},	//   жбин, טחונ, _lewą_, _eldu
  { {0x7c210084,0x2c720034,0xdb1a0012,0x394d30a4}},	//   _tilr, câd_, _altä, raes_
  { {0x29030024,0xeb9b0087,0xaa59004a,0x69de0003}},	//   āja_, _حضرت_, _вижу_, éper
  { {0x6b9c02c1,0xa5da0015,0x89d6002b,0x5e56004c}},	//   _órga, لبحر_, صویر_, ֿישע_
  { {0x69d900b8,0x04ca0015,0x26cb002a,0x7bc3001a}},	//   _umwe, لوجي_, ąco_, lknu
  { {0xe9190036,0xf7950010,0x26c300bd,0x4dfa0053}},	//   _тоді_, _мадэ, šjo_, שפרא
  { {0xe739049d,0x7bc330a5,0xf7940138,0x7d06174d}},	//   _тек_, nknu, _начэ, _økse
  { {0xe802000b,0xc5f60058,0x41b60598,0x0000006a}},	//   _रीटा_, _وثبت, осат,
  { {0x7afe007c,0x0206008b,0x75f601d3,0x0000006a}},	//   üpti, ізан, házz,
  { {0x7bc3002e,0xe1f70484,0xb0c4000b,0xf8c9000b}},	// [6240] kknu, ігу_, लैंग, िनिय
  { {0x33660015,0xdf490015,0x82360021,0x94bb000a}},	//   _بهدف, مؤمن_, _ورجا, _כמפת
  { {0xd37b0053,0x2c720034,0xaec60138,0x0000006a}},	//   _דריט, wâd_, ўбел,
  { {0xa3c2005d,0x2c720026,0x867a000a,0x6010008c}},	//   ंसक_, tâd_, ירעו, däme
  { {0xf1b30008,0x61430033,0x6606008c,0x6ab7000b}},	//   _חסר_, _іера, ilkk, _अथॉर
  { {0x2ac60001,0x749b004c,0x649b015b,0xa91d0b28}},	//   жљив, יינפ, יסנד, težn
  { {0x441b0008,0x539b004c,0x3ebe2626,0x601002dc}},	//   בוסס, שיצו, _ætt_, rämd
  { {0xa91d116e,0xea950010,0x9d460033,0x0000006a}},	//   režn, яшчэ, _феад,
  { {0xc2130008,0xd83a0010,0xa91d0796,0x2902001a}},	//   והה_, шэй_, sežn, æka_
  { {0xc07b0053,0x907b000f,0x6606008c,0xa91d013f}},	//   סטיש, סטיי, elkk, pežn
  { {0xa91d0048,0x600b0020,0xceb3000a,0x659502a3}},	//   bežo, kümn, ֥יר_, пану
  { {0xe4a7007a,0xda650067,0x3ad30015,0x6fc00012}},	//   орго, _رامي, _غينز, _wöch
  { {0xe5070015,0xb9b30015,0x6fc00012,0x29d30045}},	//   تبدي, _تمنع, _töch, rţat_
  { {0x93270015,0xa7d30015,0x82370067,0x6606008c}},	//   ترحن, _يتوص, قررا, alkk
  { {0xe658003b,0x88370024,0x6234000d,0xa294005e}},	//   _البث_, ķēša, десу, марі
  { {0xc035023e,0xe2f8005e,0x26d8006f,0x600b007c}},	//   знај, цесі_, úrou_, gümn
  { {0x61f80010,0x629e01c2,0x51f80138,0x0000006a}},	// [6250] інуў_, _erpo, іную_,
  { {0xdb180084,0xdb210107,0x15140033,0x35e1000b}},	//   mkvæ, _štít, _ідэя, _पगड़
  { {0x68e40046,0xeeab0b1e,0xc332004f,0x9e6400ce}},	//   _židl, штак_, _רוט_, двєд
  { {0x12fa000a,0xb17b30a6,0x867b004f,0x0000006a}},	//   _להתב, _småf, שראו,
  { {0xd59c0053,0xc1050225,0xb1360008,0xdb18002e}},	//   יבאל, _روسي, _מארח_, nkvæ
  { {0x00ba0008,0x42ab004f,0xf082009a,0x0000006a}},	//   _המשמ, ֹסֵ֑, _سیمپ,
  { {0xf1bf30a7,0x7bc330a8,0x9f41016e,0x75f60030}},	//   _giác_, rknu, anhã_, rázz
  { {0x2a360029,0x3e7500c0,0x7bc330a9,0x314b000a}},	//   أكيد_, måt_, sknu, ׁתֶּ
  { {0x3e750123,0xdddc0046,0xd8760058,0x0000006a}},	//   låt_, _zprů, كميت_,
  { {0x2fb60008,0xf771006e,0x9bc9000a,0xcaa70015}},	//   ִּים_, راخ_, _פֶּ֖, _وصاي
  { {0x38ca002b,0x3e750123,0xa91d0069,0x95c60058}},	//   لایی_, nåt_, pežo, كيده
  { {0xca960008,0x69dc0091,0xda7a000a,0xd7c9002b}},	//   _מדעי_, _įreg, _לנער, _گوته_
  { {0xe8ee010f,0xc952000a,0x99d40015,0x69cb1bab}},	//   _чл_, _טמא_, _تتلا, _ilge
  { {0xf8b60008,0x889a0008,0x6cfa0008,0x3e7500c0}},	//   _מפני_, _לבני, מפרס, kåt_
  { {0x515a0010,0xdbd700f2,0xc7b40015,0x63830033}},	//   йшаў_, määs, _تصنع, эгра
  { {0x7c3b01e2,0x3e750123,0x5bb8000b,0x0000006a}},	//   _otur, dåt_, _अव्व,
  { {0x3cdb000b,0xdb0130aa,0x80660138,0xb8860052}},	// [6260] _खेले_, _koló, яваж, msíð
  { {0xb886002e,0xc003000d,0x6d5b30ab,0x6d420c12}},	//   lsíð, епук, _adua, wboa
  { {0x7c3b30ac,0x03bb000a,0xdee32fd2,0x69cb143e}},	//   _atur, _הציל, нофи, _olge
  { {0x600b0064,0x2612000b,0x865a004f,0x0000006a}},	//   lüml, _धीमी_, מדעי,
  { {0xc19b000a,0x6d5b0034,0x6d4230ad,0x601002dc}},	//   _השכי, _ddua, rboa, rämb
  { {0x600b0064,0x69cb30ae,0x3e750795,0x6d5b1a2a}},	//   nüml, _alge, båt_, _edua
  { {0x9d460036,0x71d60008,0x6d4230af,0x7c3b30b0}},	//   _невд, ּוִד_, pboa, _etur
  { {0x89d80029,0x9e77000a,0x2bb8000b,0x298a004a}},	//   توبر_, _מגלה_, _अवका, сско_
  { {0x600b0064,0x67d40da4,0xa91d06c0,0x48140a32}},	//   küml, допу, ležj, ммис
  { {0x69cb30b1,0x37aa2f04,0xdb0130b2,0x6e2e30b3}},	//   _elge, стин_, _coló, _kubb
  { {0xb8860084,0xbb3b0008,0x8b3b000a,0x994a0040}},	//   fsíð, _העבי, _התבצ, _هلال_
  { {0xd6d704ab,0x56930342,0x7a8b000a,0x5eeb004f}},	//   яты_, хают, _לָדַ, מַכְ
  { {0x4dfb0053,0x9f840064,0x07a61d3b,0x629c30b4}},	//   מפטא, _göç_, _надн, evro
  { {0x48130036,0x64920085,0x0000006a,0x0000006a}},	//   _зміс, džić,   ,
  { {0x877b0008,0x36330029,0xa77b000a,0x0324004a}},	//   _האוי, _كريس, _הרופ, едён
  { {0xdb010061,0xd8430046,0x201a005b,0x0000006a}},	//   _rolü, _íčý_, empi_,
  { {0x600b0064,0x7f950033,0x0000006a,0x0000006a}},	// [6270] büml, маах,   ,
  { {0xa2b5000b,0x6e2e30b5,0xdb0130b6,0x94740015}},	//   _उपप्, _bubb, _polü, _أديا
  { {0x7c3b2a9a,0xb3bc000a,0x51f903a7,0x0000006a}},	//   _stur, _למזכ, _мною_,
  { {0x2167005f,0x201a00f2,0x2bc5005d,0x9a990024}},	//   _этог, ampi_, वस्थ, šākā
  { {0xfbd00086,0x61ed30b7,0x219a000a,0xc19a000a}},	//   گتن_, mnal, _וברא, _ושרי
  { {0x6ee70015,0xd498000a,0x3e750123,0x320930b8}},	//   _فسأل, פכות_, påt_, llay_
  { {0xf8ae002b,0x12e8000a,0xdbd7008c,0x32090061}},	//   یکه_, ּֽוֹ_, vääs, olay_
  { {0x600b0064,0xa2b5000b,0x17f7000b,0xdd940033}},	//   züml, _उपन्, ुत्व_, _пасы
  { {0xdb0130b9,0xf8a9005e,0x7c3b0573,0x6010008c}},	//   _colò, івок_, _utur, läma
  { {0xe7310029,0xa91d00bd,0x2ba4000b,0x956f0046}},	//   خصة_, ležk, _गोपा, ářní
  { {0x3b640015,0x4af9002b,0x8f36000a,0x49390033}},	//   _أُمِ, _بکشد_, ואתו_, _дзею_
  { {0x8afa000a,0x461a0033,0xceb20643,0xdbd70bb5}},	//   _והעי, ўцоў_, דיט_, sääs
  { {0xb8860084,0xdbd70e95,0xdcfb0085,0xdd56000a}},	//   rsíð, pääs, _obuč, וברט_
  { {0x660e002c,0xb886002e,0x225e01c9,0x3dcd0034}},	//   _ďaku, ssíð, átko_, _llew_
  { {0x600b0064,0x3dcd0026,0xe29722d7,0x8e270033}},	//   rüml, _olew_, мар_, кiмi_
  { {0x32090035,0x15f60015,0x6e2e30ba,0x71660015}},	//   glay_, _تستح, _rubb, باسك
  { {0xe45f00dc,0x6604003f,0x34b30015,0x00e4002b}},	// [6280] ször_, _ikik, _لميز, رتری
  { {0x6e2e02d7,0x40950010,0x76410134,0xceea0010}},	//   _pubb, эрст, oply, одзе_
  { {0xa3cb000b,0xd357000a,0x3dcd27fa,0x4357004f}},	//   ऊसर_, _קיטי_, _blew_, _קסטל_
  { {0x5ce60029,0xa91d00bd,0x56b60053,0xd6e8000a}},	//   وكال, režj, ופען_, הַנָ
  { {0x361b00b2,0x307a0015,0x2f56006b,0x61e430bb}},	//   קונד, _بحجة_, _отвс, miil
  { {0xdb21002c,0x61e40011,0x3a260026,0xdf3a0029}},	//   _štát, liil, _siop_, _ذكرت_
  { {0x3dcd003e,0x0a6a0036,0xa934054f,0xa91d006f}},	//   _flew_, ірки_, нейш, bežk
  { {0xa9c30191,0x61e404f9,0xdb010251,0x26040077}},	//   вськ, niil, _polò, iños_
  { {0x60c40049,0xb78a0054,0x3f9830bc,0x60d630bd}},	//   nyim, ољне_, _karu_, nzym
  { {0x8c4330be,0x660430bf,0x9cd7000a,0xdcf7002b}},	//   _рефе, _akik, _חומה_, _غفلت_
  { {0xd6da005e,0x69d70079,0x61ed30c0,0x3f9830c1}},	//   юти_, ëxec, ynal, _maru_
  { {0x5e57004c,0xd9430054,0x7c2830c2,0x3ad30369}},	//   ויטע_, _аеци, _hidr, _جيمز
  { {0x657d002e,0x61e40011,0x3a3e30c3,0x61ed2a33}},	//   rfsh, diil, _http_, vnal
  { {0x62850123,0x600b0012,0x466a012e,0x3384009b}},	//   _ppho, tümm, _дрим_, кусв
  { {0x61e430c4,0x60c40061,0xd7fb000a,0x533404b9}},	//   fiil, eyim, _והגל, тест
  { {0x32090035,0xdb1a016e,0x61e40045,0x600b0012}},	//   ulay_, _potê, giil, rümm
  { {0x9f580084,0x752d0014,0x3f980375,0x61ed30c5}},	// [6290] _skrá_, _igaz, _baru_, rnal
  { {0xed59010b,0xf1bf0092,0xb4cb000b,0x30a4006b}},	//   _može_, _gián_, लनी_, ърсв
  { {0x7982005c,0x8e990029,0x61e40458,0xe3f80029}},	//   _obow, ثناء_, biil, _تعيش_
  { {0x61e404f9,0xed58005e,0xafdb02de,0xd2580033}},	//   ciil, дої_, _stød, _юць_
  { {0x394f00dd,0x60d6005c,0x25d8000a,0x8d740015}},	//   _regs_, czym, וואן_, ضانا
  { {0x60100123,0xa91d00bc,0x394f30c6,0x3f9830c7}},	//   lämn, sežk, _segs_, _garu_
  { {0x7c2830c8,0x78a214a7,0x394f01f9,0x0000006a}},	//   _didr, _arov, _pegs_,
  { {0x601000c0,0x7641002c,0x644d0026,0x752d0573}},	//   nämn, vply, _owai, _ngaz
  { {0x98a50b98,0x8bd9009b,0xed59005a,0x0000006a}},	//   хипе, _емас_, _cože_,
  { {0x61e40011,0x78a2003e,0xf0920008,0x386200dc}},	//   ziil, _drov, נני_, ákra_
  { {0xba7400e6,0x644d0556,0x2bac000b,0x501c000a}},	//   _لانت, _awai, चारा, חוזו
  { {0x5a440010,0x60100123,0x764109f5,0x26040077}},	//   _рэфа, jämn, rply, eñor_
  { {0x61e40209,0xd6ce002b,0x60100123,0x851a000b}},	//   viil, لقی_, dämn, नेंट_
  { {0x69c9022d,0x6e290ecc,0xa91d0085,0x764130c9}},	//   lkee, _lieb, ježi, pply
  { {0x96940010,0x78a201cb,0x56920054,0x386d30ca}},	//   _арыш, _zrov, _бајт, luer_
  { {0x6e291f7d,0xc3230180,0xdd990b7e,0xddce002a}},	//   _nieb, умск, _naň_, źdźc
  { {0x644d0176,0xe0da010f,0xb7790008,0x386d0152}},	// [62a0] _gwai, чва_, ּאֲש, nuer_
  { {0x60d60050,0xe47b0008,0xb3580086,0x61e42091}},	//   rzym, _צריכ, _زیرا_, siil
  { {0xf1bf0023,0x44320092,0x60d6005c,0x3f981efc}},	//   _giáo_, _huy_, szym, _varu_
  { {0x6e290050,0x6d960015,0x3f9801d7,0xdd900040}},	//   _cieb, عشائ, _waru_, شوت_
  { {0xdb080152,0x4c940731,0xa91d14c4,0x7c83004a}},	//   _indé, тилс, beži, гуще
  { {0x44320467,0xdb1a016e,0xed5900bc,0xbca30015}},	//   _muy_, _hoté, _rože_, اموي
  { {0x661d005c,0x44320152,0x78a2288e,0x68ed006f}},	//   ymsk, _luy_, _srov, _ľada
  { {0x69c90234,0x68ed0046,0x6e290028,0x224c0247}},	//   gkee, _žada, _gieb, ádky_
  { {0xfd570008,0xe9370029,0x386d25d1,0x3b860ae6}},	//   _רשמי_, رسيت_, guer_, _плаг
  { {0x8b260010,0x2eaa000a,0xdb1a006f,0x290a003d}},	//   _здзе, ִשָּ, _loté, āba_
  { {0x386d0a2a,0xa5f909da,0x45d50323,0x6671009a}},	//   auer_, дену_, вонс, لگير
  { {0x386d0152,0x78a230cb,0x44322570,0xdb1a0003}},	//   buer_, _trov, _buy_, _noté
  { {0xb4cb005d,0xc4580080,0xb9bb000a,0xf993000a}},	//   लने_, ниях_, _מצאת, _תרנ_
  { {0x44320023,0xb8e6005d,0x26c50089,0x291a005c}},	//   _duy_, ोई_, bylo_, ązać_
  { {0xa5bb00dc,0xd6cf1d23,0x86c30021,0x3f87007c}},	//   tmód, _ст_, _ميون, õnum_
  { {0x9b170008,0xbbbe000b,0xdb1a0003,0x6b9a2647}},	//   תחלה_, ्सुक, _coté, _latg
  { {0x765a30cc,0x44321650,0xdb1a0003,0xa91d0085}},	// [62b0] lsty, _guy_, _doté, teži
  { {0x7c2f038d,0x6e29194b,0xa5bb0030,0x60100123}},	//   _écri, _sieb, smód, sämn
  { {0x6e290024,0x92580010,0xdfd80063,0x539a000a}},	//   _pieb, _паэт_, хът_, _חיתו
  { {0xa2b60008,0x28d9005d,0xc05b005e,0x765a26ea}},	//   _ספרד_, _बेझि, _ніг_, isty
  { {0xdd8e0086,0xc156000a,0xeb990988,0x3156004f}},	//   زوو_, _בשרו_, дил_, _בירן_
  { {0xf1bf0092,0x6b620001,0x2ba4000b,0xf3ff016e}},	//   _hoá_, акша, _गोदा, irão_
  { {0x9f050086,0x6b9a0026,0xc334000a,0x7d0900aa}},	//   _شورو, _datg, נוק_, _wyes
  { {0xe6280092,0xcd340029,0x386d30cd,0x765a30ce}},	//   _chỗ_, _مركب, tuer_, dsty
  { {0x87f90010,0x69c90384,0x26c50034,0x2d8f0030}},	//   дэнт_, rkee, wylo_, mege_
  { {0xf3ff03af,0x69c92bb3,0x4cc8000a,0xf8ae002b}},	//   drão_, skee, _אֶעֱ, تکم_
  { {0x49750010,0x44320092,0xf3ff001c,0x9665006b}},	//   _алес, _suy_, erão_, ъкне
  { {0x89370029,0x95830033,0x443230cf,0xf3ff059d}},	//   _أعضا, алюе, _puy_, frão_
  { {0x44320092,0x386d30d0,0xdb1c00dc,0x88c40087}},	//   _quy_, quer_, özök, _متول
  { {0xd70530d1,0x765a30d2,0x59a9000b,0xb8f50065}},	//   _изли, bsty, काकर, सन_
  { {0x7df5002a,0x63be001a,0xf3ff016e,0x91e60515}},	//   ząsa, _vopn, arão_, вове
  { {0x44320023,0x201800da,0x016301d2,0x0000006a}},	//   _tuy_, _shri_, иксо,
  { {0xe45a008f,0xf1bf0023,0xc9520008,0xc0060036}},	// [62c0] _ўжо_, _giám_, ימן_, впак
  { {0xd00f0029,0xbea630d3,0x9f5f001a,0x69de0030}},	//   قلق_, казк, ærða_, épez
  { {0x66160089,0xdb1a0046,0xbeaa006e,0x324615d2}},	//   ůzku, _toté, بهان_, _шенг
  { {0xb6ba0008,0x1ea90015,0x6b4e002a,0x82f7000a}},	//   וצעי, عالي_, _mógł, _יציב_
  { {0xdf740086,0x6c330015,0x20180034,0x24ed000a}},	//   _مگاب, لفنا, _thri_, ּקוּ
  { {0x64460007,0x2fb8000a,0xac450015,0x765a30d4}},	//   ipki, _אֶֽע, ائنه, ysty
  { {0xa50f000b,0xa91d003d,0x8f9b000a,0x7bca0079}},	//   _सर्च_, iežu, _קילי, rkfu
  { {0xa2b5005d,0xf1bf0092,0x1e9700f3,0x98740054}},	//   _उपस्, _xoá_, _בכלל_, глиц
  { {0x4c8500e6,0x3e7c30d5,0x0c261cf3,0x765a002a}},	//   _مؤلف, lít_, _аман, wsty
  { {0x57b430d6,0x8c260067,0x7aa60015,0x765a0a3a}},	//   убот, _شفاه, _لإصل, tsty
  { {0x601000f2,0x3e7c1754,0x99860015,0x8bd7000a}},	//   jämm, nít_, _للاو, _שובו_
  { {0xadf4005d,0x601008b1,0xdb080061,0x765a30d7}},	//   ेकिन_, dämm, _modü, rsty
  { {0x04c90029,0xd7960015,0x23e7005e,0x66cb0030}},	//   روسي_, _للشخ, вівв, tökö
  { {0xf3ff016e,0xed5900bc,0xf4340015,0x765a30d8}},	//   rrão_, _moža_, شِّح, psty
  { {0x3e7c0089,0xd2500029,0xf2c40229,0x59b6000b}},	//   jít_, ْنِ_, астн, _आचार
  { {0xa3cf021e,0x3e7c0307,0x64402b8e,0xba9b004f}},	//   _शतक_, dít_, ímic, וסלי
  { {0xdb081ed5,0xf1940248,0x248900bc,0x2d8f30d9}},	// [62d0] _kodó, шить, _upam_, vege_
  { {0xb4c1005d,0xceeb0087,0xff530015,0x753d0030}},	//   ूनी_, وران_, ؤخذ_, lcsz
  { {0xc3320008,0x69dc0007,0x3e7c00dc,0xe7f5000b}},	//   _לוי_, _įren, gít_, ीकता_
  { {0xdb08002a,0xb637000a,0x645d30da,0xe8190065}},	//   _lodó, דראס_, ossi, _नीना_
  { {0x4d640036,0x11da0008,0x50f403e7,0x68ed006f}},	//   рків, _נחשב, _взят, _ľado
  { {0xf0920008,0xe452000a,0x3e7c117d,0xd259003d}},	//   _הנך_, זֶה_, bít_, ņņu_
  { {0xbed50001,0x2d8f02de,0x9aa5012c,0x09e530db}},	//   _совј, pege_, امبو, локн
  { {0xac74002b,0x8d77002b,0x645d01d0,0x0000006a}},	//   _چالش, _جاسا, kssi,
  { {0x6ce70036,0xacf50054,0x2ba40157,0x8755006b}},	//   _ріве, _спаљ, _गोवा, лънц
  { {0x6d592eed,0xe45f008c,0x38ca002b,0x645d30dc}},	//   lawa, työn_, عايی_, dssi
  { {0xdb01001c,0x7f550077,0xc4c9000a,0xa91d00bc}},	//   _colô, _mezq, _צג_, vežu
  { {0xb17b0123,0x6d5903cf,0xcb12000a,0xd46a012e}},	//   _smån, nawa, _פלא_, ниме_
  { {0x98790053,0x4dda000a,0x45d30033,0x7bc130dd}},	//   _נאַט, תחרו, соўс, _kolu
  { {0xadc30092,0x64460007,0x601030de,0x96950180}},	//   _khẳn, rpki, tämm, _бриш
  { {0x9b09000a,0x29c30077,0x6d5930df,0x387f30e0}},	//   גִּ֥, _uñas_, kawa, ltur_
  { {0xdb0100c0,0x96b80015,0xe4d60015,0xa2b5000b}},	//   _inlä, _جاهز_, _مقعد, _उपर्
  { {0x6d590050,0x2601005d,0x6010008c,0x66061b8e}},	// [62e0] dawa, रवरी_, sämm, mokk
  { {0xa4b70008,0x3e7c0089,0xbf650015,0x387f001a}},	//   _עליה_, tít_, لدمو, itur_
  { {0x25b7002b,0x9e66006b,0x6397015b,0xed46005e}},	//   _شهید_, увед, _גדיא_, гнеп
  { {0x2bbe005d,0xbbbe000b,0xb2bb000a,0x6d59015a}},	//   ्स्थ, ्स्क, _נמכר, gawa
  { {0xf1b30008,0x3e7c00dc,0xdd8f0029,0x455b000a}},	//   _הסר_, sít_, ثون_, תכנס
  { {0x6606022d,0xda660029,0xafe630e1,0x6d59002a}},	//   hokk, هابي, _согл, aawa
  { {0x387f0084,0xadc30023,0xcb75009c,0x65640045}},	//   etur_, _chẳn, ручњ, _odih
  { {0x387f002e,0xaa870086,0xf2d3000a,0x660630e2}},	//   ftur_, انيم_, מעו_, jokk
  { {0xd90d0086,0xdb0830e3,0xbb462b45,0x6826005e}},	//   ویم_, _indí, _безк, льоз
  { {0xa09700b2,0x807b0053,0x907b004c,0xdb011ecf}},	//   נדיק_, עניצ, עטיי, _polô
  { {0xca750010,0xe5b504ab,0x35f5005e,0xe7f5000b}},	//   _вучы, айны, ипор, ीक़ा_
  { {0xd6d7087a,0xceb3000a,0xeef7000a,0x660630e4}},	//   уть_, ציר_, רמטר_, gokk
  { {0x7bc10064,0xb4c1005d,0x8ca7005d,0x65640034}},	//   _yolu, ूने_, चियो, _ddih
  { {0x6d59003f,0x645d0044,0xa8ab000a,0xa91d006f}},	//   zawa, rssi, _ט֑וֹ, režt
  { {0xa2950010,0x236c00dc,0xcb37000f,0x6666006b}},	//   шаві, ódja_, ראלי_, _сълз
  { {0xdb1a122a,0x29d8002d,0x660601d7,0x82340015}},	//   _notí, _déag_, cokk, صرفا
  { {0x9f6b03e7,0x6e350085,0x9f552d02,0xdb010123}},	// [62f0] ерез_, _suzb, ивач, _inlå
  { {0xdefb1e88,0x4f670029,0x6d40002e,0x2ba4000b}},	//   ные_, طائف, _afma, _गोला
  { {0x93150086,0x7bc130e5,0x3ea730e6,0xde950004}},	//   _خودش, _rolu, ínt_, раењ
  { {0x387f002e,0x5f240788,0x7bc10d28,0xf532004f}},	//   ytur_, сфуз, _solu, ַ֥ד_
  { {0x6aa8002d,0x6d5930e7,0x415a000a,0x7bc130e8}},	//   _ardf, rawa, _בדרג, _polu
  { {0x7aa50029,0x6d590509,0x5458000a,0xe45f008c}},	//   لإعل, sawa, נסון_, isö_
  { {0xda640086,0xdd950088,0x6d590798,0x66060030}},	//   مايي, _кавы, pawa, yokk
  { {0x7bd80020,0xc9a90404,0x387f30e9,0xb8b50015}},	//   ahvu, твие_, ttur_, لإخت
  { {0xa922010f,0xbdf80086,0xd8760015,0x6606008c}},	//   одъл, _صرفا_, لميت_, vokk
  { {0x7782005f,0xadc30092,0xa6850010,0xd7ee0015}},	//   ольз, _thẳn, алод, ِكٌ_
  { {0x387f0084,0x660615dc,0x644430ea,0x95c60015}},	//   stur_, tokk, _stii, ليده
  { {0x6606022d,0x4ac40029,0x29d8002d,0x7d16005c}},	//   uokk, _ديمق, _céad_, żyse
  { {0x89340002,0x394d30eb,0x660630ec,0xfd96004f}},	//   _اعما, mbes_, rokk, בדרך_
  { {0xb6a50191,0x46a5000d,0xf745000d,0x660630ed}},	//   _викл, _вакв, _теко, sokk
  { {0x764302d2,0x3f930227,0xfbd2000a,0x877a0643}},	//   _utny, dexu_, חתם_, _יאסי
  { {0x386d0152,0xc0460029,0xc5f9003d,0x34aa02d9}},	//   orer_, لخطو, urēt_, _авио_
  { {0xc0450015,0x7f5a0054,0xc5f9003d,0x3fe630ee}},	// [6300] مخلو, вјет_, arēs_, ажав
  { {0x82360074,0xa2e60a86,0x6e2200da,0x70530015}},	//   _پردا, _воод, wmob, تنكا
  { {0xed5a1292,0x386d00b8,0xdb1a0089,0x8ff9005e}},	//   вое_, hrer_, _potí, ухту_
  { {0x25a0003e,0x386d0595,0x0e690015,0x7bc50012}},	//   _jail_, krer_, اصلي_, öhun
  { {0x25a030ef,0x386d02de,0x6e2230f0,0xadc300a1}},	//   _mail_, jrer_, rmob, _chằn
  { {0x386d0293,0xf236000a,0x6fd50033,0x7fd5008b}},	//   drer_, ֑רֶץ_, _лісц, _лісі
  { {0x1606005d,0xf1ca005d,0x8cb2000b,0x386d30f1}},	//   रवार_, _रवान, _आपको, erer_
  { {0xdea40086,0x7e9b000a,0x386d30f2,0x298a011a}},	//   _پیچی, _בסלו, frer_, тско_
  { {0xdb1a03af,0xb9c30029,0x98b7006b,0x29d80125}},	//   _botã, تقيي, илът_, _réad_
  { {0xf7b80001,0x1ae60a0b,0x9cb30015,0xc7c6006b}},	//   угој_, _козм, _بمكت, рсии
  { {0x7bdb000a,0x394d24c0,0x75e70015,0x6440001a}},	//   _שקבו, bbes_, لأحك, ímin
  { {0x386d1352,0x96330033,0xf6e30033,0x25d9004a}},	//   brer_, ўняц, іцэн, уммы_
  { {0x9a250015,0x386d0003,0x25a00034,0x19bb000a}},	//   _اعلن, crer_, _dail_, _שמדב
  { {0x2bbe000b,0xdc8b000a,0x1514005e,0xd4070342}},	//   ्सटा, כְלָ, ідря, рями
  { {0xb8050015,0x25a030f3,0x82a4012e,0x02a400ce}},	//   _ابنه, _fail_, оште, ортм
  { {0xb6bb000a,0xcad7000a,0x3ead30f4,0x25a00d3d}},	//   _יצוי, בולת_, _čet_, _gail_
  { {0x7a350007,0xe4530015,0x660d30f5,0x629a01d0}},	// [6310] _ište, _بضع_, _ikak, ætor
  { {0x539930f6,0x33750286,0x6ab6000b,0xbfd8005e}},	//   _своя_, _угор, _अपूर, адує_
  { {0x33fc000a,0x394d1db1,0x2ca60045,0xa19507bd}},	//   _בהזנ, ybes_, evod_, _ланч
  { {0xf2d200b2,0x237f016f,0x386d2b0e,0xa19400e2}},	//   _זעט_, đuju_, yrer_, _даюч
  { {0x9b450029,0x61ed30f7,0x7df5002a,0xcb69096d}},	//   منشو, mial, ląsk, гале_
  { {0x82340074,0xa036000a,0x14d8000a,0x386d30f8}},	//   _دریا, _לאשה_, סוגל_, vrer_
  { {0xaa560001,0xf21c005d,0x7a350b6c,0xdcfb0085}},	//   бију_, _भीड़_, _ošte, _obuć
  { {0x82f80008,0x386d30f9,0x22f8000a,0xadc30016}},	//   יצוב_, trer_, יזון_, _thằn
  { {0x25a020ea,0x8b67002b,0x394d0252,0x386d30fa}},	//   _rail_, _ناام, rbes_, urer_
  { {0x6010022d,0x3a870080,0x7b770018,0x25a00e46}},	//   tämi, _выдв, _خطرا, _sail_
  { {0x86980195,0xf529000a,0xeab00015,0x61ed30fb}},	//   атят_, _נץ_, _يعم_, kial
  { {0xed5930fc,0xb9c40015,0x59c40058,0x386d03a0}},	//   _jež_, _وقلي, _ويلك, prer_
  { {0xb6070084,0xb925002b,0xdbea0030,0xdb080125}},	//   _sláð, _افشي, lőál, _indá
  { {0x660d007c,0xed5900bf,0x434318fc,0xfdc40065}},	//   _ekak, _lež_, зерв, _वक्फ
  { {0xa3e9005d,0x25a00708,0x4df7000b,0x216a29f7}},	//   _मगर_, _tail_, ंचाई_, ливи_
  { {0x463a00b2,0xed590107,0xa644002b,0x261930fd}},	//   _געקע, _než_, _بخون, léon_
  { {0xdfcf0086,0xe3b20002,0x67460030,0xaf3600c3}},	// [6320] کيل_, _فرد_, _érjé, مرات
  { {0x94bb000a,0xa819000a,0x61ed007c,0xcf260015}},	//   _עמית, אֵ֣י, aial, مرضي
  { {0x139b000a,0x5337000a,0x61ed30fe,0xb4250058}},	//   _גביע, _לנין_, bial, _بعيو
  { {0x629e010b,0x9e650015,0xcdf50033,0xed5a00c3}},	//   _ispo, زامن, оччы, اشات_
  { {0x447b004c,0xed5900bc,0x0000006a,0x0000006a}},	//   ָנצע, _dež_,   ,
  { {0x8f750010,0xf236000a,0x0fda0015,0xfbcf0015}},	//   _мусі, ֖רֶץ_, _إبحث_, فتى_
  { {0xea8a0086,0x539b000a,0xdb1a0077,0x6da608a6}},	//   اختن_, ריצו, _botá, _лива
  { {0xf9920015,0x6df60015,0x600b007c,0xdef7000a}},	//   سبع_, _اكرا, lümp, _המלט_
  { {0x26cc0034,0xc7d8005e,0xd9430054,0xdb1a30ff}},	//   wydo_, имих_, чењи, _dotá
  { {0x660d020a,0x629e016f,0x61ed3100,0xa09b000a}},	//   _skak, _ospo, zial, נייט
  { {0x59860010,0xf76f0015,0x09e6004a,0x4fbb004c}},	//   _глеб, ءاً_, _ложн, אזיצ
  { {0x89a50029,0xca3700a3,0xf8aa0015,0x69db3101}},	//   _وإنم, _הנאה_, _مدته_, chue
  { {0x629e01c9,0xdb230030,0x7a3500bc,0xdce20085}},	//   _aspo, örök, _všte, ogođ
  { {0x23e40010,0x07a30256,0x61ed002a,0x64560034}},	//   пісв, _начн, wial, _dwyi
  { {0xd7f80011,0x82370029,0x98a40064,0xf2e9002b}},	//   mnă_, إرسا, mamı_, شکده_
  { {0x52150036,0xd0d50080,0x7a350085,0x98a40061}},	//   ідат, ообъ, _ušte, lamı_
  { {0x94770002,0xb0290015,0x35f8002b,0xa2b5000b}},	// [6330] _ادعا, لكرم_, _درود_, _उपक्
  { {0xdb1f00dc,0xdb180046,0x7df50091,0x61ed3102}},	//   űvés, ejví, mąsi, sial
  { {0xeeab0010,0x6e990120,0x60cd3103,0x61ed3104}},	//   ытак_, рвер_, syam, pial
  { {0x067b004c,0xdb01016e,0x8d770015,0xd7f80045}},	//   רנאל, _falê, صاصا, hnă_
  { {0xe0e40010,0x3079004c,0x1d090054,0x61fd0079}},	//   _еўро, _דאָנ, јели_, _ijsl
  { {0xaa49000d,0xbae50015,0xcac90054,0xb17b02dc}},	//   апка_, يكشي, игле_, _småh
  { {0xdab90010,0x98a40061,0xf1bf0030,0x44332432}},	//   рылі_, damı_, _fiát_, _mix_
  { {0x3eae0134,0x3959001a,0x68f60091,0x49c90e91}},	//   æfte_, úss_, _žyda, рлин_
  { {0xc7950139,0xf7710031,0x9be7005e,0x6d5b0034}},	//   орны, واد_, _ліжк, _ieua
  { {0xf1bf002d,0x16650142,0xdc88000a,0xd7f80045}},	//   _fhág_, овом, _לְעָ, gnă_
  { {0x6d5b00e8,0xa2b5000b,0xf626006b,0x7c3b3105}},	//   _keua, _उपग्, ждно, _huur
  { {0xd7f80011,0x8c3d0064,0x75d30015,0xda1d000b}},	//   ană_, _arşi, ِيَا, _पठित_
  { {0x7c3b0458,0x98f40010,0x5cac0008,0xda08002b}},	//   _juur, _няшч, ְׁלַ, _اينه_
  { {0xa3e4005d,0xd8b20086,0xb8ed005d,0x98b2002a}},	//   पों_, _آموخ, रह_, _żyć_
  { {0x44330152,0x7c3b05ff,0xe61a01f3,0x78a93106}},	//   _dix_, _luur, _кдк_, lvev
  { {0x6d5b06ad,0x395f3107,0x21f6005e,0x44330144}},	//   _neua, naus_, іївс, _eix_
  { {0x6ab6014e,0x629e005c,0xf99200f3,0xdfd20031}},	// [6340] _अप्र, _wspo, ורן_, وير_
  { {0x395f3108,0x1df4000b,0x57f9000a,0xdb01059d}},	//   haus_, ेक्ष_, ׁלּו, _valê
  { {0x35af005d,0x629e3109,0xab5c003d,0x395f180a}},	//   _जोड़, _uspo, _soļo, kaus_
  { {0xbc4a0001,0x395f1a91,0x7c3b310a,0x2caa0004}},	//   ачке_, jaus_, _buur, икеп_
  { {0x629c0026,0x2cad310b,0x902a0015,0x395f0b9f}},	//   lwro, _cred_, _نأسف_, daus_
  { {0xe0fb0008,0x6fb60029,0x7c3b0159,0xe819000b}},	//   _כלכל, _بمسا, _duur, _नीला_
  { {0x291d002a,0x98a40061,0x2cad10e5,0xdcf60061}},	//   _azwa_, vamı_, _ered_, ğcıl
  { {0x395f0007,0x8c4a005e,0xc8660e3f,0x2cad310c}},	//   gaus_, _впав_, отои, _fred_
  { {0x61410014,0x2cad02e4,0x98a40061,0xc7ba0033}},	//   _háló, _gred_, tamı_, аён_
  { {0xd7f80011,0xe0b7000a,0x76740238,0x80ad000b}},	//   ună_, קליט_, плоф, ीमते
  { {0x212700a7,0xd7f80011,0x501b0008,0x7c3b0079}},	//   ̀nh_, rnă_, שויו, _zuur
  { {0xd6d70010,0x44330493,0xb90a07c1,0x88c60015}},	//   юты_, _six_, _кнез_, _وتشل
  { {0x7a35310d,0x7bc8310e,0xa3f8000b,0xe3b3006e}},	//   _išta, _kodu, ूकंप_, ورس_
  { {0x44330003,0xb7d8002b,0xf7480015,0x7df50091}},	//   _qix_, _دوتا_, _الغي_, rąsi
  { {0x9f84002e,0x38660293,0xd1eb0004,0x81c7004a}},	//   _röð_, _hvor_, аќал_, ощае
  { {0xd6db000a,0x41e70033,0x7a01003d,0x0000006a}},	//   _כחול, ціга, pēte,
  { {0x40590115,0xc05b005e,0x1fa70248,0x7bda310f}},	// [6350] صلاح_, ріб_, жрег, _oltu
  { {0x644f08e0,0x7f5c08e0,0x395f0091,0x6e3c17fc}},	//   mpci, _cerq, zaus_, _burb
  { {0x7c3b09e7,0x8db50036,0xdfd80063,0xe39a000a}},	//   _suur, зслі, цът_, _השתכ
  { {0x40350063,0x4c350010,0x2cad1658,0xee38017f}},	//   _немс, пэкт, _pred_, іні_
  { {0x2fc70023,0x395f0a6d,0x91ba000a,0x5f770015}},	//   ưng_, vaus_, _המרי, _واسر
  { {0x7bc804f9,0xbb850029,0x2056000a,0x7c3b0161}},	//   _codu, سلبي, _מישל_, _vuur
  { {0xfbd00086,0xaa560001,0x5f440086,0x6e3c1492}},	//   ختن_, пију_, _آنفل, _gurb
  { {0x02fc000a,0xceb2000a,0x5db70015,0x78a90030}},	//   ילומ, _איל_, _بإسر, tvev
  { {0x395f177b,0x2cad0085,0x7bc80034,0xdb013110}},	//   raus_, _ured_, _fodu, _malé
  { {0x7afc00bc,0x38662c98,0x657d0012,0x78a93111}},	//   _žrte, _dvor_, egsh, rvev
  { {0xe5a62d90,0x6be40015,0x36690054,0x395f0601}},	//   пини, _تكلم, љамо_, paus_
  { {0xdb010089,0xfb1a000a,0xf990002b,0xd6ce0015}},	//   _nalé, _הועמ, _لبه_, اقَ_
  { {0xb9c40029,0x993a0008,0x63a500b8,0x493a000a}},	//   _تقني, _התנה, _bahn, _הגנו
  { {0xc8790064,0x33b50033,0xdb03006f,0xdb010144}},	//   muş_, мёст, edné, _palè
  { {0x8c1a0008,0xc8791071,0x67ba000a,0xe1ff001a}},	//   מושי, luş_, _למסק, _bjó_
  { {0x395d003e,0x2b8f0064,0xcb120008,0xdb0118b3}},	//   _jews_, lıcı_, גלל_, _valè
  { {0x7f5c08e0,0xdcfc0024,0xd6250031,0xc57b000a}},	// [6360] _perq, čzīm, _تعوي, _הרפת
  { {0x2b8f01e2,0x00e7002b,0x6e3c3112,0xe0d705ab}},	//   nıcı_, ستقی, _purb, чву_
  { {0xe3570135,0x433b000a,0x539b000a,0xdd8f0033}},	//   _משיח_, _לעיב, _פיטו, нш_
  { {0xb2bb0008,0xf41f00f2,0x568c0053,0xd7f10092}},	//   _המטר, ntän_, שטאַ, hĩ_
  { {0xc173013a,0xa1160086,0x7bc83113,0x2c08002b}},	//   _אחר_, _روست, _podu, يعتی_
  { {0x5c970033,0x60100123,0x6e3c0d36,0x251b004f}},	//   якія_, räms, _turb, זונא
  { {0x29d8002f,0x539b000a,0x6a13009a,0x7bc83114}},	//   _déan_, מיסו, کبور, _vodu
  { {0xada3008f,0x7bc800b8,0x4efb000a,0x49ba0021}},	//   _пасл, _wodu, _ההלו, صاعد_
  { {0xeb360086,0xcb6a3115,0x29020061,0x9f4a03a0}},	//   _فراخ, _газе_, çka_, _ambé_
  { {0xf1bf0023,0xb3c1000b,0x9cdb000a,0x5837004a}},	//   _khác_, रॉफ़्, _הקמפ, язья_
  { {0xf119000b,0xadf3000b,0x916d0016,0x98b80061}},	//   _दर्द_, _आगमन_, hối_, ğrı_
  { {0xb8660029,0x7abb0008,0x63a50064,0xaa3b000a}},	//   _فاتو, _לצבו, _sahn, _התאח
  { {0xba090015,0x7df50091,0x59c30058,0x891a009a}},	//   _بتلك_, mąst, _سيوك, _اغاز_
  { {0x889b0008,0x9cd70008,0x7a010024,0xd7940063}},	//   _לבדי, לוכה_, mēta, _цикъ
  { {0x7a010024,0x764a003c,0xf773000a,0xdb013116}},	//   lēta, _utfy, _טקס_, _palé
  { {0xc2c40029,0x63a50012,0x867b000a,0x067b05bd}},	//   ريقي, _wahn, _הרהו, _הנהל
  { {0xd9040074,0x7a010024,0x63a500d9,0x442a00da}},	// [6370] ای_, nēta, _tahn, bmb_
  { {0xe9e2005c,0x7ff70015,0x660f3117,0x301405c8}},	//   leźć_, أسرا, lock, едур
  { {0x3a3e01c2,0xf1bf0016,0x7f450012,0x8e990015}},	//   _nutp_, _chác_, rchq, تناء_
  { {0x2b8f0064,0xf1bf0092,0xfe7000e5,0x78a200b3}},	//   zıcı_, _giáp_, ادل_, _osov
  { {0x0db80029,0x2b8f0064,0x656d02f2,0xdc8b02ed}},	//   ثالث_, yıcı_, _mdah, ссел_
  { {0x00ba000a,0x3f9a0045,0x7a01003d,0xdbf10046}},	//   _ומשמ, cepu_, dēta, příl
  { {0xfaa20063,0xf41f008c,0x660f1e08,0xa5bb0125}},	//   ващо, ytän_, kock, amói
  { {0xfaf00086,0xd2b80008,0x09f90015,0x60100b24}},	//   دثه_, ללות_, تفعة_, lämp
  { {0xc8c90086,0x2b8f0064,0x3775055f,0x090502ed}},	//   زودن_, tıcı_, мынс, ьпин
  { {0xe645070c,0x2fb6000a,0xc8791d56,0x60c2008c}},	//   меоп, ֵּים_, ruş_, äomi
  { {0x9f840005,0x38ca0086,0x2b8f0061,0x66e50c1d}},	//   _töö_, مایی_, rıcı_, фона
  { {0x7a350091,0x9e990138,0x0000006a,0x0000006a}},	//   _išto, сцiр,   ,
  { {0x45d3008f,0x7a010024,0x6010079c,0x6d440091}},	//   тоўс, cēta, kämp, žiag
  { {0x644d002f,0x69cb0111,0xe6c50029,0xed95004c}},	//   _dtai, _hoge, _يتغي, אַרפֿט_
  { {0x69cb0171,0xfe0d000b,0x60100dca,0x614600f4}},	//   _koge, िकास_, dämp, деба
  { {0xa5bb002a,0xe45f008c,0x69cb3118,0x660f00da}},	//   dmów, työt_, _joge, cock
  { {0x799b0111,0x69cb3119,0x3eb10012,0x200700bc}},	// [6380] ieuw, _moge, _arzt_, čnin_
  { {0x24970074,0xe29a0001,0xf1bf0016,0x69cb311a}},	//   _کنید_, _дао_, _phác_, _loge
  { {0x7a010024,0x0d860bb9,0x69cb0079,0xd5af002b}},	//   zēta, длен, _ooge, _صفی_
  { {0xcf8900b2,0x69cb00fb,0xd1fa004f,0x0000006a}},	//   יט_, _noge, _וּ֝כ,
  { {0x958800df,0xbc9a00e6,0x69b1000b,0xdca3011a}},	//   _grąž, تخاذ_, _अफ़ी, каци
  { {0xa91d0007,0xf1bf0092,0xdb0811dd,0x7a01003d}},	//   igžd, _thác_, _indú, vēta
  { {0xb17b02de,0x1600000b,0x69cb311b,0xda7a02a3}},	//   _flåd, ोकार_, _boge, іяк_
  { {0xdde90086,0x7a010024,0x1d0a096d,0x69cb311c}},	//   _فرقه_, tēta, _деби_, _coge
  { {0xcb6a029f,0x7189004f,0xfcaa009a,0x0000006a}},	//   _маае_, פְקַ, _بازو_,
  { {0xb8e6005d,0xd90d0086,0x6d44002c,0x7a010024}},	//   _उप_, حیه_, žiad, rēta
  { {0x644d311d,0x7a010024,0xd4910092,0xf8a7000b}},	//   _stai, sēta, ằm_, कटॉप
  { {0xd6d7004a,0xafdb00cb,0x7a01003d,0x0000006a}},	//   фть_, _utøv, pēta,
  { {0x443f0023,0x3a2600c0,0xd94300d7,0x660f0380}},	//   êu_, _ihop_, _речи, rock
  { {0xacd90053,0x69cb0ec2,0xd25b01b0,0x660f311e}},	//   פֿרי, _zoge, жца_, sock
  { {0xa1950036,0x26070180,0xd1bb0015,0x6010008c}},	//   навч, _очиг, يارا_, vämp
  { {0xdb1a0125,0x8aab004f,0x656d0160,0x0000006a}},	//   _botú, חֹמֶ, _udah,
  { {0x644d003f,0x60100123,0x7bd8311f,0xb17b02d6}},	// [6390] _utai, tämp, kkvu, _smås
  { {0xab63005c,0x25a90409,0x7a110046,0x2d843120}},	//   ążka, _haal_, mětř, _acme_
  { {0xdef10029,0xd356000a,0xf3ff016e,0x4ea40054}},	//   دًا_, _איתי_, lsão_, крца
  { {0xc05b0036,0xbd4500c3,0x41d30065,0x0000006a}},	//   _міг_, رنتي, _सविस,
  { {0xf3ff001c,0x644b1d2c,0xa91d0091,0x69cb3121}},	//   nsão_, _égid, bežy, _roge
  { {0x1eea0086,0xd01b0004,0x7afc0085,0x5f740015}},	//   _کوفی_, _ффм_, _žrta, _لافر
  { {0xb6060089,0x8d770067,0x4a720058,0xdd5900ce}},	//   _hláš, _يارا, هُور, _навч_
  { {0xb6060107,0xaa280015,0x5338000a,0xa8550004}},	//   _kláš, وثيق_, ונון_, нтој
  { {0x799b0026,0xfd130015,0xe8f90361,0x69cb22c3}},	//   reuw, _شجر_, яли_, _voge
  { {0x612a00dc,0x4bdb0086,0xbb550015,0xeb900002}},	//   lölé, _ببرد_, _أناب, _نظم_
  { {0x69cb0041,0x998d002a,0x7ac43122,0x25a93123}},	//   _toge, tleń_, _исце, _baal_
  { {0xa9540191,0x99d70015,0x7a01003d,0xa50a2aa8}},	//   _акці, _تتطا, mēto, зема_
  { {0x7a010024,0xdce90089,0xab5c003d,0x25a900aa}},	//   lēto, _odeč, _soļi, _daal_
  { {0x07a20080,0x1876000a,0x47d50015,0xfc27012c}},	//   _башн, _נעצר_, _سيعر, طح_
  { {0xb7da013a,0x7a01003d,0x41b606b3,0x63e70015}},	//   _מקסי, nēto, нсат, رِّف_
  { {0x09b5004c,0x21a30d3c,0x0000006a,0x0000006a}},	//   עפּט_, лисм,   ,
  { {0x6026000d,0xc952000a,0x11d70015,0x34b30040}},	// [63a0] едаа, טמן_, روكة_, _مميز
  { {0x84570053,0x7d16002a,0x25a90079,0x65663124}},	//   _רביס_, żysk, _zaal_, lakh
  { {0x24460023,0xb17b0f47,0xdb013125,0xee3a1eaf}},	//   _hôm_, _slåe, _balí, чне_
  { {0x2d9d00dd,0xafdb0af5,0x443a3126,0x645b0045}},	//   gewe_, _støt, _hip_, ţuie
  { {0x61f60064,0xf1bf0092,0xdb010046,0xdb0a0123}},	//   miyl, _khán_, _dalí, njfö
  { {0xab940036,0x3a260ab0,0x61f60061,0xb4fb000a}},	//   тикі, _shop_, liyl, הפני
  { {0x2d962971,0xed5a23e4,0x0ba90015,0xbb470040}},	//   _прас, _нов_, بانى_, رلين_
  { {0x61f60064,0x7e7e00c0,0x443a3127,0x69c0000b}},	//   niyl, mupp, _lip_, वाधी
  { {0x7e7e3128,0x60d600f2,0xf98f0015,0xa96703ae}},	//   lupp, nyym, صبي_, хиња_
  { {0x7a110046,0x61f60061,0xa5bb3129,0xdb1f0030}},	//   větř, hiyl, ológ, űvás
  { {0x752400d9,0x7e7e00c0,0xd6d7106d,0x89d6005e}},	//   _aziz, nupp, етя_, _підш
  { {0x7c3a018c,0x443a0007,0xaadb00a3,0x9adb000a}},	//   _hitr, _aip_, _מחבר, _מחבט
  { {0x66e600dc,0x99e90002,0x7e7e0012,0x5dcb000a}},	//   _béké, _تعلق_, hupp, לֶךְ
  { {0xf3ff03af,0xf8b300a3,0xf1bf312a,0xdb030046}},	//   rsão_, _תשס_, _chán_, zdní
  { {0xf3ff03af,0xa2940036,0xdce900bd,0x25a9049c}},	//   ssão_, ларі, _rdeč, _taal_
  { {0xda10014e,0x20070a00,0x224c0089,0x7c3a312b}},	//   ावित_, čnim_, ídka_, _litr
  { {0x7a01003d,0x857408f0,0x2098055f,0x64401279}},	// [63b0] zēto, _слых, нкты_, ímit
  { {0x251c00b2,0xb4fc000a,0x389b000a,0xdb010077}},	//   _צוזא, _מפחי, הימנ, _salí
  { {0x61f60064,0x661d1212,0xf5ab000a,0x7f840015}},	//   biyl, olsk, ּבְּ, المن
  { {0x61e4312c,0x443a312d,0xd657000a,0xecf90151}},	//   chil, _zip_, גיאת_, мееш_
  { {0x2d9d00dd,0xdb030089,0x7e7e008c,0x8c48005e}},	//   rewe_, rdní, aupp, епів_
  { {0x7c3a26c9,0xeb96312e,0x8c540015,0x443a0144}},	//   _citr, виш_, ائنا, _xip_
  { {0x2fc7002e,0x09e50165,0x7c3a312f,0xdb01005a}},	//   öngu_, кокн, _ditr, _talí
  { {0x7a010024,0x6d560061,0x9e34112c,0xaa0b000b}},	//   rēto, ıyac, _бесч, ावेज़_
  { {0x656600dc,0x6d44002c,0x7c3a013c,0x9c47005e}},	//   vakh, žiac, _fitr, _їхал
  { {0xf0920008,0xa5bb002d,0x7a080046,0x7d0900aa}},	//   סני_, hlód, věte, _ixes
  { {0x6e3b003f,0x65660375,0xb9950015,0x9be4005e}},	//   _kiub, takh, _للاب, _сітк
  { {0x75e6002a,0x9dd5000a,0x7c3a04ff,0x7a080046}},	//   _mózg, דוֹק_, _zitr, těte
  { {0xf1bf0092,0x6566064e,0x3e410007,0x29d1001a}},	//   _phán_, rakh, _dėti_, _fáar_
  { {0x9cd60008,0x86c50015,0x68e90808,0x61e400da}},	//   דושה_, _ليتن, mzed, whil
  { {0x61f60064,0x77f6000a,0x46a502e1,0x61e40745}},	//   tiyl, _במסד_, _райв, thil
  { {0x6604003f,0x69c93130,0xdb010144,0x24463131}},	//   _ujik, njee, _malà, _tôm_
  { {0x61f601e2,0xa0673132,0x76430035,0xef860329}},	// [63c0] riyl, ката_, _huny, клап
  { {0xe47b0053,0x61f60064,0x3fe3297b,0x69c900f2}},	//   _קריכ, siyl, ажув, hjee
  { {0x7c3a04ed,0x69db00f2,0x7d1b0035,0x4fa30001}},	//   _ritr, kkue, _ayus, рихв
  { {0xdd8f0029,0xdd900029,0xcf250029,0x973c0085}},	//   قوم_, صوت_, اركي, meće
  { {0xf7670086,0xdd8f0070,0x656400f2,0xdc2a0086}},	//   _پا_, تون_, _meih, وسته_
  { {0x65640313,0x6e290012,0xbf650040,0x387f1fc6}},	//   _leih, _eheb, _مدفو, duur_
  { {0x7ac30063,0xaa630010,0x628e3133,0xdb010144}},	//   исъе, атык, ntbo, _calà
  { {0x7c3a0050,0x2d82003c,0xf2d30008,0x225e0227}},	//   _witr, _øke_, שעה_, átky_
  { {0x7c3a038d,0xab5c0024,0xd7e601c6,0x61e30045}},	//   _titr, _soļu, віно, _înle
  { {0x7ba50015,0x7c3a0234,0xca760033,0x76433134}},	//   _مصمم, _uitr, _ауды, _buny
  { {0xc5f90024,0x69c60fb2,0x8f7b00a3,0x6671002b}},	//   ksēt_, ökes, וניק, مگير
  { {0x7a25005c,0x973c016f,0x79850029,0x22b1005c}},	//   rótc, deće, _مؤهل, _rąk_
  { {0x29550063,0x857400fd,0x661d3135,0x628e3136}},	//   _съхр, шлях, rlsk, etbo
  { {0xdb0100dc,0xf1bf0092,0xdb1a2045,0x200701a3}},	//   _halá, _pháo_, _anté, čnik_
  { {0x179b0008,0x06270004,0xd90e002b,0x27f4002a}},	//   _חיוב, _ифим, _دیک_, ędną_
  { {0x29180064,0xd6d90036,0x59c5000b,0x0737004f}},	//   ğraf_, _яті_, वायर, _באום_
  { {0x9ce800fd,0xdb013137,0x62341c3f,0x6fd70065}},	// [63d0] _офiс, _malá, рету, _मकदू
  { {0xa5bb002f,0xdefb0080,0x5f7400a2,0x50190015}},	//   slód, мые_, لامر, رياح_
  { {0x6f1c0026,0xf7730135,0x387f0079,0x0d990033}},	//   _cyrc, שקע_, zuur_, етлы_
  { {0xf1bf0092,0x6f1c0034,0xdb010046,0x6e1400ce}},	//   _khám_, _dyrc, _nalá, афіє
  { {0xbc19008f,0xf1bf002c,0x59b6000b,0x1bd5005e}},	//   нікі_, _iná_, _अफ़र, лодя
  { {0xe504014e,0x7a350007,0x5e450015,0xdb030046}},	//   रपति_, _išti, _مَسْ, edná
  { {0xfb84008f,0xbe880001,0xfa390054,0x6f1c0034}},	//   рычн, _исте_, нчић_, _gyrc
  { {0xc334000f,0xe292000a,0xa819002b,0x387f0438}},	//   סוק_, צְו_, کتبر_, tuur_
  { {0x656400b8,0x75e6005c,0x69c900f2,0x17f90015}},	//   _reih, _józe, rjee, فردة_
  { {0x68e90050,0x87b80080,0x76430665,0x69c600f2}},	//   rzed, вуют_, _puny, öker
  { {0x200714b1,0xdce00089,0x5a470010,0x68e90eba}},	//   čnih_, _odmě, _рэза, szed
  { {0x26190152,0x7a25001a,0x8e96000a,0xdb013138}},	//   déos_, bóta, נדרו_, _galá
  { {0x973c0085,0x69c0000b,0x88c40015,0xdb1a00bf}},	//   veće, वारी, _نتول, _motý
  { {0x656400b8,0x386d3139,0xa87a000a,0xb4c4000b}},	//   _weih, mser_, _נרצח, _एपी_
  { {0x973c016f,0x386d313a,0x7cea0030,0x998c0091}},	//   teće, lser_, _köré, _gudų_
  { {0x394d1915,0xa5bb0030,0xa2260015,0xafdb00cb}},	//   nces_, alób, ارسه, _støp
  { {0x973c016f,0x386d313b,0x04950033,0xf4850004}},	// [63e0] reće, nser_, _крэў, _куќн
  { {0xd8480023,0x5f760029,0x53a60001,0xceea0033}},	//   _học_, طائر, _саоб, ндзе_
  { {0x394d005c,0x7a250030,0x1eaa0058,0xdb1a0416}},	//   kces_, zóta, عاطي_, _antî
  { {0xc27b00b2,0x51550036,0xa1550063,0x386d0293}},	//   _ארטי, _втру, _върш, kser_
  { {0x386d0134,0xd8480016,0xdb1a013f,0x0000006a}},	//   jser_, _mọc_, _dotý,
  { {0xd8480092,0x386d0134,0x2aaa0001,0xdd92002b}},	//   _lọc_, dser_, етио_, _گور_
  { {0xba730015,0x141b000a,0xdb0105e2,0x69c0000b}},	//   مايت, עוצב, _palá, वाली
  { {0xdd920225,0x98740b97,0x291d002a,0x7a250030}},	//   _دور_, алиц, _bywa_, tóta
  { {0x0076000a,0x9dd7000a,0x3dfb000a,0x6947006f}},	//   אתִי_, _עומק_, _נלמד, dčeľ
  { {0x0897003b,0x18970029,0xdc9b000a,0x4897002b}},	//   اضيع_, اضية_, _אסמכ, ائيد_
  { {0xdb0103c0,0xd8480016,0x75d5006e,0x99860015}},	//   _talá, _bọc_, ليدا, _ملاو
  { {0x1f370053,0x0f370053,0x58860010,0xf7270010}},	//   טריר_, טריט_, _быка, ыцый_
  { {0xd8480092,0xa85600d0,0xe4e4005e,0xd7fa18c5}},	//   _dọc_, _стеј, бірн, _пук_
  { {0x25ad30fc,0xdce003cd,0xdd1c003d,0xf6f5002b}},	//   žel_, _nemč, kšžo, ازیگ
  { {0x7528002a,0xdb0805a4,0x268a0015,0x21e7007c}},	//   ędza, _indó, _أختي_, _lõhe_
  { {0xf1bf0092,0x21550033,0x7a01003d,0xc1050015}},	//   _thám_, ркаў, vētk, لوزي
  { {0xdff50054,0xdfdb006b,0xc0580033,0xdb010012}},	// [63f0] апањ, нъж_, гіх_, _unlö
  { {0x1e0d005d,0xe8d7004f,0x4427009a,0x0000006a}},	//   िक्ष_, אומר_, _حربف,
  { {0xa1950010,0x141c00a3,0xb5c8002b,0x9d550015}},	//   _канч, _אוזב, _شویم_, لنات
  { {0xdd950010,0x6d440007,0x0dc80c96,0xdb1a002a}},	//   рады, žian, лучи_, _lotó
  { {0xd2640024,0xdb080064,0x6b651aef,0xdb01007f}},	//   _viņš_, _endü, акла, _kalç
  { {0x207a0053,0x7a01003d,0xdb1a016e,0x386d03e6}},	//   _באשא, mēti, _notó, vser_
  { {0x7a010048,0xda62007a,0x2bc7000b,0x543c004c}},	//   lēti, овщи, लाबा, געגא
  { {0x386d313c,0x394d313d,0xda640015,0x28b10065}},	//   tser_, uces_, حاوي, जिलि
  { {0xdb1a0467,0x394d0287,0x7a01003d,0x6ce7008b}},	//   _botó, rces_, nēti, _сіве
  { {0x2cb80002,0xa765313e,0xd8480016,0xf6b50033}},	//   _حافظ_, шкод, _sọc_, аёмя
  { {0xe9750086,0xceb2004c,0x7a080046,0x9f9602de}},	//   _نهاد, ַיך_, mětn, _væø_
  { {0x1959054f,0xdb0102de,0x386d313f,0x99840369}},	//   _рады_, _palæ, pser_, _هلمو
  { {0xdb1a3140,0x0446018d,0xf1bf0030,0x9426004a}},	//   _fotó, регн, _tháj_, имме
  { {0xdb1a002a,0xb6020046,0x443e008c,0xdb0116bc}},	//   _gotó, _řádc, öt_, _calç
  { {0xd7fa000a,0x98140021,0xd2520015,0x78bc003d}},	//   _שהצל, _ابنا, تنز_, ārve
  { {0xd8480092,0x65bb00f2,0x24f60036,0x614316c7}},	//   _họa_, _vähä, _вчор, жета

  { {0x973c016f,0x20360015,0x1f66008d,0x64a63141}},	// [6400] meća, لفرس, икам, _тапа
  { {0x65bb022d,0x2f560937,0x0fc3009b,0x7a350073}},	//   _tähä, ртас, ойун, _ištu
  { {0x1eca0063,0xbea60010,0x5d6a0080,0xe37b039e}},	//   ължи_, раек, вием_, _בריר
  { {0x06960053,0x7a01003d,0x629e02f5,0x7a2c01f6}},	//   ידעם_, bēti, _ippo, oûte
  { {0x9cf60001,0xa5bb00dc,0xf3c90086,0x7a010024}},	//   јчеш, nlóa, _شبیه_, cēti
  { {0x3e68002b,0x0bf3005e,0x3eab008c,0x63530046}},	//   _مجری_, опію, äitä_, mění
  { {0xb4db0251,0x7eb508f0,0xe9e600c9,0x8f9b004f}},	//   ncàr, _лётч, ицио, _שילי
  { {0x973c016f,0x88c60015,0x6a130015,0xac7a0015}},	//   jeća, لتخل, يبير, _لمرض_
  { {0x63530089,0xc7c6032e,0x629e01d7,0xfce33142}},	//   nění, асни, _lppo, _дото
  { {0xf41f00f2,0x387900dc,0xf0930008,0xc7d70080}},	//   ntät_, ásra_, קנת_, имых_
  { {0x8c1b0008,0xd8480092,0x09e605fc,0xdb240086}},	//   _יומי, _dọa_, _кожн, _اوای
  { {0x5e77000a,0xdb1a0144,0xceb305bd,0xe4e70033}},	//   סתכן_, _fotò, קיר_, аігн
  { {0x53470124,0x75d5002b,0xd90e002b,0x69c200aa}},	//   ихва, ليگا, _زید_, _inoe
  { {0x26f7002b,0x7a01003d,0x66063143,0x63530046}},	//   اریخ_, vēti, ankk, dění
  { {0x25b000f2,0x72050015,0x06840015,0xa6c7002b}},	//   öllä_, موسم, _العُ, _نوول_
  { {0x31c40191,0x5187000d,0x7a25002e,0xf1bf0092}},	//   осув, јува, jótl, _khái_
  { {0xf2040033,0x4f6b05ab,0x25d8000a,0x8f4702ed}},	// [6410] цяро, вшем_, _כוהן_, ахед
  { {0x3d1a005d,0x7a010024,0xa8570008,0x351c000a}},	//   _बड़े_, rēti, יימה_, _בוחנ
  { {0xee870010,0x0dcb005e,0x6fc9000b,0x7a080046}},	//   рызо, куди_, राबं, větn
  { {0x7a01003d,0xce18008b,0x6e223144,0xac750369}},	//   pēti, аціі_, glob, ماتش
  { {0xf3f00086,0x442300bd,0x4c840010,0xc19a000a}},	//   _رأی_, olj_, жлів, _גשרי
  { {0x2fe50015,0xbca40015,0x92b4002b,0xb136000a}},	//   _اكسف, تمهي, _احیا, _לארח_
  { {0x6fc4005d,0x7eb000dc,0x1a68002b,0x0378000a}},	//   रारू, rópá, لیلی_, בתות_
  { {0xf9910029,0x2cac008c,0x3ebe001a,0x7a25002a}},	//   سبب_, ähdä_, _átta_, róto
  { {0x973c010b,0xe9a80029,0x7a080046,0xbca40015}},	//   veća, شدين_, pětn, _ومفي
  { {0x7d04002d,0xdb0100b8,0x7d1e005c,0x7bc100c7}},	//   úise, _palä, ępst, _unlu
  { {0x38ca0086,0x38c1002e,0x8bb40015,0xdce0003d}},	//   نایی_, færð_, _بإقا, _iemā
  { {0x5a350001,0xda65002b,0xe57a0033,0xeab00040}},	//   _унет, _ناچي, ызм_, _زعم_
  { {0xf41f00f2,0xd8480092,0x49b80115,0x7989108a}},	//   ytät_, _tọa_, _خالد_, mgew
  { {0xf8b6013a,0xb05b08e9,0x973c0085,0x79891810}},	//   _לפני_, _kräf, seća, lgew
  { {0xfbd20008,0x63830010,0xf7f40067,0x973c0160}},	//   לתך_, ягра, _بسند, lećn
  { {0x68ec0064,0x11da0029,0xb1460661,0xc0460015}},	//   _öldü, دورة_, снал, مخطو
  { {0xb4db0251,0x25fd000b,0x600a0b1e,0xdb083145}},	// [6420] scàr, _लगती_, гнам_, _radí
  { {0x798900b8,0x7a01003d,0xdb180046,0xd12f0021}},	//   hgew, mētu, ejvý, رمل_
  { {0x6d440007,0xa1360086,0xdfcf0029,0x6e2210ca}},	//   žiam, _گردش, عيم_, tlob
  { {0x79890298,0xc3330008,0x7a080046,0xf41f3146}},	//   jgew, _מות_, věto, stät_
  { {0xa1360029,0x721b000a,0xa3cc000b,0x6e223147}},	//   _دردش, _תוכח, _रचा_, rlob
  { {0x0e6a0029,0xd8480092,0x69c20079,0x395f3148}},	//   _مصري_, _bọn_, _snoe, ebus_
  { {0xeaaf0029,0x20070046,0x224200cb,0xfe580c44}},	//   فعي_, čnit_, _kikk_, _כֻּל
  { {0xf1bf0092,0xd2b7000a,0x79893149,0xd8480016}},	//   _phái_, מלצת_, ggew, _dọn_
  { {0x8b960a61,0x2242007c,0x29d80125,0xdd8f00c3}},	//   _греч, _mikk_, _béar_, _سول_
  { {0x2242003c,0x29d80125,0xf69803ae,0x7a01003d}},	//   _likk_, _péas_, авој_, dētu
  { {0x501b0008,0x70a5005d,0x38c1002e,0xd8480092}},	//   רויו, _ऑन्ल, tærð_, _gọn_
  { {0xdce00048,0xf1bf0023,0xdb1a03af,0x35e70010}},	//   _zemā, _thái_, _entã, сцов
  { {0xa5bb002c,0x999f0064,0x394601d7,0xe4e4005e}},	//   blón, lmuş_, _igos_, пірн
  { {0x4813005e,0xf64f002b,0x29d80125,0xc4280058}},	//   _еміс, بئی_, _géar_, مثّل_
  { {0x7a3500df,0xb7970008,0x8a78000a,0x9f5a0003}},	//   _ištr, _הכוח_, יָּק, cipé_
  { {0x224200dc,0xbbb4000b,0xc693004f,0x0000006a}},	//   _cikk_, ंयुक, _זאק_,
  { {0x7a080089,0xc94b000a,0x656f314a,0x4fd50f82}},	// [6430] větl, אֲבֹ, mach, ожат
  { {0x645d01d1,0x752d016f,0x9f450064,0x656f314b}},	//   mpsi, _izaz, _ölü_, lach
  { {0x543c00b2,0x2242003c,0x61e30011,0x394600d9}},	//   _געזא, _fikk_, _înlo, _ogos_
  { {0x63a70050,0x2242003c,0x656f314c,0x39460ba4}},	//   lejn, _gikk_, nach, _ngos_
  { {0x7a35016f,0x6287091e,0xc5f4000a,0xa63c004c}},	//   _oštr, lujo, הדף_, אגאר
  { {0x62870152,0x39460026,0xdb03314d,0xb05b00b8}},	//   oujo, _agos_, lené, _präf
  { {0x61ed0020,0x7a010024,0x973c0085,0xdce90085}},	//   ohal, zētu, dećo, _odeć
  { {0x26de0007,0xdd9404ab,0x656f314e,0xdb03006f}},	//   dyto_, _насы, jach, nené
  { {0x2cad0041,0x76580007,0x7989059b,0x316b002a}},	//   _used_, _atvy, rgew, _mecz_
  { {0x656f1084,0x316b005c,0xb05b00c0,0x660d314f}},	//   each, _lecz_, _träf, _ajak
  { {0x656f00b8,0x63a73150,0x7afc0263,0x060a1f67}},	//   fach, dejn, _žrtv, инок_
  { {0x656f002f,0x55f60010,0xdb26002b,0xdb03013f}},	//   gach, ічну, _بومی, jené
  { {0x61ed0f4d,0x9c820089,0x3e480064,0xdb030057}},	//   dhal, _účte, _işte_, dené
  { {0x316000d9,0x66e5207f,0x7a01003d,0x2ca00061}},	//   wbiz_, _мола, rētu, çidi_
  { {0xf6d50010,0x85550086,0x22420020,0xc7440031}},	//   _філя, غییر_, _pikk_, _عضوي
  { {0x320900b6,0x42260210,0x61ed3151,0x41aa012e}},	//   gnay_, ідав, ghal, јван_
  { {0xe936004c,0x62870091,0xdb080030,0x201a3152}},	// [6440] ַנעץ_, aujo, _madá, topi_
  { {0xb4e6014e,0x63a70089,0xa819000a,0x13a8002b}},	//   पनी_, cejn, בֵ֣י, _اندی_
  { {0x5ea603c4,0x539b0008,0x4d4a0345,0x201a01a3}},	//   تمال, _דייו, апен_, ropi_
  { {0xdb0801b2,0x44443153,0x569a000a,0xbd490015}},	//   _nadá, _hi_, ייעצ, مؤهل_
  { {0xc5f30008,0xa6de0092,0x659b0053,0xf1bf0092}},	//   ודא_, _ngưn, שינק, _cháu_
  { {0x27160089,0x2ca912b3,0xbc370015,0x61e41af8}},	//   něné_, çada_, يسوا_, lkil
  { {0xde78000a,0xb05b079c,0x61e4008c,0xf236000a}},	//   _לְּך, _präg, okil, ֗רֶץ_
  { {0x7a25002d,0x61e40ae5,0x999f0061,0xb075001a}},	//   nóth, nkil, rmuş_, _óþör
  { {0x61e4002e,0x98a30001,0x656f3154,0x44443155}},	//   ikil, диње, vach, _oi_
  { {0xc7b8016f,0x109b000a,0x08f70015,0x44443156}},	//   kođe_, סביב, غريب_, _ni_
  { {0xb05b00b8,0x61ed002c,0xf1bf0016,0x27160046}},	//   _träg, yhal, _khát_, děné_
  { {0x2fd8002f,0x69a1005d,0x656f002d,0x44443157}},	//   _lorg_, _कॉपी, uach, _ai_
  { {0x63a70089,0x44443158,0x84e40033,0x656f3159}},	//   tejn, _bi_, доўж, rach
  { {0x68ec0064,0xdb0828cc,0x61e42286,0x9c8301b2}},	//   ıldı, _zadá, ekil, _účet
  { {0x6fc9014e,0x63a7032c,0x63b50024,0x316b0001}},	//   रासं, rejn, rdzn, ишао_
  { {0x244f01e2,0x90550010,0x21270086,0x629500b8}},	//   _tüm_, звац, قيزی_, rtzo
  { {0x4444315a,0x0596002b,0x93470021,0x61ed315b}},	// [6450] _fi_, _رايگ, _وخدم, rhal
  { {0x4444315c,0x61ed315d,0xcebb0054,0x61e402f2}},	//   _gi_, shal, иље_, akil
  { {0xdb0a0084,0x644d002d,0x661d007c,0x656d013c}},	//   ldfæ, _huai, oosk, _keah
  { {0x661d00f2,0x4444315e,0x64450035,0xb05b0012}},	//   nosk, _zi_, _hihi, _präd
  { {0xe7bc014e,0x444401e2,0x69ce014e,0x6445315f}},	//   ्ञाप, _yi_, थानी, _kihi
  { {0x4ca80015,0x68e00034,0xaa45027a,0x7a253160}},	//   تُهُ_, dymd, пекл, móti
  { {0x644d002f,0x644500f2,0x539c0135,0x337c000a}},	//   _luai, _mihi, יסגא, שְׂב
  { {0x2fd80111,0xb05b00c0,0xddde0011,0x64450035}},	//   _zorg_, _träd, rupţ, _lihi
  { {0x644d002f,0xdb080030,0xa5bb0030,0xafdb00cb}},	//   _nuai, _vadá, rlól, _støy
  { {0xbca40029,0xe8f60010,0xf0920008,0x78a20046}},	//   _تمكي, ялы_, עני_, _dpov
  { {0xdb1a001c,0x61e4002e,0x98ab0064,0xb885002c}},	//   _botõ, ykil, ımız_, dpíš
  { {0x2001000c,0x64a60010,0x644d002d,0xba9a000a}},	//   hihi_, пама, _buai, _לסעי
  { {0xb4e6014e,0x644d002f,0x3f91005c,0x27160046}},	//   पने_, _cuai, _oczu_, těné_
  { {0x69d90041,0x2924002c,0x2001003f,0x644501d7}},	//   _howe, ísať_, jihi_, _cihi
  { {0x61e401e2,0x6445013c,0x232a0658,0x78bb001a}},	//   tkil, _dihi, сови_, lvuv
  { {0x644d002f,0x799b0026,0x6d49002d,0x867a000a}},	//   _fuai, nfuw, _ngea, _הרקו
  { {0x24530029,0x20d6005e,0x61e43161,0x10a33162}},	// [6460] _كنيس, чівс, rkil, нитн
  { {0xd12f0029,0x69d9003e,0x61fd0020,0xf1bf0125}},	//   امك_, _lowe, _emsl, _bhás_
  { {0xf1bf1d1e,0xcf250086,0x33db000a,0x61e40061}},	//   _phát_, ورمي, _החיד, pkil
  { {0x69d90050,0xcf89000a,0x224c0046,0x2cbf17ca}},	//   _nowe, טט_, ídku_, _brud_
  { {0x91bb0008,0x5d1a0029,0xc1bb000a,0x20010509}},	//   _המכי, حتاج_, _המכש, bihi_
  { {0xf1bf002d,0xc477000a,0x7a080046,0x2cbf0034}},	//   _fhás_, לתנו_, měti, _drud_
  { {0x6fc9005d,0xb05b0012,0xf1bf0125,0x90430015}},	//   रारं, _gräb, _ghás_, _أنّه
  { {0x5eeb0008,0x1e97000a,0xa5bb0030,0x69d93163}},	//   _הַמְ, _מכלל_, alój, _cowe
  { {0x69dd007c,0xbe130015,0xb4e60065,0x69d901f9}},	//   ösea, _أوقع, पनो_, _dowe
  { {0x25a00020,0xd90d002b,0x644d0125,0x8b260033}},	//   _abil_, جیه_, _ruai, _едзе
  { {0x212700a7,0x473418a9,0xdc3b0053,0x644d10e0}},	//   ́nh_, ьнос, _פעבר, _suai
  { {0x64453164,0x69d93165,0xe947009a,0x0000006a}},	//   _sihi, _gowe, _فرهی,
  { {0x644d03af,0xd7e6022a,0xe4c7004a,0x19bb000a}},	//   _quai, _ніко, чённ, _למאב
  { {0x493b013a,0x69d90111,0x661d0020,0x987b000a}},	//   _הגדו, _zowe, sosk, _פרוק
  { {0x45f90029,0x079b0008,0x661d0227,0x35f50004}},	//   _وفتح_, _הסול, posk, _опкр
  { {0x644d002f,0xdb1a00c0,0x82340015,0xdb0a0123}},	//   _tuai, _intä, فرقا, mdfä
  { {0xc05b0036,0x7bda0020,0xbfd9005e,0x7bc83166}},	// [6470] сіб_, _ootu, одає_, _ondu
  { {0x44273167,0x7bda3168,0x8fa40054,0xc7f8004f}},	//   _ón_, _notu, нађе, קִּר
  { {0x200101e2,0xdfd80063,0x539a000a,0x7d790015}},	//   rihi_, чът_, _ויתו, قمار_
  { {0x2ca9001c,0x98cc000b,0x20010d89,0x7bc83169}},	//   çado_, ़माए, sihi_, _andu
  { {0xee380191,0xd59c0053,0x61d6000a,0x91ba000a}},	//   їні_, מבאל, _חורף_, _ומרי
  { {0xda650029,0x653a004c,0x69d9316a,0xb05b0123}},	//   واعي, קעװד, _sowe, _träb
  { {0x75280050,0x69d90e70,0xaa560015,0x5d650015}},	//   ędzi, _powe, ولوا_, _يُسْ
  { {0x7bc80ab5,0x08c500d7,0x5f440015,0xbdf80015}},	//   _endu, дбин, _أنفل, _فرقا_
  { {0xf8a90086,0x69d9003e,0x8b47002b,0x17f90015}},	//   تگاه_, _vowe, _فضان, قردة_
  { {0xdb03316b,0xd7090080,0x17f90015,0xcb680054}},	//   lení, жное_, تربة_, _нађе_
  { {0x69d904d0,0xff56000a,0xda08002b,0x2d8f0723}},	//   _towe, ובתך_, _کينه_, ogge_
  { {0xf3e9013a,0xae00014e,0xfb1a0053,0x28ae000b}},	//   _דף_, लोपन_, _וועמ, _जैवि
  { {0x6d442801,0xab04007c,0x41d1000b,0x7ae3316c}},	//   žiav, öövä, हानस, lynt
  { {0x33d500f5,0x7a080046,0x67d41f89,0x98a20a10}},	//   ніст, věti, _почу, _рише
  { {0xd808000a,0xc5f60015,0x75e6002a,0x0443153d}},	//   _מִקָ, _يثبت, _józk, терн
  { {0xdb030264,0x25a010cd,0x163a0058,0x0000006a}},	//   jení, _ubil_, _بستة_,
  { {0xdb030227,0x0839000a,0xcf7a0015,0xf992000a}},	// [6480] dení, ַעֲל, قصاص_, כרן_
  { {0xdfa60029,0x2d8f316d,0xdee6007e,0x7a25001a}},	//   بحري, egge_, мози, mótu
  { {0x5e5a0015,0xb05b0012,0x0166004a,0x7bda0cee}},	//   زجاج_, _präc, _окно, _rotu
  { {0xb2bb000a,0xf2d3000a,0x2d920061,0x7ae3008c}},	//   _ומטר, _סער_, üye_, dynt
  { {0xc173013a,0x3ead010b,0x68ed0050,0xa3b2005d}},	//   _בחר_, _ćete_, _żadn, _ऐसा_
  { {0x2ac60001,0x69dd0c77,0xc29a000a,0xc4f7000a}},	//   дљив, ösen, ַיִך, וזני_
  { {0x160e014e,0x7bda0011,0x7ae3003c,0xed5a0036}},	//   ाचार_, _votu, gynt, _мов_
  { {0x80b5005d,0x4efb000a,0x35b2000b,0xdb030046}},	//   _उनमे, _והלו, ज़फ़, cení
  { {0x7bda2cc5,0xad260086,0x50db0053,0x6fd2000b}},	//   _totu, _آرزو, ַקטא, ठापू
  { {0x0137000a,0xcbc6002b,0x7bc8316e,0x0000006a}},	//   ורפת_, _تزري, _undu,
  { {0xd8480023,0xeb970036,0x17f70029,0xcb0a00e5}},	//   _mọi_, _цих_, برية_, _بيان_
  { {0x6d440007,0xf1bf0016,0xdb090015,0x7c2a316f}},	//   žiau, _nháp_, _عزله_, llfr
  { {0xdca60029,0xdb010057,0xe6c6002b,0x38cb002b}},	//   دى_, _malý, ستگي, _واهی_
  { {0x7a130011,0xdb030057,0xf907002b,0x8bd8004f}},	//   măta, zení, _تأمی, הַֽח
  { {0x07a3023e,0xa294005e,0x925809c3,0x7c2a3170}},	//   _рајн, карі, даст_, ilfr
  { {0x973c016f,0xae00000b,0xdd310535,0x7a250052}},	//   jeći, लोमन_, tężo, bótu
  { {0xc34b008f,0x973c016f,0x7a130011,0x60f9054f}},	// [6490] _мяне_, deći, năta, чная_
  { {0x5fc9005d,0xceeb0225,0x7ae300f2,0xa2b5008b}},	//   राइल, يران_, yynt, _збоч
  { {0x9f040015,0xa159005e,0xdb033171,0xb17b06c7}},	//   نوكو, _нану_, tení, _blåt
  { {0xbdf80015,0x8c95005e,0x7bde001a,0x0000006a}},	//   ورنا_, еркі, öpun,
  { {0x7ae30026,0xdb03002c,0x4d640036,0x415a000a}},	//   wynt, rení, тків, _מדרג
  { {0x7ae3008c,0x9f5a0144,0xdb03013f,0x0000006a}},	//   tynt, cipà_, sení,
  { {0xd8480023,0xf9910015,0xb17b00cb,0x3ce907c4}},	//   _gọi_, هبة_, _flåt, šav_
  { {0x628700f2,0x030d0092,0xfe430086,0x5d840015}},	//   irjo, _đều_, _شکای, _للفل
  { {0x7c150036,0x6d5b003f,0xa5bb002d,0x7a25001a}},	//   _здає, _ifua, clói, dótt
  { {0x660f002a,0xead50151,0x3ce00072,0x0000006a}},	//   enck, _позь, äive_,
  { {0x7a080046,0x66e50033,0x6d440091,0xd62a0a73}},	//   větv, хона, žiat, зоне_
  { {0x98a000df,0x2bc7005d,0x6abd000b,0x6d5900aa}},	//   _šią_, लाका, ्मीर, ncwa
  { {0x8cc2005d,0x98a503ae,0x75e6002a,0xe8ee0076}},	//   लियो, _чиле, _józi, _сл_
  { {0xe7870010,0xb6020089,0x98f40029,0xccf2000a}},	//   _цудо, _žáda, _جثما, נכם_
  { {0xf1bf0023,0xd348002b,0x67ed001a,0x52752666}},	//   _pháp_, بیده_, _gúja, куту
  { {0x3ebe002e,0x8cc2000b,0xd8480016,0x0000006a}},	//   _átti_, लिमो, _rọi_,
  { {0x628700f2,0x04570029,0x66063172,0xa3ff0046}},	// [64a0] arjo, _كلية_, mikk, řeší_
  { {0x66063173,0xb17b146d,0x900a0015,0x351b000a}},	//   likk, _slåt, أزرق_, _מופנ
  { {0xf1bf0092,0x7357004c,0x6606008c,0x645b0045}},	//   _tháp_, _רױטע_, oikk, ţuit
  { {0x66060c58,0x7c2a3174,0xc27b000a,0x6fc9000b}},	//   nikk, wlfr, _צרכי, राउं
  { {0xdb03002c,0xe573000a,0x6606008c,0x59d3000b}},	//   rdný, רַע_, iikk, थानर
  { {0x628e0089,0x66060f83,0xa5bb03d9,0x031f000b}},	//   oubo, hikk, rlói, _मुँह_
  { {0x539b000a,0x01fa000a,0xbf36002b,0x7c2a00da}},	//   פיקו, ּפִל, _سرآغ, rlfr
  { {0xf2d30008,0x7e9b0008,0x21e7007c,0xdb180030}},	//   רעה_, _מסלו, _rõhk_, ndvé
  { {0xbc6a0086,0x8c95009e,0x6c860031,0xdde9002b}},	//   _رمان_, _архі, _سلام, _غرفه_
  { {0x69cb3175,0xa097004c,0x6606008c,0x7a130045}},	//   _enge, עדיק_, eikk, răta
  { {0x8c1b0053,0x63ae0089,0xa3c4000b,0x97a30033}},	//   _צובי, debn, _एफ़_, урыл
  { {0x5eeb000a,0xb9260015,0x7a130045,0x628e22d3}},	//   לַכְ, _كفاي, păta, dubo
  { {0x7a25002e,0xdb030264,0x37e6249a,0x629c0654}},	//   rótt, mená, _подг, etro
  { {0x63ae018b,0x6606022d,0xdb0300dc,0xd25b0088}},	//   gebn, aikk, lená, зца_
  { {0x17570008,0xdbc70020,0x31c70010,0x628e3176}},	//   _אסור_, _töös, нсав, gubo
  { {0x660600dc,0xd49b0054,0xb05b0b14,0x59a6000b}},	//   cikk, _еро_, _drän, _कॉमर
  { {0xc61d000b,0xb17b0795,0x629c3177,0x0000006a}},	// [64b0] नवीय_, _slås, atro,
  { {0xb05b0dca,0x188b000a,0x629c3178,0x6fb800af}},	//   _frän, לְבּ, btro, нгур_
  { {0xb05b01d1,0x4423016f,0xf77300f3,0xd356000a}},	//   _grän, moj_, רקע_, _ביתי_
  { {0x31790053,0x24eb0008,0xaf340029,0x127a0053}},	//   _קאָד, ּקַּ, اركت, _קארע
  { {0x672a002e,0xa176015b,0xbc190033,0x973c0085}},	//   _lyfj, _בערד_, мікі_, meću
  { {0x4423010b,0xeab10029,0xe0df0016,0x224b050b}},	//   noj_, لعب_, _ngòi_, _hick_
  { {0x3da7008f,0xdea40074,0x224b3179,0x4ae70033}},	//   _праб, _میلی, _kick_, эўда
  { {0x63ae005c,0x6d5b003f,0xe9d10015,0xa822002b}},	//   zebn, _ufua, شغب_, یکون
  { {0x4423060b,0xbcdb0029,0x16c9005d,0x66060209}},	//   koj_, _عذرا_, िम्ब, vikk
  { {0x4423010b,0x66060150,0x113c000a,0xa8a40015}},	//   joj_, wikk, התחל, اصيو
  { {0xdb01317a,0x3dcd003e,0x63ae0107,0x9aa40021}},	//   _való, _knew_, vebn, _مملو
  { {0x7a1304f9,0xdce00089,0x3ddf0111,0xceb2000a}},	//   măto, _nemě, _jouw_, ביט_
  { {0x63ae02d5,0x7a130011,0xf41f03a4,0x6606317b}},	//   tebn, lăto, rrän_, rikk
  { {0x6606317c,0x58f60008,0x629c151c,0x442301a3}},	//   sikk, _שמסע_, ttro, goj_
  { {0x7a130011,0x629c001c,0x63ae0c1a,0x6606007c}},	//   năto, utro, rebn, pikk
  { {0x212b0089,0x63ae065d,0xe7160447,0x629c317d}},	//   _bych_, sebn, _בחצר_, rtro
  { {0x628e0035,0xa3ba0002,0x80a60015,0x8c480061}},	// [64c0] subo, _قادر_, ضمان, nişç
  { {0xb05b04d4,0x2537000a,0x3dcd00da,0x212b317e}},	//   _trän, _בנפש_, _anew_, _dych_
  { {0x224b01d1,0x6e220020,0x3ddf0111,0x8506002b}},	//   _fick_, toob, _bouw_, _سوگن
  { {0x224b01d1,0x98b10046,0xb05b0123,0x91e618fc}},	//   _gick_, íběh_, _kräl, _роме
  { {0xdb0a0134,0x22400020,0x6fc9000b,0xedf5002b}},	//   ldfø, mmik_, राखं, دينگ
  { {0xdce00089,0xb4fb000a,0x7f4a0015,0xa4fb000a}},	//   _země, ופני, _يلحق_, ולנט
  { {0x63a30014,0x7a130011,0xeaaf0029,0xdb030046}},	//   _önne, găto, قعي_, tená
  { {0x7a080089,0xa9c30036,0xa93402bf,0xdd92002b}},	//   věts, аськ, лейш, _خور_
  { {0xdca60083,0xc7b00015,0xf1bf0030,0x1c46122f}},	//   _јази, مّة_, _okán_, _анам
  { {0x66040014,0x394f003e,0xaac60015,0x6c330015}},	//   _amik, _eggs_, _لتصن, _نفقا
  { {0x7a130011,0x44231ff2,0x98a3003d,0x1bf7004f}},	//   căto, voj_, ājā_, _שצבר_
  { {0x6f0311e0,0x3ebe002e,0x628100dc,0xceb3000a}},	//   únci, _áttu_, álom, ׁית_
  { {0x44230242,0xf8b6000b,0x44b40033,0xd8480016}},	//   toj_, _अनिय, абяс, _bọt_
  { {0xa2950010,0x224b0b00,0x44230091,0x443a03f4}},	//   лагі, _sick_, uoj_, _chp_
  { {0xf8370008,0x18370008,0xaad2005d,0x224b003e}},	//   _שנות_, _שאול_, थमिक, _pick_
  { {0x5214008f,0xb05b00c0,0x61f60026,0xed5901a3}},	//   адст, _fräl, ghyl, _kaže_
  { {0xcf9b0001,0xd251002b,0x7a130045,0x1638000a}},	// [64d0] дје_, _گنج_, zăto, _בנהר_
  { {0x61440001,0x973c0085,0x224000bc,0x251c004f}},	//   ређа, seću, amik_, _קוזא
  { {0xdb0308e0,0x212b0026,0x224b317f,0x82d5004f}},	//   menç, _wych_, _tick_, _עוֹג_
  { {0xed580191,0x212b0050,0x2d94005e,0xf2d20643}},	//   вої_, _tych_, иріс, _העט_
  { {0xdd940010,0xdb03016e,0x0d8400e2,0xbca500c3}},	//   рачы, oenç, рлін, امتي
  { {0x7a130011,0x61ed0446,0xb09a000a,0x0ae90015}},	//   tăto, lkal, _אישר, فرعي_
  { {0x7a080046,0x3ddf0079,0xfbd00015,0xa5bb0030}},	//   větr, _touw_, غته_, nlós
  { {0x7a130011,0x53380008,0xc5f90024,0xdb1a0251}},	//   răto, כנון_, spēj_, _matè
  { {0x7a130011,0x7c2300da,0x9d15004a,0x79820034}},	//   săto, ponr, _сдач, _ddow
  { {0xdb03002e,0x7a130011,0xa7b5049d,0xe8f60c1d}},	//   venæ, păto, усиј, уль_
  { {0x764d00e8,0xb9950015,0x61ed3180,0x23780030}},	//   _biay, _ملاب, kkal, varj_
  { {0x21e7007c,0x443a3181,0x29c80058,0xb05b02ad}},	//   _kõhu_, _shp_, _لِمَ_, _präl
  { {0x07a5006b,0x5dfa000a,0xc7a50923,0xa43e0033}},	//   _балн, תפרנ, _билк, зьвi
  { {0xdc3500b2,0xec350053,0x61ed3182,0x44150d7f}},	//   טאָט_, טאָר_, ekal, афст
  { {0xd8480016,0x479a05bd,0x68e93183,0x61f62c22}},	//   _vọt_, _ניקס, lyed, thyl
  { {0x61ed0035,0xd5af0015,0x66043184,0x69db0077}},	//   gkal, _ففى_, _umik, njue
  { {0xb05b00c0,0x68e908c0,0xa5bb00dc,0x68fb0012}},	// [64e0] _främ, nyed, alós, nzud
  { {0xdb03001c,0xb02a0015,0xcef60004,0x442e0079}},	//   cenç, ركام_, лчењ, _óf_
  { {0xdfcf0029,0x139b0135,0x439b000a,0xbd8a0015}},	//   ثيل_, _אביע, _אביג, فنان_
  { {0xdd8f0015,0xed5a034a,0x63be007c,0x6e3b3185}},	//   كوم_, ход_, _hapn, _chub
  { {0xa0750080,0x63be00dc,0x5c0602e1,0x0cd40286}},	//   _высш, _kapn, ляка, ролю
  { {0x7ff60029,0xf537000a,0xdb1a0307,0xe457004f}},	//   _إسحا, ננסי_, _haté, איסט_
  { {0x60c4001c,0x75e600dc,0x139b000a,0xda4a004a}},	//   lvim, _józs, תבצע, нчил_
  { {0x5a34000d,0x24800b6c,0xeaaf0015,0xbc760067}},	//   јнит, _ovim_, سعى_, _مهرب
  { {0x27330092,0x26c73186,0xdb1a1446,0x0b960067}},	//   _ạn_, _arno_, _maté, _مجاد
  { {0xca760010,0x628100dc,0xdb1a3187,0x7982002a}},	//   _буды, álok, _laté, _wdow
  { {0x7fd70053,0xbae60015,0x70d1000b,0x3ffb004c}},	//   אויס_, _حكاي, _सप्ल, גפיע
  { {0x60c40064,0xdb0a001c,0x7ae50604,0x7982002a}},	//   kvim, nefí, ähte, _udow
  { {0xdb03001c,0xb05b0012,0xdb1a0144,0x55073188}},	//   tenç, _präm, _satè, учна
  { {0xe4540139,0x89370033,0x7bde008c,0x69c03189}},	//   скры, _спіс_, öpuh, ldme
  { {0xdb030341,0x3f87001a,0xdb1a151b,0xa75b0643}},	//   renç, ónum_, _baté, _אדור
  { {0x6738010b,0xdb1a0152,0xdb03001c,0x69c00100}},	//   _izvj, _caté, senç, ndme
  { {0x623400d0,0x15a8006b,0xdb1a1b89,0x2f8b0054}},	// [64f0] сету, _същи_, _daté, ељен_
  { {0x61ed0820,0x2937004c,0x6aba0012,0xa5bb0125}},	//   skal, ראמן_, _ostf, clór
  { {0x60c42f6d,0x6e9909a7,0xeeab0033,0x61ed318a}},	//   avim, твер_, этак_, pkal
  { {0x63be0227,0x867b000a,0x70950174,0x6b9c001a}},	//   _zapn, תראו, _камф, _örgj
  { {0x6aba04f9,0xeb0d000b,0x317a015b,0x417a000a}},	//   _astf, िप्त_, _בארד, _שנשב
  { {0xa3cb000b,0xda650923,0xde770015,0x8c45131f}},	//   _रोम_, авки, _مدرع, шеле
  { {0x6e3b003f,0x6ff4002a,0xff290015,0x69c00079}},	//   _thub, yńcz, _شكري_, fdme
  { {0x09e5249a,0xdb03008c,0x1a68002b,0x99d5012c}},	//   роин, venä, اینی_, شتبا
  { {0xf7710031,0x69a1000b,0xdb0301d0,0x682f064c}},	//   ياد_, क्षी, denå, lødi
  { {0xd7e60080,0xdb030e95,0xf8a8006e,0x69c0318b}},	//   имые_, tenä, اديه_, adme
  { {0x2480016f,0x68fb0012,0x80d1000b,0x645601d7}},	//   _svim_, szud, समुं, _suyi
  { {0x75e600dc,0xe4da002b,0x68e901f9,0xdb0302ad}},	//   _rózs, پوست_, pyed, renä
  { {0xdb03318c,0xd4f50033,0xb05b0123,0xe6170c31}},	//   senä, бяры, _dräk, рдя_
  { {0x69a1005d,0xdb1a026a,0x395f318d,0x225e00bf}},	//   क्री, _saté, lcus_, ítko_
  { {0xdb010089,0xe2460015,0xaaa9000a,0x569202d9}},	//   _oblí, لخري, כֹּ֖, _дајт
  { {0x7166003b,0xd8480092,0x60c4016f,0x171a000a}},	//   شارك, _họp_, tvim, _בוצע
  { {0xdfd20070,0x42230036,0x661d00dc,0x50650015}},	// [6500] يير_, ідув, érke, مطلق
  { {0xd47b0008,0xe53b0008,0x3860002d,0x60c4318e}},	//   _שאיל, _בתפר, _éire_, rvim
  { {0xdfcf00e5,0xe4f6000b,0x6fdf000b,0x71a6318f}},	//   ظيم_, ुछवि_, पॉइं, _канз
  { {0x127b0053,0xc27b000a,0x248d013f,0x6da61045}},	//   _באטע, _ברטי, šeme_, рида
  { {0xa3cb000b,0x3d10000b,0xefb2002b,0xcd270033}},	//   _रोड_, ़पें_, _ویرگ, ажце_
  { {0x9e66002b,0xdfd202be,0xdff50138,0x0000006a}},	//   _نارن, _بيس_, _лясь,
  { {0x501b000a,0x2b77002b,0x387f0034,0x80c40065}},	//   _סולו, شینگ_, esur_, रिवे
  { {0x28a6005e,0x79a3004a,0x98740da4,0xa8a61055}},	//   ашог, орье, блиц, арок
  { {0xf1bf0092,0x7aea0123,0x49b7002b,0x9cb30015}},	//   _cháy_, syft, شايد_, _ومفت
  { {0x07e60001,0xdb78000a,0x98130015,0xdcc90015}},	//   рцим, _תְּש, ْبَا, _حذفه_
  { {0x75d5003b,0xcf570008,0x8f7b0008,0x8b650015}},	//   ميدا, יבית_, כניק, _طالم
  { {0x26070036,0x98a61ff4,0x395f3190,0xba9b004f}},	//   рчог, _виде, ccus_, _יסבי
  { {0x25090086,0x69fb004c,0xf9fb000a,0x98a307d9}},	//   ارجی_, _בלאק, _בהאמ, _мице
  { {0x7792002b,0xc8fb000a,0xed590091,0xdb0321f0}},	//   _بیدا, _שִׁכ, _maža_, senå
  { {0xf8b6005d,0xa5c4005c,0xe8b6005d,0x3e480011}},	//   _अनुप, _spół, _अनुच, _eşti_
  { {0x41680001,0xd6db0008,0x33f40123,0xd712000b}},	//   ијум_, _יחול, _växa_, डपीठ_
  { {0xc0580010,0x657d3191,0x628e3192,0x3d10000b}},	// [6510] аіх_, mash, arbo, ़पों_
  { {0x4fd40036,0x59a6005d,0x1e1f000b,0x657d3193}},	//   ожут, क्तर, यक्ष_, lash
  { {0x63b5018c,0x1048005e,0x2cad00da,0x656f00bf}},	//   mezn, ряти_, _sped_, obch
  { {0x387f0026,0x657d3194,0x63b53195,0x4d880015}},	//   ysur_, nash, lezn, لَمُ_
  { {0x71d60008,0xfd100031,0x6b6501f3,0xdc98005e}},	//   _הורד_, وجه_, бкла, ивці_
  { {0xb47a004c,0xdb03006f,0xa4b8000a,0x29c30016}},	//   אָקי, menú, ילדה_, _ựa_
  { {0x3866001c,0x7a130045,0x63b5002a,0x657d3196}},	//   _ator_, lăti, iezn, kash
  { {0xf318000a,0xd90f002b,0xdb1a2db4,0xaa560015}},	//   יקוז_, ویا_, _antó, حليا_
  { {0x63b500dc,0x657d20eb,0x395f3197,0xacf500af}},	//   kezn, dash, rcus_, _упаљ
  { {0x31790014,0x657b001a,0x3862001a,0xdb01016e}},	//   _lesz_, ðuhn, íkra_, _salõ
  { {0xbbb3000b,0x87240015,0x63b53198,0xa3bd000b}},	//   ंजीक, ْعُم, dezn, ीएन_
  { {0x7bc10945,0xf3e9013a,0xd46a0ac6,0xe5a6004a}},	//   _halu, _אף_, лиме_, щими
  { {0x5a0a004c,0x7bc13199,0x25f90065,0x38cb00af}},	//   _גלײַ, _kalu, ॉफ़ी_, _јуен_
  { {0x09340029,0x03a60001,0xe3630956,0x37c40015}},	//   _برمج, љиво, зкри, _وينف
  { {0xe695003b,0xb7da013a,0x7bc1319a,0xc7d6000a}},	//   _العد, _תקצי, _malu, _לוסי_
  { {0x7bc10213,0xdb180030,0xe8620045,0x38660123}},	//   _lalu, ndvá, _înţţ, _ytor_
  { {0xe7ee005d,0x7a130011,0x00ca0010,0xe45f0123}},	// [6520] _चकमा_, găti, ылак_, lvön_
  { {0x5fd2000b,0x62950046,0x63b50046,0x2aa113c3}},	//   साइल, buzo, cezn, kób_
  { {0x683d0003,0x442a01d7,0x2c08002b,0x5436002b}},	//   cède, mob_, یعتی_, _پرکر
  { {0x7e6300dc,0x9cca0015,0x8236002b,0x7bc102f2}},	//   ínpa, ُواْ_, _درخا, _aalu
  { {0x628101b2,0x7c83034e,0x859b000a,0x9db90033}},	//   álov, пуще, רשנו, рыху_
  { {0x3ebd00f2,0x68f6005c,0x657d003f,0x8bc3006b}},	//   äytä_, _żydo, zash, зсъд
  { {0x2bb9014e,0x643b0053,0x7ac60256,0x91ba000a}},	//   _इसरा, װעקנ, ссле, ָמִי
  { {0x7ae50020,0x63b50e23,0x7bc3002c,0x6da314b7}},	//   ähta, zezn, adnu, _ниса
  { {0xe9180036,0x224c0089,0x657d1afb,0xa3bd000b}},	//   ропі_, ídky_, vash, ीएम_
  { {0x7bc1319b,0x657d06e8,0x60bb004c,0x1e8a000a}},	//   _galu, wash, נציד, ְרָֽ
  { {0x6e45002e,0xfa890036,0xdb0e00f2,0x63b5319c}},	//   _útbú, _всій_, äkäy, vezn
  { {0x61e60048,0xbb3b0053,0x7bc1319d,0x7c2a319e}},	//   _nokl, _געבי, _zalu, lofr
  { {0xd90e0086,0x200a003f,0xdce0003d,0x09360015}},	//   _سید_, _ombi_, _iemē, _اراج
  { {0xb05b01d1,0x63a9016f,0x442a0026,0xd91b000a}},	//   _kräv, đeno, gob_, _גודל
  { {0xa77b00b2,0x657d0297,0x61e60b56,0x63b5319f}},	//   _גרופ, pash, _bokl, rezn
  { {0x245d00a7,0x3f8e002e,0xe4d90086,0x7792002b}},	//   _tìm_, ófun_, _نوبت_, _بیگا
  { {0x62950089,0xf0bb002b,0x61e631a0,0x31790030}},	// [6530] suzo, دازش_, _dokl, _vesz_
  { {0xdefb0080,0x2f150010,0x5478000a,0xa3b0000b}},	//   лые_, одзё, _הגזע_, _टॉप_
  { {0x41c4005d,0x317900dc,0x9757000a,0x61e60160}},	//   _लोकस, _tesz_, ציאו_, _fokl
  { {0xa69b0053,0x660f28c9,0x569b000a,0xd0d5006b}},	//   רשאפ, nick, ריאצ, _домъ
  { {0x7bc121f6,0xdb1802de,0x200f0030,0x4c840033}},	//   _palu, ndvæ, égis_, злів
  { {0xdfdb010f,0x547c0053,0x660f31a1,0x5ba80033}},	//   _съм_, נטוו, hick, йкім_
  { {0x660f00c0,0xce940063,0x1a680086,0x7bc30b8e}},	//   kick, _наръ, میلی_, rdnu
  { {0xf865000d,0x7bc10ec5,0x7c670015,0x22f8000a}},	//   овио, _walu, _هائل, מזון_
  { {0x2aa10050,0x5c070010,0x660f31a2,0x7bc131a3}},	//   sób_, _ляжа, dick, _talu
  { {0xdb1a31a4,0xaf760053,0xa685006d,0x6e2b31a5}},	//   _zatí, ֿערס_, олод, logb
  { {0xae00005d,0x38ca0086,0x660f04af,0xcf920008}},	//   लोकन_, هایی_, fick, וטי_
  { {0xd62a0afa,0x660f0057,0x58d5017a,0xed590091}},	//   роме_, gick, _моет, _mažo_
  { {0x59840036,0x628502d2,0xb05b0012,0xddc9002a}},	//   _хліб, _avho, _kräu, _kieł
  { {0xd8740018,0x2b400046,0xd91a000a,0xdce9006f}},	//   _راهب, řice_, _דונל, _oceľ
  { {0xfbd20008,0x386d31a6,0xa34a006b,0x9a89000a}},	//   ותם_, lper_, рзва_, יָּ֗
  { {0x2cbf0264,0x799b1a5d,0xe676000a,0x442a31a7}},	//   _osud_, nguw, _ותקח_, sob_
  { {0x600a021a,0xe0da0aed,0x442a31a8,0x3fe62124}},	// [6540] анам_, шва_, pob_, ожав
  { {0xa91d002c,0x386d16fd,0xddc9002a,0xc5f9003d}},	//   mažd, iper_, _nieł, spēt_
  { {0x7a1304f9,0x91e631a9,0x2cbf007c,0x02460015}},	//   lătu, _доне, _asud_, _وَخَ
  { {0x10660058,0x0000006a,0x0000006a,0x0000006a}},	//   _وُجُ,   ,   ,
  { {0x5c730036,0x9d1a0015,0xb05b0012,0x5c970033}},	//   дліт, جزاء_, _bräu, жкія_
  { {0x200a0213,0xa3b0000b,0xf8b6000b,0xb05b0012}},	//   _umbi_, _टॉम_, _अनौप, _präv
  { {0xaab70021,0x386d31aa,0xdb1a31ab,0xd5ca000b}},	//   قدير_, eper_, _tatí, ियाज
  { {0xab5c0024,0xa91d0264,0x99840046,0x32db000a}},	//   _daļa, každ, romů_, שחקנ
  { {0xb7bc0048,0xbc6a0029,0x59a6000b,0x01fb004c}},	//   loģi, _ضمان_, क्षर, יפקל
  { {0xd90d0086,0xddc9005c,0x27f8002e,0x29180011}},	//   دیه_, _gieł, órn_, ăra_
  { {0x8cc2014e,0x660f0156,0x1f5b00a3,0xa3cb000b}},	//   लिको, tick, ידיא, _रोष_
  { {0x3dc61455,0x7d02002a,0x2ca6007c,0x35b20065}},	//   ndow_, ozos, otod_, ज़ग़
  { {0x7a1304f9,0xf8ad0074,0x7980003f,0xd7e602e1}},	//   gătu, _یکی_, mamw, _міко
  { {0xdc8b0447,0x889b000a,0xdb1802de,0x660f31ac}},	//   יְלָ, _כבדי, rdvæ, sick
  { {0x3d11005d,0x03c80010,0xf4340010,0x66730021}},	//   _देने_, цыяй_, ферэ, _قدير
  { {0xb05b0123,0x7a130045,0xf41f00d5,0xf2070033}},	//   _orät, bătu, erät_, цяго
  { {0xf8bc005d,0x7a130011,0xdcfb0085,0xdd1c006f}},	// [6550] ्टिय, cătu, _iduć, yššo
  { {0x62810089,0xe4530029,0x3ecb0054,0x2ca602f2}},	//   álos, _تضع_, ићем_, dtod_
  { {0x35d0005d,0xdd910029,0xdb180f3a,0xb3ba000a}},	//   _तोड़, فوا_, ndvä, _המתכ
  { {0xa91d016f,0x6281016f,0x25b90046,0xc0cb0054}},	//   laže, šlos, nesl_, _куге_
  { {0x61da000a,0x6e2b02de,0x3cf8002b,0x79800034}},	//   _הקרד, rogb, يعهد_, damw
  { {0xa91d0089,0x224931ad,0xab5c003d,0xa4bc000a}},	//   naže, lmak_, _paļa, שֶׁי
  { {0xf4140008,0x660d0607,0x1dc6000b,0xc3fc000a}},	//   ופס_, _omak, _रोकत, שלוש
  { {0x224901e2,0xa2cc005d,0xe9d90718,0x531c000a}},	//   nmak_, हित्, ски_, יווצ
  { {0x63a9010b,0x97d90015,0xa91d05ba,0xb05b0012}},	//   đenj, مبدأ_, kaže, _träu
  { {0xa3cb000b,0x9b880021,0x96b90054,0x386d31ae}},	//   _रोल_, _ونقل_, буму_, rper_
  { {0xf5290008,0x22490064,0xdb0a0b1c,0x09f70015}},	//   _עץ_, kmak_, gefä, _وأصد
  { {0x386d0aa0,0x60000123,0x8b3a000a,0x7a1300d4}},	//   pper_, _gömf, _התעצ, tătu
  { {0xdb1a002d,0xda080015,0x33d6005e,0x27e731af}},	//   _iatá, _بينه_, півт, _tonn_
  { {0xdb1a0014,0x33d50127,0x660d048c,0x3f8131b0}},	//   _hatá, міст, _emak, jahu_
  { {0x877a000a,0xc7b2000a,0xa77a000a,0xb7da000a}},	//   _האצי, _נבה_, _הרצפ, _לקסי
  { {0x8066042b,0x7a130045,0x26c2003d,0x91e31411}},	//   зваж, pătu, ākot_, носе
  { {0x859b0008,0xc5eb000a,0x6462002a,0xe3b20058}},	// [6560] _השפו, _הַיֹ, ówią, _كرد_
  { {0xa8560008,0x7f750010,0x683404ed,0xd9b8000b}},	//   פיעה_, дуцц, tàdi, _आस्ट
  { {0x4444010b,0x2ec60029,0x737701ac,0x59bd000b}},	//   _ih_, ثقاف, _מגיד_, ्यार
  { {0x72db0008,0xe1f20029,0xdca6009c,0x42db000a}},	//   _הקטג, _أسد_, зади, _הקטע
  { {0x444431b1,0xdb0a038f,0xab7c005e,0x2ca6007c}},	//   _kh_, ndfö, авлi, utod_
  { {0x0fda003b,0x61f600c0,0x78a400f2,0x7d0231b2}},	//   _ابحث_, lkyl, _äivi, rzos
  { {0x80c4014e,0x7528005c,0x1c390010,0xf236000a}},	//   रिके, ędzy, цяць_, ֔רֶץ_
  { {0xf99200e6,0xdb1a0a40,0xbf37004c,0xa91d00bc}},	//   ربع_, _catá, _זאלץ_, zaže
  { {0xfc640074,0xa967000d,0xa3df005d,0x6b560115}},	//   _آخری, чиња_, णाम_, _فضائ
  { {0x6d4003eb,0xdb030227,0x224931b3,0xdddc0046}},	//   _izma, lený, zmak_, _surň
  { {0xa91d016f,0x22490064,0x17f70015,0xda660021}},	//   važe, ymak_, ثرية_, _راضي
  { {0xaadb0008,0xdb03002c,0xaac2021e,0xdb180f3a}},	//   _לחבר, nený, _वैयक, rdvä
  { {0x44442533,0xa91d0046,0x0000006a,0x0000006a}},	//   _bh_, taže,   ,
  { {0x444431b4,0x764402f2,0xad1b000a,0x248d02d8}},	//   _ch_, _ehiy, מוכר, šemo_
  { {0x224901e2,0x883b0008,0xe2f9005e,0x523b0015}},	//   tmak_, _התגו, цеві_, مسرح_
  { {0x31c40036,0xa91d0089,0xdb030057,0x444431b5}},	//   нсув, saže, jený, _eh_
  { {0x224901e2,0xdb030227,0x3f8131b6,0x80c4000b}},	// [6570] rmak_, dený, tahu_, रिगे
  { {0xa7790053,0x61e41437,0xc0340054,0x34fc000a}},	//   ַרױפ, ajil, енуј, _להחד
  { {0x224901e2,0xe7ae005d,0xb05b079c,0x6d4000d9}},	//   pmak_, ज्यप, _präs, _azma
  { {0x3f8104af,0x661d31b7,0xdcf90015,0xb6bb000a}},	//   sahu_, nnsk, يفات_, מצבי
  { {0x8d28005e,0xcd2b0015,0xbc640033,0x3f81050b}},	//   поїв_, حسان_, евік, pahu_
  { {0xd0f6000a,0x027e0046,0x444431b8,0x7e610030}},	//   _חמשת_, říže_, _xh_, _élpo
  { {0x628731b9,0xdb030227,0x2ef50033,0x64570f21}},	//   nsjo, bený, _ўзбр, _mixi
  { {0xdce00091,0x60cd016e,0x3208000a,0xdb0331ba}},	//   _nemė, ovam, ּ֖הּ_, cený
  { {0x3a2d0384,0xdb0300dc,0x9f5a02c1,0xdddc0796}},	//   roep_, lenü, cipó_, _uvrš
  { {0x6287003c,0xddc9002a,0x661d31bb,0x6000203a}},	//   ksjo, _wień, ensk, _gömd
  { {0x3d11014e,0x4ac1005d,0x7c24002d,0x60cd007c}},	//   _देते_, _शनिव, éire, hvam
  { {0x444431bc,0xcb12000a,0x6b832ddf,0x60cd0085}},	//   _sh_, _בלב_, lang, kvam
  { {0xf992000a,0xf507033d,0x69d931bd,0xdd010046}},	//   _ירא_, днял_, _inwe, _čtět
  { {0xdb030057,0xd455005e,0xdb0a0123,0x6b8331be}},	//   zený, етсь, rdfö, nang
  { {0x82a30036,0x64570493,0xe1620033,0x24890061}},	//   карж, _dixi, вязi_, _evam_
  { {0x13a80086,0x24440123,0x64570144,0x69c931bf}},	//   _کندی_, döme_, _eixi, ndee
  { {0x44440041,0x64570334,0xdb030227,0x14260004}},	// [6580] _th_, _fixi, vený, _одим
  { {0x39110053,0x61f6158b,0x6b830375,0x6d5b0f9f}},	//   לטאַט, skyl, jang, _agua
  { {0x78a90198,0xdb031226,0x68110089,0x63bc12d7}},	//   htev, genü, mědě, mern
  { {0xb05b00f2,0x40960036,0x6b8331c0,0xdd8f0031}},	//   _isän, _оргт, eang, لوم_
  { {0xdb0912c3,0x91bb0008,0xdbc60020,0xdb030a52}},	//   čnýc, _ומכי, _mööb, rený
  { {0x69d913fd,0x69c9016b,0x0a6a009f,0xfbcf0015}},	//   _anwe, edee, ории_, لتى_
  { {0x629c0007,0x6d40002a,0xf41f008c,0x2417000a}},	//   nuro, _wzma, ksän_, וחסן_
  { {0x63a9016f,0xdb1800dc,0xa3b0000b,0x9f5a02b9}},	//   đeni, nevé, _टॉस_, cipò_
  { {0x80c4005d,0x6d40286c,0xdb1a001c,0xdb0a0152}},	//   रिटे, _uzma, _antô, iffé
  { {0xddc90024,0x69d90026,0xdb180003,0xbb86002b}},	//   _cieņ, _enwe, hevé, _آلاي
  { {0x2f970008,0x06150080,0x9f97000a,0x7bc80045}},	//   וכין_, едню, ודיה_, _iadu
  { {0xb4950001,0x629c0026,0x2813002b,0x64570003}},	//   нимљ, duro, _یونس, _sixi
  { {0xe9f70191,0xa3cb005d,0x63bc31c1,0x7bc831c2}},	//   _інші_, रएल_, fern, _kadu
  { {0x63bc00fb,0x7bc800d9,0x62951ed9,0x493b000a}},	//   gern, _jadu, trzo, _וגדו
  { {0x64540001,0xa5f90001,0xe4540080,0x545400d7}},	//   тврђ, _неку_, ткры, тврт
  { {0x6287003c,0xf1bf00dc,0x60cd0aee,0x66270015}},	//   rsjo, _akár_, tvam, _ترتك
  { {0x9099010f,0x40590029,0x7bda0011,0x63bc31c3}},	// [6590] яват_, سلاح_, _ontu, bern
  { {0x7bc8005c,0x628721ce,0x6d5b02b9,0x60cd31c4}},	//   _nadu, psjo, _sgua, rvam
  { {0x040e0092,0x238a002c,0x6b832ba3,0xb05b008c}},	//   hườn, šujú_, vang, _eräp
  { {0x600000b8,0x7bda31c5,0x6b830553,0x24440012}},	//   _röme, _antu, wang, röme_
  { {0x6b8331c6,0xee38005e,0xeb8e2b2c,0x7bc831c7}},	//   tang, єні_, ли_, _badu
  { {0x9f6500f2,0x6b8331c8,0x28d2000b,0x0cbf000b}},	//   ätät_, uang, तिनि, _एनीम
  { {0xfb84008f,0x7bc800b8,0xdd950010,0xeab10002}},	//   тычн, _dadu, _павы, اعت_
  { {0x44310014,0x78a931c9,0xaa560001,0x6d5b04ed}},	//   hoz_, ttev, нију_, _ugua
  { {0xf8c80023,0xddc90048,0x0ff3000b,0x6b8331ca}},	//   _cứ_, _pieņ, _आकाश_, pang
  { {0x600000dc,0xf7710029,0xd7090088,0xb902005e}},	//   _töme, داة_, зное_, узьк
  { {0x68110089,0xc9590015,0xdb03002a,0x26d131cb}},	//   vědě, _فلاش_, renó, ízo_
  { {0x7bc82737,0xdb01006f,0x63bc31cc,0x69d915f5}},	//   _zadu, _oblú, wern, _unwe
  { {0xd8b80015,0x63bc310c,0xcdf6004f,0xa988004f}},	//   _يدها_, tern, גמרי_, _חָצִ
  { {0x1d160008,0xd7c9002b,0xdcfb0fde,0x629c31cd}},	//   תקשר_, _روبه_, _neuč, turo
  { {0xed590024,0x04430063,0x2612006f,0x63bc31ce}},	//   _daži_, уерн, lšom_, rern
  { {0xe1ff002d,0xb05b0b14,0xd5e90015,0xdb0a0003}},	//   _cló_, _präp, _يعين_, uffé
  { {0x361b0008,0xa3cb005d,0xf8c80092,0x443100dc}},	// [65a0] _מוקד, _रोक_, _xứ_, boz_
  { {0x7e7c0026,0xb05b00f2,0xd9bd0065,0x4477004f}},	//   _pwrp, _isäl, ्युट, _רעיל_
  { {0xfe720029,0x539b000a,0x7bc831cf,0x399a0061}},	//   ادئ_, _ציטו, _radu, nüsü_
  { {0x97560008,0x9cca054f,0xdd92002b,0x60db1c4e}},	//   גיעו_, зыка_, اوش_, _šume
  { {0x6b8131d0,0x51550033,0xdce0003d,0x7bc831d1}},	//   _belg, _атру, _iemī, _padu
  { {0x22590227,0x6a670061,0x2ac60054,0x399a0061}},	//   _zisk_, _sıfa, ељив, küsü_
  { {0x59d1005d,0xd9bd005d,0xf8c80092,0x09bd000b}},	//   _दोहर, ्यूट, _sứ_, ्यूय
  { {0x7bc800e8,0x49ba00a2,0x6b810079,0x6aaa0034}},	//   _wadu, ساعد_, _eelg, rtff
  { {0x0c3a0029,0x7bc8003f,0x57a6006b,0x9c2601f3}},	//   _فكرة_, _tadu, ншна, _здад
  { {0x040e0092,0x7bda013c,0xdb0a0293,0xf093000a}},	//   rườn, _untu, kefø, ננת_
  { {0xa7de002c,0xa91d02c6,0xa3cb000b,0xf76f0021}},	//   _kľúč_, raža, _रोग_, حاً_
  { {0x63a5018b,0xf8c80092,0xceb3000a,0x8afb000a}},	//   _schn, _tứ_, ניר_, _מהבי
  { {0x22592084,0x63a5002a,0x35f40033,0xe61f016e}},	//   _risk_, _pchn, упяр, rnô_
  { {0x97c60015,0xe1ff001a,0xe3b0002b,0x2c34000a}},	//   _ستتم, _sló_, یرۀ_, דָֽם_
  { {0xf6d30015,0xed590085,0x1837000a,0xdb0a02de}},	//   _مزيد, _važi_, _ראול_, gefø
  { {0x9adb000a,0x644e31d2,0x28b7000b,0x7ae50601}},	//   החלט, ambi, _अहमि, ähti
  { {0x64a4009c,0x63a5002a,0x60db0046,0xb03503de}},	// [65b0] _бања, _tchn, _šumb, внаш
  { {0x7fb90115,0x23790015,0x88bb000a,0x0000006a}},	//   ظهار_, _تمدد_, הזמי,
  { {0x93f4008f,0x225931d3,0xfbdf0016,0x62880030}},	//   _спэц, _tisk_, _đê_, ádot
  { {0xdd950010,0x2eee00c0,0x6b8131d4,0xff280015}},	//   тады, äffa_, _selg, ركني_
  { {0xed4e0191,0x6b811f42,0x23eb004f,0x0cd400ce}},	//   ро_, _pelg, ּחֶ֣, лоцю
  { {0x52740086,0x629a00dc,0xd116000a,0xeb990555}},	//   _جایز, átog, _יקרה_, фик_
  { {0x6b8106f5,0xe9d10029,0x63a3002e,0x60080008}},	//   _velg, لغة_, _önnu, _נִשְ
  { {0xf2d40053,0x9f34017f,0x26120085,0x8d77006e}},	//   רעק_, _сесі, ašoj_, _سارا
  { {0xbb850015,0x3f8301d7,0x6c5531d5,0x97bd0033}},	//   _للذي, _keju_, _акау, орнi
  { {0x29030007,0x1c570015,0xd876002b,0x399a0061}},	//   ąja_, _أخرج, کمیت_, tüsü_
  { {0xfdf5000b,0xd62a19a5,0x0000006a,0x0000006a}},	//   _आवास_, доне_,   ,
  { {0x0594002b,0x24440123,0x3f83003d,0x399a0061}},	//   دادگ, döma_, _leju_, rüsü_
  { {0x47c50010,0xe9f8005e,0xa91d31d6,0xa3ae0065}},	//   _аблв, _янці_, mažo, ओऍल_
  { {0xccf20008,0xd37200e5,0x3944005e,0x96f90015}},	//   סכם_, شهر_, _сніг, _يعثر_
  { {0x644e0293,0x0367110d,0x69cb31d7,0x216a005e}},	//   rmbi, тиск_, _kage, диби_
  { {0xdb0a04d1,0x69cb31d8,0x0000006a,0x0000006a}},	//   refø, _jage,   ,
  { {0xed59016f,0x59a6005d,0xaffa0015,0x85ba002b}},	// [65c0] _kažu_, क्टर, وفرا_, _فاکس_
  { {0x62880046,0x749b000a,0x69cb31d9,0x51550058}},	//   ádos, _קייפ, _lage, ائِز
  { {0x0d8631da,0x61ef002d,0xdfcf0021,0x1fb50088}},	//   влен, _focl, تيل_, ыстр
  { {0x35aa005d,0xbf22000b,0x1bfa000b,0xa91d09df}},	//   _काफ़, _मशीन_, ऍसऍल_, važn
  { {0x38ab003c,0xdca303ad,0xa1160067,0x35d9000b}},	//   jør_, иаци, _شوست, _बोफ़
  { {0x9e760086,0x38ab04d1,0xa91d31db,0xab5c01ec}},	//   _لهست, dør_, tažn, _kaļi
  { {0x39401ce1,0xdee30cec,0x0b180015,0x6ac30015}},	//   _šis_, _кори, عقبة_, لقوم
  { {0xddc9005c,0x38ab079b,0xfe46005e,0x9f550030}},	//   _mieś, før_, _рнбо, _áfát_
  { {0x61eb00b8,0x38ab0134,0x69cb1d76,0x656d0012}},	//   ögli, gør_, _dage, _rfah
  { {0x69cb003e,0xa7740080,0xdb180ce7,0xa91d0046}},	//   _eage, ылоч, leví, mažl
  { {0xed590024,0xf1bf002c,0xe7e3000b,0x9f9b000a}},	//   _dažu_, áške_, _कचरा_, וסיפ
  { {0x1af70008,0xa3cb000b,0x28d2000b,0x60c40573}},	//   _שמאל_, _रोज_, तिदि, kwim
  { {0x3940002d,0x98a30fea,0x69c031dc,0x08fa0015}},	//   _áis_, _виче, meme, _تراب_
  { {0x69c031dd,0x58f7000a,0x8434005e,0x69cb06a8}},	//   leme, _במדע_, иняє, _zage
  { {0xe8e00023,0xdb18001c,0x2458004a,0xcc880016}},	//   _đội_, levâ, тарь_, hớ_
  { {0xd9e5005d,0x69c031de,0x59a6000b,0xdb180046}},	//   कायत_, neme, क्चर, jeví
  { {0x518431df,0x25d8000a,0x69c031e0,0x629a0144}},	// [65d0] руса, _יוהן_, ieme, àtor
  { {0x75380008,0x2612002c,0xa4b6000a,0x69c00220}},	//   _באחד_, yšok_, _עלתה_, heme
  { {0x69c031e1,0xf1ab000b,0x7415002b,0x33f40123}},	//   keme, _छापन, _لوکا, _växt_
  { {0x78a00024,0x69c000e8,0x8d740086,0x42fa000a}},	//   kumv, jeme, لاها, _נהרס
  { {0xc19a01ac,0xa91d0057,0x1d34005e,0xacf90033}},	//   _אשרי, važo, анця, энду_
  { {0x60da0053,0xb4fc0008,0x5f74002b,0x69cb31e2}},	//   _אַלג, ופדי, _نافر, _sage
  { {0xa91d00df,0x69cb31e3,0xa2c9000b,0x69c00003}},	//   tažo, _page, _हैम्, feme
  { {0x683d0251,0x38ab0293,0xb05b0123,0xd35c000a}},	//   mèdi, tør_, _osäk, ודול
  { {0xdd030024,0xf1ab000b,0xd876002b,0x0000006a}},	//   ārēj, _छानन, هميت_,
  { {0x2d840a7e,0xfbc0000b,0x95fe000b,0x1e95000a}},	//   _zeme_, _एसएम, ॉफ्ट_, ְכָל_
  { {0x2d841f9a,0x248000da,0x69cb31e4,0xe61a0883}},	//   _yeme_, _swim_, _tage, едн_
  { {0x7ae50020,0x69c031e5,0xae19000a,0x8afa05bd}},	//   ähtu, ceme, תוֹכ, _אלעז
  { {0xb9080087,0x99d4002b,0xb17b0123,0x0000006a}},	//   _لزوم_, _ختلا, _onåb,
  { {0xb8920029,0xddc9005c,0x389a00a3,0x59bd000b}},	//   _الوع, _pieś, _ניצנ, ्यकर
  { {0x3ea10020,0x75d60015,0xf7490015,0x232709ac}},	//   juht_, _ميغا, _ثلثي_, гори_
  { {0x442300bd,0xbbc0000b,0x60db31e6,0x35a60054}},	//   anj_, _एस्क, _šuma, _саиг
  { {0x6604000c,0x998d005c,0xc0e324f9,0x64c60015}},	// [65e0] _ilik, mień_, ботк, _صيدل
  { {0xdee61797,0x7f86012c,0xdb03007c,0xa5bb0030}},	//   лози, الان, lenõ, nnón
  { {0x69c031e7,0xdb180046,0x660431e8,0x683d0144}},	//   yeme, teví, _klik, gèdi
  { {0x831b0053,0x69c00251,0xc1760029,0xa91d0046}},	//   _טויז, xeme, _حددت, tažl
  { {0x645e000c,0x69c00493,0x224031e9,0x90460015}},	//   _kipi, veme, mlik_, _منحه
  { {0xbe860086,0xbc6700e6,0x3e860015,0xc27a000a}},	//   _مجرو, دمون_, _مشرف, ֲרִי
  { {0x660401d1,0xc0030001,0x69c031ea,0x6e2201d7}},	//   _olik, _упрк, teme, pnob
  { {0x6ca60029,0x224028c2,0xa9c3005e,0x200f003d}},	//   _مصطل, nlik_, бськ, īgie_
  { {0x69c031eb,0x2df70008,0xf98f0015,0xcdf7000a}},	//   reme, _עצמך_, سبي_, _עממי_
  { {0x201a0035,0x66040705,0xd8b70015,0x443a31ec}},	//   nipi_, _alik, اديا_, _nkp_
  { {0xf1bf002c,0x103705af,0xa01b002e,0xdab70086}},	//   ššie_, רטים_, _kvör, _مهلت_
  { {0x0f570008,0x56930a61,0xcf57000a,0xdd86002b}},	//   טיים_, щают, טבית_, غو_
  { {0x2240187b,0xe872002b,0x74150015,0xdb180144}},	//   dlik_, _انتگ, لوحا, levà
  { {0x36d40080,0x645e31ed,0x60000123,0x224031ee}},	//   _вокр, _cipi, _sömn, elik_
  { {0x57fb0008,0x28d2005d,0x660429c6,0xdb03007c}},	//   _אלגו, तिवि, _flik, benõ
  { {0xdb0a31ef,0xbb3b0053,0x224000dd,0x44f517bd}},	//   lefó, געלי, glik_, _впис
  { {0x30150d56,0xf3f10092,0xa3b0005d,0xcf9b0001}},	// [65f0] адар, ự_, _टॉक_, еје_
  { {0x629a002c,0x2ba4005d,0x645e0a4c,0x9474002b}},	//   átoc, _ऑफ़ला, _gipi, _اديا
  { {0xdb0a00b8,0xdd910029,0x224031f0,0x6604008c}},	//   gefü, قوا_, blik_, _ylik
  { {0x067b0053,0x3ea100b8,0x248d31f1,0x7c3a0213}},	//   גנאל, ruht_, šemu_, _aktr
  { {0xa3c9000b,0x0d840033,0xfce531f2,0x65a8000a}},	//   _ईसा_, слін, роло, א֣וּ_
  { {0x683d08e0,0xb09a0008,0x9aa50029,0x0c240036}},	//   pèdi, _בישר, لمتو, бмін
  { {0x6d9c002c,0x5fce000b,0x61ed31f3,0x0000006a}},	//   _sťaž, _होटल, ojal,
  { {0x48b50063,0x5c75012e,0xe9d910b7,0x61ed31f4}},	//   ащот, _влат, тки_, njal
  { {0x79890026,0xdb030003,0x6e3b02f2,0x61ed1075}},	//   raew, igné, _ikub, ijal
  { {0x998d005c,0x61ed0209,0xa3d4000b,0xddc20046}},	//   wień_, hjal, _सों_, dmoř
  { {0x660431f5,0x645e02b9,0xcb35006b,0xdb350054}},	//   _plik, _ripi, _тежъ, _тежњ
  { {0x7bc310cc,0x645e1640,0x5ee8000a,0x8f36000a}},	//   lenu, _sipi, אַשְ, יאתו_
  { {0x6e3b003f,0x9f4a002c,0x645e043a,0x6c79004c}},	//   _mkub, _robí_, _pipi, כאָפ
  { {0x7bc30020,0xdb1800dc,0x46f509a7,0x998d005c}},	//   nenu, levá, _вчит, sień_
  { {0x645e000c,0xdb0a0251,0x998d005c,0x2ba9000b}},	//   _vipi, lefò, pień_, ग़्या
  { {0x61ed002e,0x6d490012,0x20b3000b,0x660431f6}},	//   gjal, _ozea, ुबंध, _ulik
  { {0x7bc31581,0xa0a610cb,0x68fb01d7,0x224031f7}},	// [6600] kenu, разд, nyud, rlik_
  { {0x6aa300b8,0xa01b002e,0xdfcf0031,0x224031f8}},	//   kunf, _svör, ويق_, slik_
  { {0x63a1005c,0x7c24002d,0x639b000a,0x2ba9000b}},	//   ólne, éirm, _בסינ, च्छा
  { {0x61ed0050,0x7bc30020,0x44380939,0x80c1000b}},	//   cjal, eenu, lor_, _रैके
  { {0x44380991,0xe589000a,0x7d970484,0xcbe6004a}},	//   oor_, רָעָ, рвіс_, ицки
  { {0x2c6b0293,0x14d7000a,0xab77012c,0x443806d7}},	//   _død_, יונל_, لمها_, nor_
  { {0xaa6304f7,0x2ef8000a,0x2bc5000b,0x2612006f}},	//   отык, _גִּב, लज़ा, lšou_
  { {0x443831f9,0x929b000a,0x7bc3007c,0x28d2000b}},	//   hor_, דיקת, aenu, तिलि
  { {0x443831fa,0xed5705c4,0x5d9b000a,0x6a130015}},	//   kor_, _вот_, _שבמה, تبور
  { {0x443803b0,0x61ed002a,0x656401c2,0x764d31fb}},	//   jor_, zjal, _agih, _shay
  { {0xb05b0012,0x7c38006f,0x443831fc,0x7e6020bd}},	//   _präz, movr, dor_, _kimp
  { {0x7a8b0008,0x6b88065b,0x8afb000a,0x7af70123}},	//   _יָדַ, _hedg, _שהאי, äxte
  { {0x5e570053,0x2612002c,0x998b002c,0x85470033}},	//   ייטע_, jšou_, ôcť_, рэне
  { {0x3cee005d,0x7e6031fd,0x443831fe,0x7c3831ff}},	//   _आपने_, _limp, gor_, novr
  { {0xd838018c,0xe694003b,0x61ed0020,0x3f87002e}},	//   moč_, _البد, tjal, ðnum_
  { {0x66730029,0x764d003f,0x201802e8,0xd7a6000b}},	//   _بدور, _uhay, _amri_, _खाँच
  { {0xc9530053,0x2f8b0001,0xa4d9005e,0x7c3807c4}},	// [6610] ַמע_, вљен_, _сдпу_, kovr
  { {0xe53c0008,0x61ed0020,0x2c6b0293,0x44383200}},	//   _בתחר, sjal, _rød_, cor_
  { {0xe8e00023,0x61ed002e,0xc058005e,0x7bc30376}},	//   _đời_, pjal, ріт_, venu
  { {0x20180061,0xb05b0123,0x9757000a,0x661d3201}},	//   _emri_, _späd, ביבו_, nisk
  { {0xbc19008f,0x6d400026,0x3d11005d,0xd83800bc}},	//   лікі_, _cyma, _देखे_, koč_
  { {0x00f60008,0x8e770086,0xd83800bd,0x661d3202}},	//   _המשך_, _نارض, joč_, hisk
  { {0x7d060020,0xa91d0007,0x661d3203,0xfbd00015}},	//   _üksn, maži, kisk, بتن_
  { {0x6e3b3204,0x1dcf005d,0xa3d9005d,0xc212000a}},	//   _ukub, _सोचत, _ठोस_, ּ֔ה_
  { {0x6d400026,0xfb850086,0x443817e3,0x7bc30375}},	//   _gyma, _هدای, yor_, penu
  { {0x30da0053,0xb8cf000b,0xfe99000a,0x661d0091}},	//   אַטע, _ओम_, ְיָמ, eisk
  { {0x661d3205,0xc4c9000a,0x98b8003d,0xcb680015}},	//   fisk, _רג_, ārā_, _ضمنه_
  { {0xdb01002d,0x99d40015,0x2cbf01d7,0x89d40015}},	//   _gclá, _وتنا, _kpud_, _وتنط
  { {0x5a0c00b2,0x4dda0008,0xe9450086,0x44383206}},	//   _בלאַ, אחרו, _ارای, tor_
  { {0x96f900a2,0x35ac000b,0xf7850015,0xca6b00ce}},	//   _معبر_, ट्ज़, _الثَ, _пiдi
  { {0x98140015,0x44380ebc,0x91e60585,0x661d3207}},	//   _ببنا, ror_, бове, bisk
  { {0x63bb016f,0x7cde0011,0x661d3208,0xe1660015}},	//   đuna, _hărţ, cisk, صدري
  { {0x44380943,0xe1950033,0x7e603209,0x114a0174}},	// [6620] por_, юррэ, _rimp, упай_
  { {0x7e6900bd,0x60000123,0xa91d06c0,0x73c6002b}},	//   _čepr, _tömm, gaži, _ايدم
  { {0x8d1a0074,0x7e600375,0x62850034,0x7c380085}},	//   گزار_, _pimp, _gwho, vovr
  { {0x2612006f,0x15eb000b,0x998d00bc,0x6da6320a}},	//   pšou_, टायर_, elež_, сида
  { {0x7c38016f,0xc173000a,0x7fd6008b,0xdca306b5}},	//   tovr, _מחר_, _ліві, зачи
  { {0x6d40099c,0xcce50029,0x2bd2005d,0x9742016f}},	//   _vyma, تسمي, _धोखा, šćim
  { {0x6d400050,0x7e60320b,0xae78000a,0x501b000a}},	//   _wyma, _timp, _כְּת, _עולו
  { {0x52d70008,0x9a670029,0x187403fc,0x1e97000a}},	//   מוצע_, حميل_, огия, _לכלל_
  { {0x6d400064,0x7c2d002d,0xf8ad002b,0xd8380085}},	//   _uyma, éarc, نکو_, toč_
  { {0x7cde04f9,0x661d0050,0x76b80010,0xd0f7000a}},	//   _cărţ, wisk, алор_, צמית_
  { {0x442701e2,0xb05b00f2,0x21270092,0xd838320c}},	//   _ın_, _isät, ̃nh_, roč_
  { {0xd83800bd,0x6f090089,0x25ad0061,0xa96a012e}},	//   soč_, _řeck, üel_, _сида_
  { {0xd794006b,0xe4c7004a,0x661d0a3a,0xca37000a}},	//   _дилъ, щённ, risk, _פנדה_
  { {0x661d320d,0x1957000a,0xa5bb002a,0x3f8a0b28}},	//   sisk, _הבדל_, wiód, _nebu_
  { {0xdb1a00b8,0x96b70015,0x7a98000a,0xdb1802de}},	//   _natü, _هايز_, יֹּצ, sevæ
  { {0xdb1a0030,0x0697002b,0x2509009a,0x0000006a}},	//   _ható, _اخوت_, _نرخی_,
  { {0x60990086,0xf5b40029,0xdb180f7a,0x86080002}},	// [6630] شناس_, _رصيد, levä, _دقيق_
  { {0x31180015,0x5437002b,0x200705a4,0x3f671cc9}},	//   حتفظ_, _درعر, óni_, стаб
  { {0x8d790029,0xa91d320e,0x1048007a,0xdb18008c}},	//   لماء_, raži, сяти_, nevä
  { {0xdd94008f,0x8d870080,0xa01b00b8,0xf0750015}},	//   зацы, сужд, _zwöl, _وُجد
  { {0xa91d0007,0x2bb90029,0xda78002c,0xf36b000a}},	//   paži, لاثة_, _atď_, ְדֵּ
  { {0xdb1800f2,0x3a99004a,0xa5bb0030,0x4fc71092}},	//   kevä, атию_, niób, _усма
  { {0x93fc0053,0x39e90036,0xfbd00115,0x33fc004c}},	//   רלוי, идко_, عته_, רהונ
  { {0x05d9000b,0xaa560058,0x0000006a,0x0000006a}},	//   _बोलब, يلوا_,   ,
  { {0x7cde0011,0x09f60029,0x26dc0604,0x2d8f0493}},	//   _părţ, تفية_, _arvo_, mage_
  { {0x115c00b2,0x2ca0002f,0x39430024,0xdb1a0656}},	//   נדזע, áide_, ājs_, _cató
  { {0xfc300015,0xa5bb0030,0x65c61ab5,0x7e9c00d4}},	//   _أحق_, diób, обна, căpă
  { {0x36160036,0x2d8f0b62,0x26dc0085,0xb47f0046}},	//   ієнт, nage_, _drvo_, ěžný
  { {0x1959008f,0x893703c4,0xd9450004,0x67d50da4}},	//   _тады_, _اعضا, _ќели, _моду
  { {0x8d5a000a,0x58ba000a,0xa5bb0030,0xd8760015}},	//   יכרי, _כמנצ, giób, _بموت_
  { {0xe3630191,0x33630054,0x63a10030,0x7c240125}},	//   дкри, дврг, ólna, éiri
  { {0x21670185,0x2327005e,0x42071d8a,0x91e301d2}},	//   жити_, іоти_, онсо_, мосе
  { {0x61430165,0x2d8f320f,0xdb1a0061,0xf41f008c}},	// [6640] дета, dage_, _satü, tsät_
  { {0xa5bb00dc,0xdfa600a2,0x3fa60015,0xdb1800cb}},	//   ciób, تحري, تصرف, levå
  { {0x2d8f1426,0x2fd7012c,0xee3a00af,0xa91d0160}},	//   fage_, تولد_, анж_, mažu
  { {0x3f8a0107,0x5fac000b,0x2d8f21e0,0xadb70015}},	//   _webu_, _चावल, gage_, قهما_
  { {0xedd30015,0x61e628ac,0x7646001a,0x3f8a01d7}},	//   بيند, _inkl, ilky, _tebu_
  { {0x3e680086,0xe7ae000b,0x8bc3006b,0x7d06007c}},	//   _هجری_, ज्ञप, дсъд, _üksm
  { {0xe8e00023,0x3d1a005d,0x2d8f3210,0x7dc60015}},	//   _đối_, _मेरे_, bage_, _وترك
  { {0xddc3070c,0x2d8f1193,0xa5bb0030,0x0d860245}},	//   _обси, cage_, ziób, _флан
  { {0x1d070080,0xdb1a3211,0x2768002b,0x225e0046}},	//   _дети_, _catò, یشگی_, ítky_
  { {0x26dc01a3,0xa3d9000b,0xdb183212,0xdb0a0123}},	//   _prvo_, _ठों_, tevä, defö
  { {0x998d005c,0x45d53213,0xec130067,0x629a0030}},	//   nieś_, понс, _تولد, átol
  { {0x91da000b,0xe4e7005e,0x98e60015,0xda14002b}},	//   _पोलै, оігн, _وكاو, _عساک
  { {0xba1700c3,0x629a2f6b,0xdb183214,0x4a57004f}},	//   _بينا_, štol, sevä, _ושאל_
  { {0x998d005c,0x466a09a7,0xe947002b,0x87260015}},	//   kieś_, _крим_, _برمی, _وعثم
  { {0xf4850086,0x2d8f12f6,0x8a78000a,0x4b7b000a}},	//   _کابی, yage_, מָּק, שאלו
  { {0xceeb0086,0x96180029,0xba9b0053,0x1a9b004c}},	//   یران_, _وغير_, יסלי, יילע
  { {0x2d8f0493,0x3d1a000b,0x200a01d7,0x60f9004a}},	// [6650] vage_, _मेले_, _blbi_, щная_
  { {0xa91d0264,0xdfd10015,0xe8d7000a,0x2d8f00da}},	//   mažt, عيا_, חומר_, wage_
  { {0x644702c6,0x2d8f3215,0x99840091,0x9f5102b9}},	//   mlji, tage_, nomų_, _alzò_
  { {0x62950014,0x24890111,0xbdf80015,0x6235006b}},	//   mszo, _kwam_, يرنا_, _хему
  { {0x629500dc,0x11450029,0x4c840010,0x7cc70029}},	//   lszo, _رَسُ, длів, تزام
  { {0x60fa0008,0x99840007,0x644702c6,0x415a000a}},	//   _ההשק, komų_, nlji, _לדרג
  { {0x27e90016,0x6447001a,0x798b0034,0xdeb4004a}},	//   _đan_, ilji, _pegw, _обры
  { {0x600000b8,0xa91d0046,0x62950030,0x99840091}},	//   _römi, kažt, iszo, domų_
  { {0x644700bc,0xa925030c,0x2d8d3216,0x8cc80058}},	//   klji, ядил, _ieee_, _ووفق_
  { {0xaae70015,0x629512e0,0x798b0db6,0xb0c70138}},	//   _وساو, kszo, _wegw, спiс
  { {0xb8f2005d,0x2489163a,0x66e50010,0xa91d0107}},	//   _है_, _awam_, чона, važu
  { {0x4f160053,0x3aba000a,0xfa56002b,0x60cd0079}},	//   פֿין_, _למענ, _فرنگ, kwam
  { {0xa8790053,0x89d6002b,0x998d002a,0x45d30033}},	//   _פאַר, _روور_, zieś_, хоўс
  { {0x3cee005d,0xdd3a0008,0x64470844,0x387f0375}},	//   _आपसे_, מערכ, glji, mpur_
  { {0x629500dc,0x824a0015,0x9734002b,0x877a004c}},	//   gszo, مشرف_, _يکپا, _פאקי
  { {0xdb1200dc,0x249f0024,0xa69a000a,0x1658002b}},	//   égér, šuma_, _השקפ, _بستک_
  { {0x6447044c,0xf8bd000b,0xdb0a016e,0x68f6002a}},	// [6660] blji, ्बिय, lefô, _żydz
  { {0x13a80086,0xa3d4005d,0x62950030,0xe29a1293}},	//   _بندی_, _सोच_, bszo, _лао_
  { {0x0eb90010,0xdd920015,0x69c900aa,0x93fb000a}},	//   жучы_, فوض_, keee, _הליי
  { {0x7d060020,0xed5a0256,0x61e60012,0xf5d7000a}},	//   _üksk, бое_, _unkl, ּֽאת_
  { {0xdd8f0086,0x5c970010,0x16a8000b,0x1bd40238}},	//   اوه_, зкія_, _कम्ब, доля
  { {0xddc9002a,0x6e2b0c78,0x69c92470,0x0000006a}},	//   _cheł, angb, eeee,
  { {0xd90d002b,0x22420012,0xf1bf001a,0x671a000b}},	//   ییم_, _kkkk_, _sjái_, _फेंक_
  { {0x224201c2,0xf2d3000a,0x6447036d,0x7c660015}},	//   _jkkk_, תעה_, zlji, _فاطل
  { {0xe8e00016,0x62950030,0xdca30076,0xb8060015}},	//   _đồi_, zszo, _пати, كبده
  { {0x77920086,0xf6980054,0x6295002a,0x99840091}},	//   ریبا, овој_, yszo, tomų_
  { {0x64470a00,0x1b7b0008,0x4b7b0008,0x7bca06e8}},	//   vlji, _הטבע, _האבו, mefu
  { {0x6a1600e5,0x60cd002a,0x6e2221e8,0x7a160058}},	//   _عبار, ywam, niob, _عباء
  { {0x63a1005c,0x64470263,0x23e7005e,0x35470baf}},	//   ólno, tlji, півв, яхов
  { {0x629500dc,0x6aaa0003,0x389b000a,0xed5f006f}},	//   tszo, ouff, _פיונ, ížia_
  { {0xf7d7013a,0x67bb0008,0xd7bb0008,0x77bb0008}},	//   _מוגש_, _המוק, _הצור, _המוח
  { {0x644700bd,0x60cd002a,0x62953217,0xdb2301f6}},	//   slji, twam, rszo, érém
  { {0x62950014,0x859c0008,0x660d0035,0x85b800e5}},	// [6670] sszo, _השחו, _ilak, _رايس_
  { {0xc058005e,0xd818000a,0xd3710021,0x7d020061}},	//   піх_, קֵּש, _جهد_, dyos
  { {0x4423003f,0x03d6000a,0x6ac6000b,0x33fc000a}},	//   mij_, _חותם_, लबोर, _להזנ
  { {0xe0df0092,0x44233218,0x1eea002b,0x387f001a}},	//   _trò_, lij_, تومی_, ypur_
  { {0x865c000a,0xdfdb006b,0xeb8e05c0,0x9c590efb}},	//   צדדי, _лъв_, ки_, ошку_
  { {0xa01b002e,0x442305ce,0x73fb000a,0xcf270015}},	//   _stöf, nij_, מּ֔ו, _فرأي
  { {0x43780053,0x39460035,0x660d016f,0x80db000b}},	//   לײגן_, _ayos_, _olak, निवे
  { {0xaa560001,0x9dd5004c,0xadd40054,0x88e501b7}},	//   мију_, _קוּק_, _посљ, джие
  { {0xdcfb0086,0x63bc0026,0x88350010,0xde58005e}},	//   _ارزش_, yfrn, дэнц, _хаті_
  { {0x7bca003e,0x99dd01b2,0x22490375,0x660d3219}},	//   cefu, plňo, hlak_, _alak
  { {0x660d321a,0x6000001a,0x4423321b,0xe5a61119}},	//   _blak, _gömu, dij_, мини
  { {0x387f321c,0xfd07002b,0xbb3a000a,0x629a0085}},	//   ppur_, نج_, _ותעז, štok
  { {0x210100df,0xcd96000a,0x442300bc,0xf7f50015}},	//   nčią_, ודרת_, fij_, _يستد
  { {0x442300bd,0xb05b00c0,0x7c23156a,0x660d321d}},	//   gij_, _spän, ninr, _elak
  { {0xd7590029,0x660d0ab5,0xf6d5005e,0xc64a0015}},	//   _بلغت_, _flak, _ціля, _وجعل_
  { {0xa5bb0264,0x3a2d321e,0x0000006a,0x0000006a}},	//   lión, nnep_,   ,
  { {0x3cf9014e,0xc5eb011f,0x7bca003f,0x7e7c321f}},	// [6680] ्नों_, _וַיֹ, yefu, _strp
  { {0x4423018c,0x7d060020,0x7c2d002d,0x7d02003f}},	//   cij_, _üksi, éarl, vyos
  { {0x44443220,0xb05b00f2,0x224900dc,0x645c0012}},	//   _ik_, _epäo, blak_, mmri
  { {0xe9d90050,0xdca6004a,0x22db000a,0x42db000a}},	//   jdź_, дади, _וחטא, _וקטע
  { {0xcfaa0015,0x62a3003d,0x7bca3221,0x44443222}},	//   _واسم_, īvoš, tefu, _kk_
  { {0xe9d9002a,0x98b10046,0xaab401f3,0x7c23001a}},	//   edź_, ůběh_, ейкі, ginr
  { {0xa06709e8,0x7bca0ab5,0xeaaf0015,0x5f060033}},	//   _цара_, refu, لعي_, _ўзба
  { {0x44443223,0x44233224,0x35aa000b,0xd5aa000b}},	//   _lk_, zij_, _काग़, _कागज
  { {0xeb9a0083,0xfc2a006b,0x7bca0e39,0x44443225}},	//   _миа_, _джак_, pefu, _ok_
  { {0x31570053,0xa5bb002c,0x6b560002,0x3cfb000a}},	//   ויפן_, gión, _قضائ, _ולמנ
  { {0xe8e000a7,0xf7950086,0xf76f0015,0xfc170067}},	//   _đổi_, رچوب_, جاً_, _تقلب_
  { {0x444405cc,0x2fd80011,0x29d40015,0x442306ed}},	//   _ak_, _larg_, _سيتس, wij_
  { {0x22490409,0x44443226,0x44233227,0x9f58063d}},	//   vlak_, _bk_, tij_, _doré_
  { {0x68e200dc,0x249f0007,0xa5bb3228,0x24440123}},	//   _irod, šumo_, ción, döms_
  { {0x44440134,0xdb1a0089,0x8c1b000a,0xe2f9005e}},	//   _dk_, _obtí, קולי, чеві_
  { {0x35f80029,0x44443229,0xe707002b,0xb05b008c}},	//   _يريد_, _ek_, _تسهی, _epäl
  { {0xa2d3000b,0x44230885,0x2249322a,0xd1080015}},	// [6690] डिङ्, pij_, rlak_, وقفه_
  { {0x224912e2,0xf1bf0030,0x93470058,0x11540138}},	//   slak_, _aját_, _يخدم, ткую
  { {0x7c2d002f,0x670e000b,0x7c230003,0xfe700021}},	//   éarm, ानिक_, vinr, لدن_
  { {0xdd9b0036,0x68e2322b,0x1cb90029,0xa01b2749}},	//   іше_, _orod, كاتب_, _stöd
  { {0x30790053,0xdb0901b2,0x4444099a,0x61fd0125}},	//   _מאָנ, čníc, _yk_, _iosl
  { {0xe9d90050,0x60c0007c,0x7c840033,0x2c7b00d4}},	//   wdź_, _ämma, туце, _râdă_
  { {0xaa450054,0xbb422354,0x68e213b3,0x7c232643}},	//   некл, лешк, _arod, rinr
  { {0x61fd0048,0xf8af0086,0x7c2300c0,0xe7d7000b}},	//   _josl, لکت_, sinr, _भोजप
  { {0xa8050c30,0xe9d9002a,0xd258000a,0xb8d60015}},	//   езпл, rdź_, ושהה_, فويض_
  { {0x68e210ec,0x0aeb0015,0x22400085,0x8c19006e}},	//   _drod, _وراي_, zoik_, _عيار_
  { {0x999100dc,0xaab40029,0x44440020,0xf6261dc9}},	//   őző_, _لإنش, _rk_, едно
  { {0x61fd0024,0xe6120087,0x4444322c,0x6445013c}},	//   _nosl, اشد_, _sk_, _akhi
  { {0x68e2322d,0x4444322e,0xddce0091,0xa907002b}},	//   _grod, _pk_, _subū, _تبان
  { {0x78bb002e,0xf8b20008,0x7e69322f,0x6fc1000b}},	//   mtuv, _עשו_, _liep, र्मू
  { {0x2456002e,0x78bb0209,0xa5bb047e,0x425606a6}},	//   væmd_, ltuv, gnós, етат
  { {0x7e690050,0x471a0008,0x78bb0007,0x171a000a}},	//   _niep, _מוצג, otuv, _מוצע
  { {0x69d9003f,0xb05b008c,0x61f63230,0x78bb3231}},	// [66a0] _mawe, _epäm, rjyl, ntuv
  { {0xe53b0008,0x69d92eec,0x44442366,0xd046002b}},	//   _מתפר, _lawe, _uk_, رپاي
  { {0x93b70008,0x2904005c,0x78bb0607,0xdb030123}},	//   _אליו_, zyma_, htuv, ngnä
  { {0xf1bf032c,0x127b0053,0xc27b0008,0x7e69005c}},	//   íšte_, _מאטע, _מרטי, _ciep
  { {0x10160010,0x9597000a,0xdcf7002b,0x7e693232}},	//   _зьвя, תכנו_, فروش_, _diep
  { {0xf5370053,0x2ca61a0f,0x0000006a,0x0000006a}},	//   ענסי_, rrod_,   ,
  { {0x68e2016f,0x6da6012e,0x69d90dbc,0xada61466}},	//   _srod, _пива, _bawe, _павл
  { {0xdb1f0089,0xcb0700e6,0x48aa0c9a,0x2ca6050b}},	//   ávát, عيين_, птом_, prod_
  { {0x39770029,0x69d93233,0x20070012,0xdd8f0015}},	//   رصيد_, _dawe, önig_, _دوق_
  { {0x4c9b0008,0xdc9b0008,0x6253016e,0x2b16004a}},	//   _משמע, _מסמכ, içoa, _пьер
  { {0xa493002b,0xdc3b004c,0x68e2002a,0x32090061}},	//   گیخت, _צעבר, _wrod, ykay_
  { {0x7bda000c,0xceb30053,0x68e23234,0x4b37000a}},	//   _hatu, װיש_, _trod, _ארבל_
  { {0x68e2005c,0x7bda3235,0x61fd3236,0xb05b05ff}},	//   _urod, _katu, _rosl, _späm
  { {0x7d060020,0x672b00dc,0x69d9003f,0x78ad0227}},	//   _üksu, áljá, _zawe, ňový
  { {0x69d9000c,0x236500c0,0x7bda3237,0x45f90015}},	//   _yawe, älj_, _matu, _يفتح_
  { {0x320902f2,0x7bda3238,0x0000006a,0x0000006a}},	//   ukay_, _latu,   ,
  { {0x7e691b98,0x1fa70c71,0x0596002b,0x25d8004c}},	// [66b0] _riep, ерег, _شايگ, _טוהן_
  { {0x6d5d002d,0xb4bf000b,0xbfd8005e,0xb6040046}},	//   _úsai, ीबी_, ндує_, rmář
  { {0x7e690048,0x4fc4008f,0x3f91016f,0x42990015}},	//   _piep, ыста, _vezu_, _تنجح_
  { {0x867b000a,0x78bb0091,0xb5fb0030,0x7c9500c3}},	//   פרדו, ytuv, lmáb, نشتا
  { {0xddc00011,0xf53f01f0,0x7bda3239,0x629a0057}},	//   _simţ, mgås_, _batu, átov
  { {0x80ca000b,0x99dd0046,0xfaa511ea,0x7bda323a}},	//   _सैटे, plňk, вако, _catu
  { {0xf7710074,0x69d90647,0xdce9006f,0x629a25b6}},	//   یاد_, _pawe, _udeľ, štov
  { {0x9f5804ed,0x78bb0604,0x8d740015,0xe969006b}},	//   _morì_, ttuv, _ماكا, майл_
  { {0x7bda323b,0x290b002c,0x78bb0a6d,0xb3b2000b}},	//   _fatu, áca_, utuv, _जालख
  { {0x69d9000c,0x7bda0c3d,0xd7090892,0x6bd40002}},	//   _wawe, _gatu, дное_, _متمر
  { {0x78bb0458,0x69d90026,0x1bfa004c,0xa755006b}},	//   stuv, _tawe, _קלעב, ътищ
  { {0x78bb003d,0xba740021,0x69cb0046,0xb0ac0065}},	//   ptuv, _صامت, íneč, टूँग
  { {0x7d060020,0x7bda003f,0x59da000b,0x7989323c}},	//   _ükst, _yatu, _मोटर, mbew
  { {0x33d5022a,0xa2a6000b,0x79890654,0x0000006a}},	//   ліст, _छिद्, lbew,
  { {0xd4670124,0xf62a0029,0xb05b008c,0xdb0e0030}},	//   тире_, _يسعى_, _epäk, őköz
  { {0x7989059b,0x44310012,0x78a901f9,0xd1320369}},	//   nbew, anz_, orev, لمز_
  { {0xf99200b4,0x41270403,0xad9d002a,0x78a92b33}},	// [66c0] ירן_, вото_, _moźd, nrev
  { {0xc0e3005e,0x1005005e,0x79890012,0xdee62925}},	//   шоук, ляєм, hbew, кози
  { {0x78a90111,0x79890079,0xa01b0012,0x639b000a}},	//   hrev, kbew, _stöc, _קסטנ
  { {0x7bda323d,0xd337000a,0x9cca0033,0xf53f05bf}},	//   _satu, _יריה_, дыка_, mgår_
  { {0x10a30036,0x7bda323e,0x1cb7006e,0x8cb70058}},	//   _киян, _patu, ناوب_, ندوس_
  { {0x2ac60001,0x62531352,0xaa8504b2,0xa5bb0030}},	//   вљив, nçon, zmýš, giój
  { {0x3cee005d,0x63a1005c,0xbab30015,0x79890012}},	//   _आपके_, ólni, لصيغ, fbew
  { {0x7bda000c,0xc3330135,0x58d803fc,0xe9e3005e}},	//   _watu, יוו_, едия_, ацьо
  { {0x5cc50015,0xd83a0033,0xbc660098,0x9f58323f}},	//   _مغلق, дэн_, _авак, _morí_
  { {0xa5bb00dc,0xad1b000f,0x629c019f,0x3f85007c}},	//   ciój, _חומר, ksro, _õlut_
  { {0xa3c8005d,0x55950004,0x66b4004a,0xdb180030}},	//   ोजन_, ланѓ, ыбну, nevü
  { {0xceb301d8,0xf53f0134,0x56930142,0x6e9b000a}},	//   סיר_, dgår_, шают, ובטח
  { {0x78a9001c,0xe4a7006b,0x0000006a,0x0000006a}},	//   crev, ърно,   ,
  { {0xa3a40124,0x6aaa0026,0xddc2002a,0xb5fb0030}},	//   ијск, orff, lloń, umáb
  { {0x2bc4005d,0x442d016f,0x07a300d7,0x77d30015}},	//   ल्या, đe_, _тајн, _ضغوط
  { {0x35b501b7,0x9adb000a,0xa5bb0030,0xe5cb0033}},	//   _сбир, וחלט, ziój, _цыкл_
  { {0x39da000b,0x115501c6,0xe0d00058,0x41550138}},	// [66d0] _मोज़ि, укаю, يزك_, увас
  { {0x44273240,0xa3d5000d,0x6f950015,0xa0c40015}},	//   _ön_, _сооч, الاض, شيمو
  { {0x62670029,0xaca30092,0x629a00dc,0x78a91754}},	//   _لاحق, _trừn, átot, zrev
  { {0x78a90c4e,0x0000006a,0x0000006a,0x0000006a}},	//   yrev,   ,   ,
  { {0xfd100074,0xada40010,0xaceb002b,0x8cc50015}},	//   يجه_, раіл, برال_, اقته
  { {0xa5bb00dc,0x711a000a,0xee95002b,0xe7e2000b}},	//   fiók, _טורפ, _مدرک, _कोला_
  { {0xe4580053,0x63b50024,0x6e940268,0xbae50015}},	//   דיגט_, igzn, _вису, اكبي
  { {0x78a93241,0xb05b0012,0x2bc40065,0x0000006a}},	//   trev, _späh, ल्बा,
  { {0x8bb70029,0x798902f7,0x6aaa0052,0x0000006a}},	//   _لإضا, rbew, arff,
  { {0x7d04022d,0xa3e2005d,0x6d3a000a,0x78a6001a}},	//   äise, _नों_, _אֲבו, ákva
  { {0xa5bb00dc,0x2b470033,0x61ef2e1a,0x99d70015}},	//   ciók, _рэаг, _oncl, _لتشا
  { {0xe895005e,0x78a93242,0x99b200af,0x0000006a}},	//   _бадь, prev, иjег_,
  { {0xb05b00f2,0x629c08b8,0xe8ee05aa,0x98a50162}},	//   _epäi, wsro, _ул_, _силе
  { {0xe1ff0014,0xe6120086,0xa5070054,0x61ef0077}},	//   _fiók_, _گشت_, ћера_, _ancl
  { {0xb6a30023,0x62533243,0xe9ff0016,0xfae7012c}},	//   _xuấ, rçon, _ngẫm_, حث_
  { {0xb5fb3244,0xe6120086,0xf53f09c0,0x61460099}},	//   rmác, _دشت_, rgår_, геба
  { {0x463b0053,0x62530152,0x629c22a5,0x76460091}},	// [66e0] _רעפע, pçon, ssro, moky
  { {0xe0d702bf,0x6fa50015,0x61ef1915,0xf53f0123}},	//   ыву_, لإمك, _encl, pgår_
  { {0x442a0020,0x03d700a3,0x03bb000a,0x0d861705}},	//   mib_, _גוים_, _אציל, глен
  { {0x3ea7002f,0xf2d30135,0x7bc3002e,0x6012001a}},	//   ánta_, _פער_, efnu, _dæma
  { {0x40950124,0xb6a30092,0x7bc300b8,0x6da315ec}},	//   _врст, _suấ, ffnu, сича
  { {0x442a166f,0xbab40015,0xd0120015,0xcab40015}},	//   nib_, لمتب, _الس_, لمتظ
  { {0x4ed8000a,0x3ed8000a,0xb6a30016,0x442a007c}},	//   _בַּנ, _בַּא, _quấ, iib_
  { {0xaa540001,0x7d0d00dc,0x3f9a0024,0x6b980b56}},	//   јвиш, önsé, lapu_, savg
  { {0x442a1788,0xc7ba004a,0x7794002b,0xb8140099}},	//   kib_, нён_, لیشا, идиј
  { {0x99dd002c,0x442a0375,0x4c9b000a,0x7e620e9d}},	//   dlňu, jib_, _נשבע, lmop
  { {0x501b000a,0xcff7000a,0x442a04f6,0xa5bb0030}},	//   גויו, אציה_, dib_, liói
  { {0x2456002e,0x78c70123,0x442a02ad,0x0000006a}},	//   væma_, årvä, eib_,
  { {0x2ed1000b,0x249f0fab,0xd49b01b0,0x09f70058}},	//   _सन्त, éum_, эрн_, _حفنة_
  { {0xd1bb0086,0x5fc6000b,0x442a3245,0x7c2a3246}},	//   کاسا_, र्मल, gib_, nifr
  { {0x179701d8,0xa29502e1,0xd25b0785,0x92950033}},	//   _גדול_, рабі, еца_, рабц
  { {0xc6930053,0x2bc4000b,0x51870004,0x442a3247}},	//   _פאפ_, ल्ता, ѓуба, aib_
  { {0x3fab0001,0xb6340002,0x36340021,0xaca30016}},	// [66f0] ењем_, _دعوت, _دروس, _trứn
  { {0xf9570008,0x351c000a,0xb05b008c,0xa6e1001a}},	//   רסמת_, _רוזנ, _ysäy, óðge
  { {0x3e070033,0xa857000a,0x7e2b008b,0x7c2a3248}},	//   лядв, ניבה_, ніда_, difr
  { {0xee2e0036,0x61ef1a5b,0x64473249,0x7bc80375}},	//   ін_, _uncl, loji, _abdu
  { {0x563800b2,0xc19a000a,0x361c000a,0x319a000a}},	//   נאדע_, _בשרי, עודד, _שבשנ
  { {0x64471d7f,0xaae500a2,0xe47c000a,0xfe73002b}},	//   noji, لسعو, ערוכ, _هدر_
  { {0x3d95170d,0x9056000a,0x7bc3001a,0x3ee4006b}},	//   _вибр, _כבשו_, rfnu, _лютв
  { {0x7d040012,0xbd6b0004,0x1a0501e5,0xde590033}},	//   äisc, _зрзе_, рпим, _рабі_
  { {0x20030955,0xd5ed0023,0xa5bb00dc,0xf0920053}},	//   _koji_, _giả, ciói, ֿנט_
  { {0xb05b00f2,0x3ae30061,0x6e2b324a,0x22a10091}},	//   _epäv, _tıp_, ligb, kėk_
  { {0x99f5008f,0x442a0020,0x644715ff,0x2492005c}},	//   _вялі, vib_, doji, _swym_
  { {0x3a7a0008,0x25e6000b,0x47580033,0x200301c2}},	//   _סטנד, _जोशी_, ырыя_, _loji_
  { {0x32020264,0xb8870fea,0xdb0a001a,0x442a0ca6}},	//   _roky_, _суей, ggfæ, tib_
  { {0x799b0079,0xa01b001a,0xb4d6000b,0xa7a90088}},	//   lauw, _stön, _सनी_, _ркка_
  { {0xc7b20008,0xd7ee0015,0xa1960054,0x442a324b}},	//   _ובו_, _زكي_, ијај, rib_
  { {0xcb120053,0xa5f70001,0xb5fb30e6,0x442a324c}},	//   קלן_, _већу_, lmán, sib_
  { {0x62850176,0x6447138a,0x442a007c,0xe0da006b}},	// [6700] _etho, boji, pib_, ъва_
  { {0x60d60026,0x8fa61b01,0x22a10091,0x749b004f}},	//   rwym, раже, bėk_, _שייפ
  { {0x23fb0008,0x93fb000a,0xd1b2002b,0x7a3e003d}},	//   _ספטמ, _סלטי, _ویسک, līte
  { {0x627b000a,0x91e60c9a,0x3f9a324d,0xc27b000a}},	//   _שנכנ, _томе, sapu_, _שרכי
  { {0x2ca0002d,0x7e62324e,0x7c2a324f,0x7a3e01ec}},	//   éid_, rmop, tifr, nīte
  { {0x1eaa0015,0x6604008c,0x5bb7005e,0xbe860015}},	//   _لاري_, _loik, илія_, _نجرو
  { {0x7c2a00c0,0x3ea3005e,0x7b63004a,0xbea31068}},	//   rifr, _мирг, отъе, _марк
  { {0xce340074,0x6447003f,0x3ddf0079,0x7c2a3250}},	//   _اورک, zoji, _gauw_, sifr
  { {0x9a670015,0xb7bc003d,0xf1bf3251,0xb05b005b}},	//   جميل_, liģi, _omán_, _epäu
  { {0x9cd70008,0x7c2d002d,0xf8061b07,0x481404e5}},	//   _דומה_, éart, рчин, смос
  { {0xbb460063,0xd6d70063,0x66160091,0xab770067}},	//   _тежк, атя_, _blyk, _ضمنا_
  { {0x39460054,0x7abb004f,0xf98a02be,0x628501f6}},	//   _кнег, _יצבו, _شخصه_, _rtho
  { {0x6447121a,0x44b4006b,0xe786006b,0x94ab006b}},	//   toji, обяс, _куйо, ътна_
  { {0x5726002b,0x661600aa,0x3706005e,0xf7840058}},	//   _پرتق, _elyk, _вчив, _الغَ
  { {0x64470cd4,0x661602d2,0xa3c8000b,0x99dd0057}},	//   roji, _flyk, ोज़_, plňt
  { {0xa01b00dc,0x466802bf,0x64473252,0x52143253}},	//   _etöl, _крым_, soji, одст
  { {0xb05b002c,0xcf9b05e6,0x64473254,0x3f980046}},	// [6710] _opät, вје_, poji, _beru_
  { {0xaaa7000b,0x3ea70077,0xc10400c3,0xdff40054}},	//   _गिलक, ánto_, غولي, опуњ
  { {0x2fe40029,0xdd910029,0xc7d7000a,0x6e2b00cb}},	//   تكلف, كوا_, שובי_, tigb
  { {0x7d0b01d1,0x25b9002e,0x249f2647,0x867b000a}},	//   tygs, ngsl_, šumu_, דראו
  { {0xe9ff0092,0x3d29002b,0xddce0045,0xfce50296}},	//   hoản_, دتای_, _subţ, соло
  { {0xa5bb00dc,0x0c240036,0xda780227,0x5fc6000b}},	//   cióv, омін, _buď_, र्दल
  { {0x3a980033,0x2ef50054,0x4a980033,0x7a3e01ec}},	//   атыю_, _узвр, атыў_, zīte
  { {0x53380008,0xb05b00f2,0x3f810034,0xe9d90055}},	//   ינון_, _epät, lchu_, уки_
  { {0x6e29003f,0x7c2d002d,0x7bc5007c,0x2bc4000b}},	//   _imeb, éars, õhus, ल्हा
  { {0xb5fb0046,0x6d5b0045,0x9610000b,0x7aed003d}},	//   umán, _izua, ास्ट_, āatb
  { {0x660400f2,0xa6b4004a,0x79820034,0xbb5500c3}},	//   _poik, осящ, _ffow, _اناب
  { {0xf409103d,0xceb200a3,0xa01b0123,0x7a3e003d}},	//   _אפ_, היט_, _stöl, tīte
  { {0x7c280026,0xe7e2000b,0x660401be,0xe8ee056d}},	//   _ymdr, _कोका_, _voik, _эл_
  { {0xb5fb0084,0x6e3b0198,0x49540015,0x2d9d044d}},	//   lmál, _ljub, _بخمس, hawe_
  { {0x3ce6002c,0x2d9d002a,0xb5fb3255,0x77f6004f}},	//   zvov_, kawe_, omál, _למסד_
  { {0x66160af5,0xb5fb001a,0x3f810244,0xd5af0015}},	//   _ulyk, nmál, echu_, _كفى_
  { {0x5156071a,0x315a0015,0x3f983256,0x74ea02ed}},	// [6720] ству, اجأة_, _peru_, _сдпг_
  { {0xc9520008,0x33d5005e,0x1610000b,0x5436002b}},	//   למן_, _діют, ासकर_, _دربر
  { {0xa856000a,0x8236002b,0xe9ff0016,0xfe720015}},	//   ציעה_, _هرحا, _ngắm_, سدا_
  { {0xb05b3257,0x2d9d00dd,0xee3a04ab,0xa2f7000a}},	//   _spät, gawe_, ыне_, _המטה_
  { {0xdd99002c,0x61e40064,0xa91d0091,0xc213000a}},	//   _deň_, mdil, pažy, _זהר_
  { {0x69cb018b,0x447b0053,0x69c700dc,0x61e41bcb}},	//   _abge, אנסע, őjel, ldil
  { {0x2ef80008,0xfba90036,0x61e40020,0xb05b00f2}},	//   _דִּב, ртій_, odil, _epäs
  { {0x8f370008,0xbda50015,0xd7f80045,0xbf37004c}},	//   _האלו_, _وحقو, rmăm_, _האלץ_
  { {0xd90e0074,0x60c43258,0x9f580061,0x094a004a}},	//   عیت_, ntim, _borç_, ычки_
  { {0x60c4122e,0x61e400f2,0x7c280012,0x47341cc9}},	//   itim, hdil, _umdr, жнос
  { {0x60c4041c,0xd5b10015,0xcb0a0015,0xe758005e}},	//   htim, وفد_, _حيان_, рині_
  { {0x0f570008,0x60c43259,0xcf57000a,0x6b9a0079}},	//   מיים_, ktim, מבית_, _hetg
  { {0x61e40026,0x3f81325a,0x0000006a,0x0000006a}},	//   ddil, ychu_,   ,
  { {0x23740029,0x395900b8,0x56940033,0x8b07002a}},	//   كافح, üsse_, _дакт, _więź
  { {0x60c400df,0x1b7b0053,0xdc370053,0x5454005e}},	//   etim, רטלע, צאלט_, ївст
  { {0x53342ea0,0xdb180012,0x0737000a,0xa267006b}},	//   чест, bevö, _לאום_, съгл
  { {0x6253120b,0x60f9055f,0x307b0058,0x0000006a}},	// [6730] nçoi, шная_, احرة_,
  { {0xdb180020,0x249f0024,0x3f810bba,0x6b9a325b}},	//   levõ, šums_, uchu_, _netg
  { {0x3ed50029,0xa3e2005d,0x602f0007,0x3f81325c}},	//   تقار, _नोट_, _rėmė, rchu_
  { {0x645500b8,0xdb18007c,0xfeb80015,0xa5bb0030}},	//   llzi, nevõ, صامت_, ciót
  { {0xfe700086,0xeb99023e,0x5e440015,0x60c4164a}},	//   ردم_, аил_, أَنْ, ctim
  { {0x2bc4000b,0xb05b008c,0xa5bb0f19,0x25a90030}},	//   ल्ला, _epär, gnóz, _ldal_
  { {0xf9910029,0xa5bb005c,0xb4d6005d,0xda6505b3}},	//   وبة_, niós, _सन्_, овки
  { {0x6e29003f,0x4ae40010,0x6e3b003f,0xfcab002b}},	//   _umeb, яўча, _ujub, _مائو_
  { {0xdb18007c,0x2b49002a,0x78390004,0x6d5b0045}},	//   devõ, łac_, иџот_, _uzua
  { {0xd8250191,0xa7fc0064,0x5c040010,0x2bb80029}},	//   ідни, smın, _няха, _هامة_
  { {0xb04c004c,0xda09002b,0x83c4000b,0x60c40030}},	//   רעיִ, _پيشه_, _लॉगआ, ztim
  { {0xb9e4005e,0x91c9000b,0x9dd5000a,0x60c4325d}},	//   _нічи, _हॉलै, חוֹק_, ytim
  { {0x95560196,0x25a90026,0x4dda000a,0xb90b0015}},	//   تخدا, _ddal_, בחרו, _حزام_
  { {0xf1bf0077,0x9cd6000a,0xc7b7005e,0x68e90723}},	//   _acá_, חושה_, _уґо_, mved
  { {0xe7e2005d,0x68e9325e,0xaaa9000a,0x7a3e003d}},	//   _कोटा_, lved, יֹּ֖, līta
  { {0x60c4325f,0xa5bb0030,0x61e43260,0x661d3261}},	//   ttim, ghód, udil, chsk
  { {0xe0860015,0xd919000a,0x7a3e003d,0x68e93262}},	// [6740] تجزي, בוּל, nīta, nved
  { {0xe29a0124,0x20560484,0xb05b0c77,0x8839000a}},	//   _као_, ітар, _spär, ׁתּו
  { {0xdc2a002b,0xc2c60015,0x6da60015,0x60c43263}},	//   یسته_, _بيجي, قمام, stim
  { {0xe1ff3264,0x6b9a0144,0x27150016,0xdd8f0021}},	//   _chód_, _setg, ín_, نوم_
  { {0xac460015,0x4c94004a,0x463b004c,0x973c0085}},	//   يئته, чилс, סענע, maće
  { {0x7a3e0048,0x70190010,0x2aaa0001,0xad650086}},	//   dīta, _ліст_, атио_, سانه
  { {0xad9d002a,0x6b9a0547,0x69c93265,0x68e93266}},	//   _koźl, _vetg, ffee, eved
  { {0xddc90011,0x6b9a0161,0x5e470004,0x5b030015}},	//   _vieţ, _wetg, _дпсм_, ظِيم
  { {0x49b70002,0x53ca000b,0x9c850015,0xb5fb0046}},	//   زايد_, िभाश, _فشله, umám
  { {0x7e7c3267,0xe1ff002d,0x62530003,0xac170054}},	//   _kurp, _thóg_, rçoi, _дођу_
  { {0xdb180005,0x7bca0026,0xa01b002e,0x8f7b00a3}},	//   tevõ, mffu, _stök, יניק
  { {0xa4d50036,0xcb13000a,0xaadb000a,0x7e7c133e}},	//   помі, _קלף_, _כחבר, _murp
  { {0xa9260029,0x27150092,0xe4e405d1,0xa98b000a}},	//   _بعضه, án_, мірн, _דָוִ
  { {0x7bd80020,0xf76f0086,0xdb183268,0xddc9006f}},	//   nevu, عای_, sevõ, _mieš
  { {0x7bca3269,0x17f70058,0x0000006a,0x0000006a}},	//   iffu, _ذروة_,   ,
  { {0xd6280001,0x973c0085,0xdb180030,0x0000006a}},	//   _моје_, gaće, ggvé,
  { {0xa01b00c0,0xa5bb0535,0x7d04005b,0x64400f66}},	// [6750] _utök, biór, äisl, émic
  { {0x20070084,0x7bd80089,0x74280029,0xa5bb286f}},	//   ðni_, jevu, _وكيف_, ciór
  { {0x443101e2,0x68e9326a,0x7bd8326b,0xf412000a}},	//   miz_, zved, devu, _נפט_
  { {0xdd940010,0xdb030012,0x4431326c,0x3ced326d}},	//   дацы, rgnü, liz_, _prev_
  { {0xde580010,0xddc90024,0x01fa000a,0xe6ed006f}},	//   цаці_, _cieš, _הפרל, väčš
  { {0x44310482,0x7bd80005,0x6a950036,0xfc040036}},	//   niz_, gevu, приє, мпіо
  { {0x60d90064,0xb5fb00dc,0x4dd70015,0xdd9508f0}},	//   şamı, rmáj, _وترس, _навы
  { {0xdce8005c,0x7a3e0024,0x820b000a,0x2cb00061}},	//   _śląs, tīta, יהֶ֖, üldü_
  { {0x44310064,0x17f90015,0x25e6000b,0x69c92728}},	//   kiz_, مردة_, _जोगी_, rfee
  { {0x7bd804ed,0xb5fb00dc,0x87252ea0,0x7a3e003d}},	//   cevu, lmáh, змож, rīta
  { {0x7a3e003d,0x68e92af0,0x6a170015,0xe945002b}},	//   sīta, sved, _وبصر, _کرای
  { {0x3ebe00cb,0x65850033,0x9f510030,0x4efa000a}},	//   _åtte_, дыёз, _hozó_, צהרו
  { {0x973c0085,0x4431326e,0xa97a000a,0x26c5013f}},	//   vaće, fiz_, _האנכ, stlo_
  { {0x74160015,0xa32a0058,0xb7d90058,0xe8480058}},	//   أوسا, مأزق_, _طوعا_, _وجون_
  { {0x366a0001,0xd36f0029,0x3f9c001a,0x2456001a}},	//   _лако_, ُهُ_, ðvum_, næmi_
  { {0xd5ed0016,0x73c6002b,0x0576006e,0x15462fa0}},	//   _già, _کيدم, _عابد, _нейм
  { {0x55bb0008,0x973c016f,0xb637000a,0x7e7c0aff}},	// [6760] _המפו, raće, _מרקס_, _surp
  { {0x7e7c003e,0x98af0007,0x7d0400f2,0xddc914c4}},	//   _purp, _lygį_, äism, _rieš
  { {0x41c0004a,0x8445006e,0x42ea0891,0x644e326f}},	//   _а́ет, _تخيل, _умно_, mobi
  { {0xddc93270,0x2456002e,0xc049000a,0xc1060015}},	//   _pieš, dæmi_, אז_, _فوجي
  { {0x20170014,0xf1b3000a,0x7bd83271,0x0000006a}},	//   áció_, _אסר_, tevu,
  { {0x7e7c0048,0x61e601e2,0xddc90007,0xaae60015}},	//   _turp, _hakl, _vieš, كسبو
  { {0x501b000a,0x61e623e0,0x0000006a,0x0000006a}},	//   _פולו, _kakl,   ,
  { {0xddc90048,0x7f3b013a,0x2d80002c,0x99d60029}},	//   _tieš, _העלו, žieb_, ستعا
  { {0x44310064,0xadd7000a,0x61e63272,0xc8c70015}},	//   yiz_, _צומח_, _makl, كوين_
  { {0x3cfa005d,0xf0930008,0x7d0d00f2,0x7bc1002d}},	//   ्हीं_, ענת_, äase, _gclu
  { {0x644e12d7,0x6fc1000b,0xbbe90015,0x61e63273}},	//   dobi, र्टू, _برقم_, _oakl
  { {0xcb1300b2,0x60120084,0x8afb0008,0x2f5b0008}},	//   _אלע_, _dæmi, _להבי, מדינ
  { {0xa9c50086,0xf993000a,0x2ca602f2,0x7a3e003d}},	//   _آزمو, _טרף_, nsod_, līto
  { {0xb347001c,0xdc8b000a,0x443109ae,0x7bc13274}},	//   _naçõ, מְלָ, uiz_, _xclu
  { {0x44313275,0xd7c7002b,0xd6d00015,0x7a3e003d}},	//   riz_, _رويه_, _شقة_, nīto
  { {0x44310064,0x754800dc,0x76bb0008,0x307b0015}},	//   siz_, észé, _המהפ, محطة_
  { {0xd5ed0092,0x61e6016f,0x83870080,0x764f0305}},	// [6770] _giá, _dakl, _ныне, mocy
  { {0x649c000a,0x7538000a,0x90540054,0x644e2dd3}},	//   _היזה, _מאחד_, евуц, cobi
  { {0x3ea70014,0x200a0796,0xe1ff0016,0x9f3400ce}},	//   ént_, _dobi_, _chóc_, нефі
  { {0x7a3e0024,0x68e220b3,0x9f4a016e,0x2456001a}},	//   dīto, _osod, _robô_, væmi_
  { {0xed4e3276,0x2ca602f2,0xc1740296,0x0000006a}},	//   то_, gsod_, _плющ,
  { {0xe0fa0008,0x60fa000a,0x70fa000a,0x61e609cb}},	//   _ולשל, _והשק, _והשח, _zakl
  { {0x61e601e2,0xe45f00f2,0x62810057,0xcb660254}},	//   _yakl, ytön_, íloh, маше_
  { {0x6c850029,0x644e3277,0x2456001a,0x69ce0030}},	//   _يلزم, zobi, ræmi_, őben
  { {0x8cd5005d,0x320b005c,0x629a00dc,0xe8f90036}},	//   _मैचो, _mocy_, átoz, іло_
  { {0xb905000b,0xf8ae002b,0xaf57004f,0xbc3b009a}},	//   _पन_, شکه_, ּׁ֛ה_, _اسرا_
  { {0xfb150029,0x644e016f,0xaa590054,0x366a31f2}},	//   _تواج, vobi, _дижу_, жано_
  { {0xcb12013a,0x320b005c,0xe617005e,0xc9150054}},	//   _שלא_, _nocy_, ддю_, _одећ
  { {0xdddc0007,0xa8eb0015,0x644e3278,0xa87b0058}},	//   _surū, _دعاك_, tobi, _احصر_
  { {0xb4ce005d,0x61e63279,0xe45f00f2,0xe577004a}},	//   _रही_, _sakl, stön_, ьзя_
  { {0xe45f002e,0xe8520015,0x200a1835,0x61e6327a}},	//   mtöl_, _جنود, _robi_, _pakl
  { {0x27e70084,0x2d9f018b,0x69db00b8,0xf772000a}},	//   _hann_, _neue_, neue, _בקו_
  { {0x27e7018b,0x80aa0036,0x037a0086,0x644e1212}},	// [6780] _kann_, ював_, _وحدت_, pobi
  { {0x973c016f,0xe4d7002b,0xb4b7000a,0x69db0012}},	//   laća, _کویت_, _קליפ_, heue
  { {0x171a0053,0x27e70645,0x93fb000a,0x32460015}},	//   ֿונע, _mann_, _וליי, _ينخف
  { {0xa3c8000b,0x3ea70045,0x3eba327b,0x4f65002b}},	//   ोजक_, ânta_, rupt_, رالف
  { {0x3cfa014e,0xd5e40023,0x25a00020,0x0e690029}},	//   ्हें_, _chỉ, _meil_, أصلي_
  { {0xb5fb002f,0x7a3e003d,0x2d9f00aa,0x601b0034}},	//   rmái, tīto, _eeue_, _tîma
  { {0xa6e1002e,0x2bc4000b,0x25a000e9,0x69db0012}},	//   óðle, ल्गा, _oeil_, feue
  { {0xe1ff0023,0x6df60029,0x7a3e0024,0xb5fb00dc}},	//   _khóa_, _تكرا, rīto, lmáv
  { {0x7a3e0024,0x69ce0030,0x7c9601f3,0x27e701f1}},	//   sīto, őbeo, _ірац, _bann_
  { {0x39580024,0x9b930015,0xc7b00015,0x7c650015}},	//   ārs_, _للكت, دّد_, _كالل
  { {0x27e7018b,0x5c370135,0x2af50033,0x6b7b000a}},	//   _dann_, _קרבן_, _пяцё, _ורבנ
  { {0xa01b00c0,0x27ee002a,0x64400003,0x7af50030}},	//   _utöv, _żoną_, émin, _ázta
  { {0x7d0400f2,0xadc30092,0xed46002b,0xc8c8002b}},	//   äish, _hoản, اپ_, _روغن_
  { {0xe72f0086,0xdb03016e,0x27e701b3,0x2a870016}},	//   اصی_, danê, _gann_, _hđba_
  { {0x6adc014e,0x25a0003c,0xd7bb000a,0x70d7000b}},	//   _मनोर, _feil_, _וצור, डब्ल
  { {0xe2540015,0x69c0327c,0x0000006a,0x0000006a}},	//   نَّخ, ngme,   ,
  { {0x2a660026,0x3134327d,0xd59c000a,0xf654000a}},	// [6790] _mhob_, ветр, _ובחל, _בצק_
  { {0x2d810089,0x268a004f,0x5fbb0058,0x25a00546}},	//   ěhem_, ַנְּ, تدرج_, _zeil_
  { {0xb275327e,0x4fc4006b,0x53350004,0xbdb50054}},	//   _плош, ъста, _чент, ебеј
  { {0x2ddb0029,0xdb03001c,0x9326002b,0xf2d2004c}},	//   تبطة_, banê, _سرپن, _געט_
  { {0x2ca9002f,0x69c0003e,0x8d740067,0xd251002b}},	//   éad_, dgme, ناها, _لنگ_
  { {0xc7ce0023,0xb09a000a,0x2005007c,0x69ce0030}},	//   _sống_, _מישר, _õli_, őbel
  { {0xfeb80086,0x69db00b8,0x8b94005e,0x60230046}},	//   _يافت_, teue, тріч, růmě
  { {0x3ebe00c0,0x0378000a,0xd5e40016,0x6e22327f}},	//   _åtta_, ותות_, _thỉ, chob
  { {0x29190014,0xb4ce005d,0x6c840015,0xe26c000a}},	//   ása_, _रहे_, _للقم, חֻזָ
  { {0x9b880015,0xddc9006f,0x24803280,0x25a03281}},	//   _ينقل_, _dieť, _ruim_, _seil_
  { {0x98ab0064,0x2480002d,0xe9ff0092,0xc7ce0092}},	//   ğlık_, _suim_, _ngầm_, _tống_
  { {0x98ab0064,0xc7ce0092,0x06070286,0x27e73282}},	//   şlık_, _uống_, енюк_, _wann_
  { {0x973c0085,0x25a03283,0x64403284,0x660d07c8}},	//   raća, _veil_, émio, _doak
  { {0x25a0018b,0x33d5192f,0x7d0400f2,0x26c70086}},	//   _weil_, кіст, äisi, _قطعی_
  { {0x78a908e0,0x25a03285,0xe61a006b,0x2cbd0079}},	//   lsev, _teil_, _ндк_, huwd_
  { {0x6e2200aa,0xc692000a,0x2456001a,0x91e31cc9}},	//   xhob, _גאה_, væmu_, лосе
  { {0xe085003b,0x888c00b2,0x78a9003c,0xb1460b75}},	// [67a0] نجلي, ַראַ, nsev, хнал
  { {0x78a93286,0xc294002b,0x2cbd0079,0xb5fb005a}},	//   isev, _لیسب, duwd_, umáv
  { {0xe39b000a,0x639b000a,0xe1fa006b,0x2cbd0079}},	//   _משיכ, _מסינ, _егн_, euwd_
  { {0xa01b00c0,0x78a93287,0xdb030144,0xdb0a216b}},	//   _stöt, ksev, manè, ínít
  { {0x64410089,0x62810089,0x98b8003d,0xb4ce000b}},	//   čliv, ílov, ārī_, _रहो_
  { {0x224011aa,0x0aea0015,0x70560015,0xb5fb0030}},	//   lnik_, كربي_, _أنسا, lmát
  { {0x63a30020,0x2a660026,0xddc9002c,0x6e223288}},	//   _õnne, _phob_, _sieť, phob
  { {0x9e660086,0xbef7000a,0xfce6227a,0x22403289}},	//   _سازن, _אצלו_, _побо, nnik_
  { {0xd7f00029,0xdd8f03c4,0xbb4a0086,0x58d70033}},	//   لكة_, _طول_, _کلان_, едыя_
  { {0x3ea60024,0xc619000b,0x3a3f00da,0x660d00da}},	//   ņotu_, दस्य_, anup_, _soak
  { {0x2cb000df,0xdb06022d,0xa823002b,0x6595328a}},	//   žodį_, ämäl, دکنن, кану
  { {0x4444328b,0xb5fb00dc,0x6a9b0053,0xdced0091}},	//   _aj_, ilág, _זשאנ, škąj
  { {0xba290015,0x2240328c,0xd9970058,0x4444328d}},	//   _تسلم_, dnik_, _أنهت_, _bj_
  { {0x3e670020,0xe45f001a,0xb5fb2a0d,0x4444328e}},	//   mõte_, mtök_, emát, _cj_
  { {0x24560084,0xdb080089,0xf7480015,0x66e30180}},	//   væmt_, _oddí, _تلغي_, _боја
  { {0x7a3e0048,0x4444328f,0xa75b000a,0xa9230046}},	//   dītk, _ej_, _מדור, ůžem
  { {0xe1ff002d,0xb9ca0016,0xe45f001a,0x7a3e003d}},	// [67b0] _fhón_, _sưị_, ntök_, tītj
  { {0xfd650092,0x4444003c,0xe53c0008,0x11540127}},	//   _thuẫ, _gj_, _מתחר, укую
  { {0xdd91003b,0x2240018c,0xfe710086,0x92950937}},	//   لوا_, bnik_, لگر_, _шанц
  { {0xee380036,0xfe700115,0x91790016,0x7e280033}},	//   ннє_, مدن_, hẩm_, ніча_
  { {0x61fd3290,0xad670015,0xb5fb0030,0x0d8400e2}},	//   _insl, راؤه, mlád, улін
  { {0x7c940074,0x61ed0014,0xa1360053,0x6c940029}},	//   اشنا, ldal, _יארק_, اشنط
  { {0x9f350036,0x8d950015,0x63a1002a,0x60cd3291}},	//   _реві, _للأش, ólny, ltam
  { {0x78a93292,0x99750054,0xf8af002b,0x32092e9d}},	//   tsev, купш, مکت_, njay_
  { {0x9f430089,0x5c750292,0xe45f002e,0x60cd10d3}},	//   _mají_, _алат, gtök_, ntam
  { {0xbb840029,0x61ed0ec8,0xbf19000a,0x22403293}},	//   _ملكي, hdal, ֥וֹך, znik_
  { {0xb5fb0089,0x60cd0201,0x78a93294,0x2240002a}},	//   klád, htam, ssev, ynik_
  { {0x19950036,0x9a880029,0x78a90020,0x4421003f}},	//   _радя, _أَنْ_, psev, _alh_
  { {0x271c00a7,0x88840010,0x61ed173a,0x224001a3}},	//   ản_, _бліж, ddal, vnik_
  { {0x22400050,0x61fd02d2,0x7bc33295,0xf8b6000a}},	//   wnik_, _ansl, ngnu, _יפני_
  { {0x7866001a,0x22403296,0x7bc30012,0x03a31215}},	//   uðve, tnik_, ignu, рисо
  { {0x7866002e,0xe612002b,0x4444051e,0xdb080003}},	//   rðve, _خشت_, _wj_, élép
  { {0xf3f10023,0xa0a60010,0x9f430089,0x60cd3297}},	// [67c0] ộc_, тазд, _dají_, gtam
  { {0xa01b2e6f,0x22400c1a,0xdfcf0015,0x3cf800bc}},	//   _stör, snik_, ييق_, _črv_
  { {0x7f190010,0x22403298,0xaec6006b,0xc3b7004c}},	//   ніцу_, pnik_, тбел, _בליץ_
  { {0x44383299,0x7c2105d7,0x7bc3001a,0xb5fb16ce}},	//   lir_, _allr, egnu, lmár
  { {0x4438329a,0x60cd329b,0x7336002b,0x3cfa0021}},	//   oir_, ctam, _سرگئ, بعاد_
  { {0xdb180014,0x3e670020,0x1d070001,0x6e960015}},	//   egvá, võte_, тељи_, _للسا
  { {0x7a3e0024,0xbae30029,0xab77002b,0xfaa30033}},	//   līti, لكوي, نمها_, ашын
  { {0xdbdf0084,0x2614001c,0x4438329c,0x3ea6003d}},	//   síðu, _mãos_, hir_, ņots_
  { {0xfce31e88,0x7a3e0024,0x0a670063,0x6bd60015}},	//   _кото, nīti, ърши_, _لتار
  { {0xd7f70802,0x61ed1587,0x765d0079,0x4438329d}},	//   вую_, zdal, wlsy, jir_
  { {0x4fbb009d,0x4438329e,0x61ed329f,0xaabf000b}},	//   וציא, dir_, ydal, _एमएक
  { {0x7c3832a0,0x60cd002a,0x443832a1,0xc71700ce}},	//   livr, ytam, eir_, тоює_
  { {0x9f47002c,0x443832a2,0xdb030057,0x2bc9000b}},	//   ľné_, fir_, vané, _रामा
  { {0x7a3e0048,0x9f4704af,0x443832a3,0xb5fb0030}},	//   dīti, žné_, gir_, tmás
  { {0x6a65002d,0x31c70033,0x23d2000b,0x61ed003d}},	//   lófa, ксав, द्धद, tdal
  { {0x60cd32a4,0x61ed0026,0xcad70008,0x69dc00dc}},	//   ttam, udal, כולת_, őref
  { {0xe7cf014e,0xf8b10008,0x44380c4f,0xe5f8000a}},	// [67d0] त्वप, ֶשׁ_, bir_, _יזהר_
  { {0x44380467,0x7e6932a5,0x60cd0275,0xd83832a6}},	//   cir_, _shep, rtam, nič_
  { {0xd3710074,0x60cd32a7,0x64550269,0x539a000a}},	//   _دهد_, stam, mozi, _איתו
  { {0xadef000b,0x64550347,0x60cd32a8,0xddeb002b}},	//   ज़ाइन_, lozi, ptam, برئه_
  { {0x91ba013a,0x9856005c,0xd83800bd,0x21670010}},	//   _אמרי, _złą_, kič_, _штог
  { {0xbfb80074,0xd83800bd,0x7f940033,0xca6b01f3}},	//   _لطفا_, jič_, _варх, _мiлi
  { {0x49930086,0x6bb40036,0x628532a9,0x7bc30085}},	//   لیار, рсіє, _juho, rgnu
  { {0x63a500b8,0xaa560001,0xdb010307,0x443832aa}},	//   _lehn, лију_, _jelé, zir_
  { {0xe1ff0023,0x7d0400f2,0xa7fc0064,0x64551afb}},	//   _nhóm_, äist, klıd, kozi
  { {0x515c000a,0x26cb002a,0xd83800bc,0x661d0789}},	//   וכחו, ńcom_, gič_, eksk
  { {0x7a3e0024,0x38ca0086,0xfb150015,0xddcb002a}},	//   zīti, وایی_, _حواج, mogł
  { {0xe8f5003b,0x44380176,0xdb0132ab,0x4a9a004f}},	//   _مستخ, wir_, _relè, _נינג
  { {0x443813e5,0xcdf6000a,0x2c69016e,0x6aa10034}},	//   tir_, אמרי_, aúde_, _hwlf
  { {0x4438002f,0xd91a0053,0x645532ac,0x17150015}},	//   uir_, _רוסל, gozi, _مذبح
  { {0xdb010014,0x443832ad,0x232a0877,0x63a50012}},	//   _belé, rir_, хови_, _dehn
  { {0x7a3e0024,0xdb010107,0xe6920015,0x4438068b}},	//   tīti, _celé, _اليد, sir_
  { {0x11d70029,0x41270608,0xe0860115,0xc50a0015}},	// [67e0] طولة_, гото_, اجري, _ستظل_
  { {0xdb010251,0x7a3e003d,0xb4c00065,0x60e70138}},	//   _telè, rīti, ँढी_, ымум_
  { {0xbe850029,0xdb0100dc,0x54770008,0x2d800024}},	//   لجنو, _felé, _תגיע_, žiem_
  { {0xe1ff002f,0x52d70053,0x17560053,0x83390010}},	//   _gnó_, _גוטע_, אסער_, _шчыт_
  { {0x7a3e0024,0x7c3832ae,0x321e0091,0x0000006a}},	//   nūte, tivr, ūtys_,
  { {0xc4d30008,0x3f9a002b,0x7c380003,0xad650058}},	//   צגו_, _سپرد_, uivr, جامه
  { {0xdddc0011,0x3f6700d0,0xd8380655,0xd00f0067}},	//   _curţ, _биро_, vič_, _علف_
  { {0x6455000c,0xd5e40092,0x611a0024,0x2010002a}},	//   zozi, _nhì, _tālā, żnić_
  { {0x02e1005d,0x59d30029,0xc7ca004a,0x3913006b}},	//   _पन्न, صغير, ныне_, ймър
  { {0x6a65002e,0x998d0007,0x7aed002a,0x07e60054}},	//   rófa, rieš_, łata, уцим
  { {0x8c1b0008,0xeb970146,0xb9c60087,0xc057000a}},	//   _רובי, _сих_, _مقاي, רביץ_
  { {0x98a60083,0xd104005d,0x27ea0024,0xb5fb0b7e}},	//   _биде, रमाण_, _šinī_, dlác
  { {0x645500dc,0x661d32af,0xdb010003,0xa7fc0061}},	//   tozi, rksk, _relé, tlıd
  { {0x262f0046,0xe704009a,0xf2e70280,0x7aed01ec}},	//   vřou_, _نسبی, любо, āatv
  { {0x443f016f,0xa7fc0064,0x26f7002b,0x8ad8000a}},	//   đu_, rlıd, _مريخ_, כַּפ
  { {0x645500b8,0xc0ab012c,0x95cb0923,0x0000006a}},	//   sozi, فائل_, _чука_,
  { {0xbf1d005d,0x64551339,0xb03532b0,0xd904002b}},	// [67f0] पन्न_, pozi, анаш, أی_
  { {0x628500f2,0x27ee002e,0x2bc9000b,0xa5bb0030}},	//   _tuho, _jafn_, _राधा, skód
  { {0xdb0102c1,0x747a000a,0xc7d7000a,0xdb180123}},	//   _telé, _שנתג, רובי_, ngvä
  { {0xd5e40092,0x929a000a,0x6cf0000b,0x8c9501c6}},	//   _khí, _שירת, चिंग_, аркі
  { {0xfaf80048,0x9e950086,0x41680004,0x65c8004f}},	//   _arī_, _چارچ, _бјрм_, א֤וּ_
  { {0x27ee0084,0x00ba000a,0x3ab50054,0x6ab5006b}},	//   _nafn_, _במשמ, аљит, асих
  { {0x1b490063,0xac160054,0x7d04008c,0x2418000a}},	//   ъзки_, роју_, äisr, רחון_
  { {0x99f5005e,0x5f4400c3,0x61ef01c2,0xe338004f}},	//   рякі, _انفل, _jacl, טרופ_
  { {0x98150015,0xd825006b,0x25e9000b,0x5bc7002b}},	//   لبدا, идии, ज़नी_, _متاف
  { {0x9999005c,0x66db00f2,0x7a3e0024,0x18690054}},	//   ósł_, _näkö, dītu, ђани_
  { {0xbb84003b,0xabfa000a,0x4e19000b,0x99d90015}},	//   _المي, _שהער, _दवाई_, _لواء_
  { {0x0f56000a,0xdb03006f,0xf3f10016,0x7afc1ad6}},	//   ייתם_, naní, ộn_, _árta
  { {0xd5e40023,0x59670063,0x5a0a0053,0x98b80011}},	//   _chí, _съжа, _בלײַ, ără_
  { {0x9f5c0030,0xe7872a4b,0x03a332b1,0x8d76004f}},	//   űvé_, _судо, жиро, יגרו_
  { {0x883a000a,0xdb03006f,0x68fc003d,0xd3720015}},	//   _שתצו, kaní, ārde, زهر_
  { {0xc48632b2,0x9343005e,0xcb12000a,0x8506002b}},	//   _клик, інте, חלל_, _نوبن

  { {0xddc90048,0x2d80002c,0xdb032512,0x61ef0034}},	// [6800] _biež, žiek_, daní, _dacl
  { {0xcef60001,0x9f58001a,0xaf9603ae,0xdfa50015}},	//   ичењ, _borð_, ршај, محمي
  { {0x539b0008,0x0d8632b3,0x03bb000a,0xe7f8000b}},	//   _שיטו, ален, _בציל, ्ञता_
  { {0xfcaa0029,0xadb70015,0x53d2000b,0xf5ad000a}},	//   ناتو_, لهما_, द्रश, ֲבוּ
  { {0xddb70033,0x7646008c,0x61e432b4,0xb7e5000b}},	//   ргіі_, inky, meil, क़ाम_
  { {0x69d900b8,0xa7fc0064,0xec13002b,0x201c0030}},	//   _abwe, zlıb, يوند, övid_
  { {0x7f43129a,0x7aed005c,0x6da60036,0x5fdb000a}},	//   _держ, łatn, _виба, _שחלק
  { {0xd90d0086,0x27ee002e,0x61e432b5,0x9997006b}},	//   کیه_, _safn_, neil, акът_
  { {0x973c016f,0x094a006b,0xc8c70021,0x390a0033}},	//   maći, ъчки_, لوين_, тэйн_
  { {0x7d280064,0xa9670004,0x973c0085,0x61e432b6}},	//   ırsı, шиња_, laći, heil
  { {0x61e4022d,0x442a002f,0x501b000a,0x7e621985}},	//   keil, dhb_, דויו, olop
  { {0xd5e40092,0xbb3b000a,0xd5ed0016,0x68f90034}},	//   _phí, _בעבי, _khả, _frwd
  { {0xb894003b,0x46150086,0xa5bb016e,0xda7b000a}},	//   _التع, لوگر, nhói, _סנדר
  { {0xb4d7014e,0xc8db0008,0x7cda0024,0x76460007}},	//   _सही_, _סקוט, mārā, anky
  { {0x7cda0024,0x61e40313,0xf1a728ae,0xd25b1791}},	//   lārā, feil, иран, вца_
  { {0xd5e40023,0xe1ff0092,0x877b000a,0xb77b000a}},	//   _thí, _khói_, _באוי, _באוש
  { {0xdb03032c,0x99840007,0x60c432b7,0x7bda32b8}},	// [6810] vaní, limų_, guim, _obtu
  { {0x61e4002d,0x9f470107,0x2897000a,0x7e620123}},	//   aeil, žní_, ידמן_, elop
  { {0xdb010134,0x99840007,0x6447016f,0x61ef0026}},	//   _udlø, nimų_, mnji, _tacl
  { {0x1e8400fd,0xd356000a,0x973c0085,0x7e6232b9}},	//   ілім, _לשתק_, gaći, glop
  { {0x7afa01e2,0x50f40010,0x53f8002b,0x25a932ba}},	//   _artt, _дзят, _صریح_, _meal_
  { {0x99840007,0x7c940086,0xd116000a,0xd01b0004}},	//   kimų_, زشها, _הקשה_, _рфм_
  { {0x998400df,0x6ef000dc,0xadbd0010,0x60130089}},	//   jimų_, róbá, _павi, _výmě
  { {0x09f90029,0x99840007,0xdddc00bd,0x7e6232bb}},	//   افظة_, dimų_, _turš, clop
  { {0xa5bb002d,0x4238000a,0xe1ff0016,0x644706c0}},	//   chói, ינהל_, _chói_, knji
  { {0x998d002c,0x08d40010,0x7c2a0334,0x61e4059b}},	//   dieť_, іцыя, chfr, zeil
  { {0x64470198,0x66e5006b,0x99840091,0x3a260c12}},	//   dnji, щона, gimų_, _flop_
  { {0x25a9002d,0x08f90018,0xd99b0115,0xddc9002a}},	//   _ceal_, _مرتب_, _شخصا_, _nież
  { {0xd6ce0086,0x915e0092,0xd9450001,0x7a7a0053}},	//   وقی_, _mặc_, _ћели, _ערנס
  { {0x61e4018b,0x7e6200dc,0x321a002b,0xdb0a001a}},	//   weil, zlop, گيرد_, rgfö
  { {0x68e90176,0xddc90050,0x7a3e0024,0xb5fb002d}},	//   lwed, _bież, lūta, mlán
  { {0x78c4002e,0x60c414c8,0x171a000a,0xdb010247}},	//   _útví, tuim, _תוקע, _nelí
  { {0xe4d70086,0xf65300a3,0x68e91af2,0x998d006f}},	// [6820] _هويت_, _מצה_, nwed, cieť_
  { {0x68e90026,0x60c40161,0x2537000a,0x25a9219f}},	//   iwed, ruim, _לנפש_, _zeal_
  { {0xd00f0029,0x20550484,0x68e92c21,0xd47b000a}},	//   علم_, ітур, hwed, _תאיל
  { {0xd5ed0023,0xa5bb002d,0xb0c8005d,0x629c2d24}},	//   _phả, thói, िंदग, mpro
  { {0x41760086,0x27e504d4,0x2d02000b,0x7e620282}},	//   _دادس, keln_, लमेल_, rlop
  { {0x68e90176,0x26c50035,0x1eaa0015,0xfbcf0015}},	//   dwed, kulo_, _ماري_, ّتي_
  { {0x99d60029,0xaab70029,0xa5bb002a,0xb5fb0046}},	//   متظا, مدير_, chów, dlán
  { {0x998400df,0xae0c005d,0xd5ed0092,0xe45f00c0}},	//   vimų_, _सचिन_, _thả, ntör_
  { {0xf98f0029,0xdca328ff,0x27e50012,0x25a903b0}},	//   ربي_, _нати, feln_, _real_
  { {0x6e22003c,0x99840007,0x25a90100,0x27e5079c}},	//   lkob, timų_, _seal_, geln_
  { {0x8104014e,0xeb970008,0xcff70008,0x25a90020}},	//   रमुख_, _הדבר_, זציה_, _peal_
  { {0x66720086,0x99840007,0x7a8b000a,0x8f7b000a}},	//   وگير, rimų_, _עָבַ, טניק
  { {0x68e90026,0x27e504d4,0x99840091,0xd407006b}},	//   cwed, beln_, simų_, бяви
  { {0x7d0d00f2,0x998d002c,0x99840007,0x7bca32bc}},	//   äasi, rieť_, pimų_, ngfu
  { {0x752f0050,0x26c51ad7,0x998d002c,0xc7d7000a}},	//   szcz, culo_, sieť_, _לוגי_
  { {0x9f51016e,0x64470085,0x27ea0091,0x443a32bd}},	//   _fazê_, snji, šinį_, _emp_
  { {0x764d003f,0x914b0063,0xdb03002d,0x7c3a32be}},	// [6830] _ijay, учва_, ianá, _omtr
  { {0xddc9005c,0x64400152,0x6604005c,0x7339033d}},	//   _wież, émit, _znik, _взор_
  { {0xdb0102c1,0x68e9002a,0x4f6b0663,0x7f840015}},	//   _pelí, zwed, ушам_, ألمن
  { {0x68e90026,0x31c70da6,0x6dc70015,0x7c3a32bf}},	//   ywed, _усов, إزال, _amtr
  { {0x067c0053,0x224900dc,0x538b000a,0xed58005e}},	//   אנאל, mnak_, ְנֵ֣, бої_
  { {0x22490014,0x6f28002a,0x5fcf000b,0x973c0085}},	//   lnak_, órcó, स्खल, laću
  { {0x69c90111,0x539c000a,0xdb010030,0xce6b006b}},	//   tgee, ניהו, _telí, _брад_
  { {0x22490014,0x68e900b8,0x7c2832c0,0xca6b0484}},	//   nnak_, twed, _eldr, _мiнi
  { {0x22490f49,0x68e90035,0x786f0595,0x31fa000a}},	//   inak_, uwed, høve, בִיע
  { {0x68e91745,0x66160061,0x26c50fb3,0xd7c900c3}},	//   rwed, _soyk, tulo_, جوده_
  { {0x22490014,0x68fc0024,0x68e91527,0x443a007c}},	//   knak_, ārda, swed, _rmp_
  { {0xb5fb32c1,0xceb20053,0x27e500b8,0x443a00e8}},	//   slán, ויט_, seln_, _smp_
  { {0xe9450086,0x224932c2,0xb5fb32c3,0xf1bf0107}},	//   _برای, dnak_, plán, _plán_
  { {0x4add000b,0xdd7a000a,0xb5fb0030,0x67440030}},	//   _महाव, יטרל, llál, átjá
  { {0x63ae018c,0x366a2392,0xd36f0029,0xeaa70015}},	//   rabn, _како_, َهُ_, بع_
  { {0x9fa30084,0x22490014,0x23db000b,0xf6760015}},	//   _síðu_, gnak_, म्बद, _باتخ
  { {0x1005005d,0x7bdc002e,0xdb0a001a,0x867b000a}},	// [6840] रांश_, _örug, ínút, _דרקו
  { {0x6e29002c,0x22490375,0x7f460088,0x0d0a002b}},	//   _aleb, anak_, оезж, یقاً_
  { {0x91820092,0xdfcf00e6,0xa856000a,0x6e2200cb}},	//   iểm_, ضين_, קיעה_, tkob
  { {0xdd900115,0x645c1834,0x6e220085,0x7d260015}},	//   روت_, lori, ukob, يفان
  { {0x9f47002c,0x645c014b,0x6e2232c4,0xdb03005a}},	//   ľná_, oori, rkob, vaná
  { {0x9f4728cc,0x62830152,0x7c830457,0xab94005e}},	//   žná_, _énor, муще, чикі
  { {0xb2ba000a,0xcb070015,0xfba9005e,0xdb0332c5}},	//   ׁמַר, قيون_, стій_, taná
  { {0xbae50036,0x60d60026,0xa2cb000b,0x8f37000a}},	//   яцій, otym, तंत्, _ואלו_
  { {0x60d629ea,0xdb030227,0x645c32c6,0x3b960054}},	//   ntym, raná, kori, _дјет
  { {0x60d600df,0xb5fb0014,0x22490014,0xccf9005c}},	//   itym, alál, znak_, _myśl_
  { {0x22490064,0xda650086,0xcf93000a,0xbad60033}},	//   ynak_, _کالي, וטת_, _фізы
  { {0x46db000b,0x2a870030,0xe5a40004,0x15a8006b}},	//   _बहरह, _főbb_, миџи, жъри_
  { {0x61f60026,0x938b0063,0x645c32c7,0xf104000b}},	//   ddyl, исва_, fori, रमोद_
  { {0x9faf0064,0x201832c8,0x23970046,0xb5fb0030}},	//   _işçi_, _nori_, dějí_, mlám
  { {0x22490014,0x92940010,0xb5fb00dc,0xd5bb00ce}},	//   tnak_, дасц, llám, _ксп_
  { {0x0638002b,0x2abb0643,0x645c02b9,0xdb010030}},	//   _وسيع_, ימלא, aori, _jelá
  { {0xdcea0089,0x765d1dc1,0x2f8b0054,0x0577002b}},	// [6850] čnět, mosy, аљен_, _باغد
  { {0x224900dc,0xcf27002b,0x3a2d0061,0xcf9b03ae}},	//   snak_, يراي, zhep_, рја_
  { {0x20180011,0x224900dc,0x161f000b,0xdb080030}},	//   _dori_, pnak_, _पवार_, _fedé
  { {0xb5fb0014,0x5cf50010,0xfe700002,0x735a000a}},	//   klám, зяку, ندن_, _לכתח
  { {0x9f050086,0xcce70015,0xdca51c52,0x201802b9}},	//   _کوزو, تساي, чали, _fori_
  { {0x9f43002c,0x20c40010,0x2018044c,0x611a000a}},	//   _majú_, _ўсяг, _gori_, _הושה
  { {0xdb010030,0x63ba002a,0x1df90033,0x68e2129e}},	//   _belá, ótni, _левы_, _apod
  { {0x7a3e0024,0x6dc40080,0x645c0b04,0x69dc0030}},	//   sūtn, _осуж, zori, őren
  { {0xa3dc005d,0x645c2116,0xb17b02de,0x6faf0065}},	//   ण्ड_, yori, _ubåd, टरपं
  { {0xdb030144,0x32190bba,0xa7fc0061,0x5ba708ad}},	//   janç, _losy_, slın, _фраз
  { {0xdb0303af,0xb5fb32c9,0xc4c90008,0xdb0100dc}},	//   danç, mláj, _תג_, _felá
  { {0x765d00b6,0x60d600f2,0x99d40029,0x9aa40015}},	//   gosy, ytym, _يتنا, _آمنو
  { {0x2bd2014e,0x28060089,0x3cfe005d,0xdb080152}},	//   _सामा, ávní_, लिये_, _redé
  { {0x889a0008,0x78fa0008,0x645c00f2,0xa7fc0064}},	//   _הבסי, _לפנו, uori, nlıl
  { {0x479a0008,0x645c32ca,0xb7d6002b,0x2327201e}},	//   _פיקס, rori, _رويا_, пори_
  { {0x60d6022d,0x23970089,0x2bd2005d,0x74f60015}},	//   ttym, tějí_, _साभा, _فأخذ
  { {0xd2590010,0x20180026,0x22400020,0xa7fc0064}},	// [6860] ццё_, _pori_, riik_, klıl
  { {0xdb03001c,0xceea0010,0x60d629ea,0xe53b000a}},	//   canç, йдзе_, rtym, _לתפר
  { {0x1ee80086,0xbd8a0086,0xdfcf0087,0x60d632cb}},	//   توای_, منان_, ايم_, stym
  { {0x60d6005c,0xdd8f0031,0xb6ba000a,0x34b3002b}},	//   ptym, هوم_, מצעי, _تمیز
  { {0x127b00b2,0xac970029,0x62860035,0x7d060033}},	//   _לאטע, كننا_, _iiko, яздж
  { {0xddc2002a,0xdb030d4a,0x8aa61591,0xbd430058}},	//   lmoż, kanä, прид, عنوي
  { {0x6286003f,0xf3f10092,0xb5fb00dc,0xaac60029}},	//   _kiko, ội_, rmáz, ستثن
  { {0x8cc4014e,0xa9c30191,0xdb030064,0x28af000b}},	//   _रिपो, нськ, zanç, _फ़िशि
  { {0x19b70015,0x68fc003d,0x7a3e003d,0x49b70021}},	//   سطية_, ārdo, sūto, سايد_
  { {0x2cb70089,0x5c8b0008,0x3137000a,0x60c432cc}},	//   ředí_, _הָאֱ, פנים_, irim
  { {0x6a6500dc,0xe1ff002d,0xfaa332cd,0xdb9b000a}},	//   zófi, _mhór_, _захо, _הסבר
  { {0xae020231,0xb5fb0030,0x7866001a,0x62862f6b}},	//   _रोमन_, mlák, iðvi, _niko
  { {0xcdb70008,0xf9fb000a,0x68e203df,0x6fcc000b}},	//   הפכה_, _להאמ, _upod, ालां
  { {0x765d0035,0xddc2005c,0x3cef000b,0x628632ce}},	//   sosy, emoż, _इनसे_, _aiko
  { {0x60c40005,0xdb0332cf,0x27f70089,0xe7db000a}},	//   erim, ranç, řená_, _הקוש
  { {0xd7f80011,0x32640784,0x3e51002a,0xdb0300e9}},	//   ldă_, етув, kąta_, sanç
  { {0xdff50431,0x55bc0008,0x62860375,0x54550004}},	// [6870] мпањ, _המחו, _diko, _овит
  { {0xd7f804f9,0x44ef005c,0xe1ff32d0,0xa5bb1807}},	//   ndă_, _iż_, _phós_, chór
  { {0x4fc40010,0x2dd5034e,0xa857000a,0x6e990033}},	//   эста, джер, לימה_, цвер_
  { {0xb5fb0046,0x60c432d1,0x0000006a,0x0000006a}},	//   dlák, brim,   ,
  { {0x51fa0008,0xed58005e,0x22450046,0xa7fc0061}},	//   _והרצ, пої_, élku_, tlıl
  { {0x3cde000b,0xf092000a,0x6f01016e,0xe508000a}},	//   _गहरे_, _בנך_, _álco, ל֖וֹ_
  { {0x6f640080,0x6e95005e,0xa7fc0061,0x3ad20058}},	//   _звёз, _цибу, rlıl, نيوز
  { {0x68fb0020,0xb90500ce,0xd5ed00a1,0x0000006a}},	//   tvud, дзик, _nhà,
  { {0x68fb00c0,0xe021000b,0xa7fc0061,0xb5fb0030}},	//   uvud, _यवाद_, lmıy, mláh
  { {0xb8d5014e,0x8afc0050,0xa5bb002e,0x2c03000b}},	//   _जब_, _częs, skól, लाओं_
  { {0x44ef005c,0xa7fc0064,0xe020005d,0x9f96004f}},	//   _aż_, nmıy, _मकसद_, ודתה_
  { {0xd7f80011,0xd5ed0092,0x60c432d2,0x463a005e}},	//   adă_, _chà, yrim, ічня_
  { {0x628600f2,0xcdb60008,0xdb010061,0x0000006a}},	//   _riko, ופרה_, _belç,
  { {0x60c401e2,0xd6a8002b,0xa97a000a,0xa7fc0061}},	//   vrim, _کدوم_, _ואנכ, kmıy
  { {0xe7b20015,0x232a067a,0xe61a0004,0xd8760015}},	//   _شميد, цови_, _мдк_, _تموت_
  { {0x7aed002a,0x60c432d3,0x91061560,0x88bd0535}},	//   łatw, trim, мпбе, cyśc
  { {0x75460036,0x60c432d4,0x55bb000a,0x216732d5}},	// [6880] _іноз, urim, _ומפו, дити_
  { {0x2bd2021e,0x4f950004,0x60c432d6,0xd489004f}},	//   _साधा, ерцу, rrim, _צָפֹ
  { {0x9eea0029,0xdb0802de,0x628625d3,0xdb0a2fb1}},	//   تفال_, _uddø, _tiko, tafí
  { {0xd5ed0023,0x29000007,0xd7f80011,0xbea30010}},	//   _khá, _šiam_, zdă_, тацк
  { {0xa7fc0064,0xdb0a02c1,0x1549000a,0x8317002b}},	//   rmız, rafí, ּנוֹ_, _فقیر_
  { {0x88bd002a,0xdb0a010d,0xaf360015,0x644e047f}},	//   zyśc, safí, _قرأت, nnbi
  { {0x15ee005d,0xe811000b,0x7dc60015,0x8afc002a}},	//   ज़ार_, ़ाना_, _يترك, _rzęs
  { {0xf2d3013a,0x7f3b0008,0x7d1600cb,0xed5a2d8a}},	//   דעה_, _ועלו, øyss, _доб_
  { {0xd5ed0092,0x7c930015,0xad250015,0xd7c6004a}},	//   _nhá, _للقص, _كركو, мёно
  { {0x629e016f,0xdb0104d4,0xb5fb0f06,0xd7f80045}},	//   _otpo, _belä, mlái, udă_
  { {0xd7f80011,0xceb3000a,0x88bd002a,0xb5fb0125}},	//   rdă_, ֣יר_, tyśc, llái
  { {0xa5f90080,0xdb0132d7,0xdd110061,0xcb130447}},	//   чему_, _selç, nüşe, _בלע_
  { {0x95640063,0xa7fc0064,0xd5ed0016,0xb5fb0125}},	//   върд, nlık, _chá, nlái
  { {0x7d0400f2,0x69d500dc,0x3e75003c,0xe947002b}},	//   äisy, őzet, måte_, _ترمی
  { {0xd5ed0023,0x98a30007,0xb5fb002d,0xdb0100b8}},	//   _thà, ąją_, hlái, _gelä
  { {0x90990063,0xa7fc0064,0x31c4106d,0x96180015}},	//   зват_, klık, ксув, _يغير_
  { {0x682d002d,0xc0940015,0x44ef002a,0x1075004a}},	// [6890] _húda, نجلت, _uż_, елаю
  { {0xe811000b,0x44270016,0xa3d6000b,0x9f35008b}},	//   ़ाया_, _ôn_, _हाय_, незі
  { {0xfd100086,0x26cc02c1,0xd2510086,0x74580015}},	//   یجه_, nudo_, _مند_, _تشيس_
  { {0x60c20007,0x69dc00dc,0x63b50211,0xa7fc0061}},	//   šoma, őrej, lazn, rmıy
  { {0x34380086,0xada40033,0xeb991eb8,0xaceb00c3}},	//   _رسید_, таіл, пил_, ترال_
  { {0xdb03002e,0xa7fc0061,0x62980003,0x4c84005e}},	//   manú, pmıy, _évoc, влів
  { {0x60cd022d,0x999f002c,0x6a650030,0x61350030}},	//   luam, hnuť_, zófu, _fülé
  { {0x999f002c,0x61ed32d8,0x634e0030,0x0000006a}},	//   knuť_, neal, lőné,
  { {0x7c6700a2,0x63b532d9,0xdb03001a,0xa3c1000b}},	//   _قائل, kazn, nanú, ुला_
  { {0x699f005d,0x26cc0026,0xaae70015,0xe7390054}},	//   _ग्री, fudo_, _يساو, зео_
  { {0x61ed32da,0x6c1a000a,0x7e79000a,0x8e79000a}},	//   keal, _מֵאו, ּאָז, ּנָה
  { {0xd5ed0023,0x998d005c,0x8afa000a,0x4a55005e}},	//   _phá, nież_, _מהעי, _якес
  { {0xce36000a,0xa5bb001a,0x61ed32db,0x2e3a004f}},	//   תארת_, rhóp, deal, פגשנ
  { {0xa922002e,0x6a65001a,0xa5bb001a,0x26c500bc}},	//   _óþar, rófu, shóp, prlo_
  { {0x67d2000d,0x27f60086,0x26cc047e,0x91e63253}},	//   _соју, _سفيد_, cudo_, нове
  { {0xd5ed0023,0x11da0029,0x2bdf005d,0x2cad00da}},	//   _thá, ثورة_, प्ता, _owed_
  { {0x2bd2005d,0x63b50085,0x7646008c,0x60cd32dc}},	// [68a0] सलमा, bazn, miky, guam
  { {0xf3f10023,0x25dc005d,0x13a8002b,0xdb080046}},	//   ột_, ग्री_, _تندی_, _sedí
  { {0xf09f04ed,0x0eb90010,0xfbc9000b,0xb5fa000a}},	//   _età_, дучы_, _राजम, ּלְכ
  { {0xe29b0008,0x02460015,0xa7fc0061,0x61ed01f8}},	//   _משטר, _أَحَ, tlık, ceal
  { {0x621b0053,0x6a65002e,0xc3c9002b,0xbfc50046}},	//   _זוכק, hófs, _عظیم_, _říšs
  { {0xa7fc0064,0x3e58002c,0xf1bf0227,0xa5bb0030}},	//   rlık, dčte_, _zdá_, akóh
  { {0xb5fb32dd,0x6a65001a,0xf1bf001a,0xaa5805ab}},	//   slái, jófs, _slái_, мику_
  { {0x998d005c,0xbda50015,0x28a6005e,0xdd8f0015}},	//   cież_, _لحكو, ншог, _هوف_
  { {0x290232de,0xfce3006b,0xfbd2002b,0xd7fa2fe4}},	//   íka_, _йото, _متا_, пун_
  { {0xdb0604f9,0x26cc001c,0x9d2b000a,0x91820016}},	//   ămân, tudo_, _מֵבִ, iềm_
  { {0xd5ed0092,0x28c2005d,0x63b5206e,0x6c330015}},	//   _nhã, _शिवि, vazn, _حفلا
  { {0x999f002c,0x0ae90015,0x26c23109,0xf1bf006f}},	//   tnuť_, _تركي_, čko_, _hláv_
  { {0x61ed003e,0x28f80080,0x645a0227,0x9a250015}},	//   veal, _цель_, čtin, _جعلن
  { {0xaad4005d,0x9f47002c,0x76460007,0x389b00f3}},	//   _धमाक, ľnú_, aiky, _ציונ
  { {0x9f47002c,0xc1a70004,0x63b50d70,0xa29501c6}},	//   žnú_, ејзи, razn, табі
  { {0xfd260023,0xa3d6005d,0x60cd32df,0xc1cb000b}},	//   _đình_, _हाथ_, tuam, िलेग
  { {0x7c2a003c,0x865c000a,0x2c69006f,0x63b500bc}},	// [68b0] kkfr, _מדהי, súdi_, pazn
  { {0xc058042b,0xd4d80015,0x60cd007c,0x61ed32e0}},	//   ніх_, _أبيض_, ruam, seal
  { {0xc7b30008,0xfeb80015,0x61ed32e1,0xe811000b}},	//   רבע_, فانت_, peal, ़ाता_
  { {0x7a3e0007,0xadbc0036,0x644732e2,0x71750058}},	//   būti, зацi, liji, _لهجا
  { {0x999f005c,0x4e180029,0x244d006f,0xeb8e0004}},	//   ykuł_, عتمد_, eľmi_, ии_
  { {0x853c0008,0x3e670020,0xb4fc000a,0xef67006b}},	//   הגדי, võtu_, פלור, _зъбо
  { {0x2bd2005d,0x998d002a,0x660d32e3,0x539c000a}},	//   _सारा, pież_, _onak, ליגו
  { {0xaa560054,0x68240144,0xdb4e0015,0xdb0a001a}},	//   кију_, _mòdu, تَى_, kafæ
  { {0xac950063,0x9bc90015,0xdb0a0034,0x0b8b0004}},	//   _разш, _يورك_, rafá, _есеи_
  { {0x7c2a00c0,0x6c840015,0xa8020033,0x660d20f8}},	//   ckfr, _ملقم, азьл, _anak
  { {0x91820092,0xcf92000f,0xe5a607be,0xaac700c3}},	//   iếm_, יטי_, кини, _ستان
  { {0x25e9000b,0x0ab80015,0x9f430030,0x49da002b}},	//   ज़गी_, _أطلب_, _hajó_, _يانگ_
  { {0x2a8e002a,0x49b80058,0x7646005b,0x0000006a}},	//   _dębu_, _ساند_, riky,
  { {0x660d32e4,0xa8020064,0x44630063,0x764600f2}},	//   _enak, şırk, ивяв, siky
  { {0xc64a0029,0xfbd20008,0xc7d60008,0x2a6d0046}},	//   _يجعل_, יתם_, _יוסי_, oleb_
  { {0x29000007,0xdb08006f,0xddc232e5,0x0000006a}},	//   _šiai_, _jedá, kloš,
  { {0x7bc1010b,0xd186005e,0xe1230054,0x2bd2000b}},	// [68c0] _odlu, тлай, амти, _साला
  { {0xddc2016f,0x8fa6005e,0x25e3000b,0x70530015}},	//   dloš, таже, ट्ठी_, لنقا
  { {0x444432e6,0x7a3e0024,0x68fc0024,0xddc2006f}},	//   _im_, sūti, ārdi, eloš
  { {0x471a0053,0x78bb0607,0xdb080057,0x9ec50015}},	//   וועג, ksuv, _nedá, ازله
  { {0x7e620458,0x3e670020,0x95970008,0x30860015}},	//   roop, võtt_, דכנו_, _للحف
  { {0xdca30001,0x682d002c,0xad6500e6,0x853b000a}},	//   шаљи, _súdn, دامه, וגני
  { {0x99d60115,0x9057000a,0x7c2a001a,0x444432e7}},	//   نتظا, _סבלו_, rkfr, _mm_
  { {0xda09005d,0x0906005e,0xa2a7000b,0x7bc102de}},	//   वागत_, вчом, टीट्, _edlu
  { {0x8e550036,0xd105000b,0xbce50021,0xac860aa1}},	//   _стрі, रियण_, _مألو, _агал
  { {0x6e200467,0x88bd0050,0x4444037d,0x48140004}},	//   _homb, myśl, _nm_, умос
  { {0x64470085,0x61e632e8,0x3e750123,0x6e2032e9}},	//   viji, _obkl, låta_, _komb
  { {0x2911002f,0xf6d30086,0x444404dd,0x6e2001d7}},	//   ónaí_, گزید, _am_, _jomb
  { {0x6447016f,0x444432ea,0xb5fb0046,0xe1f3002b}},	//   tiji, _bm_, dlát, یسر_
  { {0xa5bb002a,0x316b002a,0x61e60012,0x2a6432eb}},	//   yków, _rycz_, _abkl, lomb_
  { {0x6e2000ad,0xeb91000a,0x4615002b,0xc348006b}},	//   _oomb, מָן_, _موثر, вяте_
  { {0x444432ec,0xe5e9022d,0xb5fb00dc,0x660d32ed}},	//   _em_, ämää, glát, _unak
  { {0xd658000a,0x90550033,0x64470091,0x444432ee}},	// [68d0] _שיחת_, гвац, piji, _fm_
  { {0x4ea70004,0xa5bb002a,0xe4530015,0x7d020085}},	//   врда, tków, _خضع_, dvos
  { {0xdd910029,0x42550086,0xd084004a,0xf2c40033}},	//   موا_, _مندر, рыти, _ксян
  { {0x74aa005d,0xcda80086,0x444432ef,0x29060123}},	//   जीकृ, نهمه_, _zm_, _oroa_
  { {0x44440176,0xb5fb00dc,0x44211613,0x518700d7}},	//   _ym_, llás, _koh_, _јуна
  { {0xbc64008f,0x913a0053,0xdc740010,0x27fc0293}},	//   авік, _טערק, агчы, _navn_
  { {0x2a6d0020,0x3cef005d,0xf4140135,0xb5fb00dc}},	//   tleb_, _इनके_, יפס_, nlás
  { {0x6e200014,0x2a6d0020,0xa3e3000b,0x998f006f}},	//   _gomb, uleb_, फ्त_, ťaže_
  { {0x0e440010,0x212900e8,0xb5fb0264,0x69c20034}},	//   _тэрм, nyah_, hlás, _ddoe
  { {0x1db3000b,0xb5fb0030,0x442132f0,0x6e2032f1}},	//   ुणवत, klás, _noh_, _zomb
  { {0x44440b71,0x99d50029,0x7c21002d,0x2906008c}},	//   _rm_, _مقات, _iolr, _eroa_
  { {0xb63600a2,0x212900d9,0x61fd32f2,0x629a0057}},	//   اعدت, kyah_, _nasl, ítom
  { {0x26de04ed,0x444432f3,0x442132f4,0x80d5000b}},	//   atto_, _pm_, _boh_, यूमे
  { {0xd4550036,0xdb0102e9,0xf3f10016,0x68ee0030}},	//   атсь, _belø, ộp_, őidé
  { {0x69c20034,0x88bd002a,0x96f60004,0xf745004a}},	//   _ydoe, zyśl, _бејт_, _щеко
  { {0xe811000b,0x44330144,0xc708000a,0x444432f5}},	//   ़ावा_, _elx_, _יִפֹ, _wm_
  { {0xb5fb0030,0x3fe632f6,0x41060033,0x6e202941}},	// [68e0] rlát, лжав, ызав, _romb
  { {0xb5fb32f7,0xdb03002e,0x61fd002d,0xe816005d}},	//   slát, danþ, _easl, ताया_
  { {0x0dca005f,0x224900dc,0x33db000a,0xa565002b}},	//   елей_, biak_, _אחיד, _مدین
  { {0xed5a005f,0x6e650036,0xee3a0010,0xb5fb00dc}},	//   ное_, атіж, эне_, llár
  { {0xc2130008,0x7d02008c,0xadb7006e,0xdb180012}},	//   _ההר_, uvos, اهها_, ngvö
  { {0x70560029,0x10160010,0x61e4169e,0x61fd32f8}},	//   _إنسا, _сьмя, lfil, _zasl
  { {0xbda60029,0x6e20073e,0x2ef8000a,0xab770015}},	//   _محذو, _tomb, _בִּב, همها_
  { {0xb5fb002f,0x48aa008d,0x61e432f9,0x29061ed2}},	//   hlár, нтом_, nfil, _proa_
  { {0x61e43072,0x8cca0015,0x88bd002a,0x3834249a}},	//   ifil, _سواق_, byśm, инир
  { {0x803700b2,0x00f7000a,0xd90d002b,0xd0f70c44}},	//   ָנטע_, נזים_, بیه_, נמית_
  { {0x9b93040b,0xab930029,0xb9e60036,0x26de32fa}},	//   _المت, _المغ, _біли, utto_
  { {0x7a350089,0x443800b8,0x1a9b0053,0xa906002b}},	//   _páte, ehr_, _נידע, _مبتن
  { {0x673a00dc,0x61fd0962,0x78a232fb,0x15f4000b}},	//   sztj, _rasl, _utov, इज़र_
  { {0xb4e5005d,0x493b000a,0xb5fb0030,0x61fd32fc}},	//   _नही_, _אגדו, tlás, _sasl
  { {0x0cd1014e,0x61fd0c80,0x62980152,0xa3d6005d}},	//   _सम्म, _pasl, _évol, _हार_
  { {0x53340b18,0xb5fb00dc,0x61e432fd,0x44380012}},	//   щест, rlás, gfil, ahr_
  { {0xa567003b,0xb6a50023,0x44210273,0x7bda07dd}},	// [68f0] _حدثن, _luậ, _toh_, _octu
  { {0xf1bf002f,0x61e40020,0xb5fb002e,0x661d0a00}},	//   _clár_, afil, plás, ljsk
  { {0x61fd0064,0x8db5017f,0xfe270210,0xaca30016}},	//   _tasl, аслі, льдн, _trịn
  { {0xddc2005c,0x61fd002d,0x661d01a3,0x753d002a}},	//   mnoś, _uasl, njsk, ozsz
  { {0xddc20050,0x7c2100e8,0xa7fc0064,0xc1ba000a}},	//   lnoś, _polr, nlıs, _במרש
  { {0x628f01c2,0xc49c000a,0x0000006a,0x0000006a}},	//   _hico, עשות,   ,
  { {0xf991003b,0xddc2005c,0x29030024,0xea59023e}},	//   يبة_, nnoś, ājam_, криј_
  { {0x89a60063,0x26c3006f,0x60cd32fe,0x08c5123e}},	//   акъв_, ájom_, oram, абин
  { {0xa3d6005d,0x26cc02c1,0x39350033,0x7d16008c}},	//   _हाल_, erdo_, рэйс, äyst
  { {0xaae7003b,0x3a2d020a,0xd7090080,0x661d002a}},	//   _مسؤو, skep_, вное_, ejsk
  { {0xddc2005c,0x61e41faa,0x79f5006b,0x6c8400c3}},	//   jnoś, yfil, _взех, _اللم
  { {0xddc20050,0x4a9a000f,0xa9090015,0xe8f50015}},	//   dnoś, _סינג, _ليصل_, _نستخ
  { {0x99830007,0xae1a004c,0x44380034,0xa50a0054}},	//   ėjų_, דורכ, thr_, њега_
  { {0xa93a0008,0xddc2002a,0x07390015,0x3e7c0046}},	//   _שתספ, fnoś, _لسبب_, míte_
  { {0x36d2000d,0x3e7c0227,0xe736006b,0xdb080012}},	//   _дојр, líte_, _вещ_, _gedä
  { {0x98a200df,0x64552d81,0x60cd32ff,0x201102b9}},	//   šką_, anzi, fram, _anzi_
  { {0x9f47002c,0xdb0304af,0x3e7c0057,0x60cd3300}},	// [6900] ľný_, vaný, níte_, gram
  { {0xf09f0092,0x9f470227,0xddc2002a,0x63800030}},	//   _tràn_, žný_, bnoś, gáné
  { {0xd7dd005d,0xbd8a0086,0x30750080,0x628f001c}},	//   _मानच, چنان_, сутс, _fico
  { {0xa3d6005d,0xb2bb0008,0x5de60457,0xb355002b}},	//   _हाँ_, _במטר, ржда, _ایفا_
  { {0xdb033301,0x7d090d2d,0x41030033,0x3e7c01c0}},	//   raný, _cres, _дзяв, jíte_
  { {0x3e7c0057,0xc4d3000a,0x8c430054,0x6284008c}},	//   díte_, קגו_, жеље, lmio
  { {0x661d005c,0x7d093302,0x3ae8002b,0xb6a50016}},	//   yjsk, _eres, ابتی_, _quậ
  { {0x0a6a0063,0x7d093303,0xdb080123,0x4efb000a}},	//   ърли_, _fres, _nedå, _בהלו
  { {0xa3d62033,0xddc2005c,0x229c001a,0xb4d5000b}},	//   हला_, znoś, _lík_, _हमे_
  { {0xd7f00029,0x29000007,0xdb03002a,0x63bc3304}},	//   أكد_, _šias_, ganó, jarn
  { {0x7d09005c,0xdc3b0008,0xfaa30210,0xeb970185}},	//   _zres, _שעבר, _дахо, _тих_
  { {0x3e7c0b7e,0x6aaa0012,0x47d4002b,0x63bc3305}},	//   bíte_, mpff, جيگر, earn
  { {0xdce00048,0xddc2005c,0x6284005c,0x628f3306}},	//   _izmē, wnoś, dmio, _rico
  { {0xddc2005c,0x645504ed,0x63bc3307,0xa9250015}},	//   tnoś, unzi, garn, _دعمه
  { {0xa87b000a,0x753d0030,0x628f3308,0x645502ad}},	//   _שאור, szsz, _pico, rnzi
  { {0x80c2005d,0xddc2005c,0x60cd3309,0xd234006b}},	//   _लिखे, rnoś, tram, онсъ
  { {0xddc2005c,0x518723cc,0x98ad002a,0x9f5804b2}},	// [6910] snoś, рува, rzeć_, _darí_
  { {0x60cd0e75,0x25e3000b,0x7d0902b9,0x98ad002a}},	//   rram, ट्री_, _rres, szeć_
  { {0xf09f0092,0xdb0a00dc,0x3e7c0057,0xb3f6000a}},	//   _trào_, bbfé, zíte_, _המתח_
  { {0xdb010107,0x7a3c0030,0x9e090015,0x7d0901d6}},	//   _celý, _hétf, طيتك_, _pres
  { {0xaca30023,0x787d0152,0xe216000a,0x3c390003}},	//   _trọn, lève, _הקרח_, _lève_
  { {0x1c440484,0x3e7c0057,0x9be7005e,0x8c67012e}},	//   онім, víte_, рідк, штед
  { {0xad9d005c,0xa3dc000b,0xcef40015,0x7d0908ff}},	//   _paźd, ण्ट_, _وأفغ, _wres
  { {0x61e90020,0x3e7c0227,0x4358000a,0x7d0904e2}},	//   _öeld, títe_, יסול_, _tres
  { {0x7d0900bd,0x3978004a,0x787d0003,0xdb03002a}},	//   _ures, исью_, hève, tanó
  { {0x3e7c002c,0xd7c90086,0x68450802,0x7a351421}},	//   ríte_, دوده_, ённа, _dáta
  { {0x78a9198d,0x3e7c04af,0x5b340015,0x9c640015}},	//   spev, síte_, _وعمر, _بهلو
  { {0xb9950029,0xdb260086,0xb0c7000b,0xd4da0033}},	//   _الإب, _دومی, _लिंग, льгі_
  { {0x89960008,0x99850029,0x63bc330a,0x53dc000b}},	//   _הכנס_, _الشو, tarn, _बादश
  { {0xe6920086,0xad1a000a,0x03a30c1c,0x6c79004c}},	//   _کليد, אושר, зиро, טאָפ
  { {0xcc76000a,0x1dd8000b,0xd299005e,0x63bc330b}},	//   מעשה_, _डालत, итті_, rarn
  { {0xd9f9005d,0x95960033,0x63bc330c,0x11da0015}},	//   ्यित_, _ушкі, sarn, طوطة_
  { {0x3ae10084,0xdb18330d,0x2615000b,0xf20d000b}},	// [6920] hóp_, ravé, धारी_, हाज़_
  { {0xdb010014,0x60cb002e,0x9588002a,0x351b000a}},	//   _belü, ágma, _ciąż, _עוינ
  { {0xdfa50029,0x93fb0053,0x67ba0053,0xc3fb0008}},	//   تحقي, _גליי, רמעק, _גליש
  { {0x6d03014e,0xadb70015,0xf2d3000a,0xddc2002a}},	//   लिंग_, مهما_, _צער_, wioł
  { {0x61f60064,0xbc4a02ed,0x0000006a,0x0000006a}},	//   meyl, лчке_,   ,
  { {0x6fd50191,0xdb010014,0x237f0089,0x7fd5022a}},	//   _місц, _felü, řuje_, _місі
  { {0x539b009d,0xa3d6000b,0x7bd80079,0xdb010012}},	//   ניקו, _हाई_, rgvu, _gelü
  { {0x648000f2,0xdb1f0089,0x644e330e,0xce34002b}},	//   löid, ívát, hibi, _بورک
  { {0x9e4b000a,0x644e330f,0x261c000b,0xad26002b}},	//   _עֲלִ, kibi, यानी_, _ارزو
  { {0xdb01005c,0x644e003f,0xb7d80015,0xf8af0015}},	//   _celó, jibi, جودا_, رةً_
  { {0x3916002b,0xb05b0123,0x61f60061,0x3c0f003d}},	//   _گوشز, _ovän, keyl, _dēvē_
  { {0xb05b00c0,0x98c40064,0x7a350125,0x4b7b000a}},	//   _nvän, ştık_, _táta, _גאבו
  { {0x59f90053,0xda6500e6,0xf919002b,0xda7b004c}},	//   _כּסד, _بالي, _نروژ_, _ענדר
  { {0x648000f2,0x3a260234,0x2295006b,0xf957000a}},	//   jöid, _hoop_, живя, _פסגת_
  { {0x3a260234,0x76a60015,0x2be0000b,0x31c70033}},	//   _koop_, _احتك, _नाना, йсав
  { {0xf4940086,0x644e0035,0x7a350097,0xdddb0091}},	//   _کشيد, aibi, _látn, _siuž
  { {0x32070089,0x644e3310,0x7bc8001a,0xf09f00a1}},	// [6930] ěny_, bibi, _oddu, _tràm_
  { {0x644e0467,0x75380008,0xddc9002c,0x3a262903}},	//   cibi, _לאחד_, _zmeň, _loop_
  { {0x3ea70234,0xa3c8000b,0xa1950c5b,0xe7ea000b}},	//   ënt_, ॉलर_, _манч, ज्या_
  { {0xed510074,0xdb0100dc,0x25e1005d,0x9588002a}},	//   وپا_, _velü, _काफी_, _wiąż
  { {0x6fb500c3,0xccc4005e,0x5fb50015,0xf1c40046}},	//   _ومحا, збій, _ومحط, stší_
  { {0x7c940086,0x9f581732,0xd116000a,0x14d8004f}},	//   سشها, _farà_, _וקשה_, מודל_
  { {0xdb01001c,0xdea40086,0x261c000b,0x6a851068}},	//   _reló, _فیلی, यामी_, олка
  { {0x644e0011,0x2003064e,0x5338000a,0x7ae3006f}},	//   zibi, _haji_, מנון_, rtnt
  { {0x20030375,0xf8a8002b,0x9f530003,0x3a260547}},	//   _kaji_, یدیه_, dexé_, _doop_
  { {0x752f005c,0x9f5802c1,0x68450033,0xd90c002b}},	//   dycz, _hará_, інна, ایو_
  { {0x86990083,0x2003000c,0xbb550086,0x764f002a}},	//   јтот_, _maji_, _بناب, ficy
  { {0x366a0001,0x2003008c,0xa50a01b7,0xc6330015}},	//   рамо_, _laji_, аема_, ِفَة
  { {0x2be0005d,0xf773002b,0x644e3311,0xfbe0000b}},	//   _नामा, _کاش_, tibi, _नामम
  { {0xb05b00c0,0x69db3312,0x88bd002a,0xdb010052}},	//   _svän, lgue, wyśw, _aflé
  { {0x644e3313,0x61f60061,0xe8160065,0x69db3314}},	//   ribi, teyl, तारा_, ogue
  { {0x3ebe0084,0x644e3315,0x69db3316,0xf6b6000a}},	//   _ætti_, sibi, ngue, _והקש_
  { {0x9f5802d7,0x80a60086,0x7a35163c,0x61f63317}},	// [6940] _sarà_, زمان, _láto, reyl
  { {0xdb08002c,0x66040705,0xaf360021,0xceea05ab}},	//   _vedú, _haik, يرات, идзе_
  { {0x66040945,0x44e400f2,0x648000f2,0x787a0008}},	//   _kaik, lö_, röid, בָאו
  { {0xf1bf0023,0xb76c0053,0xa6fa004c,0xce89002b}},	//   _hoán_, נדאָ, יִדי, مئنم_
  { {0x66040019,0xfd120067,0xb05b0123,0x9f580e51}},	//   _maik, بجا_, _kväl, _dará_
  { {0xc0f900b2,0x66041dc2,0x139a0008,0x69cf005c}},	//   _פּרט, _laik, ׁבְע, ócen
  { {0x752f0050,0x7a3c0014,0x34b7005d,0x9f58001c}},	//   zycz, _léte, _अब्द, _fará_
  { {0xa9c30036,0x1cba00a2,0xbb470015,0x7a35006f}},	//   мськ, _نائب_, غلين_, _dáto
  { {0x60c43318,0x58860033,0x443a3319,0x0000006a}},	//   nsim, жына, _olp_,
  { {0x9f4a0152,0xc173000a,0x7b160021,0x6c33002b}},	//   _abbé_, וחח_, _وظائ, _قفقا
  { {0x752f005c,0x907b00f3,0xeb97000a,0xd6d71092}},	//   wycz, שטיי, _ודבר_, отя_
  { {0x752f0050,0xc985002b,0xdb18001a,0x3ea50030}},	//   tycz, _کشمي, naví, _élte_
  { {0x66040007,0x78ad0227,0x3ce6331a,0x5fba000b}},	//   _daik, čový, ntov_, इराल
  { {0x7a3c038d,0x752f005c,0xdb080bfa,0x60c401ad}},	//   _déte, rycz, _bedø, dsim
  { {0x8c1b0008,0x752f005c,0x4394331b,0x60c4331c}},	//   סולי, sycz, дарс, esim
  { {0x3ce612d7,0xdb18331d,0x7a3c0030,0xbb3b000a}},	//   ktov_, javí, _hétb, בעלי
  { {0xcf9b0124,0x7c3a04ed,0x60c4331e,0xc5e80008}},	// [6950] аје_, _oltr, gsim, _וַתֹ
  { {0x7c280048,0xbfab0151,0x69c0331f,0xa98b000a}},	//   _nodr, ртае_, hame, בָבִ
  { {0x23fa0008,0x33fa0008,0x629a00dc,0xe7e2005d}},	//   _ההתא, _ההתנ, ítot, _खाना_
  { {0x7c3a196d,0x6e2200dc,0x0dcb0180,0xed590085}},	//   _altr, gjob, ружи_, _leže_
  { {0x721a000a,0x43d4002b,0xe45f0123,0x20030573}},	//   _הורח, _عزیز, bröt_, _taji_
  { {0xb4fc0008,0xb09a0008,0x5fe2000b,0xef67006b}},	//   יפדי, _לישר, _पायल, _дъбо
  { {0x764d00f2,0x7c280264,0xbef80015,0xfbd00015}},	//   _omay, _dodr, _ورفض_, ئته_
  { {0x69c03320,0xd35c000a,0x7a350030,0x44e41af8}},	//   game, ידול, _gátl, yö_
  { {0xe8e00092,0x6a640029,0x2ba70054,0x9be701c6}},	//   _đợi_, بطول, _дјев, _міжк
  { {0x6e3b0089,0xb09c000a,0xf8ae002b,0x69c0007c}},	//   _hlub, ביזר, اکن_, aame
  { {0x66040c58,0xdb230086,0x6e3b3321,0x98ab0061}},	//   _paik, _توضی, _klub, ılım_
  { {0x7c280111,0x60c41a91,0x8f1a000a,0x7a3c01c4}},	//   _zodr, ysim, צורת, _péte
  { {0x9cd501e4,0x4a440010,0x399a00a3,0x66043322}},	//   הוָה_, _ўнів, _הינד, _vaik
  { {0x86c50015,0x60c40061,0x7a3c0030,0xe7e2000b}},	//   _فيتن, vsim, _véte, _खाया_
  { {0x660400df,0x44e400f2,0x6fe2005d,0x261c000b}},	//   _taik, sö_, _पाबं, यादी_
  { {0x7a3c00dc,0x5eff000b,0xa5bb001a,0x3667005e}},	//   _téte, रबन्_, ljón, _нащо_
  { {0xf1bf0023,0x60c400df,0xf6530008,0xb1460254}},	// [6960] _toán_, usim, _רצח_, чнал
  { {0xdb03007c,0x443a042f,0x69c03323,0xaf9a187f}},	//   lanõ, _ulp_, zame, стах_
  { {0x9f580251,0x26c50026,0xdfcf00e6,0x60c43324}},	//   _març_, nslo_, طين_, ssim
  { {0x7c2800dd,0xf536000a,0x98a40091,0x23dc000b}},	//   _sodr, ּנַי_, lymą_, _बाँद
  { {0x10a3006b,0x200c016e,0xa0a30033,0xdb180227}},	//   _пиян, _ódio_, _паяд, raví
  { {0x26c50007,0x68e4008c,0x69c0158f,0x70930033}},	//   kslo_, _äidi, wame, _паўф
  { {0xcb070029,0xf413000a,0xd9f9000b,0x69c00d2d}},	//   كيون_, תפו_, ्यंत_, tame
  { {0xaf5b0008,0xad660015,0xdb1a0003,0x3ce608a9}},	//   _הכלכ, _فاذه, _jeté, ptov_
  { {0xa3dd005d,0x98a40007,0xd8e30010,0xdb1a0030}},	//   _डाल_, kymą_, нцэп, _meté
  { {0x69cb003e,0x6d3b000a,0x7c3a1647,0x69c03325}},	//   _edge, _התמנ, _ultr, same
  { {0x98a40007,0xb5fb00dc,0x4e00000b,0x7791002b}},	//   dymą_, mláz, _ईसाई_, نیها
  { {0x0f57013a,0x6b7b0632,0x3ebe002e,0x7a3500dc}},	//   ליים_, _פראנ, _ættu_, _látj
  { {0xab63002a,0xed5906c0,0x786f04d1,0xe4a707c9}},	//   ężen, _teže_, røvr, ярно
  { {0x29030024,0x78fb000a,0xe45f007f,0x0000006a}},	//   ājat_, _לפדו, erör_,
  { {0xcc770008,0xa87b000a,0xddc21dd6,0xf3140033}},	//   פעלה_, _האגר, dlož, ндрэ
  { {0xeb3b0053,0xa75b000a,0x645c0034,0x20180085}},	//   זעלש, _לדור, anri, _anri_
  { {0x236d005c,0x2007016e,0xdb1a016e,0x6e291cce}},	// [6970] łej_, ônio_, _deté, _roeb
  { {0xdfd10029,0xe53c000a,0x63870003,0x2f8b0054}},	//   ئيا_, _לתחר, géné, бљен_
  { {0x02a403e7,0xfe71002b,0xbf150015,0xdb1a0030}},	//   _прям, نگر_, بواب, _feté
  { {0xdd9100e6,0x765d038b,0x5cf5005e,0x9d550015}},	//   نوا_, nnsy, дяку, ونات
  { {0xdb010014,0xb1140010,0x3e7c0089,0x682d006f}},	//   _jelö, _змяш, mítl_, _múdr
  { {0x61ed3326,0xad9d0535,0x765d02ad,0x0000006a}},	//   lfal, _gaźn, hnsy,
  { {0x25a90034,0xdcfb06c0,0x61ed0034,0x6e2908cf}},	//   _ofal_, _izuč, ofal, _toeb
  { {0x6e3b005c,0x61ed3327,0xa2d5000b,0x2d070033}},	//   _ulub, nfal, _बटन्, _нязг
  { {0xb5fb00dc,0xe7d5005e,0x7c320030,0x261c0065}},	//   bláz, міню, ükrö, यासी_
  { {0x61ed0012,0x69c60030,0x25a90034,0x32092ece}},	//   hfal, óker, _afal_, hday_
  { {0x7b350015,0x5b250015,0x320900da,0xf771006e}},	//   _تفاؤ, _تفضل, kday_, ضاد_
  { {0x26c500df,0x5ee8000a,0xdb010123,0xa5bb001a}},	//   rslo_, הַשְ, _belö, sjón
  { {0x98a40007,0x25ef005d,0x2b5a002c,0x29030024}},	//   tymą_, ेज़ी_, ĺpce_, ājas_
  { {0x889a000a,0xe29a1372,0xdb03007c,0xe2aa00c3}},	//   _ובסי, жав_, sanõ, قارن_
  { {0xe7e2005d,0x91e60238,0x61ed1e13,0x22400012}},	//   _खाता_, мове, ffal, thik_
  { {0x11da0029,0xdb010030,0xf6520015,0x61ed2c90}},	//   تورة_, _felö, _جئت_, gfal
  { {0xdb0100b8,0xa0c90015,0xe45f0123,0x63870030}},	// [6980] _gelö, كذلك_, rrör_, téné
  { {0x7a3c0152,0x888a0053,0x61e9007c,0x78ad0061}},	//   _méta, ַרײַ, _öeln, _çavu
  { {0x441b00b2,0x4ea50036,0x141b0053,0x68e90020}},	//   _וויס, еріа, _וויב, hted
  { {0x68e901e2,0x63870030,0xddc20f81,0xb05b008c}},	//   kted, séné, slož, _yväk
  { {0x8c460063,0x25e3005d,0x7bc33328,0xfc66006b}},	//   меде, ट्टी_, fanu, мъкн
  { {0x93c50092,0xad65012c,0x2ca9202e,0x7bc33329}},	//   _nhằ, رانه, íada_, ganu
  { {0x160e005d,0xddc62320,0xa3e3000b,0x2a8e002a}},	//   ियार_, _обви, फ्ट_, _zęby_
  { {0x7bc30fb2,0x7a3c01bb,0x68e90595,0x998600bf}},	//   aanu, _béta, fted, _vlož_
  { {0xf9670010,0xa3c0000b,0x68e902de,0x765d00cb}},	//   дрэй_, ुणा_, gted, vnsy
  { {0xac83008f,0x7a3c038d,0x711b0053,0x7a35332a}},	//   _агул, _déta, קויפ, _láth
  { {0x61ed01e2,0xdc8b0008,0x6d670007,0xf8030033}},	//   yfal, _וְאָ, ąraš, тчын
  { {0xa4d5017f,0x68e900da,0xda650015,0x99860058}},	//   номі, bted, _كاني, _قلاو
  { {0x09360029,0xca370008,0x79360015,0xe4e4005e}},	//   _تراج, _קנדה_, _تعاط, кірн
  { {0x3e7521f0,0x7c380079,0x61ed00da,0xb97b004f}},	//   lått_, nkvr, wfal, _ונדי
  { {0x61ed1220,0xa5bb001a,0x87060033,0xf5390046}},	//   tfal, ljóm, _цяле, šť_
  { {0x3e5801c0,0x2509009a,0x61ed02ad,0x60d60416}},	//   očtu_, _فرخی_, ufal, frym
  { {0x60d60176,0x261c005d,0x3209003e,0xe9ff0092}},	// [6990] grym, यारी_, rday_, hiến_
  { {0xdb180014,0xdb0800b8,0xf878000a,0x61ed332b}},	//   zavá, _bedü, פְּל, sfal
  { {0x2cad0293,0x80bf000b,0x9df90a86,0x6455332c}},	//   _sted_, _लौरे, знет_, mizi
  { {0x200702c6,0x9757000a,0x6480008c,0x1757000a}},	//   žni_, ויבו_, nöin, וסבר_
  { {0xfe700029,0x4fc71179,0xdd940033,0x7bc3332d}},	//   جدل_, _осва, вацы, tanu
  { {0x7a3c0152,0x68e9002c,0x6455332e,0x6298016e}},	//   _réta, vted, nizi, _évor
  { {0x2be0005d,0xdab90010,0x6480008c,0x5dd70015}},	//   _नारा, чылі_, köin, _يترأ
  { {0xb9050001,0x6455332f,0x7bc33330,0x3e7502d2}},	//   език, hizi, sanu, gått_
  { {0x2d580146,0xe8f60139,0xcb09002b,0xdd120061}},	//   _жить_, елы_, زيکن_, müşt
  { {0x87250850,0x9c6b0054,0x64550012,0x9bf408d7}},	//   емож, _прaв, jizi, _изуч
  { {0x7a35002e,0x64553331,0x2902002e,0xa7fc0064}},	//   _láti, dizi, ækar_, nlıy
  { {0xdd120064,0xeaf80015,0x09f40015,0x8ab6000a}},	//   nüşt, _تركت_, _لأهد, _נהנו_
  { {0x6455018b,0x98e50029,0x7bc10375,0xa3f600f4}},	//   fizi, _أكتو, _kelu, нявш
  { {0x443e0014,0xe8d60008,0xd8d60053,0xfcb2002c}},	//   ót_, _נוצר_, _נוצט_, ýšiť_
  { {0x22160010,0x232a0063,0x7bc10509,0xb65a005e}},	//   нфар, чови_, _melu, _нших_
  { {0xe1ff3332,0x60d60845,0x80aa0142,0x9756000a}},	//   _skór_, trym, звав_, _ריקו_
  { {0xe0da3333,0x645502b9,0x41e1000b,0x61433334}},	// [69a0] ява_, bizi, _फारस, гета
  { {0x64553335,0x3fe30004,0x60d63336,0x7bc100d4}},	//   cizi, лжув, rrym, _nelu
  { {0x88bd002a,0x03bb004f,0xe7e20065,0xdb1a01d0}},	//   zyśp, _מציל, _खासा_, _udtø
  { {0x4d663337,0x8eb30086,0xf7720053,0xb5fb0046}},	//   нкев, امنش, נקא_, mnác
  { {0x62980152,0x7bc1013c,0xd657000a,0x25e1000b}},	//   _évoq, _belu, עינת_, कलती_
  { {0xdee60760,0x7bc13338,0xbca30015,0x3157004c}},	//   _поги, _celu, دموي, _װילן_
  { {0x3e750b56,0x7bc13339,0x8cc1000b,0x25e1000b}},	//   tått_, _delu, रीबो, _काली_
  { {0x3f7b004c,0x7bc1007c,0xa9c6002b,0xda17000b}},	//   _זאלס, _eelu, رزبو, थागत_
  { {0x0d860124,0x1e570008,0xed5907c4,0x7bc1333a}},	//   _члан, _נשמר_, _teža_, _felu
  { {0x6aa119a8,0x7bc1333b,0x98f30015,0x3959001a}},	//   _fulf, _gelu, اثيا, ússa_
  { {0x8c2b0008,0xdb24002b,0x9057000a,0xaae50015}},	//   _מֵאֵ, _جوای, תביו_, _لسنو
  { {0x200a0024,0x8b3b0008,0xbb3b0008,0xcad7000a}},	//   _labi_, _מתבצ, _מעבי, _טובת_
  { {0x648000f2,0x94ab01b7,0x6455333c,0x6f02002a}},	//   röin, ятна_, tizi, łoch
  { {0x200a064e,0xd498030e,0xd91b000a,0x8c3d0045}},	//   _nabi_, ерс_, _מודל, _iuşc
  { {0x6455333d,0xa6c70015,0xb05b0123,0xb5fb3079}},	//   rizi, _كوول_, _kväv, rnáb
  { {0xa3dd014e,0x645502d7,0xb77b0008,0xf60b0086}},	//   _डाक_, sizi, _מאוש, _رتبه_
  { {0x9099006b,0xb5fb0030,0x200a333e,0xdb18007c}},	// [69b0] дват_, anác, _babi_, lavä
  { {0xd2510074,0xb8810089,0x78a2333f,0x2f8b0054}},	//   _چند_, _říze, _muov, пљен_
  { {0x78a200f2,0x26de3340,0x6fe2000b,0x7bc13341}},	//   _luov, nuto_, _पारं, _relu
  { {0x7bc10849,0xf7730053,0x12e8000a,0x7ed40015}},	//   _selu, אקע_, _אַשּ, ازلا
  { {0x78a202d7,0x40950029,0x7bc10375,0xdd120061}},	//   _nuov, _للحر, _pelu, rüşt
  { {0x200a0035,0x8d740002,0xdb181581,0x3e7c002d}},	//   _gabi_, داما, kavä, híth_
  { {0x7bc10084,0xe452009d,0xdb180fb2,0xf24b000a}},	//   _velu, יֶה_, javä, ּגִּ
  { {0x7a3c0152,0x26de3342,0xc212000a,0x7a350030}},	//   _déto, duto_, ֹ֔ה_, _látv
  { {0xf865000d,0x2b5a002c,0xe9a80115,0x9815002b}},	//   квио, ĺpca_, ردين_, نبدا
  { {0x26de000c,0x6c970015,0xe739012b,0x7c970058}},	//   futo_, _أشرط, део_, _أشرا
  { {0xdbf9002a,0x366a008d,0x41e1000b,0xe6463343}},	//   _włók, дано_, _फांस, венп
  { {0xe7360036,0x64a63344,0x3ead0046,0xe7dd000b}},	//   тею_, кама, _četl_, _माकप
  { {0xd4f50010,0x26de05ff,0xda1e0065,0xab5c01ec}},	//   ляры, auto_, भारत_, _ieļa
  { {0x987900b2,0xb5fb0089,0xc952004c,0xc7a20248}},	//   _קאַט, tnác, _דמד_, _кишк
  { {0x200a3345,0x321a002b,0x7aac004f,0x42d5004e}},	//   _rabi_, ويسد_, ּׁמֵ, літу
  { {0x66f6000a,0x200a02f2,0xb5fb3346,0xcb12000a}},	//   _ימצא_, _sabi_, rnác, סלן_
  { {0x200a0034,0x71a30a32,0x21a31068,0xdb1a039f}},	// [69c0] _pabi_, рауз, риум, _retí
  { {0x937a0015,0x1476002b,0xe043006b,0xc05900ce}},	//   _يصدر_, _جابج, ануи, ніє_
  { {0x93b7000a,0x200a00bc,0x3e7c0030,0x6480008c}},	//   _שלטו_, _vabi_, líti_, nöim
  { {0xee3a078f,0xadb70029,0xed5a0080,0xec130086}},	//   ьне_, نهما_, мое_, یوند
  { {0x3e7c00dc,0x8d1a0086,0x200a1d6c,0x8cf40015}},	//   níti_, بزار_, _tabi_, اكتش
  { {0x61e401e2,0x0fda0029,0x8fa6000d,0x5c7302e5}},	//   lgil, _تبحث_, _јаве, аліт
  { {0x7a350f3c,0x61e4007c,0xe091002b,0xf1bf0016}},	//   _látu, ogil, _ایلخ, _soái_
  { {0x26de02d7,0x61e43347,0x6cd60015,0xbda50015}},	//   vuto_, ngil, _لقرا, _محكو
  { {0x6c060001,0xc27b0008,0x127b004c,0x2d840085}},	//   _изаз, ורקי, ואקע, _uzme_
  { {0x25a001d7,0xd8f5002b,0x26de2a8c,0x0aea0058}},	//   _agil_, ازيک, tuto_, _يرضي_
  { {0x1037000a,0xdb0102de,0xfc46006f,0x7e623348}},	//   דטים_, _aflæ, žísk_, onop
  { {0xf1e1000b,0x78a2008c,0x6480008c,0xba170015}},	//   _फाइन, _tuov, söil, _ليما_
  { {0x3e7c00dc,0xdb18014b,0x4615002b,0x26de3349}},	//   gíti_, savä, نوگر, suto_
  { {0xe45f00c0,0x8c3d0064,0x7a35163c,0x2937000a}},	//   msök_, _kuşa, _dátu, _באדן_
  { {0xe81f005d,0xdcc80092,0xf1a7000d,0x7e620409}},	//   बारा_, hỉ_, врзн, knop
  { {0xb797000a,0xdde100bc,0xdb1a0144,0xf66b0015}},	//   _בכוח_, _žuže, _metà, _تحته_
  { {0x7a35002e,0xa2940036,0x68e00064,0xf599005e}},	// [69d0] _gátu, раті, numd, _явищ_
  { {0xc104003b,0x351a0008,0x7a35087d,0x7e6202de}},	//   ؤولي, _נותנ, _hátt, enop
  { {0x53350bb9,0x320b002a,0x660d334a,0x7a35006f}},	//   _сент, _tacy_, _kaak, _zátu
  { {0xd251002b,0x68e0003d,0x660d0601,0x0000006a}},	//   _چنگ_, kumd, _jaak,
  { {0xd7f10092,0x84f5000b,0x660d334b,0x7a35001a}},	//   hĩa_, ेबिट_, _maak, _mátt
  { {0x69c60084,0x7a35331d,0x853c000a,0x6f15002a}},	//   ðken, _látt, וגדי, _trzc
  { {0x629d334c,0x9be40036,0xadbd02e1,0xe45f00c0}},	//   _kiso, річк, _навi, esök_
  { {0x200100d9,0x60cd334d,0x539c004c,0xb05b008c}},	//   lehi_, osam, ויוו, _evät
  { {0x3d940191,0x60cd334e,0x629d0e18,0xad19000a}},	//   _витр, nsam, _miso, _אוּר
  { {0x7d090020,0x7b0800f2,0x25a00026,0xfc300015}},	//   _ises, ästä, _sgil_, _وحل_
  { {0x6d680011,0x2bc8000d,0x99f50033,0xe739018d}},	//   ăsaţ, _шуто_, _бялі, хен_
  { {0x20cf0024,0x09e4005e,0xd62a005e,0x6480008c}},	//   kļi_, _воїн, хоме_, röim
  { {0xd6ce0086,0x61e40061,0x0000006a,0x0000006a}},	//   يقی_, vgil,   ,
  { {0x60cd334f,0x3e7c0030,0x64a32527,0x66e51943}},	//   dsam, ríti_, сара, _бока
  { {0x3e7c00dc,0x629d052a,0x61e41776,0xd808000a}},	//   síti_, _biso, tgil, _יִקָ
  { {0x3e7c0030,0xb5fb0030,0x969508f0,0x41b53350}},	//   píti_, lnán, _крыш, исут
  { {0x7644000c,0x60cd3351,0x61e43352,0x7a350030}},	// [69e0] _iliy, gsam, rgil, _háts
  { {0x84060036,0x660d005c,0x629d0026,0xb5fb0125}},	//   _спож, _zaak, _eiso, nnán
  { {0x44443353,0x7a3500dc,0x76440035,0x7d09137b}},	//   _il_, _játs, _kliy, _ases
  { {0x5d6a005f,0xb05b002c,0x27760053,0xb5fb0046}},	//   нием_, _svät, אגען_, hnán
  { {0x7a3500dc,0x20170030,0x55bb000a,0x62a9003d}},	//   _láts, íció_, גמנו, ēpoš
  { {0x444400e8,0x7e6200f2,0x4c94004a,0x6ec6002b}},	//   _jl_, snop, шилс, _مترق
  { {0xb5fb0089,0xb05b00f2,0x9f4a00f2,0xdb1a0030}},	//   dnán, _eväs, äjän_, _betá
  { {0xdd08032c,0x2be0005d,0x44441a62,0x3e51002a}},	//   môže, _नाका, _ll_, kąty_
  { {0xdbf9005c,0x8cdb000b,0xa9670054,0x8d660033}},	//   głów, _नियो, лића_, _свае
  { {0xe45f01d1,0x68e001e2,0x44440298,0x3cfb0008}},	//   rsök_, rumd, _nl_, _אלמנ
  { {0xc0770053,0x3ad30015,0x7c930015,0xddcb00bc}},	//   רגיז_, _هيلز, _اللص, logš
  { {0xd6d70080,0xdb0800c0,0x7f3b004c,0x7bca0e63}},	//   ыть_, _bedö, געטו, lafu
  { {0xdca60029,0x629d3354,0x0936002b,0x44443076}},	//   تى_, _riso, _حراج, _bl_
  { {0xf99301d8,0x7bca3355,0xd7f80045,0x3913002b}},	//   _פרס_, nafu, onăm_, _دوهز
  { {0x77920086,0x8c1b000a,0x629d3356,0x439507c3}},	//   _دیدا, עולי, _piso, равс
  { {0xf1271e88,0x53980036,0x7a3500dc,0x44443357}},	//   льзо, увся_, _hátr, _el_
  { {0x9055008f,0xd49b3358,0x60cd00b8,0xa3d50ea6}},	// [69f0] авац, _про_, usam, _копч
  { {0x60cd3359,0x6480008c,0x2be0000b,0xb4fc000a}},	//   rsam, jöih, _नागा, _טפחי
  { {0x629d00bd,0x30780015,0x749a000a,0x60cd335a}},	//   _tiso, احقة_, _שיתפ, ssam
  { {0xb5fb0089,0x60cd2663,0x6dc70015,0x787d0144}},	//   znán, psam, ازال, rèvi
  { {0xb05b0123,0x644b0091,0x1d091119,0x16c1000b}},	//   _dvär, _įgij, тели_, _शब्ब
  { {0x26d1002c,0xab5c0024,0xe29f002e,0x6fe2000b}},	//   ázok_, _ceļo, _hið_, _पाएं
  { {0xb5fb0089,0x441c000a,0xdd050061,0x7a3c0030}},	//   vnán, תווס, ısız, _kéth
  { {0x4df90053,0x44210618,0x3208000a,0xe8f9335b}},	//   _שפּא, _lnh_, ָ֖הּ_, вли_
  { {0x7a3c0152,0xe29f002e,0x22490375,0xa805006b}},	//   _méth, _mið_, ihak_, азпл
  { {0xb8fd005d,0xc795004a,0x69c9007c,0x0835006b}},	//   _तट_, ирны, saee, рхия
  { {0xf529000a,0x69cf0077,0xf626335c,0xb5fb335d}},	//   _קץ_, óces, адно, rnán
  { {0x44210023,0x7ae3335e,0x06560033,0xdb1a063b}},	//   _anh_, munt, ртоў, _betæ
  { {0x64a60329,0x4433335f,0x7ae303b0,0x44443360}},	//   рага, _box_, lunt, _pl_
  { {0x99840029,0xc9640036,0xe4760010,0xa5070001}},	//   _الهو, _увій, румэ, јера_
  { {0xb77900b2,0xe29f002e,0xe2b50010,0xd5e40092}},	//   _באַש, _bið_, йстэ, _chị
  { {0x7644003f,0x7ae33361,0xceb80091,0x682d006f}},	//   _uliy, iunt, _įę_, _núdz
  { {0x067b000a,0x443303b8,0x4fb60015,0x7bca3362}},	// [6a00] _שנפל, _fox_, لصار, yafu
  { {0x44443363,0x7ae3022d,0xf1bf0092,0xc8dd005d}},	//   _ul_, kunt, _soát_, _मिनट
  { {0xaf061bc8,0x7f190033,0x5ed6002b,0x7dc60015}},	//   рпел, ліцу_, شتاز, لتشك
  { {0x13a80086,0xb5fb00dc,0x645c3364,0x7a3c0030}},	//   _جنگی_, jnál, liri, _vétk
  { {0x7bca0f4d,0xcfaa0087,0x91bb000a,0xc1bb000a}},	//   tafu, _لازم_, _במכי, _במכש
  { {0x394d0024,0x80bf005d,0xe7ea000b,0xa5bb001a}},	//   dzes_, _लौटे, ज्ञा_, ljót
  { {0x0b180029,0xcb070225,0xb05b00c0,0x7ae30e0c}},	//   اقبة_, ليون_, _tvär, gunt
  { {0x645c3365,0x6480008c,0x7a3519fe,0xb5fb0154}},	//   hiri, söih, _sátr, gnál
  { {0x8c3d0061,0xc7b00015,0x645c3366,0xc866006b}},	//   _kuşl, ًّة_, kiri, итои
  { {0x7a3c0152,0xa7fc0064,0xb5fb0227,0xfc64002b}},	//   _méti, anın, anál, _اخری
  { {0x645c3367,0xcb67118f,0x0000006a,0x0000006a}},	//   diri, _кафе_,   ,
  { {0x8c3c01e2,0xe7e2005d,0x645c3368,0x44332b92}},	//   _diğe, _खाका_, eiri, _sox_
  { {0x7bc8013c,0x1a9b004c,0x61f602de,0xc8d7005e}},	//   _kedu, _סידע, dfyl, _вміє_
  { {0xd7ef0029,0x645c3369,0x493b000a,0xad640016}},	//   _يكن_, giri, _בגדו, _đừn
  { {0xeab4000a,0x7792002b,0xd5bb09c3,0x61f60034}},	//   מִּי_, _گیگا, _исп_, ffyl
  { {0x645c002d,0xd9f8005d,0x61d80080,0x079b000a}},	//   airi, ्जित_, имся_, _בסול
  { {0xe29f09f0,0x765d07d2,0x2249013c,0x91c9000b}},	// [6a10] _við_, misy, rhak_, ़रबै
  { {0x2fc700a7,0xb5fb336a,0x62880251,0x7e7b336b}},	//   úng_, znál, ïdor, _skup
  { {0x753d0030,0xcef50054,0xbfa80033,0x394d08e2}},	//   lysz, спећ, ртуе_, zzes_
  { {0xf1ab0086,0xda660015,0x765d336c,0x7a3c0f63}},	//   _جاده_, _رُ_, nisy, _féti
  { {0x4255002b,0xdca501c5,0x753d0030,0x9f58030b}},	//   _ننگر, щали, nysz, _baró_
  { {0x01360008,0xec780036,0xcaf50015,0x6cd20015}},	//   _הרשת_, апі_, مسبب, أقوا
  { {0x8b940063,0x7ae300f2,0x3e7c00dc,0x7bc800d1}},	//   оръч, uunt, gíts_, _dedu
  { {0x7e7b336d,0x394d336e,0xed590796,0x3a3f013c}},	//   _ukup, tzes_, _leži_, ukup_
  { {0x2011000c,0x98a30007,0x63a5002d,0x26de336f}},	//   _kazi_, ąjį_, _oghn, erto_
  { {0x69c40020,0x7ae33370,0xdb1a08e9,0x6c850015}},	//   _õien, punt, _betä, _الطم
  { {0x394d0014,0x44260092,0x915e0092,0x2011003d}},	//   szes_, _đo_, _mắc_, _mazi_
  { {0x645c0026,0x6480008c,0x7d1b3371,0x4efa000a}},	//   wiri, nöiv, _krus, נהרו
  { {0xba74003b,0xca740029,0x753d00dc,0x645c3372}},	//   _بالت, _بالغ, gysz, tiri
  { {0x17070086,0x765d0007,0xd8b80015,0x7a3c0003}},	//   _نفتی_, aisy, _ضدها_, _réti
  { {0x765d0035,0xf7730067,0x5315006b,0x28dd000b}},	//   bisy, _باش_, офту, _मिडि
  { {0x645c0780,0x28c4005d,0x7a3c0003,0x753d002a}},	//   siri, लीवि, _péti, bysz
  { {0x61f6002e,0x20113373,0x11d70015,0xd295005e}},	// [6a20] rfyl, _bazi_, صولة_, ірсь
  { {0x224000dd,0x61f61db6,0x66063374,0x0000006a}},	//   skik_, sfyl, lekk,
  { {0x1ea9003b,0x2d800024,0x7d1b264d,0x1fb53375}},	//   لاني_, ļiem_, _arus, юстр
  { {0x7d1b1160,0x8c3d0045,0x98bf002a,0x7a3c0030}},	//   _brus, _duşm, czuć_, _hétv
  { {0x8c3d0064,0xed5a0029,0x7bc8013c,0xf1b3000a}},	//   _tuşl, دشات_, _pedu, _מסר_
  { {0x69dd002e,0x765d0064,0x6c340029,0x2ac60054}},	//   ósen, zisy, تفتا, бљив
  { {0x753d0050,0x6af30029,0xb2ba000a,0x66060030}},	//   zysz, كثير, אמֶר, kekk
  { {0x2618005d,0x7f3b0053,0x66060bad,0x7bc80079}},	//   _बोली_, _געלו, jekk, _wedu
  { {0x765d00d9,0xed46009c,0x78260015,0xcce50015}},	//   visy, _унап, معدل, _وسكي
  { {0x6b810084,0x3137009d,0x0137000a,0x0854005e}},	//   _fylg, צנים_, צרית_, івню
  { {0xbb860029,0x27170092,0x907b0135,0x307b000a}},	//   _الاي, _căn_, רטיי, ראינ
  { {0xdb1a00f2,0x660600dc,0x3cd2000b,0x753d0535}},	//   _vetä, gekk, _सिफ़ा, tysz
  { {0xb996003b,0x765d00b6,0x67d43376,0x18f30058}},	//   _الشب, risy, _долу, _فأوج
  { {0x765d00b6,0xb97b004c,0x26de00bc,0x62843377}},	//   sisy, _ענגי, prto_, elio
  { {0x765d3378,0x27e3002a,0x7ad8000a,0x8ad8000a}},	//   pisy, ójne_, יַּה, יַּפ
  { {0x628402d7,0x915e0016,0xf7830058,0x68e00546}},	//   glio, _sắc_, _عليَ, ormd
  { {0xc035000d,0x26d1002c,0x98bf005c,0x40350010}},	// [6a30] онај, ázov_, rzuć_, оеас
  { {0x68e0003d,0x62843379,0x0000006a,0x0000006a}},	//   irmd, alio,   ,
  { {0x5e870010,0xde350010,0xedd50029,0xff530029}},	//   будз, жэль, قياد, أخذ_
  { {0x2011003f,0xf12704ab,0xb5fb0030,0xc332000a}},	//   _wazi_, _льго, liáb, _חוט_
  { {0x915e0092,0xbbe90029,0xdc99005e,0x6480008c}},	//   _tắc_, لرغم_, авді_, röiv
  { {0x7d760015,0xb5fb0030,0x66060030,0x23cb000a}},	//   غمور_, niáb, zekk, אצַּ
  { {0x447c0053,0xf43c000a,0x1a2901e5,0x7a3c001a}},	//   אנגע, רגומ, ижки_, _létu
  { {0x648000f2,0x99850015,0x8c3d0061,0x27170016}},	//   löit, يلثو, _kuşk, _răn_
  { {0xaca30092,0x6aa220b3,0x4238000a,0x27170016}},	//   _trốn, _diof, מנהל_, _săn_
  { {0xddc2002a,0x6480008c,0xc8650015,0x660608cf}},	//   choł, nöit, تطعي, wekk
  { {0x89d90086,0x62840026,0x61fd0107,0x6606337a}},	//   _نوار_, ylio, _obsl, tekk
  { {0x27170023,0x28f90080,0x59c40029,0x78bb0201}},	//   _văn_, _ведь_, _فيمك, ppuv
  { {0xa5bb0084,0x6606337b,0xda080015,0x1416005e}},	//   tjór, rekk, _دينه_, оєвр
  { {0x648000f2,0x2d8d003f,0x660616a1,0xb5fb0030}},	//   jöit, _mzee_, sekk, giáb
  { {0x03a300a5,0x2bfb000b,0x78ab001a,0x66060030}},	//   диро, ल्यू_, _hugv, pekk
  { {0xcb12039e,0x6284290a,0x69cb337c,0x26d104b2}},	//   ולל_, ulio, _jege, ázou_
  { {0x2d8d003f,0x2b5a002c,0x06970015,0x69cb337d}},	// [6a40] _nzee_, ĺpci_, _بنية_, _mege
  { {0x57cc00b2,0x6fd50010,0x69cb337e,0x7a3c0030}},	//   ָמאַ, зіцц, _lege, _hétt
  { {0x1eda0029,0xeda60760,0x78a3337f,0x232a15ee}},	//   شباب_, ошло, _minv, _тони_
  { {0x5bb4000b,0x69cb3380,0xf8a70015,0xf5ad000a}},	//   ुर्व, _nege, _ية_, ְבוּ
  { {0xc27b013a,0xf6530008,0x3246002b,0x8fe60015}},	//   _כרטי, וצא_, _هنگف, _وأسم
  { {0xdfd20074,0x8c430080,0x7f760010,0x251b000a}},	//   _زير_, мече, _дубц, יונא
  { {0x69cb186c,0x6480008c,0x291d02f2,0xda4a024f}},	//   _bege, löis, _arwa_, ичил_
  { {0xb5fb0f87,0xe45f00c0,0x539b000a,0x6edc0045}},	//   rnák, nsör_, סיקו, răbă
  { {0xed5a0083,0x69d90026,0x648000f2,0x99970063}},	//   _тоа_, _ddwe, nöis, окът_
  { {0x29da0016,0x6d37004f,0x0000006a,0x0000006a}},	//   ừa_, _וטמא_,   ,
  { {0x501b000a,0x69cb3381,0x7c9b000a,0xd7f80045}},	//   בויו, _fege, _כשמג, rfă_
  { {0xa5f90080,0x6f790008,0x8b6500e6,0x69cb3382}},	//   щему_, מְרו, _عالم, _gege
  { {0x7e9b01e4,0xb8650086,0xb5fb002d,0xca97000a}},	//   יסטו, _کانو, nnái, _ודאי_
  { {0xaaa9005d,0x69cb0079,0xc8170015,0x3ea400cb}},	//   _चूँक, _zege, _وينص_, _limt_
  { {0x3a260991,0xb5fb3383,0x67bb0008,0xd25b1811}},	//   _knop_, riáb, _דמוק, аца_
  { {0xd5bb005e,0xb21b02de,0xdb1f0030,0xb5fb0030}},	//   _тск_, _skæb, övér, siáb
  { {0x3fab0124,0xc6940053,0x25a90020,0x6480008c}},	// [6a50] ањем_, _קאפ_, _igal_, töit
  { {0x7a3c00dc,0x24b80008,0x644e0334,0x88bb000a}},	//   _kéts, _והזן_, chbi, יזמי
  { {0x648000f2,0xb5fb002c,0xaaa9000b,0x1048005e}},	//   röit, ciác, _चूंक, цяти_
  { {0x9f58002e,0x7bda0030,0x2d9901c0,0xae5800ce}},	//   _varð_, _adtu, _úsek_, оріє_
  { {0x63b5002a,0xb5fb0030,0x7a3c0030,0xdb1a016e}},	//   oczn, rnáh, _léts, _getú
  { {0x113a01e4,0xfaa513df,0xc19a000a,0x6ee70015}},	//   _התשל, пако, _לשרי, _وسأل
  { {0xeb990a61,0xfe7300e5,0x6bd60015,0xd0100015}},	//   щик_, _قدر_, سويس_, _جلّ_
  { {0xefc80092,0xe9d10015,0x61ed3384,0xb9190058}},	//   _đỉnh_, رغب_, ngal, متخذ_
  { {0x7a3c0084,0x69cb3385,0x7c870054,0xb5fb006f}},	//   _rétt, _vege, _дуже, ziác
  { {0x1bf2005d,0xa2dc005d,0x69cb08e1,0x25b6000b}},	//   _घायल_, _फिल्, _wege, ूर्ण
  { {0x69cb3386,0x1e950008,0xc052000a,0xed593387}},	//   _tege, ּכָל_, גזי_, _vežu_
  { {0x63b5005c,0x291d005c,0xaca30092,0x8afa000a}},	//   eczn, _trwa_, _trồn, _להעי
  { {0x28f80010,0x03a60001,0x04b603fc,0x80b0000b}},	//   _мець_, зиго, ясня, _अंधे
  { {0xa5070001,0xdd56000a,0x2ab1001a,0xfc27006e}},	//   џера_, לברט_, _káb_, رح_
  { {0xc7b20008,0x28120029,0x68e9008c,0x75d60015}},	//   _אבו_, _سويس, lued, _فيغا
  { {0xcb1200b2,0x57560008,0x673c0197,0xd6da0008}},	//   עלן_, _מבצע_, ärje, _החקל
  { {0xb5fb006f,0x41270923,0x80a6012c,0xdd2900ce}},	// [6a60] siác, пото_, سمان, _вхiд_
  { {0x3ea40011,0x61ed1634,0xe0d7042b,0xe45f0123}},	//   _simt_, agal, яву_, ssör_
  { {0xe45700b2,0xc43b0008,0x643b000a,0x66160061}},	//   _זייט_, _התיי, _העינ, _kayk
  { {0x7a3c0014,0x443a1061,0x0000006a,0x0000006a}},	//   _létr, _hop_,   ,
  { {0x7cd70036,0x721b0008,0x443a016b,0x2ca50b1c}},	//   змір_, _הוכח, _kop_, _bild_
  { {0x1eaa0029,0xb5fb03d9,0x14d7000a,0x68e90034}},	//   _هاري_, rnái, לונל_, dued
  { {0xaab80086,0x044d000a,0xc8790045,0x6023134f}},	//   زگار_, שׂוּ, cuşi_, _ядра
  { {0xeaaf0029,0x28dd000b,0xe9e30238,0x98b81635}},	//   دعو_, _मिशि, нцьо, олит_
  { {0x63b50050,0x68e90026,0x443a3388,0xb5fb016e}},	//   yczn, gued, _oop_, onáv
  { {0x31570008,0x2ca5002e,0x60d60091,0x61ed3389}},	//   פיין_, _gild_, isym, zgal
  { {0xab7a0086,0x7a3c0152,0xa2b1005d,0x27e3002a}},	//   _امضا_, _détr, _आंध्, ójna_
  { {0x60d623c1,0x645e04ed,0x8c3d0011,0x7e62338a}},	//   ksym, _ampi, _ruşi, niop
  { {0xd90e0086,0xab5c003d,0x89f50033,0x443a20e2}},	//   _صید_, _ceļv, _цяхц, _bop_
  { {0x443a08e0,0xdb1a0293,0xf8b7000a,0x61ed0034}},	//   _cop_, _betø, _צפוי_, wgal
  { {0x1dcc005d,0xd7fb0008,0x57fb0008,0xb5fb0057}},	//   ारात, _ההול, _הלוו, dnáv
  { {0x6234338b,0xe2840004,0x645e16c8,0x72050015}},	//   несу, еѓун, _empi, بورم
  { {0x61ed338c,0x10070010,0xd904002b,0x365c000a}},	// [6a70] rgal, зяем, دی_, _לכהנ
  { {0xc87904f9,0x7c3a338d,0xbfab0010,0x6d420061}},	//   tuşi_, _notr, стае_, dyoa
  { {0x33fa0008,0xfeb80029,0x23fa000a,0x2cad00da}},	//   _והתנ, كانت_, _והתא, _sued_
  { {0x28dd000b,0xf2d2004c,0xb6a40016,0xc8790045}},	//   _मिलि, _בעט_, _nhẫ, ruşi_
  { {0xd5fc0053,0xc8790011,0x7c95002b,0x6ca7033d}},	//   מפאר, suşi_, وشتا, чреж
  { {0xa0a40010,0xf1c40264,0x1c44005e,0x68e9008c}},	//   _паўд, prší_, ннім, vued
  { {0xfbd0338e,0x764d0064,0x7c3a005c,0x7a3c0003}},	//   اته_, _olay, _dotr, _rétr
  { {0x7c280c83,0xca060063,0x3ebc002c,0x2ca50b9d}},	//   _endr, днъж_, ívte_, _wild_
  { {0x2cad0020,0x7a3c338f,0xfe70002b,0x8d15005e}},	//   _uued_, _pétr, _صدف_, _юдаї
  { {0xefc80023,0x103a0053,0xb905000b,0x2ab10125}},	//   _định_, ַגרע, _फि_, _táb_
  { {0xc7a50004,0xddc20085,0xcfb6000a,0x501c004f}},	//   ќинк, lnoš, ולתי_, מוזו
  { {0x2b4f01e2,0xdbcc0084,0x60d600f2,0xba740029}},	//   ımcı_, lóði, ysym, _كانت
  { {0x68e92906,0x443a3390,0x49b80067,0x19940033}},	//   qued, _pop_, _راند_, _заця
  { {0x93c30045,0x399a000a,0xf992000a,0x2a6d007c}},	//   _ţărm, _וינד, _סרג_, lneb_
  { {0x64a3008f,0x63833391,0xb5fb0057,0x6e290e93}},	//   тара, вгра, vnáv, _oneb
  { {0xe1fa0010,0xb6590010,0x2a6d007c,0x75470030}},	//   ўга_, _ншых_, nneb_, örzé
  { {0xc6930008,0xdbcc001a,0x11d70015,0x62650015}},	// [6a80] _באה_, kóði, بوقة_, رافق
  { {0x6d42003f,0xb05b002c,0x6e2901cb,0xddc20085}},	//   vyoa, _zväz, _aneb, dnoš
  { {0x287a0053,0xdfcf0087,0x187a004c,0x2a6d007c}},	//   קנעמ, شين_, קטעב, kneb_
  { {0x93ee014e,0xdd8a01b7,0xd3370643,0x6e3b3392}},	//   _जाँच_, обед_, _חרטה_, _coub
  { {0x6e3b3393,0x7c3a3394,0xc8790061,0xfd0f0015}},	//   _doub, _potr, luşu_, لجو_
  { {0x7c830080,0x2a6d007c,0xa1930033,0xeb4a005e}},	//   куще, eneb_, _шаўч, жчик_
  { {0x7c3a0b7a,0x212200d9,0xce4a0010,0xb5fb3395}},	//   _votr, _hrkh_, _дзве_, onát
  { {0x20180375,0x539b000a,0xaf5b000a,0xaa630033}},	//   _hari_, חיצו, _וכלכ, ктык
  { {0x93ee005d,0x9cb30015,0x67d4024f,0x98c30033}},	//   _जांच_, _لمقت, нопу, ксэл
  { {0x6c030001,0x8b26000d,0x764d17e3,0xb5fb0030}},	//   _изуз, _одзе, _slay, gián
  { {0x764d3396,0x9b460115,0x26d80003,0x7791002b}},	//   _play, _تناو, éro_, هیها
  { {0x20180375,0x39460883,0x3dc63397,0xcb8b000a}},	//   _lari_, _онег, nbow_, _וְדֹ
  { {0x94ab0010,0x9813002b,0x25ad024d,0x3ce6006f}},	//   ютна_, ربیا, želo_, nrov_
  { {0x36d40036,0x32bb0029,0x3ce600bc,0xc2bb0015}},	//   _зокр, قدرة_, irov_, قارئ_
  { {0xd5ed0023,0x02a708fb,0x287b000a,0xd6cf052b}},	//   _chạ, драм, _ונגמ, _шт_
  { {0x764d000c,0x92940010,0x20180035,0xd5b80286}},	//   _ulay, васц, _aari_, _ось_
  { {0xdb1a002e,0x6e3b3398,0xd0d4006b,0x237f002a}},	// [6a90] _netþ, _roub, котъ, łuj_
  { {0xdfd1003b,0x6e3b0089,0x2a640011,0x2f8b0054}},	//   ايا_, _soub, himb_, ољен_
  { {0x2a6d0026,0x2018013c,0xd347002b,0x3f87001a}},	//   yneb_, _dari_, _غیره_, ænu_
  { {0x539a0008,0xb05b07fd,0xdd910021,0xddc20085}},	//   _מיתו, _städ, هوا_, tnoš
  { {0xe3a50086,0xddc2003d,0x6e2900bc,0x20183399}},	//   _تشکی, unoš, _vneb, _fari_
  { {0x2018003f,0x6b88002a,0xddc21d94,0x8d740058}},	//   _gari_, _bydg, rnoš, خاما
  { {0x8cdb000b,0x3219002a,0x1b4901c5,0xddc232fc}},	//   _निको, _kasy_, язки_, snoš
  { {0xc2120008,0x5f9400d0,0x89d50015,0xff280015}},	//   ָ֔ה_, _рист, رتبط, _تكفي_
  { {0x201802f2,0x321902fa,0x5c751afd,0x2cb9004f}},	//   _yari_, _masy_, _злат, _זֶ֣ב
  { {0xc0520053,0x2a6d0020,0x3219002a,0x8c5900c3}},	//   ָזט_, sneb_, _lasy_, _علاء_
  { {0xfe99000a,0xb5fb339a,0x96660099,0xf7490058}},	//   ּיָמ, jnás, екне, سلحي_
  { {0xfb1a0008,0xf65200e6,0xb21b02de,0x673c02dc}},	//   _מועמ, ائد_, _skæn, ärja
  { {0xe1ff001a,0x2a360058,0x0000006a,0x0000006a}},	//   _ljós_, _سكود_,   ,
  { {0x8c3d0064,0xd5ed0092,0x6f15005c,0x993a000a}},	//   _tuşu, _phạ, _oszc, _מתנה
  { {0xe29a0142,0xf6520015,0xa856000a,0x6f02002a}},	//   зав_, _مئة_, _ריצה_, łocz
  { {0x68fb0034,0xdb1a0069,0xc8790061,0x2018339b}},	//   otud, _netý, ruşu_, _sari_
  { {0x26d8002c,0x2018339c,0x68fb339d,0x9f980046}},	// [6aa0] árov_, _pari_, ntud, _vším_
  { {0x68fb0020,0x3219339e,0xb4fb000a,0x6557000a}},	//   itud, _easy_, _צפיי, _נביא_
  { {0x68fb0005,0x7e2a0010,0xb5fb1a4b,0x2018339f}},	//   htud, зіла_, cnás, _vari_
  { {0xee3a33a0,0x3ce60f5d,0x752433a1,0xb2bb000a}},	//   яне_, trov_, _kriz, _ממטר
  { {0xb5fb07a2,0x23720024,0xccb7005e,0xac1800d2}},	//   onár, šajā_, егії_, долу_
  { {0xc4d30008,0x0469000a,0x7e60002a,0x60c433a2}},	//   נגו_, ֽיהָ_, _wmmp, mpim
  { {0xddc20046,0x9e660015,0xfaa60342,0x68fb33a3}},	//   zhoř, _كارن, ншин, etud
  { {0xdff0000b,0x752411c8,0x2b77002b,0x60c4008c}},	//   _चाँद_, _oriz, رینگ_, opim
  { {0x68fb00dc,0x3f8a0026,0xb8660015,0x49b70021}},	//   gtud, _hybu_, فادو, رايد_
  { {0x60c400df,0x66040020,0x2a6a00dc,0x9cd7000a}},	//   ipim, _abik, őbb_, _נובה_
  { {0xc053000a,0xf8030033,0xd6d70fea,0xe80f000b}},	//   רזת_, учын, нтя_, ़ज़ा_
  { {0x2120016f,0xb5fb33a4,0xdb18001a,0x69c60030}},	//   kvih_, ciál, favö, űkeb
  { {0x75240011,0xdff0000b,0x758b004a,0xdb0802de}},	//   _criz, _चांद_, ясов_, _afdø
  { {0x628633a5,0x38cb0086,0x34950010,0xddc90085}},	//   _akko, _راهی_, тагр, _mješ
  { {0x60c433a6,0xddc90085,0x3219037c,0x7524039f}},	//   epim, _lješ, _pasy_, _eriz
  { {0xa7fc0061,0xdddb0085,0xf6990015,0xb5fb30aa}},	//   anıt, _okuš, _تنبع_, rnás
  { {0x067c0008,0x60f91561,0x660f0057,0xf1bf0016}},	// [6ab0] _מנהל, ьная_, meck, _xoáy_
  { {0x628600dc,0xcf9b000d,0xb1140033,0x6f15002a}},	//   _ekko, пје_, ымуш, _pszc
  { {0xc88500b8,0xdb1a002c,0x661d00dd,0x32750033}},	//   äßig_, _metó, odsk, _агнё
  { {0x31c7005e,0x660f33a7,0xdb18007c,0xddc90085}},	//   _ясов, neck, navõ, _bješ
  { {0xed58129a,0xdd940010,0x660f0012,0x6f15002a}},	//   ної_, гацы, ieck, _wszc
  { {0xa5bb0030,0xdb18007c,0xa49b0144,0xe522000b}},	//   ldód, havõ, stòf, मिति_
  { {0x6f15002a,0xf3f2000a,0x9e070033,0x7f940b9b}},	//   _uszc, ׁ֣ה_, _пчал, _барх
  { {0xe79a0046,0x628d02f2,0x68fb0255,0xfb24002b}},	//   _běží, nlao, ttud, اروپ
  { {0xdb18007c,0xb5fb339a,0xdb1a006f,0x394b1793}},	//   davõ, riál, _betó, ács_
  { {0xf982006b,0x661d00aa,0x68fb29f6,0xa9040067}},	//   ргьо, edsk, rtud, ابين
  { {0xf0920008,0xdddb0089,0x5a470033,0xd763002b}},	//   שני_, _zkuš, _пэда, انجی
  { {0x6d59005c,0xcb12000a,0x6b840012,0x8ab6000a}},	//   ozwa, _כלב_, ßige, _סלנג_
  { {0x99d40015,0xd9440015,0x45d30033,0x4dda000a}},	//   _إتما, _مئوي, шоўс, וחרו
  { {0xa2e60080,0xe7310087,0xf994004c,0x1875004c}},	//   когд, _نصب_, _גרױ_, _שײַך_
  { {0xe7390191,0xb5fb1756,0xd012002b,0x68e933a8}},	//   _цей_, rnár, یلر_, lred
  { {0x26c506d4,0x69c4007c,0x69c906a8,0x68e9051c}},	//   mplo_, _õiet, nbee, ored
  { {0x216733a9,0x50b603ea,0x68e933aa,0x21a6135f}},	// [6ac0] вити_, тсбу, nred, тиам
  { {0x0715005d,0xddc9016f,0x60c42f6d,0x64550012}},	//   _तनाव_, _rješ, rpim, chzi
  { {0x68e90176,0x7d09001c,0xdddb00bd,0xe29a004a}},	//   hred, _apes, _skuš, _оао_
  { {0x9e66006b,0xddc90085,0xf772015b,0x68e905bf}},	//   ъвед, _pješ, סקא_, kred
  { {0x9cb30029,0x1ea90015,0x68e902de,0xb5fb0030}},	//   لمنت, رامي_, jred, fiáj
  { {0xb5fb00dc,0xddc9016f,0x455b000a,0x5f060923}},	//   giáj, _vješ, וכנס, _изга
  { {0x501b0008,0x69c90111,0x6aab10df,0x6243007c}},	//   _קולו, fbee, _bigf, _tõot
  { {0xf2d30008,0x68e933ab,0x798b0d4f,0x8b650015}},	//   בעה_, fred, _bygw, داهم
  { {0x660f33ac,0x5dcb000a,0x68e933ad,0xadb7002b}},	//   veck, _חֶבְ, gred, _شهلا_
  { {0x660f33ae,0x8d5b000f,0xeb9a002b,0xbca6002b}},	//   weck, _חכמי, _قضات_, _شماي
  { {0x660f1fa4,0x0bb7000a,0x68e933af,0xa5f90920}},	//   teck, _סלאם_, ared, нену_
  { {0x3ce910ca,0x26f2000b,0x7bd833b0,0x68e9153c}},	//   šave_, _अमीर_, lavu, bred
  { {0x68e91ae0,0x660f33b1,0x8467006b,0x2918003d}},	//   cred, reck, въве, āras_
  { {0x26d800dc,0xdb18007c,0x67d414fd,0x7bd833b2}},	//   áros_, savõ, _соку, navu
  { {0x38790014,0x07f70086,0x3d19005d,0xe5c70199}},	//   ésre_, _شروع_, _मैने_, _испо
  { {0x35470010,0x765d0091,0x62580125,0x35f50725}},	//   _ахов, ūryb, _líof, _спир
  { {0x518733b3,0x90d40015,0xaad9000b,0x25d8000a}},	// [6ad0] тува, لآلا, _यौनक, _סוזן_
  { {0x7bd8002c,0x25be0046,0x90540033,0x5335098b}},	//   javu, ětle_, авуц, _беот
  { {0xd2510074,0x7bd8157f,0x7d0933b4,0x2bc6000b}},	//   _هند_, davu, _spes, _र्धा
  { {0xc33200a3,0xcf9805e6,0x6d1e000b,0x60e80061}},	//   _הוט_, тју_, पिंग_, ürmü
  { {0xb05b008c,0x865c000a,0x0000006a,0x0000006a}},	//   _etäa, ודאי,   ,
  { {0xac840033,0x4c8401f3,0x68e933b5,0xeb991eb8}},	//   агіл, алів, vred, нил_
  { {0x9f340191,0x8c420229,0xb5fb0030,0x68e90034}},	//   _кері, сеще, riáj, wred
  { {0x68e933b6,0xc334000a,0x7bd80201,0x0000006a}},	//   tred, שוק_, aavu,
  { {0x8cbb0074,0x69c900f6,0xde640063,0x7aea001a}},	//   _آدرس_, rbee, _търп, arft
  { {0xc9840001,0x69c905a0,0x68e933b7,0xf8ae009a}},	//   јући, sbee, rred, سکه_
  { {0x68e933b8,0x27ea002a,0x9056004f,0x8c1a004f}},	//   sred, óbna_, רבתו_, _רועי
  { {0xcf920008,0x7959006b,0x68e933b9,0x3ead003d}},	//   מטי_, _пиер_, pred, _jiet_
  { {0xf484002b,0x48e5018d,0x0000006a,0x0000006a}},	//   لاسی, _солв,   ,
  { {0x972500a2,0x3ead33ba,0x16d90015,0x0000006a}},	//   _مفتو, _liet_, _كذبة_,
  { {0xc8a80063,0x91e633bb,0xfbd2000a,0x7d1e003d}},	//   _ръце_, лове, מתם_, āpsi
  { {0x3ead0a9c,0xf772000a,0xddc2002a,0x425533bc}},	//   _niet_, _לקו_, zkoł, атут
  { {0xc0060766,0x63c7005a,0x0000006a,0x0000006a}},	// [6ae0] лпак, írné,   ,
  { {0xc4d3000a,0x251b004f,0xf537004f,0x908a0058}},	//   _הגז_, _טופא, _עניי_, رناك_
  { {0x93fb0053,0xaf96023e,0xc3fb000a,0xc7b2000a}},	//   _אליי, ушај, _אליש, צבא_
  { {0x4e1a0015,0x22160361,0x4b34002b,0x80dd0065}},	//   عتاد_, _сфор, یکاس, _पिचे
  { {0xa0760080,0x9bd40010,0x61f60034,0x3ead17cb}},	//   _бывш, ажлі, mgyl, _diet_
  { {0xcb1a000d,0x61f60026,0x5c970033,0xb5fb0030}},	//   еќи_, lgyl, гкія_, tiák
  { {0x41b8000b,0x7bd8022e,0x7aea0012,0x22420926}},	//   _अलास, ravu, urft, _kokk_
  { {0xcb0700e6,0xb5fb00dc,0x25ad30fc,0x61f60034}},	//   ايين_, riák, želi_, ngyl
  { {0xc7b00029,0xa2bb005d,0x644e00cb,0x286a10b3}},	//   يّة_, _शून्, kkbi, ерно_
  { {0x3ead0111,0xe8df0092,0x0d75044e,0xbcaa0015}},	//   _ziet_, uyền_, _тыся, _أدرك_
  { {0x80370053,0x1037000a,0x98c40061,0xf6990054}},	//   אניע_, אטים_, ıtım_, квој_
  { {0x9f650030,0x63720030,0xdb4f0058,0x0000006a}},	//   ütés_, zűné, _عَن_,
  { {0xda4b004f,0xf992009a,0x58d4009b,0x0000006a}},	//   _אֲגָ, _ابا_, _толт,
  { {0xb9930015,0x3387006b,0xe3c50015,0x6355005e}},	//   _الهب, губв, شْرَ, авгу
  { {0x5695010f,0x0464034e,0xdb78000a,0xe2c9002b}},	//   _какт, стям, דְּש, ئورو_
  { {0xdb0901f6,0x0000006a,0x0000006a,0x0000006a}},	//   înée,   ,   ,
  { {0x3ead0651,0x4fd51673,0xa158140a,0x637201d3}},	// [6af0] _riet_, ижат, гату_, tűné
  { {0x2007001a,0xba3d0046,0x644e33bd,0x26de33be}},	//   ýni_, omůc, ckbi, osto_
  { {0x22950036,0x6258002d,0xb3ba000a,0xd80b000a}},	//   _виня, _bíod, _במתכ, עִמָ
  { {0x433a0053,0x9f5c0089,0x51870e88,0x26de1550}},	//   _סערב, ývá_, _буга, isto_
  { {0x11da000a,0xd2510086,0xb5fb0030,0x3ead33bf}},	//   _שחשב, _هنگ_, riáh, _viet_
  { {0x26de21ac,0xcb690180,0x1be6006b,0x14d8004c}},	//   ksto_, кале_, адши_, רוגל_
  { {0x0b160029,0x26de00bc,0x0000006a,0x0000006a}},	//   لقوة_, jsto_,   ,
  { {0x2f180036,0xdb2400dc,0xdd09002c,0xa5c3001a}},	//   _щось_, ásáh, môžt, þóls
  { {0x71d8000a,0xe9d9002a,0xdd940033,0x26de33c0}},	//   אוחד_, raź_, _гаты, esto_
  { {0xddc2005c,0x7d1b1688,0x7c970015,0x7c87006b}},	//   akoń, _isus, _إشرا, _субе
  { {0xb06400b8,0xfb15002b,0x6d4b33c1,0xf7710015}},	//   lmäß, _خواج, lyga, تاة_
  { {0x366a1d90,0x7aba000a,0x27330016,0x0607004e}},	//   тамо_, _סצנו, _ḷng_, анюк_
  { {0x69db00b8,0xb0640012,0x2d8200cb,0x26de33c2}},	//   maue, nmäß, _øket_, asto_
  { {0xe3b20029,0xb05b2e6f,0x7e6b0035,0xf992000a}},	//   ترح_, _stän, higp, _ורד_
  { {0x96760010,0xb0640012,0x44240046,0x93430004}},	//   _выпі, hmäß, ěm_, онре
  { {0x69db177b,0x877a01ac,0x75460a61,0x8b88000a}},	//   naue, _באצי, _вниз, רָשֶ
  { {0xa5b7013a,0xe3b200e6,0xf0660174,0x806602a3}},	// [6b00] _דלפק_, _ورد_, акап, аваж
  { {0x69db020d,0x859b000a,0x23760015,0xc4c5002b}},	//   haue, _בשפו, _ناجح, _اتيو
  { {0x2fd70086,0x38bb00dd,0x444433c3,0xa856000a}},	//   شوند_, _lêr_, _io_, סיעה_
  { {0x72db0008,0xb76c0053,0xfee90029,0xcee70080}},	//   _בקטג, עדאָ, اعلى_, рдце_
  { {0x55bb0008,0x69db00b8,0x444433c4,0xa5bb0030}},	//   דמנו, daue, _ko_, ndóa
  { {0x26de002a,0xb5fb0030,0x444433c5,0x5336004f}},	//   ysto_, riái, _jo_, ֹנֵן_
  { {0xdb1a0014,0x444433c6,0xe3e90053,0x907b000a}},	//   _letö, _mo_, אַפֿ, _סטלי
  { {0x3ce9044c,0x444428dd,0x38bb0034,0x5a3404bb}},	//   šava_, _lo_, _bêr_, снит
  { {0x44440035,0x3eb800ea,0x7bc10034,0x58d70138}},	//   _oo_, _hurt_, _fflu, адыя_
  { {0x29d40074,0xb8fe014e,0x8bd80008,0xe7260036}},	//   جيکس, _तब_, _תַּח, аємн
  { {0xbb1a0029,0x69db00b8,0x2fd80045,0x96f80033}},	//   _جزءا_, baue, _merg_, ыент_
  { {0x444411e0,0xdb1a00dc,0xf76f00e5,0x6e2033c7}},	//   _ao_, _betö, باً_, _jamb
  { {0x6e2033c8,0x444433c9,0x3eb800cb,0x48b6004a}},	//   _mamb, _bo_, _lurt_, _тщет
  { {0xea010092,0x7d0233ca,0x444433cb,0x25be0046}},	//   _đẩy_, itos, _co_, ětla_
  { {0x32670010,0x883b0008,0x889b000a,0xe757005e}},	//   атав, _בתגו, _שבוי, _вищі_
  { {0x6e20000c,0xd258070e,0xb05b008c,0xd567005e}},	//   _namb, ацу_, _etäl, _втоп
  { {0xdb1a00b8,0x444433cc,0x2fd833cd,0x067c004f}},	// [6b10] _getö, _fo_, _berg_, _שנחל
  { {0xd7f804f9,0x444433ce,0x351c0008,0x75380008}},	//   ngă_, _go_, _יוחנ, _כאחד_
  { {0x7d0200f2,0x6258002d,0x6e2033cf,0x3eb833d0}},	//   etos, _díob, _bamb, _curt_
  { {0x444433d1,0x6e20114d,0xb05b008c,0xb0640012}},	//   _zo_, _camb, _itäm, tmäß
  { {0x444433d2,0x4421048c,0x7bc10012,0x644533d3}},	//   _yo_, _kah_, _pflu, _kohi
  { {0x4421048c,0x7518000a,0xb0640012,0xbc64008b}},	//   _jah_, שַׁע_, rmäß, овік
  { {0x38bb0026,0xb06400b8,0x68e200bc,0x5f45012c}},	//   _sêr_, smäß, _avod, _انزل
  { {0x73780008,0x539c0008,0x44210509,0x0378000f}},	//   יגוד_, כיוו, _lah_, יתות_
  { {0x97d90036,0x7e69003f,0x7d550010,0x69db336e}},	//   льну_, _imep, _увах, raue
  { {0x442133d4,0x3eb817e3,0xf1bf0046,0x38bb016e}},	//   _nah_, _yurt_, _znát_, _vêr_
  { {0x9b95003b,0xab950029,0x2d82003c,0xbb850015}},	//   _الات, _الاغ, _øker_, _الضي
  { {0xb05b01d1,0x06560010,0xda080086,0xd7f80011}},	//   _stäl, стоў, _نيمه_, agă_
  { {0xc987023e,0x644533d5,0xf771002b,0x69d900aa}},	//   _тужи, _bohi, تاک_, _iewe
  { {0x2a6d2829,0x6e22128d,0x9479004a,0x442101c2}},	//   lieb_, zdob, ассу_, _cah_
  { {0x4444032c,0x7d020014,0x69d900e8,0x7c2e002e}},	//   _vo_, ztos, _kewe, _óbre
  { {0x4444018b,0x69d90334,0xf55a0015,0x56650015}},	//   _wo_, _jewe, _ملعب_, _وديف
  { {0x394d08e0,0x3eb80251,0x444433d6,0xe2970c5b}},	// [6b20] nyes_, _surt_, _to_, сат_
  { {0xa3d9014e,0xd12f003b,0x69d933d7,0x64450026}},	//   ारण_, عمل_, _lewe, _gohi
  { {0xb5fb001c,0x6e200035,0x645c0bd7,0xc0a90015}},	//   riáv, _pamb, mhri, شاكل_
  { {0x7d0204ed,0xed5a0892,0x69d933d8,0x61e602de}},	//   ttos, лое_, _newe, _udkl
  { {0x9cf40010,0x7e7b02ce,0x5e250015,0x7c2133d9}},	//   ізкі, _djup, تعلق, _balr
  { {0x705600b0,0xdff50033,0x7e7b003d,0x395f003d}},	//   _انسا, _мясь, _ejup, dzus_
  { {0xa3d9005d,0x644100f2,0x69d933da,0xf1bf002d}},	//   ारत_, ölii, _bewe, _inár_
  { {0xac06002b,0x69d901d7,0xc333000a,0x7d020bbc}},	//   _گذرو, _cewe, לוו_, ptos
  { {0x02660023,0x645c00d9,0x69d933db,0x3ebf0085}},	//   _đến_, khri, _dewe, _čuti_
  { {0xd7f80011,0xe00b005d,0x2d57000f,0xdd8f0015}},	//   ugă_, स्पद_, _השמש_, _أوك_
  { {0x3aeb0086,0xd7f80011,0x7bda0024,0x69d90b00}},	//   _مبنی_, rgă_, _ietu, _fewe
  { {0x9f970008,0xa5f90080,0xfb1b0008,0x291a0018}},	//   מדיה_, шему_, _תואמ, _مقصد_
  { {0xb05b04d4,0x68e20263,0xba170015,0x7bda15e1}},	//   _stäm, _uvod, _دينا_, _ketu
  { {0x645c00d9,0xe947002b,0x3ea6008c,0x2768002b}},	//   ghri, _درمی, hmot_, _پشتی_
  { {0xb8650018,0x92b70015,0x29040061,0x7bda33dc}},	//   _بانو, إحسا, ltma_, _metu
  { {0x6258002d,0x2bcf000b,0x64450012,0x6aba0061}},	//   _ríoc, _स्ना, _wohi, _mutf
  { {0x64450020,0x6258002d,0x3134135d,0xb5fb0030}},	// [6b30] _tohi, _síoc, петр, knáz
  { {0x7bda00df,0x645c19f7,0x34b5005d,0x6aba33dd}},	//   _netu, chri, ंदीद, _outf
  { {0x8db50036,0x41b50015,0x752d013f,0xcf9b0099}},	//   ослі, _ومدر, _hraz, уја_
  { {0x7415002b,0x2d550015,0x7bda007c,0xe717000a}},	//   _اوگا, يَاس, _aetu, מחבר_
  { {0x69d9002a,0x2a6d006f,0x7bda1af0,0xb5fb0030}},	//   _rewe, vieb_, _betu, liás
  { {0x3ce900bd,0x7bda2609,0xa3d9000b,0x60cd33de}},	//   šavo_, _cetu, ारि_, mpam
  { {0x9f5f00f2,0x2a6d002c,0xbb850015,0xeb990098}},	//   ärän_, tieb_, غلبي, шик_
  { {0x7e69003f,0xef22005c,0x08c5023e,0x752d33df}},	//   _umep, _dużą_, обин, _oraz
  { {0xa3d9014e,0x2a6d121c,0x6f0500da,0xb05b0123}},	//   ारा_, rieb_, lthc, _ntäk
  { {0x7bda09f0,0xf8650036,0x69d9050b,0x60cd33e0}},	//   _getu, івно, _wewe, ipam
  { {0x752d33e1,0xceb3000a,0x225200aa,0x2bcf000b}},	//   _araz, ּי֩_, ykyk_, _स्या
  { {0x68ee0064,0x99350015,0xf50633e2,0x25be0046}},	//   ündü, _وفات, озмо, ětlo_
  { {0x2bc6005d,0x37e52229,0xd874002b,0xa50a0054}},	//   रुवा, _долг, _کانب, јега_
  { {0x2bcf000b,0x660d007c,0xe8840033,0xdc39000a}},	//   _स्मा, _ebak, _егіп, ׁעָר
  { {0x645c002e,0xe2aa0067,0xb05b008c,0x8ae9000a}},	//   rhri, لارن_, _etäk, יַּ֤
  { {0x21760054,0x90e60015,0x645c00da,0x765d0012}},	//   оузр, قسطن, shri, chsy
  { {0xb93600b2,0x645c002d,0x752d1f30,0x3636002b}},	// [6b40] ֿרעג_, phri, _graz, _هرکس
  { {0x409600e2,0x10a61591,0xb5fb039f,0x60260138}},	//   ірат, цизн, siát, ўджа
  { {0x11d60029,0x7bda0223,0xef1a15b6,0xe29a0515}},	//   _وتحد, _retu, рме_, _ван_
  { {0xb5fb33e3,0x1ea900e6,0x91f60015,0xa0c60015}},	//   chád, ماني_, _بأدا, _ويجو
  { {0x7bda0049,0xddc2002a,0x3ea633e4,0x0217004f}},	//   _petu, mnoż, rmot_, _וחכם_
  { {0x98a60089,0x8c430001,0x3cd90010,0x69dd001a}},	//   _proč_, деље, сьцю_, ðsen
  { {0x6c830015,0xbc670021,0x7bda33e5,0xdee60788}},	//   بلوم, تمون_, _vetu, _фоби
  { {0xd2b7000a,0x58d4006b,0xcd020535,0x98a6013b}},	//   חלקת_, поит, _puść_, _vroč_
  { {0x4974007a,0x998d0061,0xad260067,0x62960727}},	//   ялис, rdeş_, _برزو, ilyo
  { {0xa7fc01e2,0xc8660029,0x3137000f,0x0137000a}},	//   lnız, تطبي, קנים_, קרית_
  { {0x4fbb0135,0xb9e6005e,0xb5fb016e,0xa3d9000b}},	//   יציא, _діли, diár, ारस_
  { {0xe6670036,0x1db1000b,0x752d33e6,0xb05b005b}},	//   ітно, ुँचत, _praz, _etäh
  { {0x64b5000b,0x2aaa002a,0x04590058,0x998f0073}},	//   ंदेश, róbę_, ملحة_, _dogų_
  { {0xc1d3005d,0xb5fb1756,0x752d005a,0x35b40138}},	//   तर्ग, giár, _vraz, ьбяр
  { {0x9f4701e2,0x026b0033,0x926b0004,0x0000006a}},	//   ünü_, ашай_, араа_,
  { {0xa75b0008,0x212900bd,0x95cb05b3,0xb05b008c}},	//   _כדור, tvah_, _тука_, _itäi
  { {0x50f5005f,0x51f80010,0xf19403e7,0xdfd10015}},	// [6b50] язат, ўную_, дить, فيء_
  { {0xb5fb001c,0x75d50086,0xea010016,0x60cd33e7}},	//   ciár, _بيکا, _đậy_, rpam
  { {0xceeb0086,0x2bde000b,0xb0280015,0xdefb0033}},	//   شران_, _नज़ा, تكلم_, рыз_
  { {0x8ed80015,0xa5bb001a,0x531a000a,0x1df90088}},	//   تذكر_, kdóm, _פורצ, седы_
  { {0xddc2005c,0xfe080015,0x8d74002b,0x28da000b}},	//   lkoś, تقني_, واها, _मौलि
  { {0x64550111,0x00ba000a,0x60d6000a,0x0000006a}},	//   nkzi, _למשמ, _מושא_,
  { {0xf3f2000a,0xca750138,0x0000006a,0x0000006a}},	//   ׂ֣ה_, зупы,   ,
  { {0x6258002d,0x6aa233e8,0xd37c000a,0xb05b0012}},	//   _líon, _chof, ירוט, _stäh
  { {0x2bcf005d,0x38ca0086,0x010b000a,0x6e94005e}},	//   _स्था, یایی_, ׁלֵּ, _циту
  { {0xfc3000c3,0xf7190033,0xad88000a,0xf771009a}},	//   _لحم_, бімы_, _וְעֻ, ّاح_
  { {0xcc56000a,0xe8480015,0xb5fb0794,0xe7bc000b}},	//   _צבעי_, تجين_, viár, ोड़प
  { {0xfbcf005d,0xca480015,0xddc2002a,0x2bcf000b}},	//   _स्तम, _ولله_, dkoś, _स्ता
  { {0x6258002f,0x6fdc000b,0x49ba000a,0xb05b008c}},	//   _bíon, _फ़लू, _המנס, _etäi
  { {0xb5fb00dc,0xddc90085,0x58040058,0x0000006a}},	//   gháb, _njež, _يونك,
  { {0xb7da000a,0x82a6005e,0xb5fb0030,0x8ac9000a}},	//   _הקצי, завж, riár, מֶּ֗
  { {0xb21b00fb,0x2aa10030,0xc243004a,0x56930b1e}},	//   _skær, lóbb_, ннск, _пајт
  { {0x15fb0008,0x6aa9003f,0xddc2002a,0xddc90085}},	// [6b60] _ההפע, imef, akoś, _bjež
  { {0xb4d8021e,0xd179005e,0xe573000a,0x6aa90012}},	//   ाठी_, істі_, _רַק_, hmef
  { {0x0dca0036,0x41dc000b,0x141b000a,0x389a004c}},	//   були_, बरदस, _פוטב, ציענ
  { {0x9e650031,0xce6900ce,0x0000006a,0x0000006a}},	//   وانن, орід_,   ,
  { {0xe3b20086,0xacf80127,0x9be6005e,0x20070144}},	//   _ترک_, інку_, пійк, ònic_
  { {0x3ced000b,0xdfd20040,0x6aa233e9,0x8078004f}},	//   _घिरे_, _سير_, _shof, _וְֽה
  { {0x8b230054,0xa0a30788,0x0000006a,0x0000006a}},	//   едје, _чард,   ,
  { {0xdb01002e,0x0f7b000f,0x7c66002b,0x9f58016e}},	//   _uglý, _האלב, _کارل, _ecrã_
  { {0xd90e0074,0x15e3005d,0x6934002b,0xbc662f04}},	//   ایت_, _ख़बर_, بکار, _евак
  { {0x6aa9003f,0x4778005e,0xddc9002a,0x2aa10030}},	//   amef, жбою_, _oleś, góbb_
  { {0x21270023,0x3e7501cb,0x62580125,0x0057000a}},	//   ̉nh_, sťte_, _ríon, פשטת_
  { {0xbb3b000a,0x3abb000a,0xdb9b004f,0xe9d20058}},	//   _לעבי, _המאנ, _פסאר, _أغا_
  { {0xb05b00f2,0x6258002d,0xda650040,0x6934008b}},	//   _itäv, _píon, _تالي, _інку
  { {0x201a0085,0xd4910016,0xa3b80015,0xe75800ce}},	//   jepi_, ồ_, كافر_, _милі_
  { {0xa2950010,0x929509a7,0x7ea3007c,0xd25b055f}},	//   даві, давц, lõpe, бца_
  { {0xc29902e1,0xb797000a,0x877b000a,0xd5c1000b}},	//   іках_, _מכוח_, _לאוי, _एलिज
  { {0x212f002d,0xc1050015,0x6441007c,0xddc2002a}},	// [6b70] ígh_, بوذي, ölis, skoś
  { {0x2fc70023,0x4fc40033,0x1fa704bb,0x0000006a}},	//   ùng_, есца, прег,
  { {0x7f190087,0xc7d7000a,0xddc90085,0xb5fb013f}},	//   تياز_, פואי_, _vjež, chác
  { {0x7d9904c5,0x0000006a,0x0000006a,0x0000006a}},	//   овес_,   ,   ,
  { {0xf1ab0074,0xece80036,0xcd280029,0x69dd002e}},	//   _داده_, зділ_, كسون_, ðsem
  { {0x5fe1014e,0x113a000a,0xada40033,0xc156000a}},	//   _फ़िल, _ותשל, хаіл, _חששו_
  { {0x3c2d00dc,0x6e67006b,0x7c94002b,0x5f740015}},	//   jövő_, _етаж, رشها, _كافر
  { {0x88c9052b,0x224b0f21,0x8338004f,0xe9a6009a}},	//   олив_, _jock_, לאוס_, ژگون_
  { {0x2aa100dc,0x97d90015,0x224b00da,0x3ddf0079}},	//   tóbb_, يبدأ_, _mock_, _ieuw_
  { {0x9d28000a,0x6fdd000b,0x224b2fa8,0x06e90342}},	//   _מֵעִ, यरिं, _lock_, омок_
  { {0x2aa10030,0xcb550058,0xa75402ed,0x47390138}},	//   róbb_, _تناظ, етящ, ічоў_
  { {0x2cbf0020,0xf3e90008,0x7afc0123,0x39150058}},	//   _kuud_, _כף_, _årta, _يواز
  { {0x6258002d,0xc9f40058,0x0000006a,0x0000006a}},	//   _díol, _أسمع,   ,
  { {0x2cbf0005,0xe8d60008,0x68fb0201,0x1c1d000b}},	//   _muud_, _חוסר_, muud, फ़िल_
  { {0xa2e6006b,0x27f8002a,0x23271c80,0x2cbf0072}},	//   ьовд, órne_, мори_, _luud_
  { {0xcb120008,0x82160015,0x224b27b6,0xe0da17b6}},	//   כלל_, بورص, _cock_, жва_
  { {0x224b0876,0xb4760015,0x404a0054,0x201a01c2}},	// [6b80] _dock_, _يُعث, опао_, tepi_
  { {0x394200f2,0xf1b10015,0x4f5a0115,0xb09a005e}},	//   äksi_, اءِ_, يجاد_, ітає_
  { {0x6258002d,0x2605000b,0x5457000a,0x20070144}},	//   _híom, _वामी_, _חסין_, ònia_
  { {0xf2d3013a,0x64920134,0x90c60361,0x68fb0601}},	//   _שער_, pæis, _обме, kuud
  { {0x68fb0604,0xcd36002b,0x0caa0965,0x61e433ea}},	//   juud, براب, отки_, mail
  { {0x3ddf0111,0x76880061,0x3f8e0061,0xc0e30054}},	//   _eeuw_, lıyd, üfus_, _јорк
  { {0xaec30010,0xab770021,0xf413000a,0x0000006a}},	//   _абсл, ومها_, דפו_,
  { {0x8fa3008f,0xda660021,0xa9c3005e,0x61e433eb}},	//   _расе, باتي, кськ, nail
  { {0x60c2002f,0x2bcf014e,0x58860010,0xec7a0902}},	//   íomh, _स्वा, дына, _дпа_
  { {0x0c260127,0x6258002d,0x61e433ec,0x7ea3007c}},	//   _імен, _síol, hail, rõpe
  { {0x61e42aa7,0x8c4305e6,0xcff7000a,0x501b000a}},	//   kail, _шефе, וציה_, חויו
  { {0xaae50029,0x7c2a33ed,0x645e0fb7,0x8aa5005e}},	//   _أسلو, ldfr, _alpi, _зрід
  { {0xb9560086,0x98a90061,0x6846007e,0x224b270b}},	//   _تئات, _çağ_, _онда, _rock_
  { {0xa99b000a,0xa5bb0125,0x7c2805fb,0x7c2a33ee}},	//   _ובדר, idói, _jadr, ndfr
  { {0xd7fb000a,0x0464005e,0x7c28189e,0xe2930015}},	//   _והול, ттям, _madr, نذر_
  { {0x61e40007,0x645e00e8,0x0614004a,0x7c2823e1}},	//   gail, _elpi, _адъю, _ladr
  { {0xa2940036,0xd4db0029,0x661d33ef,0x60f9056d}},	// [6b90] таті, _ببعض_, mesk, яная_
  { {0xcf9b0124,0xc1040002,0xd9bb000b,0x61e40201}},	//   оје_, ئولي, _उल्ट, aail
  { {0x833500b2,0x03d6013a,0x61e4002d,0x387e0045}},	//   _װאָס_, _אותם_, bail, intr_
  { {0x28df0372,0x7c280005,0x61e4002f,0x7c3a33f0}},	//   पीडि, _aadr, cail, _antr
  { {0x64680020,0xed580036,0x91f60008,0x644e00bc}},	//   _äriü, мої_, _אמרו_, žniš
  { {0x7c2833f1,0x68fb00f2,0xb4fc000a,0x8c48005e}},	//   _cadr, vuud, קפוי, мпів_
  { {0xbef80029,0x661d33f2,0xa5bb0125,0xaae4012c}},	//   _يرفض_, kesk, adói, نسيو
  { {0xdb0e0089,0xdd95054f,0x68fb0209,0xb05b008c}},	//   ádán, _забы, tuud, _etät
  { {0x3959002e,0x2aa10030,0x661d33f3,0xbc3b0058}},	//   áss_, góba_, desk, _وسطا_
  { {0x6258017e,0xd1980008,0x661d0020,0x68fb0604}},	//   _ríom, וכחי_, eesk, ruud
  { {0x68fb022d,0x6e290020,0xd6ce0086,0xf092000f}},	//   suud, _kaeb, یقی_, רני_
  { {0x68fb0020,0x661d33f4,0xb9950015,0x2605000b}},	//   puud, gesk, _كلاب, _वाणी_
  { {0x61e433f5,0x05b60033,0x443a33f6,0x0000006a}},	//   vail, эсоў, _pnp_,
  { {0x7c28016e,0x68e90061,0x6d3a000a,0x61ef33f7}},	//   _xadr, msed, הֲלו, _adcl
  { {0xb5fb002f,0xa69603f1,0xb7790053,0x68e933f8}},	//   mhán, _приј, _מאַש, lsed
  { {0x69c933f9,0xb5fb0046,0x62580125,0x11d70015}},	//   ncee, lhán, _tíom, فوفة_
  { {0x60dd0026,0x7524003f,0x68e933fa,0x867b000a}},	// [6ba0] _cwsm, _usiz, nsed, _מרקו
  { {0x2bcf005d,0x76880061,0x04460054,0x20c4007c}},	//   _स्ला, sıyd, _чеон, _vöi_
  { {0xdfcf0029,0xe3b20029,0x68e90064,0x61e433fb}},	//   صين_, _حرة_, hsed, pail
  { {0x7c28010b,0x63a100dc,0xcd060345,0x7c2a0026}},	//   _sadr, ülne, ечки, wdfr
  { {0x7c28208e,0xd469002b,0x7e620123,0x60dd0034}},	//   _padr, _رحیم_, rhop, _gwsm
  { {0x69cb00f6,0xa5bb002d,0x7e6233fc,0xeb4a004a}},	//   _afge, rdói, shop, зчик_
  { {0x68e9018c,0x9bc70015,0x8fa30658,0xa097000a}},	//   esed, رويك_, _баре, _נדלק_
  { {0x41bb0053,0x0dc90029,0x5a3406ac,0x8938106d}},	//   ּציע, _يبقى_, тнит, дпис_
  { {0x4c860010,0x661d33fd,0xbc760015,0xb05b008c}},	//   _злав, vesk, _كهرب, _itär
  { {0xb5fb0089,0xbc6a0115,0x99820046,0x2aa113c3}},	//   ghán, _عمان_, žků_, róba_
  { {0x2eaa0008,0xa5f9125d,0x661d33fe,0x45d52815}},	//   ּשָּ, мену_, tesk, конс
  { {0xea010023,0x69c91ee1,0xff7b05bd,0x8ca40065}},	//   _đầy_, ccee, לטימ, _चीतो
  { {0x94ab0010,0x661d33ff,0x15a8006b,0x0000006a}},	//   зтва_, resk, еъри_,
  { {0x493b000a,0xb5fb3400,0x661d3401,0x0000006a}},	//   _מגדו, chán, sesk,
  { {0x82a70080,0x43950342,0xd25b3402,0x02a73403}},	//   ешае, тавс, пца_, ерам
  { {0xa79b000a,0xc6a7005e,0x179b000a,0x079b004f}},	//   _משוח, _ярли, _מיוב, _מסול
  { {0x2cff014e,0xddc90045,0x69dd0052,0x0000006a}},	// [6bb0] _ईमेल_, _aleş, ðsei,
  { {0xa98b000a,0x6e3b3404,0x5064011e,0x0000006a}},	//   הָבִ, _snub, лтха,
  { {0xf4120008,0xe1d90036,0x1fe1000b,0x22950015}},	//   _דפי_, _одні_, _फ़ीड, _للدس
  { {0xa3d9005d,0xbdf80021,0x68e90034,0xdce23405}},	//   ारक_, فرها_, ysed, azoč
  { {0xddc9062c,0x2d580036,0x1cd80010,0x7c290004}},	//   _eleş, ниць_, едчы_, долг_
  { {0x00f6039e,0x22493406,0xeb9907d1,0xa4bb004f}},	//   _במשך_, ljak_, мил_, הֶ֔י
  { {0xdde300dc,0x2bac000b,0x626c29b3,0xe26b004f}},	//   űről, टेला, rşov, ּדִֽ
  { {0x68e90020,0xc334039e,0x25ed000b,0x4dd70015}},	//   tsed, רוק_, _आएगी_, _سترس
  { {0x87f90010,0xee84055f,0x22493407,0x69c90546}},	//   мэнт_, _сыро, ijak_, rcee
  { {0x68e911b1,0x69c90079,0x0000006a,0x0000006a}},	//   rsed, scee,   ,
  { {0xf7710002,0x0a150015,0x6b840012,0x4758004a}},	//   شاد_, _لواح, ßigt, еряя_
  { {0x8cd8000b,0xa5bb0030,0xcf92004f,0x68e9007f}},	//   नीको, deób, שטט_, psed
  { {0xceb200b2,0xb5fb03d9,0xe945002b,0x8623009a}},	//   ייט_, mhál, _جرای, شکيل
  { {0xdb0d002e,0x22490509,0x64a601b0,0x58f6000a}},	//   _þjóf, ejak_, тага, _ימנע_
  { {0xe29a0142,0xe8480029,0x44ed002c,0x97d80015}},	//   дав_, _سجون_, aľ_, _أظهر_
  { {0xb5fb0046,0x067600ce,0x0000006a,0x0000006a}},	//   nhál, _шуля,   ,
  { {0x41b30015,0x290d3408,0xe29704d7,0x04ca0058}},	// [6bc0] لمفر, ntea_, тат_, _توخي_
  { {0xb21b00fb,0xb05b079c,0xa4fb000a,0x7ed6005e}},	//   _hjæl, _stär, _קליט, відч
  { {0x52aa0124,0xb21b00cb,0x7e2a005e,0x645c17ff}},	//   _овом_, _kjæl, діла_, mkri
  { {0xedf40086,0x7536002a,0xcce6006e,0x645c128a}},	//   ايشگ, _kryz, نستي, lkri
  { {0xb5fb0125,0x645c0081,0x0000006a,0x0000006a}},	//   dhál, okri,   ,
  { {0x201e001a,0x63a90046,0x645c3409,0xe573004f}},	//   _úti_, řene, nkri, סַף_
  { {0xbae3008f,0xcb0700e5,0x645c340a,0x8bc5005e}},	//   ацый, نيون_, ikri, усід
  { {0xddc70045,0xb5fb0030,0x9e66002b,0x98a60535}},	//   ălţa, ghál, _شازن, _kroć_
  { {0xfe910086,0xac0a000d,0x4c160086,0xa3e2000b}},	//   _اینج, _онаа_, _لباس, दरा_
  { {0xea010092,0x60d60073,0x0000006a,0x0000006a}},	//   _đấy_, ipym,   ,
  { {0x3ffb0008,0xb5fb002d,0x20350053,0x661b0020}},	//   ופיע, bhál, אָרש_, õuko
  { {0xab7900b2,0xcf930008,0x7b790053,0xa4d500fd}},	//   _אָנז, יטת_, _אָנצ, ломі
  { {0xda070086,0xda650196,0xe918005e,0x94770067}},	//   _شيوه_, _حالي, _чолі_, ندسا
  { {0x1fe1000b,0x645c340b,0xe80e0065,0x0000006a}},	//   _फ़ेड, gkri, ़्शा_,
  { {0x13b4003b,0x94840010,0x20070144,0xb5fb001a}},	//   لصفح, рыяд, ònim_, lhám
  { {0x3264044a,0x7536340c,0xddc9006f,0x160a0065}},	//   атув, _fryz, _omeš, _वायर_
  { {0x0574002b,0x753606ed,0xd1300015,0xf485002b}},	// [6bd0] _پايد, _gryz, يمِ_, _مادی
  { {0xc058008f,0x1fd80029,0x7ff40015,0x94ab0015}},	//   кіх_, نظمة_, لسما, _تطبق_
  { {0x9df905e6,0xc2cb0015,0x9ed907d9,0xa3470033}},	//   енет_, _تبخل_, хмет_, _рэпл
  { {0x20d70029,0xa2c0005d,0x4ea41c64,0x2007002a}},	//   _لتسج, वदर्, арча, żni_
  { {0x96160053,0x76880061,0x645a0012,0xa5bb039f}},	//   רקױף_, nıya, ötig, cdót
  { {0xc1b8078f,0xc172000a,0x4d64005e,0x9f650030}},	//   _шлях_, _פחם_, шків, átót_
  { {0xf092000a,0x9f05002b,0xb5fb1793,0xeb96016a}},	//   _הנם_, _حوزو, thál, лиш_
  { {0x0b16003b,0xf2d40053,0xa3d3005d,0xee870010}},	//   اقية_, בעק_, हुत_, _рыго
  { {0x290d0011,0xe8f60033,0x29190144,0x48790a66}},	//   utea_, глы_, ïsa_, есня_
  { {0x290d04f9,0x6d59005c,0xb21b0bfa,0xe8f6054f}},	//   rtea_, mywa, _sjæl, ыль_
  { {0x290d04f9,0xfc300029,0xd5e60a86,0x6d590416}},	//   stea_, _بحق_, лжни, lywa
  { {0x98ad00bd,0x290d0011,0x8935006e,0x7536002a}},	//   mveč_, ptea_, _معتا, _pryz
  { {0x6d5910ec,0xa3f6004a,0x645c340d,0xb5fb0069}},	//   nywa, лявш, tkri, chám
  { {0x98790053,0x765d002a,0xd7fb0033,0xe8d6000a}},	//   _ראַט, aksy, _цуд_, _עוצר_
  { {0x237a002b,0xe739004a,0x645c31d8,0xb9060065}},	//   رمرد_, _чей_, rkri, यी_
  { {0x5faa000b,0x645c0a3a,0x7d1b340e,0x9756000a}},	//   _करबल, skri, _opus, _תיקו_
  { {0x25d70008,0x645c0007,0x8ffa0015,0x9ffa0015}},	// [6be0] _גופן_, pkri, فرار_, فراء_
  { {0x6d59005c,0xa41b005d,0x7bc10125,0xf8c80016}},	//   dywa, _पॉपप_, _nglu, _hức_
  { {0x98ad018c,0x50b50004,0x0876004c,0x7d1b0045}},	//   jveč_, рсту, נעעט_, _apus
  { {0xe813005d,0x1ea90029,0xd37b0008,0x5de609ef}},	//   त्ता_, ناني_, _טריט, ужда
  { {0xf8c80023,0xa2b3000b,0x61e6003d,0x68fb08f9}},	//   _mức_, ूआरऍ, _iekl, jrud
  { {0x6284005c,0x626c0011,0x7d77002b,0xddc900bc}},	//   lnio, cşor, دمهر_, _vmeš
  { {0x1fb5005f,0x2605005d,0xf0630036,0x6af30015}},	//   _встр, _वाली_, _укрп, مثير
  { {0x6d59005c,0x7bc10026,0x68fb0304,0x1eaa002b}},	//   bywa, _eglu, frud, _سازي_
  { {0x61e603eb,0x2bcf005d,0xd7e60484,0x628414d8}},	//   _mekl, _स्का, ліно, inio
  { {0xb5fb0084,0x80aa014e,0xad1b0008,0x97140010}},	//   rhám, _जीमे, _אומר, амоц
  { {0xb8cb005d,0xf8c80092,0x68fb0962,0xfafa002b}},	//   _की_, _bức_, arud, _سراغ_
  { {0x69dd0084,0x68fb0b30,0xe5b5004a,0xf76f0015}},	//   ðset, brud, ийны, ثاً_
  { {0x5507008f,0x62840050,0x4a7b00b2,0x7d020007}},	//   ычна, dnio, _אראב, nuos
  { {0x62840050,0xd7ef0001,0xd32701c5,0x76880061}},	//   enio, _ћу_, льби, rıya
  { {0x6d590050,0xa7370015,0x28b90033,0x61e6340f}},	//   zywa, _مثير_, _руцэ_, _bekl
  { {0x82370018,0x62842852,0xb6040046,0x20183410}},	//   درسا, gnio, tkář, _abri_
  { {0x7d020007,0xb5fb0030,0x20750033,0xa0750e3b}},	// [6bf0] juos, rkád, алаў, агач
  { {0x09d1000b,0x33750fea,0xa49b0144,0xa0680054}},	//   _सभ्य, _вгор, atòr, гађа_
  { {0x6d593411,0x200f005c,0x645a00f2,0x44233412}},	//   wywa, ęgi_, ötie, mej_
  { {0xcf981cf5,0x6d59005c,0xa49b0251,0x44230b15}},	//   ују_, tywa, ctòr, lej_
  { {0xade80015,0xc694004c,0x7d020091,0x44310535}},	//   افهم_, זאף_, guos, odz_
  { {0xb5fb00dc,0x6d5910ec,0x4423066f,0x60fa000a}},	//   nkáb, rywa, nej_, _בהשק
  { {0x6d59005c,0x54580447,0x1a68002b,0x4423002a}},	//   sywa, רסון_, گینی_, iej_
  { {0x7f840029,0x442301c9,0x6d59002a,0x9b680033}},	//   _الفن, hej_, pywa, ышча_
  { {0x0d670063,0x44233413,0xf8650004,0x38ab02de}},	//   _съвм, kej_, ивио, høre_
  { {0xf8c80023,0xe7390001,0xa8550e88,0x4423066f}},	//   _sức_, вео_, ртиј, jej_
  { {0x38ab003c,0x628409bf,0x4c3a000a,0x44233414}},	//   jøre_, ynio, _שתעב, dej_
  { {0x44313415,0x2bb80015,0xdb080030,0x68fb3416}},	//   edz_, _صالة_, _álás, prud
  { {0x62960003,0x61e63417,0x9f43039f,0x442301ea}},	//   voyo, _rekl, _dejé_, fej_
  { {0xe3b20029,0x6284005c,0x05270180,0x38ab079b}},	//   قرأ_, wnio, јорк_, føre_
  { {0xf8c80023,0xf66a0086,0x38ab0134,0x46a60a21}},	//   _tức_, _لحظه_, gøre_, _какв
  { {0x768801e2,0xb226000d,0x471a0008,0xf8c80092}},	//   mıyo, јмал, _יוצג, _hứa_

  { {0x76880064,0x442303df,0x70b60015,0x1c05000b}},	// [6c00] lıyo, bej_, لمرض, रलाल_
  { {0xa49b08e0,0x26c70273,0x7d0209e2,0x44233418}},	//   stòr, _kuno_, vuos, cej_
  { {0x61e601e2,0x768801e2,0x6284005c,0x93fb00a3}},	//   _tekl, nıyo, pnio, _בליי
  { {0x60c60035,0x7d023419,0xed5a341a,0xc7b2000a}},	//   _tukm, tuos, кое_, קבא_
  { {0x1bd40063,0x7640008c,0x6e221018,0xb5fb0247}},	//   боля, ömyy, reob, lkác
  { {0x5c730191,0x76880064,0xcff4002b,0x5c970033}},	//   оліт, kıyo, _ديسک, акія_
  { {0xb5fb25d9,0x6f1c0089,0x7d021a91,0xcb46005e}},	//   nkác, _uprc, suos, рхли
  { {0x6cd60029,0xe813005d,0xeaaf0029,0x4423341b}},	//   _نقرا, त्सा_, وعي_, zej_
  { {0x48aa0511,0xf98f0015,0x3dfb000a,0x62580125}},	//   ктом_, ِبٍ_, _שלמד, _híos
  { {0xb5fb002f,0x00760008,0xc051000a,0x0b1a0015}},	//   mhái, יתִי_, ִ֖י_, _لقطة_
  { {0x27e7018b,0x4423002c,0x2bcf005d,0x10370008}},	//   _denn_, vej_, _स्टा, בטים_
  { {0x44230050,0x6f030251,0xfdf8005d,0xba17002b}},	//   wej_, ànci, ुलिस_, _نيما_
  { {0x76880064,0x27e700dc,0xa7fc0064,0x4423066f}},	//   mıyl, _fenn_, tkıd, tej_
  { {0x2904341c,0xb5fb0030,0x25a9013f,0x4431003d}},	//   muma_, ukáb, _vzal_, udz_
  { {0x4423341d,0x4df8000b,0x92b70015,0x4431003d}},	//   rej_, ुलाई_, لحرا, rdz_
  { {0xf8ad0074,0xd7bb013a,0xf6d30086,0x67bb000a}},	//   _يکی_, _בצור, _بزود, _במוק
  { {0x2904341e,0xf1dc0065,0x0000006a,0x0000006a}},	// [6c10] numa_, बरजन,   ,
  { {0xb5fb0125,0x859c000a,0x764f02dc,0x0000006a}},	//   dhái, _בשחו, ljcy,
  { {0x9f040029,0x64b40015,0x64a40004,0x2904341f}},	//   قولو, _بحير, _фаќа, huma_
  { {0xf2d20008,0xfe700086,0x29043420,0x6258002d}},	//   _מעט_, ودن_, kuma_, _díos
  { {0xa5da00b2,0x29040048,0x76883421,0xbd280029}},	//   אַצי, juma_, zıyo, لأول_
  { {0x2904000c,0xa3be014e,0x31560008,0x91ba0008}},	//   duma_, ुँच_, _הישן_, _תמשי
  { {0xbbf8005e,0x660d0061,0x27e73422,0x9e350c30}},	//   рхії_, _ocak, _renn_, _левч
  { {0xb5fb002f,0x8e850029,0x61ed3173,0x4a453423}},	//   bhái, _الره, naal, снив
  { {0xb5fb3424,0xe9390086,0x29043425,0x27e708d2}},	//   chái, اسبت_, guma_, _penn_
  { {0x76880064,0xfc300029,0x35fa002b,0x26c73426}},	//   tıyo, _يحل_, گردد_, _puno_
  { {0x2bdd005d,0x27e7003c,0xdd060064,0xf529000a}},	//   _न्या, _venn_, _köşe, _רץ_
  { {0x27e7018b,0x6b7a0053,0x76880064,0x21290509}},	//   _wenn_, _גרענ, cıyl, kwah_
  { {0x1e3a0053,0x5e56004c,0x0555013e,0x29043427}},	//   אגרא, צישע_, отря, cuma_
  { {0x6258002f,0xa3d3005d,0x43f90080,0x4d7a0053}},	//   _níor, हुल_, ихся_, אָלא
  { {0xe79a0089,0xd8740015,0x28120015,0xa6d5002b}},	//   _těší, _بانب, _رويس, _اغتش
  { {0xe813014e,0x5756013a,0x6d5600cb,0x61ed3428}},	//   त्रा_, _לבצע_, øyak, gaal
  { {0xc693000f,0x71250015,0xbba4000b,0x41aa312e}},	// [6c20] _מאה_, يركل, _ओर्क, уван_
  { {0xf5370008,0x320902f2,0x76880061,0x629d3429}},	//   _פריז_, agay_, zıyl, _ekso
  { {0x20b90080,0x444431c1,0xa3b4000b,0xc2c6002b}},	//   рыть_, _in_, जेश_, _ديجي
  { {0xdee50029,0xb5fb002d,0x2904003f,0x5d6a004a}},	//   تأكي, thái, yuma_, лием_
  { {0x6258002d,0xfff80086,0xcd330015,0xdd060061}},	//   _fíor, _نکات_, كروب, _döşe
  { {0x29042b4d,0x55bb000a,0xead80033,0x343a004c}},	//   vuma_, אמנו, амкі_, רײַע
  { {0x907b00b2,0x3ed80008,0x4ed8000a,0x76880061}},	//   _עטלי, _כַּא, _כַּנ, tıyl
  { {0xb5fb342a,0x78d4006b,0x2904342b,0x764402f2}},	//   phái, ожих, tuma_, _nniy
  { {0x768801e2,0xa3d8005d,0xc7c60036,0x44440e92}},	//   rıyl, ाडा_, йсни, _on_
  { {0x76880064,0x082a0254,0x4444342c,0x3157000a}},	//   sıyl, уции_, _nn_, ציין_
  { {0xab960029,0xdd120024,0xb09b0008,0x309b0008}},	//   _الضغ, kļūt, רייר, רשימ
  { {0x4444342d,0x38a2002e,0x1dbc000b,0x656f0ccc}},	//   _an_, iðri_, _ऋणात, tzch
  { {0x44441521,0xa2b9000b,0x09360021,0x88c60015}},	//   _bn_, ्दस्, _دراج, _اتصل
  { {0x656f005c,0x76440064,0xf48701f3,0x39590353}},	//   rzch, _eniy, сумн, ässe_
  { {0xa87b0008,0x7e620c4d,0xa3d8000b,0x6d46001a}},	//   _תאור, kkop, ाड़_, _ákaf
  { {0x63a90089,0x23d9000b,0x5b7b004c,0xe5c70300}},	//   řeno, _ब्रद, ארלא, _уско
  { {0x10d80029,0xc0d50086,0x61ed342e,0x752d0046}},	// [6c30] مبلغ_, زياب, raal, _usaz
  { {0x61ed0201,0x91d9000b,0x7e62342f,0x3387005e}},	//   saal, _फ्रै, ekop, _гумв
  { {0xff040010,0x61ed3430,0x38a2001a,0x2bcc000b}},	//   зячн, paal, gðri_, ाशना
  { {0xf8c8005d,0xf5ab000a,0xa3ae000b,0x079b004c}},	//   रदाय, ְבַּ, _औरत_, נסאל
  { {0x44443431,0xccfb0001,0x6258002d,0xb6bc000a}},	//   _yn_, уће_, _tíor, אצאי
  { {0x4c840010,0x6ab3005d,0x8c4220d1,0x351c000a}},	//   плів, ुद्र, деше, טודנ
  { {0xfcb2002c,0x1ee7002b,0x44333432,0xb4e60065}},	//   úšať_, _دوزی_, _max_, _पब्_
  { {0x9f430089,0x3ce00011,0xdab90010,0xdaa9012e}},	//   _její_, ţiva_, шылі_, јвид_
  { {0x3945005e,0x88c902d9,0xdc27007f,0x0000006a}},	//   іног, јлов_, _göğs,
  { {0xa8740080,0x645701f9,0x998b005a,0x0000006a}},	//   зующ, _noxi, žců_,
  { {0xdb1f00f2,0xddc00064,0xf6263433,0x7e693434}},	//   äväs, _komş, одно, _klep
  { {0xa3bf005d,0x3cf0005d,0x9f4a001c,0x2c6b0293}},	//   ेशन_, ुंचे_, _bebê_, _døde_
  { {0x1c1e000b,0x0ab80015,0xd8750015,0x6457270e}},	//   _मॉडल_, _اطلب_, _واتب, _boxi
  { {0xf9b6000a,0xf813002b,0xe73902c4,0x66e506a6}},	//   _והנך_, _رستگ, _век_, _дока
  { {0x44443435,0xa3b4005d,0x389a0008,0xe27a006b}},	//   _vn_, जें_, _דיסנ, ащаш_
  { {0x4444108d,0xb5fb2918,0xf6970015,0xd6b60058}},	//   _wn_, lkán, _ونوع_, _بإتب
  { {0x01d70029,0xa19e0033,0x44443436,0xfc4701c0}},	// [6c40] توقع_, тывi, _tn_, _číny_
  { {0xf8bb000b,0x394d0144,0xa3eb0157,0xa3d3000b}},	//   ैदिय, ixes_, मरण_, हुआ_
  { {0xb7fa000a,0x0dca155e,0x27f8002a,0xdee6005e}},	//   שפעת, алей_, órni_, іоди
  { {0xf3f10023,0x7e620007,0x61460076,0xa5bb0030}},	//   ực_, ukop, _дема, deój
  { {0x1ea90029,0xbc4a0001,0xa2b9005d,0x1bd410a0}},	//   حالي_, ичке_, ्दर्, поля
  { {0x653b0053,0x7e693437,0xdc2a002b,0x7e623438}},	//   יענד, _elep, شسته_, skop
  { {0x7e623439,0xbb430004,0xcb670054,0xbb470015}},	//   pkop, дејк, жаје_, قلون_
  { {0x1fa70036,0x0ab30029,0x2c6b0293,0xaab30015}},	//   _єкти_, وحيد, _røde_, وصيت
  { {0xbe1300c3,0x7faa0065,0x2c6b01d0,0x0000006a}},	//   _توقع, _करुँ, _søde_,
  { {0x7e69099c,0xe1ff0030,0x3ea6343a,0x7c660015}},	//   _zlep, _alól_, llot_, _بارل
  { {0xf0930053,0xd83800bd,0xbb8600e6,0xda660015}},	//   ונז_, joče_, _بلاي, _واصي
  { {0x645a007c,0x8f9b000a,0xd83802d8,0x7d02076d}},	//   ötin, שיטי, doče_, oros
  { {0xb05b008c,0x4433343b,0x7d020d28,0xd6280138}},	//   _etäy, _pax_, nros, цоўе_
  { {0x7faa000b,0x2813002b,0x6fda000b,0x7d02343c}},	//   _करूँ, _يونس, _प्लू, iros
  { {0xd838018c,0x22bb0015,0x54b8005e,0x7ea3007c}},	//   goče_, لدرع_, ігся_, sõpi
  { {0x4789078f,0x443300da,0x6595005e,0x44f50e60}},	//   _усім_, _wax_, _найу, _епис
  { {0x4433003e,0xe0d000c3,0x661b007c,0x6457343d}},	// [6c50] _tax_, نزل_, õuku, _toxi
  { {0x30a70010,0x7e69343e,0xa0a7005e,0xd83800bc}},	//   ірав, _slep, ішал, ločb_
  { {0xf4940015,0xf412000a,0x27ea002a,0x40840c30}},	//   _تشيد, _אפי_, óbny_, футб
  { {0xbdf80015,0x3ea6343f,0x38ab04d1,0xb5fb013f}},	//   قرها_, glot_, jørn_, chát
  { {0xee380010,0x61e202c1,0xdca10033,0xa63c004c}},	//   ўні_, ñole, нскi_, יגאר
  { {0xec78005e,0x91ba000a,0x434b000a,0xe58c000a}},	//   опі_, _למרי, ֹעֵ֑, יָוָ
  { {0x7d023440,0x0000006a,0x0000006a,0x0000006a}},	//   aros,   ,   ,
  { {0x7e69005c,0x394d0251,0x7d023441,0x98af0160}},	//   _ulep, txes_, bros, đače_
  { {0x527c0053,0xe806000b,0xa3eb000b,0xceb2000a}},	//   ינהא, _शाखा_, मरा_, _טיל_
  { {0x394d3442,0xd709004a,0xf8b1002b,0xe61f0034}},	//   rxes_, бное_, رکش_, snôl_
  { {0x786d0084,0x4eb5000a,0x628f002a,0xf7451e40}},	//   _núve, ּהָב_, _ojco, чено
  { {0xeaae0036,0xe1ff002e,0xb5fb3443,0xbb840015}},	//   _їй_, _blóm_, skán, _تلمي
  { {0xe79a0089,0x2f150123,0x2a360015,0xd94506a6}},	//   _měří, håg_, _ركود_, _хели
  { {0xa7fc0064,0x52b4000b,0x493a000a,0x1d16000a}},	//   lkın, ंग्स, _לגנו, הקשר_
  { {0x03390036,0x290b006f,0xb5fb3444,0x7d022402}},	//   оїть_, žiaľ_, okál, zros
  { {0xb5fb00dc,0x02c3030c,0x26130065,0x7d020535}},	//   nkál, ейсо, _थायी_, yros
  { {0xdfd200e6,0xd83800bc,0xe7f2000b,0xb5fb3445}},	// [6c60] فيذ_, soče_, _आजमा_, rhát
  { {0x2bdd005d,0xb53b000a,0xd3e4002b,0xf3f10016}},	//   नुमा, _פגיש, _تقدی, ựa_
  { {0xa7fc01e2,0xef1a0001,0xd00f0115,0xb099005e}},	//   kkın, сме_, الم_, ітує_
  { {0x442a21f6,0x8ca4000b,0xb5fb0030,0xdb160046}},	//   leb_, _चीजो, lhár, ícíh
  { {0xb2bb0008,0x61e43446,0x3ea63447,0xdca63448}},	//   _למטר, mbil, rlot_, пади
  { {0x442a3449,0x251b000a,0x4438344a,0x3fcb002b}},	//   neb_, מונא, ndr_, _هدفی_
  { {0xeb470033,0x7bf30015,0x44380034,0xdee60515}},	//   зчык_, رثوذ, idr_, _хоби
  { {0x442a0020,0x61e41914,0xdb0f001a,0xeb970054}},	//   heb_, nbil, _ódýr, џић_
  { {0xb21b0af5,0x6e930015,0x99d30015,0x61e40a2d}},	//   _kjær, _ألقا, رتيا, ibil
  { {0x645a00f2,0x98730afa,0x7dd1002d,0xa7fc0061}},	//   ötil, ельц, _tósó, akın
  { {0x7bdb013a,0x442a0176,0x1faa005d,0x9f4a0533}},	//   _הקבו, deb_, _करोड, _bebé_
  { {0x442a007c,0x673a00cb,0xfb87002b,0x4438344b}},	//   eeb_, rvtj, _عدلی, edr_
  { {0x4a57000a,0x442a0034,0x61e4344c,0xd94300af}},	//   _משאל_, feb_, dbil, _пеци
  { {0x27e90023,0xd7fa000d,0x19bb0008,0x34950010}},	//   _đang_, _ѓул_, _המדב, фагр
  { {0x85570086,0x926b0004,0xf837000a,0x7524344d}},	//   زیگر_, браа_, _זנות_, _epiz
  { {0xfbdf0092,0x61e40035,0x63a50107,0xd6eb000a}},	//   _đêm_, gbil, _vyhn, _הַזָ
  { {0xd49b0191,0xb5fb002d,0xc694000a,0xdb010046}},	// [6c70] _грн_, shás, _ראפ_, _vylé
  { {0xd8b90053,0x3942008c,0x2f150123,0xb5fb04b2}},	//   ַצײכ, äksy_, tåg_, chár
  { {0xde350010,0x6d4008aa,0x61e42e84,0xa5bb0030}},	//   дэль, _arma, bbil, deói
  { {0xdbf7000b,0x8d74009a,0x63c3005a,0x0000006a}},	//   ील्ड_, کاما, ětně,
  { {0xc7b8010b,0xe79a0089,0x2f1500c0,0xb21b00cb}},	//   među_, _věří, såg_, _fjær
  { {0x92030024,0x7c2a344e,0xdb20013f,0xb21b00cb}},	//   žādu, gefr, _štáb, _gjær
  { {0x64550111,0xff04054f,0x290401c2,0x6d40344f}},	//   ijzi, _пятн, erma_, _erma
  { {0xac770074,0x628d0020,0x9e34004a,0x442a3450}},	//   _کارش, nnao, _песч, zeb_
  { {0x61ef0064,0xcbc7002b,0x62880003,0xa7fc0061}},	//   _mecl, _فزاي, édoi, rkın
  { {0xa3bf005d,0x27ee0026,0xa7fc0061,0x752f002a}},	//   ेशा_, _cefn_, skın, dwcz
  { {0x752f005c,0x442a0046,0xa49b0144,0x998f0046}},	//   ewcz, veb_, tròn, _tagů_
  { {0xf1bf000b,0x61ef0045,0x9c13003d,0x442a02b8}},	//   ्शान, _necl, žādī, web_
  { {0x442a3451,0xe5770010,0xfdf60008,0xcdf6000a}},	//   teb_, дзя_, וצרת_, ומרי_
  { {0x27ee0026,0xd4550036,0xb5fb00dc,0x49ba000a}},	//   _gefn_, нтсь, nkáj, _ומנס
  { {0x61e43452,0x03a3007a,0xa69607c1,0xd6aa0015}},	//   tbil, виро, _ориј, _ودعم_
  { {0xd2aa0010,0x442a3453,0x96950033,0x52aa0138}},	//   ікае_, seb_, _прыш, івам_
  { {0xd83800bd,0x442a0020,0x8ffa00e5,0x15fb000a}},	// [6c80] loča_, peb_, قرار_, _והפע
  { {0xc4830323,0x61e43454,0x6aa902ad,0x0000006a}},	//   _альк, sbil, hlef,
  { {0x69cb04ed,0x69d90111,0xee3a226a,0x889a004f}},	//   _ogge, _ofwe, жне_, קבעי
  { {0x9e660010,0x7c2a0026,0x61ef0186,0x0d861899}},	//   ьвед, wefr, _gecl, млен
  { {0x0000006a,0x0000006a,0x0000006a,0x0000006a}},	//     ,   ,   ,
  { {0x69d90234,0xd0120015,0x35a5000b,0x8d63006b}},	//   _afwe, _جلس_, _गुफ़, ъвче
  { {0xd83800bd,0x7d0b0095,0x7c2a3455,0xa037004f}},	//   joča_, augs, refr, _קאלה_
  { {0xa7fc0061,0x6aa901ee,0x9f7b000a,0x0f7b000a}},	//   akıl, glef, _ונלח, _ואלב
  { {0x6d401edd,0xedd30015,0x6440003d,0xad66002b}},	//   _urma, _شيلد, ēmij, _غاره
  { {0x29fe0092,0x6c860087,0x8bb60015,0xe786008b}},	//   ịa_, _غلام, _قصاص, думо
  { {0xd838018c,0xeafa012c,0xb5fb0046,0x25b21c65}},	//   goča_, _ذرات_, skám, _azyl_
  { {0xeef7000a,0xeb91004f,0x2bcc0065,0x8cc60065}},	//   ומטר_, _גָד_, ाशवा, ादको
  { {0x61ef0440,0x661d3456,0xa7fc0061,0x95c80d7a}},	//   _recl, rfsk, lkım, дура_
  { {0x3d06000b,0xe8540015,0x61ef00da,0x6aa0025d}},	//   _हटने_, _سنبد, _secl, lomf
  { {0xd25b0001,0xe72f0015,0x889b000a,0x5b7b004c}},	//   оца_, _نصي_, _ובגי, ַרמא
  { {0x96fb0008,0x6aa000c0,0xcb370008,0x46580029}},	//   _ולהת, nomf, ואלי_, _يؤيد_
  { {0x4a5b0008,0x61e20077,0x5187005e,0x6e2b0030}},	// [6c90] קדמו, ñola, фува, vegb
  { {0xa7fc0064,0x31c40001,0xd098002b,0x32c70034}},	//   kkım, ђств, وئلا_, _gŵyn_
  { {0x61ef3457,0x91c00065,0x0000006a,0x0000006a}},	//   _tecl, लेबै,   ,
  { {0x7bda3458,0x5fdf005d,0x44ed0046,0x61fd02de}},	//   _aftu, _प्रल, ož_, _udsl
  { {0xece80036,0xa7fc0061,0x6e2b166c,0x6489003d}},	//   дділ_, tkıl, regb, ažie
  { {0x44ed0089,0x6ee70015,0x7d0b2790,0x62880247}},	//   iž_, _يسأل, rugs, édov
  { {0xa7fc0061,0xb7f2000b,0xfaa50120,0x6cc20033}},	//   rkıl, _आज़म_, нако, ыйша
  { {0xa3b4014e,0xa7fc0061,0x7d040125,0x7bda001a}},	//   जेट_, skıl, áisc, _eftu
  { {0xfd100015,0xa7fc0061,0xf865005e,0xb5fb005a}},	//   _نجل_, akım, евпо, akák
  { {0x44ed016f,0xd83800bc,0xd709004a,0xac380058}},	//   dž_, toča_, пное_, _يسلط_
  { {0x0c840033,0x44ed3459,0xdeb9000a,0xc052000a}},	//   _рытм, ež_, ּמָל, אזי_
  { {0x7e790064,0xd838345a,0x26c902b9,0x6aa000da}},	//   _çapı, roča_, _ciao_, comf
  { {0xf484002b,0x2a56000a,0xceb2000a,0x0000006a}},	//   ناسی, _רבנן_, טיט_,
  { {0xe1ff00dc,0x3a2d1d9d,0x28150015,0x0000006a}},	//   _adó_, leep_, _أوغس,
  { {0x787a000a,0x6ed4000b,0x366a14c2,0x14170058}},	//   _צָדו, _बंधु, _нако_, عيفة_
  { {0x26c90023,0x3d00005d,0x47580036,0xe0da3333}},	//   _giao_, _रिले_, _юрія_, зва_
  { {0x41270403,0xd5b204c9,0x31260033,0x62840072}},	// [6ca0] ното_, _حفظ_, эдаг, riio
  { {0xfe0d005d,0x80a60002,0x351b000a,0x859b000a}},	//   _हाउस_, رمان, _צוינ, _משפו
  { {0xb4be000b,0xdd92002b,0x7ed5005e,0x3a2d345b}},	//   ेदी_, گوش_, вічч, keep_
  { {0x2bdd005d,0x443a0026,0x42db0008,0x645e345c}},	//   नुसा, _hap_, _מקטע, _hopi
  { {0x61f60064,0xb7bc0024,0x443a345d,0xdd920067}},	//   mayl, reģi, _kap_, دوش_
  { {0x61f60064,0x3d20000b,0xbd43006e,0x645e345e}},	//   layl, _यहीं_, انوي, _jopi
  { {0xc27a0008,0xf413000a,0xaa87002b,0x443a345f}},	//   ּרִי, אפו_, کنيم_, _map_
  { {0x443a0014,0x61f60064,0xb5fb0030,0x44ed0046}},	//   _lap_, nayl, rkák, yž_
  { {0x7e970029,0x99980046,0x7ac3004a,0x3942001a}},	//   _أنقر_, ěrů_, ысше, íks_
  { {0x443a00dc,0x645e133c,0xdcf70015,0xe872002b}},	//   _nap_, _nopi, _أفلت_, اندگ
  { {0xaae60015,0xd794009b,0x49ca01e9,0x0000006a}},	//   _أسطو, тинъ, _елен_,
  { {0x76880064,0xa4d5005e,0x443a0079,0x7c3a3460}},	//   dıys, комі, _aap_, _hatr
  { {0x7c3a0048,0x5dfb000a,0xda650021,0xb5fb0030}},	//   _katr, הפכנ, _جالي, nkái
  { {0x443a08e0,0x69dc0050,0x645e1470,0xed4e0033}},	//   _cap_, śred, _copi, роi_
  { {0x443a00d9,0x083b0135,0x27e00092,0x883b000a}},	//   _dap_, _מעגל, _đinh_, _מתגו
  { {0x32c70026,0x61f60061,0x7c3a3461,0x0000006a}},	//   _gŵyl_, gayl, _latr,
  { {0x764d33c8,0x81170015,0xe0d30015,0x60390033}},	// [6cb0] _inay, عذرا, ازر_, мпаў_
  { {0xc1040015,0xc0ab0015,0xed51002b,0x443a02e7}},	//   اولي, ساءل_, یپا_, _gap_
  { {0x3f150238,0x61f63462,0x289b000a,0xe818000b}},	//   тдес, bayl, לימא, _दाना_
  { {0xa2d6014e,0x78a10011,0x91a2005d,0x41b50015}},	//   _मंत्, zolv, _कुवै, _لمجر
  { {0xc1f6013a,0x443a28f8,0xd83800bc,0xdb010046}},	//   _במרץ_, _yap_, jočo_, _vylí
  { {0x538b0008,0xe53c0008,0xc4d40643,0x7c3a3463}},	//   ּנֵ֣, פתור, אגס_, _catr
  { {0x764d3464,0x7c3a0026,0x78a13465,0xac74002b}},	//   _onay, _datr, volv, دانش
  { {0xde46002b,0x5338004f,0x0b880058,0x0000006a}},	//   _لیمو_, תאהב_, عضوي_,
  { {0xdb080089,0x3912002b,0x78a10030,0xfd130015}},	//   _vzdá, لويز, tolv, _حجز_
  { {0x7c3a00e8,0x29030198,0x764d3466,0xf7710015}},	//   _gatr, čja_, _anay, لاج_
  { {0x6e3b0005,0x78a100dc,0x5b550015,0xd7c9002b}},	//   _kaub, rolv, _جَاء, بوده_
  { {0x645e3467,0x443a3468,0x7c3a3469,0x78a1346a}},	//   _sopi, _sap_, _zatr, solv
  { {0x290d0077,0x645e0fd0,0x78a1346b,0xba740040}},	//   quea_, _popi, polv, _حالت
  { {0x232a0036,0xc976000a,0x6e3b346c,0xccf2000a}},	//   моги_, _בגני_, _laub, שכם_
  { {0xf8c80023,0x889a0008,0x61f60064,0x68fb0134}},	//   _cứu_, _קבצי, tayl, lsud
  { {0x69db02c1,0x02be000b,0x6e3b02f2,0x48e8000b}},	//   ncue, ्देन, _naub, चीको_
  { {0xd5af0029,0x02d2000b,0x645e346d,0x61f60f0a}},	// [6cc0] _وفى_, _दूरभ, _topi, rayl
  { {0x64890085,0x3fe30ee7,0x0446012e,0x443a01d7}},	//   ržic, ижув, _реон, _uap_
  { {0xdfcf00e5,0x93fb000a,0xf3f3000a,0x7eb100cb}},	//   زين_, _קלטי, _דףת_, råpn
  { {0x59b3000b,0x64890091,0xbd8a00c3,0x7e27005e}},	//   ुधार, mžia, ونان_, віша_
  { {0xdd8f003b,0x6cd30015,0x786d0144,0x5d170015}},	//   يوم_, لقنا, _núvo, نتوج_
  { {0x6489002c,0x68fb346e,0xeb4a033d,0xa2b0000b}},	//   ožia, dsud, дчик_, ंतव्
  { {0x7c3a0cd0,0xab270099,0x6e3b346f,0x9fc70151}},	//   _vatr, воја_, _faub, _агра_
  { {0xcc880092,0x8f37000a,0x2f1c0030,0xba180015}},	//   iới_, _באלו_, míg_, ريخا_
  { {0x7e60002f,0x67d40165,0xb21b02de,0x20d8000b}},	//   _iomp, лопу, _omæn, _भूमध
  { {0x6e3b00b8,0x91bb01ac,0xf8c80016,0x7e60008c}},	//   _zaub, ומפי, _nứt_, _homp
  { {0xbbd7000a,0x7e603470,0xfeca000a,0x68fb007c}},	//   _סואץ_, _komp, ֽמָּ, asud
  { {0x648900df,0x69db0152,0x6b7b0053,0xa5bb0f3c}},	//   džia, ccue, _קראנ, deór
  { {0x3940002f,0x66de0024,0xe61f006f,0x5507006b}},	//   _éis_, _sīkd, dnôt_, ъчна
  { {0xdddb01e2,0x80d6005d,0xd7ef009c,0x23770015}},	//   _oluş, _बढ़े, _њу_, نازح
  { {0xf8c80092,0xd6cf006b,0x248d0085,0x0000006a}},	//   _dứt_, _ът_, đem_,
  { {0x764d000c,0xbb3b0008,0x31352044,0x82370015}},	//   _unay, ועלי, лебр, خرسا
  { {0x2ba9014e,0xc05b078f,0x64892786,0x6e3b0012}},	// [6cd0] _चुना, між_, ažia, _raub
  { {0xa0740033,0x4ee70033,0x62880030,0x2f8b0054}},	//   агуч, відз, édor, мљен_
  { {0x2fc701d1,0x44313471,0x4dd70015,0x201c0144}},	//   äng_, mez_, نتشس, òvia_
  { {0x44313472,0x7e600c90,0xacf90511,0x38b90003}},	//   lez_, _comp, енду_, mère_
  { {0x867c0008,0x38b90152,0x067c000a,0x7d25006e}},	//   וראו, lère_, ונאל, افتن
  { {0x30790053,0x6738016f,0x44313473,0xcfe9006e}},	//   _טאָנ, _osvj, nez_, _سفره_
  { {0x6d420440,0x3ec7008f,0x0af4008f,0x39460176}},	//   avoa, _асаб, ачыў, _aros_
  { {0x44311f11,0x68fb3474,0x39463475,0x5e450058}},	//   hez_, tsud, _bros_, _حَرْ
  { {0x38b90152,0x69db0140,0xc8f8002b,0x88c90004}},	//   hère_, rcue, نويچ_, нлив_
  { {0x39460176,0x69db0c07,0xead5004a,0x46e9249a}},	//   _dros_, scue, _божь, ндон_
  { {0xeb090029,0xf77100e6,0x5e75000a,0xf09405bd}},	//   _أقصى_, صاد_, ָתָן_, ינץ_
  { {0xddc20024,0x38b90152,0xa50a03de,0x69dc0046}},	//   lkoš, dère_, нема_, ěrec
  { {0x39463476,0x80d3000b,0x69da004c,0x6faa000b}},	//   _gros_, _भूले, _אַוו, _जुनू
  { {0x44311f05,0x38b90003,0x26d1016e,0xf4950033}},	//   gez_, fère_, ízos_, арсю
  { {0x38b90152,0x291f00f2,0xe2ba0054,0xf8b2000a}},	//   gère_, ltua_, ећај_, _השג_
  { {0x6489002c,0x59c0000b,0x3ce6006f,0xa5bb1945}},	//   ržia, शेवर, ypov_, mfón
  { {0x66040035,0xb1460010,0xf4960015,0xb5fb0046}},	// [6ce0] _idik, ынал, _مشدد, tkáv
  { {0x44310152,0x64891283,0x38b90003,0x2a6d007c}},	//   cez_, lžin, bère_, hkeb_
  { {0x441b00b2,0x291f00f2,0x141b00a3,0x7f8600e5}},	//   _אויס, htua_, _אויב, دلان
  { {0x4ea50036,0xb5fb0089,0xd337000a,0x23650123}},	//   аріа, skáv, _ערכה_, älje_
  { {0xadf30036,0x127b004c,0xac1806ab,0x93fa000a}},	//   спіш, _טאטע, волу_, ֲלֵי
  { {0xdca30036,0x75370053,0x3eaf0723,0x22403477}},	//   бачи, טאנד_, algt_, ldik_
  { {0xf4130008,0xfaa6006b,0x9f56002a,0x291f07c8}},	//   צפה_, лшин, ęgów_, etua_
  { {0x44310050,0x6f930029,0x5f930029,0xba760015}},	//   zez_, _الفض, _الفئ, طاعت
  { {0xa9c30191,0x4431038d,0xde170015,0x212000bc}},	//   йськ, yez_, _حققت_, ntih_
  { {0xb8dc005d,0x628100dc,0x3137000a,0x38b90003}},	//   _आठ_, éloz, ננים_, yère_
  { {0x44313478,0x0057000f,0x6286271c,0xe655005e}},	//   vez_, אשית_, _omko, авнь
  { {0x1efb0053,0x3ea60159,0x38b90003,0x212000bc}},	//   עלכע, noot_, vère_, ktih_
  { {0x44313479,0x9c8300bd,0xa4d50127,0xe918042b}},	//   tez_, _ščit, рогі, _ролі_
  { {0x38b90152,0xa4d4005e,0x64890091,0xb5fb0030}},	//   tère_, сорі, ažin, nház
  { {0x4431347a,0xfe14000b,0x212000bc,0x66e301ca}},	//   rez_, _डांस_, etih_, _лоја
  { {0x4431038d,0xeb91000a,0x38b90003,0x7d0b001a}},	//   sez_, קָם_, rère_, yrgs
  { {0xf4850086,0x38b90003,0x7c28347b,0xda4b000a}},	// [6cf0] _نادی, sère_, _obdr, עֲלָ
  { {0x38b9211c,0x7ff40015,0x7d1d007c,0x2240007c}},	//   père_, مسما, _ässi, adik_
  { {0x6ee70029,0x63680063,0x63a900b8,0x8f470033}},	//   اسئل, _бряг_, ßend, ыхад
  { {0x63a90061,0x4fc4004a,0x7c28347c,0x3ea6042f}},	//   ğend, ссуа, _abdr, goot_
  { {0x067c0053,0xed580036,0xa3bf000b,0xd167006b}},	//   ענדל, лої_, ेशक_, _съни
  { {0x61ed0111,0x6b65347d,0x4d880015,0x5b350015}},	//   lbal, икла, دَهُ_, لعبر
  { {0xb5fb00dc,0xcbf80015,0xe9d10015,0xec120015}},	//   nkás, اءها_, يغة_, زويد
  { {0x291f0ddf,0x752d0844,0xddc20085,0x23bc0046}},	//   ttua_, _opaz, skoš, _hájí_
  { {0x291f00f2,0xe8f60802,0x6e2902f2,0xcb09002b}},	//   utua_, алы_, _ibeb, ريکن_
  { {0x648900df,0xb5fb27b8,0x00f6000a,0x22400030}},	//   džio, cház, סמתך_, zdik_
  { {0xab840010,0x291f00f2,0x2ca70220,0x8b35002b}},	//   _луцк, stua_, mond_, _خفاش
  { {0xa6de0092,0x61ed0111,0xf1c5005d,0xaa2b00f2}},	//   _trưn, jbal, वधान, äkää_
  { {0x69670086,0x38ab02e9,0x61ed2fb8,0x99d4012c}},	//   _حداق, ført_, dbal, _اتما
  { {0x18661174,0x6676002b,0x4415006b,0x2ca702f2}},	//   _ваши_, ادگر, йфст, nond_
  { {0xd8b80086,0x07d80029,0xf836039e,0x81f6005e}},	//   _صدها_, _إذهب_, _כנסת_, ичаї
  { {0x61ed0035,0x171a004c,0x179a000a,0x2ca70079}},	//   gbal, _סופע, _שיקב, hond_
  { {0x2ca70005,0xdb0100f2,0x22400915,0x25d7000a}},	// [6d00] kond_, _hylä, rdik_, _דופן_
  { {0xf00b0023,0xa4fb0008,0xb5fb0089,0xe0df0092}},	//   _đảng_, _שליט, skát, _tròn_
  { {0xe29a008f,0x21200582,0x6d49347e,0xef860054}},	//   _аан_, stih_, _area, јлеп
  { {0xa1160086,0xb5fb00dc,0x6d490541,0x63a8007c}},	//   _پوست, lkár, _brea, üdnu
  { {0x2bb50092,0x3ea60234,0x6d49189e,0x2ca7347f}},	//   _ác_, root_, _crea, fond_
  { {0x23ba005d,0x6d493480,0xbfd30015,0x6f0b0061}},	//   _इराद, _drea, _ويُع, ümcü
  { {0xe4570053,0x8bc30063,0x290d1f5f,0xb5fb1115}},	//   ייסט_, осъд, erea_, rház
  { {0x6d49002f,0x7f3b0008,0xd83800bd,0x998a0046}},	//   _frea, _בעלו, moči_, émům_
  { {0x62960035,0xd83800bd,0x6d490541,0xda77006b}},	//   inyo, loči_, _grea, рящ_
  { {0x2ca70493,0xc7c618ba,0xc86605b3,0x7bf8000a}},	//   cond_, исни, ртии, _תִּה
  { {0xa2d6014e,0x290d04f9,0x752d04ed,0x6d490d55}},	//   _मूल्, area_, _spaz, _zrea
  { {0xe818005d,0xe6950080,0x7aea00b8,0x5694034e}},	//   _दावा_, симы, mpft, жают
  { {0x9538006b,0x4a7b004f,0x7a7b004f,0xc98300af}},	//   азят_, _בראב, _בראס, _муши
  { {0xb8ea005d,0x939700a2,0x997b000a,0xa786002b}},	//   लग_, لجزا, _שָׁפ, _پشتو
  { {0xe2870083,0xd83800bd,0x83f80afa,0x38cb002b}},	//   аѓан, joči_, ресс_, _شاهی_
  { {0x2777013a,0x4394005e,0x2ca7158f,0xd8380b28}},	//   _כגון_, іатс, zond_, doči_
  { {0xf8ba005d,0x2ca7003e,0x89eb0008,0x98ba005d}},	// [6d10] _उठाय, yond_, דַבֵ, _उठाए
  { {0xae14005d,0x78a800bc,0x61ed2dcc,0xb5fb0030}},	//   _डाउन_, nodv, sbal, ckár
  { {0xd83800bd,0x6d49002d,0x2ca70079,0x61ed00aa}},	//   goči_, _srea, vond_, pbal
  { {0xb5fb00dc,0x2ca70079,0x9757000a,0x4255006e}},	//   ljáb, wond_, ייבו_, _انحر
  { {0x2ca70111,0x5cf4004a,0xf532000a,0x68e93481}},	//   tond_, оящу, ּ֥ד_, xped
  { {0x7eb8002c,0x6d490011,0xc538000a,0x4c84005e}},	//   rípa, _vrea, שָׁה_, олів
  { {0xa3d8005d,0x2ca70161,0x6d4900da,0x0000006a}},	//   िशत_, rond_, _wrea,
  { {0x6da50086,0x6d49286b,0xdb060030,0x7d0c0061}},	//   _همزم, _trea, ámál, ülsü
  { {0x6d990010,0x2ca70152,0xb5fb30e6,0x66de003d}},	//   _сваё_, pond_, kjáb, _rīka
  { {0xa855009c,0x648905ca,0x66de003d,0x8d740021}},	//   стиј, užil, _sīka, _بافا
  { {0xe9450086,0xa5bb002e,0xf8ae002b,0xa822002b}},	//   _گرای, sfól, رکه_, سکون
  { {0xcf92000a,0x290d0983,0xd67a0015,0x68e91666}},	//   לטי_, prea_, احدا_, pped
  { {0xe9450086,0x98e50015,0xd763002b,0xe5720021}},	//   _درای, _اكتو, _ژنتی, سطح_
  { {0x261a000b,0xc952000a,0xb5fb0030,0x0000006a}},	//   _भावी_, _ממד_, gjáb,
  { {0xa3b4005d,0xfbd2000a,0x66de003d,0x786d03a0}},	//   ड़ें_, לתם_, _tīka, _núvi
  { {0x23653482,0x569300d7,0xb5fb0046,0x20cd0160}},	//   älja_, _најт, skár, _džim_
  { {0xa6170008,0x2fd60029,0xffd60015,0x70b60015}},	// [6d20] _הקפד_, متاح, مغاد, ممرض
  { {0x26d2000c,0x2f56034e,0x6aa90161,0x2aa1002a}},	//   _hiyo_, йтес, hoef, róby_
  { {0x20c90015,0x6437004c,0xdfcf0015,0xb5fa000a}},	//   شبكي_, _פאטא_, فيك_, ָלְכ
  { {0x290200df,0x786d001c,0xe3570008,0xd83800bd}},	//   škai_, _dúvi, _השטח_, roči_
  { {0x361b05bd,0xdb080046,0x64890729,0x0000006a}},	//   רונד, _vydí, džij,
  { {0x653b0053,0x3ead00dc,0x3d09000b,0xdca30004}},	//   טענד, _eket_, _सिरे_, пачи
  { {0xbc190036,0x26c03483,0x6aa900aa,0x7b460015}},	//   річі_, _ohio_, foef, إئتل
  { {0x25ad0050,0x6e96003b,0x26d20035,0x5e960015}},	//   żeli_, _الرا, _niyo_, _الرط
  { {0xdb240086,0x69340086,0x6c1a0015,0x4ddb000a}},	//   _ژوئی, تکار, _متاح_, _תחמו
  { {0x7c650029,0xc051000a,0xcd77000a,0x96ea0666}},	//   _والل, ֵ֖י_, _העמק_, льма_
  { {0xcb090036,0xa635008b,0xf6990054,0xcb6a0058}},	//   _вхід_, онні, ивој_, _حماه_
  { {0x8f9b000f,0xa7fc0061,0x78a80030,0x64891c4e}},	//   ריטי, tkıs, sodv, ržim
  { {0x261a005d,0x395900b8,0x9f470125,0x98a624bf}},	//   _भारी_, ässt_, únú_, _лиде
  { {0xf4840063,0x648901cb,0xd91b000a,0xdc19002a}},	//   пусн, mžik, _עוול, _błęk
  { {0xd9040086,0xe1d9005e,0xdb78000a,0xa7fc0061}},	//   کی_, идві_, בְּש, skıs
  { {0x7d023484,0xb797000a,0x2a66007c,0x32bb0058}},	//   ksos, _לכוח_, _joob_, ادسة_
  { {0x786d002c,0xc0ab0015,0xb5fb0030,0xc694000a}},	// [6d30] _súvi, هائل_, pjáb, _מאק_
  { {0x2a6600b6,0x46150086,0x5f950063,0x3ebf003e}},	//   _loob_, _اوکر, оизт, _shut_
  { {0xfe710086,0x9f040015,0x2c6b02de,0x273a003d}},	//   وگر_, كولو, _mødt_, _jūn_
  { {0xdd91006e,0xd8380085,0xe7870046,0x2242001a}},	//   ووا_, moču_, náší, _gakk_
  { {0xdca10010,0x656f2dd4,0xbd450015,0xed590a0b}},	//   мскi_, nych, تنشي, рол_
  { {0xc05b0036,0x2c6b0595,0xada40033,0x64893485}},	//   _сім_, _nødt_, чаіл, džik
  { {0xa7fc0064,0x6aa90079,0x3ebf0012,0x00ba000a}},	//   ykır, toef, _thut_, _כמשמ
  { {0x88e501b7,0xe9d9011a,0xfbd00015,0xc334004f}},	//   ожие, шки_, ءته_, פופ_
  { {0x2ba9000b,0x7d020030,0x527c000a,0x6aa90079}},	//   _चुरा, csos, טנהא, roef
  { {0x26d2003f,0x7c97012c,0x6c970015,0x68020046}},	//   _siyo_, _اشرا, _اشرط, víjí
  { {0x2ca010e0,0x38ca002b,0x9b950040,0xab95006e}},	//   éide_, جايی_, _بلات, _بلاغ
  { {0x8f1a000a,0xe7360342,0x9ae8000a,0xf3e9004f}},	//   סורת, цею_, _הַסִ, _יף_
  { {0x15ba0010,0x2c6b0293,0x656f0034,0x958302ed}},	//   рыны_, _født_, gych, дляе
  { {0x7d04002d,0x045a0015,0x7bf9004c,0xb5fb001a}},	//   áisi, جلسة_, יפֿצ, skáp
  { {0x43430063,0x3246068e,0xd25200c3,0x2242007c}},	//   мерв, оевг, ونس_, _pakk_
  { {0xd6d20029,0x4f5a0086,0x656f0046,0x63a90012}},	//   _تقع_, یجاد_, bych, ßena
  { {0x806609a7,0x33d605d1,0x25df000b,0xe3d60015}},	// [6d40] оваж, _мінт, _गलती_, _وتدع
  { {0x1fb60036,0x6ecc0064,0xe3b20029,0xd00a09d9}},	//   осер, _işbi, _يرد_, реже_
  { {0xe821005d,0xddc00089,0x224221b7,0x44443486}},	//   _माना_, _pomů, _takk_, _ia_
  { {0x44443487,0x87ac004c,0x764609f5,0x44380c6b}},	//   _ha_, נשאַ, ndky, ler_
  { {0x8cf3008f,0x61e40064,0xe7ab000b,0x44443488}},	//   дзіц, mcil, _घुसप, _ka_
  { {0x61e40064,0x82360086,0x44443489,0xfc2f0015}},	//   lcil, _ارگا, _ja_, نحى_
  { {0x656f005c,0x66de0024,0x9f4302c1,0x2c6b0293}},	//   zych, _rīko, _dejó_, _rødt_
  { {0xead3005f,0x4438348a,0xada601ca,0x4444348b}},	//   мощь, her_, _дабл, _la_
  { {0xe51c000b,0x79a30033,0x9a6700c3,0x4438348c}},	//   भूमि_, дрэе, تميل_, ker_
  { {0x7e62016f,0xf1b30008,0x3157000a,0x6d402ddf}},	//   ljop, וסח_, קיין_, _isma
  { {0x2a660020,0x673a0079,0x09e6067a,0x6fdb000a}},	//   _toob_, uwtj, _доен, יקיס
  { {0x656f005c,0x7e95005c,0x7e6200c0,0x4438049c}},	//   tych, tąpi, njop, eer_
  { {0x1dca005d,0x44380495,0xe4e4005e,0x4444348d}},	//   िधित, fer_, дісн, _ba_
  { {0x6a7c0152,0x4444348e,0x656f348f,0xf993000a}},	//   _défe, _ca_, rych, _קרס_
  { {0x6faa000b,0x7c2a0123,0x9f4102b9,0x44443490}},	//   _जुलू, iffr, cchè_, _da_
  { {0xd8381798,0x4444237d,0x66b403fc,0xa49b0144}},	//   leč_, _ea_, _общу, rròq
  { {0x142b022a,0x4444010a,0x20750033,0x44383491}},	// [6d50] _кіно_, _fa_, плаў, ber_
  { {0xdb01002c,0x44443492,0xe8d7000a,0x1017002b}},	//   _vylú, _ga_, קובר_, تبرد
  { {0x9f41002d,0x1eea0086,0x44213493,0x6d403494}},	//   lbhú_, مولی_, _ich_, _asma
  { {0x2259003b,0x29040020,0x9f41151c,0x51870001}},	//   _الحد_, ksma_, nché_, _дуга
  { {0x44443495,0x644500b6,0x61fd0024,0x78760045}},	//   _ya_, _kahi, _iesl, _râvn
  { {0xd838010b,0x644700dd,0x5cab0001,0x62a5002c}},	//   ječ_, ndji, шњег_, ťroč
  { {0x6d401f27,0x2ddb0015,0x64453496,0x6d463497}},	//   _esma, _نبذة_, _mahi, _škat
  { {0x60d501e2,0x4421002f,0x44383498,0x539c0135}},	//   _hizm, _lch_, zer_, ייוו
  { {0x442127a9,0x44380493,0xdb080107,0x61fd3499}},	//   _och_, yer_, _vydá, _mesl
  { {0x26dc00df,0x66de0048,0xa8740080,0x7c380152}},	//   _buvo_, _tīkl, дующ, cevr
  { {0x4444349a,0x66e80089,0xe73903ad,0xf092000a}},	//   _ra_, _někd, щен_, תני_
  { {0x4421017e,0x4444349b,0x64570493,0x9f4102b9}},	//   _ach_, _sa_, _anxi, rchè_
  { {0x2001349c,0x290200dc,0x89da000a,0xa49b0144}},	//   kahi_, ákat_, _החני, tròp
  { {0xb4b6005d,0x60d5003d,0xa3e707be,0x20011839}},	//   जते_, _nizm, здра_, jahi_
  { {0x64a3008f,0xd7fa0008,0x60dd00b8,0x4444349d}},	//   хара, _ההצל, _ausm, _va_
  { {0x44440f4d,0x60d50024,0xb5fb00dc,0xd5a7005d}},	//   _wa_, _aizm, lján, _टुकड़
  { {0x7c2a0026,0xa022002e,0x64451f9a,0xe0d7042b}},	// [6d60] yffr, _þökk, _fahi, зву_
  { {0x8fa6010f,0x61e402d7,0xb5fb0030,0x4444349e}},	//   пазе, scil, nján, _ua_
  { {0x33db000a,0x7d190079,0x69d90034,0x787a004f}},	//   _לחיד, euws, _ogwe, צָמו
  { {0x69d90026,0x0dca0080,0x61fd349f,0x5576000a}},	//   _ngwe, блей_, _gesl, ּעַן_
  { {0xa25b00a7,0x3eba0024,0x6445003f,0x41b9000b}},	//   _khôn, ēpt_, _yahi, _आरएस
  { {0x70190036,0x69d90026,0x91bb0008,0x55bb000a}},	//   _міст_, _agwe, _למכי, זמנו
  { {0xd83800bd,0x5e9604c9,0xb5fb00dc,0x207b0135}},	//   več_, _فلسط, dján, _פאלא
  { {0xb9540191,0x5eeb000a,0xf8ad002b,0x753d002a}},	//   двищ, _לַמְ, یکو_, ywsz
  { {0x48aa006d,0x6d40088a,0x2d820b1f,0x0000006a}},	//   йтом_, _usma, _åke_,
  { {0x6c860806,0xf8060036,0x7d7b0008,0xb5fb0030}},	//   _علام, ччин, _הנמו, gján
  { {0x35a5005d,0xd83807c4,0x644534a0,0x648906c0}},	//   _गुज़, reč_, _rahi, oživ
  { {0xd6d70a7f,0x644534a1,0x2a7f0313,0x4fbb000a}},	//   ять_, _sahi, chub_, מציא
  { {0x6445025c,0x9f4134a2,0x661d34a3,0x2cae0079}},	//   _pahi, rché_, rgsk, oofd_
  { {0x753d0050,0x290200df,0x26dc02c1,0x61fd0064}},	//   rwsz, škas_, _tuvo_, _sesl
  { {0xe821000b,0x88bb000a,0x64451150,0x24910ff8}},	//   _माता_, _המגז, _vahi, rizm_
  { {0x20010ef3,0x60f9054f,0xa79b000a,0x44210034}},	//   wahi_, жная_, _לשוח, _wch_
  { {0x644534a4,0x7e69016b,0x1c1c000b,0x442134a5}},	// [6d70] _tahi, _roep, नलाल_, _tch_
  { {0x66de0048,0xa2270086,0xd01100e5,0x34fc000a}},	//   _rīkj, _کرده, ئلا_, _ההזד
  { {0x7e7b34a6,0x61fd2667,0xf412000a,0x0f550015}},	//   _plup, _tesl, _בפי_, بَاح
  { {0xbdf80015,0xddd00091,0x3d95029f,0x7d79009a}},	//   كرها_, _šešt, миер, يمار_
  { {0x8c45058b,0xbdab0058,0x7ed4009a,0xdb080535}},	//   деле, حطام_, رزما, _ozdó
  { {0x69d90026,0xa3b1000b,0xa022007c,0x6f030030}},	//   _sgwe, टअप_, öötl, áncs
  { {0x9f340191,0x7e690384,0x660d34a7,0x6e9534a8}},	//   _пері, _toep, _odak, _живу
  { {0x22490d25,0x660d0064,0xc334000a,0x98e50015}},	//   ndak_, _ndak, תוק_, وكبو
  { {0x7d04002d,0x22490849,0x21290375,0xa9e40015}},	//   áist, idak_, ntah_, رثين
  { {0xa8890127,0x660d0375,0x2a7f34a9,0x7d0914a2}},	//   ійна_, _adak, shub_, _ives
  { {0xfb350010,0xa25b34aa,0x63a90012,0x628f01c2}},	//   _індэ, _rhôn, ßenl, _omco
  { {0x4975044a,0x7bc10085,0x150a0015,0x0000006a}},	//   _олес, _izlu, يْجٍ_,
  { {0xaa880029,0xa25b0092,0x63a90061,0xb5fb0030}},	//   _عنهم_, _phôn, şenl, pján
  { {0x02c6000b,0xb8e1000b,0x660d12be,0xc8c90058}},	//   लग्न, ंत_, _edak, _بوتن_
  { {0x394d0041,0x91e634ab,0xdc88000a,0x14170015}},	//   lves_, добе, פְשָ, ظيفة_
  { {0x648900df,0xc7b20008,0x7d0932fa,0x7eb8006f}},	//   džiu, _שבה_, _oves, rípk
  { {0xa25b00a7,0x4127017a,0xad9d002a,0xd3da0015}},	// [6d80] _thôn, мото_, _jeźd, _وبدا_
  { {0xb5fb001a,0x394d1359,0x2246006f,0x11d70058}},	//   hjál, ives_, žok_, ذولة_
  { {0x7f750010,0x72c605c4,0x7d0934ac,0x545b000a}},	//   нуцц, _обоз, _aves, _וכיצ
  { {0x11d60029,0xdddb0046,0x7d0900bc,0x0000006a}},	//   _يتحد, _kouř, _bves,
  { {0xb21b0134,0x66e1003d,0xdd92002b,0x648900b3}},	//   _slæg, _sēkl, خوش_, rživ
  { {0x394d00dc,0x718b0008,0xbd870067,0x7d0934ad}},	//   dves_, _וְלַ, ظنون_, _dves
  { {0x2ac60001,0x64890227,0xdee60054,0xeb470033}},	//   мљив, mžit, _цоби, дчык_
  { {0xb21b0134,0x2a7d0026,0xa27b0053,0x998f0073}},	//   _glæd, _clwb_, ַװיז, _nagų_
  { {0xdb0800f2,0xd2b7000a,0xa2b7000a,0xee3700e2}},	//   _sydä, ולקת_, ופקד_, _інф_
  { {0x6a7c0152,0x5b360015,0x2ba9000b,0x60db0144}},	//   _défa, _يعار, _चुका, _èume
  { {0x7bdb0008,0x4ccb000a,0xe758005e,0xf093000a}},	//   _וקבו, _וֶאֱ, чині_, כנז_
  { {0x787f0152,0xdddb0089,0x2a7d0026,0x63a90012}},	//   _rêve, _bouř, _glwb_, ßenm
  { {0x63a90061,0x47d4002b,0xb5fb0046,0xcdf7004f}},	//   ğenm, بيگر, okáz, ומכי_
  { {0xa9670001,0x61f60089,0x19bb000a,0xa5bb016e}},	//   _циља_, ebyl, _ומדב, egóc
  { {0xa4d40191,0x46a7005f,0x628100df,0x026b0010}},	//   торі, _ошиб, ūlom, ошай_
  { {0xe0df02d7,0xd6c30086,0x660d003f,0xdd0e000b}},	//   _può_, _جمعی, _udak, _सिंध_
  { {0x7eb8001c,0x90550010,0xf194007a,0x15fa000a}},	// [6d90] cípi, нвац, вить, _מִימ
  { {0x60b5006e,0x0000006a,0x0000006a,0x0000006a}},	//   رمائ,   ,   ,
  { {0x7d09016f,0xc4d2000a,0x21292fb0,0xceeb0369}},	//   _sves, _תגי_, stah_, زران_
  { {0xc33200b2,0xb21b0134,0x8de50015,0x0000006a}},	//   _גוט_, _emær, ركته,
  { {0x427a004c,0xf1c5000b,0x7d080058,0xddc2005a}},	//   _זארג, लेखन, ِيهِ_, akož
  { {0x351c0008,0x60fa000a,0xa0c50015,0xe0fa000a}},	//   קוונ, _מהשק, _سيزو, _מלשל
  { {0x1ee70086,0x24c8000a,0x7e78003d,0x8f690015}},	//   _آوری_, וּהָ_, īvpr, _عمرك_
  { {0xcdf40015,0x8b320015,0xb5fb0069,0xe8f9226f}},	//   _لأكث, افيش, akáz, пли_
  { {0xb5fb002e,0x9f41002d,0x394d34ae,0x8d770015}},	//   rjál, ichí_, uves_, _غارا
  { {0xb5fb34af,0x394d34b0,0x4c570015,0x1c570015}},	//   ckáz, rves_, _تضرر, _تخرج
  { {0xdddb0089,0x69c20111,0x394d34b1,0xe7ee000b}},	//   _souř, _ezoe, sves_, छड़ा_
  { {0x6f7a0008,0xda67002b,0x9733002b,0xaaf6004f}},	//   לְכו, _تائي, _یکجا, _נזנח_
  { {0xa25b0003,0x69fa004f,0x6abb02ad,0x7ae134b2}},	//   _chôm, _זלנק, mluf, _hult
  { {0xccf2000a,0x9817002b,0xc7a50ee7,0x94d30033}},	//   רכם_, _آبشا, _пилк, лоўц
  { {0x987a000a,0xd7e4005e,0x53a3005e,0xa87a000a}},	//   _מאסט, _річо, гарб, _מאסר
  { {0x7ae10939,0x85060015,0x60ea0033,0xb21b001a}},	//   _mult, _كوبن, змам_, _smær
  { {0x56370053,0x9f5834b3,0x660634b4,0xa69b000a}},	// [6da0] _טאקע_, _verí_, makk, _משקפ
  { {0x25d7000f,0x64890107,0x660634b5,0x94f7000a}},	//   _אופן_, užit, lakk, _רציף_
  { {0xdef90010,0x6fd50010,0x1eda0029,0x44e60092}},	//   дыі_, віцц, سباب_, _hô_
  { {0xc2240086,0x660634b6,0xc7d6000a,0x57cc004c}},	//   _جکسو, nakk, גועי_, קמאַ
  { {0x629601e2,0xdb010064,0x6284002d,0x7ae10003}},	//   miyo, _eylü, mhio, _ault
  { {0x44e60023,0x62961761,0x7ae134b7,0xb5fb006f}},	//   _mô_, liyo, _bult, ukáz
  { {0x7ae103b8,0x44e60468,0xa0a32c2a,0x0b5a0033}},	//   _cult, _lô_, _сард, ярды_
  { {0x62963279,0x66e80046,0xdb070046,0xba54012e}},	//   niyo, _něka, ílán, твиј
  { {0x44e61baa,0x6e930015,0x823b004c,0x6da31293}},	//   _nô_, _إلقا, לעקצ, _бита
  { {0x629600b6,0xd7f71561,0xdb24002b,0x893300c3}},	//   hiyo, ную_, _لوئی, اعيا
  { {0xe821005d,0x62961843,0xfeca000a,0x600b000a}},	//   _मारा_, kiyo, ּמָּ, הִכְ
  { {0x1b7b000a,0x6606013c,0xe695004a,0x6e2234b8}},	//   _מטבע, gakk, тимы, ngob
  { {0x44e60023,0x62960064,0x55070010,0xe4a7007a}},	//   _cô_, diyo, эчна, ерво
  { {0x6606008c,0x7792002b,0x672b0030,0xb5fb0046}},	//   aakk, _میخا, éljá, oják
  { {0xd7f80011,0xe4540033,0xa8470021,0xa2c70054}},	//   mbă_, ыкры, _سليم_, ељак
  { {0x67bb013a,0xd7bb0008,0x77bb000a,0xf7bb000a}},	//   _ממוק, _מצור, _ממוח, _מזומ
  { {0x68e20007,0x51870805,0x02440015,0x883a000a}},	// [6db0] _juod, хува, دَقَ, ּת֣ו
  { {0x68e2022d,0x28c60065,0x1fa700ce,0x545502ed}},	//   _muod, _रीमि, нрег, _рвот
  { {0x68e2022d,0x83670029,0xd7f80045,0x26c9052d}},	//   _luod, _أدخل, ibă_, _khao_
  { {0x628434b9,0xc7b3004c,0xa2f6000a,0x394634ba}},	//   chio, אבע_, _שמרה_, _osos_
  { {0x44e60092,0x7ae10fda,0x32540033,0x68e20091}},	//   _xô_, _sult, _свяр, _nuod
  { {0xd116000f,0xd7f80045,0xfb590054,0x224b34bb}},	//   _בקשה_, jbă_, дрић_, _hack_
  { {0x0ebb0002,0x14d8000a,0xa088000a,0x63a90012}},	//   _فارغ_, גוגל_, _נְשִ, ßenh
  { {0x6a7c0003,0x7ae134bc,0x224b0d3a,0x6f18005a}},	//   _défo, _vult, _jack_, ávce
  { {0x660616a1,0x7c3c0030,0x09020033,0x88c9006b}},	//   vakk, _űrre, апын, млив_
  { {0xeafb0086,0x224b003e,0xd8830086,0x6abb2061}},	//   _فرصت_, _lack_, اهدی, sluf
  { {0x07a506b4,0x394602c1,0x6606235a,0x200300bc}},	//   танн, _esos_, takk, _meji_
  { {0xd7f80045,0xa8020061,0x68e20034,0xb5fb0030}},	//   abă_, çırm, _fuod, njáh
  { {0x7d190026,0xb6a30fea,0x56930033,0x62960061}},	//   nrws, риял, раўт, viyo
  { {0x44e60023,0x6606236d,0xa7fc0061,0x200334bd}},	//   _vô_, sakk, kkıy, _neji_
  { {0x629601e2,0xe517005d,0xc2b60001,0x62840335}},	//   tiyo, _तिथि_, вљањ, thio
  { {0x44e60092,0x3a3f00da,0xf5960058,0x0000006a}},	//   _tô_, neup_, _للعج,
  { {0x629601e2,0x9f580251,0xd6cf0029,0xe0da0785}},	// [6dc0] riyo, _serà_, _بقي_, два_
  { {0x62962351,0x6284065b,0x660434be,0x03960256}},	//   siyo, shio, _heik, _армя
  { {0x40330036,0x6fb30029,0x3a3f026f,0xdfcf0015}},	//   реєс, لمكا, keup_, قيك_
  { {0x6a7c0152,0x644e34bf,0xb5fb0030,0xbfb50015}},	//   _réfo, ldbi, gjáh, احْت
  { {0xf653000a,0xa1930033,0x8fe60015,0x25f50065}},	//   יצא_, _ваўч, _لأزم, ूरती_
  { {0xdb1a00dc,0x3a260011,0x6aca000b,0x660434c0}},	//   _aztá, _scop_, ाग्र, _leik
  { {0x68e2022d,0xa03700f3,0x9b430015,0x749b004c}},	//   _suod, _שאלה_, لنوو, ויספ
  { {0x6604002e,0x7eb800dc,0xeaaf00e6,0x249800b8}},	//   _neik, típu, يعي_, hirm_
  { {0x58d803fc,0xfc1a0015,0xa9c3005e,0x63a90061}},	//   ндия_, _يقرب_, иськ, ğeni
  { {0x68e2022d,0x63a91d56,0x26c934c1,0x0000006a}},	//   _vuod, şeni, _shao_,
  { {0xdc9b0008,0x501b0008,0xd7f80011,0xf093000f}},	//   _קיבל, וויו, rbă_, שנת_
  { {0xeb970008,0x68e200f2,0x6f031224,0xa3b6000b}},	//   _בדבר_, _tuod, ânci, _जड़_
  { {0xceb3103d,0x66de0024,0x7989002a,0x24980a1c}},	//   שיר_, _rīku, czew, firm_
  { {0xf7540029,0xc977000a,0xc7960015,0x60dc34c2}},	//   _منتج, _בגדי_, _لشعب, _nirm
  { {0x35c7014e,0x26c90092,0x8c430064,0x66e3000d}},	//   रेज़, _thao_, _öğes, _која
  { {0x442d0089,0xd6270029,0xa7fc0061,0xcb37000a}},	//   ře_, _شعبي, vkıy, כאלי_
  { {0x6a7c0152,0x6a75001a,0x7c230034,0x60dc34c3}},	// [6dd0] _réfl, _gáfu, ygnr, _birm
  { {0x9f580e57,0x155a0008,0x9598000a,0xdc1c000b}},	//   _será_, _נכתב, _שכזו_, नलोड_
  { {0x224b01d1,0x764d0035,0x929534c4,0xde190015}},	//   _tack_, _kaay, _банц, فقات_
  { {0xfe700074,0x271c0092,0x12790053,0xade9002b}},	//   يدن_, ảng_, _נאָע, رفتم_
  { {0xed580191,0x721a013a,0x621a0008,0x764d0035}},	//   кої_, _אורח, _אורק, _maay
  { {0x60dc01e2,0x0c240036,0x66e80089,0x0c750086}},	//   _girm, имін, _něko, دگرد
  { {0x9f58001c,0xeb350086,0x5b350029,0x80c0000b}},	//   _terá_, ارتخ, اعتر, वतरे
  { {0x4a450001,0x4a980010,0x66e80046,0x764d02f2}},	//   унив, ктыў_, _pěkn, _naay
  { {0x660434c5,0x60dc0061,0x6e2905ed,0xf8af009a}},	//   _reik, _yirm, _iceb, يکت_
  { {0x7989005c,0x91bc0008,0x660434be,0x0dc81791}},	//   rzew, ומחי, _seik, _руси_
  { {0xd709008f,0x7989005c,0x660434c6,0x66e80046}},	//   энне_, szew, _peik, _děko
  { {0x8afa000a,0x8b88004f,0x4a740138,0x0000006a}},	//   _נהני, _בָנֶ, _вышт,
  { {0x22400007,0x660415ff,0x65c1002c,0x66de0024}},	//   veik_, _veik, _náhľ, _sīkt
  { {0x399a103d,0xd8790029,0xa99a000a,0xd91a0643}},	//   _אינד, _سمعت_, _אבנר, _נוצל
  { {0x88830086,0x387800c0,0x660434c7,0xe7680015}},	//   _میکن, örre_, _teik, _لحين_
  { {0x6d4900dd,0x2007001a,0x61461e84,0xc77605bd}},	//   _osea, ðnin_, леба, _תתקצ_
  { {0x463b00b2,0x60dc15ff,0x00ca0010,0xc693000a}},	// [6de0] _טעקע, _pirm, елак_, _לאה_
  { {0x6e29039f,0x645e34c8,0xceea04c5,0x224034c9}},	//   _aceb, _unpi, едже_, seik_
  { {0x28960053,0xc356006b,0x2f560033,0x6d4934ca}},	//   נדען_, _съпъ, ытас, _asea
  { {0x127a003b,0xdfcf0196,0x1eaa0015,0xdc1c000b}},	//   _أحدث_, سين_, راضي_, नल्ड_
  { {0x63be1bc0,0x63a90012,0xa49b0144,0x11da0015}},	//   _hypn, ßenv, rsòv, _سوسة_
  { {0x67211075,0xafe31b5d,0xf537004f,0x0000006a}},	//   kulj, _горл, רנסי_,
  { {0x290d0077,0xe457000a,0xb9e600ce,0x67210160}},	//   esea_, טיסט_, ліпи, julj
  { {0xde1a0015,0xc9140054,0xad26002b,0x39142124}},	//   _سقطت_, адић, _مرطو, амир
  { {0x98060010,0xf65f02de,0x9997006b,0x229f008c}},	//   лянд, llæg_, лкът_, läkä_
  { {0xe937002b,0x7b05001a,0x764d02f2,0xfd57000a}},	//   اسيت_, úttó, _saay, _גשמי_
  { {0x30db0053,0xf65f0134,0x1b290015,0x0a160015}},	//   ײַזע, nlæg_, _لأني_, _موضح
  { {0x8f57004c,0x7bc80085,0xcf93000a,0x45d50719}},	//   אסטא_, _izdu, מטת_, ионс
  { {0xd90e002b,0xb5fb1ad6,0x94ab1411,0x7e7b004f}},	//   _عید_, kjáv, етва_, תאכז
  { {0x98a30608,0x67d4257f,0x67210160,0x0000006a}},	//   _личе, _колу, bulj,
  { {0xa3d5005e,0xb5fb0030,0xd25b1e9d,0xddc90045}},	//   ровч, djáv, нца_, _oneş
  { {0xf65f00fb,0x31a50015,0x48fb0065,0xf66b0058}},	//   dlæg_, لمزف, लीको_, _سحبه_
  { {0x05960086,0x44a70015,0x61ed34cb,0xd01b02ed}},	// [6df0] _پايگ, _محدّ, rcal, ефе_
  { {0x212a0086,0xf00b0092,0xb5fb0030,0x629a34cc}},	//   ئيلی_, _đẳng_, gjáv, étor
  { {0x2fc701d1,0xcfab0015,0xa0c40015,0x201c016e}},	//   ång_, رائم_, حيلو, óvia_
  { {0x9e35005e,0xdbff000b,0x5d5500d2,0x5ed40015}},	//   редч, ैण्ड_, икет, متنز
  { {0x2d58005e,0x2cd5004a,0x8d650248,0xc5f4004f}},	//   лиць_, аждё, рвле, צדס_
  { {0x1ee70086,0xc19a00a3,0xeb99067a,0x0000006a}},	//   _موسی_, _ישרי, кил_,
  { {0x7c840001,0xda6506b5,0x3cf8013b,0x7eb8016d}},	//   ључе, ивки, _črve_, rípr
  { {0x6d49002d,0x6ce7005e,0x09350033,0x6f030045}},	//   _tsea, _біже, ахоў, âncu
  { {0x6d49022d,0x25f40065,0xd8750058,0x186900af}},	//   _usea, ंडसी_, لادب, вапи_
  { {0x5d84003b,0x76960007,0xc052000a,0xbf19000a}},	//   _الكل, ršym, ַ֖ת_, ֣וֹך
  { {0xf7710087,0x5ba70bb9,0x0a150087,0x9666068e}},	//   زاد_, _сраз, _نواح, акне
  { {0xc4c90008,0xcfb6000a,0x3696005e,0x99d5006b}},	//   _חג_, ילתי_, ршос, _кюлч
  { {0x9f580144,0x05b30015,0x7a7a004f,0xd91b02ed}},	//   _terç_, ْمُح, _שרנס, _чье_
  { {0xd7e70010,0xd5470001,0x65c300fd,0x898a000a}},	//   _сідо, јпре_, ібра, _שָׁ֔
  { {0xe29a34cd,0x889a0447,0x289a000a,0x64a30aa1}},	//   вав_, _בבסי, _שיצא, цара
  { {0xd13200e5,0x63be0227,0xd2a7007e,0xf6b30015}},	//   يمز_, _vypn, аксе_, _وموج
  { {0x11d70015,0x66bb004f,0xa1e90058,0xb5fb01d3}},	// [6e00] لوفة_, _במקה, ارفك_, tjáv
  { {0x2f5615ed,0x757b0053,0x2a7f007c,0xf06307ec}},	//   итес, _סטיפ, hkub_, окуп
  { {0x661602d5,0xd4370053,0x7e2a0210,0x8fa60015}},	//   _kdyk, _דריק_, віла_, جماه
  { {0xb17b00c0,0xd8380085,0x0000006a,0x0000006a}},	//   _igån, miče_,   ,
  { {0xe3b20086,0xafe60004,0xd83834ce,0x62862fd9}},	//   _درک_, _вогл, liče_, _ilko
  { {0xcf260086,0x5cb70033,0x62810091,0xb4fb000a}},	//   _پرسي, аліў_, ūlot, דפסי
  { {0xf4130008,0xbb470029,0x8fa32535,0x2d8034cf}},	//   קפה_, للون_, _даре, šie_
  { {0x531b000a,0xda660015,0x7bc80057,0x69aa0015}},	//   דוקצ, شابي, _vzdu, َاةُ_
  { {0x5c160086,0xd90d0086,0xad9d002a,0x1ea90015}},	//   _نظار, فین_, _jeźl, _صافي_
  { {0x9da50086,0x3137000a,0x0137000a,0x6a7c0003}},	//   _اصفه, סנים_, סרית_, _méfi
  { {0xda65002b,0x6286008c,0x907b004c,0x7bc80085}},	//   _گالي, _olko, דטיי, _uzdu
  { {0x3ea634d0,0x3cfd000b,0xd83834d1,0x443a02e3}},	//   nnot_, रीके_, diče_, _abp_
  { {0x59d2000b,0xda650015,0xe5040015,0xb5fb0030}},	//   देशर, _دالي, ْبِي, dját
  { {0x68ed002d,0xb97b000a,0xb5fb0030,0x628634d2}},	//   _éada, _בנדי, eját, _alko
  { {0x443a00d9,0xd2d70029,0xf7930033,0x66e80046}},	//   _dbp_, لغرب, _машэ, _měkk
  { {0x88bd005c,0xf00b0092,0x32640902,0x97c50015}},	//   puśc, _đằng_, отув, _اتهم
  { {0xa0c50029,0x3015176c,0xd904002b,0x8fe7005e}},	// [6e10] ميرو, йдар, بی_, ацед
  { {0x6a7c038d,0xd5ed0023,0x55bc0008,0xc1040015}},	//   _défi, _hoà, _במחו, توكي
  { {0x3f670c1d,0xdb230061,0xaf080058,0xed590160}},	//   штаб, ürük, لقلم_, _srž_
  { {0x63bb01e2,0x4ea4008f,0xa2830086,0x2007005c}},	//   ğund, орча, _بیرو, źni_
  { {0x067c0053,0xfe700021,0xbd6b006b,0x63bb0061}},	//   כנאל, بدل_, ърже_, şund
  { {0x30850029,0x71d6000a,0x208500c3,0xddc2003d}},	//   _السف, _לורד_, _السّ, ujoš
  { {0xa3d7014e,0x26c2005c,0x2a7f0020,0x2418000a}},	//   िधि_, ylko_, tkub_, בחון_
  { {0x769600df,0xadbd0033,0xdb0e0046,0x0000006a}},	//   ršyk, _забi, ídán,
  { {0xe9d90080,0xbb55002b,0xceb2015b,0x02950016}},	//   ыки_, _گناب, _זין_, _đếm_
  { {0xac74003b,0xa3d7005d,0x7c2d016f,0x9ccb02bf}},	//   _والش, िधा_, đars, _рыба_
  { {0xe7390001,0x38ca0086,0xf7450fea,0x387802dc}},	//   ћем_, دايی_, щено, örra_
  { {0xceb204dc,0x8b9a000a,0xd8380de8,0x99860160}},	//   ִים_, _גבעת, viče_, šiše_
  { {0x18270086,0x38ca002b,0x44a60015,0x959a0432}},	//   _نقشی_, ضایی_, محسّ, утну_
  { {0xa95600b2,0xd838016f,0x58f60008,0xb4b2000b}},	//   _לינק_, tiče_, _המסע_, टके_
  { {0xf7190010,0x06f50029,0xe739030c,0xa3b5000b}},	//   _сілы_, _استج, _сей_, _छुआ_
  { {0xd8380085,0x273134d3,0xe29734d4,0x056607ec}},	//   riče_, mán_, бас_, _гвин
  { {0x2b49005c,0x273134d5,0x05ba0015,0x216734d6}},	// [6e20] łach_, lán_, _حدثت_, бити_
  { {0x27310092,0x6f18006f,0x764634d7,0x6e3b34d8}},	//   oán_, ávco, leky, _abub
  { {0x6d5b0005,0x54770008,0xb5fb0030,0xe29a080e}},	//   _arua, _הגיע_, pját, _бан_
  { {0x6286022d,0xb5fb00dc,0x3ea60024,0xdddb06e6}},	//   _ulko, ljár, unot_, _sluš
  { {0x2731002f,0x32570008,0x6d5b34d9,0x3ea634da}},	//   hán_, _הסכם_, _crua, rnot_
  { {0xb5fb00dc,0x6d5b00e7,0x212001d7,0x3ea634db}},	//   njár, _drua, mrih_, snot_
  { {0x7f86003b,0x27310014,0x66df0007,0x5ef8000a}},	//   _الأن, ján_, _būkl, _כִּס
  { {0xdd920029,0x7bc10026,0xc333000a,0x9aa40015}},	//   _فوز_, _dylu, פוח_, تمعو
  { {0xc27b000a,0xed57320a,0xb86602be,0xda77009b}},	//   טרקי, _лот_, مادو, сящ_
  { {0x7ae800dc,0xbc19005e,0xa7140054,0x971405a7}},	//   _tudt, _віці_, одољ, омоц
  { {0xb8ef014e,0xf8030010,0xb5fb00dc,0xb21b002e}},	//   _वी_, ччын, djár, _slæm
  { {0x27150092,0x7c2a01f0,0x657d008c,0xb5fb0030}},	//   ính_, lgfr, tysh, ejár
  { {0xfd67000a,0xb5fb001a,0x397a0015,0xd94307bd}},	//   ֶ֑ךָ_, fjár, _حصاد_, _неци
  { {0xc9170008,0xe3b30015,0x201c1279,0x212006c0}},	//   _פחות_, كرز_, óvil_, drih_
  { {0xd5ed0023,0xd6db005e,0x289b004c,0x273102e0}},	//   _toà, _йти_, _גיגא, cán_
  { {0x46a40292,0x6d400111,0x22940080,0x78ba2996}},	//   _најв, _opma, пися, lotv
  { {0x22580080,0x9fe70029,0x7ae234dc,0x909934dd}},	// [6e30] щиты_, مساه, _miot, ават_
  { {0x7ae2002d,0x3015005e,0x297b004c,0x9f430030}},	//   _liot, ідер, אטמא, _ifjú_
  { {0x6d400024,0x7528005c,0xbe150029,0xa3d8000b}},	//   _apma, ądze, قواع, ़ेद_
  { {0x539a000a,0xad9d002a,0x7c2a0030,0x28cf000b}},	//   _כיתו, _weźm, egfr, _सीनि
  { {0x27150092,0x628d002d,0x645502ef,0x273134de}},	//   ánh_, mhao, odzi, zán_
  { {0x645534df,0xf00b0016,0x7ae2008c,0x44ef0cea}},	//   ndzi, _đặng_, _aiot, _mü_
  { {0x15f9005d,0x747c000a,0x6455090f,0x547c015b}},	//   ंडार_, רנוג, idzi, רטוו
  { {0x273134e0,0x539c0135,0x44ef0020,0x7bc10227}},	//   ván_, טיוו, _oü_, _vylu
  { {0x39350010,0x44380026,0x3ebf0049,0x27310077}},	//   цэйс, yfr_, _ikut_, wán_
  { {0x6455005c,0x48790b18,0x273134e1,0x40ec000a}},	//   jdzi, рсия_, tán_, נַחֲ
  { {0xd5ed0092,0x97c50029,0x6455005c,0xe7391944}},	//   _soá, تقدو, ddzi, шен_
  { {0x9f5804f3,0x7ae234e2,0x645534e3,0x273134e4}},	//   _perú_, _giot, edzi, rán_
  { {0x2731216a,0x99dd006f,0x76460091,0x18690c30}},	//   sán_, meňo, reky, _вали_
  { {0x273107d3,0xb4b6000b,0x6455002a,0x6a7c0003}},	//   pán_, ड़ते_, gdzi, _défu
  { {0x44ef0020,0x200a0251,0xe6c60015,0x63a90012}},	//   _eü_, _rebi_, _وتعي, ßenp
  { {0xd5ed0023,0x68e334e5,0x35a60010,0x200a01a3}},	//   _toá, _hind, _майг, _sebi_
  { {0xb5fb00dc,0x0ffa0015,0x68e30af3,0xdb1a0046}},	// [6e40] pjár, لعاب_, _kind, _rytí
  { {0x28cf005d,0x68e30089,0x7f5a0054,0x4fa620f0}},	//   _सीमि, _jind, ијет_, оизв
  { {0xe3b20086,0xc43b000a,0x63bb0061,0xf43b000a}},	//   _زرد_, _דתיי, ğunc, _דגימ
  { {0x9e3a0015,0x628d086c,0x68e334e6,0x44ef068c}},	//   ؤساء_, chao, _lind, _yü_
  { {0x2d580036,0x8afc005c,0xc43a000a,0x7ae21308}},	//   силь_, _kręg, ֹתֶי, _riot
  { {0x6ce30036,0x0b5a0015,0x5c970033,0x3ead02de}},	//   міще, لشعب_, окія_, _ejet_
  { {0x7ae2005c,0xa5bb002d,0xe7270015,0x62840091}},	//   _piot, rgói, _تص_, okio
  { {0x68e303af,0x6455005c,0xdcfa002b,0x62840d91}},	//   _aind, zdzi, _نفرت_, nkio
  { {0xfe430191,0xf2d30008,0xb86a0001,0x5ca600a4}},	//   _інфо, ועה_, ајне_, _диаб
  { {0x0b1a0029,0xc19b0053,0x395d0026,0x6a7c0152}},	//   _نقطة_, ישפי, _drws_, _réfu
  { {0x660f2838,0x68e334e7,0x7ae20123,0x9f5802b9}},	//   tack, _dind, _tiot, _perù_
  { {0x64550050,0x7aa60015,0x8cb4000b,0x68e334e8}},	//   wdzi, _بإطل, ेतको, _eind
  { {0xd6d80191,0x1fb7005d,0xfad70053,0x6447062c}},	//   ють_, _अड्ड, _וואך_, teji
  { {0x645534e9,0xb5fb0030,0x67330030,0x660f34ea}},	//   udzi, ajáp, ödjö, sack
  { {0x64550050,0xf76f0015,0x57fb000a,0x628d0125}},	//   rdzi, _لاي_, _דלוו, thao
  { {0x44ef0020,0xd3190054,0x66740015,0x68e334eb}},	//   _tü_, _цeнт, _يدير, _zind
  { {0x628d0026,0xf6d40029,0x518706b3,0x23e7005e}},	// [6e50] rhao, _تزود, цува, _мінв
  { {0x660d0020,0x6284008c,0x0000006a,0x0000006a}},	//   _heak, akio,   ,
  { {0x0ff80015,0x0574002b,0x67280085,0x660d088a}},	//   تعقب_, _فاید, nudj, _keak
  { {0xfe71002b,0xf773000a,0x03d6000a,0xb3ba000a}},	//   رگز_, וקע_, _מותם_, _למתכ
  { {0x63ad0048,0x248c0007,0x869c004c,0x27070030}},	//   šinā, šimų_, סידז, zőn_
  { {0x317a013a,0x6d5d002e,0xc05b005e,0xcf270015}},	//   _הרשמ, _ásam, _тім_, _ورأي
  { {0x6cc20010,0x68e334ec,0x672800bc,0x69c60061}},	//   эйша, _rind, judj, üken
  { {0x6721016f,0x68e334ed,0x0905004a,0x660d34ee}},	//   vrlj, _sind, ппин, _neak
  { {0x6aa934ef,0xd945005e,0x68e334f0,0x99dd006f}},	//   rnef, чепи, _pind, reňo
  { {0x27070030,0x6abb01f6,0x0000006a,0x0000006a}},	//   tőn_, souf,   ,
  { {0xf092000a,0x68e334f1,0x27e90061,0x6aa9001a}},	//   גני_, _vind, _şans_, pnef
  { {0x64900020,0x8f9a0008,0x68e32fa8,0xe7360342}},	//   _käig, מיתי, _wind, чею_
  { {0x0ab80029,0x9583004a,0x7d1c003d,0x68e334f2}},	//   _بطلب_, еляе, _ārsk, _tind
  { {0x6728022d,0x78fa0008,0x9c7c016f,0x443e0089}},	//   budj, _הפסו, _ličn, ýt_
  { {0x98140086,0x9359017f,0x87040115,0x67d203ae}},	//   _آبها, орту_, _قبيل, _пољу
  { {0xc7b20008,0x660d00dd,0x7d160007,0xf770002b}},	//   _רבה_, _geak, šysi, _جاه_
  { {0x66e80089,0x2167130d,0xe5a60912,0x61430fac}},	// [6e60] _děku, пити_, _хипи, нета
  { {0x90c3005f,0x76960007,0x859b000a,0x8236002b}},	//   ебуе, ašyt, _לשפו, _کردا
  { {0x547b000a,0xe47b000a,0xd47b000a,0x747b000a}},	//   _הטיו, _הריכ, _האיל, _הניג
  { {0x2129013c,0x4dda0015,0xddcf34f3,0x6ce602a3}},	//   buah_, موضح_, _šeše, піке
  { {0x78a10084,0x7d090176,0x12880086,0x72db000a}},	//   kilv, _cwes, _همگی_, _לקטג
  { {0x653b0053,0x6da30015,0x394d00aa,0x853b004f}},	//   מענד, عموم, dwes_, מגני
  { {0x0ef90010,0x5f2712ba,0x3af10016,0x394d00aa}},	//   _мэты_, _норм_, _cáp_, ewes_
  { {0x8f37000a,0x0000006a,0x0000006a,0x0000006a}},	//   _מאלו_,   ,   ,
  { {0xfe430010,0x7d090026,0x6490007c,0x78a134f4}},	//   _янто, _gwes, _käid, filv
  { {0xb0be005d,0x8afc005c,0x611e0011,0xfc64002b}},	//   ्तिग, _pręd, călţ, _تخری
  { {0x660d34f5,0x66e80089,0x99e609ef,0xec130015}},	//   _peak, _někt, _ежед, _سوند
  { {0x368b131f,0x916900a1,0x0000006a,0x0000006a}},	//   ссон_, sửa_,   ,
  { {0x3ea700dc,0x4a5b000a,0x20be000b,0xca97000a}},	//   énti_, _לדאו, ्ताध, _צדדי_
  { {0xb9db013a,0x660d003e,0xa4e40010,0x64900458}},	//   _החדש, _weak, еўск, _näid
  { {0x75280050,0x083b011f,0x883b000a,0xe3b0002b}},	//   ądza, _העול, _התוו, هرف_
  { {0xe8df0023,0xd1bb0029,0x02450015,0x212901d7}},	//   ược_, ماذا_, بَرَ, tuah_
  { {0x76960007,0x2249003e,0x82340021,0x9c7c006f}},	// [6e70] ršyt, reak_, عرفا, _ničo
  { {0x212900d9,0x4f6b0080,0xa4d5005e,0x6490007c}},	//   ruah_, йшем_, _іоні, _räig
  { {0x212900d9,0x6e190029,0x3f870264,0xa2950033}},	//   suah_, قياس_, ánu_, _жані
  { {0x3f8f0050,0x66df0007,0x3af10016,0x9cfd0033}},	//   ągu_, _būki, _ráp_, ацкi
  { {0x3f87016f,0x3af10016,0x78a10030,0x69c60061}},	//   šnu_, _sáp_, yilv, ükel
  { {0xd7e6003b,0x4338002b,0x8c42004a,0xa227002b}},	//   _لك_, _بسیج_, веше, _برگه
  { {0x6a7c0003,0x9e15005e,0x645734f6,0xaac4009a}},	//   _réfr, _одві, _maxi, کتون
  { {0xbe650015,0xe8f908a0,0x0000006a,0x0000006a}},	//   _تهري, оли_,   ,
  { {0xdd9402bf,0xdb1a01b2,0x78a134f7,0x7e6934f8}},	//   _заты, _vytá, tilv, _inep
  { {0x5d540b9b,0x9f5a0077,0x6490007c,0x76561efa}},	//   _якут, capó_, _käie, _sayy
  { {0x7e7b0089,0xdb080123,0x0000006a,0x0000006a}},	//   _koup, _sydö,   ,
  { {0x29d50029,0xe5a601e5,0xe612002b,0x3bba000a}},	//   _قياس, дими, خشد_, _ומעד
  { {0x78a101be,0xd838006f,0x6b830aa7,0x7a88004f}},	//   pilv, cičo_, lyng, _מָסַ
  { {0x98f40029,0x94d30010,0x645703a6,0xd9420988}},	//   _أثنا, коўц, _caxi, _реши
  { {0xa3d8005d,0xd3b50080,0xd7fa000a,0xe795002b}},	//   ़ें_, есть, _והצל, _تاشک
  { {0x4433059d,0x452a04c5,0x221502db,0x0000006a}},	//   _ecx_, _джин_, еффр,
  { {0x00e6008f,0x6b830026,0x100a0015,0x8afc002a}},	// [6e80] джан, hyng, قتضى_, _kręc
  { {0xeb0d005d,0x96f9000a,0xa988000a,0x44f4005b}},	//   _सबूत_, ַלְת, הָעִ, _iä_
  { {0x64900020,0xdd8f0086,0x44f407c2,0xa3dd0065}},	//   _väid, یوم_, _hä_, तेद_
  { {0xe1f20087,0x7e7b0376,0xdfcf0015,0xbd8a006e}},	//   _جسد_, _coup, جيم_, ينان_
  { {0x64900020,0x41030063,0xc213000a,0xbea30054}},	//   _täid, _изяв, _בהר_, њачк
  { {0x6b830176,0x6fd6000b,0x9597000a,0xac970015}},	//   fyng, _भरपू, וכנו_, وننا_
  { {0x64900020,0x6b830026,0xcb670001,0x44f400c0}},	//   _käib, gyng, даје_, _lä_
  { {0x5a340063,0x8f9b0008,0xf1bf002d,0x38600011}},	//   хнит, _וילי, _gcás_, _şir_
  { {0x6df30015,0x09030033,0xbea31c0b,0x44f434f9}},	//   _شكلا, кчэм, _ратк, _nä_
  { {0xc7ca0033,0x7d020738,0x9c7c0085,0xd7f7043d}},	//   жыме_, mpos, _kičm, мую_
  { {0xf76f0029,0x7d0234fa,0x8afc002a,0x3ce7000b}},	//   لاَ_, lpos, _dręc, _छूटे_
  { {0x4992002b,0xa5bb002a,0x98ae0061,0x79a6257f}},	//   _لیبر, dgór, ınıp_, _орле
  { {0xb4e9021e,0x99340015,0x7d0234fb,0x0000006a}},	//   यदे_, _أفتت, npos,
  { {0xd7ef023e,0x0000006a,0x0000006a,0x0000006a}},	//   _ју_,   ,   ,
  { {0x4c9b000a,0xd7730015,0x4395005e,0x88bb004f}},	//   קבלו, _لايع, хавс, _ומגז
  { {0xd7f80011,0xeb91000a,0xc1050015,0xc6780015}},	//   lcă_, נָם_, فوري, _يحيط_
  { {0x7e7b34fc,0x44f40123,0x273834fd,0x645734fe}},	// [6e90] _roup, _gä_, lén_, _taxi
  { {0xd7f80011,0x291900dc,0x7e7b34ff,0xd0110031}},	//   ncă_, ásai_, _soup, الا_
  { {0x2fc70134,0xd7f80045,0x27380030,0x7e7b3500}},	//   æng_, ică_, nén_, _poup
  { {0x92950099,0xdde20081,0x0000006a,0x0000006a}},	//   _чамц, _šušt,   ,
  { {0x84980074,0x6e1600a2,0x1d090775,0x6b830034}},	//   _رئیس_, ريوس_, чели_, wyng
  { {0x64900005,0xc4d5004c,0x27380030,0x673a0795}},	//   _täie, עגַ_, kén_, kttj
  { {0x27380014,0xb0be005d,0xce950063,0x4fc402bf}},	//   jén_, ्तरग, _завъ, _аста
  { {0x7d022657,0x9b680033,0x6b833501,0x27383502}},	//   bpos, ьшча_, ryng, dén_
  { {0xf9910015,0x22593503,0x8afc002a,0x4431002a}},	//   طبة_, _mask_, _pręc, kgz_
  { {0x7d1b008c,0x13fb000b,0x44f40b1f,0x0000006a}},	//   _ivus, ्रोह_, _rä_,
  { {0x3946020a,0x20110089,0x273800dc,0xac380015}},	//   _epos_, _mezi_, gén_, _تسقط_
  { {0xd7f804f9,0xc4c90008,0x63bb0064,0x28cf005d}},	//   acă_, _הג_, ğunl, _सीरि
  { {0xd9140010,0x394600dd,0xe9ab0086,0x3eaf0c1b}},	//   _адчы, _gpos_, _بدان_, ingt_
  { {0xf9880015,0x628f3504,0x27383057,0x5d9a004f}},	//   _تنهي_, _alco, bén_, לברה
  { {0x7d021223,0xb6a6006b,0xf8b6000a,0x225928b7}},	//   zpos, _пикл, _אפסי_, _bask_
  { {0x44f400f2,0x7d02005c,0x8e200010,0x98a4003d}},	//   _tä_, ypos, зiн_, mumā_
  { {0x9556003b,0x98a40024,0x0839000a,0xe29715be}},	// [6ea0] _أخبا, lumā_, ּעֲל, хат_
  { {0x50650015,0x888c004c,0xb21b063b,0xd12f0021}},	//   َالِ, ֿראַ, _blæs, صمم_
  { {0xd4370008,0x03a60511,0xeef50033,0x7d1b3505}},	//   _אריק_, _чино, вячэ, _avus
  { {0x2007002e,0x2bb6000b,0x644e3506,0x7d023507}},	//   ðnir_, _अखबा, lebi, tpos
  { {0x127b0053,0x271c0016,0x273816ce,0x2d800045}},	//   _זאכע, ảnh_, zén_, âie_
  { {0x644e3508,0x98a40024,0x7d023509,0x28cf000b}},	//   nebi, kumā_, rpos, _सीलि
  { {0x98a40048,0x644e1164,0x4444350a,0x7d021b65}},	//   jumā_, iebi, _mb_, spos
  { {0x65640035,0x273800dc,0xdb22005c,0x9b4300e6}},	//   _orih, vén_, _śród, انيو
  { {0x4444350b,0xdcfa0029,0x644e350c,0x66d60030}},	//   _ob_, _رفضت_, kebi, kákb
  { {0x31370008,0x644e016f,0x2738350d,0xc19b000a}},	//   ענים_, jebi, tén_, פשיי
  { {0xf98f0086,0xd7f80011,0x7bc80064,0xf093000a}},	//   لبی_, rcă_, _uydu, רנת_
  { {0xd7f804f9,0x9bb70008,0x8f8b0008,0x4444350e}},	//   scă_, _אהבה_, לְכֵ, _ab_
  { {0xceb300a3,0x27381043,0x673a0b56,0xad2a000a}},	//   ריר_, sén_, sttj, הוָ֨
  { {0x273800dc,0xdb1a008c,0x644e0653,0x98a4003d}},	//   pén_, _tytä, gebi, bumā_
  { {0x3267008f,0xd32403e7,0xb865002b,0x4444350f}},	//   нтав, льти, _جانو, _db_
  { {0x65640a3a,0xd2583510,0x44443511,0x645c1e45}},	//   _frih, нцу_, _eb_, adri
  { {0x2b52005c,0x644e3512,0xb6bc000a,0xe4e7005e}},	// [6eb0] łych_, bebi, _מצהי, _піон
  { {0x644e001c,0xd91b000f,0x765d086c,0x22403513}},	//   cebi, פובל, ldsy, afik_
  { {0x752f005c,0x22590556,0xceeb0018,0x20113514}},	//   lucz, _task_, سران_, _vezi_
  { {0x9f5809a3,0x531a0053,0x765d0134,0x395f0007}},	//   _però_, _קורצ, ndsy, yvus_
  { {0x760c00b2,0x44441788,0x98a4003d,0x4421006f}},	//   פּאַ, _yb_, zumā_, _kdh_
  { {0x7d1c003d,0x6da40015,0x9db80015,0x44441d8e}},	//   _ārst, دمهم, ردنز_, _xb_
  { {0xb21b02de,0xdfd40033,0x9f410077,0x7c94002b}},	//   _ulæs, _боры, rchó_, دشنا
  { {0x6d5d0007,0x644e0d41,0x98a4003d,0x7d250015}},	//   _šsau, zebi, vumā_, _لفرن
  { {0x644e01e2,0xb6040089,0x764f002a,0xbec3003d}},	//   yebi, ndář, decy, ļūda
  { {0x98a40024,0xd9440015,0x8c190021,0x21291d41}},	//   tumā_, ائيي, _آيار_, irah_
  { {0x6c7a0053,0x32090035,0x753d0030,0x29040061}},	//   _קרעד, kbay_, etsz, apma_
  { {0x98a40024,0x645c0e18,0x656405fb,0x7996002a}},	//   rumā_, wdri, _prih, _żywe
  { {0xd4970092,0x4a9a000a,0x644e3515,0x21290375}},	//   ằng_, _קינג, tebi, jrah_
  { {0x2ca70011,0x98a40024,0xe800000b,0x61fd3516}},	//   nind_, pumā_, लुदा_, _afsl
  { {0xd6aa0029,0x644e17e3,0x2ca70045,0x752f002a}},	//   _يدعم_, rebi, iind_, aucz
  { {0x7afc0014,0xb21b002e,0xb5fb0089,0x2ca711e5}},	//   _érte, _slær, gdád, hind_
  { {0x3ea600f2,0x6f1c0046,0x44443517,0x2ca73518}},	// [6ec0] viot_, _svrc, _tb_, kind_
  { {0xe3d60015,0x9f58001a,0x04ca0015,0x44443519}},	//   _لتجع, _berð_, _زوجي_, _ub_
  { {0x22a80064,0xee3a2152,0xc2c60015,0x3ea6008c}},	//   aşka_, дне_, _ليدي, tiot_
  { {0x26c3010b,0x787e0089,0xcf250015,0xdddb0046}},	//   čkog_, _závě, ارلي, _dluž
  { {0xf5ad0008,0x2ca70ffd,0x6458001a,0x3ea6351a}},	//   ּבוּ, find_, _óvis, riot_
  { {0x3ea600f2,0x9f58002e,0x0316000b,0x2ca7351b}},	//   siot_, _ferð_, _तबाह_, gind_
  { {0x9f58002e,0x3ea6008c,0xdddb003d,0x8fa60fdc}},	//   _gerð_, piot_, _gluž, _раве
  { {0x69cb351c,0x5a460010,0xaa63005e,0xcb670054}},	//   _byge, тэка, атьк, ђање_
  { {0xda77006b,0x7aeb351d,0x9c7c036d,0xd838351e}},	//   тящ_, _digt, _liči, liči_
  { {0x2ca7002d,0x2bbb000b,0x4778005e,0x1874009b}},	//   cind_, _ऊँचा, ебою_, угоя
  { {0x320900b6,0xd83806f2,0x9b8a0015,0xc212000b}},	//   ybay_, niči_, _تنال_, ़राब_
  { {0x752f005c,0x91690016,0x4421351f,0x753d06cd}},	//   tucz, hứa_, _sdh_, ttsz
  { {0x3857002b,0x6d5d0030,0x764f06ed,0xa2d3000b}},	//   رشید_, _ásat, recy, _भीष्
  { {0x3af83520,0x98a3000d,0x752f002a,0x9c7c0091}},	//   _kép_, _киче, rucz, _biči
  { {0xa3dd005d,0xd4980142,0x753d2c23,0xc8c7002b}},	//   तें_, тря_, stsz, _جوون_
  { {0x92b40015,0x3af80016,0x21293521,0x2ca73522}},	//   لحقا, _mép_, trah_, zind_
  { {0x3af80408,0xdddb3523,0xc4c70015,0x212907c8}},	// [6ed0] _lép_, _služ, _لتدو, urah_
  { {0x99dd3524,0x66df2233,0x91e40054,0x64550054}},	//   meňt, _tūks, рође, _свођ
  { {0x2ca73525,0x64900020,0xdb1e0152,0x6d493526}},	//   vind_, _käin, _évèn, _spea
  { {0x64580084,0x9f58002e,0x212900e8,0xa3dd000b}},	//   _óvir, _verð_, prah_, तेः_
  { {0x9e340036,0x7aeb3527,0x869c004c,0x2ca70045}},	//   речч, _rigt, ויאז, tind_
  { {0x64900020,0x6acb000b,0xe314002b,0x7aeb272c}},	//   _läin, ात्र, _حبیب, _sigt
  { {0x447c00b2,0xdd030064,0x2ca73528,0x69cb02de}},	//   ונגע, ırım, rind_, _syge
  { {0x2ca704f9,0x66d600dc,0x64900fb2,0x6933002b}},	//   sind_, káka, _näin, لکتر
  { {0x7aeb00fb,0x52dc0053,0x2d9900cb,0x6448007c}},	//   _vigt, וקהײ, _åse_, õdik
  { {0xd709005f,0x69cb0227,0x7996002a,0x48050033}},	//   нное_, _vyge, _żywc, ыпов
  { {0x69cb005c,0x16aa3529,0x3af80030,0x6754002b}},	//   _wyge, евни_, _gép_, لیوس_
  { {0xb803000b,0x8f88000a,0xa5f70054,0x19b902ed}},	//   _श्रम_, דְשֵ, леџу_, _пуль_
  { {0x5e560053,0x19940010,0x2808006f,0xa3e6000b}},	//   נישע_, _каця, ätná_, बेन_
  { {0xc9520008,0x6aa91735,0x74160015,0x2eed352a}},	//   _למד_, lief, طورا, _lief_
  { {0xa6f9000a,0xa284009a,0x78ad005a,0x0000006a}},	//   _אִ֥י, لیدو, čivě,
  { {0xb2950001,0x66d600dc,0xc7b2000a,0x6aa9199a}},	//   ајућ, báka, _לבו_, nief
  { {0x412706ac,0x7d040024,0x798928fa,0xf1aa0015}},	// [6ee0] лото_, ģisk, nyew, راره_
  { {0x0717005d,0x759b0447,0x459b000f,0x66160061}},	//   _दबाव_, _נסיג, _נסיע, _heyk
  { {0xe45700b2,0xdfcf0015,0xaf36002b,0x3f8e0fff}},	//   _גייט_, كيك_, طرات, áfu_
  { {0xdb1e0152,0x98a40007,0x645e1dc1,0x6aa9352b}},	//   _évén, mumą_, _hapi, jief
  { {0x63b60048,0x98a40007,0x1ea90015,0x2d5800f4}},	//   šanā, lumą_, خالي_, тиль_
  { {0x6adc014e,0x30760036,0x10a61215,0xd83810cd}},	//   मग्र, _сумс, _сигн, piči_
  { {0x69dd0084,0xb5fb01c9,0x7b460015,0xe457004c}},	//   ýsen, ndác, ائتل, ריצט_
  { {0x6f030251,0x201a0035,0x6f4b000a,0xdd16002b}},	//   ínce, lapi_, _אֲמַ, _مورخ
  { {0xd7f00015,0x99dd0046,0xcc360040,0xa1120138}},	//   يكة_, deňs, _مراع, ацiл
  { {0x31570008,0x8d930029,0xc157000a,0x201a0030}},	//   ניין_, _الكش, נשיו_, napi_
  { {0xb8660086,0x29020024,0x6490008c,0x66160061}},	//   ناگو, ūka_, _päin, _beyk
  { {0x60280024,0x66d60030,0x443a270e,0x0000006a}},	//   līmē, táka, _acp_,
  { {0xe1ff005c,0x201a013c,0xda650021,0x799b002a}},	//   _znów_, kapi_, _خالي, czuw
  { {0x94050086,0x44f40004,0x645e06d7,0xdd000046}},	//   شوره, спрс, _capi, _štěd
  { {0x98a40007,0x201a08c0,0x43940684,0x56950033}},	//   gumą_, dapi_, барс, _вайт
  { {0x68ed002d,0x9258013d,0x66dd0030,0x7bdb004f}},	//   _éadr, ласт_, dékg, תקלו
  { {0x2eed00b8,0x1da4000b,0x645e0034,0x66dd0030}},	// [6ef0] _rief_, _खेलत, _fapi, tékf
  { {0x201a00e8,0x98a40007,0x645e352c,0x628d0072}},	//   gapi_, bumą_, _gapi, skao
  { {0x23fa0008,0x14b80029,0xfe710086,0x20d400f2}},	//   _בהתא, _حديث_, يگر_, päin_
  { {0x645e304c,0xdbff000b,0xd8380085,0xdd9100c3}},	//   _zapi, ॉर्ड_, miču_, يوا_
  { {0xddc5209b,0x621a000a,0x645e0061,0xa3a9000b}},	//   јбли, _בורק, _yapi, _खेत_
  { {0x64900604,0x99dd0046,0xaf090015,0x201a01c2}},	//   _näil, zeňs, _لقسم_, capi_
  { {0x3f870020,0x7528005c,0x2eed00b8,0x3e070033}},	//   änud_, ądzi, _tief_, _бязв
  { {0xfbd00015,0xca85006b,0xa8020061,0x3dd2002a}},	//   أته_, ргий, çınm, żywa_
  { {0xe9d90063,0x66160462,0x8e840015,0x5c75018d}},	//   ъки_, _reyk, _القه, _клат
  { {0xa3b5005d,0x7b08007c,0x57450238,0xd008000a}},	//   जपा_, õrtö, аноб, ְּתֹ
  { {0xe7390124,0x799b0012,0x645e352d,0x2287007c}},	//   њем_, szuw, _rapi, _jõks_
  { {0x6b7a00b2,0x48750086,0x98a40007,0x8f36000a}},	//   _ברענ, ادکس, vumą_, סארו_
  { {0xc4c60015,0x4ac4002b,0x60200046,0x69c60061}},	//   لتسو, _اينق, námí, üket
  { {0x98a40007,0x2aba0024,0x37e5005e,0x399a004c}},	//   tumą_, mība_, _колг, _בינד
  { {0xa3a9005d,0x2aba0024,0x43750036,0xf773002b}},	//   _खेद_, lība_, бутт, _داش_
  { {0x60280048,0x98a40007,0x645e12d1,0x6b600030}},	//   zīmē, rumą_, _wapi, lágá
  { {0x2aba0024,0x201a0375,0xe611000a,0x645e16c8}},	// [6f00] nība_, tapi_, _מִי_, _tapi
  { {0xa4940086,0x64900020,0x602602c5,0x7f46004a}},	//   _ایست, _käim, рджа, иезж
  { {0x547b0008,0x41d5005d,0x201a013c,0xb4c4000b}},	//   _סטטו, _दरअस, rapi_, ौती_
  { {0xdfcf003b,0x201a0035,0x291f00f2,0x42fb000a}},	//   ذين_, sapi_, ksua_, _שהכס
  { {0xa2c3000b,0x2aba003d,0x8d56070c,0x6d5b01d3}},	//   लवर्, jība_, ртеч, _csua
  { {0x66dd00dc,0x2aba0024,0xd0071179,0x25d7000a}},	//   méke, dība_, _вере_, בונן_
  { {0x8cc5005d,0x66dd00dc,0xbca30015,0x5aaa0015}},	//   ाक़ो, léke, تموي, َابَ_
  { {0xe8df0023,0x64900458,0x2018352e,0xaf5b000a}},	//   ước_, _säil, _heri_, _בכלכ
  { {0x2018051c,0x66d60b31,0x7c3a21f8,0xed57352f}},	//   _keri_, tákn, _tctr, _кот_
  { {0x61e00089,0x7e600faa,0xe9cf0015,0x6d420045}},	//   _úmlu, _hamp, بغى_, mtoa
  { {0xb8fd014e,0x501b0008,0xcf930053,0xcff70008}},	//   _थी_, כויו, ַטש_, יציה_
  { {0x20180064,0x44380026,0x7bda0024,0x2aba0024}},	//   _leri_, egr_, _iztu, bība_
  { {0x2aba0024,0xaae50087,0x7e600375,0xda7b000a}},	//   cība_, _اسلو, _mamp, _שנדר
  { {0x442d018b,0x66dd00dc,0xd8380085,0x7e600faa}},	//   ße_, déke, tiču_, _lamp
  { {0x442d0064,0x602000dc,0x92a70001,0x24180080}},	//   ğe_, zámí, ајал, росы_
  { {0x442d19a0,0xb77b000a,0x7e600338,0xf62b005e}},	//   şe_, _יאוש, _namp, _ріки_
  { {0x661d3530,0xa1150015,0xc42b004a,0x51f8054f}},	// [6f10] mask, صوات, _июне_, рную_
  { {0xdb1a0152,0x212a0086,0x20183531,0x661d3532}},	//   _exté, ايلی_, _ceri_, lask
  { {0x46bb014e,0xa8570008,0xf4560008,0x2aba0024}},	//   _उदाह, שיבה_, _היתר_, zība_
  { {0x64553533,0x44fd0092,0x0356000a,0x7e600b8b}},	//   lezi, _kì_, _פירש_, _camp
  { {0x63bb01e2,0x4e180086,0x66d601b2,0x7e603534}},	//   ğunu, شتند_, záko, _damp
  { {0x20180562,0xaf370086,0x00f60008,0x63bb0064}},	//   _geri_, _پرست, _למשך_, şunu
  { {0x2f18008f,0x69d9005c,0x6f950029,0x7f850015}},	//   _вось_, _szwe, _الأض, _الزن
  { {0x13b80008,0x291f00f2,0x2aba0024,0x7e6019b9}},	//   יהול_, tsua_, tība_, _gamp
  { {0xe9a90074,0x1c0b005d,0xcaa40029,0xdd940010}},	//   دگان_, _स्थल_, تصوي, _даты
  { {0x2aba0024,0x20013535,0x7e603536,0x66d6006f}},	//   rība_, nchi_, _zamp, táko
  { {0x66dd0f87,0x2aba0024,0xf7710031,0xc5e9000a}},	//   zéke, sība_, ساد_, _נד_
  { {0xaf760053,0xa9270007,0x6b6000dc,0x44380034}},	//   צערס_, _pažį, ságá, wgr_
  { {0xddcb005c,0x99f6000a,0x645502b9,0x75290085}},	//   legł, _הזנה_, fezi, šezn
  { {0x2b930092,0xb4c4000b,0x88c40015,0x4d7a004c}},	//   ọc_, ौते_, _وتول, ארשע
  { {0xf6520029,0x66e6203f,0xe2960004,0xe29a12ab}},	//   _فئة_, _лока, браќ, гав_
  { {0x66dd0014,0x272301e2,0x20180213,0x6490007c}},	//   téke, mın_, _seri_, _käik
  { {0x44fd0023,0x27230064,0x0637000a,0x32192ebe}},	// [6f20] _gì_, lın_, _הנפט_, _desy_
  { {0x7e62005c,0x64550ba1,0xb4db0251,0xf65f0134}},	//   wdop, cezi, ltàn, slæt_
  { {0x27230482,0x20180567,0xf4570008,0x8cc6000b}},	//   nın_, _veri_, _פיטר_, िवसो
  { {0xc333013a,0xb4db0251,0x4ea5005e,0x6d420739}},	//   _צור_, ntàn, оріа, ttoa
  { {0x763b00b2,0x7bda005c,0x463b0053,0x6604003f}},	//   רענג, _sztu, רענע, _mfik
  { {0x6ab2014e,0x272301e2,0x40960029,0xad650086}},	//   ुक्र, kın_, _السر, غانه
  { {0xbb470029,0x2906003f,0xa3e0005d,0x6d423537}},	//   ملون_, _stoa_, _तरफ_, stoa
  { {0x27230064,0x20d4007c,0xda660015,0xd83800bc}},	//   dın_, käik_, صابي, ihče_
  { {0xdee3005f,0x497400fd,0x2b930016,0x62863538}},	//   _хоти, ілос, ạc_, _moko
  { {0xc1730008,0x415b0053,0xf98f0015,0x909b004c}},	//   פחת_, נדיג, عبي_, ָסטק
  { {0x44fd04ed,0xc07b0053,0x7bda0024,0xf1bf002d}},	//   _sì_, אטיש, _uztu, _ndán_
  { {0x628607df,0xcf9300f3,0x64550079,0xb5fb0046}},	//   _noko, פטר_, wezi, adán
  { {0xa3e6005d,0x66dd00dc,0x64553539,0x661d353a}},	//   बेस_, tékb, tezi, rask
  { {0x44fd0023,0x27230064,0x6604016f,0x661d2609}},	//   _vì_, bın_, _efik, sask
  { {0xd7f80011,0xf8bf0152,0xd2d70029,0x27230064}},	//   ndăm_, éée_, مغرب, cın_
  { {0x7afa353b,0x44fd0016,0xb4db0144,0x6286220c}},	//   _mutt, _tì_, ctàn, _coko
  { {0x764d0035,0xe1f00029,0x7afa353c,0x6455353d}},	// [6f30] _ibay, فسك_, _lutt, pezi
  { {0x649000f2,0x7afa353e,0x63550bb1,0xccf9002a}},	//   _näih, _outt, _двоу, _ruś_
  { {0x200104ed,0x628600dc,0x57fb000a,0x9df900a5}},	//   rchi_, _foko, אלבו, анет_
  { {0x2001094c,0x7c28043a,0x656d2b06,0xbdf80015}},	//   schi_, _addr, _krah, مرها_
  { {0x272301e2,0x7afa022d,0x823a0053,0x764d003f}},	//   zın_, _autt, _דערצ, _mbay
  { {0x27230482,0x251c0053,0x7afa11a9,0xe3b0002b}},	//   yın_, נווא, _butt, _آری_
  { {0x2b930092,0x543c0053,0x7afa003e,0x9f340036}},	//   ục_, טעגא, _cutt, _нері
  { {0x64900020,0xdb200046,0xf78a0061,0x28ab000b}},	//   _päik, ítán, _maçı_, टोनि
  { {0xc9850029,0xfaa60086,0xe8f60139,0x98e50015}},	//   تشغي, تجوی, олы_, يكبو
  { {0x7d040048,0x64900005,0x272301e2,0x28a4005d}},	//   ģist, _väik, tın_, गोलि
  { {0xa3a9005d,0x752404ed,0x656d0375,0x7afa353f}},	//   _खेल_, _sviz, _arah, _gutt
  { {0x27230482,0xceb2000a,0x66d60030,0x9208003d}},	//   rın_, ֵים_, mákk, orāž
  { {0xdce004f9,0x272301e2,0xb4db0251,0x62863540}},	//   _urmă, sın_, rtàn, _roko
  { {0x27230064,0xb4db0251,0x62863541,0x58f6000a}},	//   pın_, stàn, _soko, _ומסע_
  { {0x57240029,0x6e29037f,0x35de000b,0xaca30016}},	//   _فريق, _odeb, नेज़, _huỳn
  { {0x07d8003b,0x28dd005d,0x6e2d00dc,0x6604003f}},	//   _اذهب_, _नीति, óabl, _ufik
  { {0x70860286,0x3eaf3542,0x64c60015,0xa12a0015}},	// [6f40] огаз, digt_, _ويبل, شكال_
  { {0xd026005e,0x66d60030,0x3eaf3543,0x6286002a}},	//   імей, kákk, eigt_, _woko
  { {0x62863544,0x8fa30033,0x7d093545,0xdddb005a}},	//   _toko, мафе, _ates, _rouš
  { {0x82360074,0xfee90029,0xc7b2000a,0x3eaf1a93}},	//   _بردا, معنى_, ובב_, gigt_
  { {0xadb70029,0xdd900067,0x6490008c,0xdddb0247}},	//   يهما_, عوت_, _päih, _pouš
  { {0x6e2901e2,0xcf2f0064,0x7afa1d40,0xcf26002b}},	//   _edeb, üşüm_, _putt, _ورزي
  { {0xddc900bd,0x0b180015,0x46ca000b,0xf48d004f}},	//   _vneš, حقبة_, रवाह, ראוּ
  { {0x80ba005d,0xee370127,0xd7f80045,0x98a40b48}},	//   ्ववे, _мнс_, rdăm_, irmą_
  { {0xad66002b,0x26cb02b9,0x1d073546,0x66d60030}},	//   _بازه, voco_, _мети_, mákh
  { {0x7afa02d7,0x7c280134,0xb7b50092,0xa177004c}},	//   _tutt, _uddr, rạn, קעיד_
  { {0x7afa022d,0xe7580036,0xa6ab0015,0x78bd0030}},	//   _uutt, щині_, لاحق_, ésva
  { {0xc6a70036,0x56940142,0xc7b8016f,0x656d3547}},	//   ірни, дают, gađa_, _prah
  { {0x19b60029,0xfaf80024,0x26cb3548,0x95380a32}},	//   _بحاج, _trīs_, roco_, озят_
  { {0x14cb0080,0x3eaf0079,0x656d013f,0xf989009a}},	//   рыми_, zigt_, _vrah, _دخمه_
  { {0x69d606f5,0xc6d70029,0xa3e6000b,0xa3e0000b}},	//   _øyeb, _وتعت, बेल_, _तरण_
  { {0x764d0752,0x61f90033,0x656d3549,0x079b000a}},	//   _ubay, снаў_, _trah, _כסול
  { {0xd1300015,0x7ae20125,0x80270015,0x9099006b}},	// [6f50] َمِ_, _mhot, قرام, бват_
  { {0x44b40080,0x6f6b0054,0x7ae2354a,0xb5fb1712}},	//   _обыс, ијев_, _lhot, zdál
  { {0xa7fc0064,0x7d09354b,0x3eaf354c,0x3cde0065}},	//   ydın, _stes, tigt_, गतने_
  { {0x9f4a00dc,0x7f45003e,0x9f98002e,0xd35a000a}},	//   áján_, rthq, ráða_, _פדרל
  { {0x41e706b4,0x427a0008,0x527a0008,0x3eaf11bc}},	//   _фіна, _הארג, _הנרא, rigt_
  { {0x4c84008f,0x3eaf1639,0xf53800f3,0x60fa000a}},	//   млів, sigt_, קטור_, _להשק
  { {0x7ae20125,0x2b57002b,0xda710015,0xb18602dc}},	//   _bhot, تیاد_, ُّع_, _tvåå
  { {0xb3bc0008,0x03bc000a,0x7ae2354d,0x6e2902de}},	//   ימוכ, יצול, _chot, _udeb
  { {0xf2d400b2,0x314b0008,0xa7fc0064,0x7d090971}},	//   ועק_, ׁתֵּ, rdın, _utes
  { {0x4879005f,0x7c970015,0x7ae2003d,0xa49b0144}},	//   ссия_, _بشرا, _ehot, ipòs
  { {0x64900020,0x7ae2002d,0x8048000a,0x290d007c}},	//   _käiv, _fhot, חֲרֶ, spea_
  { {0x98ad00bd,0x869a0784,0xa7fc0061,0x68e80034}},	//   mreč_, стот_, ldıl, amdd
  { {0xc7b80085,0xe946002b,0x7ae9354e,0xfa34009a}},	//   rađa_, _فروی, mmet, _زرند
  { {0xa7fc0061,0xb5fb0030,0x7ae201c0,0x7ae92629}},	//   ndıl, ndáj, _zhot, lmet
  { {0xa3e6014e,0xccf2013a,0xe296000d,0xe4d70029}},	//   बें_, תכם_, праќ, سوفت_
  { {0xe61f002c,0x80d4000b,0xe29a006b,0x66e3354f}},	//   skôr_, _बीजे, щаб_, _поща
  { {0x8ffa0029,0x9ffa0015,0x27e2002a,0x7ae93550}},	// [6f60] مرار_, مراء_, ękne_, imet
  { {0x3ead0020,0xd12f0070,0x3ebf3551,0x8afc002a}},	//   _amet_, امل_, _ajut_, _kręt
  { {0xd4c50070,0x7ae93552,0xe3b20087,0x33fb000a}},	//   _تغيي, kmet, _سرد_, _להינ
  { {0xdfcf00e5,0x4379000a,0x7ae932e8,0xde0318dc}},	//   ديم_, _וְשׁ, jmet, епци
  { {0x7ae91be7,0x8e470015,0xddb80138,0x0000006a}},	//   dmet, سلوك_, ўглі_,
  { {0x2bb8000b,0x7ae23553,0xdca3171b,0x3ead3554}},	//   इपला, _shot, начи, _emet_
  { {0x7ae23555,0xe81f000b,0x3cd90033,0xa09b0643}},	//   _phot, _मज़ा_, цьцю_, _פילט
  { {0xbae30033,0x7ae93556,0x7dc60015,0x62960c17}},	//   нцый, gmet, _فتذك, nkyo
  { {0x6284003f,0x3ea70409,0xfcd60015,0xada3006b}},	//   ijio, ënte_, _فيرج, _затл
  { {0x26c31007,0x7ae90020,0x2db700a3,0xc7c6006b}},	//   čkom_, amet, _זלמן_, зсми
  { {0x7ae9001c,0x7a360064,0x163510cb,0x7ae23557}},	//   bmet, gütü, меня, _thot
  { {0xba17003b,0xfaa30010,0xeb970008,0x6b7b000a}},	//   _فيما_, _пахо, _מדבר_, _לרבנ
  { {0xb5fb0030,0x55070174,0xe4d70015,0xdddb002a}},	//   ldák, ячна, كتسب, _zauł
  { {0xe72f0086,0x3ae1002c,0xe2f9005e,0x6e220125}},	//   خصی_, rópe_, жеві_, haob
  { {0x67d305fc,0x17f70015,0xf76f0015,0x9cd7000a}},	//   _пошу, _عروة_, _ماي_, פולה_
  { {0xd7bb0008,0x32640036,0xb5fb00dc,0x67bb000a}},	//   _לצור, нтув, zdáj, _למוק
  { {0xdce900bd,0x64480251,0x66dd00dc,0x85040015}},	// [6f70] _sreč, òdic, léko, _كوين
  { {0x7ae901e2,0x351c000a,0xdce93558,0x859c000a}},	//   zmet, _הוזנ, _preč, _לשחו
  { {0x64900945,0x7afc0030,0x44233559,0xf412000a}},	//   _päiv, _érth, maj_, _שפט_
  { {0xcf980054,0x02a71853,0xdce900bc,0x4423355a}},	//   чју_, _хром, _vreč, laj_
  { {0xdd940010,0x249e0007,0x9d450a10,0x0000006a}},	//   нацы, šymų_, фелд,
  { {0xdce90007,0x2c6d00dc,0x66dd01b2,0x24f7000a}},	//   _treč, ködő_, kéko, הֶ֔ם_
  { {0x26c3016f,0x66dd00dc,0x7ae9355b,0x9cc80033}},	//   čkoj_, jéko, tmet, чыца_
  { {0x66dd00dc,0x7ae90863,0x0378000a,0x439c000a}},	//   déko, umet, לתות_, מבוג
  { {0x64900005,0x44232f11,0x6efa0089,0x98350010}},	//   _käit, kaj_, _vůbe, мэні
  { {0x8cbb002b,0x290b003d,0x8afc002a,0x442310a4}},	//   _ادرس_, īca_, _pręt, jaj_
  { {0x229c0084,0xb904005d,0x3f470020,0xe7f6000b}},	//   _líka_, _भी_, nõu_, ूँगा_
  { {0x7a360064,0x98a4002a,0xb8820030,0x7c23355c}},	//   rütü, irmę_, áírv, lanr
  { {0x9583005f,0xa3e0005d,0x20bf005d,0x56930033}},	//   вляе, _तरह_, ्वाध, таўт
  { {0x64900458,0x673a0251,0x78fa009d,0x629d2932}},	//   _näit, butj, _ולספ, _also
  { {0x3f47007c,0x82f60033,0x6e22355d,0x36e9009a}},	//   jõu_, дчац, yaob, تریپ_
  { {0x7c2300d9,0x7996005c,0x0000006a,0x0000006a}},	//   hanr, _żywi,   ,
  { {0x0665002b,0xb5fb0030,0x44231129,0x7c23005b}},	// [6f80] _سايپ, zdák, baj_, kanr
  { {0x917a0023,0x51b90010,0x4423136b,0x99800091}},	//   _cấp_, чыся_, caj_, _žiū_
  { {0xb4da005d,0xd47b0008,0xdfcf0029,0x645c355e}},	//   ़ती_, _ואיל, ليك_, meri
  { {0xc04900b2,0x645c27af,0x6463003d,0x9fe50015}},	//   יז_, leri, ītiņ, رسله
  { {0xfee90029,0xfe790089,0x6463003d,0x7c230034}},	//   أعلى_, _dnů_, ūtiņ, fanr
  { {0x64900020,0x7d1b002a,0x9325002b,0x66dd0030}},	//   _täiu, _dwus, _ترین, yéko
  { {0xcb070015,0x3c4b002b,0xdfd20067,0x6abe0030}},	//   ويون_, تثنی_, _شير_, épfo
  { {0xa7fc01e2,0x64900020,0xafe30142,0x63a300dc}},	//   rdım, _käis, _росл, _ünne
  { {0xa80201e2,0xdd8f0086,0x4444355f,0x52d7004c}},	//   _çıka, _پول_, _oc_, ווקע_
  { {0xb17b00b2,0x66dd00dc,0xf74a0036,0x317b004c}},	//   קטיר, téko, оїми_, קרימ
  { {0x10370008,0xa7fc0064,0x2c14021e,0x6e20013c}},	//   וטים_, ldık, _न्यू_, _kemb
  { {0x44443560,0x4423005c,0x6e2000e8,0x86740036}},	//   _ac_, waj_, _jemb, влює
  { {0x649000f2,0xa7fc0064,0x44233561,0x44443562}},	//   _näis, ndık, taj_, _bc_
  { {0xb9db000a,0xb5fb0030,0x6e2023c3,0xe4e4008b}},	//   _וחדש, zdáh, _lemb, вісн
  { {0x44233563,0x083b000a,0x828b0033,0x66dd0030}},	//   raj_, _ועול, осаб_, lékm
  { {0x44230b0e,0x05aa000b,0x44443564,0xd2583565}},	//   saj_, _चेकब, _ec_, мцу_
  { {0x4423018c,0x9099006b,0x645c22bf,0xe4a70054}},	// [6f90] paj_, пват_, beri, _жрно
  { {0xc8d900b2,0xfe700086,0xc0d5002b,0x753d002a}},	//   ִקײט, یدن_, رياب, musz
  { {0x3ae10084,0x9f0400e5,0x64900607,0x8e550033}},	//   hópa_, نولو, _väit, етлі
  { {0x76f900b2,0x765d0a4c,0xaedc005e,0x9e670015}},	//   פּעצ, nesy, обхi, بائن
  { {0x64900005,0xb5fb0125,0x7aed00bf,0x6e201755}},	//   _täit, meád, ňatk, _demb
  { {0x6c350086,0x611a0008,0x64900607,0x711a000a}},	//   رفعا, _מושה, _häir, _מושפ
  { {0x44210026,0xf8af002b,0x66c80061,0xcf15002b}},	//   _meh_, یکت_, lıke, _سوءظ
  { {0xc334013a,0xc1e3005d,0x753d0fce,0x6e200509}},	//   דוק_, _खराब_, kusz, _gemb
  { {0xd84e0092,0x64450011,0x753d2c23,0xc8b5055f}},	//   _vọng_, _ochi, jusz, есны
  { {0xa8740080,0xe7390001,0x6445003f,0x645c082e}},	//   вующ, пео_, _nchi, xeri
  { {0x765d0064,0x69d6003c,0x4c9a000a,0xe800000b}},	//   fesy, _øyen, _צבעו, ोड़ा_
  { {0xeb9600b2,0x8f9a000a,0x645c3566,0xe6ca000b}},	//   _אדער_, פירי, weri, रवेज
  { {0x26de0024,0x753d06e7,0x9474002b,0x8e96000a}},	//   ēto_, gusz, نگدا, גדרו_
  { {0xb4da005d,0x7c210030,0x2610000b,0x8afc002a}},	//   ़ते_, _jelr, _थ्री_, _kręp
  { {0xfbc70029,0x69d90026,0xfddc005d,0x44213567}},	//   ات_, _hywe, _बर्फ, _deh_
  { {0x644504f9,0x75460036,0x645c3568,0x28ab000b}},	//   _echi, _зниз, seri, टोरि
  { {0x6564003f,0xd2590010,0x66250015,0x7afc0030}},	// [6fa0] _usih, ьцё_, _شريك, _értv
  { {0x6029005e,0x5f06004a,0x6e203569,0x649001be}},	//   діїв_, езжа, _semb, _väis
  { {0x6e20013c,0xe4c90015,0x4f660015,0x7d00356a}},	//   _pemb, _تبين_, عاطف, _sums
  { {0x64900020,0x171a0053,0x21290227,0x471a004c}},	//   _täis, פונע, bsah_, פונג
  { {0x6fd0005d,0x69d900dd,0xe2970d7f,0x11d60058}},	//   _तुरं, _nywe, _чая_, _ستحد
  { {0x765d005c,0xcb340063,0xfb660054,0xa7fc0061}},	//   zesy, векъ, ењим, rdık
  { {0x6e200278,0x7c21356b,0x6d4b2004,0x753d002a}},	//   _temb, _delr, atga, zusz
  { {0x69d900dd,0x2aaa0033,0xc333000a,0x7c21007c}},	//   _bywe, ятло_, אוה_, _eelr
  { {0x7af90034,0xb5fb01c0,0x7c21356c,0x69d90034}},	//   _diwt, odáv, _felr, _cywe
  { {0x69d90176,0x5d130029,0xb5fb356d,0x765d002a}},	//   _dywe, _إِلا, ndáv, wesy
  { {0x80370053,0x21290057,0xeb97006b,0x6445356e}},	//   ענטע_, zsah_, _пиф_, _rchi
  { {0x6f03356f,0x64453570,0x66dd0030,0x753d3571}},	//   ínci, _schi, mékk, tusz
  { {0xba170015,0x66dd0030,0xf9920015,0x765d3572}},	//   _أيها_, lékk, _حبا_, resy
  { {0x753d005c,0x67280123,0xf4870099,0x765d3573}},	//   rusz, psdj, хумн, sesy
  { {0x765d0035,0x94040015,0x52090015,0x753d002a}},	//   pesy, اوفه, ِيرُ_, susz
  { {0xe7db0008,0x753d0eba,0x44210012,0xb5fb013f}},	//   _מקוש, pusz, _weh_, edáv
  { {0x44213574,0x60f9054f,0xa1583028,0xdb03006f}},	// [6fb0] _teh_, дная_, нату_, rzné
  { {0x2aba0024,0x21290012,0x55bc000a,0x66dd0030}},	//   mību_, rsah_, _ממחו, kékk
  { {0x2aba0024,0x8d87002b,0xbfab006b,0x7aed006f}},	//   lību_, کشان, чтае_, ňati
  { {0xd7b70053,0x1ee7002b,0x6d4b2a98,0xaf340021}},	//   עהאט_, روشی_, ttga, ارلت
  { {0x2aba0024,0x8d650080,0xf618000a,0x8c453575}},	//   nību_, твле, תחדש_, веле
  { {0x0136013a,0x6d4b2903,0x229c001a,0x7af90034}},	//   _ברשת_, rtga, _líkl_, _siwt
  { {0x4c920124,0x9f4700f2,0x7bda0026,0xfaa50860}},	//   ријс, änä_, _cytu, како
  { {0xb5fb0014,0x6f090107,0xfbd00015,0x7bda002a}},	//   ldáu, _čech, حته_, _dytu
  { {0xdce90045,0xaa560054,0x66d60030,0xfc33006e}},	//   _creă, тињу_, kákr, _محض_
  { {0xd7090afa,0xacf70015,0x2ba70054,0x2aba003d}},	//   мное_, _أسرت, _пјев, dību_
  { {0x7bda0026,0xddc2003d,0x7af90034,0x0000006a}},	//   _gytu, mdoš, _tiwt,
  { {0x969600d7,0xc4c9000a,0x02bd000b,0xa6960099}},	//   трош, _וג_, ्कोन, трој
  { {0x29d20086,0x05633576,0xdbdc001a,0x290f00cb}},	//   _پيوس, авян, _háði, _utga_
  { {0xf7700086,0x2a6d0026,0xd1320086,0x66d60030}},	//   _گاه_, ldeb_, یمز_, gákr
  { {0xddc20024,0x628f0375,0x394d3577,0x752d0045}},	//   idoš, _boco, ltes_, _evaz
  { {0x2a6d0026,0x2aba0024,0x5756000a,0x628f3578}},	//   ndeb_, bību_, _יבצע_, _coco
  { {0x2aba0024,0x4127066c,0x394d3579,0x50660015}},	// [6fc0] cību_, кото_, ntes_, َاطِ
  { {0x394d357a,0xe58b000a,0x66d60030,0x13060555}},	//   ites_, _חָטָ, cákr, _изом
  { {0x03a60036,0x394d357b,0x649b0632,0x3f9c0107}},	//   _рино, htes_, _חסיד, ávu_
  { {0x3ea000dc,0x24920024,0xe126004a,0x7bda0b48}},	//   óit_, žamā_, _имми, _rytu
  { {0x7bda005c,0x11f8002b,0x0000006a,0x0000006a}},	//   _sytu, _سوسک_,   ,
  { {0xdd930010,0xb5fb002d,0x61e6357c,0xdbdc001a}},	//   рашы, leác, _izkl, _báði
  { {0x2d800440,0x2aba0024,0xfe460004,0x69dd0012}},	//   ţie_, zību_, _инво, üsen
  { {0xdee609ac,0xdce20085,0xcb670054,0xddc2003d}},	//   _роби, kvoć, таће_, adoš
  { {0xd83a0174,0xdef90033,0x394d357d,0xb5fb3395}},	//   мэн_, _чыё_, gtes_, ndát
  { {0x7bda0050,0xa7860086,0x26c2066f,0xc7b80085}},	//   _tytu, نشجو, enko_, lađi_
  { {0x752d357e,0x69c40091,0x27e2002a,0x903b000a}},	//   _svaz, _žied, ękno_, ועיה
  { {0x2aba0048,0xc7b8016f,0xb4bd000b,0xf1b4000b}},	//   tību_, nađi_, ेक्_, ूपान
  { {0x394d357f,0x98c62073,0xd9430054,0xb5fb006f}},	//   ctes_, _искл, _вечи, deác
  { {0x2aba0024,0xccf1000a,0x09e304b9,0xe4c5002b}},	//   rību_, ֶ֛ם_, _точн, اصحی
  { {0x2aba0024,0x628f2fce,0x63f40015,0x6235004a}},	//   sību_, _poco, لأفر, леву
  { {0xb5fb0030,0x660d27a4,0x8b57004f,0x673a013b}},	//   reáb, _ufak, כילס_, mrtj
  { {0xb5fb00dc,0xd9040086,0x8079005e,0xc0ab0015}},	// [6fd0] gdát, تی_, нбас_, وائل_
  { {0x6aa20026,0x26c30057,0x25d8000a,0x2edb000b}},	//   _llof, čkou_, _בוחן_, बत्त
  { {0xfaf80024,0xdfd10015,0x628f2a67,0x394d0bae}},	//   _drīz_, حيا_, _toco, ztes_
  { {0xdbdc001a,0x539a0447,0x394d3580,0x9f3400ce}},	//   _ráði, _נירו, ytes_, реці
  { {0x394d3581,0x51841006,0x6db50033,0x201b0015}},	//   xtes_, _кура, ыйду, _يتسع_
  { {0xd5da0053,0xb5fb00dc,0x9f050002,0x7d760021}},	//   ײַנש, ldás, _موسو, امور_
  { {0xe0d200b2,0xddc20024,0x5458000a,0x6aa23582}},	//   _הײם_, rdoš, דסון_, _blof
  { {0xb5fb00dc,0x6f0302c1,0x394d3583,0x3ea63584}},	//   ndás, íncu, ttes_, chot_
  { {0x2a6d0026,0x394d3585,0xb4db0714,0x1db7000b}},	//   rdeb_, utes_, ntàs, _अधित
  { {0x8c190015,0xddc906c0,0x394d3586,0x0000006a}},	//   _أيار_, _knež, rtes_,
  { {0x5b150403,0xf1bf0046,0x6b150054,0x394d3587}},	//   _смет, _zdát_, _смеђ, stes_
  { {0x26c2008c,0x394d3588,0x6608005a,0x6aa20416}},	//   unko_, ptes_, ědko, _glof
  { {0xf507004a,0xc984002b,0x673a1086,0xba740058}},	//   лнял_, _نشوي, artj, _خالت
  { {0x657600aa,0xf7450588,0xf771009a,0x0000006a}},	//   _vryh, _беко, _هاب_,
  { {0xf773002b,0x61e6002a,0x42563589,0x03a3222c}},	//   _خاش_, _szkl, лтат, биро
  { {0x36360086,0xb7da0053,0x86460c1c,0xcb12000a}},	//   _صربس, _אקצי, _сниж, מלל_
  { {0x95560029,0x91ee000b,0x11e60054,0x30760088}},	// [6fe0] _إخبا, चेंज_, ужам, лужс
  { {0xb4662791,0xe3b2002b,0x60de0079,0xb5fb358a}},	//   _скол, _هرج_, ulpm, adás
  { {0xef1a010f,0xb4c0021e,0xc2c600a2,0xee3a358b}},	//   хме_, ंची_, _ميدي, ене_
  { {0xcd2a0080,0xb4db358c,0x442a358d,0xe7f6000b}},	//   ежде_, gràf, lab_, ुखता_
  { {0x61e60048,0xf653000f,0x8e20005e,0xf084002b}},	//   _uzkl, מצא_, дiв_, _پیاپ
  { {0x442a0005,0x6aa20026,0x4095049d,0xed350033}},	//   nab_, _slof, _крст, рэцэ
  { {0x8fa6358e,0x200710cd,0xb5fb358f,0x9e5a0033}},	//   _саве, žnic_, ndár, _праф_
  { {0xaae60029,0xcb67000d,0xd91a0b08,0xbea31393}},	//   دستو, ѓање_, ньо_, _ласк
  { {0x6e930070,0x5e930029,0x442a3590,0x984a0296}},	//   _القا, _القط, kab_, няна_
  { {0x5dcb000a,0x442a3591,0x78740030,0xb5fb0030}},	//   _אֶבְ, jab_, küvő, zdás
  { {0xda6f008f,0x442a3592,0xd7f704ab,0xdc9b000a}},	//   _ля_, dab_, лую_, _ריבל
  { {0x442a0020,0xcff7000a,0x8f9b000a,0x466b0004}},	//   eab_, טציה_, גיטי, хром_
  { {0x95c8016a,0x0000006a,0x0000006a,0x0000006a}},	//   гура_,   ,   ,
  { {0x673a00bd,0x442a1804,0xa98b000a,0x44250f08}},	//   prtj, gab_, _רָאִ, úl_
  { {0x389b0053,0xd8db000a,0x7e6200cb,0x3207002a}},	//   _איגנ, _רקור, keop, śnym_
  { {0x442a0020,0xadf6005d,0x78ba0796,0x99840046}},	//   aab_, ेशान_, litv, namů_
  { {0xd4910092,0x96180029,0x21270086,0xa63c000a}},	// [6ff0] ừ_, _صغير_, ايطی_, _נגזר
  { {0xdddb3593,0x78ba00bd,0x9417000a,0x442a01f9}},	//   _použ, nitv, _עַ֖ד_, cab_
  { {0xb4fa000a,0xa857000a,0x00d80067,0x7ced00e1}},	//   _שפתי, ריבה_, ابقت_, lúrg
  { {0xdce9016f,0x2f380015,0x32670c31,0xb4db0144}},	//   _kreć, اثلة_, _стов, ctàr
  { {0x070b005d,0xdb030089,0x8e08005e,0xc537000a}},	//   _संभव_, rzní, унів_, אָ֔ה_
  { {0x78ba00bd,0x113a0008,0x64550012,0xdddb0046}},	//   jitv, _בתשל, nfzi, _touž
  { {0xd4980008,0x78ba3594,0xb4fc0053,0x447c000a}},	//   רכות_, ditv, גלגר, תנוע
  { {0xc7b80085,0x3eb90123,0x628d008c,0x442a3595}},	//   nađu_, _öst_, njao, zab_
  { {0x3c4700c3,0x628d0072,0xb5fb0417,0x0000006a}},	//   _مضاف, ijao, zdár,
  { {0x7c2a3596,0x661d0012,0x0000006a,0x0000006a}},	//   cafr, ebsk,   ,
  { {0x442a0020,0x2902002e,0xcc7a004c,0xfc300015}},	//   vab_, íkar_, _שװער, _رحل_
  { {0xfd4c0023,0x64400007,0x6e2b0035,0x442a0d25}},	//   _nhiề, ėmim, nagb, wab_
  { {0x78ba00bd,0x5e560053,0x442a0b83,0x1a9a0053}},	//   bitv, סישע_, tab_, _שינע
  { {0x49b80002,0xb4c0021e,0xfdf6000a,0x6b7c0045}},	//   _حامد_, ंचे_, יצרת_, _făgă
  { {0xa4430015,0x753d002a,0x6b7c0045,0xa284002b}},	//   تَّو, arsz, _găgă, میدو
  { {0xfd4c0092,0x442a3591,0xf1aa002b,0xb6d30015}},	//   _chiề, sab_, پاره_, _وقوع

  { {0x7c2a0026,0x6146007a,0x442a007c,0xd6db000a}},	// [7000] yafr, реза, pab_, _בחקל
  { {0xd59b000a,0x34b30015,0x130a004a,0x7f1a008b}},	//   _סביל, _وميز, _иной_, віду_
  { {0xa7fc01e2,0x09e2005d,0x643b0008,0xa06730d1}},	//   ldır, _पर्य, _בעינ, раха_
  { {0x17560053,0x2eed3597,0x9756000a,0xcd2a002b}},	//   יסער_, _chef_, ייעו_, نستن_
  { {0xa7fc01e2,0xc2370008,0xb5fb002d,0xc2c6002b}},	//   ndır, _דרכו_, heán, _ميگي
  { {0xd577000a,0x8b340015,0x7b760015,0x66dd0030}},	//   יתנה_, مفتش, لطعا, lékt
  { {0xf76704b6,0x78ba018c,0xe7870107,0x91830016}},	//   _با_, vitv, yšší, _iếp_
  { {0xb5fb002d,0xf1bf002d,0xa3e9000b,0x0000006a}},	//   deán, _meán_, _बरस_,
  { {0x78ba00bd,0x4efb000a,0x99470015,0xf9920015}},	//   titv, _יהלו, لليل_, تبغ_
  { {0x3157000a,0x6c330015,0xc61f000b,0xec77052b}},	//   סיין_, _وفقا, पर्य_, _кпу_
  { {0x78ba018c,0xdce9016f,0x7c28003d,0xfcd30015}},	//   ritv, _sreć, _iedr, _بيلج
  { {0x8b9b000a,0xdce90085,0x3b950054,0x8b951368}},	//   _שבאת, _preć, _ујут, _уруч
  { {0x2a64018c,0x09e30180,0xd407005e,0x78ba00bc}},	//   memb_, _доцн, ияви, pitv
  { {0x66c80064,0x39440024,0x7c280796,0xdce90085}},	//   lıkl, mums_, _jedr, _vreć
  { {0xb5fb002d,0xfd4c0092,0x7c2811b9,0x39443598}},	//   ceán, _phiề, _medr, lums_
  { {0xdce9016f,0x26c9003f,0x66c80064,0xcb37000a}},	//   _treć, _ujao_, nıkl, יאלי_
  { {0x59a6005d,0x39440024,0xe4e70127,0x7c280026}},	// [7010] गनिर, nums_, _вінн, _oedr
  { {0x85040086,0x656d0035,0x628d0020,0xa0380029}},	//   _گوین, _isah, sjao, لأمر_
  { {0x7fb90031,0xfd4c0016,0xddcb0030,0x9f5501b0}},	//   دهار_, _thiề, vegő, свеч
  { {0x39440048,0x63ad0048,0xcd350029,0x11d90029}},	//   kums_, ģinā, مرتب, _موجة_
  { {0x39440048,0x66c80064,0x68e100c0,0x66dd00dc}},	//   jums_, dıkl, ylld, léks
  { {0x229c002e,0x40950029,0x3944003d,0x8c48005e}},	//   _ríki_, _الآر, dums_, ипів_
  { {0x8c540029,0xe4580053,0x1cb80029,0x6e2b0035}},	//   تئنا, ייגט_, جانب_, pagb
  { {0xc334000a,0xa7fc0061,0xba750015,0x224901c2}},	//   קופ_, ydır, صابت, ngak_
  { {0x39440024,0x7c280026,0x26d93599,0x6aa9359a}},	//   gums_, _fedr, doso_, rhef
  { {0x91830023,0xf1b2000a,0x18690054,0x7c28299d}},	//   _xếp_, פסי_, ћани_, _gedr
  { {0x7ced02c1,0x3ae1002e,0x656d359b,0xd62a0add}},	//   gúre, hópi_, _asah, лоне_
  { {0x1f5a0053,0xba7400e6,0x7d0101ab,0x66c80061}},	//   נדרא, _وانت, _hils, cıkl
  { {0xf1bf002d,0xceb201d8,0x3944003d,0xc5d6008b}},	//   _seán_, ליט_, cums_, сінь
  { {0x7d090467,0xb5fb359c,0xe9d80033,0x6e29007c}},	//   _mues, peán, _ткі_, _leeb
  { {0x03a30bb9,0xb8dd005d,0x2cfa004c,0x66dd0030}},	//   пиро, ीच_, טלשא, tékt
  { {0x7d090152,0x224900e8,0xa206359d,0xe64a0e3f}},	//   _oues, ggak_, спад, _спид_
  { {0x7d090467,0xb5fb002d,0x6441359e,0x044601b7}},	// [7020] _nues, neál, ólic, _лепн
  { {0xdb0a0030,0x6f000d3a,0x7d01359f,0xad270138}},	//   szfé, _simc, _nils, _свiс
  { {0xa3bc005d,0xcf250015,0x6e291b03,0xe4fb000a}},	//   _अधि_, قرني, _beeb, _תפיש
  { {0x5286003b,0xcf250029,0xdfcf0806,0x6e460010}},	//   _الحك, تركي, رين_, седз
  { {0xa2f70008,0x7d0902c1,0xc21300f3,0x6e29007c}},	//   _למטה_, _cues, _מהר_, _deeb
  { {0xd5ed0023,0x39440024,0x26d9039f,0xb5fb005a}},	//   _hoạ, vums_, zoso_, deál
  { {0x7c2835a0,0x66c80061,0x6e290a1c,0x26d91d46}},	//   _vedr, tıkl, _feeb, yoso_
  { {0x8f9b0008,0x7d0935a1,0x394435a2,0x6da60180}},	//   _גילי, _fues, tums_, _либа
  { {0x7e97003b,0x7d091af1,0x41bb004c,0x7d0135a3}},	//   _انقر_, _gues, ָציע, _fils
  { {0xdb0303c0,0xd5ed0023,0x98a40007,0x8afc005c}},	//   szná, _loạ, ksmą_, _spęd
  { {0xe758005e,0x7ced016e,0x66dd0030,0xec13006e}},	//   шині_, búrb, dékr, _روند
  { {0xcf930008,0xb5fb00dc,0x6b850015,0x0f7b004c}},	//   לטת_, beál, _بشكل, ארטל
  { {0xb5fb002d,0xe9ff0016,0xceb3015b,0xf48735a4}},	//   ceál, _trạm_, פיש_, бувн
  { {0x7bc60046,0xb937004f,0xa9a300af,0x66dd01d3}},	//   _ěkuj, _פרוג_, _хиљд, téks
  { {0x443f01e2,0xa857000a,0x2d9d002a,0xd7ef35a5}},	//   ğu_, _ליגה_, zywe_, _ху_
  { {0x97c50029,0x443f140d,0x02450015,0x9b17004f}},	//   _بتهم, şu_, تَرَ, מחלה_
  { {0x86380008,0x656d35a6,0xc2c40015,0x51870054}},	// [7030] _הרחב_, _usah, سيكي, љуба
  { {0x51f8054f,0x61f80033,0x6e2935a7,0x0000006a}},	//   сную_, снуў_, _seeb,
  { {0xf7090023,0x984c0024,0xa295022a,0xd488000a}},	//   _lần_, dēļu_, _дані, _הָרֹ
  { {0x7d0902c1,0xb7db0008,0xde590036,0x51871ce2}},	//   _pues, נקאי, раді_, _луга
  { {0x6e290005,0x7d010048,0x7d09052a,0xb4db0144}},	//   _veeb, _pils, _ques, cràc
  { {0xcc890074,0x7d0902c1,0x2d9d00aa,0x6e2904f6}},	//   شنبه_, _vues, rywe_, _weeb
  { {0xc49c000a,0x547a004c,0xaedd0033,0x7d0135a8}},	//   רשות, ינװײ, _абвi, _vils
  { {0xb5fb002d,0xeab10015,0x27170016,0xdce90085}},	//   teál, بعت_, _hăng_, _iseč
  { {0xf7090023,0x7d090020,0x7d012b0e,0x2d9200cb}},	//   _cần_, _uues, _tils, øyet_
  { {0xd90c0074,0xf7090092,0x47c50127,0x7c34005e}},	//   دیو_, _dần_, жбов, _неух
  { {0xe9a8002b,0x27170016,0xe8f601b0,0xc5e9000a}},	//   لدین_, _măng_, юль_, _סד_
  { {0x19590010,0x27170016,0x442e0091,0xd7060033}},	//   _вады_, _lăng_, _žf_, ўняе_
  { {0xf7090023,0xc1c8000b,0xf8bf0003,0x66dd0030}},	//   _gần_, _रखेग, éés_, tékr
  { {0x27170023,0x229c002e,0x141a0015,0xd5ed0016}},	//   _năng_, _líkt_, شيرة_, _soạ
  { {0x232a0036,0xe2ba0001,0x6fd9000b,0x7785005e}},	//   роби_, аћај_, _बुलं, _єлиз
  { {0x98a40091,0x200701c0,0x24960091,0x0000006a}},	//   rsmą_, žnil_, _žemą_,
  { {0x27170092,0x74f60015,0x1538002b,0x90360015}},	// [7040] _băng_, _وأخذ, _ازبک_, قراص
  { {0x20560010,0x27170092,0xbd8a002b,0x701a005e}},	//   ўтар, _căng_, ینان_, ріат_
  { {0xb4d6014e,0xf1c50091,0x8e0a0923,0x6f660040}},	//   िकी_, višų_, анев_, تهام
  { {0x7ce40251,0xad660015,0x6da60015,0xa75a004c}},	//   mòri, قاته, يمام, ידער
  { {0x82370086,0x628635a9,0x7ce40144,0xac1805b5}},	//   _برپا, _inko, lòri, болу_
  { {0xccb70036,0x5cb70033,0xac970015,0xdca318fc}},	//   огії_, оліў_, يننا_, мачи
  { {0xc27a000a,0x2aaa0099,0xa4fb000a,0x9e66006e}},	//   ֹרִי, итио_, בלסט, _وارن
  { {0x5a340a21,0x5fb7000a,0x539b000a,0x2705003d}},	//   чнит, _והלא_, ייצו, _lēns_
  { {0xcc8a0086,0x09e30001,0x9966005e,0x6e2235aa}},	//   _پناه_, моћн, ітил, mbob
  { {0xf7090092,0x91bb000a,0x19b70015,0x27170016}},	//   _vần_, ימפי, غطية_, _xăng_
  { {0x6d42003e,0xa7140010,0x5bc60021,0x7aa60015}},	//   lroa, ямні, _بقال, _وإصل
  { {0xf7090092,0x99860015,0x98ab003d,0xe9da0054}},	//   _tần_, _ولاو, ālāk_, _кке_
  { {0x55070033,0x95c50015,0x35b40033,0x443a141d}},	//   ючна, سيسه, дбяр, _bdp_
  { {0xdc080048,0x443a003e,0x62860b30,0x18670004}},	//   rēķi, _cdp_, _anko, _мачи_
  { {0x4395005e,0x8c1b000a,0x27170016,0x883b000a}},	//   чавс, שולי, _răng_, _כתגו
  { {0xeb910008,0xc1050029,0xbb3b000a,0x56950788}},	//   עָם_, كوري, יעלי, _хаит
  { {0x35b40063,0x200701a3,0xca97000a,0xb80e000b}},	// [7050] _обър, žnim_, קדמי_, _सलाम_
  { {0x6735002e,0x8fe705c8,0x628635ab,0xd01b19a5}},	//   _ófjö, оцед, _enko, рфа_
  { {0x44310df3,0xe9ff0092,0x44f800c3,0x27170016}},	//   maz_, _trầm_, _بريج_, _văng_
  { {0x443135ac,0x59ca000b,0xdce20085,0x9df9004a}},	//   laz_, ापार, dvođ, бнет_
  { {0x27170023,0xdd940010,0x867c000a,0x61c6000b}},	//   _tăng_, мацы, יראו, लपृष
  { {0x443133c3,0x251c0135,0x51fa000a,0x01fa000a}},	//   naz_, סווא, _להרצ, _לפרל
  { {0x643c000a,0x7ced0077,0x2d9200cb,0xeb991092}},	//   בעונ, gúra, øyer_, сий_
  { {0x7f840086,0x6d4235ad,0x443135ae,0xda650058}},	//   _تلفن, broa, haz_, ساعي
  { {0x8d770074,0x443122b4,0x8d870015,0xbd440015}},	//   _بازا, kaz_, _بشأن, _ينفي
  { {0x78a90124,0x29030ca0,0x443135af,0xe612002b}},	//   ског_, öja_, jaz_, کشد_
  { {0xbb48003b,0xeb090029,0xe7390001,0xdce00091}},	//   _ولكن_, _اقصى_, љем_, _armė
  { {0x6441001a,0x9980006f,0x3eb50061,0x443a35b0}},	//   ólin, _žiť_, _çatı_, _sdp_
  { {0x38ca002b,0x443135b1,0x66dd0030,0x443a35b2}},	//   شایی_, faz_, rékp, _pdp_
  { {0x7ce40251,0xf7090016,0x3ae135b3,0x64a60138}},	//   tòri, _hầm_, rópu_, чага
  { {0xdc88000a,0x07a524cc,0x6383120a,0x3ba9004f}},	//   קְשָ, _хайн, нгра, זֹּ֑
  { {0x28010046,0x57a40033,0x13030238,0x6e2d0052}},	//   ěrně_, _юшча, езсм, ðabl
  { {0xb146008f,0xc2430010,0x26c2003f,0xf1c00024}},	// [7060] янал, энтк, miko_, ēšot_
  { {0xb063002c,0xf7090092,0x55bb000a,0x26c235b4}},	//   jväč, _lầm_, _למפו, liko_
  { {0xb4e8005d,0x649b000a,0xc49b000a,0x9e6610b9}},	//   बती_, _הסיד, _השית, звед
  { {0x26c203ac,0x69c40007,0x645c35b5,0xfe7200e6}},	//   niko_, _žiem, lfri, عدا_
  { {0x3ae10084,0x2ee60409,0xc27b000a,0x627b000a}},	//   hóps_, rlof_, _הרכי, _הנכנ
  { {0x75370053,0x6ef102de,0x645c35b6,0x644e35b7}},	//   לאנד_, våbe, nfri, ngbi
  { {0x7d1b022d,0x645c35b8,0x8fe60058,0x26c201f9}},	//   _etus, ifri, _رأسم, kiko_
  { {0x60de35b9,0x4a530063,0xf7090092,0x7f3b0008}},	//   lopm, екъс, _cầm_, _לעלו
  { {0xd90d0074,0x44310064,0x26c20b63,0x25fe000b}},	//   لین_, yaz_, diko_, रेमी_
  { {0x7c3a00fb,0xb19b0053,0xe29f002e,0x3ea60024}},	//   _udtr, צייכ, _miða_, lkot_
  { {0xf0930008,0x61e6002e,0x8c1b0008,0x9b850015}},	//   תנת_, _lykl, _הובי, _يؤمن
  { {0x64430064,0xb5fb002d,0x76ab2372,0x644e0030}},	//   _öniz, leái, стов_, egbi
  { {0xceb30008,0x9aeb0008,0x443135ba,0x3ea6324d}},	//   תיר_, _הַגִ, taz_, ikot_
  { {0xb5fb002d,0x26c20007,0xa5040210,0x645c35bb}},	//   neái, aiko_, еясл, gfri
  { {0x08770053,0x02a70010,0x443135bc,0xa85b000a}},	//   _מעגט_, прам, raz_, _הדוכ
  { {0x9294008f,0x66e403f1,0x644e0035,0x6fbd000b}},	//   насц, _поја, agbi, ्पसं
  { {0x4431047e,0x80270015,0x21550033,0x76bc000a}},	// [7070] paz_, كرام, ькаў, _למהפ
  { {0x39440024,0xc1b80015,0xb21b02de,0x3ea601ec}},	//   irms_, ساقط_, _knæk, ekot_
  { {0xe8d7000a,0xc104006e,0xa3d5006b,0x649c004f}},	//   לומר_, رومي, _цонч, _ליזה
  { {0x2018001a,0x3ea601d7,0x1e14005e,0x7ff4006e}},	//   _efri_, gkot_, емця, رسلا
  { {0x527a000a,0x427a000a,0xf7090016,0xacf5009a}},	//   _ונרא, _וארג, _rầm_, وستت
  { {0xc058005e,0xbdf80015,0x26c235bd,0xf5ac004f}},	//   _ніс_, سرنا_, ziko_, מ֑וּ
  { {0xb3d6005d,0xfc300029,0x61e635be,0xfb16012c}},	//   _मुफ़्, احه_, _zykl, وقوع_
  { {0x0af40033,0x68e80547,0x6e3b0085,0x26c235bf}},	//   нчыў, eldd, _udub, xiko_
  { {0x645c35c0,0x7d1b00d9,0x3ead0061,0xbc690015}},	//   yfri, _utus, _ilet_, _ومرن_
  { {0xb5fb002f,0xb4bc005d,0xa3ad005d,0x4759006b}},	//   ceái, _आगे_, कना_, ормя_
  { {0xf7090092,0x6d4b35c1,0xcb550054,0x212b0034}},	//   _tầm_, luga, _цвећ, _lwch_
  { {0x291f008c,0xfa900061,0xa5bb0eab,0xb4d60065}},	//   ppua_, çütü_, rbón, िक्_
  { {0x200702c6,0xce36000a,0x99670054,0x5a440033}},	//   žnih_, וארת_, _хтел, _чэха
  { {0xb8080029,0x7ae935c2,0x06070033,0x3ead0144}},	//   _فيهم_, llet, ьняк_, _llet_
  { {0x3ead022d,0x6d4b0b41,0x290f002e,0x26c20035}},	//   _olet_, huga, _huga_, piko_
  { {0x6d5935c3,0x672100bc,0x3ead00aa,0x7ae935c4}},	//   ktwa, mplj, _nlet_, nlet
  { {0x290f013c,0x290735c5,0x212b0034,0x7afb0030}},	// [7080] _juga_, _kina_, _cwch_, imut
  { {0x2907000c,0x25fe005d,0xe5060087,0x7ae90495}},	//   _jina_, रेणी_, _تبعي, hlet
  { {0x212b0176,0x61e60050,0xe29a0124,0x290f003f}},	//   _ewch_, _wykl, _дан_, _luga_
  { {0x2907003f,0x7ae900dc,0x5f06005e,0x7afb0046}},	//   _lina_, jlet, єзда, jmut
  { {0xb5fb002d,0xfbc3005d,0x212b0034,0x6d4b013c}},	//   teái, _वेबम, _gwch_, guga
  { {0x6ad6000b,0x7ae235c6,0x35c5000b,0x5c73005e}},	//   डक्र, _skot, _लेफ़, кліт
  { {0xb5fb002d,0x6609001a,0x7e560054,0x290f35c7}},	//   reái, þekk, _отац, _auga_
  { {0x29072018,0xda7a0010,0xb5fb002d,0x7afb00dc}},	//   _aina_, іяй_, seái, gmut
  { {0xb5fb002f,0xc19b0053,0xb86a0001,0x286a24f9}},	//   peái, ַשטי, ојне_, орно_
  { {0x7afb0020,0x5d9b000a,0x5fd5000b,0x290735c8}},	//   amut, _ובמה, _दशमल, _cina_
  { {0x290727a9,0x291d018b,0xa7fc0064,0x478a005e}},	//   _dina_, _etwa_, ldız, ісом_
  { {0x290735c9,0x290f35ca,0x8f37000a,0x27e70034}},	//   _eina_, _fuga_, ואטו_, _dynn_
  { {0xe4e70036,0x96080010,0x8afb0008,0xbafb000a}},	//   дівн, дэра_, _והאי, _והאש
  { {0x67d42ea0,0x7ae00030,0xf9c7002b,0xa8870033}},	//   _полу, lomt, _تحمی, _ойча_
  { {0x7d0835cb,0xe2f9005e,0x386c0034,0x6d4b02ad}},	//   _mids, зеві_, medr_, zuga
  { {0x66c800dc,0x7d0835cc,0x290735cd,0x7982002a}},	//   tűke, _lids, _zina_, _krow
  { {0x660d0020,0x64480656,0x80f50033,0x38b20045}},	// [7090] _igak, ódic, епах, _vârf_
  { {0x3ead00fb,0x7ae90014,0x29070251,0x752d003f}},	//   _slet_, zlet, _xina_, _iwaz
  { {0xb4db000b,0x7ae90710,0x69b00065,0x7ae0016d}},	//   ़वी_, ylet, आईडी, komt
  { {0x57fb0008,0x6443001c,0x23fa000a,0x33fa000a}},	//   קלאו, _ônib, _מהתא, _מהתנ
  { {0x212b0176,0x721a0008,0x7ae90064,0xd01b005e}},	//   _uwch_, _מורח, vlet, _мфв_
  { {0x66c80064,0xdd8e0029,0x84aa000a,0xdce90085}},	//   lıkt, صوى_, ּיקִ, _pređ
  { {0x6d4b35ce,0x7ae935cf,0x6933002b,0x629d35d0}},	//   suga, tlet, چکتر, _koso
  { {0x9f050029,0x69dc0064,0xfbd00029,0x290735d1}},	//   _أورو, ğren, جته_, _sina_
  { {0x2bdf014e,0x270c0089,0x798235d2,0x7afb35d3}},	//   _पुरा, _měnu_, _crow, rmut
  { {0x7d08020a,0xc1720008,0xc8f8002b,0x798227c8}},	//   _gids, נחי_, وويچ_, _drow
  { {0xdce9010b,0xf092039e,0x7ae935d4,0x57e9006d}},	//   _uređ, אני_, plet, ядом_
  { {0x6721016f,0x19b90210,0x629d35d5,0xa7fc0061}},	//   rplj, _нуль_, _noso, ndıy
  { {0x7982003e,0x66c80700,0x0ab80029,0x6f09005c}},	//   _grow, dıkt, _تطلب_, _miec
  { {0xc9520008,0x443e0003,0x6f0935d6,0x6aa904d1}},	//   _עמו_, ût_, _liec, lkef
  { {0x7c3e03af,0xd8760015,0x394d35d7,0x629d26a4}},	//   ópri, _سميت_, lues_, _boso
  { {0xe2970124,0x68e100dc,0x6f09066f,0xe81b000b}},	//   нас_, lold, _niec, पुरा_
  { {0x394d2d6c,0x21670185,0x68e1007c,0x95c60021}},	// [70a0] nues_, нити_, oold, _سيده
  { {0x68e135d8,0x23db000b,0x9c7c013f,0x0000006a}},	//   nold, _मुकद, _akčn,
  { {0x5457000f,0xf45700f3,0x6aa9079b,0xdfcf0015}},	//   _אביב_, _אייר_, kkef, ميك_
  { {0x629d0176,0x7d0800fb,0x2fd70086,0x68e135d9}},	//   _goso, _sids, روند_, hold
  { {0x2d58004a,0x6f0935da,0x66c80061,0x2388002a}},	//   филь_, _diec, lıks, łuję_
  { {0x653b00b2,0x5d830015,0x394d08e2,0x68e10013}},	//   לענד, الول, dues_, jold
  { {0x6f0904f9,0x7d0801ee,0x394d35db,0x68e135dc}},	//   _fiec, _vids, eues_, dold
  { {0x79820050,0x6ee30020,0xafe32066,0xa3e30065}},	//   _prow, sõbr, _сосл, _फँस_
  { {0xf9920225,0xdceb0064,0x68e135dd,0xbd290015}},	//   ابع_, aygı, fold, _يأكل_
  { {0x68e100dc,0x3157000a,0x8157004c,0xc157000a}},	//   gold, עיין_, עסיע_, עשיו_
  { {0x9cb3003b,0xc5fb005d,0x25fe000b,0x9cd7000a}},	//   _حملت, ृश्य_, रेसी_, _טומה_
  { {0x79820026,0x2911002d,0x7b190012,0x6aa91623}},	//   _trow, únaí_, säuß, ckef
  { {0x96340010,0x18740010,0x18a60010,0x6672002b}},	//   ыняц, _агля, _падм, شگير
  { {0x629d2c17,0xd7940015,0xe853002b,0x79b7000a}},	//   _soso, _للتخ, _منهد, _אלדד_
  { {0x629d31d3,0xc2c50029,0xb8e6000b,0x2768002b}},	//   _poso, نيسي, ैच_, _آشتی_
  { {0xa2d40015,0x2d8435de,0x9f630030,0x0000006a}},	//   هيّت, _orme_, _ívét_,
  { {0xfe710086,0x629d0077,0x6f0935df,0x65950004}},	// [70b0] یگر_, _voso, _riec, _рапу
  { {0x6f090050,0x75200030,0x673a007c,0xdb0a0012}},	//   _siec, ímze, ostj, lzfä
  { {0xdfd10029,0x9f55004a,0x6f0935e0,0xf458000a}},	//   جيا_, твеч, _piec, _טיזר_
  { {0x6ee7003b,0x52a70029,0xb2a70029,0xf5ab000a}},	//   رسال, _أصدق, _أحده, ּבַּ
  { {0x2a6d007c,0x41680004,0xdcf90015,0xa2de0065}},	//   veeb_, _пјрм_, ورتش_, पवर्
  { {0xe104008f,0x6f09005c,0xc57c000a,0xb47b000a}},	//   _бясп, _wiec, פרות, לָ֔י
  { {0xdea10086,0x2012002c,0x9e150010,0x673a0079}},	//   _پیشی, ániť_, _адбі, jstj
  { {0xaa560054,0x09e535e1,0x443335e2,0x394d027b}},	//   вићу_, койн, _lex_, tues_
  { {0xe9d90191,0xe8f90080,0x68e106e7,0x1603000b}},	//   ьки_, мли_, told, रेमर_
  { {0x7e7b018b,0xa2c1005d,0x6c740086,0x673a002e}},	//   _haup, रोत्, _مطمئ, fstj
  { {0x394d0bf5,0x7e7b35e3,0x8c3c0061,0x673a09c0}},	//   sues_, _kaup, _doğd, gstj
  { {0x99850029,0x7cf60045,0x68e135e4,0x63a7002a}},	//   _للصو, râre, sold, dyjn
  { {0x7e7b00e8,0x394d35e5,0x67240085,0xd252002b}},	//   _maup, ques_, _čije, ینس_
  { {0x98a2017c,0x7e7b35e6,0x97c50015,0x8d48000a}},	//   _више, _laup, _لتعم, עֲרֵ
  { {0x6ef80089,0xe29f002e,0xa5071e64,0x14170015}},	//   líbe, _boð_, тера_, ضيقة_
  { {0xe286006b,0xc2432bb4,0xe058002b,0x9586008a}},	//   ълби, инск, کیست_, _алие
  { {0xe6110008,0x942608d7,0x7ced006f,0xa2060515}},	// [70c0] _לִי_, _импе, gúrk, тпад
  { {0xe537004c,0xd023005e,0xb5fb35e7,0x443301f9}},	//   _שטיט_, имуй, reát, _gex_
  { {0x63a70050,0xe0d50191,0xb4c0005d,0x7e7b0012}},	//   cyjn, ують, ूची_, _baup
  { {0x0dca0088,0xb21b02de,0xa2c1000b,0x6e180015}},	//   млей_, _snæv, रोद्, ريتس_
  { {0x44380011,0xdce00024,0xbea30180,0x2919006f}},	//   oar_, _apmā, јачк, ísal_
  { {0x55bb0008,0xad250015,0x237f002a,0x0c380015}},	//   ומנו, ارنو, łuje_, ركبة_
  { {0xf70a0092,0xf4130008,0xdca30001,0x207b0135}},	//   _hầu_, ספה_, раји, _קאלא
  { {0xc3330008,0x44382533,0x9f450030,0x3a741119}},	//   בוה_, har_, _álá_, улир
  { {0xdc540086,0x63a7005c,0x20070089,0xbea305b3}},	//   _مراک, zyjn, žnit_, _татк
  { {0x673a0084,0x7e7b00bd,0x4438068b,0xf70a0016}},	//   tstj, _zaup, jar_, _mầu_
  { {0xa5bb002d,0xfd4e0092,0xd7f735e8,0xf70a0016}},	//   mbói, _ngoặ, кую_, _lầu_
  { {0x7c3803af,0x443d005c,0xf8030010,0x673a002e}},	//   lavr, _św_, шчын, rstj
  { {0x673a002e,0x443835e9,0xdd860021,0x25fe000b}},	//   sstj, far_, حو_, रेली_
  { {0x7d1d0251,0x3d15000b,0x443835ea,0x7c3835eb}},	//   _ésse, _फंसे_, gar_, navr
  { {0xd6db000d,0x24180010,0x25ad0820,0x3494030c}},	//   _оти_, тосы_, šel_, шарр
  { {0xf70a0023,0x443809f2,0x63a7005c,0x8bd7000a}},	//   _bầu_, aar_, ryjn, דולו_
  { {0xf70a0023,0x63a7005c,0x60f904f7,0x50670015}},	// [70d0] _cầu_, syjn, еная_, َائِ
  { {0x2edb014e,0xf70a0092,0x51f80139,0x443835ec}},	//   यक्त, _dầu_, тную_, car_
  { {0xf412013a,0x200700f2,0x6d5b19cf,0xc7f8000a}},	//   _לפי_, äni_, _squa, תִּר
  { {0x4ea7010f,0x753d00dc,0xa295022a,0x6e45002b}},	//   ърза, ossz, _самі, انشم
  { {0xb6bc000a,0x1eea002b,0xdca10033,0x628f0bbc}},	//   וצאי, روهی_, йскi_, _inco
  { {0x753d0014,0xd838044c,0xec19009a,0x0000006a}},	//   issz, jač_, رآتش_,
  { {0x9f340036,0xbb850015,0x8f340033,0x4c920054}},	//   _весі, البي, _весц, сијс
  { {0xdce9016f,0x44381e0a,0x20070091,0x2af50033}},	//   _oseć, zar_, žnis_, ыялё
  { {0x38ca0074,0x1017005d,0x44381f86,0xf9910015}},	//   کايی_, _तलाश_, yar_, صبة_
  { {0x38750001,0x4438194d,0xd8380085,0x7ced001a}},	//   ућит, xar_, gač_, kúri
  { {0xa6ca0b9c,0x443835ed,0x97c50033,0x753d0030}},	//   елна_, var_, уйне, essz
  { {0xba3900b2,0xcb120008,0x9a880029,0x443835ee}},	//   _װײַט, _הלא_, _لَمْ_, war_
  { {0x4a9a000a,0xf9900040,0xe8ee176c,0x44381a2a}},	//   _רינג, _وبه_, _гл_, tar_
  { {0x628f02d7,0x2a7f0020,0xb4c0000b,0x443835ef}},	//   _anco, ldub_, ूचे_, uar_
  { {0xc8da000a,0x6d4b0012,0x54970033,0x787a000a}},	//   _אקסט, hrga, ывёў_, _טָהו
  { {0x2a7f0020,0x670c000b,0x443835f0,0x7c382f93}},	//   ndub_, _सूचक_, sar_, zavr
  { {0x753d0014,0xea160053,0x81860010,0x44383029}},	// [70e0] cssz, אַבי_, ыгаж, par_
  { {0x395f263d,0x628f0aff,0x3f5c001a,0xc0ea0040}},	//   itus_, _enco, tíu_, رفان_
  { {0x395f0020,0x7f190210,0xc209000a,0xd00f0015}},	//   htus_, вічу_, פה_, ألم_
  { {0x395f2233,0xd8380085,0x644c002a,0xf70a0016}},	//   ktus_, zač_, łnią, _tầu_
  { {0xdca606c3,0xd657000a,0x6f030079,0x2cea05b5}},	//   лади, רינת_, ïnca, нько_
  { {0xfce30036,0xbd870115,0xdb03006f,0xcf490061}},	//   бочо, انون_, rzný, üşük_
  { {0x2a7d0026,0x3f780008,0xe0d7000d,0x9c630015}},	//   _bawb_, _בָּע, _свр_, صهيو
  { {0x7644003f,0xdee62229,0x93fb004c,0x7c380085}},	//   _ndiy, _соби, עלקי, savr
  { {0xed630046,0x9992002a,0x4c560015,0xd8380480}},	//   ěží_, _żył_, _مضار, tač_
  { {0x415b0053,0x444435f1,0x2bdf000b,0xc173000a}},	//   עדיג, _nd_, _पुका, צחת_
  { {0x2a66001e,0xd8380d98,0xda660087,0x08f70015}},	//   _бълг, rač_, _ماشي, دريب_
  { {0x444435f2,0x0f57000a,0xdb230030,0x6f020077}},	//   _ad_, ניכם_, _óráv, nmoc
  { {0xf6e40033,0x76440034,0xe894021a,0x88942a91}},	//   сцэн, _ddiy, _валь, _вилх
  { {0x764401e2,0x6aa209f2,0x7ced35f3,0x2ee60547}},	//   _ediy, _hoof, túri, hoof_
  { {0xb8650074,0xfc170135,0x32672a7b,0xc348006b}},	//   _خانو, רקלי_, лтав, ляте_
  { {0x444435f4,0x673c0030,0x375b000a,0x6f021b3f}},	//   _ed_, árju, _נכחד, jmoc
  { {0xf194007a,0x7a8b000a,0xc10500c3,0x40871eea}},	// [70f0] бить, עָלַ, لوري, лужб
  { {0x14190029,0x3d18000b,0x26cb35f5,0x656d02f2}},	//   _جيدة_, _पढ़े_, lico_, _ipah
  { {0x6d4000c0,0x3f8735f6,0xe29f001a,0x8e150515}},	//   _avma, ínu_, _liði_, адец
  { {0x628f003e,0x395f0007,0x26cb35f7,0x539a000a}},	//   _unco, ytus_, nico_, _סירו
  { {0xb23a0053,0x2d640015,0xce580015,0x6e392a38}},	//   _בערז, مطوّ, اؤما_, rawb
  { {0x251c00b2,0x7b750029,0x21290509,0x6f0235f8}},	//   עווא, لطبا, mpah_, amoc
  { {0x2a7d0026,0xeb99087a,0xe4580053,0xab760015}},	//   _pawb_, тий_, טיגט_, لموا_
  { {0xf53f01d1,0x34d2005d,0x6008000a,0x26cb35f9}},	//   kså_, _सद्द, _תִשְ, jico_
  { {0x2024002e,0x395f09e2,0x6b880012,0x2a7f007c}},	//   _árið_, utus_, _erdg, rdub_
  { {0x229c0089,0xa765018f,0x9d1835fa,0xf8b80016}},	//   _díky_, акод, _софт_, ghĩ_
  { {0x444435fb,0x395f35fc,0x656d008c,0x26cb25d5}},	//   _rd_, stus_, _apah, fico_
  { {0x444435fd,0x66e635fe,0xe7360121,0x6aa217cd}},	//   _sd_, рома, шею_, _goof
  { {0xf53f079b,0x89370015,0xe57712ae,0xdb030030}},	//   gså_, _إعصا, азя_, sznó
  { {0x19ba000a,0x7ae40def,0x1d16004f,0x6f021b3f}},	//   _שמסב, čite, יקשר_, zmoc
  { {0xdc080024,0xd7880029,0x394d00e8,0xc30600c3}},	//   mēģi, _مخيم_, lres_, لبرو
  { {0x394d35ff,0xdc08003d,0x78a30030,0x644501d7}},	//   ores_, lēģi, _honv, _edhi
  { {0xb69b0011,0x867b000a,0x61ef0b62,0x90c60033}},	// [7100] omân, _ירקו, _cycl, абае
  { {0x444400fb,0x394d038d,0xdb180014,0x3d0f005d}},	//   _ud_, ires_, szvé, ादों_
  { {0x394d00b8,0x6fd50010,0xee3a3600,0x7fd5005e}},	//   hres_, біцц, вне_, біці
  { {0x394d005c,0x33db000f,0xeda60080,0x6d440007}},	//   kres_, _יחיד, ишло, šiam
  { {0x6f023601,0x2ee63602,0x6aa23566,0x2ab80030}},	//   rmoc, roof_, _roof, _jébe_
  { {0x1d190010,0x95fb004c,0x8c3c0061,0x394d0e84}},	//   уюць_, כּוח, _boğa, dres_
  { {0x9f5c022d,0x394d3603,0x8b2300af,0x0000006a}},	//   ävä_, eres_, одје,
  { {0xc3330008,0x8c3c0064,0x290e003f,0x0f7b0008}},	//   קוח_, _doğa, _sifa_, _באלב
  { {0x99970063,0x26cb3604,0xa3cd000b,0xdce00091}},	//   икът_, vico_, _शेन_, _apmą
  { {0x61eb0012,0x98e30015,0xa8a6004a,0x78a33605}},	//   ügli, يكيو, ррик, _conv
  { {0x3ea40298,0xd0f7000a,0x7017000a,0x07e3005e}},	//   _komt_, שמית_, יחיד_, жцям
  { {0xbad50010,0xaf77004c,0xbf9b004c,0x394d3606}},	//   _лічы, בעטס_, דיטש, bres_
  { {0x26cb2a83,0x1a9b000a,0x4976002b,0x74a701ca}},	//   rico_, _שידע, _خداآ, ајве
  { {0x14cb0080,0x79bb05bd,0x26cb3607,0x98a401ec}},	//   тыми_, _שֶׁה, sico_, rsmē_
  { {0x3384005e,0x26cb3608,0xe72f0015,0xa29501f3}},	//   оутв, pico_, _قصي_, баві
  { {0xa79b000a,0x68e80034,0x96350588,0x57b7004f}},	//   _ישוח, lodd, _униц, _כלוב_
  { {0x26c9016f,0x6fd9005d,0x5187000d,0x64413609}},	// [7110] _imao_, _मशहू, јуба, ólis
  { {0xe4eb0074,0x68e80026,0x6445003f,0x64550054}},	//   _جعبه_, nodd, _udhi, _увођ
  { {0xbe150015,0x1877000a,0x394d01d3,0xd018360a}},	//   مواع, שעבר_, zres_, рфу_
  { {0x2295003b,0x68e80176,0x99840007,0xda660015}},	//   _الحس, hodd, namų_, _عُ_
  { {0xce380015,0x27e2002a,0x2bdf000b,0x8c3c0061}},	//   شأنا_, ękny_, _पुजा, _soğa
  { {0x394d360b,0x3e470092,0x9b450029,0xb4db0251}},	//   vres_, ốt_, منتو, cràt
  { {0x3f850152,0xfe73002b,0x7ced0125,0x394d0034}},	//   _élu_, _ودر_, dúrt, wres_
  { {0xaae40086,0x99840007,0x8d770086,0xdea4002b}},	//   يسيو, jamų_, _پارا, _ویلی
  { {0xdc080024,0x68e80034,0x394d360c,0x99840091}},	//   tēģi, fodd, ures_, damų_
  { {0x248100b8,0x48790063,0xa7fc0061,0x26d90003}},	//   _nahm_, усия_, rfın, éron_
  { {0xd70a0080,0xb69b098d,0x78a30030,0x37e501ca}},	//   лное_, rmân, _vonv, сонг
  { {0x869a000d,0x7b150089,0x394d360d,0x1bf6000a}},	//   утот_, _všud, pres_, _הצער_
  { {0x4549004a,0xb5fb0030,0x18691246,0x7ae90546}},	//   ичём_, lfáj, _бали_, moet
  { {0xf8ab005d,0x1423000d,0x78ba0ec2,0xf992000a}},	//   _छविय, здрм, chtv, _מרד_
  { {0x8af9004c,0xb5fb0030,0x2ca51d9d,0x9836000a}},	//   ָפּק, nfáj, _mold_, _הרצף_
  { {0xdb1200dc,0x7ae90bd8,0x7782009b,0x6abb2fde}},	//   ógép, noet, _хлъз, nhuf
  { {0x10160029,0xb6bb000a,0x6d92001a,0xe0da15be}},	// [7120] مباد, _תצפי, iðað, гва_
  { {0x3ce1000b,0xa494002b,0x3ae1006f,0x69dd0061}},	//   खकों_, _بیست, rópy_, üsey
  { {0xe47b0053,0xd00f0015,0xd5e9002b,0xa067006b}},	//   _גריכ, فلك_, _معین_, саха_
  { {0x3ec5005e,0x443a360e,0x25bd0061,0xe29a135e}},	//   осіб, _hep_, _özlü_, _сам_
  { {0x443a00aa,0x865b000a,0x9cca056d,0x2ca5360f}},	//   _kep_, רדני, лыка_, _bold_
  { {0x2ca5003e,0xba3d0046,0xc43a000a,0x3cf4000b}},	//   _cold_, chůz, אתַי, ेगें_
  { {0x7ae90026,0xc27a000a,0x63830046,0x2ca50123}},	//   foet, ָרִי, míná, _dold_
  { {0xd00f0029,0xd3570008,0x443a00bd,0xc2120008}},	//   _ألف_, ציפי_, _lep_, ּה֙_
  { {0x9c5a0086,0xe29b0053,0xae1b0008,0x2ca500da}},	//   _مجاز_, רשפר, _תומכ, _fold_
  { {0xad1b0008,0xb17b0053,0x2ca527fc,0xa17b004c}},	//   _עובר, נטיר, _gold_, נטיט
  { {0x68e80176,0xbb860086,0x15e1000b,0x99840091}},	//   rodd, _دلاي, _गुजर_, tamų_
  { {0xfaa315ed,0xeb970008,0x6e2200e8,0x68e8173a}},	//   _нахо, _לדבר_, ncob, sodd
  { {0x62840b7c,0x7c3a1bb6,0x6d4213e3,0xe4d70058}},	//   ddio, _ketr, nsoa, متسب
  { {0x443a3512,0xd5b802e1,0xdcfb0085,0x8c3c0061}},	//   _cep_, ссю_, _vruć, _moğo
  { {0x57260018,0x87260002,0x9cd7000a,0x8c1b000a}},	//   _ارتق, _اعتم, צולה_, רולי
  { {0x41e70010,0x443a3610,0xbb3b004c,0xe3c40015}},	//   біза, _eep_, טעלי, سْقَ
  { {0xdb0a00dc,0x61150036,0x51870956,0xa1591aef}},	// [7130] gyfé, іджу, щува, разу_
  { {0x69c00064,0x1007006b,0x9898000a,0x7c3a3611}},	//   izme, бяем, סֹּפ, _netr
  { {0x83670029,0xc1040029,0x2fd900c3,0x0000006a}},	//   _ادخل, أولي, جواد_,
  { {0x2ca5003e,0xa1590010,0xa6fb000a,0x2bc30065}},	//   _sold_, _каму_, נִ֑י, _वेगा
  { {0x5d670063,0xee38017f,0x867c05bd,0x0d67004a}},	//   стез, сні_, טראו, съем
  { {0x61fd0048,0x547c0053,0xe38b000a,0xb53c004f}},	//   _izsl, ָנהײ, ָאֵֽ, נגוש
  { {0x7ae92f4c,0x2023002a,0x69c03612,0x9a690015}},	//   toet, ąpią_, ezme, لمثل_
  { {0xbd450015,0x39490054,0x7c3a007c,0xa925008d}},	//   _ونزي, азио_, _eetr, одил
  { {0x2ca5003e,0x6d92002e,0xb5fb0030,0x78890015}},	//   _told_, rðað, sfáj, لَةِ_
  { {0x25ed005d,0x7ae40d98,0x2905003f,0xb5fb0030}},	//   _घड़ी_, čita, umla_, pfáj
  { {0xe7390124,0x69c010ca,0xc052000a,0xc987002b}},	//   јем_, azme, וזי_, _گشاي
  { {0x7d1b0044,0xb9950015,0xc8780061,0x8b88000a}},	//   _kuus, _ولاب, doğu_, _לָנֶ
  { {0xaca30016,0xe29f001a,0x7d1b3613,0x443a3614}},	//   _huốn, _liðs_, _juus, _pep_
  { {0x69dc0064,0x38bb00dd,0x7d1b0607,0x62840034}},	//   ğret, _bêre_, _muus, wdio
  { {0x86c60002,0x25fe000b,0xd2aa0054,0xdce00091}},	//   _ويتن, रेजी_, акве_, _esmė
  { {0x6e3b2cd8,0xa22a0004,0x6d440091,0x62843615}},	//   _neub, ржаа_, šiai, udio
  { {0x7d1b00dd,0x291f0003,0x443a3616,0x00ca1ff7}},	// [7140] _nuus, nqua_, _tep_, алак_
  { {0x70f600ce,0x6ab90416,0xbfb602be,0x0000006a}},	//   ічає, _llwf, يحات,
  { {0x2d8d04ed,0x256416a6,0x6fd6005e,0x6e46002b}},	//   _aree_, löl_, ціац, قنام
  { {0xcfa90029,0xa3e3000b,0x645c2903,0x69c0002a}},	//   حاكم_, _फुट_, lgri, yzme
  { {0x2d8d12d4,0x63830046,0x4c94033d,0x25640012}},	//   _cree_, píná, зилс, nöl_
  { {0x4d390036,0x6e2211dd,0x645c3617,0x2240003d}},	//   сяця_, scob, ngri, laik_
  { {0x6d4203af,0xa2c1005d,0xb4fb000a,0x645c3618}},	//   ssoa, रोक्, ספצי, igri
  { {0x2d8d003e,0xf4130008,0x7d1b008c,0xad660015}},	//   _free_, ופו_, _fuus, _واذه
  { {0x2564002e,0x69c00085,0x26d9006f,0x6f1c1793}},	//   jöl_, uzme, érom_, _hurc
  { {0x6cd60029,0x6f1c002a,0x25640359,0x5cb8000a}},	//   _بقطا, _kurc, döl_, _פֶּס
  { {0xd6d10015,0xd794006b,0xe0fb000a,0x3b8600af}},	//   فقد_, чинъ, שליל, _флег
  { {0x22400030,0xa96a2aaa,0x645c02f7,0x6f1c1ed2}},	//   jaik_, _вида_, egri, _murc
  { {0xcb13000a,0x291f1c75,0x199402bb,0x88c60015}},	//   _חלף_, cqua_, _халя, _وتتل
  { {0x645c00e8,0x18670054,0x6f1c3619,0x0000006a}},	//   ggri, _даљи_, _ourc,
  { {0xaca30023,0x92a707c1,0x93882a9b,0xe1f90091}},	//   _xuốn, ојал, оста_, _šų_
  { {0x92940010,0x7304005e,0x645c361a,0xc793002b}},	//   масц, дчуж, agri, _آشوب
  { {0xa2c1005d,0x4177002b,0xf2c40015,0x9965000a}},	// [7150] रोग्, غارس, ذْكُ, ּיעַ_
  { {0xddc90011,0xb5fb002e,0xad3a005e,0x2f8b0054}},	//   _aceş, tgáf, _свiт, иљен_
  { {0x2fc70023,0x22400509,0x4e350015,0x3e350015}},	//   àng_, baik_, كفاء, كفار
  { {0x6f1c0bcf,0xef18008f,0xde59005e,0xb7db000a}},	//   _durc, імі_, саді_, סקאי
  { {0x429a000a,0x38c40091,0x329a000a,0x62340138}},	//   _הסרב, _kūrė_, _הברד, _іеру
  { {0xbd180036,0xd57c000a,0x0136000a,0xc058017f}},	//   іції_, שָׁר, _מרשת_, _міс_
  { {0xeab10029,0x8fa50015,0x7ae400bc,0x256406cd}},	//   فعة_, _عمره, čitn, zöl_
  { {0x33dc0008,0x2d8d014c,0xdddb0045,0x63a804d1}},	//   יחוד, _tree_, _cauţ, ødni
  { {0x3a3f01d7,0xcd340058,0x66d6013b,0x0000006a}},	//   raup_, _يركب, nške,
  { {0x6d590273,0x291f0003,0x28990004,0xf8690015}},	//   muwa, rqua_, стиќ_, حمدي_
  { {0xc5e901e4,0xf7710225,0x6d59361b,0x291f0119}},	//   _עד_, راد_, luwa, squa_
  { {0x1959008f,0xabfa0008,0xc4c9000a,0x9f520003}},	//   _гады_, _ההער, _גג_, édée_
  { {0x75d60086,0xeab000e6,0x645c361c,0x6d440091}},	//   سيسا, _جعل_, tgri, šiav
  { {0xa50a0549,0x88c40015,0xd11c000b,0x270d0046}},	//   сега_, _يتول, _भूषण_, _měny_
  { {0x291d000c,0x883a0008,0x232a0036,0xf7490029}},	//   _huwa_, _התצו, соби_, _البي_
  { {0x645c0176,0x291d000c,0xdbd70c58,0x6d59002a}},	//   sgri, _kuwa_, määr, kuwa
  { {0x865b0008,0x6f1c361d,0xa5bb026a,0x66bb004f}},	// [7160] _הדפי, _surc, ncól, _למקה
  { {0xe45a008f,0x6f1c259c,0xe366006b,0x2240361e}},	//   _ужо_, _purc, _екои, saik_
  { {0x2721002e,0x141b004c,0x2f560033,0xaca30016}},	//   _jón_, _לויב, ятас, _luồn
  { {0x471a0053,0x2721361f,0x639b000a,0x127a0015}},	//   צונג, _món_, _הסטנ, _احدث_
  { {0x568d0053,0xce190010,0x6d5902f2,0x27210125}},	//   יטאַ, іцці_, guwa, _lón_
  { {0xdbd701be,0x4127006b,0x201801bc,0x6f1c3620}},	//   käär, _хоро_, _ugri_, _turc
  { {0x62860582,0x6d59002a,0xe4570643,0x27210016}},	//   _kako, auwa, ליסט_, _nón_
  { {0x5fdb000a,0x628609cd,0xaca30016,0xda660015}},	//   _החלק, _jako, _buồn, سابي
  { {0xdee30036,0x62863621,0x99630033,0xaca30016}},	//   _чоти, _mako, нтэл, _cuồn
  { {0x38c80086,0x62861e69,0xed5f0091,0xdbd7007c}},	//   تابی_, _lako, ėžta_, fäär
  { {0xf0930008,0xdc8b000a,0x6bd70015,0x2919001a}},	//   גנת_, _לְאָ, _فوكس_, ísar_
  { {0xa3cd005d,0xa9a6000d,0x62863622,0x6d440091}},	//   _शेष_, _ниед, _nako, šiau
  { {0x6f030003,0xe8df0016,0xf1bf0077,0xceb3000a}},	//   ïnci, guồn_, _afán_, גיר_
  { {0x2721002d,0xe5040029,0xa9c5002b,0x0000006a}},	//   _fón_, ّبِي, _غزنو,
  { {0xb4bd005d,0xe1ff00dc,0xada3006f,0x62863623}},	//   _आती_, _szó_, _zlúč, _bako
  { {0x92b70015,0xb7db000a,0xdddb003d,0xf8bc0065}},	//   أحسا, _לקוי, _lauš, _ऋतुप
  { {0xa3cd000b,0x764d01c2,0x62d4002b,0xb1150054}},	// [7170] _शेर_, _iday, رآفر, дмаш
  { {0x55bc0008,0x04590029,0x853c000a,0x66d600bc}},	//   _למחו, _بلدة_, _הגזי, rške
  { {0x5f790040,0xf8b3004f,0x0000006a,0x0000006a}},	//   تماس_, עשע_,   ,
  { {0x6ee70029,0x7c280159,0xff500115,0x5dd50015}},	//   أسئل, _afdr, اخل_, وقائ
  { {0xef20002a,0xdce204b2,0x2c6f0061,0x0000006a}},	//   ężar_, atoč, yıdı_,
  { {0x319a0008,0xb19a000a,0xbbe9002b,0xf538000a}},	//   _ובשנ, _וישכ, يرغم_, לנדי_
  { {0x6d5916c1,0xdca205c4,0xf092000a,0x0c360015}},	//   suwa, тащи, _בנם_, ذكية_
  { {0xfbd00029,0xdbd70209,0xda650015,0xab63002a}},	//   دته_, väär, ذاعي, łżon
  { {0xcda9003b,0x272108e0,0x38550063,0x09050f82}},	//   _بهذه_, _són_, мънс, мпин
  { {0x764d0064,0xfd130015,0x917a0016,0xdb180030}},	//   _aday, _أجر_, _hập_, szvá
  { {0x6d440007,0xabb50015,0x9a9d0033,0xa146003d}},	//   šiat, _تماث, _вулi, _zeķē
  { {0x6441001a,0x98a2003d,0x070a0058,0xaca300a1}},	//   ðlin, īkā_, تيجي_, _tuồn
  { {0x19940010,0xe8ee0a21,0x6286053e,0x35fa0021}},	//   _паця, _ал_, _rako, تردد_
  { {0x917a0023,0x443e0092,0xdce2006f,0xe73907d1}},	//   _lập_, út_, ytoč, _дек_
  { {0x62863624,0xccf2000a,0x0000006a,0x0000006a}},	//   _pako, דכם_,   ,
  { {0xdb240014,0x7cf60045,0xe2972143,0x6e2d039f}},	//   éséh, râri, мас_, ñabl
  { {0x3f830020,0x21670a6c,0x3f910061,0x67240085}},	// [7180] _asju_, мити_, _arzu_, _čiji
  { {0xc0590036,0x6aab0134,0xf5060010,0x3f910085}},	//   зії_, _logf, _ізно, _brzu_
  { {0x1eca000d,0x6d490667,0xc49b000a,0x628625b6}},	//   олжи_, _avea, _ושית, _tako
  { {0x917a0023,0xc333000a,0x7e9a0058,0x0000006a}},	//   _cập_, _שור_, تنصر_,
  { {0x627b000a,0xdc740033,0xc27b000a,0xdce23625}},	//   _ונכנ, еглы, _ורכי, stoč
  { {0x3e4e0023,0x1603000b,0x61430054,0xa2ca000b}},	//   ột_, रेटर_, _јера, सोर्
  { {0xeb97012e,0x6aab02de,0xe2ab0052,0x0000006a}},	//   диј_, _bogf, _úðð_,
  { {0x3e8600df,0x8f970015,0xdb230030,0xed5a2a4b}},	//   _būtų_, _تنفذ_, úrák, _моб_
  { {0xbc660001,0x6aab0026,0x6f030011,0xc9140054}},	//   _овак, _dogf, înce, ндић
  { {0xd90d0074,0xb4bd005d,0x47342923,0xb4e8000b}},	//   مین_, _आते_, ннос, यको_
  { {0x9057009d,0xf98f0086,0x20570053,0xc0570008}},	//   וסיף_, هبی_, וייל_, וביץ_
  { {0x5694034e,0x9f650030,0x3ea601d7,0x5ee4000b}},	//   вают, étét_, njot_, टकट्_
  { {0x2d840089,0x6ef8002d,0xfe370008,0x9564006b}},	//   _jsme_, ríbh, ורכי_, кърд
  { {0x26c2018c,0xf9fb004f,0x79fb004f,0x0000006a}},	//   ahko_, _והדמ, _ולדח,
  { {0x2cac0176,0xe6c70015,0x38cb002b,0xa3b80015}},	//   _modd_, _يتبي, _بانی_, وافر_
  { {0xae0e000b,0xcb8b004f,0xa7fc007f,0x0000006a}},	//   िधान_, חְמֹ, rgıd,
  { {0x34953626,0x752d2d15,0xa1190015,0xf70a0016}},	// [7190] _запр, _utaz, سقاط_, _nầy_
  { {0x44270064,0xd91b0008,0x3169016e,0x8078116f}},	//   _ün_, קובל, rtaz_, мбус_
  { {0xdfd1003b,0x316901c2,0x6d490ed1,0x61e63627}},	//   ديا_, staz_, _svea, _exkl
  { {0xdd910029,0xf70a0016,0x62080061,0x83b6004f}},	//   ُوا_, _bầy_, örlü, _נפרע_
  { {0x41e70036,0x2cac2c07,0xf70a0016,0x0000006a}},	//   _ціна, _bodd_, _cầy_,
  { {0x113a000a,0xab65006b,0x4c840033,0xcb690015}},	//   _מתשל, евкл, клів, كمته_
  { {0x917a0092,0xe452000a,0x2cac3628,0xee7b0058}},	//   _tập_, רֶד_, _dodd_, _وصرت_
  { {0xff070010,0x6e940457,0x59d0000b,0xdb03006f}},	//   _цягн, _иису, _तेहर, lynú
  { {0x2cac0026,0x99d50029,0x9d550086,0xe9d90142}},	//   _fodd_, عتبا, _سنات, яки_
  { {0xa3c1005d,0x6ca70010,0x77c90f09,0xa3e0000b}},	//   ्छा_, _ўраж, злог_, _दखल_
  { {0x66d60007,0xdb23009a,0xd77502be,0x3ebf01ec}},	//   eška, _شوشی, رادع, _klut_
  { {0xcf560008,0x0bb6004c,0xba740015,0xb4e80157}},	//   עברת_, _אלעם_, _لاهت, यक्_
  { {0x3ead00f6,0x249a01d7,0xc6430015,0x0000006a}},	//   _moet_, _pnpm_, طَّي,
  { {0xb956000a,0x37e519a5,0xf8680015,0xf7450098}},	//   _ניצח_, _полг, _يمني_, _зеко
  { {0xd5b80048,0xa856000a,0xabf9004c,0xe29a052b}},	//   ņā_, _טיסה_, לפֿז, пав_
  { {0x171a00b2,0xef190050,0x05660036,0xc7d6000a}},	//   _צופע, _niż_, _звин, _רוקי_
  { {0x4afa0053,0x26c0003f,0x7afb0a6f,0x2003002a}},	// [71a0] פּלײ, _ilio_, ilut, _azji_
  { {0x7afb0084,0xdcfb016f,0xf0630004,0x26d9006f}},	//   hlut, _oruđ, лкуп, érov_
  { {0xc43b0008,0x3ebf00b8,0x443806bd,0x7e2a0033}},	//   _מתיי, _blut_, mbr_, піла_
  { {0x92b60029,0x3ea60024,0x11d60036,0xd357000a}},	//   _أحدا, ujot_, _зігр, _איטי_
  { {0x3ead0111,0x86370053,0x26c0003f,0x721b000a}},	//   _doet_, גאנג_, _mlio_, _מוכח
  { {0xa7fc0061,0xdca33629,0x1bd400fd,0x224200cb}},	//   ngıc, лачи, коля, _hekk_
  { {0x7afb2061,0x26c0154b,0x7eb60015,0x3ebf0012}},	//   flut, _olio_, _كمسؤ, _flut_
  { {0xbf160015,0xdbd2007c,0x3ead0079,0x9409000a}},	//   _أورب, müür, _goet_, וּפֵ
  { {0x63b5005c,0xc8661eaf,0x2cac24a7,0xed57125c}},	//   zyzn, нтни, _todd_, _пот_
  { {0xd6fb014e,0x2918362a,0xb866002b,0x3ead0079}},	//   ृष्ठ_, öra_, راخو, _zoet_
  { {0x6441002e,0x290c0061,0x7afb0012,0xa3c10065}},	//   ðlim, rmda_, blut, ्ज़ा_
  { {0xf8030010,0x7d1a0035,0xfa360015,0x88c40046}},	//   ычын, _hits, _أراد, dměň
  { {0x8e20008f,0xa2c4000b,0x7d1a362b,0x6aa60123}},	//   вiк_, रसन्, _kits, ökfu
  { {0xf76f0086,0x6604005c,0xf9930135,0x26c023ac}},	//   جای_, _dzik, _תרס_, _elio_
  { {0x58f70008,0xf76f0087,0x27f30057,0x78b50030}},	//   _רצון_, _هاي_, čané_, özve
  { {0x7d1a0020,0x57fb000a,0xb7fb000a,0x32640850}},	//   _lits, _מלוו, _מפות, лтув
  { {0x645a0656,0x2242311f,0x26d9362c,0xddc9362d}},	// [71b0] ótic, _dekk_, érou_, _obeš
  { {0x9028008f,0x3ebf11bc,0x8fe7006b,0x938b0004}},	//   ецца_, _slut_, нцед, _есма_
  { {0xa8570008,0x64470024,0x75d5002b,0x3ead362e}},	//   תיבה_, maji, _سيگا, _poet_
  { {0x2242002e,0xa75b000a,0x7e6200cb,0x6447362f}},	//   _gekk_, לדבר, ggop, laji
  { {0xf2040010,0x31350054,0x3ead08cf,0x7d1a3630}},	//   _бяро, _јегр, _voet_, _bits
  { {0x64473631,0x71d6000a,0x91ba000a,0x0000006a}},	//   naji, _יורד_, _חמשי,
  { {0xd498000a,0x747c000a,0x7cf60045,0x672d013f}},	//   תכות_, פנהג, vârt, _čajo
  { {0x644700e8,0x628d31c8,0x539c000a,0x1dd2000b}},	//   haji, ndao, ליוו, _देवत
  { {0x8d740087,0x7d740015,0x2d58004a,0x44380034}},	//   _مالا, _مالط, _пить_, ybr_
  { {0x644716d3,0x7afb3632,0x5d170015,0xd20a004c}},	//   jaji, slut, _أبرز, ולפֿ
  { {0xf0920008,0x38ca0086,0x66040030,0x6f1b0573}},	//   בני_, بايی_, _szik, _kiuc
  { {0x8c3c0064,0x6d591126,0x8e2000ce,0x869a011e}},	//   _doğu, orwa, вiй_, фтот_
  { {0x958301d9,0xb8950029,0x41d0000b,0x95991398}},	//   аляе, _للإع, _सेंस, нтру_
  { {0x764600df,0x39560008,0x99d4002b,0x395f008c}},	//   saky, _ישנם_, _حتما, muus_
  { {0xccf20008,0xa7fc0061,0x97280015,0xa2d6006e}},	//   יכך_, rgıc, _كثيف_, نيست
  { {0xd5b20018,0x26c0003f,0x6aa92215,0x3f8e001a}},	//   _نفع_, _ulio_, njef, æfum_
  { {0x4223000d,0x64470213,0x224200cb,0x395f3633}},	// [71c0] рдув, baji, _vekk_, nuus_
  { {0x888c00b2,0x7ae4016f,0x8c3c0064,0xf55b0008}},	//   ּראַ, čiti, _yoğu, _קדימ
  { {0x7d1a0084,0x75240111,0x5457000a,0xe457000a}},	//   _rits, _huiz, _בסין_, _בייט_
  { {0x444403c2,0x67232acd,0xa3c1000b,0x6f093634}},	//   _he_, _munj, ्छर_, _chec
  { {0x44443635,0x7d1a3636,0x6b830034,0x395f01be}},	//   _ke_, _pits, ewng, juus_
  { {0x8cf30010,0xfd0f0015,0x66d6003d,0x44443637}},	//   азіц, يجو_, kško, _je_
  { {0x8cb3005d,0xbc890015,0xa5bb0125,0x9b940015}},	//   _अवरो, عضهم_, rcói, البت
  { {0x44443638,0x66d62fd7,0x237a01c2,0xfaef0015}},	//   _le_, dško, _mppj_, يثي_
  { {0x66d600df,0xf2d301e4,0x8c3c0064,0x20c4007c}},	//   eško, יעה_, _soğu, _töid_
  { {0x6c4a0029,0x7d1a09f2,0x4df50010,0x6aa90183}},	//   _آلاف_, _uits, _сяст, ajef
  { {0xb0b70008,0x08f70015,0xf806006b,0x6e470123}},	//   דפיס_, خريب_, ъчин, _örbä
  { {0x44441bb4,0x64470049,0xda650002,0x89a60015}},	//   _ae_, waji, _ماهي, _لإتم
  { {0x44443639,0xb4d70029,0xa9540010,0x6447363a}},	//   _be_, نغست, _склі, taji
  { {0xa4e4008f,0x75240111,0x4444363b,0xe4e40033}},	//   аўск, _duiz, _ce_, аісн
  { {0xe7950086,0xa3cd000b,0xd91b000a,0x32670033}},	//   _مايک, _शेख_, _קוול, ктав
  { {0x4444363c,0x6447363d,0xf2c42b41,0x6d4b0034}},	//   _ee_, saji, асун, ysga
  { {0x44440b7c,0x8cb3005d,0xe2f80036,0x628d0125}},	// [71d0] _fe_, _अवलो, теті_, rdao
  { {0x4444363e,0x25b923bb,0xc0340054,0xff530015}},	//   _ge_, mysl_, инуј, لخص_
  { {0xce330086,0x15f40086,0x6e9506b3,0xa5c7001a}},	//   لواک, _مسیح, лижу, _fróð
  { {0xf77300b2,0x6d59005c,0x26d90007,0x629d003e}},	//   יקע_, trwa, niso_, _unso
  { {0x22492514,0xee38042b,0x4444363f,0x6d4b0012}},	//   maak_, тні_, _ye_, usga
  { {0x44443640,0x395f00f2,0x40342551,0x55bc000a}},	//   _xe_, vuus_, _верс, ומדו
  { {0xdce00024,0xfc640063,0x6f090e18,0x6c54005e}},	//   _apmē, ръчн, _thec, ртіє
  { {0xf4140008,0x395f00f2,0xc207000b,0xc334000a}},	//   ספק_, tuus_, _शराब_, בוק_
  { {0x99dd0057,0x291c0085,0xae0f000b,0x26d93641}},	//   raňo, _biva_, ़ेशन_, diso_
  { {0x61fd0f1b,0x6aa600c0,0xe73907c1,0x3156000a}},	//   _mysl, ökfr, нео_, ניתן_
  { {0x395f022d,0x75243642,0xf092000a,0x69c90030}},	//   suus_, _suiz, זני_, szee
  { {0x66d60085,0x6ef8016e,0x44443643,0xb5fb3644}},	//   rško, líbr, _se_, rgán
  { {0x44440440,0x75243645,0x64453646,0xef1f002a}},	//   _pe_, _quiz, _behi, ężyc_
  { {0x67230375,0x97c50015,0x64450045,0x291c0123}},	//   _tunj, _متعم, _cehi, _giva_
  { {0xb5fb03c0,0x7ae400bd,0xd3b5007a,0x44443647}},	//   lgál, čitv, асть, _ve_
  { {0x16660001,0x9f9b0020,0x52de000b,0x44443648}},	//   _свим, _määr_, नचेस, _we_
  { {0x44443649,0xa7fc0061,0x394d16c8,0x11f9002b}},	// [71e0] _te_, ngın, nses_, پولک_
  { {0x7e690467,0x60260010,0x644504de,0xb53b000a}},	//   _acep, уджа, _gehi, _רגיש
  { {0xe8d6000a,0xa78c004f,0x0000006a,0x0000006a}},	//   נוער_, ֽאדֹ,   ,
  { {0x71260015,0x64450061,0x394d364a,0xbd6a1f5c}},	//   _مرسل, _zehi, kses_, ерке_
  { {0x463b0053,0xdcb10092,0x4d730015,0x763b004c}},	//   גענע, _bỏ_, مطور, גענג
  { {0x55770053,0x0b8a0608,0xc213000a,0xdfcf002b}},	//   רעסן_, есии_, _להר_, _کيف_
  { {0xb5fb00dc,0xd0070268,0x291c364b,0x394d364c}},	//   egál, _бере_, _riva_, eses_
  { {0x8c3c0064,0xd7f80011,0xdc54002b,0x2615000b}},	//   _coğr, ugăm_, _چراک, नेडी_
  { {0x8c3c01e2,0xc27b0008,0x26d904ed,0xcb070029}},	//   _doğr, גרפי, viso_, ديين_
  { {0x22490079,0x28860054,0x4c78000a,0x6b8d002a}},	//   zaak_, ућив, _שָּׁ, łaga
  { {0x644511d3,0x394d1e0f,0x29020024,0x00f7000a}},	//   _rehi, ases_, ēka_, רזים_
  { {0x2f970053,0x6445013c,0xe80a000b,0x645a001a}},	//   אכטן_, _sehi, हेगा_, ótin
  { {0x25bf0014,0x76b80238,0x1af7000a,0x656f0618}},	//   ául_, уляр_, _גמאל_, utch
  { {0x8387056d,0x833500af,0x656f364d,0x0000006a}},	//   лыбе, ингх, rtch,
  { {0x77920074,0xd6d10806,0xa3bb002b,0x64450b8b}},	//   _ایجا, _وقت_, راسر_, _vehi
  { {0xc2c50029,0xa6ab0225,0xb5a70238,0xa6fb000a}},	//   جيري, _سابق_, _брой, _אִ֖י
  { {0x64450020,0x60f90892,0x22490161,0xa382007c}},	// [71f0] _tehi, вная_, raak_, õõra
  { {0x61fd0057,0xd1b80015,0x22492fa3,0xa3d5045f}},	//   _vysl, دافا_, saak_, _вооч
  { {0x3e350015,0x800710cb,0x61fd002a,0xc1040015}},	//   لفار, учае, _wysl, حولي
  { {0x66f7005d,0xcf880010,0x8db5005e,0xb147002b}},	//   ीतिक_, ысуд_, ислі, _میرم_
  { {0xa2ba005d,0xada50146,0xc05b005e,0x6da5364e}},	//   _एकत्, ралл, _пів_, рила
  { {0x6b55006b,0x394d007c,0x25d8004f,0x9ce70138}},	//   атих, vses_, נוגן_, ыцел
  { {0xeab10029,0x749c0008,0xfaa5004a,0xdcb10016}},	//   قعة_, תיופ, иако, _vỏ_
  { {0x394d20e9,0xc334000a,0x8e480015,0x628f11e8}},	//   tses_, זוק_, _ملفك_, _jaco
  { {0xf1b20053,0xf27c0008,0xa9250004,0x394d364f}},	//   ַסט_, תרחש, јдол, uses_
  { {0xb8f20029,0x3f980026,0x718c000a,0x394d07fc}},	//   يكيب, _yrru_, תְהַ, rses_
  { {0xd7ee0015,0x394d0aff,0xf7450054,0xb5fb0030}},	//   ِكٍ_, sses_, јемо, sgál
  { {0x89d60086,0x066e0053,0xd4910092,0x49d9004a}},	//   اویر_, ראַך_, ồn_, _идею_
  { {0xcb12013a,0xa969006b,0xa7fc0061,0x04b60033}},	//   _ולא_, _рила_, lgıl, асвя
  { {0xa50a1079,0xd4f6004a,0x79ca004f,0x89ca004f}},	//   тега_, рямы, _שֶׁ֔, _שֶׁ֤
  { {0x98f40029,0xb7d90015,0xb7d6002b,0x628f24a8}},	//   _اثنا, _جوغا_, _پويا_, _baco
  { {0xd1320029,0x8e200138,0x0000006a,0x0000006a}},	//   قمر_, вiн_,   ,
  { {0x225d005c,0x6906001a,0x41270190,0xdb03006f}},	// [7200] ówka_, iðen, иото_, lynó
  { {0xe3ba009e,0xbebd0091,0x55bb000a,0xa5bb04e6}},	//   _або_, _liūd, _סמיו, rcót
  { {0x628f04ed,0xb4c2000b,0x3d09000b,0x7e260162}},	//   _faco, ंसी_, ितने_, адеж
  { {0x539b013a,0x27760053,0xad660029,0xfe720015}},	//   _סיכו, יגען_, لاته, تدئ_
  { {0xdd920015,0xc8780061,0xfa900061,0x7d7802be}},	//   توش_, liğe_, çümü_, امتر_
  { {0xcb540015,0x61430658,0x3cd3005e,0x0000006a}},	//   منتظ, _фера, ожіс,
  { {0x69dd002c,0x9f06002b,0x7b05001a,0xcc490015}},	//   úsen, _نوآو, róun, اؤهم_
  { {0x02b60008,0x5a340063,0x8f370008,0xdee6012f}},	//   יהֶם_, щнит, _כאלו_, _тоби
  { {0x8d2a0036,0x63bc0843,0x6e930015,0x99830015}},	//   _розв_, hyrn, _بلقا, قليو
  { {0xc1730008,0x2007005c,0x8c660086,0x99d30029}},	//   קחת_, żnie_, _خطرن, غتيا
  { {0x627e005c,0xbb860029,0xeb9a0004,0xe811000b}},	//   _złoż, _خلاي, _јие_, डेला_
  { {0x7bdb0008,0xfaa30a3e,0x6f023650,0x98ab01ec}},	//   _בקבו, _махо, nloc, īcā_
  { {0x628f0590,0x99340031,0x99f6005e,0x6f02006f}},	//   _raco, _افتت, _тяжі, iloc
  { {0x19bb000f,0x399b000a,0x397b000a,0xc8780061}},	//   _במדב, _שיגד, _סטונ, fiğe_
  { {0x628f001c,0x6f022dc7,0x322b02a3,0xe3170058}},	//   _paco, kloc, візм_, لبرب
  { {0x798b0026,0x6f020011,0x1b7b004c,0x4733006e}},	//   _ysgw, jloc, כטלע, _بروز
  { {0x5187297b,0xc1050002,0xf194004a,0x90550033}},	// [7210] шува, موري, оить, йвац
  { {0x89370053,0xa7fc0064,0x3168000d,0x6f023651}},	//   ירמע_, ygıl, јшто_, eloc
  { {0x33950196,0xff530015,0xb608013f,0xde350033}},	//   _الجز, تخذ_, _tuší, бэль
  { {0x139a0053,0x539a00f3,0xc332000a,0x44310bba}},	//   _עברע, _עירו, _מוט_, lcz_
  { {0x127a0053,0x6b9a0012,0x66c60030,0xdb03002a}},	//   _גארע, _artg, _jóka, zynó
  { {0x8c4205b3,0xf538004f,0xfbc502ed,0x44313652}},	//   пеше, סטור_, йбло, ncz_
  { {0xde670063,0xd47c000a,0x5458000a,0x627e002a}},	//   _възп, דאול, בסון_, _włoż
  { {0x3a980080,0xa7fc0064,0xb5fb0030,0x1dd20065}},	//   атью_, rgıl, rgáj, _देकत
  { {0xe8f90146,0x627e002a,0xda640067,0x0c8702ed}},	//   лли_, _ułoż, زايي, _выем
  { {0xdb03002a,0x66d600bc,0x7739006b,0x78a900af}},	//   tynó, mški, лямс_, уког_
  { {0x30fa000b,0xa088000a,0x3cfa004c,0x7c94002b}},	//   ्ततः_, בְרִ, _עלענ, _بشقا
  { {0x0f7a0053,0x66c6002e,0x5b15049d,0x4431002a}},	//   נארב, _bóka, _умет, ecz_
  { {0x59c40029,0x6608005c,0x2efa000a,0xdddb0091}},	//   _ويمك, ędko, רִיב, _lauž
  { {0x66d60007,0xb9040033,0x2dda004c,0xd83b0033}},	//   iški, _дзік, אַלב, _рэд_
  { {0x78a3003c,0x97350018,0xb8d40015,0xc3060021}},	//   _innv, _اعتص, _بتنش, مبرو
  { {0xc8780064,0x86463162,0x395f0327,0x66d62647}},	//   riğe_, _униж, orus_, kški
  { {0x955604b6,0x463b0053,0xe297085d,0xa5bb09ae}},	// [7220] _اخبا, _געפע, щат_, scór
  { {0xb4660124,0xb4db0251,0x51b90010,0xdfcf002b}},	//   _укол, ssàr, шыся_, کيم_
  { {0x61ef3653,0x644e3654,0xc8da004c,0x66eb002a}},	//   _excl, mabi, נקעט, iękn
  { {0x644e3655,0xb0560086,0x91e602bf,0xf4130008}},	//   labi, _گپست, _гоме, _מפת_
  { {0x1dd2005d,0x3e6b002b,0x7c660015,0x26c23656}},	//   _देखत, اجمی_, ماثل, ikko_
  { {0xd5770008,0x644e3657,0xdb09002c,0x361b0135}},	//   מתנה_, nabi, ľnýc, אונד
  { {0x91830023,0xdb090227,0x395f1996,0xe453004f}},	//   _tệp_, žnýc, erus_, פֶס_
  { {0x539b000a,0xeb970054,0x644e0390,0x3202008c}},	//   ריקו, сић_, habi, _kyky_
  { {0xa3df005d,0xd91a3658,0xd90d002b,0x6d91001a}},	//   _देन_, льо_, چین_, rðaá
  { {0xd90d0086,0xab2a02e1,0xf8af0015,0x89330015}},	//   نین_, _божа_, ّةَ_, أعيا
  { {0x38330010,0xda7a0063,0x395f013c,0xd4910016}},	//   янэр, _бял_, arus_, ồm_
  { {0xb5fb03d9,0x6aa200da,0x76ab01c5,0x443304f6}},	//   lgái, _unof, утов_, _sfx_
  { {0xb5fb002d,0x8afb000a,0xd7c7002b,0x644e3659}},	//   ogái, _גלאז, لویه_, fabi
  { {0xb5fb002d,0x19e7000a,0xe4e7005e,0x644e365a}},	//   ngái, _ל֥וֹ_, сімн, gabi
  { {0xf8db0008,0x1877000a,0x76d50015,0x241901b0}},	//   _תחומ, _העור_, _ويتض, ровы_
  { {0xcb37000a,0x42750033,0x66d60091,0x656601c2}},	//   מאלי_, ўгас, yški, bukh
  { {0xdce2002c,0x644e365b,0x11380015,0xe4eb002b}},	// [7230] dvoľ, babi, مثلث_, _معده_
  { {0x764f005c,0x11540010,0x90550036,0x746b006b}},	//   lacy, якую, івец, _срив_
  { {0xdea10086,0x301b0015,0x7415002b,0x22400030}},	//   ویسی, اتذة_, _گوگا, bbik_
  { {0x57fb0008,0xd7fb0053,0xa2b3005d,0x395f1634}},	//   נלאו, נהאל, _इकट्, yrus_
  { {0x9cf50036,0x74150086,0xfd110015,0x629a01c0}},	//   озді, _دوگا, وجت_, ábož
  { {0xd01b0063,0x66d61573,0xe1ff002a,0xab3503ae}},	//   _бфб_, rški, _obóz_, охиј
  { {0x764f005c,0x66e40030,0x0000006a,0x0000006a}},	//   kacy, lőke,   ,
  { {0xf9890015,0x395f1e15,0x644e365c,0x49790033}},	//   لنبي_, trus_, zabi, асоў_
  { {0x644e01e2,0x7e64002d,0x395f365d,0xdab60015}},	//   yabi, óipe, urus_, تهيت_
  { {0x212b003e,0x2dd80015,0xf7710031,0x395f365e}},	//   _much_, _طبقة_, واج_, rrus_
  { {0x644e3604,0x06ea0146,0x212b0125,0x8bc7131f}},	//   vabi, имок_, _luch_, _усад
  { {0x98aa0048,0x224b08b8,0x6f030045,0x26c2008c}},	//   āmām_, _neck_, înch, ukko_
  { {0x26c200f2,0xa50a00a4,0x7afb1005,0x644e365f}},	//   rkko_, иема_, mout, tabi
  { {0x2eb6014e,0x7ae93660,0x7afb3661,0xf7451208}},	//   _अक्त, lnet, lout, _деко
  { {0x212b0bcf,0x644e3662,0x36e9002b,0x690f02de}},	//   _auch_, rabi, _گروپ_, røed
  { {0x212b00b8,0x7ae93663,0x31600656,0x75d60015}},	//   _buch_, nnet, triz_, _ويغا
  { {0x224b0708,0x7ae93664,0x29053665,0x644e3666}},	// [7240] _deck_, inet, olla_, pabi
  { {0xd5e0005d,0xf8a5002b,0x7ae933a7,0x34b30015}},	//   _पेयज, رک_, hnet, _يميز
  { {0x290510d0,0x212b00b8,0x7f860021,0x93c30045}},	//   illa_, _euch_, تلان, ţări
  { {0x57ca0053,0x7afb0152,0xeef50010,0x2eb9000b}},	//   סמײַ, jout, пячэ, _आवृत
  { {0xddc8005c,0xcd330029,0x3f86002c,0x7afb0743}},	//   _żołn, وروب, ňou_, dout
  { {0x764f005c,0x31230036,0xab94005e,0x2007002a}},	//   zacy, _одяг, зикі, żnia_
  { {0xf76704b6,0x7ae900b8,0xbc670087,0x7afb0079}},	//   _تا_, fnet, زمين_, fout
  { {0xeaf70086,0x29053667,0x7afb3668,0x7ae922c2}},	//   يريت_, ella_, gout, gnet
  { {0x764f0111,0x68fa0011,0xef17005e,0x4ce61092}},	//   vacy, totd, _єму_, _джаб
  { {0x1d0a010f,0xb17b0053,0x764f002a,0x66d60091}},	//   _тези_, סטיר, wacy, išku
  { {0x660d0014,0x66e40f87,0x8ca7005d,0xa09b00a3}},	//   _szak, zőke, चारो, בייט
  { {0x29053669,0xd6db366a,0x7afb366b,0x0000006a}},	//   alla_, рто_, cout,
  { {0x764f0050,0xe9cf0086,0x672401c2,0x0000006a}},	//   racy, _لغو_, _diij,
  { {0xd5b8008f,0x212b1212,0xf7720015,0x66e40030}},	//   іся_, _ruch_, _قاع_, vőke
  { {0x212b0041,0x57f303f1,0x98a30001,0x439400d8}},	//   _such_, _општ, _ције, марс
  { {0x25a600bd,0x66e400dc,0xb8820089,0x83f8004a}},	//   _šole_, tőke, řídi, цесс_
  { {0x660d0064,0xd52d0092,0xf8ad002b,0x41c70033}},	// [7250] _uzak, _dựn, _شکی_, цёва
  { {0xcf9b1cf5,0x7aed002c,0x8fc700e6,0x7ae90820}},	//   ије_, čati, يزان, znet
  { {0x80bc000b,0x7afb0957,0x69c000a9,0x764d01c2}},	//   _एवरे, yout, hyme, _keay
  { {0x23fa0008,0x7982005c,0x33fa0008,0xc7b3000f}},	//   _להתא, _opow, _להתנ, ובע_
  { {0xaaa9000b,0x2905366c,0xed44005e,0xdca5366d}},	//   कासक, ylla_, дніп, зали
  { {0x91ba0008,0xccfb0001,0x6c350029,0xe53c000a}},	//   _המשי, шће_, أفغا, סתור
  { {0x447c00b2,0x7e64002d,0x7afb366e,0xd0fa000b}},	//   ינגע, óipc, tout, ्तरण_
  { {0xfbd00074,0x66e400dc,0xe7fe000b,0x7ae00091}},	//   خته_, zőkb, _उड़ा_, gimt
  { {0x69c00026,0x29050144,0x2a620030,0x79650015}},	//   gyme, tlla_, ókba_, أطعم
  { {0x18690001,0x2905366f,0x66c60030,0x40b6000a}},	//   љани_, ulla_, _póko, ִּיל_
  { {0xb8e3005d,0xd62a0080,0x07a5022a,0x7ae93670}},	//   _एक_, йоне_, чанн, pnet
  { {0x6a940036,0xa5c2001a,0x6b7a000a,0x0000006a}},	//   _оріє, _þókn, _לרענ,
  { {0x6b50002d,0x28f9005e,0xa9a507f7,0xd6cf0058}},	//   _tógá, _ледь_, _хилд, اقُ_
  { {0xe617004a,0x2a6d007c,0xddc90183,0xdb030030}},	//   ядя_, lgeb_, _obež, gynö
  { {0x03a30080,0x7cf60011,0x083a0053,0x68e13671}},	//   ниро, târz, _פעקל, mild
  { {0x2a6d0020,0x2c5f003d,0x61e93672,0x1dab000b}},	//   ngeb_, lādē_, _žela, चमात
  { {0xdb0a00dc,0xa2cd000b,0xa6e2001a,0x0000006a}},	// [7260] ínés, _सतर्, æðue,
  { {0xb4660892,0x759b000a,0x41030ee7,0x68e13673}},	//   _экол, _פסיג, езув, nild
  { {0x94bb0008,0xdee6005e,0xdfcf0015,0x69c03674}},	//   _המית, пожи, هيك_, zyme
  { {0x25a02b50,0x68e13675,0x3f9e3079,0xaf490058}},	//   _kril_, hild, _átum_, تشكل_
  { {0x4c9405c4,0x68e13676,0x729b000a,0xe29b000a}},	//   дилс, kild, _הסכס, _השכר
  { {0xeb4a02db,0xdce20073,0x0000006a,0x0000006a}},	//   бчик_, puoč,   ,
  { {0x79820050,0x68e10064,0xf65f0134,0xd4910016}},	//   _spow, dild, mhæv_, ồi_
  { {0x66c6002e,0xaf5b000a,0x68e13677,0x78b802b9}},	//   _bókm, _לכלכ, eild, _sovv
  { {0x39140080,0xeaaf0015,0xddc900bc,0x68e13678}},	//   ммир, اعى_, _zbež, fild
  { {0x2d570008,0x68e1002e,0xd90e0086,0x69c03679}},	//   _משמש_, gild, دیت_, ryme
  { {0xdc3b01e4,0xa09b0053,0x7c3b000a,0x67d4005e}},	//   _העבר, זייט, _התבס, фону
  { {0x6906002e,0xcb8b000a,0x6b850015,0xfa54009a}},	//   iðei, _לְדֹ, _تشكل, _آراگ
  { {0x7982005c,0x18a6367a,0xa2a0000b,0x2b400085}},	//   _upow, _надм, _ऑफ़्, ćicu_
  { {0x99dd0089,0x65600125,0xb8f40015,0xf53f3076}},	//   raňt, ámha, _تكتب, rpå_
  { {0x187b0008,0x987b009d,0xa87b0008,0xd6d90015}},	//   _הטוב, _האוט, _האור, _ووتش_
  { {0x97c50015,0x0000006a,0x0000006a,0x0000006a}},	//   _تتهم,   ,   ,
  { {0xc2c4003b,0xa6e3001a,0xb5fb0030,0x6e290012}},	// [7270] ريكي, öðus, ggát, _rgeb
  { {0x3fc9002b,0x66f2003d,0xdb030003,0x0000006a}},	//   يدای_, māka, lynô,
  { {0x2fc700a7,0x66f20024,0x6d49003e,0xdfd10015}},	//   áng_, lāka, _swea, خيا_
  { {0xde58005e,0xd356000a,0x7d1d0030,0x0e340033}},	//   заці_, _קירי_, _éssz, енцю
  { {0x7e870007,0xacf90127,0xfe700115,0xdcf90015}},	//   _įspė, онду_, ادم_, يرتش_
  { {0x2fc70023,0x4e180086,0xddc90045,0xc57c000a}},	//   ơng_, ستند_, _aceţ, צרות
  { {0xfc460089,0x5e450015,0x3f91002a,0xddc900bc}},	//   _říci_, _يَسْ, _uszu_, _ubež
  { {0xcf920008,0x2d9f003e,0x0378000a,0x68e11db8}},	//   _בטל_, _true_, פתחת_, wild
  { {0x2f180146,0x89a9005e,0xac27367b,0x7c870880}},	//   _хоть_, іков_, _ефек, _нуже
  { {0x9f88002e,0x57e90080,0x68e1367c,0x66f2003d}},	//   _kóða_, ждом_, uild, dāka
  { {0x68e101e2,0xc0520008,0x7b47002b,0x2c5f003d}},	//   rild, כזי_, _رئال, rādē_
  { {0xabfa000a,0x1bfa000a,0xc4c9000a,0xdce20061}},	//   _והער, _ולעב, _דג_, otoğ
  { {0x68e115ff,0x66f20024,0x15ba0033,0x7afc0030}},	//   pild, gāka, цыны_, _írta
  { {0xa25b0016,0xa3df000b,0xe8f801f3,0x89340058}},	//   _xlôv, _देह_, _елі_, _أعنا
  { {0xe8520086,0x141a0015,0x29160015,0x96fa0015}},	//   _شنيد, زيرة_, _تقود_, _وعبر_
  { {0x66f20024,0x130a0010,0x06f60015,0x257602de}},	//   bāka, інай_, _تستج, pæl_
  { {0xf1de005d,0x74f60029,0x7bc30107,0x2128002b}},	// [7280] _नेशन, _يأخذ, hynu, سيای_
  { {0xdcfb016f,0xa3df000b,0x25bf0012,0xf06302ed}},	//   _osuđ, _देव_, äule_, ккуп
  { {0x78fa004c,0xd6d7009a,0x0000006a,0x0000006a}},	//   קלעפ, _رویش_,   ,
  { {0x27330092,0x7ed50010,0x6700000b,0x539b000a}},	//   _mãn_, нічч, ैतिक_, _ויטו
  { {0x471b0053,0xb5fb367d,0xe2ca002b,0xdc390061}},	//   קונג, lgár, _هوگو_, _açıd
  { {0x236500bd,0x4095049d,0x25d7000a,0x2bba0015}},	//   šlje_, _прст, וונן_, قاعة_
  { {0x6023008f,0x66f20024,0x9f88002e,0x44380034}},	//   _адра, zāka, _góða_, icr_
  { {0x5fdb000a,0xbae30033,0x63a10123,0xb4bb000b}},	//   _וחלק, кцый, ålni, _अक्_
  { {0xadba0029,0x225d005c,0x645e367e,0x828b000a}},	//   _بهذا_, ówki_, _odpi, חְיֶ
  { {0xc0a9000a,0x66f2003d,0xb5fb0030,0xa4f8000b}},	//   ִירָ, vāka, zgás, ंकोच_
  { {0x1bf20231,0x69c600cb,0xda6f01b7,0x656601c2}},	//   _अखिल_, økeb, _ия_, erkh
  { {0x66f20024,0x25a600bd,0xec13002b,0x59d9000b}},	//   tāka, _šola_, _شوند, _बेकर
  { {0xceb30008,0x99d30015,0x25bf0045,0xdbe90065}},	//   דיר_, _لتوا, âul_, टपॅड_
  { {0x66f20048,0xf76f0086,0x2615000b,0x61e907c4}},	//   rāka, دای_, नेगी_, _želo
  { {0xa3df021e,0x66f2003d,0x25ad0045,0x6566128f}},	//   _देश_, sāka, ţel_, arkh
  { {0x2bb6005d,0x32640805,0xdb18000a,0x4428008b}},	//   _अपना, ктув, לֵּך, ьцям_
  { {0xa3df005d,0x52080015,0xb1150684,0xb5fb0030}},	// [7290] _देर_, ِيقُ_, емаш, rgás
  { {0x2ec7014e,0x3959001a,0x2fcb0021,0x43950659}},	//   लस्त, ássi_, يباً_, _заос
  { {0x6455367f,0x66c6001a,0x4814000a,0x2007001a}},	//   mazi, _bókh, תַּן_, æni_
  { {0x7c3a20d3,0x64553680,0xa25b0003,0x7d0a0079}},	//   _aftr, lazi, _clôt, elfs
  { {0xdd940010,0xfd480010,0x0eb800a2,0x6d440045}},	//   кацы, дзік_, بالغ_, ţian
  { {0x645502d7,0xd13e0050,0x8b95025f,0xe057002b}},	//   nazi, żące_, ерич, _آیات_
  { {0x780d005d,0x0c360029,0x6d420045,0x66e40030}},	//   _हरेक_, ركية_, apoa, dőkn
  { {0xa3c2005d,0xda650015,0xdd950033,0x64553681}},	//   ्नत_, راعي, _пабы, hazi
  { {0x64553682,0xe8ca000b,0x7bce0012,0x68ef0077}},	//   kazi, िसूच, _übun, écdo
  { {0x6455003f,0xb8810057,0xa7fc0061,0x5745004a}},	//   jazi, _číse, ygıt, нноб
  { {0x64553683,0xc5e9000a,0xd0f8004f,0x628d005b}},	//   dazi, _פד_, ומזת_, keao
  { {0xeaae0010,0x7ac42229,0x27330016,0x65600030}},	//   _ёй_, _исче, _vãn_, ámho
  { {0xfa560086,0x38ca002b,0xa9c70015,0x79a40054}},	//   _سرنگ, زایی_, _تزاو, _арје
  { {0xbebd00df,0x6d59003f,0x2bb6000b,0x182a002b}},	//   _siūl, iswa, _अपमा, _فقهی_
  { {0x63830c5b,0xa34a006b,0x66e62c63,0x07a50974}},	//   лгра, язва_, _пока, _чайн
  { {0x3d16000b,0x66f2003d,0xa7fc0061,0x443a2f8e}},	//   _पीने_, māko, rgıt, _wfp_
  { {0xe1ff002d,0x65960015,0x66f2003d,0x66e40030}},	// [72a0] _scór_, _أجبر, lāko, lőko
  { {0x645502d7,0xc0590191,0xc1060029,0x15fb000a}},	//   cazi, дії_, رواي, _מהפע
  { {0x66f20024,0xb4cc000b,0xc2090643,0xbe66002b}},	//   nāko, लसी_, צה_, فهاي
  { {0x481600b2,0xddc00089,0x66c6002e,0xaff70015}},	//   ײַבן_, _zemř, _bóki, رفنا_
  { {0x7e27005e,0x6d590012,0x6da30719,0xe8df0016}},	//   ніша_, gswa, лица, ýớc_
  { {0xdb0a001a,0x6f030045,0x0000006a,0x0000006a}},	//   eyfð, încr,   ,
  { {0x7ac6005f,0x1a66002b,0xb4fb000a,0xa3c2000b}},	//   еспе, فیای_, הפסי, ्नि_
  { {0x7e530029,0xc333000a,0xbb830015,0x0f7b000a}},	//   _منفص, נוח_, اليي, _מאלב
  { {0x66e40014,0x6d59003f,0xa7fc0061,0xf2d3000a}},	//   tőkn, cswa, ygıs, טעה_
  { {0xa3c2005d,0x61db0008,0xdce200bd,0xada90029}},	//   ्ना_, פקיד, oroč, _تدفق_
  { {0xa3df005d,0x64553684,0xe9cf002b,0x36d50004}},	//   _दें_, vazi, لغی_, вонр
  { {0x7c460024,0x212a002d,0x5694006d,0x6455003f}},	//   ūrrē, _libh_, гают, wazi
  { {0x64553685,0x7ae20160,0x0000006a,0x0000006a}},	//   tazi, _imot,   ,
  { {0xdb1f002e,0x66f20024,0xdce20227,0x7ae20227}},	//   ðvör, bāko, kroč, _hmot
  { {0xa7370029,0x64553686,0x67d4005e,0x291e001a}},	//   _كثير_, razi, _шоку, mmta_
  { {0xdce2018c,0x92940010,0x92590004,0x2007002a}},	//   droč, ласц, ќаат_, żnik_
  { {0xe1f00015,0x94ab0054,0x64553687,0x96fc000a}},	// [72b0] مسك_, _етна_, pazi, _מלהת
  { {0x25d8000a,0xdb18008c,0x91640015,0xa2240015}},	//   _רוזן_, lyvä, اهله, ارِه
  { {0x6d440011,0x6d403688,0x291e3689,0x04640033}},	//   ţial, _atma, imta_, _стым
  { {0xf4120008,0x8f340010,0x59b0000b,0x6d59368a}},	//   _כפי_, уецц, जमार, tswa
  { {0x22490375,0x225d002a,0x66f2003d,0x3f870046}},	//   mbak_, ówku_, zāko, ůnu_
  { {0xfebb002b,0xdb18008c,0x657d0353,0x6d59368b}},	//   _کاست_, hyvä, itsh, rswa
  { {0xdb18022d,0xa3d1005d,0x643c0053,0xa2d8005d}},	//   kyvä, वनि_, לעגנ, नोक्
  { {0xeab1003b,0xada6002c,0x22490111,0x656f368c}},	//   شعب_, _slúž, nbak_, kuch
  { {0x61e90a00,0xe9a9002b,0xa3e80157,0x224901d7}},	//   _želj, بگان_, _मेन_, ibak_
  { {0xa3d1005d,0x4d980010,0x656f099c,0x7ae20af3}},	//   वना_, _якую_, duch, _emot
  { {0x366a2d90,0x207c004c,0x656f368d,0x3a750189}},	//   мано_, לאזא, euch, _алер
  { {0x66f20024,0x0bb6000a,0x88bc0046,0xdb01368e}},	//   rāko, _בלעם_, eměd, _orlé
  { {0x3ebf16c3,0xdce2036d,0xc6430015,0x66f2003d}},	//   _mout_, zroč, شَّي, sāko
  { {0x7d03368f,0xb4db0144,0x7ae21223,0x98a6006f}},	//   nons, spàn, _zmot, _zvoľ_
  { {0xe7b20086,0x29070061,0x656f3690,0x316927e5}},	//   _نمود, _ikna_, auch, eraz_
  { {0x23650014,0x212a002d,0x656f3691,0x7d033692}},	//   álja_, _sibh_, buch, hons
  { {0x656f02c1,0x88c50046,0xa2d8000b,0x7d0319ff}},	// [72c0] cuch, aměř, नोग्, kons
  { {0x7d03003c,0xe0430180,0xe424002b,0x4fa60054}},	//   jons, инуи, _مکزي, кизв
  { {0x224900dc,0x3ebf3693,0x7d033694,0x31693695}},	//   bbak_, _bout_, dons, araz_
  { {0xcfa9003b,0xe3570008,0xfe42002b,0xbf650021}},	//   عالم_, _בשטח_, شکری, ادلو
  { {0x916d0092,0x290c0e05,0xf53f17ca,0x7d033696}},	//   _tốt_, ylda_, rvåg_, fons
  { {0x5c73005e,0x7d033697,0xdce21de3,0xddc0002a}},	//   иліт, gons, proč, _zemś
  { {0x3ebf00f6,0x25e9000b,0xc0e30db7,0xc4d3000a}},	//   _fout_, _चेनी_, _торк, שגו_
  { {0xeb970001,0xb998059c,0x49743698,0xf8ca000b}},	//   тић_, евих_, глис, िस्प
  { {0x0d770086,0xeef50010,0xc8780064,0x5b230015}},	//   _لینک_, _сярэ, liği_, جفيل
  { {0x52bf014e,0x1be3005d,0xcd77000a,0xbcaa0015}},	//   _एक्स, _केवल_, _בעמק_, _تدرك_
  { {0xdb1800f2,0x656f0012,0x5b360033,0x9cd7000a}},	//   tyvä, wuch, _рэзу, _שובה_
  { {0x7c270014,0x657d0804,0x3169002a,0x3d16000b}},	//   _újra, ttsh, yraz_, _पीते_
  { {0xb8960029,0x8ab7000a,0x3e7d0030,0xfad7004f}},	//   _للشع, _שהדו_, látó_, _בואך_
  { {0xdb1800f2,0x657d28ce,0xc2c5002b,0x62860012}},	//   syvä, rtsh, گيري, _abko
  { {0x656f018b,0xdfe1005d,0x49170008,0x68e83699}},	//   such, _गेंद_, _שקול_, midd
  { {0xc8780064,0x66c6001a,0xc2c50040,0x656f1e9a}},	//   diği_, _bóku, ديري, puch
  { {0x5215009c,0x3ebf00da,0xa158369a,0x0000006a}},	// [72d0] удат, _rout_, кату_,
  { {0xc8780064,0x0efb000b,0x897b000a,0xe0d30015}},	//   fiği_, एक्स_, ורמצ, جزر_
  { {0x672d003f,0x212a002b,0xf0270004,0xa818000a}},	//   _kiaj, ريمی_, тќан, תֵּי
  { {0xf773000a,0x31690061,0x8d790054,0xa3c2000b}},	//   שקף_, praz_, ељку_, ्नर_
  { {0xadbc0036,0xde58005e,0x7d03369b,0x3ebf00aa}},	//   мацi, тачі_, tons, _vout_
  { {0x629d0014,0x3ead002a,0x6932002a,0x9b45009a}},	//   _haso, _wnet_, _złeg, هنتو
  { {0x3ebf038d,0x7d03116e,0x69c6003c,0x629d198e}},	//   _tout_, rons, øken, _kaso
  { {0x66eb005c,0xb8820089,0x1a65002b,0x5e440015}},	//   ięks, říli, ایشی_, _نَفْ
  { {0x660d003f,0x629d369c,0xbdf5023e,0x1be3000b}},	//   _nyak, _maso, _спај, _केरल_
  { {0xe8f6004a,0x9b8b0015,0x629d369d,0x66160535}},	//   ллы_, _يخاف_, _laso, _rzyk
  { {0xab940036,0x660d0064,0x28d9005d,0xfbd00029}},	//   _вихі, _ayak, योगि, _وتم_
  { {0x1db7005d,0x96660010,0x28b1000b,0x4e170065}},	//   _आपात, ыкме, जाहि, _तराई_
  { {0x7ae9002c,0x672d0375,0xc964005e,0xe9800033}},	//   miet, _diaj, _ввій, _мацi_
  { {0x7ae93270,0x64a60001,0xa3c2000b,0x6abb00bc}},	//   liet, ћава, ्नल_, ljuf
  { {0xd8380010,0x82f60033,0x2905369e,0x629d369f}},	//   _рэч_, гчац, mola_, _baso
  { {0x290500e8,0x7ae936a0,0xe29736a1,0x629d0a35}},	//   lola_, niet, лас_, _caso
  { {0xe049002b,0x2167292e,0x3f8a01d7,0x708601f3}},	// [72e0] چشمه_, лити_, _spbu_, лгаз
  { {0xc8780064,0x7ae936a2,0x290536a3,0x0000006a}},	//   tiği_, hiet, nola_,
  { {0xa856000a,0xb4c2000b,0xe3b200c3,0xa2e61c8c}},	//   ריעה_, ूसी_, _طرد_, _бонд
  { {0xc8780064,0x7ae90024,0x92b60029,0x66c6002e}},	//   riği_, jiet, _إحدا, _tóku
  { {0xd436000a,0x7ae936a4,0x290536a5,0x6c5436a6}},	//   ְטֵי_, diet, kola_, аклу
  { {0x2f1500c0,0x629d005c,0xa1ab000a,0xd47a004c}},	//   råga_, _zaso, _אֱלִ, גאַל
  { {0x290536a7,0x68e80ef2,0x7ae936a8,0x66c60052}},	//   dola_, vidd, fiet, _jóks
  { {0x61e914b1,0x69c6003c,0x5a340254,0x7ae936a9}},	//   _želi, økeo, шнит, giet
  { {0x2bb6005d,0x62840026,0x88ea0004,0x9c85002b}},	//   _अपवा, ifio, еќна_, _چشمه
  { {0x39420024,0xbd5b000a,0x290536aa,0x7de7005e}},	//   īks_, _נכבש, gola_, _смуг_
  { {0x37730010,0x7ae936ab,0xa6f5004a,0x3942003d}},	//   быўс, biet, изош, ūks_
  { {0xfa360029,0x2f5b000a,0x68e836ac,0x4bfb000a}},	//   _إراد, עדכנ, sidd, _אלבס
  { {0x672d0656,0x290536ad,0x629d36ae,0x0000006a}},	//   _viaj, bola_, _raso,
  { {0x660d003f,0x66c6002e,0x89db000a,0x6892002b}},	//   _vyak, _bóks, _אחדי, _ایدئ
  { {0xa3df014e,0xa3d40036,0x083b0053,0xe4e4022a}},	//   _देख_, борч, _טעגל, сіян
  { {0x8c1b0008,0x6d55002a,0x0000006a,0x0000006a}},	//   תולי, _łzam,   ,
  { {0xdcfb016f,0x42e40015,0xb06b36af,0x66e40030}},	// [72f0] _upuć, حسِّ, ереж_, zőkk
  { {0x3d0e005d,0x9584005c,0x629d003f,0xe1f000a2}},	//   ितों_, żący, _waso, أسف_
  { {0x629d00f2,0x8e550010,0x7a2b0064,0x5f950661}},	//   _taso, атлі, _kötü, риет
  { {0xa283002b,0x7ae900da,0x25a90061,0xa6fb000a}},	//   _دیرو, xiet, _kral_, עִ֑י
  { {0x69c6003c,0x6440005c,0x7ae936b0,0xe80b000b}},	//   økel, śmie, viet, _सुना_
  { {0x7ae90050,0xdca52cd9,0x41de000b,0x161a000b}},	//   wiet, раки, _नेटस, नेटर_
  { {0x2fc700c0,0x7ae936b1,0x645736b2,0xfc64006b}},	//   ängd_, tiet, _mexi, съчн
  { {0x2bb6005d,0x69c900f2,0x66f2003d,0x69db0012}},	//   _अपरा, tyee, rākk, tzue
  { {0x8c3c0064,0xc8b5054f,0xd90c002b,0x78890015}},	//   _bağd, асны, کیو_, نَةِ_
  { {0xd1980008,0xf1b2000a,0xa805006b,0xddc00061}},	//   רכזי_, קסי_, изпл, _hemş
  { {0xf0920008,0x7ae936b3,0xdb1f0030,0x62840034}},	//   חני_, piet, ívós, yfio
  { {0x06560010,0x3f810026,0x28d9005d,0x26560054}},	//   штоў, ithu_, योजि, шњос
  { {0x66f2003d,0x290536b4,0x270e0065,0x28a60065}},	//   nāki, pola_, सतौर_, _कोवि
  { {0xccf200b2,0x20f4005d,0xf5070080,0x07a50033}},	//   ַכן_, _आदेश_, инял_, _вакн
  { {0x161a000b,0x230a0015,0xe29f001a,0xa927003d}},	//   नेजर_, نتري_, _bað_, rdžī
  { {0xd7fa009d,0x7a2b0064,0x98140086,0x877a01ac}},	//   _בהצל, _götü, _ابها, _סאפי
  { {0x3f810026,0x628436b5,0xe2970162,0x395f36b6}},	// [7300] ethu_, rfio, шат_, nsus_
  { {0x66c6002e,0x66f2003d,0xe0d736b7,0x28d9000b}},	//   _tóks, dāki, аву_, योचि
  { {0x0eba0033,0x645c36b8,0x200e001a,0x8f7601c6}},	//   куды_, mari, æfi_, рузі
  { {0xdfcf002b,0x644e0012,0x395f36b9,0x645c36ba}},	//   بيم_, lbbi, ksus_, lari
  { {0x2d960146,0xe29736bb,0x40960004,0x66f2003d}},	//   ррес, _тая_, _крвт, gāki
  { {0xfb660001,0xa06a004a,0x31600061,0x9c570054}},	//   ањим, _шага_, msiz_, ашћу_
  { {0x645c072a,0x612b000a,0x3160007f,0x395f36bc}},	//   iari, _יֵלְ, lsiz_, esus_
  { {0x2fc700b8,0x8f9b0135,0x8c3c0061,0x645c36bd}},	//   änge_, _בילי, _sağd, hari
  { {0x645c36be,0x31600061,0x127b004c,0x6ac3006e}},	//   kari, nsiz_, דאפע, تقيم
  { {0x28a6014e,0x645c36bf,0xdbdc0107,0x58d4004a}},	//   _कोशि, jari, lším, соот
  { {0x10370008,0x80370053,0x395f00e8,0xb037004c}},	//   יטים_, יניע_, asus_, יניג_
  { {0x28a6005d,0x31600064,0x645736c0,0xeb97000a}},	//   _कोरि, ksiz_, _sexi, _כדבר_
  { {0xceb300a3,0xe5c403fc,0x395f0034,0x3a73008b}},	//   קיש_, осро, csus_, _флір
  { {0x63f70015,0x3f810034,0x645c36c1,0xacc7004f}},	//   لأزر, ythu_, gari, ֹּךְ_
  { {0x2ba9000b,0x88bb000a,0x66f2003d,0xd3a40004}},	//   किया, _במגז, zāki, ортп
  { {0x66e4000d,0xd7bb000a,0x31600061,0xdbdc0057}},	//   _моја, _יצור, fsiz_, jším
  { {0xe29f002e,0x645c0523,0x765d03cf,0xd13100c3}},	// [7310] _vað_, bari, masy, سما_
  { {0x44990a7f,0xf8b10008,0x765d36c2,0x59b9000b}},	//   _свою_, ּשׁ_, lasy, ेहतर
  { {0x3207005c,0x7ff40015,0x34fc000a,0x2fc736c3}},	//   łny_, يسما, _בהזד, âng_
  { {0x3f81214f,0x92940010,0x265a004c,0x3946008c}},	//   rthu_, _даюц, ָכװא, _otos_
  { {0x6da50191,0xf6780053,0xa2b6000a,0x8c450b97}},	//   сила, שײדט_, _הפרד_, беле
  { {0x66f20024,0x01360008,0x395f0020,0x656f0aaf}},	//   rāki, _לרשת_, vsus_, irch
  { {0x765d2351,0x66e400dc,0x3946016e,0x2259007c}},	//   kasy, sőki, _atos_, _kesk_
  { {0x395f0005,0xc3340008,0x1a68002b,0x765d01c2}},	//   tsus_, חוק_, لیمی_, jasy
  { {0xf991003b,0x645c1645,0xd2b8000a,0x44240016}},	//   سبة_, yari, שלחת_, ̀m_
  { {0x71d80008,0x645c1702,0x395f36c4,0x4dd40058}},	//   יוחד_, xari, rsus_, _بتفس
  { {0x395f1fca,0x69d60061,0x2139219f,0x394601d7}},	//   ssus_, _üyen, _lush_, _etos_
  { {0x2b81005c,0x765d04a7,0xc4c9000a,0x4ac40015}},	//   móc_, gasy, _אג_, _ويلق
  { {0x7afe1043,0xaa36000a,0xceb2000a,0xa96906a6}},	//   épte, _הטנק_, פיך_, _сила_
  { {0x984b0080,0xe802000b,0x2ec4000b,0x2ed4000b}},	//   _ряда_, _रुका_, _वक्त, _दत्त
  { {0xaadb000b,0xd6d7002b,0x645c36c5,0x656f3501}},	//   _बताक, _گويش_, rari, arch
  { {0x31600064,0x96e50015,0x213936c6,0x645c36c7}},	//   tsiz_, _وثيم, _bush_, sari
  { {0x8066022a,0xb1160015,0x645c36c8,0x225936c9}},	// [7320] йваж, مورغ, pari, _desk_
  { {0x316001e2,0x20ca0015,0x98c9004f,0x90e50369}},	//   rsiz_, دبري_, נֶּ֥, يسلن
  { {0x4444003e,0xbbb6005d,0xa85a0053,0xdbdc0247}},	//   _if_, _अपेक, רדעכ, tším
  { {0x539b0008,0xe8e00092,0xad660115,0xa77a004c}},	//   _עיכו, _thủy_, ماته, טרעפ
  { {0x2cea005f,0xa3c2000b,0xdbdc01c0,0x78140065}},	//   лько_, ्नक_, rším, _डर्क_
  { {0x765d01e2,0x3ea00089,0x659b015b,0x66eb0046}},	//   zasy, žit_, טינק, yřko
  { {0x66f20024,0x444436ca,0x765d0061,0xc29a000a}},	//   lāku, _mf_, yasy, ָיִך
  { {0x656f0176,0xc3330008,0xdee60001,0xcff70643}},	//   yrch, הוה_, _уоби, _הצלה_
  { {0x444436cb,0x38c80074,0x66f20048,0x19ba0029}},	//   _of_, لادی_, nāku, اطعة_
  { {0xdd8f0086,0x50db0053,0x656f0264,0xf1b3000a}},	//   _سوم_, ָקטא, vrch, פסת_
  { {0xa3e8014e,0x765d2351,0x30fb000b,0x48a7055f}},	//   _मेल_, tasy, ्वतः_, стым_
  { {0x444436cc,0x4b37000a,0xdb0e008c,0x8674005e}},	//   _af_, _הראל_, äjäk, плює
  { {0x656f1d04,0x765d36cd,0x394602f2,0x7d0a00aa}},	//   urch, rasy, _utos_, oofs
  { {0x897b0008,0x765d0035,0x98a30bb9,0xe4e40033}},	//   _ערוצ, sasy, _ниче, пісн
  { {0x765d0035,0xcc3b004c,0xdceb0045,0xed5f0091}},	//   pasy, רעלט, lugă, ėžia_
  { {0x444436ce,0x2ba9014e,0xd2580010,0x213936cf}},	//   _ef_, किता, йцу_, _push_
  { {0x02440015,0x6440002a,0x7afc0030,0x444436d0}},	// [7330] سَلَ, śmia, _írtu, _ff_
  { {0x88bc0089,0x3982002e,0xa0a70054,0x444436d1}},	//   změn, iðs_, љшал, _gf_
  { {0x6235000d,0xa2270086,0xc4d2000a,0xbfab0033}},	//   _мену, _گرده, _חגי_, ытае_
  { {0x66f20024,0xbbe9002b,0x6aa20125,0xe8b5000b}},	//   bāku, یرغم_, _naof, _अच्च
  { {0xa69c004c,0xbebd0091,0xa227002b,0xf0470033}},	//   טשאפ, _siūs, _درده, _гэбо
  { {0x4f5b0115,0xf1b2000a,0xab990015,0xdb09006f}},	//   _مجرد_, _קסם_, لخبر_, ľníc
  { {0xfd1000b0,0xaed5005e,0x8c3c0061,0xdb09013f}},	//   رجه_, _довш, _sağc, žníc
  { {0x527c0053,0x66f20024,0xcf9201d8,0xa3bc000b}},	//   ָנזא, nākt, _קטן_, _आपस_
  { {0x69d601e2,0x4995005e,0xcdf40015,0x99dd013f}},	//   _üyel, ішит, _فأكث, ybňu
  { {0xe6c5016f,0xdd0e0064,0x18690180,0x6f0b36d2}},	//   _češć, mışl, јани_, logc
  { {0xa3e8005d,0x6d440011,0xb8d1000b,0x66f2003d}},	//   _में_, ţiat, _ऑफ_, zāku
  { {0xd62a0175,0x444436d3,0x6008004f,0x60c7007f}},	//   ионе_, _sf_, מִרְ, _lojm
  { {0xdd0e0064,0x45d30033,0x19940033,0x8937012c}},	//   nışl, доўс, _наця, _اعصا
  { {0x1cb9000a,0xf771002b,0x6aa2002a,0x8c3c0061}},	//   ׁמָע, _قاب_, _zaof, _kağa
  { {0xd372003b,0x889a000a,0xd3b9005e,0x7e690dd2}},	//   ظهر_, _כבסי, буті_, _odep
  { {0x8c3c0064,0x25b502c1,0xdd0e0061,0x66f2003d}},	//   _mağa, ñaló_, kışl, tāku
  { {0x64a6008f,0x463b0053,0x60ea36d4,0x02ca000b}},	// [7340] _дапа, _דעפע, амам_, _रवीन
  { {0x66f20024,0xe8e00092,0x78a336d5,0x0ef4000b}},	//   rāku, _thụy_, _janv, ेक्स_
  { {0x66f20024,0xee3a36d6,0xa4b7000a,0xcf460033}},	//   sāku, ане_, _וליה_, цней
  { {0x2fc700c0,0x0f290015,0x88bc0046,0x24980144}},	//   änga_, مثنى_, eměl, lerm_
  { {0x22650089,0x78a30123,0x7d0a042f,0xdd96006e}},	//   řský_, _oanv, tofs, تجاع
  { {0x6d49002f,0x361b0053,0xa7fc0061,0xafe628e5}},	//   _dtea, בונד, rgız, _догл
  { {0xdfd20070,0x3d09005d,0x66f2003d,0x3f67098a}},	//   _غير_, ाक़े_, nāks, _миро_
  { {0x24980111,0x78a300f6,0xff070004,0x996607d9}},	//   herm_, _aanv, _деск_, отол
  { {0x249800dd,0x78a315c8,0x0000006a,0x0000006a}},	//   kerm_, _banv,   ,
  { {0x236500bd,0x3982002e,0xd90d0086,0x78a31ee1}},	//   šlji_, rðs_, هین_, _canv
  { {0x2a660063,0x907b000a,0x38c8002b,0x5cc90015}},	//   _дълг, סטטי, لاگی_, _ابقَ_
  { {0xd6d9005c,0x3ea636d7,0xb9c60015,0x8f9b004f}},	//   ół_, ndot_, _وتشه, ביטי
  { {0x3ea60024,0x2d8600dd,0x26070036,0x66f2003d}},	//   idot_, ntoe_, ючог, vākt
  { {0x3ea6022d,0xc953000a,0x98a70045,0x96340033}},	//   hdot_, _חמס_, _vină_, ьняц
  { {0xb92300a2,0xa7530015,0x92c70da4,0x24190033}},	//   _تفوي, _قضيت, ощад, совы_
  { {0x290c0024,0xdd0e0061,0x236d1cb2,0x57270058}},	//   loda_, yışl, čej_, _برتق
  { {0x60c70ea1,0xe1f00015,0x2d8600aa,0x91750033}},	// [7350] _pojm, نسك_, jtoe_, ягац
  { {0x3ea600f2,0x66f20024,0x55bc000a,0x31780015}},	//   edot_, sākt, _כמחו, تحفظ_
  { {0xc49a0008,0x6d4936d8,0x649a000a,0xa0c40058}},	//   _השתת, _stea, _הסתד, بيلو
  { {0xfba9014e,0x539a01e4,0xd7bb0053,0xdd0e0064}},	//   किसम, _פירו, יצבר, tışl
  { {0xdd9b059c,0x2229002b,0xa282002b,0x867c000a}},	//   рше_, _دزدی_, _سیلو, שרדו
  { {0x113a0008,0xece80036,0xaaa3005d,0xdd0e0061}},	//   _לתשל, оділ_, _खोजक, rışl
  { {0x600802bf,0x5458000a,0xf36b000a,0x69c6008c}},	//   _днём_, חסון_, ׁדַּ, äken
  { {0x93fc0008,0x1a65002b,0x88bc0046,0xdb080058}},	//   ילוי, سیتی_, směl, يزيه_
  { {0x394d038d,0x99150010,0x7c8705ab,0x78a3006f}},	//   upes_, зьні, _муже, _panv
  { {0x394d36d9,0xedb40015,0x3c440015,0x290c36da}},	//   rpes_, _تحفظ, _يَقِ, goda_
  { {0x9f45022d,0xaa950036,0x3cfa0053,0xd70a0088}},	//   _älä_, _нижч, _פלענ, йное_
  { {0x66da0063,0x8c1a000a,0x394d36db,0x0000006a}},	//   сьор_, _הועי, ppes_,
  { {0xf3f70092,0xaa3a000a,0x8908004c,0x9a3a000a}},	//   ộng_, _התנח, כּל_, _התנק
  { {0x1dac000b,0x27f60046,0xc9f40015,0x7afb36dc}},	//   चितत, ádná_, _تسمع, lnut
  { {0xe8d600a3,0x69c600cb,0x7416009a,0x0000006a}},	//   _מוסר_, økev, سورا,
  { {0x36360086,0x66f20024,0xf65f02de,0x27f8006f}},	//   _عربس, rāks, skær_, úrne_
  { {0x867b0008,0xe0da0063,0x66f20024,0xdb0100c0}},	// [7360] _הרפו, бва_, sāks, _irlä
  { {0x3d05005d,0x7afb01c9,0x8855000a,0xb9c4000a}},	//   शकों_, hnut, לֹ֣א_, וּעַ_
  { {0x645e36dd,0x7afb049e,0x643b000a,0xc43b000a}},	//   _iepi, knut, _לעינ, _לתיי
  { {0x4ea302bf,0x645e0061,0x3ea6003d,0x290c00b3}},	//   ерша, _hepi, udot_, zoda_
  { {0x1ea90029,0x2ca50334,0x7afb36de,0x645e36df}},	//   تالي_, _bald_, dnut, _kepi
  { {0xeaf6014e,0x361b0053,0x2d860161,0x93f6000a}},	//   ुक्त_, זונד, rtoe_, ּצֵא_
  { {0x290c2064,0xbc670021,0xeb470033,0x273a0073}},	//   voda_, سمين_, пчык_, _kūne_
  { {0x645e36e0,0x7afb016f,0x6ffb000a,0x290c002a}},	//   _lepi, gnut, _הפלג, woda_
  { {0x2ca50134,0x290c36e1,0x61e436e2,0xed5710b2}},	//   _fald_, toda_, nzil, _нот_
  { {0x645e0048,0xf98f00e6,0x290c0a6d,0x4ddb000a}},	//   _nepi, ابي_, uoda_, _החמו
  { {0xd7f70080,0x290c36e3,0xa08b000a,0x6b560067}},	//   зуя_, roda_, זְכִ, _رضائ
  { {0xaa570029,0x5b570053,0x501b0008,0xcb670010}},	//   _فلما_, _זשאן_, מויו, _хаце_
  { {0x690f02de,0x61e40030,0x66e40030,0x290c36e4}},	//   røer, jzil, tőkr, poda_
  { {0x29370053,0xdb0100b8,0x61e436e5,0x248d0085}},	//   _זאגן_, _erlä, dzil, đemo_
  { {0x026b0010,0x7e62003f,0x98a30054,0xd91b000a}},	//   йшай_, kaop, _чије, _הוגל
  { {0x381701e4,0xba3d0089,0xd7fb000a,0x82a40033}},	//   _מקום_, jdůl, _להול, ншуе
  { {0x3ced005d,0xf1940a61,0xc694004f,0x00e5009a}},	// [7370] _अगले_, нить, _טאק_, وتئی
  { {0xd8b9004c,0x66f2003d,0x91e40054,0x7afb0c5d}},	//   ֿצײכ, lākp, хође, znut
  { {0x75d5002b,0x988b004f,0xdb08039f,0x7afb016d}},	//   _ريگا, מָאֵ, _ardí, ynut
  { {0xa9230007,0xbdf503ae,0xadf502d9,0x7d180013}},	//   ėžim, мпеј, мпеш, elvs
  { {0x71a40033,0x69c6008c,0x1df80033,0xdca51cd9}},	//   _заўз, äkel, пецы_, дали
  { {0x88bc0089,0xdb030046,0x8e08005e,0x91ba000a}},	//   směj, rvní, чнів_, _ומשי
  { {0x786900dc,0x7afb03ed,0x2ca536e6,0xe8ee0138}},	//   _jövő, tnut, _vald_, _шлi_
  { {0xfe6e0086,0x61220152,0x2ca500b8,0xe9d9107c}},	//   _نگه_, rôle, _wald_, жки_
  { {0xd6e0002a,0x6f190034,0xc8c8000b,0x68ef0144}},	//   ółmi_, mlwc, ाउंट, ècdo
  { {0x6f190176,0xe1ff0030,0x7afb36e7,0x0000006a}},	//   llwc, _adók_, snut,
  { {0x7afb0057,0xfb85002b,0x7d040125,0x443a01d7}},	//   pnut, _زدای, éise, _rgp_
  { {0x6ab40010,0x645e36e8,0x5ba40138,0x443a36e9}},	//   _псіх, _sepi, _яруз, _sgp_
  { {0x186923e4,0x69c600cb,0x628d0034,0x628a0030}},	//   _дали_, øket, dfao, őfok
  { {0x2a7f36ea,0x6aa936eb,0x8d76000a,0x61e40061}},	//   lgub_, ldef, וגשו_, vzil
  { {0xdc450007,0x645e0046,0x04430a24,0xe36600ce}},	//   jūči, _vepi, тесн, ькви
  { {0xd808000a,0x6aa936ec,0xe57a01b7,0x0000006a}},	//   _מִפָ, ndef, _дзи_,
  { {0x8c3c01e2,0xa0a60033,0xc0d6002b,0x79890079}},	// [7380] _bağl, маад, ويرب, ntew
  { {0x6f190034,0x6ff60015,0x7989002a,0x61e43522}},	//   elwc, وساط, itew, rzil
  { {0x6f190026,0x6fd50010,0x8c3c0064,0x7fd5005e}},	//   flwc, ніцц, _dağl, ніці
  { {0xf42a022d,0xfe720015,0x79890079,0x5576004f}},	//   _enää_, ئدا_, ktew, ֥עַן_
  { {0xdd900087,0x6aa936ed,0x7e53005e,0x7e6204d1}},	//   اوت_, ddef, твіє, raop
  { {0x6aa912e2,0x6f190034,0x69c607c2,0x4c9300ce}},	//   edef, alwc, äkem, вишс
  { {0x8f750036,0xf7670086,0xbb470029,0xbfd6002b}},	//   _путі, _جا_, ولون_, _غيرع
  { {0xf96a0080,0xff24002b,0xaae60067,0xcf260058}},	//   орой_, _سبزی, بستو, _آرسي
  { {0x7989020a,0xf53f00cb,0x8c3c0061,0x2c760058}},	//   gtew, rvåk_, _yağl, _يُرس
  { {0x41bb0053,0x6ab90034,0x6e3b36ee,0x7e6036ef}},	//   קציע, _enwf, _zgub, _hemp
  { {0xd83802c6,0x7e6024b9,0xdc3b000a,0xa8a30033}},	//   ječe_, _kemp, _ועבר, трык
  { {0xd83800bd,0xa3d2000b,0x7e602415,0x69c600cb}},	//   deče_, वहन_, _jemp, økes
  { {0x7e600d25,0x8cc2005d,0x94ab006b,0xf5e7005e}},	//   _memp, लापो, отва_, фінм
  { {0x28a6000b,0x7e600861,0x5dcb004f,0x777a03a0}},	//   _कोचि, _lemp, חֶלְ, putx
  { {0xa295008f,0x3d16005d,0x6d4036f0,0xa87b0008}},	//   наві, _पीछे_, _luma, _ואור
  { {0x8c3c01e2,0x92940010,0xa2940138,0x0000006a}},	//   _sağl, касц, касі,
  { {0x26d900df,0x914b006b,0x6d4036f1,0xd5bb005e}},	// [7390] ūros_, ючва_, _numa, _єси_
  { {0xf0fb000b,0x6e3b0034,0xa11500c3,0x628d0034}},	//   ्वेद_, _sgub, روات, sfao
  { {0x8cc2000b,0xe610002b,0xc7a9000a,0x4ee70033}},	//   लानो, _مشی_, ּׁנָ, мідз
  { {0x6d4000b6,0x7e6001c2,0x2455002b,0x5e5800ce}},	//   _buma, _cemp, _تنگس, диця_
  { {0xbdf80031,0x6d4036f2,0x657d3069,0x200f002a}},	//   ورها_, _cuma, nush, łgi_
  { {0x515a000a,0x6d4036f3,0xee38005e,0xdcbb02ed}},	//   _מכשו, _duma, фні_, юще_
  { {0xeb910086,0x657d003f,0xfc64006b,0xd6e0002a}},	//   اظت_, hush, тъчн, ółki_
  { {0x657d003f,0x9b920087,0x7e600049,0x3219008c}},	//   kush, اليت, _gemp, _kysy_
  { {0x6d40025c,0xee840010,0x6aa936f4,0xbd440058}},	//   _guma, _шыро, rdef, _لنقي
  { {0x47c50080,0xa3df005d,0x7b310024,0x657d007c}},	//   ебов, थना_, _jāuz, dush
  { {0x69c6003c,0x6d400012,0x7e6000aa,0x798936f5}},	//   øker, _zuma, _yemp, stew
  { {0x3a540033,0x68e6003d,0x7e6036f6,0xfaa700ce}},	//   _акцё, īkda, _xemp, _ішен
  { {0x58d50b03,0x15ba0010,0x99840015,0x4a720015}},	//   _подт, чыны_, _للنو, _صُور
  { {0x09f60008,0xcdf60008,0x98a20004,0x26d936f7}},	//   _אמנם_, תמשי_, _бише, akso_
  { {0xd83810ca,0x141a0015,0x0876004c,0x232a0de9}},	//   teče_, سيرة_, _טעסט_, зови_
  { {0x97d8003b,0x8c3c0064,0x07d80015,0x657d1bd0}},	//   _تظهر_, _rağm, _تذهب_, bush
  { {0xd335008f,0x7e6036f8,0xa3bc000b,0xe0da006b}},	// [73a0] тэры, _remp, _आपक_, пва_
  { {0x6d400375,0x7e6036f9,0x80a60015,0x63bb0046}},	//   _ruma, _semp, عمان, ácný
  { {0x6d4036fa,0x4f7a004a,0x7e6036fb,0x14d7000a}},	//   _suma, ящая_, _pemp, _נוטל_
  { {0x040b0023,0x6d4000b6,0x9daa006b,0x9c7c0046}},	//   _lượn, _puma, зъка_, _mlče
  { {0xe2a6001a,0x7e60008c,0xd657000a,0x98a70535}},	//   öðun_, _vemp, גינת_, _winę_
  { {0xeb18000b,0xa1160015,0x10160033,0x93fa000a}},	//   दत्त_, _أوست, _зьбя, ּלֵי
  { {0xc4d30008,0x1e96287f,0x6adb000b,0x9103047d}},	//   רגו_, _прар, बसूर, _спре
  { {0x6d4035c1,0x539b000a,0xda660015,0x501b000a}},	//   _tuma, פיפו, رابي, _זולו
  { {0xb997005f,0x828b0008,0x99630010,0x80c4000b}},	//   евых_, הְיֶ, лтэл, रापे
  { {0x4973008f,0xc173000a,0xcd97000a,0x657d007c}},	//   ыльс, נחת_, _אדמת_, vush
  { {0x5cf50036,0x273a0007,0x9cd7000a,0xd6d10015}},	//   _ряту, _būna_, _רובה_, لقد_
  { {0x7bdb0008,0x09e60180,0x657d0044,0xcf93000a}},	//   _מקבו, _поен, tush, נטר_
  { {0x1af70053,0x55070010,0xceb30008,0xe9730002}},	//   _אמאל_, ечва, איר_, _مهند
  { {0x62860123,0x93c30045,0x657d36fc,0x321936fd}},	//   _acko, ţămi, rush, _rysy_
  { {0x25bf0011,0xad1b0008,0xa7860015,0xb5fb001a}},	//   ţul_, פולר, _أشتو, maám
  { {0x41e7009e,0xe7b7000a,0xc2c50015,0x3219008c}},	//   ніза, _טהור_, خيري, _pysy_
  { {0x8b030046,0x60ce0034,0x41e702a3,0x69c6008c}},	// [73b0] ířil, _bobm, хіва, äkeh
  { {0xd5640063,0x52140036,0x10070457,0x710b005e}},	//   _стъп, удут, няем, їхав_
  { {0xc104003b,0xb5fb00dc,0xf536000a,0x7fb9006e}},	//   دولي, zaál, _שנתי_, بهار_
  { {0xd3560008,0x2f740015,0x877b000a,0x6d5e002a}},	//   _שירי_, اطلس, לאבי, ćpan
  { {0xee2e033f,0xada50139,0x6da507ec,0xc27a004f}},	//   рн_, талл, тила, _קרשי
  { {0xd378010b,0xeb991466,0x8b9502ed,0x3ea90160}},	//   šće_, дик_, врич, žat_
  { {0xe4ac000a,0xeab10015,0xc10400c3,0x8027009a}},	//   לֹהָ, لعة_, _صوفي, _سرآم
  { {0x7b440086,0x9f34005e,0xb80b000b,0x0b190015}},	//   دئول, _бесі, _सुगम_, بقعة_
  { {0x69c6003c,0xf4000011,0x2f1500c0,0xceb2039e}},	//   økep, ăţii_, sågs_, _דין_
  { {0x8e380015,0x2903007c,0x80c4000b,0xa3c3000b}},	//   _أسفر_, õja_, राये, ्हा_
  { {0x040b0016,0x3878001a,0x66e60822,0xaa950058}},	//   _vượn, órra_, вона, _للاث
  { {0x0000006a,0x0000006a,0x0000006a,0x0000006a}},	//     ,   ,   ,
  { {0x040b0023,0xa2b5000b,0x38ca002b,0x8aa8000a}},	//   _tượn, _उफ़्, سایی_, _רֹעֶ
  { {0xe9d8009e,0x64a60001,0x3afa003d,0x37c50015}},	//   _які_, њава, rūpe_, _ليتف
  { {0x58f60008,0x6386006b,0x67d20004,0xccf2000a}},	//   _במסע_, ъгва, _воју, בכם_
  { {0x06f60074,0xe29701e1,0x0000006a,0x0000006a}},	//   _جستج, кас_,   ,
  { {0xe717000a,0xd24f0015,0x6143006b,0xa5260328}},	// [73c0] _בחקר_, تنق_, иета, _имид
  { {0x62330001,0x6aab0843,0x00e30033,0x9ffa00c3}},	//   ређу, _lagf, ажун, وراء_
  { {0xb47900b2,0xdd1c002c,0x44770053,0x33d50033}},	//   _אָרי, _nášh, _בעיל_, _біят
  { {0xad660029,0x6aad001a,0x0000006a,0x0000006a}},	//   ناته, _óafh,   ,
  { {0xcd2a0086,0xbe850015,0x5de6006b,0xdee30004}},	//   وستن_, اجمو, ъжда, шоци
  { {0x60260033,0x2b5e01c2,0x25d7000a,0x8d1300ce}},	//   _адга, _pwtc_, כונן_, адії
  { {0x8bc30063,0x9c450033,0xb4fb000a,0xa4fb000a}},	//   исъд, ухіл, ופסי, ולסט
  { {0x2b550086,0x1eaa0015,0xd83800bc,0x4a53006b}},	//   ایند_, _غازي_, ječa_, акъс
  { {0xbd8a0074,0xc333000a,0x4938004a,0x62840034}},	//   _زنان_, סוח_, нзию_, igio
  { {0xd7fa0784,0x88bc0046,0x6f021837,0x2ee60c0c}},	//   дум_, jmět, lnoc, lhof_
  { {0x88bc0089,0xb07b000a,0x6f0204a5,0x907b000a}},	//   dmět, וניז, onoc, וטיי
  { {0x6f02028e,0x5b360002,0x5a430033,0xb3420061}},	//   nnoc, _شعار, _кэша, ıçla
  { {0xe894021a,0xaa87002b,0xcb37004f,0x272b00a1}},	//   _баль, _شنوم_, _סנדק_, hùng_
  { {0xe7b40015,0x7ae21d9b,0xd4980054,0x628436fe}},	//   _ممتد, _hlot, крс_, egio
  { {0x24180139,0x389b000a,0xf7430004,0x249e007c}},	//   воры_, _חיונ, _кејо, õtma_
  { {0x628402d7,0x69d60064,0x75d50086,0x2cac0026}},	//   ggio, _üyes, _ميبا, _ladd_
  { {0x2aea005d,0xc1050115,0x7bd80007,0x2ee60012}},	// [73d0] जोएँ_, هوري, hyvu, dhof_
  { {0x273b0007,0x1bf4000b,0x7ae20144,0x90540054}},	//   _kūno_, ेपाल_, _llot, ивуц
  { {0x291e00f2,0xa3d5000d,0x44f80015,0xe1ff0030}},	//   ilta_, _сонч, _جريج_, _adót_
  { {0x612b0020,0x8f14022a,0xfe700021,0x522701e3}},	//   külg, афіч, قده_, _афга
  { {0xc332000a,0x6aab0034,0xa91d36ff,0x4ab6000b}},	//   _לוט_, _ragf, stži, _अफ़व
  { {0xe7c2000b,0xe80b000b,0x3eba003d,0x4c8400ce}},	//   षमाप, _सुझा_, ēpta_, илів
  { {0xab760015,0x30a4006b,0x7c84008d,0xeb990121}},	//   هموا_, _тряв, руче, хий_
  { {0xdd1c032c,0x7ae2003e,0x88bc0089,0x59850036}},	//   _vášh, _clot, změt, глиб
  { {0xa91d0089,0xd83800bd,0x8d790015,0x7c94002b}},	//   huže, veča_, _سماء_, _چشما
  { {0xe9a80015,0x9783002b,0x8cbb0015,0x88bc0046}},	//   ئدين_, لیته, _تدرس_, dměs
  { {0xc7b80010,0x62840026,0xcb550054,0x25a920f8}},	//   вёў_, ygio, _свећ, _asal_
  { {0xeab00029,0xa91d016f,0xa68309ef,0x291e3700}},	//   _وعن_, duže, блюд, alta_
  { {0x55f60892,0xc6430015,0x5a440033,0xcb12004f}},	//   учну, صَّي, _тэха, _פלד_
  { {0x612b0061,0xdce910cd,0x7ae23701,0x0000006a}},	//   nüld, _oveč, _zlot,
  { {0xdb01001c,0x7d03158b,0x88bc0046,0x69c6008c}},	//   _islâ, inns, aměs, äkev
  { {0xe3550010,0x425512d9,0x612b02ad,0x932602be}},	//   ртрэ, итут, hüld, ارسن
  { {0x612b0014,0x71650029,0x422604f7,0xe1650015}},	// [73e0] küld, لالك, удав, لدلي
  { {0x155b0008,0x6f02002a,0x3ebf01d7,0x61220003}},	//   _רכיב, wnoc, _anut_, rôlo
  { {0xd12f0029,0x2cac0026,0x58f60053,0xd8da004c}},	//   أمل_, _radd_, נצען_, עקער
  { {0x2bb50092,0x7e2a01f3,0x91e607be,0x645c3702}},	//   _ích_, ніла_, _боме, lbri
  { {0x80c4005d,0x865b000a,0x9e65002b,0x78a13703}},	//   रादे, גדני, شانن, kelv
  { {0x7bd800df,0xfbaa0080,0xed570054,0x2ee63704}},	//   tyvu, етий_, ћој_, shof_
  { {0x2d8f0251,0xafe60894,0x645c3705,0xd0f7000a}},	//   atge_, _совл, ibri, _עמלת_
  { {0x7980000c,0x5fbb000a,0x539b000a,0x7d033706}},	//   tumw, _אצלנ, תיקו, anns
  { {0x88bc0089,0xf2d3000a,0xa9670054,0x78a1072f}},	//   dměr, מעה_, гиња_, felv
  { {0x78a13707,0xa3c50065,0xb69b059d,0x0000006a}},	//   gelv, _ऎपल_, gnân,
  { {0x6ecb005d,0xd1170008,0x7ae20034,0x645c3708}},	//   _सचमु, רקיה_, _tlot, dbri
  { {0x7c2500b8,0x8cc2005d,0xa6350036,0x7c2818e1}},	//   ühre, लावो, инні, _izdr
  { {0xd7c70086,0xab63005c,0x612b0548,0x645c2061}},	//   نویه_, ążen, lüle, fbri
  { {0xc9530008,0xa91d016f,0x97a61673,0xacc7004f}},	//   _המס_, tuže, _брил, ָּךְ_
  { {0x612b03ba,0x24190139,0xf76f0058,0x0000006a}},	//   nüle, товы_, _فاي_,
  { {0xddc00089,0x8c1b000a,0xa91d1422,0x41c70033}},	//   _nemů, גולי, ruže, лёза
  { {0x394600df,0x612b00b8,0x645c04ed,0xddc906d5}},	// [73f0] _juos_, hüle, bbri, _odeš
  { {0xd378010b,0x3d0e005d,0x656f0b8e,0x0f0d000b}},	//   šća_, ाकों_, msch, िक्स_
  { {0x656f0b8e,0x9295077a,0x0f35002b,0x351c000a}},	//   lsch, _канц, لکرد, _אוזנ
  { {0x7d1a0005,0x628a00dc,0xde950001,0xd7fb0053}},	//   _akts, őfor, радњ, עהאל
  { {0x656f19f7,0x9e640036,0x78a100dc,0x0e6401c6}},	//   nsch, свід, yelv, скін
  { {0x88bc0089,0xd83800bd,0x656f1f28,0x78a10123}},	//   změr, ječo_, isch, xelv
  { {0x656f00b8,0x612b3421,0xa2dc000b,0x25fc000b}},	//   hsch, rüld, _नवम्, _लेनी_
  { {0x645c02c6,0x2fc7007c,0x656f0c0d,0x78a11d9d}},	//   zbri, ängu_, ksch, welv
  { {0x9c870225,0x72b6000a,0x8d740015,0x656f0079}},	//   _مشاه, בִיב_, _هالا, jsch
  { {0x612b00dc,0x656f237b,0x78a13709,0x7e6b370a}},	//   lülb, dsch, uelv, lagp
  { {0xa91d016f,0x78a1030f,0x00f6000a,0x0b780015}},	//   tužb, relv, שמתך_, _مصنع_
  { {0x656f0b8e,0xa3b9000b,0xf529000a,0x66da006b}},	//   fsch, चिन_, _חץ_, тьор_
  { {0x95830080,0x7ae90d17,0x656f0ec2,0x6b83370b}},	//   оляе, mhet, gsch, lung
  { {0x7afb0007,0x88bc0089,0xf6230036,0x68e80026}},	//   liut, směr, ідро, chdd
  { {0x82f60010,0xe4e50010,0x660d04d4,0x78fa0447}},	//   ачац, сіўн, _exak, _בפסו
  { {0x656f00b8,0x6b830586,0x7546005e,0x645c1717}},	//   bsch, iung, _книз, sbri

  { {0xd6d70086,0x216a0805,0x6b83370c,0x612b0548}},	// [7400] _خويش_, тизи_, hung, züle
  { {0x6b830273,0x3d0f000b,0xf34a0004,0x290500cb}},	//   kung, िवों_, _ипол_, nnla_
  { {0x6b830780,0x747b0008,0x444400dc,0xd47b000a}},	//   jung, _בניג, _ig_, _באיל
  { {0x6b8335d3,0x232a0054,0x3eba003d,0xed5a0b27}},	//   dung, _јоми_, ēpto_, вод_
  { {0x61ed005c,0x6f09016f,0x7ae90d9c,0xce77005e}},	//   czal, _djec, dhet, рбії_
  { {0x6b830f4d,0x612b0064,0x7ae900dc,0x6f092fce}},	//   fung, tüle, ehet, _ejec
  { {0x7afb04ed,0xadf2000b,0x2fc707fd,0x6b83370d}},	//   fiut, _आइकन_, ängt_, gung
  { {0x44440020,0x7c2800bd,0x612b3240,0x64370053}},	//   _lg_, _vzdr, rüle, סאקא_
  { {0x0c760086,0x09060036,0xe1ff370e,0x4444370f}},	//   _نداد, ичом, _león_, _og_
  { {0x444408e6,0xa3b9005d,0x7ae90020,0x672d003f}},	//   _ng_, चिम_, ahet, _shaj
  { {0xe7270036,0x7d18099c,0x7ac60457,0xe0b7000a}},	//   иємн, movs, _всле, בליט_
  { {0x4444015d,0x656f19f7,0x39460007,0x7ae93710}},	//   _ag_, tsch, _tuos_, chet
  { {0xd9540225,0xca970008,0x656f00b8,0x249a01c2}},	//   _انتخ, _כדאי_, usch, _bbpm_
  { {0xa4e4008f,0x656f25bf,0xdb0d00f2,0xdb01307e}},	//   оўск, rsch, äköi, _islá
  { {0x656f3711,0xf7840015,0xa81c005e,0x32670155}},	//   ssch, _العَ, _язкi, итав
  { {0x083b0008,0xf2c40036,0xd2581174,0x883b000a}},	//   _בעול, осун, ицу_, _בתוו
  { {0x6b833712,0x25090086,0x90990063,0xa4d90033}},	// [7410] zung, _مردی_, лват_, _бдпу_
  { {0x7ae900dc,0x3d20000b,0x89eb000a,0xf957000a}},	//   zhet, यतों_, כַבֵ, יסמת_
  { {0x7e6b00b6,0x1eea002b,0x8f680015,0x2ba6000b}},	//   tagp, گونی_, لملك_, _कैला
  { {0xa3d0005d,0xb5fb016e,0xcf44005e,0xdb0104b2}},	//   _वॅट_, mbáb, іній, _oslá
  { {0x44442a56,0x1eea0086,0x612b00dc,0x6e920067}},	//   _yg_, دونی_, rülb, سلوا
  { {0x7d183713,0xd7e60015,0x2fc70123,0xdc98005e}},	//   govs, _فك_, ängs_, ивчі_
  { {0x7e6b00b6,0xee870080,0x7ae93714,0xeeab004a}},	//   pagp, _вызо, thet, _итак_
  { {0x6f1b016f,0x6b833715,0x9f050115,0x2ef50033}},	//   _ukuc, rung, _اورو, _узбр
  { {0xdce90227,0x7ae93716,0x60d505e3,0x8288000a}},	//   _uveď, rhet, _kozm, בְתֶ
  { {0x64450023,0x6b833717,0x7ae93718,0xfce40054}},	//   _nghi, pung, shet, _дођо
  { {0x6d410035,0x7e691104,0xe73a057e,0x7afb0091}},	//   _iila, _keep, лео_, piut
  { {0xe5a60063,0x6f19005c,0xaab40015,0x64453719}},	//   бими, nowc, _وإنش, _aghi
  { {0x6eba000a,0x19940033,0x39900144,0xee32000a}},	//   אזרח, _маця, càs_, ּֽר_
  { {0xdff9005d,0x3a360008,0x6f190026,0x98e50015}},	//   ्पाद_, _פרסם_, howc, _دكتو
  { {0xd3b5005f,0x67550115,0x6f19005c,0x6d41371a}},	//   ость, _اختر, kowc, _mila
  { {0x4444005c,0x23090029,0x61e9005c,0x6f19002a}},	//   _wg_, لتقي_, _żela, jowc
  { {0x80c4005d,0xf1aa0086,0x6f190305,0x9f49006f}},	// [7420] राले, دازه_, dowc, ľkým_
  { {0x6d412411,0x60d50045,0x59ae000b,0x96040065}},	//   _nila, _cozm, _जैफर, रपीट_
  { {0x82360086,0x00190010,0x25fc000b,0xa25b016e}},	//   _گردا, аўцы_, _लेती_, _inôn
  { {0x6d41371b,0x2bbd000b,0x6f19002a,0xddc00045}},	//   _aila, ्मना, gowc, _nemţ
  { {0x7ce60084,0x471b0053,0x6d411640,0xd2b7000a}},	//   _aðra, נונג, _bila, _הלכת_
  { {0xdcb10023,0xb5fb0089,0x5c970010,0x7dc50015}},	//   _cả_, lbác, йкія_, تتمك
  { {0xcec30089,0x6d410375,0xad66002b,0x6f19002a}},	//   áří_, _dila, _گازه, bowc
  { {0x39900251,0xa3b9021e,0xee3a006b,0x6d41371c}},	//   tàs_, चित_, _бнб_, _eila
  { {0xdb1f00dc,0xab63005c,0x7c96006d,0x7d0d0125}},	//   ívás, ążan, _грец, éasc
  { {0xd8f80036,0x19a70063,0x39900251,0x2d570008}},	//   рної_, стъп_, ràs_, _לשמש_
  { {0xf98f0074,0x61300dca,0xb09b000a,0x0000006a}},	//   وبی_, mäld, ניטר,
  { {0xf1bf00dc,0xa91d016f,0xa25b016e,0x6d41371d}},	//   _szám_, ruža, _anôn, _zila
  { {0x2fc700a7,0xda650015,0x858b0138,0xb5fb0de4}},	//   ̣ng_, _ذاني, ыёна_, dbác
  { {0x44270023,0x38c80086,0x96340033,0x612b3513}},	//   _ơn_, _خاصی_, яняц, küla
  { {0x60d51f58,0x78b30046,0x7af90034,0x7b78000a}},	//   _rozm, řevá, _ymwt, יָּצ
  { {0x92590083,0x3fc9002b,0x612b007f,0x0000006a}},	//   раат_, یدای_, düla,
  { {0x60f9008f,0xa3ce005d,0x3ea60604,0xc0470015}},	// [7430] аная_, _शपथ_, deot_, مخاو
  { {0x7e69371e,0x20750033,0x449900f4,0x612b007c}},	//   _seep, ілеў, _твою_, füla
  { {0x2fc70092,0x4427371f,0xdcb10016,0x6d412f4a}},	//   ãng_, _án_, _rả_, _rila
  { {0x52a70029,0x23fa000a,0x8e850015,0xb2a70015}},	//   _اصدق, _כהתא, زلته, _احده
  { {0x6f1910bd,0xd57b000a,0x7e69007c,0xa91d0085}},	//   rowc, אָ֔ר, _veep, dužn
  { {0xe58c000a,0xfbd0002b,0x7e6900da,0xbca50015}},	//   רָאָ, کته_, _weep, زمبي
  { {0xd52d0092,0x7e69007c,0x04dc015b,0x6d413720}},	//   _mừn, _teep, רקול, _vila
  { {0xce940063,0x93fc0053,0x788300dc,0x6d410375}},	//   _насъ, טלוי, kívü, _wila
  { {0x6d41022d,0x44240023,0xdcb10092,0x6c750001}},	//   _tila, ́m_, _tả_, _млађ
  { {0xb9020010,0x99320015,0xe8f9012b,0x1cbb0058}},	//   дзьк, وفيت, рло_, _حارب_
  { {0x628f04ed,0x25a0193d,0xed590085,0x629d3721}},	//   _occo, _spil_, _drže_, _obso
  { {0xc4c90008,0xa91d31f1,0x2ca73722,0x61303723}},	//   _בג_, drže, lend_, mäle
  { {0x27320092,0xc5d60033,0x04b601c5,0x8f1a000a}},	//   háng_, цінь, освя, שורת
  { {0x628f3724,0x1e3a015b,0xd40a0015,0x2ca715f6}},	//   _acco, יגרא, لتزم_, nend_
  { {0xd52d0092,0x7d04002d,0x443e008c,0x613000d5}},	//   _dừn, éisi, ät_, näle
  { {0x03260127,0x2ca73725,0x4424003d,0x8883002b}},	//   ідан, hend_, ām_, _بیگن
  { {0x2ca700ed,0x8e201ff7,0xdb010b12,0xb5fb3726}},	// [7440] kend_, аiн_, _islä, rbác
  { {0x505a008f,0xe0860029,0xddc000bd,0x6ab6005d}},	//   ршая_, تجري, _nemš, _अफ्र
  { {0x232a0191,0xb3760086,0x61300123,0x32460aa1}},	//   _вони_, _بدخش, väld, _менг
  { {0xaec60010,0x479a004c,0x61300012,0x6da6008a}},	//   юбел, ייעס, wäld, жида
  { {0xc27b0008,0x8236002b,0xf8a9000b,0x2ca70043}},	//   _דרכי, _گرگا, क़ाय, fend_
  { {0x6ca30063,0xbca40015,0x2ca727fc,0x55bb000a}},	//   дръж, سمعي, gend_, ימנו
  { {0x82360074,0x28cd005d,0xe7490092,0x7d0d002d}},	//   _درگا, ़ानि, _sẵn_, éasa
  { {0xe043005e,0xbb170015,0x27320030,0xeb33002b}},	//   _інти, يزيا_, nánd_, وريخ
  { {0x6e930029,0xc333011f,0x2ca700b8,0x6f030144}},	//   _تلقا, ווה_, bend_, ènce
  { {0x2007005c,0x2ca700da,0xcce60058,0xac8300af}},	//   źnie_, cend_, _بسري, _огул
  { {0x4c060029,0xc053000a,0x612b0030,0xb5fb0052}},	//   _بِال, וזת_, küln, jaár
  { {0xb9c60018,0x8cc2000b,0xa91d2793,0x8c1b000a}},	//   _وقاي, लाको, vrže, _דובי
  { {0xd6270029,0x6a9b000a,0x0000006a,0x0000006a}},	//   تعدي, _כשאנ,   ,
  { {0x99fb0008,0xa91d0046,0x3959016e,0x47d60015}},	//   _דפדפ, trže, ísse_, _ويشر
  { {0x926b000d,0xd52d0016,0xdb1a3727,0x5b58004f}},	//   ираа_, _cứn, _arté, מֻּד
  { {0xd838010b,0x25b0022d,0x1b7b0053,0x2ca70f55}},	//   ječi_, ällä_, יטלע, zend_
  { {0xd52d0092,0xf1940146,0xfad7000a,0x41e70033}},	// [7450] _từn, мить, קומך_, ціва
  { {0x1601000b,0x51f80033,0x9fe7009a,0x0000006a}},	//   _लेयर_, цную_, يساه,
  { {0xb4e7005d,0x33ab006b,0x2ca73728,0x5f94009b}},	//   पसी_, _тъпо_, vend_, дихт
  { {0x15ff005d,0x2ca70234,0x6130008c,0x8db50033}},	//   _उधार_, wend_, väle, зскі
  { {0xa3b9005d,0xd256000a,0x7cef0013,0xddab029b}},	//   चिव_, _משרה_, _jørg, ртел_
  { {0x11da013a,0x7d760029,0xf1bf0f14,0xac750015}},	//   _החשב, أمور_, _irá_, ساتش
  { {0x8c42000d,0xab63005c,0x447c000a,0xf1bf006f}},	//   неше, ążon, שְׂא, _hrá_
  { {0xdd950010,0x20c9005d,0x05cb005d,0xaac5000b}},	//   _набы, रावध, ामाब, वाइक
  { {0xceb23729,0x2ca720ea,0x2d58005e,0xaa560054}},	//   _אין_, pend_, _мить_, чињу_
  { {0x8bb70015,0x49980033,0x612b0030,0xb08b000a}},	//   _وإضا, ітыя_, züln, ׁנִ֖
  { {0x1601000b,0x0000006a,0x0000006a,0x0000006a}},	//   _लेबर_,   ,   ,
  { {0x99d70015,0x68ea0079,0x6b9c007c,0x6d5b372a}},	//   _وتشا, _elfd, _ärga, _ktua
  { {0x63be04c6,0x69dd007c,0x7aeb003d,0x060702bb}},	//   _srpn, äsed, _ilgt, зняк_
  { {0xa8790053,0x395f26c9,0x6aa908cf,0xae1a000a}},	//   _האַר, mpus_, leef, מורכ
  { {0x9734002b,0x7e7b0085,0x66e606f4,0xe73a04bb}},	//   _يکجا, _odup, _нока, _лек_
  { {0xdb010012,0xb7da000a,0xf1bf001a,0x93430148}},	//   _erlö, _לקצי, _brá_, енсе
  { {0x612b00dc,0xcb12000a,0xf656002a,0xa5f70054}},	// [7460] rüln, גלן_, ążąt_, _нећу_
  { {0x15fb013a,0xf6170008,0x45fb000a,0x612b0030}},	//   _להפע, _מחפש_, _להפג, süln
  { {0x6d5b03af,0xc2c60029,0x09a8000b,0x7c250012}},	//   _atua, _فيدي, _कन्य, ührl
  { {0xf1bf0084,0x2fc700c0,0xee3a364e,0xe357000a}},	//   _frá_, ånga_, бне_, _משטח_
  { {0xb2bb000a,0xaabf000b,0xaac5000b,0x8d630850}},	//   _המכר, _शोधक, वाईक, евче
  { {0xd83800bd,0x6d5b002d,0x7aeb0020,0x612b0061}},	//   seči_, _dtua, _algt, nüll
  { {0xab38372b,0xd52d0016,0xb60600bc,0xa91d00bc}},	//   опку_, _hữn, lošč, ružl
  { {0x6aa9372c,0x0f7b000a,0x612b0012,0xb40d000a}},	//   geef, _לאלב, hüll, ילוֹ
  { {0xe9e601b0,0x612b0a63,0x0000006a,0x0000006a}},	//   яцко, küll,   ,
  { {0x47780036,0x7e7b002a,0x7aeb0091,0x6f02372d}},	//   обою_, _zdup, _elgt, lioc
  { {0x3f780340,0x7cef0293,0x5c5b000a,0xa993002b}},	//   nču_, _sørg, _הדבק, وشیت
  { {0x6f02372e,0x600b000a,0xb606013b,0x0000006a}},	//   nioc, מִכְ, košč,
  { {0x612b00b8,0xd7f80045,0x25580046,0xe8940138}},	//   füll, mbăm_, vělý_, _жаль
  { {0xb97b000a,0x2ed9000b,0x897b000a,0xb4e7000b}},	//   _פרוז, _भक्त, _פרוצ, पसे_
  { {0x28b7000a,0x389b0447,0xc2c5002b,0xa567002b}},	//   _מפגש_, _היונ, ويسي, _کدبن
  { {0x53980036,0xc2990033,0x291e372f,0x72d400af}},	//   явся_, ўках_, lota_, носф
  { {0x867c0008,0x63bc00bd,0x7cef0293,0x30a71206}},	// [7470] _הרחו, avrn, _høre, зрев
  { {0x3cf8005d,0x7cef0134,0x6b830026,0x04670080}},	//   ्चों_, _køre, yrng, _этим
  { {0xc9170008,0x81440067,0x749a000a,0x290c3730}},	//   לחמת_, رنمن, _ויתפ, inda_
  { {0x9f4c00dc,0xfbbd000b,0x6f023731,0x671d000b}},	//   álás_, ्मसम, gioc, नविक_
  { {0x3f780024,0x82d6000a,0x291e3732,0xdd9b006b}},	//   aču_, _חורג_, kota_, сше_
  { {0x69d60061,0x291e3733,0x33292a38,0x6aa90546}},	//   _üyey, jota_, llax_, weef
  { {0xeb99005f,0x612b0061,0xdbf10046,0xc052000a}},	//   ций_, nülm, přím, _יזם_
  { {0xa91d049f,0x61300123,0xcf92000a,0x290c3734}},	//   drža, mäla, _שטן_, enda_
  { {0xe9a90086,0xed580015,0x6aa90d16,0x7d790015}},	//   تگان_, _فشلت_, reef, _ذمار_
  { {0x1e320086,0xd3780085,0xac940004,0x7d043735}},	//   _شکنج, šći_, _пауш, éist
  { {0x395f0011,0xb905000b,0x9056000a,0x16aa2124}},	//   spus_, _नव_, ובתו_, овни_
  { {0x98a20024,0xfb380029,0xe9d1002b,0xd8380085}},	//   ēkā_, _فأنت_, _لغت_, ječu_
  { {0xba740002,0xdce90085,0xa2cc000b,0x7d030125}},	//   _سانت, _cveć, हास्, oins
  { {0x58d40229,0x63550091,0xb60600bc,0x7cef2b0e}},	//   _почт, _sąna, vošč, _føre
  { {0x7cef02de,0xeb93000a,0x15431466,0xda57004f}},	//   _gøre, ךָּ_, терм, ִׁ֑י_
  { {0x39470084,0x99e30264,0xdb01002d,0x7d0301d4}},	//   _hins_, žňuj, _bplé, hins
  { {0x50960001,0x45363736,0xd5af0015,0x067b000a}},	// [7480] дређ, _охот, _نفي_, _ונפל
  { {0xb60600bd,0x26c90085,0xa759000a,0x213a2af8}},	//   rošč, _znao_, ַדְר, umph_
  { {0x4f7a0080,0xdc3c006f,0x7d033737,0x0702000b}},	//   ющая_, _páči, dins, _लगाव_
  { {0xeda60036,0xc7d60053,0x4ea3049d,0xd808000a}},	//   дшко, וועי_, врша, הִנָ
  { {0x290c13f0,0x7bc10034,0x60e90030,0xa91d0085}},	//   ynda_, _arlu, ásmó, ružj
  { {0x2b460026,0xa3e5000b,0x61e4008c,0x2007002a}},	//   _sioc_, बैक_, myil, źnia_
  { {0x612b0020,0xe208005c,0x291e09df,0x2b460125}},	//   külj, _wróć_, vota_, _pioc_
  { {0xf27b0053,0x9f56002a,0x8417000a,0x291e3738}},	//   ֿריש, łgów_, וקצב_, wota_
  { {0x7e970029,0x291e173b,0x7d033739,0x7d040003}},	//   _تنقر_, tota_, bins, éiss
  { {0xfbc60457,0x290c373a,0x0d83005e,0x39470061}},	//   _обзо, unda_, _шлун, _cins_
  { {0x394708e0,0x311f005d,0x290c002e,0xda7a0063}},	//   _dins_, भवतः_, rnda_, _дял_
  { {0x39470084,0xfbd30008,0x6d48373b,0x386e0034}},	//   _eins_, _שתף_, _hida, _wefr_
  { {0x3947373c,0x6d4816d3,0xc9930015,0x291e373d}},	//   _fins_, _kida, _للنظ, pota_
  { {0x612b0061,0x60dc373e,0x6724373f,0x0000006a}},	//   tülm, _norm, _ekij,
  { {0x6d480005,0x98a30001,0xa3470033,0xdb01216b}},	//   _mida, _рије, дэал, _splé
  { {0x612b0064,0x26c9003f,0x41e7017f,0x69c23740}},	//   rülm, _unao_, міза, _kroe
  { {0xda0e005d,0x05790015,0xdce90085,0xde8f0016}},	// [7490] ापित_, _عمدة_, _uveć, hịch_
  { {0x27320cb1,0x60b50015,0xb4270015,0x78ba3741}},	//   mána_, عمائ, _يعدو, ndtv
  { {0xdb1a0782,0x7d033742,0x27320247,0x2d860079}},	//   _artí, vins, lána_, eroe_
  { {0xff250086,0x6d483743,0x9db904ab,0xa7fc0061}},	//   ربای, _aida, зыку_, ybın
  { {0x61f6005c,0x6d48013c,0xa2cc000b,0x27320046}},	//   czyl, _bida, हार्, nána_
  { {0x6d4803af,0x7c2800dd,0x60dc3744,0xc537000a}},	//   _cida, _bydr, _gorm, וָ֔ה_
  { {0xa3c1005d,0x7c280034,0x28d2000b,0x6d483745}},	//   ूमि_, _cydr, तानि, _dida
  { {0x764d00b6,0x3947003e,0xeab10086,0x6d4814d8}},	//   _ngay, _sins_, اعث_, _eida
  { {0xc9a6005f,0x69c20176,0x80b6005d,0x59820010}},	//   евые_, _croe, _उसमे, глыб
  { {0x27320089,0xf1b200f3,0xa91d0227,0xe8f6154c}},	//   dána_, נסי_, ouži, ель_
  { {0x2f39000a,0xb907000b,0x78b802b9,0x39470f24}},	//   ּגָד, _यक_, _davv, _vins_
  { {0x3947014c,0xbbbd000b,0xf2df0034,0x6d483746}},	//   _wins_, ्मीक, _siân_, _zida
  { {0x69c23747,0x612b00dc,0xa91d006f,0x7ae90e8c}},	//   _groe, rülj, huži, mket
  { {0x39992bee,0x94d60015,0x89da000a,0x7ae902cd}},	//   mès_, ريزش, _מחני, lket
  { {0x03a30080,0x46a6005e,0xaad3000b,0x39991e83}},	//   лиро, _зайв, थापक, lès_
  { {0x6724003f,0xfbd20008,0x61e400f2,0xa91d0085}},	//   _ukij, נתן_, tyil, duži
  { {0x656d0176,0x399918b3,0xf5570015,0x6e2901d7}},	// [74a0] _gwah, nès_, _كليب_, _nyeb
  { {0xb5f70008,0x61f61515,0x42230902,0x6ab90b58}},	//   _נציג_, rzyl, удув, _lawf
  { {0xd00f0029,0x40950063,0xd12f00e6,0x60dc3748}},	//   ملك_, ъртт, حمل_, _vorm
  { {0xfe7200e5,0x6d483749,0xa75a004c,0xee3a15bc}},	//   ادا_, _sida, לדער, пне_
  { {0x867b0008,0x6d480523,0xc333000a,0x4c94004a}},	//   פרסו, _pida, _תור_, вилс
  { {0xd378016f,0xa91d374a,0x5577004c,0x39990006}},	//   šću_, držo, געסן_, dès_
  { {0x27320089,0x29051422,0x6d48374b,0x6e2900da}},	//   zána_, dila_, _vida, _eyeb
  { {0x8f9b0dab,0x6d480ec5,0x69c2374c,0xd00f0031}},	//   _מילי, _wida, _proe, _الف_
  { {0x7c2810ec,0x6d480375,0x5d860015,0xa92a0033}},	//   _wydr, _tida, _سلال, зіне_
  { {0x273202d5,0x01970053,0x69c20150,0x7c282fa3}},	//   vána_, עכיש_, _vroe, _tydr
  { {0x28d2005d,0xa09b0053,0xad1b0053,0x656d225f}},	//   ताबि, הייט, _צובר, _swah
  { {0x6aa2003f,0x7ae9374d,0x69c2374e,0x2905374f}},	//   _ubof, cket, _troe, aila_
  { {0x916d00a7,0xceb300b2,0x95cb0124,0x39991df5}},	//   _một_, ניש_, чуна_, cès_
  { {0x27323750,0xa91d01c0,0x47d400c3,0x29053751}},	//   rána_, yuži, _ليتر, cila_
  { {0xd7ef1cf5,0x9f470227,0x28cd000b,0x97a30033}},	//   _су_, šné_, ़ारि, _брыл
  { {0xe6050058,0x0000006a,0x0000006a,0x0000006a}},	//   _لِعَ,   ,   ,
  { {0x02e1021e,0x96b80054,0x612b30b6,0x45d50099}},	// [74b0] _नवीन, _чују_, lüli, _ропс
  { {0xa91d0085,0x6d4f0003,0x65600030,0xa98b004f}},	//   tuži, _écai, ímhe, לָבִ
  { {0x6130022d,0x2d80002c,0x5f950661,0xbf580036}},	//   mäll, šiel_, тиет, ерії_
  { {0x916d0092,0x6f640086,0xa91d02c6,0x8d75002b}},	//   _cột_, اهنم, ruži, ناتا
  { {0xa91d0091,0x7f491342,0xa3b90065,0x5d19004e}},	//   suži, _vieq, चिक_, мікс_
  { {0x7c840054,0xa4bb000a,0xee3801c6,0x6130008c}},	//   гуће, לֶ֔י, хні_, näll
  { {0x61140063,0x7ae93752,0x29050fdd,0x3034004a}},	//   _сдру, tket, vila_, _берё
  { {0x63ba0134,0x290512d1,0xb5fb0046,0x39991e83}},	//   ætni, wila_, rbáj, tès_
  { {0x613016a0,0x7ae93753,0xb9920015,0x2ddb0015}},	//   käll, rket, لليب, _عبرة_
  { {0x39991347,0x613000f2,0x3eaf3754,0x25fc000b}},	//   rès_, jäll, legt_, _लेगी_
  { {0x2d8f010b,0x8ae70036,0x613000f2,0x612b00dc}},	//   luge_, _підл, däll, rülh
  { {0xb8e8000b,0x612b0030,0x39990144,0x29053755}},	//   _लो_, sülh, pès_, sila_
  { {0xd7f804f9,0x4e7a0053,0xc8f50063,0x61302e6f}},	//   ază_, וארצ, _издъ, fäll
  { {0x7c2413cc,0x27f50015,0x6d88004f,0x0000006a}},	//   şire, _لأبح, עָרְ,
  { {0xb4b2014e,0x25a900d9,0xe29a09a7,0xb8f5021e}},	//   _ऐसी_, _epal_, мав_, हा_
  { {0x2ed0005d,0x7c2c0030,0x2d8f007c,0x00e4009a}},	//   _सचेत, _önrő, kuge_, گتری
  { {0xdddb0011,0x9c7c00bd,0x43430809,0xd6eb000a}},	// [74c0] _reuş, _hoče, ретв, _חַיָ
  { {0xf0630001,0xd0590210,0x00e4002b,0x2128002b}},	//   икуп, ерці_, دتری, ريای_
  { {0x27320046,0x8f7600e2,0x7f7600ce,0xaf9a00ce}},	//   náno_, тузі, тузц, ьтах_
  { {0x2d800024,0xdfcf0087,0x69c40007,0x79891316}},	//   šiem_, تيم_, _šiem, krew
  { {0x9c7c00bd,0xd6570008,0xada30264,0x7db30015}},	//   _loče, דינת_, _naúč, لصوا
  { {0xed570124,0x2739002c,0x0ba60731,0x61eb063b}},	//   њој_, méne_, вшим, øgle
  { {0x1b770029,0xfce30004,0x69dd3756,0x9c7c00bc}},	//   نصية_, ројо, äsen, _noče
  { {0x27320089,0xf413000a,0x501b000a,0x64df000b}},	//   dáno_, יפו_, _חולו, _नक्श
  { {0x645c0079,0xdee30054,0xada60004,0x443f0016}},	//   kcri, _тоти, _јазл, ̀u_
  { {0xc173000a,0x98c6005e,0x7792002b,0xddc80030}},	//   סחת_, тсил, لیتا, _élőv
  { {0x6130022d,0xf093000a,0xeb9a07be,0xd7f80045}},	//   väll, בנת_, _цие_, uză_
  { {0x0f7b0008,0xcf930008,0x4bfb000f,0x80c9000b}},	//   ורטל, סטר_, _קלאס, _होने
  { {0x613001d1,0xceb30008,0x99d30086,0x59630063}},	//   täll, ביר_, _نتوا, _къща
  { {0x27160024,0x612b00dc,0x89d70040,0x0000006a}},	//   rāna_, lülv, _جوهر_,
  { {0x24580010,0xe8d7000a,0x2bc5000b,0xd3700015}},	//   тась_, _בוגר_, विया, ْهِ_
  { {0x6130022d,0x326418cd,0xdb080012,0x68fd003d}},	//   säll, итув, _erdö, īsde
  { {0x13a7002b,0xb5a40174,0x25a9013b,0x0000006a}},	// [74d0] رچگی_, _крэй, _upal_,
  { {0x3eaf00b8,0xb147002b,0x0000006a,0x0000006a}},	//   wegt_, ئیسم_,   ,
  { {0xdfa70029,0x7cef02de,0xfe73002b,0x0000006a}},	//   ضحاي, _børn, لدش_,
  { {0x2455002b,0x975705bd,0x2d8f007c,0x8e850058}},	//   _جنگس, דיאו_, tuge_, الشه
  { {0x27320089,0x3eaf047f,0x7bde007c,0xce94006b}},	//   záno_, regt_, äpun, рачъ
  { {0x3e710092,0x2d8f3757,0x2d9d002a,0x3eaf003d}},	//   ạt_, ruge_, rtwe_, segt_
  { {0xeab1003b,0xac09008f,0xc8780061,0x7cf40144}},	//   معة_, энка_, dağ_, _bàrb
  { {0x273202d5,0x613005ff,0x8afc0535,0x0000006a}},	//   váno_, jälj, _rtęc,
  { {0x6ca70029,0xca74002b,0xdb1a02de,0x09d40138}},	//   _لصال, شچنک, _ortæ, ацэў
  { {0xb4b2014e,0xbdf80015,0x9c7c06ca,0x27320046}},	//   _ऐसे_, _شرقا_, _poče, táno_
  { {0xd70a008f,0xc5e90008,0x66e63758,0xeef5004f}},	//   енне_, _צד_, гона, ָמָר_
  { {0x7c2500b8,0x7cf40144,0x2cf30065,0x2732005a}},	//   ühru, _vàre, _अतुल_, ráno_
  { {0x2bbd000b,0xf985006b,0x2910001a,0x98a505aa}},	//   ्मका, _сгло, ðlað_, _биле
  { {0xdc430046,0xa91d0085,0xb97a000a,0x9c7c10cd}},	//   _léči, tužu, _טרנז, _toče
  { {0x04570029,0x29360053,0x63830010,0xd91a000a}},	//   الفة_, _גאסן_, йгра, _אוסל
  { {0x82f50033,0x645c3759,0xa91d375a,0xb8f60065}},	//   ачуц, scri, ružu, ाफ़_
  { {0xa116002b,0x171b004c,0x645c0079,0xd1320015}},	// [74e0] هورت, _רופע, pcri, ممر_
  { {0xe0850015,0xc059005e,0x45fb000a,0x601a03ae}},	//   لجمي, вії_, _נהיג, нцер_
  { {0x903600e2,0x20552aa8,0x749b004f,0xa4b7004f}},	//   ухач, ртур, _אייפ, _גליה_
  { {0xdb240061,0xad660015,0x5f2501f3,0x6b9c007c}},	//   örüy, هاته, афіз, _ärgi
  { {0xc27b000f,0xfce603e7,0x69dd008c,0xd5b3000a}},	//   _ארכי, лодо, äsel, ֶׁה_
  { {0x412a0036,0x7bde00f2,0x7aa1000b,0xe589000a}},	//   _чого_, äpuo, क्सॅ, דָקָ
  { {0xec69005e,0xf76700c3,0x2fb8000a,0xeb4a0121}},	//   трік_, _دا_, _בֶּע, нчик_
  { {0xaba70002,0xa3ac000b,0x3af10f06,0x6296375b}},	//   اهيم_, _गहन_, _pápa_, ngyo
  { {0x61300eb4,0x7f3b0053,0x99830015,0x38c8002b}},	//   välj, _טעלו, مليو, نادی_
  { {0xc19b0008,0x81b70008,0xdd8f0018,0xbc6a0015}},	//   עשיי, נהיג_, _روم_, _أمان_
  { {0xf0930008,0x7c2500b8,0x98c30256,0x6be60015}},	//   זנת_, ührt, ссыл, _حكام
  { {0x8c1b0008,0x28d2000b,0x5694005e,0xceb3000a}},	//   _אובי, ताहि, бают, ֖יר_
  { {0xceb3000f,0x09e6005e,0x15a8006b,0x7a7b015b}},	//   זיר_, _щодн, лъри_, _טראס
  { {0x613000c0,0x7a37005e,0x644301c0,0xf9830054}},	//   sälj, _спір_, _únik, _угљо
  { {0x7ae2375c,0x7aa1000b,0x926b0004,0x3255011e}},	//   _koot, क्वॅ, ерза_, иввр
  { {0x2007005c,0x75d50015,0x88350033,0x28d2000b}},	//   źnik_, _نيبا, _тэчц, तावि
  { {0x9f470089,0x90990063,0x7ae20607,0x533405b3}},	// [74f0] ání_, кват_, _moot, сетт
  { {0x7ae20a54,0x7bc8375d,0x62960030,0x04590058}},	//   _loot, _ordu, agyo, _جلدة_
  { {0x9f470089,0xdcea0046,0xbfab0033,0x7cef00cb}},	//   šní_, žnět, этае_, _søro
  { {0xef0e0127,0xf1ca006f,0xa1952143,0xc2eb0058}},	//   ім_, _stáť_, _камч, _أعدم_
  { {0x127a00b2,0xed4e0010,0x427a000f,0x527a000a}},	//   _בארע, жо_, _בארג, _שנשא
  { {0x55780053,0x612b00b8,0xbd450029,0xdf770015}},	//   רעגן_, gült, جنتي, _مدرب
  { {0x2bc5005d,0x4c920001,0x611a000a,0x711a000a}},	//   विधा, цијс, _יושה, _יושפ
  { {0x89d50015,0xff0700fd,0x5985168a,0x28b70065}},	//   لتخط, _сягн, алиб, _असहि
  { {0x88d5008f,0x2d8b0089,0x61300123,0x7bc80012}},	//   аўні, _íce_, fälh, _erdu
  { {0xa85500d0,0x3ebf375e,0xe9a80040,0x2176004f}},	//   штиј, _haut_, ادين_, סתתר_
  { {0x3ebf2c20,0x7ae20376,0xddc200bc,0x366a261d}},	//   _kaut_, _foot, mboš, кано_
  { {0x9f96000a,0x79c90015,0x7ae20577,0x0000006a}},	//   סדרה_, _لوصف_, _goot,
  { {0x86990010,0xdce204af,0x3ebf0375,0x7ccb003d}},	//   ытэт_, zpoč, _maut_, _tērē
  { {0xdce200bf,0x3ebf375f,0xe4520058,0xf9fa004f}},	//   ypoč, _laut_, تضح_, _שהסמ
  { {0x28d2005d,0x0446058f,0xed590263,0x7cef00cb}},	//   तारि, ревн, _drži_, _rørl
  { {0xe355008f,0x1601005d,0x33930029,0x62660015}},	//   стрэ, _लेकर_, تلفز, شارق
  { {0x26d200b6,0x71650029,0xa91d0007,0x30560001}},	// [7500] _inyo_, مالك, erži, ађет
  { {0x27390057,0x757b000a,0xe589000a,0xa5650067}},	//   ména_, _שטיפ, _עָפָ, _ادين
  { {0x68e30738,0x3ebf0012,0xbe66002b,0xdfcf0015}},	//   _mond, _baut_, لهاي, ويك_
  { {0xbea60010,0x3ebf0045,0x3af80030,0xe37b000a}},	//   радк, _caut_, _képe_, _ברטר
  { {0x82360086,0x26c0001c,0x7ae20100,0x7609000a}},	//   _خردا, _maio_, _root, ְּנַ
  { {0x7ae23760,0xfbaa005e,0x6da30054,0x68e33761}},	//   _soot, втий_, циља, _nond
  { {0x3ebf038d,0x3af80089,0x26d2003f,0x7d0a002e}},	//   _faut_, _lépe_, _onyo_, rifs
  { {0xbab81a9a,0x612b00dc,0x9c7c0264,0x39a6042b}},	//   угих_, sült, _doča, ашов
  { {0xdcfb016f,0xed5a0286,0xbb470015,0x3af80030}},	//   _zvuč, _роз_, جلين_, _népe_
  { {0x26d200b6,0xc051000a,0xcc78000a,0x3c78000a}},	//   _anyo_, ּ֖י_, _תְּר, _תָּב
  { {0x7ae22ba4,0x00570008,0x31370008,0x01370008}},	//   _toot, ישית_, שנים_, שרית_
  { {0xf8030010,0x6d4f0152,0x3ea6007c,0x37070219}},	//   ічэн, _écar, nfot_, рчов
  { {0x6f0308e0,0x26c50089,0x8afb004c,0xdb010046}},	//   ènci, ělo_, _בלאז, _uplá
  { {0x2bbd005d,0x248d00b8,0x68e33762,0x27320016}},	//   ्मचा, ßem_, _gond, hánh_
  { {0x38cb002b,0xa93b000a,0x09b6000b,0x9cd7000a}},	//   _جانی_, _שתופ, _अनुय, סולה_
  { {0x68e30298,0x8c1b0008,0x6d43002a,0x248d0061}},	//   _zond, דולי, zmna, şem_
  { {0x50670015,0xdddb0085,0x3ea60123,0x6b550091}},	// [7510] لطاق, _oduš, dfot_, _išge
  { {0x20670001,0xe04b002b,0xd1300015,0x3ebf0003}},	//   рђав, نشاه_, ِمْ_, _saut_
  { {0x9028008f,0xa0540036,0x7e550015,0x83190021}},	//   ацца_, івці, مناص, _مقدر_
  { {0x2bbd005d,0xe3b00086,0xc7d7000a,0xcd28002b}},	//   ्मघा, _کری_, יובי_, یسون_
  { {0xadbc0036,0x3ebf0152,0x5c950015,0xd738000a}},	//   кацi, _vaut_, مؤثر, בטאת_
  { {0xd57a0053,0x9c7c3763,0xdd8e0015,0x61ed3764}},	//   אָקר, _poča, روى_, myal
  { {0x69c602de,0x9b680054,0xddc2003d,0x290c00be}},	//   æken, ашња_, rboš, dida_
  { {0xfbd003c4,0x61300044,0x68e33765,0xb418000a}},	//   بته_, väli, _sond, יקוס_
  { {0x6f09003f,0x61ed2ee0,0x26c0016e,0x3df50054}},	//   _imec, nyal, _raio_, _узас
  { {0xe8f60256,0x3c450015,0x9c7c0085,0x290c0f9e}},	//   йлы_, _هَذِ, _toča, gida_
  { {0xfbd0003b,0x26c03766,0x0b780015,0x68e33767}},	//   _يتم_, _paio_, _نصنع_, _vond
  { {0xbae40015,0x68e32903,0x6bd40015,0x06750fea}},	//   _وكلي, _wond, _بتكر, журя
  { {0x9c7c00bd,0xa2cb005d,0xcb36000a,0xdb26002b}},	//   _močn, _हफ़्, _פאני_, _اونی
  { {0x69cb00b8,0x64a60001,0xd7c90015,0xa91d0091}},	//   _irge, љава, _موته_, eržv
  { {0x9359005e,0xf7850015,0xa8a40004,0x7afb2b06}},	//   ирту_, _البَ, _фрчк, ohut
  { {0x61e2177b,0x87050015,0x443a0046,0x9c7c1417}},	//   äolo, _وبيل, _vzp_, _nočn
  { {0xd5b10092,0xe0560029,0x612b0030,0x61ed0030}},	// [7520] ắc_, مخاب, vülr, gyal
  { {0x27320089,0xd83e00bd,0x6f09003f,0x20563768}},	//   dáni_, ščem_, _amec, стар
  { {0x287a0053,0xa3ba0087,0x9c7c0910,0xe457004c}},	//   רנעמ, _صادر_, _bočn, _לייט_
  { {0x6e93003b,0x4e960029,0xee7a0029,0x290c3769}},	//   كلما, إشار, اصات_, zida_
  { {0xf63a004c,0x7c3a0030,0x9f47216b,0xadbc01f3}},	//   װײַל, _sztr, áná_, талi
  { {0xa3cc000b,0xed590085,0x3e4b0091,0xdb1a006f}},	//   लिप_, _duž_, dėtį_, _isté
  { {0x9f470057,0x6c830015,0x290c376a,0x9bc608f0}},	//   šná_, سليم, vida_, сёлк
  { {0x60170008,0x7c3a00bc,0xb69b0003,0x290c002a}},	//   _החלף_, _vztr, niât, wida_
  { {0x290c376b,0x0000006a,0x0000006a,0x0000006a}},	//   tida_,   ,   ,
  { {0x41bb0053,0x8d5b000a,0x80db000b,0x610f0091}},	//   נציע, _עכבי, नाये, _gėlė
  { {0xda6f008f,0x69cb08e1,0x290c376c,0xe838005e}},	//   _ня_, _erge, rida_, рпні_
  { {0xdc3b0053,0x290c1c6c,0xc7f70036,0x2bc5005d}},	//   _געבר, sida_, снює_, विरा
  { {0xeb14014e,0xfa360087,0x80db000b,0xc5170021}},	//   तचीत_, _اراد, नामे, مبست
  { {0xa99b0008,0x985c003d,0x5558070c,0x9c7c0069}},	//   _עבור, nāļi_, саря_, _močo
  { {0xa87b0008,0x8937000a,0x80cc000b,0xdb1a0140}},	//   _גאור, _הרגע_, _सफ़े, _asté
  { {0x27390089,0x672d003f,0x2d76002a,0x3817000a}},	//   méno_, _ukaj, kłe_, _לקום_
  { {0x315b0015,0x9c7c1e25,0x7cef01d0,0x0000006a}},	// [7530] اجرة_, _ročn, _førh,
  { {0x46a5005d,0x27320089,0x61ed191c,0x2d76002a}},	//   ग्रह, váni_, ryal, dłe_
  { {0xdfd10029,0x61ed376d,0xa8570008,0x9c7c376e}},	//   بيا_, syal, ציאה_, _počn
  { {0x61ed01e2,0x8e740010,0x3e7d0091,0x273216ce}},	//   pyal, пушч, kštų_, táni_
  { {0x2d76005c,0x3d8b004a,0xbdfb002b,0x7c240061}},	//   głe_, ущен_, درضا_, şirl
  { {0x4aa6000b,0x2732376f,0x27080030,0x9356002b}},	//   क्सव, ráni_, tőnk_, _دریچ
  { {0x9c7c01a3,0xc49c000a,0x2d76002a,0x7afb00aa}},	//   _točn, אשות, ałe_, thut
  { {0x6f09003f,0xdd950010,0x7afb1dad,0x93f8000a}},	//   _umec, _мабы, uhut, מצוא_
  { {0xda090086,0x627c000a,0xe8f92e79,0xc8b508f0}},	//   شيده_, אנחנ, или_, осны
  { {0xa3cc005d,0x16b2005d,0x9cf40033,0x7e7b0079}},	//   लिम_, ज़्ब, _езуі, _heup
  { {0xf092013a,0x6d410064,0x7e7b00d9,0x60c5002d}},	//   וני_, _ihla, _keup, idhm
  { {0x6f190026,0x78820089,0x8f9a000a,0x9c7c00bc}},	//   nnwc, tíví, סירי, _ločl
  { {0xf6260036,0x69cb248e,0x7c2d0061,0xc6030033}},	//   ідго, _urge, şard, дзяй
  { {0x6d5b00f2,0x186903e7,0x2a7f0012,0xa988004f}},	//   _muua, _таки_, laub_, _הָקִ
  { {0xab89000a,0x6d5b007c,0x7a0b003d,0xc952000a}},	//   יָּ֖, _luua, sētī, _קמו_
  { {0xf26a0229,0x613000b8,0x7a0b003d,0x2316005e}},	//   риал_, hält, pētī, ієвс
  { {0x3d1a005d,0xc05a0c5b,0xb5fb0077,0x10a60a32}},	// [7540] _बदले_, арец_, lcán, жизн
  { {0xe0d73028,0x91360033,0xd24f0015,0x613007c2}},	//   ову_, іхаі, ئنك_, jält
  { {0x09b6005d,0x14d70053,0x6f190034,0x6130008c}},	//   _अन्य, _וויל_, fnwc, dält
  { {0x0dca05c4,0x80b6000b,0x8d6a01ca,0x6d411848}},	//   илей_, _उसके, ајка_, _ahla
  { {0x6d260010,0x3dcd0b00,0x61300c77,0x61460033}},	//   оддз, _crew_, fält, _мема
  { {0xc5f30008,0x3dcd003e,0x9c570001,0x7e62248e}},	//   ודד_, _drew_, ошћу_, scop
  { {0x2d76002a,0x69c92544,0x2bb70015,0x6aa900cb}},	//   słe_, evee, قاية_, ffef
  { {0x19aa0033,0x63bc0034,0xbb470015,0x2d76002a}},	//   атоп_, iwrn, يلون_, płe_
  { {0x3dcd003e,0xaaa6005d,0xdc54002b,0xf1bf0030}},	//   _grew_, क्षक, _فراک, _száz_
  { {0x998000df,0x6d41002f,0x80d0005d,0xd8f80036}},	//   _šių_, _ghla, _डोमे, сної_
  { {0xe0b70008,0x6c57000a,0x9208003d,0xfaa604d7}},	//   חליט_, _ויבא_, liāļ, _мажо
  { {0xf76f0086,0x87070033,0x273201c0,0xd29b0138}},	//   کای_, іяне, kánu_, зiны
  { {0x6b550007,0xe3b80061,0xda6500c3,0x6a1600c3}},	//   _išga, çın_, _راني, _ببار
  { {0x4aa6005d,0x7c2d19a0,0x645a0091,0x27320046}},	//   क्रव, şare, žtin, dánu_
  { {0xe4540010,0xd7e6017f,0x6f190034,0xe4e402a3}},	//   дкры, _філо, ynwc, фіян
  { {0x26c5003d,0x72d415d2,0x9259011e,0x0000006a}},	//   ēlos_, мосф, саат_,
  { {0x67ff00dc,0x9a36000a,0x05770015,0x60f908f0}},	// [7550] _tájé, חָ֑ד_, _باعد, бная_
  { {0x759a000a,0x96a7000b,0xd1310115,0x306b0b1e}},	//   _פיתח, ट्रॉ, رما_, рјан_
  { {0x74150086,0x7e7b0152,0x44270e36,0x6130008c}},	//   _روحا, _peup, _ân_, vält
  { {0xf8b7005d,0x59bc000b,0x8e850015,0x7cfd0003}},	//   _अस्प, ्टार, سلته, _mère
  { {0xbdf80029,0x6d410026,0xf1bf016e,0x5e450015}},	//   يرها_, _phla, _usá_, أَشْ
  { {0x7cf40251,0x6cc202bf,0xc5bc000a,0x9f05002b}},	//   _fàrm, ейша, שֶׁר, _کورو
  { {0x4154000d,0x73fb000a,0x2a7f0012,0x538b004f}},	//   _цврс, יּ֗ו, taub_, ׁנַ֣
  { {0x6130022d,0xa3cc005d,0xdb23002b,0x6d5b007c}},	//   sält, लित_, بوبی, _tuua
  { {0xfc460084,0xf991003b,0xc3340008,0x7cfd0251}},	//   _þínu_, ربة_, ווק_, _pèrd
  { {0x48050036,0xe8f905ae,0xdcf70015,0xb902005e}},	//   зпов, сло_, _بأرب, езьк
  { {0xf09200b2,0xccf20008,0x69c9007c,0xe7320015}},	//   ענט_, _רכב_, svee, فصح_
  { {0xd5b10092,0x4c3a0008,0x7c3a000a,0xd7ee0015}},	//   ắn_, _התעב, _התעס, اكَ_
  { {0xcb12013a,0x4a5a004f,0x0000006a,0x0000006a}},	//   _אלא_, _הדנו,   ,
  { {0xa7fc0061,0x27320046,0xd83e00bc,0x18a201f3}},	//   mcın, vánu_, ščam_, _зашм
  { {0x58f6000a,0x987a000a,0xfdb8000b,0x395d0034}},	//   _ממסע_, _האצט, _इन्फ, _huws_
  { {0x877a0053,0xd348002b,0xaabd000b,0x9756004f}},	//   _פאפי, تیجه_, ्यिक, _ציפו_
  { {0xd6eb0008,0xa7fc0064,0xe7170008,0xc693004c}},	// [7560] _הַיָ, ncın, _מחקר_, _נאז_
  { {0x505a004a,0xa3cc000b,0x273201c0,0x0000006a}},	//   сшая_, लिद_, ránu_,
  { {0x447700b2,0x4abd005d,0xc2090008,0x54770008}},	//   _מעיל_, ्याव, נה_, _מגיע_
  { {0x794d005c,0x7c240061,0x9476009a,0x6da63770}},	//   _dźwi, şirk, _بدکا, зида
  { {0x237f016f,0x2007001a,0x3257000a,0xd257004f}},	//   ćuje_, únir_, _מסכם_, _משכה_
  { {0xd1320029,0x2bba0029,0x61300123,0x4c940ac9}},	//   _أمس_, ماعة_, räls, фикс
  { {0x6130008c,0xc4d3000a,0x602305a7,0x9f4901c0}},	//   säls, תגו_, _здра, žkám_
  { {0xfbcf0002,0x70530015,0x539b000a,0x9c7c0046}},	//   اتو_, _أنفا, ציפו, _kočk
  { {0xd7f80045,0x49d8005e,0x0000006a,0x0000006a}},	//   rcăm_, ідою_,   ,
  { {0xfcaa0086,0x7cfd0003,0x8dfb000a,0x7cef00cb}},	//   _دارو_, _père, _ההמת, _sørv
  { {0xd6d10015,0x4ccb000a,0xda66006e,0x56953771}},	//   نقد_, _לֶאֱ, _فاشي, мант
  { {0x7bdb013a,0x103b000a,0xfaa60033,0x0000006a}},	//   _לקבו, מגיע, _хадо,
  { {0x27320014,0xbae30015,0x69dd014b,0x6d4a3772}},	//   vánt_, _سكوي, äset, omfa
  { {0x48e30b44,0xe4e4008b,0x19bb000a,0x3f9a3773}},	//   _почв, нісн, _למדב, kupu_
  { {0xf3f30029,0xb909002b,0x27390030,0x2915006f}},	//   رأس_, _بزنم_, nénk_, ýbať_
  { {0x78ba0014,0xf4080029,0x662800dc,0x0cb9000b}},	//   letv, سيقى_, éské, _इस्म
  { {0x442d005c,0x672f005c,0x7cef02de,0x27320030}},	// [7570] łe_, mocj, _kørt, ránt_
  { {0x78ba0134,0x51f8054f,0xdb031a4b,0x2499002b}},	//   netv, чную_, rtné, _بندد_
  { {0x8fb90029,0xdb030f19,0x3f87013f,0x28ae000b}},	//   تهاء_, stné, énu_, ज्यि
  { {0x8db50010,0xff04005e,0xf773000a,0x64430144}},	//   дскі, нячн, תקף_, _úniq
  { {0xddab2b16,0x6da5024f,0xee2e011e,0x68ea0546}},	//   стел_, фила, тн_, _oofd
  { {0x21270086,0x11da000a,0x2fc6002a,0x7cfd0144}},	//   _ريزی_, _וחשב, łoga_, _sèrb
  { {0xeab10015,0x1ae5005e,0x672f002a,0x5ff50033}},	//   نعة_, дойм, kocj, _ўзбу
  { {0x13c8000a,0xbc380015,0x5f7400c3,0x3eb9013f}},	//   פּוֹ_, أسها_, _سافر, _úst_
  { {0xceb204dc,0xda640086,0xe9d9005e,0x8cdd000b}},	//   _בין_, رايي, іко_, पादो
  { {0xecd5002b,0x6e2d0535,0x78ba01d3,0x0000006a}},	//   _تحرک, żabs, getv,
  { {0x7bc11007,0xdb0102de,0x69c200aa,0x60c73774}},	//   _uslu, _oplø, _esoe, _majm
  { {0xa7fc01e2,0x273200dc,0xa3cc021e,0xf771002b}},	//   mcıl, váns_, लिस_, _یاب_
  { {0x443c0007,0x7cef079b,0x6abb02b9,0x98a5008a}},	//   _šv_, _ført, meuf, _жиле
  { {0x613000c0,0xf2df0026,0xcd96000a,0xb92500c3}},	//   jälp, _siâp_, ודשת_, _تفتي
  { {0xa7fc0064,0x03a301c5,0xa35e0033,0x270a0015}},	//   ncıl, киро, рэгi, _وقتٍ_
  { {0x7cef0134,0x7aeb00dc,0x9c7c0264,0x41c9000b}},	//   _kørs, _jogt, _počk, रिंस
  { {0x045a0029,0x27390030,0x60ea15f4,0xcb12004f}},	// [7580] _وجدت_, zénk_, омам_, דלן_
  { {0x61eb0400,0x3f9a3775,0x0ffa0015,0x50650015}},	//   ägla, tupu_, يعاب_, ّانِ
  { {0xd12f0015,0xdee60004,0xdff50033,0x443c00bf}},	//   جمل_, можи, няць, _áv_
  { {0x78ba00dc,0x9c7c02c6,0x9eda0015,0x7aeb042f}},	//   zetv, _točk, غذاء_, _nogt
  { {0xb2bb000a,0xcd2a0015,0x11460015,0x62843776}},	//   _ומכר, يستن_, _يَجُ, maio
  { {0x8e20005e,0x3f9a01c2,0x9c7c0729,0x6aa23777}},	//   бiв_, pupu_, _koči, _scof
  { {0xa2a5000b,0x3fc8002b,0x7aeb02de,0x290e01d7}},	//   ङ्क्, _عدسی_, _bogt, _rmfa_
  { {0x60c7005c,0x98be0091,0x6e930015,0x7cef01de}},	//   _zajm, imtą_, _للفا, _børs
  { {0xcb070029,0x9c7c00bd,0x78ba2635,0x6da6002b}},	//   بيين_, _loči, tetv, _زمام
  { {0x7c2d0064,0xa1ab000a,0x6f020028,0xd83e006f}},	//   şara, חֱטִ, lhoc, áčom_
  { {0xd5b10023,0x656d3778,0x07e3005e,0xc7ca0033}},	//   ắm_, _stah, вцям, цыпе_
  { {0x7cef0293,0xab770015,0x65952bdf,0x0000006a}},	//   _førs, _آمنا_, наму,
  { {0xdb1a03af,0x77920074,0xc9f60029,0x672f0085}},	//   _estã, ریکا, _تساع, rocj
  { {0x9f470125,0xd37b005e,0xba57000a,0x672f002a}},	//   ánú_, жча_, _חסדו_, socj
  { {0x2458004a,0xf4340033,0x389b000a,0x289b000a}},	//   дарь_, верэ, _ויונ, _ויוא
  { {0x87270029,0x9f47002c,0x7348005e,0x60c70085}},	//   _تعتم, šnú_, дчув_, _sajm
  { {0x656d003f,0x8655005e,0x067c000a,0xd011002b}},	// [7590] _utah, _яких, _ונחל, گلا_
  { {0x272401e2,0x25d60008,0xa3cc000b,0x609b0015}},	//   mına_, _נותן_, लिश_, تخرج_
  { {0x6f02002d,0x83670015,0x5ef0000b,0x291e3779}},	//   fhoc, _تدخل, _आवश्_, inta_
  { {0xfe7000a2,0x539a000f,0xa2a5000b,0x53470033}},	//   لده_, _צירו, ङ्ख्, _іхна
  { {0x27240064,0x60c7016f,0x80a7000b,0xfca90015}},	//   nına_, _tajm, _चापे, كاغو_
  { {0x459c0053,0xd13b000d,0x7cef10d7,0x8c451045}},	//   קסוע, _фхм_, _rørs, неле
  { {0xdb800010,0xeb9903e7,0xa1581923,0x7cef377a}},	//   арыi_, чий_, _цару_, _sørs
  { {0x2014005c,0x8458000a,0x2b460003,0x2ca90046}},	//   ócił_, ובוס_, _choc_, řad_
  { {0xba75002b,0x28db000b,0xdbc7007c,0x27240061}},	//   واکت, बालि, _nöör, jına_
  { {0x78a90124,0xdb1a08e0,0x2eed00dd,0xe3b80064}},	//   чког_, _està, _hoef_, çık_
  { {0x645a0007,0xd90c002b,0xe73a05aa,0x7aeb234f}},	//   žtik, تیو_, зен_, _togt
  { {0x291e377b,0x7a87002b,0x27240061,0x3af80030}},	//   anta_, _آشام, fına_, _lépj_
  { {0xdb030089,0xaa88002b,0x2d9d00aa,0x9a84005e}},	//   ntní, _آنهم_, nuwe_, _рухл
  { {0xb0ce014e,0xdb03002d,0x4e16000a,0x9c7c377c}},	//   _होंग, itní, תחשב_, _poči
  { {0xb6020089,0x38ca002b,0x78fa004f,0x0000006a}},	//   _žádn, _راوی_, _מפסו,
  { {0x27240064,0x3f470020,0xdb030046,0x7cf40144}},	//   bına_, nõud_, ktní, _vàri
  { {0xc355006b,0xa227006b,0x27240061,0xe2970033}},	// [75a0] търъ, ежта_, cına_, эат_
  { {0x1c1f005d,0x83c60010,0x2d9d0079,0x6284016e}},	//   यपाल_, _збож, duwe_, saio
  { {0x447b000a,0x628402b9,0x9c7c0085,0x1fb60033}},	//   _מניע, paio, _uoči, эсар
  { {0xa8560008,0x4444060b,0xdb1a002c,0x3f470020}},	//   גיעה_, _iz_, _ostá, jõud_
  { {0x6441003d,0xc693000a,0x291e377d,0x9c7c0b28}},	//   ļlie, ראד_, ynta_, _močv
  { {0x6f02002f,0xab94005e,0x3df30033,0xebc60054}},	//   shoc, викі, ызіс, ељин
  { {0x27240061,0xbc670040,0x50430a0b,0x6abd000b}},	//   zına_, رمين_, _берб, ्यूर
  { {0xe6ca005d,0xc2120008,0x27240064,0x6bd300e5}},	//   ियोज, ָה֙_, yına_, اتور
  { {0x25660026,0x9b430015,0x2902003d,0x66e4000b}},	//   _nôl_, دنيو, ūkam_, गानक_
  { {0xf2df0023,0x395800c0,0x4444377e,0x291e377f}},	//   _nhân_, örs_, _oz_, unta_
  { {0xdb1a0a49,0x8cdd000b,0x1be4000b,0xaba50015}},	//   _está, पारो, _कपिल_, _لإنه
  { {0x501b0008,0xdbc70020,0x27240064,0x69cd000b}},	//   לויו, _pöör, tına_, तिशी
  { {0x444403c0,0xaa570029,0x7c3a0026,0x7a490003}},	//   _az_, _كلما_, _hytr, rêté
  { {0x272401e2,0xf2df0023,0x98a50011,0x88c60015}},	//   rına_, _chân_, rolă_, _ستتل
  { {0x272401e2,0x9cd70008,0x2bd3005d,0x68f50064}},	//   sına_, עולה_, थिया, özde
  { {0xdbc70020,0x083b0008,0x883b000a,0x443a3780}},	//   _töör, _מעול, _מתוו, _dyp_
  { {0x44443781,0xf1940a61,0xdce90796,0x6d5a016e}},	// [75b0] _ez_, лить, _steč, _oita
  { {0x6d5a003f,0x32440015,0x361c000a,0x26170065}},	//   _nita, انكف, _מוחד, _पेयी_
  { {0x44443782,0x268b004f,0x0f35009a,0xbec801ec}},	//   _gz_, ִנַּ, نکرد, zgūš
  { {0x3ee4010f,0xfe710086,0x6d5a0020,0xda20000b}},	//   лючв, شگر_, _aita, मपात_
  { {0xa2a6005d,0x0e640033,0x9c7c00bc,0x6d5a3783}},	//   _छात्, укін, _loču, _bita
  { {0x27390057,0xdb030046,0x3d720015,0x6d5a3784}},	//   ménu_, rtní, جُوز, _cita
  { {0xdb030107,0x6d5a15c2,0x7c3a002a,0xdce91a80}},	//   stní, _dita, _cytr, _uteč
  { {0x6d5a3785,0x4034004a,0xb5fb0125,0x673d0079}},	//   _eita, _сесс, acái, jlsj
  { {0xe9a6002b,0x6d5a03a6,0x5d551293,0xee3f006f}},	//   نگون_, _fita, _акат, _áý_
  { {0xd9450001,0x25660026,0xc8db000b,0xf1b2000a}},	//   ђени, _rôl_, बाइट, ססי_
  { {0x78bc007c,0xe9050016,0x0b940058,0xf8ae009a}},	//   õrva, gượ, _مجند, تکن_
  { {0x7b740029,0x6d5a1fd5,0xeafb0015,0x66da006b}},	//   _إطلا, _zita, _عرضت_, фьор_
  { {0xf2df0023,0x7ae9016f,0x44441054,0x2a980015}},	//   _phân_, mjet, _sz_, _أئمة_
  { {0x7ae93786,0x7afb3787,0x8996004f,0x44443788}},	//   ljet, lkut, _יכנס_, _pz_
  { {0xb8f5000b,0xd3b9005e,0x3f870045,0x29050125}},	//   ाए_, нуті_, ânul_, mhla_
  { {0x61f6008c,0xf74a0015,0x61e40144,0x7afb3789}},	//   tyyl, _تلبي_, txil, nkut
  { {0xf2df0023,0x7d01378a,0x6e3b003f,0x7ae90085}},	// [75c0] _thân_, _olls, _nyub, ijet
  { {0x42550760,0xd59b000a,0xc5eb000a,0x443a0bc5}},	//   утст, _קביל, _חַטֹ, _typ_
  { {0x4444378b,0x6d5a3128,0x7fd50036,0x6fd50010}},	//   _uz_, _rita, ліці, ліцц
  { {0x127a0029,0x65641437,0xdb01001a,0xdfcf00c3}},	//   _تحدث_, _kuih, _pplý, غين_
  { {0x568d00b4,0x6d5a010b,0x7ae9378c,0xe433002b}},	//   לטאַ, _pita, djet, _مفید
  { {0x656400f2,0xb5fb00dc,0x27390030,0xdb01006f}},	//   _muih, tbáz, lént_, _vplý
  { {0xb607001a,0xb5fb0125,0x6d5a378d,0x2bc20157}},	//   _kráð, rcái, _vita, _वैशा
  { {0xab270083,0x6d5a005c,0x3ea2003c,0x7afb00e8}},	//   која_, _wita, _økt_, gkut
  { {0x7c3a005c,0xb5fb0030,0x6d5a378e,0xee370323}},	//   _wytr, sbáz, _tita, _ант_
  { {0x6d5a0011,0x7afb0201,0x88bc0046,0xdca60004}},	//   _uita, akut, dněc, _јажи
  { {0x27390014,0xa09b00b2,0x57190010,0xad1b000a}},	//   ként_, וייט, ежня_, _קובר
  { {0x7c240061,0x2905006f,0x7afb025d,0x973d0085}},	//   şirs, ahla_, ckut, kuće
  { {0xceb30053,0x973d016f,0xf9fa0015,0x3af80030}},	//   סיש_, juće, _تراث_, _népi_
  { {0x973d0085,0x19b7000a,0xb7d40015,0x2905378f}},	//   duće, _ספור_, _مقتب, chla_
  { {0xa2950484,0x02a71ced,0xb8070015,0xb607001a}},	//   лаві, крам, _ليوم_, _bráð
  { {0xfbb7000a,0xf76f0021,0x98a51e7f,0x0bb7000a}},	//   כפלת_, _باو_, rolą_, כללם_
  { {0x973d016f,0xdb1a00c0,0x45d50cb9,0xb28401b0}},	// [75d0] guće, _istä, _сопс, рыск
  { {0x5f770015,0xd01b007e,0x2739013f,0x2509009a}},	//   ناصر, мфе_, rénu_, _سرخی_
  { {0x753511b7,0x6e3b01d7,0x50642f7c,0x6e9907f7}},	//   mozz, _syub, ртуа, евер_
  { {0xdb230020,0x7535160a,0xf2df0016,0xb607001a}},	//   örüh, lozz, _khâm_, _gráð
  { {0x41e4008f,0xa1840256,0x7ae93790,0xada800c3}},	//   _кіра, _высл, vjet, ندوق_
  { {0x70740029,0x7ae90303,0xd658000a,0xcd040004}},	//   _نافذ, wjet, דידת_, ичји
  { {0xa3cc005d,0x4fc4004a,0xeeab005e,0xb4b8000a}},	//   लिए_, _кста, _отак_, דלופ_
  { {0xdb1a0123,0x05c3000b,0x75350030,0x7ae93791}},	//   _nstä, षबाब, hozz, ujet
  { {0x753500dc,0x9c7c0264,0x6abd000b,0xf1c9000b}},	//   kozz, _počt, ्यौर, रिटन
  { {0x6f190026,0x7ae93792,0xd7e90080,0x57e91179}},	//   liwc, sjet, емое_, едом_
  { {0x7ae90085,0x6564008c,0x2606000b,0xddc2002a}},	//   pjet, _suih, सैनी_, zboż
  { {0x7aa40036,0xc4c90008,0xbc0c0053,0x8f9a000a}},	//   _виїз, _מג_, _קהאָ, עירי
  { {0xf2df0016,0x0000006a,0x0000006a,0x0000006a}},	//   _châm_,   ,   ,
  { {0xdb1a022d,0xc9920029,0xddc200bd,0x2739001c}},	//   _estä, _الوظ, ncoš, féns_
  { {0x273900dc,0x141a0015,0xb8920015,0xf8b2004f}},	//   tént_, ريرة_, _طليع, _השו_
  { {0x04570015,0x77f6000a,0xf772000a,0x0000006a}},	//   طلقة_, _תמקד_, _פקח_,
  { {0x6f190176,0x98ac0024,0xa09a0029,0x91e30254}},	// [75e0] diwc, lodā_, فضاء_, боте
  { {0x2739001c,0x51560c71,0x656b0030,0x26c23793}},	//   béns_, утбу, _égha, leko_
  { {0xdb1a022d,0xeef60010,0x6f190026,0x9f470227}},	//   _ystä, лядэ, fiwc, šný_
  { {0x6e460018,0x6f190034,0x6e9600c3,0x26c212a8}},	//   هنام, giwc, الشا, neko_
  { {0xa3cc0372,0x62860048,0x26c20091,0x7d181590}},	//   लिक_, _ieko, ieko_, tivs
  { {0xac18201e,0x98ac003d,0x6b810034,0x0657004f}},	//   колу_, kodā_, _bwlg, אינך_
  { {0x7d180123,0x62863794,0x910300eb,0x0b930058}},	//   rivs, _keko, _упре, مجيد
  { {0x6f190176,0x7cf408e0,0x6b450030,0x26c20085}},	//   ciwc, _càrr, tóga, jeko_
  { {0xbef70008,0xbb470021,0x62863795,0x2739059d}},	//   _עצמו_, دلين_, _meko, zéns_
  { {0xd8f80036,0x5bc60029,0x19b70029,0xd90d0086}},	//   тної_, _متصف, اطية_, وین_
  { {0xf98f0086,0x3cfb0008,0x39420024,0x3137000a}},	//   يبی_, _רלבנ, ēks_, רנים_
  { {0x7b170011,0x20570135,0xa96a1377,0x62861ecd}},	//   nţul, טייל_, _зида_, _neko
  { {0xf2df0092,0x75350030,0x0000006a,0x0000006a}},	//   _giây_, tozz,   ,
  { {0xc8b2009a,0x0000006a,0x0000006a,0x0000006a}},	//   _طلبک,   ,   ,
  { {0x75353302,0x99470021,0xa3ce0046,0x62863796}},	//   rozz, _حلول_, _píší_, _beko
  { {0x80a7005d,0x98a70089,0x7cf40251,0x41e7022a}},	//   _चाहे, _okně_, _màrq, ліза
  { {0x82370086,0x9259000d,0x7abb000a,0x75350030}},	// [75f0] ارزا, таат_, עצמו, pozz
  { {0x10072ac6,0xb375002b,0xdddb005a,0x0000006a}},	//   ляем, _نگرش, _neuš,
  { {0x155a0008,0x9976005c,0x7982005c,0x4ab4000b}},	//   _שכתב, nęły_, _lwow, ंभाव
  { {0x94740086,0xa77b01ac,0xa264006b,0x62862707}},	//   _پدیا, גראפ, _гърл, _geko
  { {0x6f190026,0x6130008c,0xd5b4004f,0x31590058}},	//   riwc, häly, ֶׁק_, _للحج_
  { {0x6f190176,0x3ea60035,0xe3b0002b,0x3e320015}},	//   siwc, agot_, _بری_, غفور
  { {0x6f190026,0x1d06006b,0x9976002a,0x94f8000a}},	//   piwc, рещи_, jęły_, רצוף_
  { {0xdab90010,0x24180008,0xd5460016,0x1a68002b}},	//   тыкі_, טחון_, iến, هیمی_
  { {0x31af01e2,0x09050036,0x6ca700e5,0xfd610016}},	//   nüz_, ипин, _مصال, huyế
  { {0xbc680029,0x290300dc,0xe8f6004a,0xe8f93797}},	//   _ممكن_, ója_, илы_, тло_
  { {0x7b1704f9,0xe0d200b2,0x26c21286,0x28a6005d}},	//   lţum, קײט_, teko_, _खारि
  { {0x1036000a,0xa036000a,0x6a670058,0x0000006a}},	//   יטתם_, יאתה_, _إطال,
  { {0xd8f50086,0x38ca0086,0x6b45002c,0x8f360008}},	//   _پزشک, رایی_, lógo, שארו_
  { {0x88bc0089,0x48670063,0x64a600d0,0x2fc6002a}},	//   lněn, _съдб, јава, łogi_
  { {0x833a005e,0x443e02de,0x07a5167f,0x9c29004f}},	//   вчат_, æt_, _тайн, דֵּ֥
  { {0x44243798,0xaabd000b,0x236b0046,0x973d002a}},	//   ăm_, ्यटक, _žijí_, erćf
  { {0x11da0015,0xc73b000a,0x62863799,0x21a62dfa}},	// [7600] خوذة_, _שתפת, _veko, ризм
  { {0xb05a0029,0xd5b10092,0xd5fb039e,0xdb03007c}},	//   نشاط_, ắt_, _ספיר, ltnä
  { {0x34b7013a,0xc0590036,0xc49b0008,0x9e6611ea}},	//   _דפים_, гії_, _בשית, авед
  { {0xf9870074,0x88bc0089,0x98a51501,0x9f650030}},	//   _وب_, jněn, rolę_, átás_
  { {0x88bc0089,0xc27b000a,0x7b170045,0x6263005e}},	//   dněn, _ברכי, rţul, _євра
  { {0x2bba0029,0x6bd60015,0xcbc60015,0x8d13005e}},	//   ناعة_, لتعر, لزبي, одії
  { {0x69d90176,0x9be60036,0xb5fb379a,0xefd50033}},	//   _arwe, рілк, ncár, _лютэ
  { {0x2b930092,0xbea3379b,0x539b000a,0x6b6a002a}},	//   ịch_, _маск, דיקו, _węgo
  { {0x38c80086,0x6c960029,0x5e9b000a,0x2bb8000b}},	//   هادی_, _نشاط, _שבמק, _आहवा
  { {0x63be003c,0xd90e0086,0x61eb079c,0xa3c8000b}},	//   _oppn, بیت_, ägli, ोटा_
  { {0x60d900b2,0x69d9018b,0x4735379c,0x30d90053}},	//   אַרג, _erwe, йнос, אַרע
  { {0x88bc0089,0x7bfb004c,0x31af0061,0xabfb000a}},	//   cněn, _שפאצ, yüz_, _שהאר
  { {0xceb30008,0x973d016f,0x96470010,0x58d40004}},	//   חיר_, guća, рэнд, _голт
  { {0xd90e0086,0x31af0061,0x89330015,0xe3b300c3}},	//   _آید_, vüz_, _وعوا, يرز_
  { {0xd7fa0001,0x273202e6,0xd7940015,0x7ae2379d}},	//   _јул_, hány_, _البخ, _knot
  { {0xe7050086,0xe1d2000b,0x9fe7002b,0xdb1a16a3}},	//   _دستی, सिंघ, یساه, _astú
  { {0x20670001,0x61d90033,0xa1870033,0x408b0054}},	// [7610] ађев, ымая_, рыбл, вљем_
  { {0x27320089,0x88bc0089,0x399b000a,0x4395271f}},	//   dány_, zněn, כימד, _лаос
  { {0xa2670063,0x83f90850,0xa7fc0061,0x95540015}},	//   _въгл, _сенс_, mcıs, _بخيا
  { {0xa8570008,0x7ff40015,0xdb1a00e1,0x7ae2379e}},	//   ביבה_, غسلا, _estú, _nnot
  { {0xd0870080,0x88bc0089,0x6b6a005c,0x7f85002b}},	//   _выби, vněn, _węgl, _گلزن
  { {0xfbd10029,0x7ae20dd3,0xa7fc0061,0xd256000a}},	//   كتب_, _anot, ncıs, _לשרה_
  { {0x4ea7000d,0x88bc0046,0x94bc000a,0x7f420003}},	//   _врза, tněn, דמות, bloq
  { {0xcac9005f,0xd5b9005d,0xff07005e,0x7ae2002a}},	//   угие_, ेबाज, _тягн, _cnot
  { {0x88bc0089,0xd996002b,0x7bdc001a,0x5cc72e38}},	//   rněn, منيت_, _árun, _всез
  { {0x60c5018b,0x7ae200bd,0x88bc0089,0x77c90054}},	//   nehm, _enot, sněn, глог_
  { {0xdab9008f,0x88bc2af9,0xd90d002b,0xc7b80033}},	//   _былі_, mněl, ویچ_, аёў_
  { {0x98ac0011,0xcb550001,0x6d43379f,0x0a18002b}},	//   todă_, _увећ, llna, افیک_
  { {0x45260015,0x7cfd0144,0x69cb0012,0xdb0303c1}},	//   مرسِ, _aèri, _usge, rtnä
  { {0x7ae200bd,0x07f90115,0x4aa7000b,0x6a24002b}},	//   _znot, _مربع_, _गाँव, _بفهم
  { {0x2bda005d,0x27320089,0x68e3158b,0x68fc2d34}},	//   भिया, zány_, _innd, örde
  { {0xadf9005d,0x14170029,0x6aa937a0,0x27f8007c}},	//   ्नान_, حيفة_, ngef, ärne_
  { {0x9c820007,0xe16a0018,0x6aa90012,0x69c937a1}},	// [7620] ščia, اصره_, igef, nwee
  { {0x273202d5,0xf6170008,0x6aa900b8,0x26d20b63}},	//   vány_, _לחפש_, hgef, _hayo_
  { {0x26d2025c,0x3ceb005d,0xdb1a002c,0x63be2749}},	//   _kayo_, चाने_, _vstú, _uppn
  { {0xf7720008,0xe809000b,0x27320046,0x8e4a0015}},	//   פקד_, हैया_, tány_, هلاك_
  { {0xdd8f0115,0x26d237a2,0xe357000a,0xb606006f}},	//   فون_, _mayo_, _לשטח_, bráť
  { {0x26d20035,0xd13200e5,0x06e4000b,0x4096002b}},	//   _layo_, _رمز_, गाँव_, _دلسر
  { {0x973d016f,0xb60600bd,0x6aa9074c,0x447b0053}},	//   dućn, lišč, fgef, אנצע
  { {0x26d2003f,0xb60600bc,0x497410b3,0x79a622d7}},	//   _nayo_, oišč, олис, брое
  { {0x1efb0053,0xbda50015,0xdce20085,0xb60600bc}},	//   _עלמע, _وحكو, spođ, nišč
  { {0x973d010b,0xdd8f003b,0xa2da005d,0xf7b80004}},	//   gućn, _أول_, _पोस्, агој_
  { {0x6f02006f,0x06e4000b,0xa7fc0061,0xcc77004f}},	//   okoc, गांव_, vcıs, _הגבת_
  { {0x25d90080,0x89d7002b,0x26d20077,0x2d49039f}},	//   аммы_, _گوهر_, _cayo_, núen_
  { {0x7cfd0251,0xdd860029,0x7afd37a3,0xe89408fc}},	//   _sèri, بو_, öste, _даль
  { {0xb60600bd,0xf76f0086,0x64740174,0x290201ec}},	//   dišč, بای_, згру, īkas_
  { {0xd91b00b2,0x249f0064,0x68b7000a,0xae1f000b}},	//   _גוגל, ğum_, _הלוא_, _मेनन_
  { {0x291e37a4,0x8c1b000a,0x6378004a,0x88bc0046}},	//   lita_, אולי, ссёр_, zněl
  { {0x291e00f2,0x6f02002c,0xa4d50210,0xa3ce0046}},	// [7630] oita_, dkoc, _допі, _míří_
  { {0x83190086,0x88bc0089,0x291e37a5,0x657d29ff}},	//   _چقدر_, kněm, nita_, mpsh
  { {0x83190015,0xf53f02d6,0x2957004f,0x69c90546}},	//   _نقدر_, stås_, מסמך_, zwee
  { {0x9f56002e,0x141a0008,0xb60600bd,0x7d1a13ef}},	//   ægðu_, _כותב, bišč, _amts
  { {0x291e025c,0xc694004c,0x3f8e001a,0xdd9b06da}},	//   kita_, פאס_, áfur_, уше_
  { {0x21ba0053,0xed590004,0xdb030003,0x6f02002a}},	//   _דזשא, шол_, muné, akoc
  { {0xd498000a,0x5ea50015,0x973d0085,0x7bdc0030}},	//   זכות_, _ومسل, jućo, _árul
  { {0x69c90041,0x8c160115,0x4af6002b,0xbd6b0054}},	//   twee, غيير_, يکند_, _брже_
  { {0x88bc0089,0x26d20077,0x8d740021,0x7d740015}},	//   mněj, _rayo_, _فالا, _فالط
  { {0x6aa900b8,0x88bc0089,0xc9840001,0x26d237a6}},	//   sgef, lněj, чући, _sayo_
  { {0xb17b01d1,0x26d20035,0x6aa9002e,0x711a000a}},	//   _fråg, _payo_, pgef, שותפ
  { {0x88bc0089,0x7b330011,0xceb20008,0xcf92000a}},	//   nněj, dăug, ֽים_, וטט_
  { {0xa9040086,0x291e37a7,0x15ba0033,0x95830174}},	//   زبین, bita_, шыны_, мляе
  { {0x3a240010,0x6f090026,0x9a56000a,0xd5b10016}},	//   _эміг, _llec, _וינצ_, ắp_
  { {0x26d20035,0xc7460018,0x1c1f000b,0x6f02006f}},	//   _tayo_, _وضعي, यपटल_, ykoc
  { {0xb606018c,0x98ac00df,0x256f00dc,0xa22a0254}},	//   tišč, rodą_, _fül_, ажба_
  { {0xdce00011,0x88bc0089,0x256f0064,0x9f5c0046}},	// [7640] _jumă, dněj, _gül_, áví_
  { {0xb60600bd,0x888c0053,0xa2da005d,0x76440061}},	//   rišč, ָראַ, _पोर्, _iyiy
  { {0xdfd20015,0x753c37a8,0x6f02006f,0x889a000a}},	//   بيض_, morz, tkoc, שבעי
  { {0x63a1002c,0x87ac004c,0x753c002a,0x213a0012}},	//   álne, רשאַ, lorz, soph_
  { {0xdce004f9,0xf2df0023,0x444437a9,0x753c0111}},	//   _numă, _châu_, _hy_, oorz
  { {0xc5cb0008,0x6f090390,0xd47a004c,0xcc870054}},	//   שֶׁ֨, _elec, באַל, обље_
  { {0x44440f75,0x88bc0089,0x8ec60015,0x9ca70015}},	//   _jy_, bněj, _وآرم, زهيل_
  { {0x291e005c,0x93fb01ac,0x39452efb,0x444437aa}},	//   wita_, ילצי, ells_, _my_
  { {0x753c0050,0x444437ab,0x291e37ac,0xf9c6005e}},	//   korz, _ly_, tita_, іщин
  { {0xeb9a0063,0x64410020,0x6f09005c,0x672d016f}},	//   _виж_, ülik, _zlec, _sjaj
  { {0x291e235a,0xe1ff0016,0xdce90085,0x39590144}},	//   rita_, _ngón_, _steć, ïssa_
  { {0x38690064,0xbad50033,0x8f9b000a,0xa2da000b}},	//   _şart_, _нічы, סיכי, _पोल्
  { {0x4444025c,0xdb03002c,0x291e37ad,0x6672002b}},	//   _ay_, ytnú, pita_, رگير
  { {0xe4e405d1,0x444437ae,0x753c002a,0x88bc0046}},	//   місн, _by_, gorz, zněj
  { {0x987b0053,0x59d2000b,0x7b78000a,0xa87b000a}},	//   _דרוק, तिकर, מָּצ, _דאור
  { {0x444437af,0x8b9b000a,0x2bc20065,0x6beb004f}},	//   _dy_, יבלת, _शहना, בַמַ
  { {0x88bc0089,0x764d0061,0xdb03001a,0x78ba0183}},	// [7650] vněj, _uzay, ttnú, oftv
  { {0x44440176,0x6f090298,0xb97b000a,0x673d37b0}},	//   _fy_, _slec, ינמי, losj
  { {0x88bc0089,0x30780015,0x6f0937b1,0xd13800fd}},	//   tněj, تحقة_, _plec, іху_
  { {0xdb0337b2,0xf456000a,0xb69b1d2c,0xdb460015}},	//   stnú, _מיתר_, chât, _سَ_
  { {0x237f016f,0x444437b3,0x88bc0046,0x61e90046}},	//   ćuju_, _zy_, rněj, _šelf
  { {0x88bc0089,0x757c000a,0x656d0061,0x444437b4}},	//   sněj, סטופ, _muah, _yy_
  { {0x4bd9008f,0xcfb40063,0x6b4537b5,0x656d01c2}},	//   сьля_, _обръ, lógi, _luah
  { {0x6f7a000a,0xf2df0016,0xb17b153c,0x3cdb0065}},	//   _לְמו, _thâu_, _tråd, _गोरे_
  { {0x99d2002b,0x644501be,0x60d537b6,0x0000006a}},	//   فقيت, _lyhi, _kazm,
  { {0x00f60008,0xdb1a002c,0x07f90015,0x07a503ae}},	//   ִ֖ים_, _istý, مرجع_, паон
  { {0x6d410b71,0x753c285f,0xbca40015,0x68fc0123}},	//   _ikla, vorz, _زمني, örda
  { {0x753c0050,0xdb230086,0x27f80123,0x656d0049}},	//   worz, _توصی, ärna_, _buah
  { {0x444437b7,0x753c37b8,0x9af20015,0x7cfd0144}},	//   _sy_, torz, _سكوت, _fèrt
  { {0xb97a0008,0xa97a000a,0x19580033,0x89da000a}},	//   _הנסי, _האסכ, _дачы_, _לחני
  { {0xccf20053,0x63860afb,0x987a015b,0xa90400c3}},	//   ײכן_, ягва, _פאקט, _زبون
  { {0xd7fa0008,0xfbd20643,0x444437b9,0x29051f5a}},	//   _להצל, עתן_, _vy_, lkla_
  { {0xf1a90087,0x5bb8000b,0xe2460015,0x753c37ba}},	// [7660] قاله_, _आह्व, سخري, porz
  { {0xd24f0029,0x56370053,0xb1430001,0x6b6a005c}},	//   انك_, _מאפע_, енул, _węgi
  { {0x00190010,0x444437bb,0x8e860015,0xd00f0015}},	//   оўцы_, _uy_, كلاه, هلك_
  { {0x6d4104a7,0x1eaa0015,0x59bd000b,0x0000006a}},	//   _akla, صاصي_, ्बार,
  { {0x62840467,0x26c0003f,0x5de6006b,0x9e3a0015}},	//   mbio, _mbio_, яжда, حساء_
  { {0x98ac002a,0x55bb004f,0x0000006a,0x0000006a}},	//   bodę_, ממנו,   ,
  { {0x69c20150,0x248c002a,0x62841d66,0xb17b02d6}},	//   _spoe, ódmy_, obio, _gråb
  { {0x6d4137bc,0x79a60e71,0x0b180015,0x8f9b000a}},	//   _ekla, прое, تقبة_, _לילי
  { {0x60d50064,0x6da337bd,0xada337be,0x5a34005e}},	//   _yazm, _пита, _патл, ьнит
  { {0x290a12f7,0xe918005e,0x0217000a,0xad650015}},	//   óba_, іоні_, פחים_, _قاله
  { {0x656d168c,0x6c4a0021,0x225c0046,0x7cfd0144}},	//   _suah, _الاف_, ěvky_, _vèrt
  { {0x6d410046,0xe7ed000b,0xeb91000a,0xb9030065}},	//   _zkla, _छपरा_, _יָד_, _पो_
  { {0x673d18f5,0xcb13000f,0x7f3b015b,0x6284002a}},	//   rosj, _אלף_, מעטו, dbio
  { {0x290500c0,0x8cbf000b,0x38c8002b,0x6445008c}},	//   ckla_, ल्पो, _ذاتی_, _pyhi
  { {0x58bb013a,0x88bb000a,0xf8b30008,0x60d5065d}},	//   _המוצ, _המוז, _נשק_, _razm
  { {0xc2c50015,0x2ae5000b,0x60d501c2,0xdb1a016e}},	//   بيري, काएँ_, _sazm, _istó
  { {0xd2340063,0x60f90010,0x2258004a,0xb606013f}},	// [7670] ентъ, оная_, зиты_, _práš
  { {0x80c7000b,0x98ac002a,0x26cb04e6,0x0000006a}},	//   रजें, todę_, leco_,
  { {0x34fc000a,0xd0110015,0xb355033d,0x628437bf}},	//   _להזד, خلا_, _окош, bbio
  { {0x200f002a,0x6d4105e3,0xd251002b,0x98ac0c00}},	//   ągi_, _skla, _لنج_, rodę_
  { {0xb6bc0008,0x9f5c1724,0x200701a3,0x60d50061}},	//   מצאי, ává_, šni_, _tazm
  { {0xee38192f,0x26cb001c,0xe58c000a,0x628f0034}},	//   чні_, heco_, זָהָ, _heco
  { {0x7af9005c,0x41540001,0x6d410227,0xab760015}},	//   _powt, _чврс, _vkla, وموا_
  { {0x64410050,0xbed40054,0x7cfd0144,0x3ceb000b}},	//   żliw, _посј, _pèrs, चाहे_
  { {0xc27c0008,0x0b160029,0x2905013f,0x39350033}},	//   זרחי, بقية_, tkla_, дэнс
  { {0x48050191,0x5e440015,0x6284002a,0x273914b9}},	//   дпов, _أَكْ, zbio, mény_
  { {0xf0920008,0x629d30fc,0xba770015,0xa6ca0a0b}},	//   כני_, _odso, _فاشت, олна_
  { {0xeab00029,0x628f0011,0x2cfa000b,0xba55012c}},	//   _معه_, _neco, ्सॅल_, _قناع
  { {0xe8f50029,0xcb120008,0xe617005e,0xa9090015}},	//   _يستخ, _בלא_, ддя_, _ويصل_
  { {0xd82500d7,0xf992000a,0x629d37c0,0x0000006a}},	//   _одли, _ירד_, _adso,
  { {0x628f0041,0xc9520008,0x8cbf005d,0x98ac0089}},	//   _beco, _שמו_, ल्यो, hodě_
  { {0x63a100dc,0x26c00085,0x2407005e,0xfb19000a}},	//   álna, _ubio_, єнти_, קוּמ
  { {0xa09a0029,0x99680053,0xd6eb01d8,0x628f1139}},	// [7680] قضاء_, ִיאַ_, _וַיָ, _deco
  { {0x8cbf005d,0xc0a90029,0x2617005d,0x798b0034}},	//   ल्मो, كامل_, _पेटी_, _mwgw
  { {0xc209000a,0x600a0033,0x6b450030,0x628f02b9}},	//   סה_, ўнем_, lógu, _feco
  { {0x628f0298,0xe80e000b,0x1fb50033,0xaf0602bb}},	//   _geco, ानता_, эсур, ьпел
  { {0x7c25002c,0xe629004f,0xbf65009a,0x0000006a}},	//   úhrn, ּחוֹ_, ردمو,
  { {0x2cfa000b,0xc617000a,0xe589000a,0x7afd0123}},	//   ्सेल_, וחני_, פָנָ, östn
  { {0x69dd0134,0xfce30004,0x629d00aa,0x0c95009a}},	//   æsen, тојо, _ydso, ردوگ
  { {0x539b000a,0x501b000a,0xdee3004a,0xdb0a0123}},	//   קיפו, _וולו, _иоси, xtfä
  { {0xdceb0061,0xbebd0091,0x7c961092,0xfe431520}},	//   argı, _smūg, _жрец, _анто
  { {0x8dfb000a,0xc7ba004a,0x3dfb05bd,0xcce60040}},	//   _והמת, оём_, _ולמד, _تسري
  { {0x7c650029,0xdb0a0123,0x3ceb0065,0x26cb37c1}},	//   _كامل, ttfä, चारे_, teco_
  { {0xef11000a,0xdb26002b,0xdb1a0144,0x6d4a37c2}},	//   ָּט_, _کوچی, _estò, llfa
  { {0x27680086,0xdb03002c,0x6d4a002d,0x6abc000b}},	//   _کشتی_, ntný, olfa, ्जीर
  { {0x628f0fb7,0xf1b9003d,0xdb0a0b14,0x26cb039f}},	//   _seco, _īš_, stfä, seco_
  { {0x98be0011,0xd6db0036,0x3eaf05d7,0x9d1b000a}},	//   altă_, _дтп_, yggt_, קולט
  { {0xe667049d,0xf79b000a,0x80c1000b,0x973d0085}},	//   _отпо, _ובהמ, र्ने, kući
  { {0x443f005c,0x973d016f,0x115501c5,0x628f003d}},	// [7690] łu_, jući, екаю, _veco
  { {0x7b1704f9,0x3cfa005d,0xc5f2000a,0x4616002b}},	//   nţur, ्सों_, _עדי_, _سوپر
  { {0x442701d1,0x5f94006b,0xfe73002b,0x35f8002b}},	//   _än_, вихт, ندش_, _فرید_
  { {0x8db500fd,0x6267002b,0x98ac0046,0x69dc003d}},	//   ескі, _ياحق, todě_, ārej
  { {0x973d010b,0x31790053,0x7de7002b,0xee2e0432}},	//   gući, _מאָד, بسام, ун_
  { {0x787100dc,0xabd500d7,0xb80e000b,0x4d64005e}},	//   _művé, ециј, ानाम_, вків
  { {0x9f050029,0x8d62004a,0x8c4216db,0xac091ece}},	//   _كوسو, ывше, леше, янка_
  { {0x4ea40010,0xcbd80033,0x6d4a2ce8,0x290e37c3}},	//   _арфа, ьфіі_, alfa, _alfa_
  { {0x1d350063,0x7dc70015,0xdb1a02de,0x09e501f3}},	//   _зная, _تتأك, _optæ, хопн
  { {0xdb030125,0x6c840015,0x5d54145a,0xd0fa004f}},	//   irné, _للكم, _акут, ִּיר
  { {0xb8d7000b,0xeb900015,0x9cd6000a,0x0000006a}},	//   _छा_, _نظن_, _רועה_,
  { {0x6448007c,0x99d70015,0x290e1a5e,0xe5a62c63}},	//   üdim, _يتشا, _elfa_, ними
  { {0xaa070087,0xdb030045,0xba2b0021,0x95960033}},	//   _تظاه, punâ, _بسام_, эшні
  { {0x257400c0,0x80c1005d,0x98a50024,0xf9fa000a}},	//   _väl_, र्मे, rolē_, _מהנמ
  { {0xdddb0947,0xd37200e5,0xb8d3000b,0xfbc7006e}},	//   _neuž, اهر_, टल_, دت_
  { {0x2ba7000b,0xdb03013f,0x98a501ec,0x0000006a}},	//   _गिना, ytný, polē_,
  { {0xcb120053,0x05770015,0x947a0342,0x41aa006b}},	// [76a0] אלן_, _كمية_, _нсну_, яван_
  { {0x973d0085,0x3d09000b,0x61eb0123,0x81460015}},	//   vući, वसों_, ågla, رنان
  { {0xa4b70008,0x24b7004c,0x88bc0046,0x34b7000a}},	//   _אליה_, _אהין_, mnět, _אפים_
  { {0x6710005d,0x216a03e7,0x88bc0046,0x3f86006f}},	//   ासिक_, _ними_, lnět, ďou_
  { {0x6e930067,0x9e65002b,0xe4fa000a,0x629637c4}},	//   الها, ناهن, ּפֶש, mayo
  { {0x659b015b,0xdb03006f,0xace70054,0x629637c5}},	//   לינק, rtný, емља_, layo
  { {0xdb030264,0x1fb505c1,0xcec30046,0x7b662143}},	//   stný, _истр, íří_, нтие
  { {0x629633c8,0x6e930029,0xa6db002e,0x88bc0089}},	//   nayo, _ملفا, koða, hnět
  { {0x88bc02d5,0xcf57000a,0x95ef000b,0x5eeb000a}},	//   knět, _טבלת_, _चपेट_, _צַלְ
  { {0x7e0b000a,0xfd97000a,0x6c860058,0xbce50058}},	//   _מִבֶ, _נדבך_, _ألام, _لأمو
  { {0xf53f00c0,0x62960b63,0x082a004a,0xeb9a0004}},	//   från_, kayo, яции_, _ѕид_
  { {0x8a460029,0xca760010,0x1dd4000b,0xab770015}},	//   _كَان, _чужы, _धनात, _أمنا_
  { {0x8afb0008,0x49730033,0x80c1000b,0x80d3000b}},	//   _מהאי, _бліс, र्डे, ड़मे
  { {0x25a40014,0xba290015,0x63a1376f,0x056801ca}},	//   ámla_, _تسمم_, álno, ејси_
  { {0xa295008f,0x2c34000a,0x92950117,0x63ae0160}},	//   каві, דָּם_, кавц, gubn
  { {0xdb18002c,0xe2c90029,0x62960035,0xa6db002e}},	//   ftvé, بورو_, gayo, boða
  { {0x4ac2005d,0x6b5b000a,0x30a7008d,0xd1b80015}},	// [76b0] व्यव, לדלפ, ерев, فالا_
  { {0xf8b10008,0xb17b00c0,0x62960035,0x33750731}},	//   ֹשׁ_, _från, aayo, _игор
  { {0x230b0015,0xbfab0033,0xdb180030,0x351c004f}},	//   _فتحي_, ятае_, atvé, _מוזנ
  { {0xc7b30008,0xfe700018,0x63a8006f,0x539a0c44}},	//   טבע_, مده_, ádne, _קירו
  { {0xa69c0053,0x7afd0123,0x4ea401f3,0xec6e0b98}},	//   לשאפ, östm, урха, ип_
  { {0x7f850015,0x7c94006b,0x313537c6,0xe1ff00a1}},	//   _للسن, гръц, _регр, _ngói_
  { {0x7c940086,0x313402ed,0xf53f02dc,0xdce9007f}},	//   اشها, _серр, yrån_, _eteğ
  { {0x2d8d09f2,0x7e7b003f,0x99d50031,0x88bc0046}},	//   _twee_, _ufup, نتخا, znět
  { {0x12e8000a,0x0edd000b,0xa7fc0061,0x3ec20030}},	//   תֽוֹ_, _नोएड, mcıy, értő_
  { {0xb0c70010,0x6606008c,0x245c0046,0x74ad000b}},	//   дпiс, vykk, námé_, _जागृ
  { {0xab84000d,0x3cfa0053,0xdab90010,0xe73a37c7}},	//   _бучк, _קלענ, _жылі_, ден_
  { {0xfbd201d8,0x80c1000b,0xd62a005e,0x6b6a002a}},	//   _כתב_, र्ते, доме_, _węgr
  { {0xaa880029,0x50b3005d,0xb0b3000b,0x88bc0046}},	//   _أنهم_, ुभाष, ुभाग, tnět
  { {0x290b0024,0x2b400796,0x97c5005e,0x66060595}},	//   īcas_, čice_, _айке, rykk
  { {0xa8480015,0x629637c8,0x88bc0046,0x3f47007c}},	//   _كلهم_, tayo, rnět, nõus_
  { {0x2d8004f9,0xf7720008,0x6d430509,0x9836000a}},	//   ţiei_, _דקה_, hona, _ברצף_
  { {0x88bc0089,0x973d016f,0x6d4337c9,0x50960054}},	// [76c0] pnět, guću, kona, вређ
  { {0xb17b0123,0x6d4337ca,0x629637cb,0x0000006a}},	//   _trån, jona, sayo,
  { {0x62960035,0xaf360086,0x888c0053,0xdb1800dc}},	//   payo, پرات, פראַ, stvé
  { {0xbe660115,0xa856000a,0x4f26006b,0xb7fa000a}},	//   نهاي, דיעה_, ъдеб, ופעת
  { {0xdd8f0029,0x9db700e5,0xdb030034,0x6d431202}},	//   قون_, ندوز_, ernï, fona
  { {0x80c1014e,0x3076119f,0xdfd2002b,0x6b550091}},	//   र्दे, _шумс, _پير_, _išgy
  { {0x7bb30015,0xdea2002b,0x60dc0cb4,0x8e860015}},	//   لإيط, _نیای, _iarm, _للأه
  { {0x1a66002b,0x49d8004a,0x8c430054,0x60dc37cc}},	//   نیای_, едию_, јеће, _harm
  { {0x4d660010,0x2498002a,0x6b45026a,0x6d4337cd}},	//   _акав, karm_, tógr, bona
  { {0x998d005c,0xdc750033,0x2b4d00bc,0x60dc37ce}},	//   dzeń_, _быць, alec_, _jarm
  { {0x394c0a99,0x66950054,0x645a001a,0xd7f7004a}},	//   rlds_, ланђ, ýtil, вуя_
  { {0x75270298,0x60dc0152,0x8f9b004c,0x7b330045}},	//   wijz, _larm, ויטי, năul
  { {0x6f0303af,0xcb67000d,0x858b0033,0x236000bc}},	//   ênci, _раце_, ьёна_, dmij_
  { {0x062401b7,0x224b0123,0x7bdc0030,0x0000006a}},	//   рфюм, _ryck_, _árus,
  { {0x18a300d0,0x98a30054,0x24190033,0x752725c2}},	//   _тајм, _тије, ховы_, rijz
  { {0x237e00dc,0x533407c1,0x61e600bc,0x6d4337cf}},	//   ítja_, аест, _brkl, zona
  { {0x998d005c,0x42740004,0x6d4337d0,0x6d5a008c}},	// [76d0] czeń_, ргус, yona, _ohta
  { {0x50670015,0x4095006e,0x67240f81,0xb9bb000a}},	//   نطاق, الار, _zmij, וצמת
  { {0xd2600024,0x1eea0086,0x6d4337d1,0x7e770015}},	//   ļņas_, کونی_, vona, ناشئ
  { {0x5ea40029,0xe7e3000b,0x6d430cc1,0x6f0037d2}},	//   لممل, गिता_, wona, _comc
  { {0xddc51635,0x60dc37d3,0xa7fc0061,0x61e60085}},	//   убли, _farm, rcıy, _grkl
  { {0x621a00f3,0x3f47007c,0x60dc108f,0x6d4301e0}},	//   _טורק, tõus_, _garm, uona
  { {0x8b940010,0x5f942586,0x6d4337d4,0xb4fc000a}},	//   арыч, _вист, rona, ולגר
  { {0xe9d91fdb,0x5458000a,0x6d430ebc,0x8f690058}},	//   еки_, כסון_, sona, _أمرك_
  { {0x7c3a05ed,0x764d0c99,0xe9690891,0x6d4337d5}},	//   _extr, _nyay, наил_, pona
  { {0x6724016f,0x08d5006b,0x29110069,0x973d0160}},	//   _smij, уция, óza_, kućs
  { {0xa088000a,0xaf910033,0xd825107c,0x8afd0046}},	//   כְרִ, авiл, удни, emře
  { {0xeef50008,0xef12000a,0x6b7a004c,0xa3e7000b}},	//   אמֹר_, ֶּר_, _טרענ, पिन_
  { {0xaa0b0029,0x9f4e0030,0x2d800045,0x2adf0065}},	//   _تزال_, ónév_, ţiev_, _खोएँ_
  { {0x998d005c,0x7afb37d6,0x58870088,0x9f5c0030}},	//   rzeń_, ljut, _рыда, ávú_
  { {0x998d005c,0x88ba000a,0xdce9006f,0x24490058}},	//   szeń_, _נזקי, _oveľ, نجفي_
  { {0x7afb064e,0x26de0024,0x2aec000b,0xc7b2000a}},	//   njut, ētos_, झाएँ_, _הבה_
  { {0x60dc37d7,0xdb0a37d8,0x05a8000b,0x42530015}},	// [76e0] _parm, énés, _कटिब, منفر
  { {0x7afb007c,0x98a50091,0xdb0301be,0x394537d9}},	//   hjut, rolė_, lunä, nols_
  { {0x60dc37da,0xbeaa0086,0x94bb0008,0x20562c52}},	//   _varm, فهان_, _אמית, утар
  { {0xee3a078f,0x69cb0384,0x8f450036,0xef1a04f7}},	//   нне_, _opge, ахід, эме_
  { {0x7afb37db,0x3945003d,0x272f008c,0x61e637dc}},	//   djut, kols_, lönä_, _urkl
  { {0xfbd20029,0xd657000a,0x61e437dd,0x8078004f}},	//   متع_, ניסת_, mvil, _יְֽה
  { {0x4fd8000a,0x5bc30015,0x394537de,0x79821514}},	//   _בַּד, مقول, dols_, _stow
  { {0x61e404f6,0x29030123,0x7afb07e0,0x7d010160}},	//   ovil, öjan_, gjut, _eols
  { {0xcb670001,0xee370063,0xda660015,0x80c1000b}},	//   ћање_, _бнт_, داثي, र्वे
  { {0x41bb00b2,0x91bb0135,0xc1bb004c,0x7afb007c}},	//   עציע, עמיי, עמיש, ajut
  { {0x4735111b,0xac970029,0xd8e30010,0x5719005e}},	//   инос, _إنما_, сцып, вжня_
  { {0xd6db022a,0xcdd4000a,0x7bda37df,0x8037004c}},	//   хто_, ֑ךָ_, _istu, רנטע_
  { {0x7d010061,0x466b004a,0x394537de,0x160c0065}},	//   _yols, эром_, bols_, हनगर_
  { {0x69c00007,0xb9db000a,0xdb1a016e,0xee2e0033}},	//   mtme, _נחוש, _estô, ўнi_
  { {0x25a0003e,0xa9230089,0xa87b0447,0x69c037e0}},	//   _evil_, ížej, _ארוח, ltme
  { {0x67bb0008,0x2bac021e,0x73f80015,0x69c00079}},	//   _נמחק, _घटना, دِّر_, otme
  { {0x765a005c,0x26c9003f,0xd1bb0015,0xc1770015}},	// [76f0] ętyc, _ibao_, عارا_, ادرت
  { {0x31c40001,0x7bda37e1,0x926803fb,0xba57000a}},	//   љств, _ostu, урса_, רסמו_
  { {0xdfd100e6,0x69c0007c,0xff072b41,0x4fd507be}},	//   تيا_, htme, лядн, ржет
  { {0xaf4b012c,0x5064027c,0x7d010d3d,0x6da50058}},	//   رشال_, стуа, _sols, لمصم
  { {0xfda70001,0x829a0053,0x7d01037f,0x7dc40015}},	//   ујем, _בױרק, _pols, متوك
  { {0x1bb90086,0x7b210003,0x0658000a,0xc57c000a}},	//   نابع_, nœuv, אידך_, ערות
  { {0x6e950036,0x20c40010,0x2d840064,0x61140001}},	//   _вибу, _усяг, _etme_, _удру
  { {0x7afb007c,0x49c901b7,0xdb03007c,0x7d0137e2}},	//   ujut, влин_, htnö, _wols
  { {0x7afb0005,0xa2dd005d,0xdb180089,0x39450251}},	//   rjut, _पसन्, ctví, tols_
  { {0x2b40116e,0xf8400092,0x661d0024,0x7afb05ff}},	//   čica_, ườn_, dzsk, sjut
  { {0x69c0003e,0x61e40796,0xa7a9006b,0x661d2c8a}},	//   atme, zvil, ъкна_, ezsk
  { {0xd5e60080,0xf7461310,0xabfa000a,0x966606a6}},	//   ажми, ремо, _בהער, икне
  { {0x69c000da,0x20c6000b,0x394537e3,0xd7f80045}},	//   ctme, र्डध, pols_, axă_
  { {0x2ed2000b,0xf9900021,0x69cc0045,0x7bda0034}},	//   _सस्त, _ربه_, âneş, _ystu
  { {0xdb030020,0xe29a1f8c,0x232a0bb1,0x9bc9004f}},	//   punä, кав_, вови_, כֶּ֖
  { {0x883a009d,0x25a000cb,0x27ea02de,0x1dc5000b}},	//   _בתצו, _tvil_, æbne_, लझात
  { {0xc0760001,0xc693000a,0x64a60317,0x673d0030}},	// [7700] аћењ, _ואח_, _капа, érje
  { {0x865b013a,0x11d70029,0x659b000a,0xd59b000a}},	//   _בדפי, ؤولة_, _שייק, _שביל
  { {0x98be003d,0x61e437e4,0xe0430e64,0x9c7c0160}},	//   notā_, svil, онфи, _jače
  { {0x539b013a,0x639b000a,0xc43b000a,0x98ac003d}},	//   _ביטו, _בסטנ, _יתיי, indā_
  { {0x80c1005d,0x1ea90029,0xd8380844,0x69c00400}},	//   _रॉके, طاني_, mače_, xtme
  { {0x1d890029,0xbd870015,0x5ba637e5,0xd838174f}},	//   ائني_, جنون_, ариз, lače_
  { {0xed570001,0x2bb70029,0x9c7c37e6,0x1d070054}},	//   јој_, لاية_, _nače, реји_
  { {0xa3e7014e,0x2ba7005d,0x6f190026,0x5fdb0008}},	//   पित_, _गिरा, chwc, _בחלק
  { {0xb99702bf,0x3f680061,0x0000006a,0x0000006a}},	//   авых_, _oğuz_,   ,
  { {0xdde90086,0x57b40080,0x4c98000a,0x69c037e7}},	//   _حرفه_, ббот, _תֹּא, rtme
  { {0x7989005c,0xad1b000a,0x69c037e8,0xa157000a}},	//   apew, _שובר, stme, שביה_
  { {0xb0c6005d,0xf53f0971,0x6b8a207b,0x61e90046}},	//   र्तग, pråk_, mpfg, _šelm
  { {0xef110053,0x661d0089,0x95d8006b,0x8afb000a}},	//   פּט_, uzsk, адят_, _שהדי
  { {0xf8060036,0xb8940015,0x661d006f,0x98be003d}},	//   _вчин, _الثع, rzsk, botā_
  { {0x68fc0020,0xe4e40010,0x97d70002,0x734b005e}},	//   ördu, ціян, _نظير_, вчав_
  { {0x27a90053,0xd83800bd,0xd3700029,0x42750033}},	//   _עספּ, gače_, ِهِ_, сгас
  { {0x9c7c018c,0xcad7000a,0x94ab0004,0x9abe0138}},	// [7710] _zače, סומת_, _итна_, _цiха_
  { {0x823400e6,0x2ba7000b,0x87da000b,0xa5bb002a}},	//   زرقا, _गिला, _बनाऊ, rzód
  { {0xd498008f,0x20070011,0x6f190034,0x6448007c}},	//   _тры_, âni_, thwc, üdit
  { {0xc7f7000a,0xf3fa004c,0x63b500bc,0x0000006a}},	//   יזבת_, _עִיל, muzn,
  { {0xa2f60008,0x9758000a,0xd838013b,0x0000006a}},	//   _המרה_, ביאו_, načb_,
  { {0x645a0012,0x8b95016a,0x0000006a,0x0000006a}},	//   ütig, брич,   ,
  { {0x1d06006b,0xdfd8006b,0xab292de5,0xdb030077}},	//   сещи_, _кът_, лока_, erná
  { {0xd438009d,0xe438000a,0x2bb8000b,0xfebb002b}},	//   יטוי_, ירוח_, _इमरा, _جاست_
  { {0xd5ed0023,0xceb2039e,0x9c7c0085,0xdd91002b}},	//   _ngà, _מין_, _sače, _روا_
  { {0x29030084,0xe8f91017,0x98be003d,0x7015000a}},	//   ðja_, уло_, totā_, ֶחָד_
  { {0x3829041b,0x5746006b,0x66e62cb0,0x4c140058}},	//   ужно_, йноб, бона, _وبمس
  { {0x273200bd,0xfb840086,0xceb2000f,0x1ae4005e}},	//   kšne_, _بگوی, ּים_, _моєм
  { {0x4df900b2,0x9985003b,0xda78010f,0x7afd0020}},	//   נפֿא, _التو, _тях_, östu
  { {0xa879004c,0x63a80247,0xaa580054,0x7a540015}},	//   _גאַר, ádno, _тичу_, _بضما
  { {0x58f60008,0xd8380107,0x6379004a,0xa507024f}},	//   _למסע_, tače_, истр_, щера_
  { {0xf7430805,0x7bc3001a,0xdb0a0046,0x82f50138}},	//   _нещо, itnu, oufá, очуц
  { {0x171b0008,0xe717000a,0x7bc3007c,0xdb03001a}},	// [7720] _תופע, _לחקר_, htnu, funú
  { {0x644810cc,0xb5fb000a,0x2f31002a,0x3179002a}},	//   üdis, _עליכ, iągu_, _dusz_
  { {0x44770008,0xee860010,0xc20900a3,0xe7ea000b}},	//   _לעיל_, было, עה_, टिया_
  { {0xbda6003b,0xf4870086,0xdfcf00e6,0x5f25005e}},	//   محتو, _پایی, عين_, офіз
  { {0xdee5003b,0x1df8004a,0x7bc3006f,0xdb0a0012}},	//   تألي, релы_, etnu, rtfü
  { {0xa1160067,0x865b000a,0xdce10091,0x3257000a}},	//   _اوست, נדסי, _kilę, _לסכם_
  { {0xeb4a006b,0x9be601f3,0xeb9702d9,0xdee613d0}},	//   лчик_, сілк, биј_, _лови
  { {0xef910086,0xa0370008,0x2b4000bd,0xe29f002e}},	//   _آیند, _האלה_, čico_, _koða_
  { {0x2b55002b,0xed5a012f,0xee3a0fe9,0xdca60585}},	//   آیند_, _боа_, _сна_, _гази
  { {0x9d46004a,0x0000006a,0x0000006a,0x0000006a}},	//   _уезд,   ,   ,
  { {0xd6d50256,0xd787002b,0xf093004f,0xbce50058}},	//   ожны, ینیو_, הנת_, _بأقو
  { {0x3057013a,0xdd120024,0x20570008,0x6d4a16d3}},	//   משיך_, kļūs, מייל_, lofa
  { {0xceb30008,0x8cbf005d,0x96340033,0x0000006a}},	//   היר_, ल्को, зняц,
  { {0x80ca000b,0x49bb004f,0x6d4a37e9,0x0000006a}},	//   स्मे, _עמוס, nofa,
  { {0x9388005f,0x7ae20020,0xe5280010,0x24180256}},	//   йста_, _kaot, сіяй_, боры_
  { {0xe29f002e,0xddc9005c,0x7ae20e95,0xa6db001a}},	//   _boða_, _cześ, _jaot, koði
  { {0x90991705,0xa5bb0030,0x6d4a37ea,0x0000006a}},	// [7730] иват_, szób, kofa,
  { {0x29c20084,0x672f005c,0x7bc3099c,0x7ae237eb}},	//   iða_, licj, ytnu, _laot
  { {0x660f00c0,0x8fa40015,0xc7a9004f,0x0000006a}},	//   lyck, كمله, ֹׁנָ,
  { {0x672f005c,0xdb03002c,0xdb1801c0,0x3f87003d}},	//   nicj, sunú, ytvá, īnu_
  { {0x644a002a,0xc694004c,0x660f0123,0x645a001a}},	//   ęliś, לאף_, nyck, ýtiv
  { {0xdb180e5f,0x212a37ec,0x7c8400af,0xace9116f}},	//   ntvæ, _gmbh_, пуће, рмка_
  { {0x9b450115,0xf36b000a,0xff5300c3,0xc0580138}},	//   ينتو, ְדִּ, _فخر_, _гіт_
  { {0xc9a9010f,0x2f180010,0xa6db002e,0x3eb90293}},	//   авие_, _лось_, boði, _øst_
  { {0x88d5008f,0x29c2002e,0xf2d4004c,0x7bc30c6b}},	//   оўні, gða_, לעק_, stnu
  { {0x6d4a005c,0x660f0089,0xb0870033,0x8e380015}},	//   cofa, dyck, абiс, _اسفر_
  { {0xe8f60127,0x29c2002e,0xc5e9000a,0x070a0015}},	//   ілю_, aða_, _שד_, ليدي_
  { {0xdb180134,0xe737005e,0xfbd0002b,0x366a1079}},	//   etvæ, жею_, _ستم_, иано_
  { {0x18a52c4f,0xd54a0015,0x98a50561,0xddc9002a}},	//   _далм, لجسم_, _диле, _rześ
  { {0xddc9005c,0x98a50024,0xdd7a0053,0x7fc90065}},	//   _sześ, bilā_, יטשל, _रहूँ
  { {0xccf20008,0x68e3003f,0x9c7c0085,0x672f002a}},	//   וכם_, _iand, _jača, bicj
  { {0x6d4a000c,0x25ad0089,0x6abb3072,0xdb120061}},	//   zofa, šela_, nguf, şgör
  { {0xd83800bd,0x6d4a003f,0x290737ed,0x68e337ee}},	// [7740] mača_, yofa, _kona_, _kand
  { {0x290737ef,0xd83830f4,0x68e31632,0x20560979}},	//   _jona_, lača_, _jand, отер
  { {0xdfa60015,0xaad9000b,0x68e337f0,0x9c7c0bf6}},	//   تحذي, ढ़ाक, _mand, _nača
  { {0x29c2002e,0x645e37f1,0x4379000a,0xe1ba002b}},	//   yða_, _izpi, _לְשׁ, _پُست_
  { {0xbdf70015,0x6da30a1f,0xdd900015,0x6d4a37f2}},	//   قروا_, дича, روث_, tofa
  { {0x7ae2002d,0x0d990010,0x9e65002b,0xe58905bd}},	//   _saot, стцы_, سانن, זָקָ
  { {0x7eb60015,0x26c00077,0x62840cf7,0x660f002a}},	//   _ومسؤ, _ocio_, ocio, zyck
  { {0x39a60036,0x68e3049c,0x7dc60015,0x62841309}},	//   ошов, _aand, _وتذك, ncio
  { {0x29070251,0x80c1000b,0x68e337f3,0x6cd60015}},	//   _bona_, र्के, _band, _وقرا
  { {0x29c20084,0xdd8f0086,0xa3ca000b,0xed5a006b}},	//   rða_, _شوم_, लझा_, _тоз_
  { {0x7ae20005,0xc07b0053,0x807b0053,0x907b000a}},	//   _taot, יטיש, יניצ, יטיי
  { {0x80ca005d,0xda65002b,0x660f0c3d,0x7bdb000a}},	//   स्ते, _کامي, tyck, _כקבו
  { {0x29070024,0xfa360002,0x9c7c37f4,0x7d080123}},	//   _fona_, _براد, _zača, _kods
  { {0x32d50092,0x660f2631,0x25fc000b,0xa3c9000b}},	//   _ấy_, ryck, _ऊपरी_, ोबल_
  { {0x7d080134,0x38cb002b,0xa7570021,0x98be0091}},	//   _mods, _خانی_, _وضعت, gotą_
  { {0x8c1b000a,0x5335005e,0xf7f3002b,0x68e31094}},	//   בולי, чебт, _آسود, _zand
  { {0x68e30064,0x291e0e95,0x672d37f5,0x7d08042f}},	// [7750] _yand, ohta_, _imaj, _oods
  { {0xa5080001,0x98ac0007,0x98be0b48,0x3ebf0045}},	//   _мења_, rodė_, botą_, _scut_
  { {0x3cfe005d,0x645a002e,0xc10400e6,0x7038002b}},	//   लाने_, ýtit, بولي, يسمس_
  { {0x6284329b,0x28ca000b,0xb17b00cb,0xddc10033}},	//   ccio, ़्ति, _bråt, еткi_
  { {0xfe7004b6,0x97580008,0x291e01c2,0xcddb03ae}},	//   نده_, קידו_, khta_, рње_
  { {0x3eba0091,0x80c2000b,0xd8380085,0xa17a000a}},	//   ėpta_, _लाये, zača_, _לטשט
  { {0xeb990a2c,0xce950063,0x7ed700e5,0x251c00f3}},	//   щий_, _навъ, _وزرا, שווא
  { {0x273200bd,0x290737f6,0xe291000a,0x130b000a}},	//   kšna_, _sona_, ךְ֙_, יהֶ֑
  { {0xd83837f7,0x68e321f7,0xb17b30a6,0x629d37f8}},	//   vača_, _pand, _gråt, _meso
  { {0x2ba50048,0x9c7c0085,0x629d37f9,0x6284002a}},	//   pēc_, _tača, _leso, zcio
  { {0x6f1b0050,0xd838122c,0xc174000a,0x765a002a}},	//   _kluc, tača_, וחץ_, ętym
  { {0xa6db002e,0x629d37fa,0xe73a37fb,0x291e12a5}},	//   koðu, _neso, сем_, ahta_
  { {0xe9ce37fc,0x645e005c,0x291e002d,0xd8380b6c}},	//   _як_, _szpi, bhta_, rača_
  { {0x291e0f45,0x68e30bd6,0xd8380085,0x672d007c}},	//   chta_, _uand, sača_, _emaj
  { {0x629d37fd,0x78fa000a,0xe3b10015,0x8d5a000a}},	//   _beso, _לפסו, َرِ_, מכשי
  { {0x98a504f9,0x26d937fe,0xd764002b,0x65d60058}},	//   bilă_, ceso_, _تنبی, _فيعط
  { {0x28c2014e,0xb6bb000a,0x93130015,0x6284329b}},	// [7760] _शामि, _הצפי, روكش, rcio
  { {0x20b90010,0xc0e3005e,0x645a001a,0x62840a45}},	//   жыць_, ноук, ýtis, scio
  { {0xd47b000a,0x547b000a,0x62842e2f,0x6f020045}},	//   _לאיל, _לטיו, pcio, tjoc
  { {0xa6db002e,0x629d37ff,0x78a13800,0x93fb000a}},	//   boðu, _geso, halv, _הלטי
  { {0x7d083801,0x5ea3006e,0xed5a0342,0x78a13802}},	//   _pods, رمول, бод_, kalv
  { {0x60220014,0xac970029,0x5cc3006b,0x6f1b3803}},	//   _címé, كنها_, есъз, _eluc
  { {0x9ca70015,0x6f1b1bfa,0x7d083804,0x6e220030}},	//   سهيل_, _fluc, _vods, szob
  { {0x612001e2,0xa03b00b2,0xdee322b2,0xe80f005d}},	//   _bölg, _העלפ, _поси, ाहना_
  { {0xa9c30033,0xdb0a0123,0x79990034,0x78a10030}},	//   нсэк, ktfö, _cwww, falv
  { {0x78a10f28,0x98a50045,0xed090015,0x61200012}},	//   galv, vilă_, _وآله_, _wölf
  { {0x80c1014e,0xdc750010,0x6120002e,0xf8b80092}},	//   र्टे, _жыць, _tölf, ghĩa_
  { {0x9bfb0008,0x10370008,0x56940142,0x61202061}},	//   _להבט, לטים_, нают, _höld
  { {0x26d92be0,0x394c00da,0x629d08aa,0x61200061}},	//   reso_, pods_, _reso, _gölg
  { {0x26d900b6,0x2564002e,0x629d3805,0x2ec8000b}},	//   seso_, jöld_, _seso, रभुत
  { {0xd83800bd,0xccf80089,0x7d57000a,0xa6e3001a}},	//   mačo_, _mně_, פילד_, áðst
  { {0x083b0008,0xc7d70008,0xd7bb0008,0x883b000a}},	//   _לעול, _זוהי_, _הצהר, _לתוו
  { {0x9f47002d,0x629d00bd,0x7178012e,0xd6fa000a}},	// [7770] íní_, _veso, збур_, _וִיש
  { {0x612b005c,0x86380008,0x44443806,0x629d002a}},	//   ożli, _מרחב_, _fx_, _weso
  { {0xd2b50033,0x6f1b0ca8,0x6f093807,0x629d2244}},	//   зiдэ, _pluc, _poec, _teso
  { {0x63b5018c,0xde190115,0xb7db000a,0x80c1000b}},	//   mrzn, يقات_, מקבי, र्जे
  { {0x6f1b0111,0xdef40010,0x4e780015,0x1d0912fd}},	//   _vluc, эпцы, أحمد_, жели_
  { {0xf3b7000a,0x9598004f,0x61ed3808,0xf0750058}},	//   ִּ֔י_, לכדו_, mval, _يُحد
  { {0x9c7c016f,0x78a10458,0x61ed3809,0xdfd40088}},	//   _tačn, valv, lval, _поры
  { {0x7b15002c,0x291c380a,0x25a91bd0,0x6d582244}},	//   _záuj, _alva_, _oval_, alva
  { {0xe29f09f0,0x61200014,0x3ead0293,0x78a1380b}},	//   _með_, _föld, _idet_, talv
  { {0x98350010,0x36e6000b,0xdb030125,0xdb0a0123}},	//   дэмі, _जोड़ी_, isné, xtfö
  { {0x6d410079,0xb0cf000b,0x99d5002b,0x78a1207b}},	//   _ijla, स्यग, ستکا, ralv
  { {0xdb03002c,0x09f90029,0x612000dc,0x3b640015}},	//   hrnú, _وفاة_, _zöld, _كُلِ
  { {0x78a1022d,0xdb0a00c0,0x0ab40015,0xa5bb0030}},	//   palv, ttfö, _أحمد, szón
  { {0xcdb6000a,0xf8ce0016,0xb97a000a,0x7ae9380c}},	//   ופשה_, _hứng_, _ונסי, ldet
  { {0x58940029,0x27220092,0x58d205e6,0x3cfe000b}},	//   _أجهز, _nóng_, _ројт, लाते_
  { {0x00e40086,0xdb0a13f0,0xd67a0015,0x179a000a}},	//   کتری, stfö, _بحثا_, _ויקב
  { {0x80c2005d,0x61ed380d,0x64450390,0x98a50091}},	// [7780] _लादे, gval, _exhi, ailą_
  { {0x27220092,0x7ae900f2,0x3ead0064,0xa5b70dab}},	//   _bóng_, hdet, _adet_, _קליק_
  { {0x69c9022d,0x044603ad,0x3366009c,0xaec60004}},	//   htee, _ценн, _овог, дбел
  { {0x69c91601,0xa25b0152,0xbefa0029,0x61ed0024}},	//   ktee, _icôn, غراض_, bval
  { {0x1dda00a2,0x7ae91493,0x8d6a00d0,0xad660015}},	//   تباع_, ddet, ојка_, واته
  { {0x273200bd,0x69c90020,0x98be002a,0x61200061}},	//   kšno_, dtee, botę_, _böle
  { {0x6120002e,0x69c9043c,0x1fb50033,0xc8780061}},	//   _völd, etee, _пстр, neğe_
  { {0xf8ce0092,0x69c9003e,0xd00b000a,0xaf060033}},	//   _cứng_, ftee, _וּמֹ, _ўпал
  { {0x7b730029,0x49740004,0x28c2000b,0xf8ce00a1}},	//   خطوا, нлис, _शादि, _dứng_
  { {0x7ae907f6,0xd917004a,0xad650015,0x61200030}},	//   adet, дью_, _كاله, _föle
  { {0x8c3c0064,0x9c830107,0xe759005e,0xdb4f004a}},	//   _beğe, _účas, зині_, _аю_
  { {0x872b0010,0x63bc380e,0x61ed19ff,0x29050160}},	//   іўна_, durn, yval, ajla_
  { {0x8c3c01e2,0x69c90298,0x8a03006b,0x98a5002a}},	//   _değe, ctee, _изце, wilą_
  { {0x63b5005c,0x8e200010,0x29030123,0xd83a004a}},	//   trzn, нiк_, öjat_, _мэй_
  { {0x63bc010b,0xd7e60036,0x58bb0008,0x88bb000a}},	//   gurn, _ціло, _ומוצ, _ומוז
  { {0xf8ce0092,0xeb910008,0x7bca00c7,0xd3540015}},	//   _xứng_, רָם_, itfu, نَّة
  { {0x41790029,0x27220092,0xd567380f,0x869c000a}},	// [7790] سماح_, _sóng_, _отоп, _ויחז
  { {0x7ae900dc,0x3f87001c,0xf8b1000a,0xf1550015}},	//   zdet, ínuo_, ָשׁ_, رَاد
  { {0x753504ed,0x61ed3810,0x7ae90941,0xc7b1004f}},	//   mizz, sval, ydet, ָ֑ב_
  { {0x75350ede,0x26dc0053,0x7ed40010,0x69c900f2}},	//   lizz, ַקומ, вішч, ytee
  { {0x69c9003e,0xa3e7000b,0x8e740015,0x80ca0065}},	//   xtee, पिक_, ناهض, _सॉके
  { {0x753504ed,0x6df20015,0x69c9007c,0x7bca16a9}},	//   nizz, اكوا, vtee, ftfu
  { {0x4fc40797,0xfbd10040,0x7bca01d0,0x7ae93811}},	//   _иста, اتت_, gtfu, tdet
  { {0x69c9022d,0x7ae90057,0x9f050015,0x3ead0739}},	//   ttee, udet, _ثورو, _udet_
  { {0x7ae903c0,0x69c90201,0xae59004c,0x5d840015}},	//   rdet, utee, _זכּר, _للقل
  { {0xf8b1002b,0x7bca00da,0x69c915fc,0x6e450045}},	//   اکش_, btfu, rtee, ărbă
  { {0x309a0008,0x6be40029,0xa5bb00dc,0x69c93812}},	//   השתמ, _لكلم, szól, stee
  { {0xc4c90008,0xfc160053,0x612000dc,0x69c93813}},	//   _לג_, _אקעי_, _kölc, ptee
  { {0x6b810020,0x4a9a0053,0xceb20008,0x59c40029}},	//   _hulg, _זינג, ניך_, _لينك
  { {0x59d8000b,0x6b81007c,0x4aa5000b,0xb607001a}},	//   _बैटर, _kulg, _ऐ़डव, _spáð
  { {0xc8780064,0xf8b2000f,0x6b813814,0xd91a000f}},	//   teğe_, _עשה_, _julg, _מוסל
  { {0xf7d6000a,0x63bc001a,0xd83e0046,0x6b810158}},	//   _נופש_, rurn, íčem_, _mulg
  { {0xda1f000b,0x22460061,0x2aba0061,0x22470ffe}},	// [77a0] यनित_, çok_, lübü_, епти_
  { {0x753502d7,0x63bc1a26,0x2259005c,0xb97a004c}},	//   cizz, purn, _dysk_, פרעז
  { {0xa3e7000b,0xb80f000b,0x5436002b,0x031a0015}},	//   _मैप_, ाहिम_, _سردر, _فتحت_
  { {0x26c20035,0x612000dc,0x73e3034e,0x705300e6}},	//   ngko_, _bölc, _союз, دنما
  { {0xed5a0124,0xc27b0008,0x2d96005e,0xf2d3004c}},	//   под_, _מרכי, хрес, _גער_
  { {0x61e6010b,0x763b004c,0x6b813815,0x7bca0400}},	//   _iskl, הענג, _bulg, ttfu
  { {0x2259002a,0x61432b9d,0x2722006f,0xa157004f}},	//   _zysk_, _сера, _zóne_, _נבלה_
  { {0x200d0064,0x28c2000b,0x63a10045,0x61e6174d}},	//   çmiş_, _शाहि, âlni, _kskl
  { {0xf98f0086,0xa3e7000b,0x98ac003d,0x49d70033}},	//   یبی_, _मैन_, eidā_, едыю_
  { {0xf1b301d8,0x6b8133fa,0xd8f8005e,0x9c7c05e3}},	//   נסת_, _fulg, фної_, _mačk
  { {0x31370008,0x5bc50015,0x645a007c,0x753502b9}},	//   תנים_, _لتنف, ütil, vizz
  { {0x8c1b0008,0xfaa6045f,0xa5bb0030,0x29030123}},	//   _מובי, _чадо, szóm, öjar_
  { {0x753504ed,0x4b370008,0x05770015,0xb7140121}},	//   tizz, _אראל_, فاسد, удящ
  { {0x2b40016f,0xe4e405d1,0x93970015,0x22590123}},	//   čicu_, лісн, فجرا, _rysk_
  { {0x75353816,0x39570008,0xd90e002b,0xf3672c63}},	//   rizz, _רשום_, _نیک_, етан
  { {0x3f870084,0x443f0011,0x24580033,0x9c7c3817}},	//   ínum_, ău_, хась_, _bačk
  { {0xbb3b000a,0x80c2000b,0xcad7000a,0x1be20065}},	// [77b0] פעמי, _लाशे, עומת_, _कैसल_
  { {0xda4b000a,0x98be0046,0x6aa20125,0xd045002b}},	//   הֲבָ, votě_, _leof, نپذي
  { {0x7b1c0152,0xc4350086,0x442700c0,0xc4d2000a}},	//   _réun, _شکست, _ån_, _דגי_
  { {0xdb010057,0x22592b0e,0x7ff40015,0x9e750015}},	//   _ovlá, _tysk_, دسكا, نهات
  { {0x6b810020,0x6463016f,0x1bf9000b,0x867c000a}},	//   _sulg, štić, ऍमऍल_, פרגו
  { {0x271e005d,0xb820000b,0x25e9000b,0x6b813818}},	//   _पत्र_, मनाम_, _छननी_, _pulg
  { {0xfaf10029,0xcb690015,0x5e950015,0x1d06006b}},	//   لثة_, ومته_, _للأط, тещи_
  { {0xe29f002e,0x6b812070,0x61200030,0xadbd0033}},	//   _boði_, _vulg, _tölc, _мабi
  { {0x39450c55,0xea880015,0x6b81002a,0xe9690b27}},	//   книг, رخين_, _wulg, маил_
  { {0xcda80015,0x3f83007c,0x6b81007c,0x0e3402a3}},	//   _أهله_, _kuju_, _tulg, _сную
  { {0x97830086,0x8c190015,0x08d40033,0x2ca715fc}},	//   دیبه, _تيار_, уцыя, mand_
  { {0x81c3003d,0xeb98005e,0x2ca73819,0x6aa2381a}},	//   ģēju, _чиї_, land_, _geof
  { {0xee32000a,0x7aeb02de,0x0000006a,0x0000006a}},	//   ֹֽר_, _iagt,   ,
  { {0x32dc0016,0x2ca7381b,0x0000006a,0x0000006a}},	//   _ậy_, nand_,   ,
  { {0xdb010107,0x64a315ce,0xf8b6000a,0x03a3004a}},	//   _zvlá, раса, _ספקי_, ииро
  { {0x78a302e9,0x2b04000b,0x2ca725f8,0x9343381c}},	//   _henv, वायु_, hand_, ансе
  { {0x98a5005c,0x7aeb381d,0x60ea004a,0xcb12000a}},	// [77c0] wilę_, _magt, ммам_, בלן_
  { {0x31230010,0x7aeb00c0,0x4f96000d,0x2ca72544}},	//   адуг, _lagt, врду, jand_
  { {0x98ac0011,0xa3ba0015,0x70530015,0xdff500fd}},	//   lidă_, _غادر_, لنكا, ляць
  { {0x7aeb00b6,0x9c7c016f,0xee3a381e,0x69d908cf}},	//   _nagt, _tačk, мне_, _opwe
  { {0x54360086,0x2ca700b8,0x61e619df,0x28c2000b}},	//   _سرگر, fand_, _uskl, _शालि
  { {0x5d530033,0x8d630c68,0x9c7c381f,0x6146012b}},	//   акіт, авче, _kači, _рега
  { {0x4fa30036,0xdddb002a,0x9c7c0085,0x5ba30033}},	//   _висв, _czuł, _jači, арыз
  { {0xf4130008,0xdd920031,0xcefa002b,0x25ad0046}},	//   שפה_, _نور_, _تفرش_, šeli_
  { {0xcb670001,0x89d80018,0x78a33820,0xd8380796}},	//   њање_, رودر_, _benv, mači_
  { {0x61e400b8,0xbce50002,0x3105000b,0xd105000b}},	//   iwil, _مأمو, रायः_, रायण_
  { {0x61e41817,0x2d57000a,0x78a33821,0xbf110046}},	//   hwil, _ישמש_, _denv, žíšo
  { {0x9c7c060b,0xb8f9005d,0x78a30161,0xd83802c6}},	//   _nači, _डॉ_, _eenv, nači_
  { {0xfb1b013a,0x61e40079,0xc66b004a,0x25ad0003}},	//   _קודמ, jwil, ьшое_, éel_
  { {0x78a30525,0x69c03822,0x7ae03823,0x61e419e6}},	//   _genv, mume, lemt, dwil
  { {0x2d840667,0x94740015,0x2458004a,0x2914002a}},	//   _lume_, لدفا, варь_, ęcać_
  { {0x08570008,0x3ea40134,0x395e0123,0x1877000a}},	//   _שבהם_, _nemt_, llts_, _בעור_
  { {0x2d8404f9,0x60f91292,0xd49b0054,0x200e0012}},	// [77d0] _nume_, нная_, _орн_, äfin_
  { {0xd4990036,0xdce80089,0x7bda016f,0x31c40cb9}},	//   _якої_, _vidě, _optu, јств
  { {0x442a005c,0x69c03824,0x2ca73825,0xc49a004f}},	//   czb_, hume, vand_, _אשתת
  { {0x4e94003b,0x141a0008,0x2ca704de,0x63ba006f}},	//   لشهر, _נורב, wand_, átne
  { {0x7bda0048,0x4ed40036,0xf1a4012e,0x3267008b}},	//   _aptu, рюєт, _врсн, _штов
  { {0x7aeb3826,0x3fb70029,0xdb03002e,0x9c7c3827}},	//   _sagt, _لإرس, rsní, _zači
  { {0x7aeb00b6,0x3134005f,0x78a30152,0xdb800010}},	//   _pagt, _терр, _renv, орыi_
  { {0x3ea40134,0x39e90001,0x1ee7002b,0xb9280016}},	//   _gemt_, едио_, _جوری_, _thuở_
  { {0x2ca70bf5,0xa3c5000b,0x80ca000b,0x7aeb02de}},	//   pand_, उंड_, स्के, _vagt
  { {0x78a800dc,0xfd100029,0x7aeb3828,0x645a007c}},	//   gadv, _وجل_, _wagt, ütik
  { {0xc1d0005d,0x98150086,0x6bb40036,0xec150002}},	//   _सङ्ग, ابخا, _всіє, _حواد
  { {0x2ca51965,0xc9f500e5,0x8b9a000a,0x7aeb063b}},	//   _held_, _مستع, _נבנת, _uagt
  { {0x6d433829,0x9a84006b,0x27320016,0x69c0382a}},	//   onna, _тухл, hơng_, cume
  { {0x5e560053,0x27220251,0x3eba0007,0x9c7c0085}},	//   רישע_, _dóna_, ėpti_, _sači
  { {0x9c7c00df,0xb8f7000b,0x2ca5382b,0x68e1382c}},	//   _pači, ाभ_, _meld_, meld
  { {0x28cf014e,0x083a0053,0x98ac0011,0x273200bd}},	//   त्रि, _רעקל, pidă_, kšni_
  { {0x62660083,0xd5af0029,0xf8a7000b,0xd6a9002b}},	// [77e0] уваа, _ففي_, _ग़ाय, _شديم_
  { {0x68e1382d,0x859b000a,0x80a6006e,0x659b000a}},	//   neld, _רשיו, امان, _רייק
  { {0x9c7c00df,0x6724010b,0x05770008,0xd8380057}},	//   _tači, _klij, _תגים_, tači_
  { {0x68e1382e,0x643b0008,0x91860086,0x6d43382f}},	//   held, _טעינ, _مجسم, enna
  { {0xdd8f003b,0x4dd30029,0x01660029,0x9757000a}},	//   كون_, متوس, _مُحَ, נינו_
  { {0xdb18002e,0x3fa60115,0x68e131d4,0xd8380085}},	//   ruví, _مصرف, jeld, sači_
  { {0xa0670083,0x68e10171,0xfbcf0015,0xddd0002a}},	//   _бара_, deld, كتي_, _żeńs
  { {0x69c03830,0x6d433831,0xe9a8002b,0x7c2a0012}},	//   tume, anna, نگتن_, rzfr
  { {0xdb0a0152,0x2ca500b8,0x78a83832,0x2d84003f}},	//   nsfé, _feld_, tadv, _uume_
  { {0x9e4b0008,0xdb0100c0,0x68e10e7b,0xdb0a0125}},	//   _אֲבִ, _avlä, geld, isfé
  { {0x6ac60074,0x815700b2,0x67240298,0xafa20010}},	//   _مقام, רסיע_, _blij, авiк
  { {0x3989002e,0x37070004,0x0c370015,0x2918007c}},	//   _fús_, учов, _حكمة_, örab_
  { {0xe5c70033,0x68e1376b,0x0000006a,0x0000006a}},	//   ысно, beld,   ,
  { {0x7e7d002c,0x67243833,0xf993000a,0xe2a6001a}},	//   _úspe, _elij, _הרס_, áðna_
  { {0xf7700086,0xdb03001a,0x657e3834,0x245902ed}},	//   تای_, runö, _diph, тавь_
  { {0x57fb0008,0x322b042b,0x291e3835,0x8e2001f3}},	//   _טלוו, нізм_, lkta_, нiм_
  { {0x6d430176,0x41b50086,0x6d5a3836,0x291e0061}},	// [77f0] ynna, شمار, _okta, okta_
  { {0x3eb8003d,0xc2740054,0x291e3837,0x9a420016}},	//   _ērta_, слуј, nkta_, _đằn
  { {0xa2d0005d,0x6724008c,0x6441002a,0x155c000a}},	//   _डॉक्, _ylij, źlib, _אכזב
  { {0x539a013a,0x256400c0,0xceeb0086,0x6d5a3838}},	//   _שירו, höll_, عران_, _akta
  { {0xdbde0084,0xfe71002b,0x6120001a,0xde050004}},	//   _síða, زگر_, _köll, рпли
  { {0x8b05005c,0x91ba000a,0x0bb5006b,0x5bc50015}},	//   _mięś, _במשי, ащия, لقتل
  { {0x2ca50161,0x2f3b0015,0xb4fc000a,0x5f9405ab}},	//   _veld_, _كثرة_, תפוי, _гист
  { {0x09d5008f,0x2ca50176,0x63a1002c,0x1df70086}},	//   ацоў, _weld_, álny, _مکتب_
  { {0x25640123,0xaa450818,0xc9a6004a,0x68e12433}},	//   föll_, репл, авые_, teld
  { {0x6724010b,0x7d790086,0xbdf80029,0xe8f63839}},	//   _slij, _شمار_, _حرفا_, аль_
  { {0x6c84003b,0x1bb80031,0x80ca000b,0x69dc0045}},	//   _المم, _مانع_, स्टे, ărea
  { {0x3989002f,0xe73a383a,0xef12000a,0x9056000a}},	//   _tús_, тем_, ַּר_, יבתו_
  { {0x7b7404b6,0xaa880029,0x645e002a,0x7bc33352}},	//   _اطلا, _إنهم_, _sypi, lunu
  { {0xdb0a00b8,0x4a44042b,0xb8090015,0x291e0123}},	//   zufü, _унів, _ليتم_, ckta_
  { {0x7ce8000a,0xa956000a,0x7bc3383b,0x61200061}},	//   נַשֶ, _דיסק_, nunu, _döll
  { {0xc3230e88,0xc7b20008,0x95862ea0,0xf7720015}},	//   омск, _ובה_, _клие, _بات_

  { {0x645e005c,0xb6060007,0x09b5004c,0x7bc3383c}},	// [7800] _wypi, ukšč, יפּט_, hunu
  { {0x7b330045,0xb6060091,0x645e383d,0x41030ee7}},	//   găuz, rkšč, _typi, озув
  { {0x94bb000a,0x04950033,0x7bc3383e,0x3fe61114}},	//   _במית, _урыў, junu, ржев
  { {0xe806005d,0x8f450036,0xbe850015,0xdfcf0021}},	//   षमता_, бхід, مجهو, ظين_
  { {0x7e69002a,0xa5bb0030,0x4f650015,0xcd0602c4}},	//   _czep, szóv, حالف, ички
  { {0x7bc3002e,0x8e20005e,0x21a311bd,0xd5f7004c}},	//   funu, нiв_, _фирм, יזנט_
  { {0x237f0057,0x9c7c0046,0x4ae60033,0x62830046}},	//   ňuje_, _načt, аўпа, ěnov
  { {0x3f9a008c,0x7bf7006b,0x0000006a,0x0000006a}},	//   mppu_, рнър_,   ,
  { {0x9c7c15eb,0xacea000d,0x9e650015,0xd906005e}},	//   _raču, _имаа_, _هاكن, аїно
  { {0x9c7c016f,0x9cb30015,0x7bc3383f,0x69340174}},	//   _saču, _ومقت, bunu, ённу
  { {0x4c360010,0xe8380036,0x7bc3062c,0x28b7000b}},	//   _тэат, упні_, cunu, _आयरि
  { {0xdc3b0008,0x8f9b004c,0x8b05002a,0x291e0085}},	//   _בעבר, כיטי, _pięś, skta_
  { {0xb9940029,0x9f6500dc,0xd8380d98,0xc9940015}},	//   _التب, ítés_, vaču_, _التظ
  { {0x61200061,0x48e30054,0x25640030,0x6d582a33}},	//   _bölm, _мочв, lölj_, nova
  { {0x80aa014e,0x6b880041,0x612000b8,0x92a7050e}},	//   टरने, _judg, _völl, ијал
  { {0xa87b009d,0x6d583840,0x987b0135,0x187b004f}},	//   _באור, hova, _ברוק, _בטוב
  { {0x673d3841,0x61f90010,0x6d58053e,0x7bc30061}},	// [7810] misj, ынаў_, kova, zunu
  { {0x6d580107,0xd46b0015,0x7bc30061,0x7e69002a}},	//   jova, _لحجم_, yunu, _rzep
  { {0x7e6912e0,0xc7a9000a,0x80070033,0x13f50033}},	//   _szep, ָׁנָ, шчае, _узня
  { {0xbf580036,0x673d003c,0x7bc33842,0xf456000a}},	//   арії_, nisj, vunu, _ליתר_
  { {0x6d583843,0x8c3c007f,0x0000006a,0x0000006a}},	//   fova, _değm,   ,
  { {0xc27a0008,0x7bc30ae3,0x6d583844,0x6b883845}},	//   _תרשי, tunu, gova, _budg
  { {0x16a7000b,0xbbf50015,0x25640123,0x9cb20015}},	//   _ख़ूब, إستث, följ_, سميت
  { {0x7bc33846,0x0ae9004a,0xcda9002b,0xc332000a}},	//   runu, удий_, _مهره_, ּ֕ה_
  { {0x673d003c,0xdd940010,0x7bc327af,0x6d58336b}},	//   disj, _маты, sunu, bova
  { {0x6d580264,0x7bc33847,0x661d1200,0x7c870054}},	//   cova, punu, dysk, _ђузе
  { {0xbb85003b,0xc5e90008,0xdb18002e,0x753c0024}},	//   _الصي, _רד_, duvæ, virz
  { {0xb925002b,0xcaf40015,0xb82600f4,0x28d80065}},	//   _گفتي, _وسنب, союз_, ब्बि
  { {0x98780048,0xcb120008,0x612000c0,0xe73704ab}},	//   kšķi_, _מלא_, _dölj, сея_
  { {0xf992000a,0xae5a004c,0xa5c7001a,0xc964005e}},	//   _צרו_, רכשר, _stóð, _двій
  { {0x612001d1,0xc7950002,0x89340015,0xe4e50033}},	//   _följ, _اشتب, _بعنا, ціўн
  { {0xe7ec005d,0x935a3848,0x6d5829d0,0x33660033}},	//   _जनता_, ургу_, zova, ёваг
  { {0x95c9000d,0xdb0e00dc,0xe0da0a0b,0xf1a90021}},	// [7820] _куќа_, ájék, лва_, لاله_
  { {0x6d58099c,0xd00a0254,0x6146005e,0x98be003d}},	//   xova, лезе_, щеза, ontā_
  { {0xdfcf00a2,0x6d5832d9,0x8e3a002b,0x7e60010c}},	//   فيل_, vova, گسار_, _symp
  { {0x3f9a00e8,0xdb030123,0xdfa50015,0x8cda000b}},	//   rppu_, nsnä, تحكي, प्नो
  { {0x9c7c018c,0x6d580480,0xa2f7000a,0x98ac0091}},	//   _načr, tova, _המכה_, aidę_
  { {0x40ab0086,0x6d581bff,0x0000006a,0x0000006a}},	//   _مخفی_, uova,   ,
  { {0x2bb70029,0x661d005c,0x3cf70015,0x6b740a86}},	//   ماية_, zysk, صعود_, олку
  { {0x9b440015,0x6d58049e,0x661d008c,0x501b000a}},	//   تنعو, sova, yysk, _גולו
  { {0x673d31d4,0x5e4a3849,0x6d580dd9,0x25640030}},	//   visj, _спам_, pova, rölj_
  { {0x57b40142,0x0217000a,0x7189000a,0x64400061}},	//   обот, צחים_, סְפַ, şmiy
  { {0xa3e7005d,0x515b0008,0x415b0053,0xe9cf002b}},	//   _मैं_, רכיו, רדיג, وغی_
  { {0x661d384a,0x95cb2124,0xdb030123,0xcdd4004f}},	//   tysk, луга_, gsnä, ֗ךָ_
  { {0x99d30018,0x0000006a,0x0000006a,0x0000006a}},	//   _فتوا,   ,   ,
  { {0xea770008,0x673d003c,0x661d005c,0x3f980024}},	//   _הגדר_, sisj, rysk, _otru_
  { {0xb8de021e,0x3cf0000b,0xe534004a,0x9c7c00bc}},	//   ेल_, _इसने_, черь, _začr
  { {0xd3700029,0x6b82003f,0xc2c50015,0x61200030}},	//   ّهِ_, _jiog, تيري, _fölk
  { {0x60870029,0xd6e8000a,0xd7f80045,0x41e400fd}},	// [7830] مشاك, _הַתָ, lvă_, зіха
  { {0xdb1801be,0x69c0384b,0x0000006a,0x0000006a}},	//   luvä, irme,   ,
  { {0xc1040029,0x7e990015,0x69c00012,0x836b0015}},	//   ثولي, لنار_, hrme, _مصحف_
  { {0xe2f90036,0xdb18007c,0x62830046,0x9df90302}},	//   _темі_, nuvä, ěnos, инет_
  { {0x2f740015,0x69c002de,0xa227006e,0x848b004f}},	//   أطلس, jrme, _طرحه, ְטֵ֥
  { {0xe3b00086,0x2d8100b8,0x80d8000b,0x912b0015}},	//   _تری_, öhe_, न्दे, _إسحق_
  { {0x251c00b2,0xeb9903e7,0x69c0384c,0xdb18014b}},	//   רווא, ший_, erme, kuvä
  { {0xaf340015,0x3f5c001a,0x0000006a,0x0000006a}},	//   _فرقت, síur_,   ,
  { {0x6b820026,0x3eaf02de,0x3f5c001a,0x799b02f2}},	//   _diog, magt_, píur_, upuw
  { {0x78a90001,0x3eaf02cd,0xdca40054,0x718c000a}},	//   шког_, lagt_, _нађи, נְחַ
  { {0xd70a008f,0x69c0384d,0x1869113a,0x073a0015}},	//   анне_, arme, рани_, لسحب_
  { {0x61ef002d,0xa6db002e,0x373a005e,0xdb18007c}},	//   _oscl, eiðb, рчою_, guvä
  { {0xe9ce005e,0x25640030,0x0a6b0054,0x64b30046}},	//   _юк_, löli_, _сржи_, _ořiď
  { {0x612000b8,0x2bc6000b,0xfbdd000b,0xdb0100cb}},	//   _völk, रूवा, _महाम, _avlø
  { {0xa87900b2,0x98790053,0x9c29000a,0xe7320015}},	//   _דאַר, _דאַט, בֵּ֥, _يصب_
  { {0xe29a000d,0x798300b8,0x33660033,0x3eaf344e}},	//   раа_, _hinw, іваг, jagt_
  { {0x6aab0014,0xa5bb0030,0x80aa0850,0xf0aa0350}},	// [7840] _megf, szór, ивав_, икал_
  { {0x6aab0014,0xb09a005e,0xe04602ed,0x0000006a}},	//   _legf, ртає_, онзи,
  { {0x61ef384e,0x6ecd0030,0x79830034,0x4fea20ae}},	//   _escl, zőbő, _minw, рмен_
  { {0x57cc00b2,0x9e66384f,0x268d000a,0x8f76005e}},	//   רמאַ, овед, ְנוּ, цузі
  { {0x2ee6003e,0x6df60015,0x3f87001a,0x4c94004a}},	//   reof_, تكشا, ínur_, пилс
  { {0x412a0a7f,0xd6570008,0x98be0045,0x63450091}},	//   _того_, חינת_, intă_, vėni
  { {0xdcfa0048,0x6b8202b9,0x4093002b,0xdee60015}},	//   _citā, _piog, _آلفر, _وأري
  { {0xa037000a,0x539b000a,0x6ecd0030,0x547b004f}},	//   _ואלה_, ביקו, tőbő, סטקו
  { {0xc8780061,0x6ab90034,0x69c00546,0x0000006a}},	//   meği_, _ddwf, urme,
  { {0xdce80048,0xdddb0085,0xad26002b,0xc878007f}},	//   _vidē, _uguš, _بررو, leği_
  { {0xf09301e4,0x99e3002c,0x80cf005d,0x78aa001a}},	//   ונת_, ĺňaj, स्टइ, _vefv
  { {0x798300b8,0xc8780064,0xd7f80011,0x5694006d}},	//   _einw, neği_, rvă_, мают
  { {0xceb30008,0xdb18007c,0xdcb10016,0xa6e2001a}},	//   ויר_, ruvä, _hỏa_, óðab
  { {0xa3a703ae,0x798302f2,0x6d4a3850,0xdb18005b}},	//   жјак, _ginw, nnfa, suvä
  { {0x68e83851,0x2cac0026,0x389b0008,0x44253852}},	//   medd, _medd_, _דיונ, ál_
  { {0x80d8000b,0x2cac0795,0x6d4a0012,0x249e0061}},	//   न्से, _ledd_, hnfa, ıtma_
  { {0x8c3c0482,0x2cac0b7c,0xe72b0086,0xa4870029}},	// [7850] _deği, _oedd_, _مسکو_, _وجدن
  { {0x68e80026,0xdb0a00b8,0x2cac0026,0x21670033}},	//   nedd, erfü, _nedd_, ітаг
  { {0xdb18007c,0xa29500fd,0x129507f9,0x0000006a}},	//   ltvõ, _нані, _нинџ,
  { {0x68e80026,0x5319000a,0x98ac005a,0xaf3402be}},	//   hedd, _הוֹצ, tidě_, ورنت
  { {0x80d8005d,0xc3320053,0xed4e0001,0x7de70015}},	//   न्हे, _טוט_, ео_, تسام
  { {0x427a0008,0x68e8003c,0x3eaf3853,0xa1290015}},	//   _לארג, jedd, sagt_, _اكسل_
  { {0x68e83854,0xdb18007c,0xa4bc004f,0xc878007f}},	//   dedd, htvõ, שֶׂי, beği_
  { {0xc87801e2,0xeab10015,0x7f490015,0x7e7d013f}},	//   ceği_, رعب_, _الرق_, _úspo
  { {0x68e80026,0x7b1c0003,0x2cac0034,0x61ed3855}},	//   fedd, _réut, _fedd_, nwal
  { {0x3ead0111,0x77c90010,0x7c070015,0xa8190015}},	//   _heet_, блог_, _وباك, متجر_
  { {0x25a90375,0x3cf80015,0xf8ae002b,0xe8f6005e}},	//   _awal_, _بعقد_, اکه_, їлю_
  { {0xd5b80048,0xf77200e5,0x2d853856,0xe737008b}},	//   ņām_, عاد_, _hile_, зею_
  { {0x7ae90020,0x3ead0106,0x95960033,0x98ac0061}},	//   meet, _meet_, яшні, aldı_
  { {0x6a240015,0x80c7000b,0xfd07006e,0x61ed3857}},	//   _تفهم, _लागइ, رج_, dwal
  { {0x2d853858,0x69c90f80,0x29073859,0xb8f20015}},	//   _mile_, luee, _inna_, _سكيب
  { {0x2d85003f,0x7ae90607,0x2b910016,0x74130015}},	//   _lile_, neet, _mác_, روقا
  { {0x63b50014,0x229c0089,0x7bc30107,0x61ed385a}},	// [7860] aszn, jáků_, hrnu, gwal
  { {0x3f84000c,0xa6db002e,0x2d850705,0xa3e7000b}},	//   _simu_, miða, _nile_, _मैक_
  { {0xc8780064,0xa6db002e,0x7ae90020,0xf1a9000a}},	//   teği_, liða, keet, רס_
  { {0x2cac0bc8,0x2d85385b,0xdfcf0015,0x6d4a00da}},	//   _sedd_, _aile_, طيه_, wnfa
  { {0x5e5a0015,0xbdf70015,0x7ae9007c,0xc8780061}},	//   حجاج_, كروا_, deet, reği_
  { {0x2b910092,0x2d8502b9,0x6d4a385c,0x69c924a1}},	//   _bác_, _cile_, unfa, duee
  { {0x2b9100a7,0x9c7c018c,0xbea60036,0x3f84385d}},	//   _các_, _obče, _навк, _timu_
  { {0x2d85017e,0x93fb013a,0x68e80176,0xb998385e}},	//   _eile_, מלצי, wedd, ових_
  { {0x2d85052a,0x68e80034,0x2cac0030,0x7bc302ad}},	//   _file_, tedd, _tedd_, arnu
  { {0x2918002e,0xfe450086,0xc237000a,0x2d85385f}},	//   ðra_, _تکمی, פריו_, _gile_
  { {0x7d081405,0x61ed0050,0xbc6a0087,0x4c9b000a}},	//   _inds, zwal, _امان_, _השבע
  { {0x2d853860,0x61ed07e9,0x68e816e0,0xa6db001a}},	//   _zile_, ywal, sedd, fiða
  { {0x98be0007,0x7bca002e,0x8afb000a,0x9b17000a}},	//   entą_, lufu, _להאי, _מחאה_
  { {0x58d3000d,0x05840001,0xda7b0008,0x2d850144}},	//   _зошт, еусм, _הנדר, _xile_
  { {0x2b910023,0xf8db0008,0xd8db0008,0x63a9016f}},	//   _xác_, _החומ, _הקור, ćeno
  { {0xe3b000e5,0x28d8000b,0xe1ff016e,0x61ed3861}},	//   طرف_, ब्रि, _pró_, twal
  { {0x76bc0008,0x8ccd005d,0x9758000a,0x35b50033}},	// [7870] _המחפ, _सालो, _מיהו_, _ўбор
  { {0x395e0048,0x61ed3862,0x72040015,0x229c0046}},	//   nots_, rwal, عولم, váků_
  { {0x61ed000c,0x3d10005d,0x2d850045,0x9f04002b}},	//   swal, ढाने_, _rile_, کونو
  { {0x2b910092,0xe6bf000b,0x7bc30085,0x248f0091}},	//   _rác_, ्लिङ, vrnu, šomą_
  { {0xff500029,0x41e4017f,0x12fa000a,0xfe700002}},	//   دخل_, _піра, _והרב, هده_
  { {0x3ead00f6,0x644e00bd,0xd62c000a,0x395e003d}},	//   _weet_, šniš, מ֥וֹ, jots_
  { {0x2d85000c,0x395e0048,0x672605d8,0x7ae90607}},	//   _vile_, dots_, ykkj, teet
  { {0x256400dc,0x394c04d0,0x3f150010,0xbcdb002b}},	//   lölt_, ends_, _ўдас, _گذرا_
  { {0x1dd1005d,0x7ae90100,0xedd50031,0x78890015}},	//   _समित, reet, _زياد, يَةِ_
  { {0x2b910023,0x2d85002f,0x3eb80024,0x8d740015}},	//   _tác_, _uile_, _ērti_, _كالا
  { {0x61200084,0x7ae90020,0x86c60021,0x6f0902f7}},	//   _tölv, peet, ويدن, _knec
  { {0x98ad01e2,0xfb840033,0xfaa80015,0x3878001a}},	//   ının_, _зычн, _فهمي_, ýrra_
  { {0x61200014,0x6f1b3863,0xcb12000a,0xdcfa0045}},	//   _költ, _mouc, _שלד_, _uită
  { {0xdce80007,0x28d4000b,0x6f1b3864,0x29070b35}},	//   _didė, _दायि, _louc, _unna_
  { {0x3cf0005d,0x66010024,0x289a000a,0x889a000a}},	//   _इससे_, ālka, _ויצא, _ובצי
  { {0x6d43349c,0xa6db002e,0xa22a000d,0x82f5006b}},	//   hina, liðn, ожба_, нчуц
  { {0x05b50033,0xb6bb000a,0x9f43008c,0x7bca0012}},	// [7880] _псэў, _וצפי, _yrjö_, zufu
  { {0xa6db002e,0x69c600bd,0x2564002e,0x6e22003f}},	//   niðn, škeg, tölu_, vyob
  { {0xc0590036,0x6f1b1a8b,0x4f660015,0xbe8a0402}},	//   пії_, _bouc, واصف, осле_
  { {0x7d1a0005,0x6d4300df,0xf41304dc,0x3f9c0024}},	//   _sots, eina, _ספר_, īvu_
  { {0xdd8f06e4,0x6120002e,0x9f6500dc,0x6f090089}},	//   لون_, _sölu, ítás_, _dnec
  { {0x6d4303b8,0x7bca00d5,0x39923865,0x0000006a}},	//   gina, tufu, _râs_,
  { {0xfbcf003b,0x7bd8007c,0x395e3866,0x6f1b027b}},	//   لتي_, utvu, vots_, _fouc
  { {0x1b77003b,0xa6db002e,0xdee600e5,0x6d433867}},	//   وصية_, eiðn, _تأسي, aina
  { {0x4423005c,0x395e0024,0x3ea600dc,0x4abf000b}},	//   zyj_, tots_, mbot_, _एयरव
  { {0x61200084,0x394c003e,0x66e1005d,0x672d12df}},	//   _tölu, unds_, ग्नक_, _slaj
  { {0x395e0024,0xcb6a15ed,0x8c260087,0x99820046}},	//   rots_, _даже_, _تفاه, šků_
  { {0x613202de,0xba261d9e,0x3a260d7a,0x3ea63868}},	//   _hæld, _одек, _омег, nbot_
  { {0x66640063,0xaac50029,0x672d0107,0xf66b002b}},	//   върз, _أتمن, _vlaj, تحده_
  { {0xb34703af,0xe4e40036,0x95c40058,0x0000006a}},	//   _opçõ, кісн, ضيفه,
  { {0x61e60007,0x3dc600da,0xceb90046,0x98130015}},	//   _apkl, hrow_, _hoře_, _لبيا
  { {0x68f80b99,0x4423005c,0x8c1b000a,0x291c0030}},	//   _havd, ryj_, חולי, _hova_
  { {0x25090086,0x21270086,0x83840080,0x3495070e}},	// [7890] _فردی_, ويری_, тыре, _папр
  { {0xceb90089,0x6f1b3869,0x257602de,0x306b0054}},	//   _moře_, _souc, vælg_, ојен_
  { {0xa3e7014e,0xa3d6005d,0x6f1b386a,0x256400dc}},	//   _मैच_, _समय_, _pouc, rölt_
  { {0x6d43386b,0x5f740015,0xdb0a0dca,0x7e55005e}},	//   wina, نانر, nsfä, нвеє
  { {0xf4850086,0x6d43386c,0xddeb0015,0x6f1b055e}},	//   _تاکی, tina, تراه_, _vouc
  { {0x0d840191,0x8cda005d,0x691f00dd,0x3ea60035}},	//   влін, प्लो, _lêer, abot_
  { {0x61320134,0x6f1b0493,0xac9600e6,0xa3c5000b}},	//   _sælg, _touc, رنيا_, उंट_
  { {0x6d43386d,0x63ba386e,0x61203445,0x3dc601f9}},	//   sina, átni, _föls, brow_
  { {0x61200014,0x27340092,0xda090086,0xbd6b0054}},	//   _tölt, _hãng_, سيده_, _држе_
  { {0x6132386f,0x63a9010b,0x63ba00bd,0x98730024}},	//   _vælg, ćenj, štni, ežāk_
  { {0x3f790053,0x3158004c,0xbd680054,0xf649000a}},	//   ּאָס, ויזן_, _црте_, _פצ_
  { {0xdb0a01d1,0xe732006e,0xabfa000a,0x3f910061}},	//   gsfä, اصد_, _מהער, _muzu_
  { {0xa6db002e,0x9a270029,0xee32000a,0x27340016}},	//   miðl, _تعان, ָֽר_, _lãng_
  { {0x613202de,0x7afb007c,0x7af926d0,0x65770016}},	//   _kæle, ldut, _hawt, _chxh
  { {0x187500b2,0xf7460b1e,0x27340016,0x69db0da5}},	//   _אײַך_, _пеко, _nãng_, ltue
  { {0x14170029,0xdcb10092,0x7afb3870,0xd387004a}},	//   ريقة_, _lẻ_, ndut, ейсе_
  { {0x6462005c,0x7afb0007,0xc5f60015,0xf8d9000a}},	// [78a0] _świę, idut, _أثبت, ּחֲמ
  { {0xb1430418,0x7afb008c,0x865b000a,0xb17b04d1}},	//   гнул, hdut, _מדפי, _upål
  { {0xe1ff00dc,0x14d70135,0x96fa000a,0x69db0201}},	//   _szót_, _אויל_, ּלְת, htue
  { {0x54370086,0xef1a0758,0x539b000f,0x66043871}},	//   _سرپر, яме_, _מיטו, _krik
  { {0x3945002e,0x3ea63872,0x82360015,0xe1950033}},	//   kils_, rbot_, _أرجا, _арсэ
  { {0x3dc63873,0x3ebf008c,0x3eb8003d,0xa5b7004f}},	//   rrow_, _edut_, _ērtu_, גלסק_
  { {0xd47a0053,0x60c10026,0xc4d3000a,0xdfd20015}},	//   האַל, _ôlma, אגו_, _حيز_
  { {0x26c0000c,0x5fdb0008,0xf413000a,0x6d410061}},	//   _ndio_, _מחלק, רפה_, _emla
  { {0xe9460f5c,0x39453874,0x2a970058,0x38c8009a}},	//   ехно, fils_, رئية_, وادی_
  { {0x26c00026,0x8afd0089,0xadb70015,0xf98f0015}},	//   _adio_, voře, _أهلا_, حبي_
  { {0xe7590036,0x31370008,0x59c2000b,0x0137000a}},	//   дині_, גנים_, _शिवर, גרית_
  { {0xd6db004a,0x65950033,0xdb06008c,0x8afd0046}},	//   что_, каму, ämäm, toře
  { {0x6d410176,0xbb3b0008,0x69db3875,0xae03000b}},	//   _ymla, _צעדי, ctue, लियन_
  { {0x98c00024,0x291c02b9,0x39450144,0xdb0a3876}},	//   āpēc_, _uova_, cils_, ssfä
  { {0x2897000a,0x66043877,0x0000006a,0x0000006a}},	//   _אדון_, _erik,   ,
  { {0x2b09005d,0xdb0a0123,0x6beb000a,0xa7f70015}},	//   वाएँ_, arfö, הַמַ, _أعوذ_
  { {0xa6db002e,0x60f904ab,0x6459002a,0x201c008c}},	// [78b0] niðm, мная_, _świd, ävin_
  { {0x859a000a,0x7d1e02dc,0x0000006a,0x0000006a}},	//   _קשתו, öpsl,   ,
  { {0x853c000a,0xf8b3000a,0xaf98005e,0x9ed93142}},	//   _מגזי, רשע_, етіх_, дмет_
  { {0xdcb10092,0x798a003f,0x30780015,0x93270015}},	//   _sẻ_, _lifw, رحلة_, _أردن
  { {0x7ed40018,0x69db2fd8,0xa6db001a,0x62670015}},	//   ازما, xtue, viðl, _ساحق
  { {0xfce53878,0xa63c000a,0x27340016,0x8c4504d5}},	//   токо, הגדר, _tãng_, келе
  { {0xdcb10092,0xd10e000b,0x41540054,0xa156000a}},	//   _vẻ_, सारण_, _сврс, _יבשה_
  { {0x7afb008c,0x6441002a,0x25ad0046,0x69db3879}},	//   udut, źliw, šely_, ttue
  { {0x3945038d,0x682b00dc,0x2bcf000b,0x69db008c}},	//   tils_, ködö, संहा, utue
  { {0x6d4100b8,0xc27c000a,0xfe6e002b,0xb902005e}},	//   _umla, הרחי, _بگم_, азьк
  { {0xf09201e4,0x5bc70015,0xec15012c,0x6604050b}},	//   יני_, _ستاف, _جواد, _srik
  { {0x6604387a,0x0a940033,0x69db0bed,0x3945387b}},	//   _prik, _бацю, ptue, sils_
  { {0xbb3a0053,0xceb20008,0x394500da,0x99d70015}},	//   _קעני, סיך_, pils_, _ستشا
  { {0x96a2005d,0xbb44008c,0x629d387c,0x6448006f}},	//   _क्रॉ, äävä, _afso, údio
  { {0x6b8b0134,0x073a0015,0xd4670054,0x442c1549}},	//   _kigg, _يسبب_, вире_, ád_
  { {0x798a003f,0xc7d60008,0x98be003d,0x26c00085}},	//   _zifw, _סופי_, mitā_, _udio_
  { {0x877b0053,0x69c904eb,0x26ee000b,0x25a0387d}},	// [78c0] _קאפי, nree, ज़ीर_, _util_
  { {0x64590050,0x45b70053,0xb5b700a3,0x00c7006b}},	//   _świe, _שפיל_, _שליח_, клук_
  { {0xd2aa0080,0x69c90111,0x6fb30015,0xdfcf0015}},	//   _окне_, hree, لملا, قيل_
  { {0x25ad0011,0xd00f0029,0x3eb8003d,0x5276012f}},	//   ţele_, تلم_, _ērts_, _аугу
  { {0xf2d300b4,0xa6970008,0xe1ff005c,0x2dd70015}},	//   _דער_, דכנה_, _wzór_, نبوة_
  { {0x6da30001,0xa6db002e,0xa0a3387e,0xc5f3000a}},	//   шиља, viðm, _вард, ידד_
  { {0x6b8b25ef,0x2bb70015,0xa157000a,0x69c9387f}},	//   _bigg, ناية_, _סבלה_, eree
  { {0xac250010,0x28d4000b,0x96a2000b,0x69c91b03}},	//   ыфік, _दाहि, _क्लॉ, free
  { {0xecd40086,0x63a9016f,0x7de503c4,0x46b6000b}},	//   _محاک, ćeni, _مسلم, _अज़ह
  { {0xf1b30008,0xc27b00f3,0xc9860015,0x0c7a002b}},	//   ססת_, ורפי, خشبي, _قصاب_
  { {0x26ee000b,0x98730248,0x5bc5006e,0x97a6006b}},	//   ज़ूर_, ильц, _متنف, ърпл
  { {0x16bf005d,0x2d8c3880,0x6b8b3881,0x69c93882}},	//   ्लेब, _hide_, _gigg, bree
  { {0x15ec005d,0x35f40033,0x69dc0045,0x69c93883}},	//   फ़िगर_, апяр, ăres, cree
  { {0x6b8b01f9,0x8afd005a,0x0000006a,0x0000006a}},	//   _zigg, mořa,   ,
  { {0xc9770008,0x80cc000b,0x2d8c3884,0x19570033}},	//   _שגוי_, ालैं, _mide_, _шашы_
  { {0x656e002d,0x2d8c0f47,0x3817000a,0x59a9000b}},	//   albh, _lide_, _יקום_, चीकर
  { {0x88370024,0x1167002b,0x4275090a,0xe1f00058}},	// [78d0] ģēša, نلری_, угас, يسك_
  { {0x89db000a,0x644e0030,0x637a0079,0x44f50974}},	//   וחמי, ániá, eïnd, _спос
  { {0xb4c1005d,0x51841034,0x0000006a,0x0000006a}},	//   ुली_, рута,   ,
  { {0x2d8c038d,0xceeb0086,0x64410030,0xd9f2000b}},	//   _aide_, ظران_, úliu, _अनंत_
  { {0xdcb10092,0x5dd4004a,0x6b8b2bd2,0x7bca3885}},	//   _hỏi_, ающу, _rigg, erfu
  { {0xbebd0024,0x4d64005e,0x69c908cf,0x2d8c007f}},	//   _plūs, аків, vree, _cide_
  { {0xcb690001,0xeb910015,0xa6db001a,0xf3f2000a}},	//   наке_, حظت_, riðj, ֶ֣ה_
  { {0x69c92ba3,0x2b980003,0x2d8c3886,0xa3d60065}},	//   tree, _déc_, _eide_, _समस_
  { {0xc3340008,0x0ae60033,0xceb2000a,0x6aa93887}},	//   יוק_, удый_, _לין_, rbef
  { {0x6e24007c,0xdcf60045,0x752114e9,0x8288000a}},	//   äibe, ăcăm, ölzl, כְתֶ
  { {0xdb23002b,0x7ad50067,0x7c250012,0x69c913f3}},	//   _پوشی, _مقاص, ährd, sree
  { {0xe5a61c35,0xbb44008c,0x6132001a,0x69c93888}},	//   лими, äätä, _mæla, pree
  { {0x26de005c,0x5df9004c,0x3f8d0045,0x7f3a000a}},	//   ęto_, עפֿנ, _mieu_, תערו
  { {0x3f8d038d,0x98a22c63,0xe98000ce,0x0000006a}},	//   _lieu_, _лише, _дачi_,
  { {0xb8f7021e,0x87260015,0x637a2044,0x2b980016}},	//   िल_, _معظم, есар_, _xéc_
  { {0x3f8d00dd,0xd808000a,0x6459002a,0x787a004f}},	//   _nieu_, _יִפָ, _świc, _אָחו
  { {0x9f5e038d,0x02060010,0xa20602bf,0x9046002b}},	// [78e0] _été_, ызан, ыпад, گناه
  { {0x98be04f9,0xd5b80024,0x79810034,0x9617000a}},	//   mită_, ņās_, nmlw, _עקיף_
  { {0x25b20026,0x98be0011,0x2d8c3889,0x232a1e40}},	//   _hwyl_, lită_, _ride_, _зони_
  { {0xbefa0015,0x5fc9000b,0x2d8c14dc,0xa6db0052}},	//   عراض_, ांजल, _side_, viðk
  { {0x3f8d038d,0x98be0011,0x2d8c02c1,0x2b98388a}},	//   _dieu_, nită_, _pide_, _séc_
  { {0x61460254,0xd1320015,0x0000006a,0x0000006a}},	//   _сега, _امس_,   ,
  { {0xc4d30008,0x2d8c388b,0x4ff8000a,0x0b8a0c5b}},	//   צגה_, _vide_, _בִּנ, нсии_
  { {0x3cf0005d,0x2d8c003e,0x26ee000b,0x1eaa0015}},	//   _इसके_, _wide_, ज़ोर_, _ساري_
  { {0x4cd60086,0x442a0264,0x693407d9,0xdca605a7}},	//   _مغاز, hyb_, иниу, _бази
  { {0xa6db002e,0xc237000a,0x98be0045,0x61f60034}},	//   miði, טרפו_, dită_, iwyl
  { {0x7c93003b,0xa6db002e,0x61f60026,0x8afd0089}},	//   _المص, liði, hwyl, mořn
  { {0x7c2500b8,0x8c1b000f,0x9a6a0015,0xa9230091}},	//   ähre, _רואי, _كمال_, _įžen
  { {0xa6db002e,0xdb0a169b,0x291800c0,0x6d4a003f}},	//   niði, dsfø, öras_, oifa
  { {0xe4c70010,0x4992002b,0xb4c1000b,0x65940033}},	//   ыёмн, _پیگر, ुले_, сару
  { {0xf1bf0089,0xcc58000a,0xa3be000b,0x2c34000a}},	//   _svá_, דֳּכ, ुंग_, בָּם_
  { {0x6d4a000c,0xf8d4000b,0x98be0045,0x78ba388c}},	//   hifa, _दाँय, bită_, latv
  { {0x98be0011,0x7c2a0026,0x6d4a003f,0x25b20026}},	// [78f0] cită_, hyfr, kifa, _gwyl_
  { {0xf1c80029,0x463c0053,0x6d4a003f,0x78ba0091}},	//   اولى_, _רעזע, jifa, natv
  { {0xa6db002e,0x7a48003d,0xf48b00f4,0x2b460244}},	//   eiði, lītī, _ящик_, _omoc_
  { {0x672f0050,0x61f60034,0xf1bf0046,0x7c2a0034}},	//   nkcj, bwyl, _tvá_, dyfr
  { {0x9b450086,0x9f5c0089,0x386e0026,0xf8d4000b}},	//   ینتو, ívá_, _lyfr_, _दांय
  { {0xa1590033,0x98ac0091,0x6d4a0072,0xdce80073}},	//   _рагу_, midė_, gifa, _didį
  { {0x98be0011,0xbae50015,0x14d80447,0x78ba0030}},	//   zită_, لكثي, טוגל_, datv
  { {0x8b250e4d,0xcc080040,0x0000006a,0x0000006a}},	//   рдие, ازون_,   ,
  { {0xdce10024,0x6d4a0045,0x78ba001a,0x3328000a}},	//   _eklā, bifa, fatv, ר֗וּ_
  { {0xbb4400f2,0x98be0011,0x3945168f,0x672f002a}},	//   äärä, vită_, рног, ekcj
  { {0xe73a066c,0x386e002a,0x2eff0012,0x070a0015}},	//   вен_, _cyfr_, _kauf_, نيدي_
  { {0xfe670029,0x98be0011,0x25b20034,0x61f60034}},	//   قد_, tită_, _pwyl_, ywyl
  { {0x63a5002d,0x96760010,0x86760010,0x29c80015}},	//   _athn, рыні, рынц, _مِنَ_
  { {0x64590050,0x98be04f9,0x18a50001,0x6abb00b8}},	//   _świa, rită_, _такм, lauf
  { {0x98be0011,0x88830086,0x29f6002a,0xc2b60054}},	//   sită_, _دیدن, _zła_, иљањ
  { {0x97c40086,0x3f9c00dc,0x6d4a003f,0x6abb00b8}},	//   _اتوم, ívum_, zifa, nauf
  { {0x47360074,0x81a50015,0xe1fa006b,0xe0da28ae}},	// [7900] _مرکز, محلل, ъга_, ква_
  { {0x399b001c,0xf9920008,0x867b000a,0x55bb000a}},	//   _mês_, קרב_, _ברפו, _שמיו
  { {0xd00f0029,0x6abb00b8,0x5ea600a2,0x3d19000b}},	//   ولك_, kauf, لمال, पाने_
  { {0x7c2e00b8,0x98be0007,0x539b0008,0xa8560008}},	//   _übri, mitą_, _שיכו, ביעה_
  { {0x9cb60015,0x6d4a048f,0x4df6004a,0x9757000a}},	//   لمشت, tifa, ряет, סינו_
  { {0x80dd005d,0xebc60001,0xa6db001a,0x8bc6012f}},	//   _पाये, аљин, riði, асид
  { {0x6d4a13e5,0xbd430015,0x672f002a,0xb60600bc}},	//   rifa, تنوي, ykcj, ljšč
  { {0x98a50007,0x6d4a0213,0xa3b8000b,0x2417000a}},	//   filį_, sifa, घीय_, שחקן_
  { {0x3f98000c,0x5b230015,0x78ba0030,0x6f060030}},	//   _huru_, تفيل, tatv, gébő
  { {0x3f980048,0xdb18001a,0xf091000a,0x6f0200e7}},	//   _kuru_, msví, ּ֠י_, ldoc
  { {0x6567002c,0x78ba002e,0x3f980273,0x6d3b000a}},	//   vojh, ratv, _juru_, _שתבנ
  { {0x98be0007,0x29f6002a,0xca47002b,0x98a50091}},	//   ditą_, _tła_, الیه_, bilį_
  { {0x09e30010,0x78ba0007,0x6996004a,0x6f02002a}},	//   _моцн, patv, _трех, idoc
  { {0x5e770008,0x7a790053,0xa5f80054,0x69c0388d}},	//   יתכן_, _גרױס, јеру_, msme
  { {0x48f90053,0x397b0053,0x897b000a,0xb97b000a}},	//   _תּנא, _שטונ, _שרוצ, _שנוי
  { {0x394c2efb,0x70af0065,0x6f0001f9,0xc6a7011e}},	//   lids_, टर्ल, _namc, _трки
  { {0x926b0001,0xf9930053,0x6f0217f9,0xe4e7005e}},	// [7910] трва_, ַרף_, ddoc, _кінн
  { {0x31c40010,0x2eff0152,0x6f02059b,0xe0d30067}},	//   ўств, _sauf_, edoc, تزر_
  { {0xc104012c,0x6f060030,0x1419004f,0x69c002ad}},	//   تولي, zébő, _עוֹב, hsme
  { {0x6d480176,0x69c0388e,0x671a000b,0xb6a40016}},	//   _amda, ksme, धायक_, _ngẫ
  { {0xdef80802,0xa3d3021e,0xfca90015,0xcddb0054}},	//   рых_, हूर_, هاغو_, тње_
  { {0xa6db002e,0xa3be005d,0x0dc80feb,0xee38022a}},	//   miðu, ुंच_, руци_, шні_
  { {0xadc30092,0xa6db002e,0x3f98388f,0x6abb3890}},	//   _trắn, liðu, _guru_, tauf
  { {0x394c0024,0x54580008,0xd47c0008,0x6f060030}},	//   eids_, יבוב_, כאול, tébő
  { {0x6abb00b8,0xe2a6002e,0x3f98003f,0xa6db002e}},	//   rauf, óðin_, _zuru_, niðu
  { {0x9be70191,0x6abb00b8,0xe8f63891,0x6f060030}},	//   _відк, sauf, бль_, rébő
  { {0xc6890008,0x29110064,0x27fc0092,0x6f0600dc}},	//   _נא_, ıza_, _csvn_, sébő
  { {0xaa950029,0xcc760008,0xe73a054f,0x8f19000a}},	//   _الإث, _הגעת_, уем_, אוֹת
  { {0x2b4d005c,0x98be002a,0xca96000a,0x7d013892}},	//   miec_, witą_, _הדני_, _kals
  { {0xba740015,0xdce32a75,0x057a0015,0xa50a0054}},	//   _بامت, konč, امسة_, ћева_
  { {0x1dd1005d,0x672d0030,0x320b0e9d,0x7d013893}},	//   _समझत, üljö, _arcy_, _mals
  { {0x2b4d066f,0xe5a6006b,0x98be0091,0x0000006a}},	//   niec_, _лиии, ritą_,
  { {0x61320134,0x200a3894,0x6f001755,0x0000006a}},	// [7920] _fæll, _srbi_, _ramc,
  { {0x61203895,0xe03a0033,0x03a8002b,0x11d70015}},	//   _hölz, ляеш_, _نگرو_, صومة_
  { {0x8f76005e,0x0576002b,0xdce300bc,0xb099005e}},	//   буді, _پاکد, gonč, ртує_
  { {0xee3a0124,0x8f45005e,0x6ab9258f,0x7d013896}},	//   лне_, охід, _newf, _aals
  { {0x7d011cdb,0x7ee30015,0x6f0216c4,0x4cb800ce}},	//   _bals, سكون, rdoc, аллю_
  { {0x3f960083,0xac970015,0x69c00123,0x3f983897}},	//   _граѓ, منها_, vsme, _turu_
  { {0xa1370053,0x7d010fce,0x9bf4005e,0x69c00034}},	//   _פאלק_, _dals, ізич, wsme
  { {0x5a34017a,0xf413000a,0x69c600bc,0xaf34002b}},	//   жнит, לפו_, škem, _بورژ
  { {0xcb670001,0x9998000d,0x7d0118b4,0x61e40390}},	//   љање_, јкот_, _fals, ntil
  { {0xce37000a,0x8e200033,0xa3d3000b,0x6d4801d7}},	//   _האמת_, мiж_, हूँ_, _umda
  { {0xab960029,0x2b4d005c,0x9c7c03cd,0xac970015}},	//   _الصغ, biec_, _obči, _انما_
  { {0x6d580024,0x2b4d005c,0xd5ed0092,0xddc9005c}},	//   lnva, ciec_, _ngạ, _rzeź
  { {0x8b65003b,0xe6670229,0xef110008,0x394c1ee1}},	//   _بالم, стно, וּם_, pids_
  { {0x2902003d,0xf1c50091,0x2240002a,0x63a10046}},	//   ēkas_, našų_, dzik_, ílno
  { {0x22400796,0x6b9a0144,0x61e43898,0xa3d30065}},	//   ezik_, _jutg, etil, हूं_
  { {0xdc37004c,0xe61600bc,0x3f860046,0xdb030123}},	//   זאלט_, žišč, jmou_, ssnö
  { {0x61320134,0x22400030,0x25ac013f,0x61e43899}},	// [7930] _tæll, gzik_, čilý_, gtil
  { {0x3d02000b,0xf8b1000a,0xa6db001a,0x6b9a1f63}},	//   लयों_, ֥שׁ_, riðu, _outg
  { {0x7e7b00dc,0xa295022a,0xd0110002,0x3ff50015}},	//   _szup, _мані, بلا_, تكار
  { {0xa6db0084,0x660d389a,0x7879000a,0xd488000a}},	//   miðs, _krak, בָנו, _לָרֹ
  { {0x2dcb0001,0xdb18007c,0x7d0111ec,0xa6db001a}},	//   ућен_, nuvõ, _pals, liðs
  { {0x2b4d005c,0x5fbb0015,0x067c004c,0xdce3006f}},	//   wiec_, _مدرج_, אנדל, ponč
  { {0xeab1003b,0xcda90086,0x98a50007,0x7d01389b}},	//   وعة_, _چهره_, nklą_, _vals
  { {0x1ee7002b,0xdb18007c,0x26c901d7,0x7d01389c}},	//   _دوری_, kuvõ, _ndao_, _wals
  { {0x7e7b005c,0x28d4000b,0xaac40021,0x7e770015}},	//   _uzup, _दाखि, ستين, _طارئ
  { {0xbd6b0054,0x57e9227a,0x0dc80054,0x47c50974}},	//   _србе_, адом_, _ћути_, обов
  { {0x25a90026,0x2b4d005c,0xb69b1224,0x3854004a}},	//   _atal_, piec_, rdân, зъяс
  { {0x61e4389d,0x0a150015,0x660d389e,0x7bc3389f}},	//   ytil, _وواح, _brak, msnu
  { {0xe57a007a,0x64a60033,0xba2b0040,0xdb18007c}},	//   изм_, жага, _حسام_, guvõ
  { {0x6b5e003d,0x3f860247,0xa50a0054,0x660d310c}},	//   mīga, zmou_, шега_, _drak
  { {0x660d3010,0x6b5e0024,0x7bc338a0,0xe7b50015}},	//   _erak, līga, nsnu, _بمعد
  { {0x163a003b,0x52aa0063,0xe29738a1,0x26cc0091}},	//   _نسخة_, рвам_, жат_, ėdos_
  { {0x61e40152,0xf1a90029,0x6b5e0024,0x224001c2}},	// [7940] util, ماله_, nīga, uzik_
  { {0xb17b01d1,0x61e438a2,0x290538a3,0x64550030}},	//   _spår, rtil, ndla_, áfiá
  { {0x224000dc,0x071e005d,0xb4d6000b,0x660d07d4}},	//   szik_, _बचाव_, हली_, _zrak
  { {0xd47b0008,0x447b000a,0xe47b000a,0x547b000a}},	//   _כאיל, _כניע, _כריכ, _כטיו
  { {0xad660029,0x3f8638a4,0xf2d3004c,0x021a005e}},	//   ياته, rmou_, _קעש_, _тінь_
  { {0x6b5e003d,0x11390033,0x613202de,0xa116012c}},	//   dīga, _лясы_, _mælk, _بوست
  { {0xf1c50007,0xa4b7000a,0x6d580804,0x7ae938a5}},	//   rašų_, קלקה_, rnva, ffet
  { {0xdddb0064,0xdb01001c,0x539b000a,0x2fc70045}},	//   _uyuş, _atlâ, סיפו, ânge_
  { {0xb9970139,0x9b430058,0x9da5009a,0xaa630138}},	//   овых_, بنيو, _فصله, дтэк
  { {0x0217000a,0x4c160015,0x6120008c,0x98a50091}},	//   קחים_, _وباس, _pöly, yklą_
  { {0xeb9a0083,0xdaba0086,0x2005002e,0x25a90264}},	//   _тие_, _نهضت_, _álit_, _stal_
  { {0xa6db002e,0xdb18007c,0x660d38a6,0xcdd4000a}},	//   eiðr, tuvõ, _prak, ֔ךָ_
  { {0xb6040010,0x6b5e0024,0x95d805c4,0x34950afa}},	//   мярк, cīga, одят_, загр
  { {0xfa770008,0xdce30046,0xb865009a,0x660d38a7}},	//   _ועדת_, dlně, _کاهو, _vrak
  { {0x734b0342,0xdb18007c,0xf441005e,0x25fb0065}},	//   ачав_, suvõ, ховi_, _लैरी_
  { {0x92b700c3,0xd5bb006b,0x660d38a8,0xc2990280}},	//   تحسا, _ксо_, _trak, сках_
  { {0xa2dc005d,0xeb91000f,0xd6e8000a,0x25a90101}},	// [7950] _फार्, תָם_, _וַתָ, _utal_
  { {0xc1780036,0x7bd838a9,0x0000006a,0x0000006a}},	//   оїх_, kuvu,   ,
  { {0xb4fa0008,0x5f950063,0x28dd021e,0x6b5e003d}},	//   _הפתי, чиет, _मासि, zīga
  { {0xdb1802de,0x03d6004f,0x80dd0065,0x0000006a}},	//   lsvæ, _צורם_, _पावे,
  { {0x20d70015,0xe1ff0077,0xdca50974,0xb1e70058}},	//   _وتسج, _usó_, пали, _بأجه
  { {0x25d80008,0xc10b0010,0xd658000a,0x15fc000a}},	//   קוון_, _тэме_, חידת_, שִׁמ
  { {0x7bd80048,0x6b82002d,0x9c7c00bd,0xc1720008}},	//   guvu, _bhog, _obču, _נחל_
  { {0x6b82002d,0x6b5e003d,0x845c000a,0x28dd000b}},	//   _chog, tīga, יכוז, _माहि
  { {0xe9d10029,0x7c38016f,0x6ce7005e,0xdb0e0030}},	//   رغة_, _čarš, _міже, ójáh
  { {0xa2cb005d,0x6b5e0024,0x3942004a,0xaaab000b}},	//   तृत्, rīga, еньг, _ट्रक
  { {0x6b82002d,0x2c74002d,0x98be0089,0x6b5e003d}},	//   _fhog, rúdú_, litě_, sīga
  { {0xdc880008,0x290302c6,0x1dcf000b,0x2576001a}},	//   _וְנָ, žja_, _हटात, mæli_
  { {0xdb1809f0,0x98be0089,0xba9a000a,0xcb12000a}},	//   fsvæ, nitě_, _הסני, _רלד_
  { {0xb4d6005d,0x6b8900dc,0x69da0008,0xdb1802de}},	//   हले_, lmeg, _הַהו, gsvæ
  { {0x29360053,0xf9900031,0xd8750015,0xd7c9009a}},	//   _מאסן_, _شبه_, _عاتب, _اوبه_
  { {0xf1c7005d,0xc7a80015,0x0000006a,0x0000006a}},	//   _लिखन, _بدول_,   ,
  { {0x9757000a,0x26c22ea4,0xdce3003d,0xd36f0058}},	// [7960] _משקף_, mako_, zonā, اهق_
  { {0x41030036,0xb09a0036,0x26c238aa,0x6b890012}},	//   нзув, стає_, lako_, hmeg
  { {0xdeef0010,0xc49b000a,0x749b000a,0x7c250012}},	//   ны_, _לשית, _לייפ, ährl
  { {0x61320084,0xdce30089,0x98a70089,0x26c20aee}},	//   _mæli, plně, _plně_, nako_
  { {0xddcb01e2,0xae03000b,0xadd802a3,0x6b8938ab}},	//   ğişi, लिगन_, імку_, dmeg
  { {0xdd990036,0xc27b000a,0x6cd30015,0x1e130033}},	//   іші_, _לרכי, فقها, эмія
  { {0x26c2044c,0x913b0053,0x8cc70015,0x21e6006f}},	//   kako_, _פעלק, سويق_, lôh_
  { {0xd90d0086,0xd00f0029,0x6b8900dc,0xa3d4000b}},	//   یین_, _حلف_, gmeg, _हटन_
  { {0xadc30023,0xa3d6005d,0xeaaf0015,0x7bd805ff}},	//   _trạn, _समझ_, دعى_, suvu
  { {0x3acc0016,0x27340016,0xd7fa0cab,0xbd460040}},	//   ớp_, _hãnh_, бум_, _عناي
  { {0x37aa000d,0x28dd000b,0x6b8201b3,0xd8780015}},	//   љтон_, _मारि, _thog, تمدت_
  { {0xcc570008,0x6c7b0053,0x907b0008,0x26c202f2}},	//   _צבאי_, _פראד, מטיי, gako_
  { {0x613301e2,0x27340016,0xdb1802de,0x80dd0065}},	//   _yılı, _mãnh_, tsvæ, _पाले
  { {0x27340023,0x8afd0089,0xb52402bf,0xfd67000a}},	//   _lãnh_, voři, ньск, ּ֑ךָ_
  { {0xdb18002e,0x26c2003f,0xb97b000a,0x387a0030}},	//   rsvæ, bako_, _הנגי, _ápr_
  { {0xb7db013a,0x926b0b1e,0xdb18001a,0xa85b004f}},	//   _הקהי, брза_, ssvæ, _לדוכ
  { {0x671a000b,0x69bf000b,0x6458001a,0x85c80058}},	// [7970] धारक_, लीपी, _þvin, _فِيْ_
  { {0x55bc0008,0x98be0046,0xfc3f0046,0xc0ab0015}},	//   _המזו, vitě_, _řím_, صائل_
  { {0x6721005d,0x98aa005c,0xe3a50086,0x389b01ac}},	//   यापक_, óbę_, _تشخی, ציאנ
  { {0xdb1800c0,0xc7d7000a,0x8afd0046,0x2127009a}},	//   nsvä, לובי_, poři, _کيسی_
  { {0x2fc70023,0x28dd005d,0xed4e023e,0x1eea0086}},	//   ũng_, _मालि, во_, تونی_
  { {0xac39005e,0x98be0046,0x7ae20533,0xe3b0002b}},	//   жчих_, ritě_, _acot, _جری_
  { {0xbbe80029,0xdb1800c0,0x8d740018,0xdb010077}},	//   كريم_, ksvä, راها, _atlá
  { {0x643c000a,0x3e070033,0xeeb914c2,0xc9a9158e}},	//   מעונ, _нязв, _флаш_, овие_
  { {0x26c20085,0xef19002a,0xdb180123,0x6b8938ac}},	//   vako_, _inż_, dsvä, rmeg
  { {0x9f410125,0xdb1a0123,0x3ebf0012,0x6b8938ad}},	//   ithí_, _avtä, _heut_, smeg
  { {0xfbd000b0,0x6b5e0024,0xe7320015,0x5c750033}},	//   _متن_, cīgo, نصح_, _ўлет
  { {0xc4c90dab,0x2d9f0020,0xe7370248,0xba55009b}},	//   _כג_, _kuue_, дею_, _отлъ
  { {0x7bd20024,0xd63a0033,0xae03000b,0x46470033}},	//   ījuš, іямі_, लिटन_, дзян_
  { {0xe29f0084,0x98a50007,0x64a6000d,0x26c238ae}},	//   _raða_, yklę_, ќава, sako_
  { {0x26c200bd,0xe9720029,0x64a30b75,0xfc3f0046}},	//   pako_, _جهود, таса, _říj_
  { {0x29070084,0xc7d60008,0xae1d000b,0xe947002b}},	//   _hana_, _חוקי_, पमान_, _برچی
  { {0x87050015,0x69c60091,0x6abd001a,0x2d8501d7}},	// [7980] _سبيل, škev, ósfy, _ohle_
  { {0x66040005,0x7afb00f2,0x2011016f,0xe29f002e}},	//   _isik, heut, _brzi_, _vaða_
  { {0x251b00b2,0x1fa50036,0x7afb00f2,0x351b0135}},	//   _וויא, еріг, keut, _ווינ
  { {0x2fc70011,0xdfcf0002,0xe0850015,0xdb0a38af}},	//   ânga_, شيه_, رجلي, lsfö
  { {0x7afb018b,0x26c003af,0x6da31b07,0x25a00003}},	//   deut, _meio_, вича, _juil_
  { {0xdb0a00c0,0x7ae20ec3,0x9e65002b,0x3ea600da}},	//   nsfö, _scot, رانن, scot_
  { {0x69cf0089,0xdb0a0012,0x3ebf0003,0x31a40030}},	//   ácen, isfö, _feut_, _höz_
  { {0x539b0008,0x7dc60015,0x63ba006f,0x6b5e003d}},	//   חיקו, _يتذك, átny, rīgo
  { {0xdb0a0123,0x64580091,0x290738b0,0xbb4700c3}},	//   ksfö, _žvil, _bana_, بلين_
  { {0x63ba006f,0xa9670004,0x9cb30015,0xdb180123}},	//   štny, миња_, _لمكت, dsvå
  { {0xdb0a00c0,0xf84a0036,0x290738b1,0x7d1a166f}},	//   dsfö, ючий_, _dana_, _ints
  { {0xf0930008,0x274b0036,0x7d0800dc,0x45d50180}},	//   כנת_, ічно_, _hads, номс
  { {0xceb30008,0xdb1807a3,0x66040030,0xcb37004f}},	//   כיר_, rsvä, _csik, _קאדי_
  { {0xdb0a0123,0xda7b000a,0xf10d000b,0xdb1804d6}},	//   gsfö, _ונדר, _सफेद_, ssvä
  { {0x66040604,0xf8db000a,0xf9870015,0xd8db000a}},	//   _esik, _וחומ, _تنوي_, _וקור
  { {0x61320084,0x2abb0053,0xe3b000e6,0x2b17000b}},	//   _mælu, ַמבא, شرف_, थाएँ_
  { {0x7d1a049c,0x29071843,0x61d9004a,0x395e38b2}},	// [7990] _onts, _yana_, ямая_, onts_
  { {0xda080092,0x00db0015,0xe0d00021,0x7d080e9c}},	//   _mỏ_, تبرت_, لزم_, _nads
  { {0x3ebf038d,0x395e1359,0xdf470033,0x3ed50058}},	//   _peut_, ints_, мэдп, فقار
  { {0xf1a7005d,0x69cf021e,0xf5cb000a,0x93440004}},	//   _कंपन, _दिली, ַזֶּ, _анџе
  { {0x3ebf0152,0x31a40064,0x877c000a,0x0000006a}},	//   _veut_, _göz_, קאדי,
  { {0xb6380008,0x91ba000f,0x20d40015,0xe6dc000b}},	//   ורדס_, _ממשי, _لتفج, _मञ्ज
  { {0x7afb00f2,0xfaa50b08,0x7d080026,0x3ea030fc}},	//   teut, найо, _dads, žita_
  { {0x7d1a018b,0xda080023,0xd4980008,0x290738b3}},	//   _ents, _bỏ_, וכות_, _sana_
  { {0xda080092,0xc9550256,0xedd50015,0x4b240015}},	//   _cỏ_, етны, _سياد, ضعيف
  { {0x60c500b8,0x7d0838b4,0x26c0016e,0x721a000a}},	//   nahm, _gads, _seio_, פותח
  { {0xc1720008,0x29070020,0x6d43002d,0x6132002e}},	//   רחי_, _vana_, mhna, _gælu
  { {0x395e38b5,0x2907003f,0xf092000a,0x9bb6000a}},	//   ants_, _wana_, טני_, _נהנה_
  { {0xf652003b,0x26c0001c,0xdb0a00c0,0x9986005c}},	//   ائج_, _veio_, tsfö, _broń_
  { {0xa9090015,0x63a80046,0xdb180123,0x9a56004f}},	//   _ريبل_, ídno, rsvå, _אינצ_
  { {0x31a40064,0x6132002e,0xdb0a0123,0xe73a38b6}},	//   _söz_, _mælt, rsfö, _нек_
  { {0x23270292,0xa8560008,0x6aa938b7,0x8afd0046}},	//   носи_, _ריקה_, ncef, mořs
  { {0xd1860080,0xdb0a0123,0xa5960965,0xda080016}},	// [79a0] елай, psfö, _прощ, _xỏ_
  { {0x69c900f2,0x7cf30064,0xf205000b,0xc5f3000a}},	//   isee, nırı, रिज़_, _עדת_
  { {0x6d43002d,0x7d0801f1,0x46c4000b,0x6f0938b8}},	//   dhna, _rads, _वजाह, _baec
  { {0x69c938b9,0xf413000a,0x9ea70054,0x6fb30067}},	//   ksee, _עפר_, евца_, امنا
  { {0x20d6005e,0xf1a7000b,0x7cf30061,0x236028c7}},	//   _півс, _कूपन, kırı, mnij_
  { {0x6d43002f,0xa3d4005d,0xdd8f00e5,0x2360002a}},	//   ghna, _हटा_, مون_, lnij_
  { {0x69c9022d,0x7cf30064,0xfbcf00c3,0x7d0830a6}},	//   esee, dırı, متي_, _vads
  { {0xff260063,0xbbd0000b,0x9c570015,0x9f4a07c2}},	//   _ямбо, _सटीक, عجوز_, ömän_
  { {0xbc6a002b,0x8afd0046,0x3d88002b,0x7cf3007f}},	//   _کمان_, vořt, _قحطی_, fırı
  { {0x6d4338ba,0xda080016,0x395e38bb,0xdce3002a}},	//   chna, _vỏ_, unts_, toną
  { {0x23600050,0xdd8f03c4,0x6bd60086,0x9d2b000a}},	//   knij_, _اول_, _ستار, _מֵאִ
  { {0xda080092,0xdc3b000a,0x7c3b000a,0x0ab60015}},	//   _tỏ_, _מעבר, _מתבס, _أحاد
  { {0x2360002a,0xfa33002b,0x569400f4,0x29d3009a}},	//   dnij_, _مرود, лают, _مينس
  { {0x69c60007,0x68460003,0xa5040033,0x61320052}},	//   škes, _cédé, лясл, _mæls
  { {0x998200df,0x236038bc,0x60c501d7,0x7bca2def}},	//   škų_, fnij_, vahm, nsfu
  { {0x487b0008,0x7c2500b8,0xa87b20c1,0x987b000a}},	//   _מטוס, ähri, _מאור, _מרוק
  { {0x68460152,0x290c0034,0x46150058,0x0000006a}},	// [79b0] _fédé, odda_, _شودر,
  { {0x290c0026,0x315b0015,0x7bca0804,0x684601f6}},	//   ndda_, أجرة_, ksfu, _gédé
  { {0xf3cb0021,0xb4dd0157,0x6aa9002a,0x60c52219}},	//   _عبده_, डली_, ycef, rahm
  { {0x7cf30061,0x6fd6000b,0x69c938bd,0x61e90045}},	//   zırı, मंजू, ysee, _ţelu
  { {0xdd9b0080,0x6d43130f,0x22842246,0x8f340033}},	//   чше_, thna, _бург, ыецц
  { {0x063800b2,0xc5f4000f,0x6b990034,0x61ed38be}},	//   ענגט_, רדס_, _siwg, mtal
  { {0xdfd8010f,0x6c520001,0x6d43002e,0x6fb90010}},	//   _път_, икљу, rhna, _ігар_
  { {0x5f940431,0x69c90eb4,0x6f1b06d1,0x6d4338bf}},	//   _бист, tsee, _unuc, shna
  { {0x7cf301e2,0x9aa80029,0xc334000a,0x1989004a}},	//   tırı, رديف_, טוק_, мбии_
  { {0xfd1300e6,0xe7a90da4,0x69c938c0,0x2ba90065}},	//   _حجر_, мвол_, rsee, _चंपा
  { {0x0889004a,0xc7b80033,0x7cf30061,0xf74605a7}},	//   ьбой_, нёў_, rırı, вено
  { {0x23be0089,0x61ed38c1,0x290c0123,0x69c938c2}},	//   vůj_, ktal, adda_, psee
  { {0x69c60089,0xcb360008,0xa266002c,0xc603005e}},	//   šker, _שאני_, omôž, азяй
  { {0x2360005c,0xa3bf005d,0x98a20248,0xc7a8002b}},	//   wnij_, ुओं_, _кише, بدیل_
  { {0x33d505d1,0x8bac000a,0x2360002a,0xe8d6000a}},	//   літт, ּׁמִ, tnij_, _סוקר_
  { {0xdb0100c0,0x61ed38c3,0xe3630b98,0x7176009a}},	//   _utlä, ftal, акси, چهرا
  { {0xa0a60010,0xf55a0029,0x61ed2472,0x95860608}},	// [79c0] вазд, _يلعب_, gtal, _илие
  { {0xe0d71853,0xf53f0123,0x7bca00aa,0xd5e90015}},	//   кву_, spår_, ysfu, _أعين_
  { {0x838a0191,0x101500fd,0xa4b7000a,0x224901c2}},	//   _обов_, льця, _שלטה_, azak_
  { {0xa266002c,0xc2940086,0xdb03006f,0x6d4138c4}},	//   emôž, _میزب, apnú, _alla
  { {0x290c38c5,0xdee32b98,0x22491835,0x3ea01ffb}},	//   ydda_, рочи, czak_, žito_
  { {0x6fb60029,0x628600bd,0x6b5e003d,0x9cb30015}},	//   _لمسا, _izko, mīgi, لمهت
  { {0x9f5c00dc,0xd47a004c,0x6d4101d7,0x1d190033}},	//   ívó_, ואַל, _dlla, эюць_
  { {0xceea0010,0x6d4138c6,0x7bca38c7,0x0000006a}},	//   _ідзе_, _ella, rsfu,
  { {0x7bca0041,0x44380026,0x4974004a,0xa25b016e}},	//   ssfu, hyr_, ллис, _leôn
  { {0x41da000b,0xd917004a,0x0000006a,0x0000006a}},	//   यूएस, вью_,   ,
  { {0x3137009d,0x290a002c,0x6d580201,0x61ed38c8}},	//   דריך_, ľba_, miva, ztal
  { {0xbb44008c,0x290a22b4,0x0b170015,0x6d5838c9}},	//   äädä, žba_, _لقمة_, liva
  { {0x6d5800f2,0x291a0015,0x9f470003,0x25de000b}},	//   oiva, _يقصد_, îné_, कूली_
  { {0x44380026,0x61ed02d2,0x6616001a,0xba9b05bd}},	//   fyr_, vtal, _dryk, _חסדי
  { {0x78fb0008,0xe2f90036,0xa99b0c44,0xe45408f0}},	//   _חלופ, неві_, _קבור, акры
  { {0x3207002a,0x6459002a,0x61ed1983,0x66160795}},	//   łnym_, _świs, ttal, _fryk
  { {0x52150010,0xa6e3002e,0x20c7004a,0xd234006b}},	// [79d0] ыдат, íðut, всег, антъ
  { {0x6d58010b,0x61ed0832,0x443801f0,0x80b4005e}},	//   jiva, rtal, byr_, ибух
  { {0x66740086,0x7d080007,0x6d5838ca,0x224913c3}},	//   _مدیر, iūrė, diva, szak_
  { {0x673d06f5,0xf43a000a,0x65750030,0x61ed38cb}},	//   nksj, _נגרמ, lozh, ptal
  { {0x22da0008,0xdd2c0007,0x7d080007,0x926b0cb9}},	//   _אחרא, _dėžu, kūrė, _црна_
  { {0xa63c0008,0x6d583482,0x1be9144a,0x63a538cc}},	//   וגדר, giva, едки_, _kuhn
  { {0xbbf50029,0x6ce4005e,0x7d080091,0x764b0030}},	//   استث, річе, dūrė, _ügyf
  { {0x657500dc,0xbc18005e,0x6d58008c,0x4c340033}},	//   hozh, тіші_, aiva, рэшт
  { {0x657500dc,0x2bae005c,0x0b420010,0x4e940029}},	//   kozh, _ręce_, ёньн, _نشكر
  { {0x6d58016f,0x25760134,0xc27c0008,0xd90f0086}},	//   civa, jælp_, ורחי, زیع_
  { {0x9056000a,0x25b20689,0x6b5e003d,0xbca40058}},	//   ָ֑יו_, _styl_, zīgi, _ضمني
  { {0x6d460007,0xf74603a9,0x7c250012,0xfb85002b}},	//   _įkai, уемо, ähru, _صدای
  { {0xcb12013a,0x44380176,0x7f3a0053,0x6abb003f}},	//   _ללא_, wyr_, גערו, mbuf
  { {0x3944008f,0x443838cd,0xe5a30883,0x98a7003d}},	//   _кніг, tyr_, сири, _fonā_
  { {0x62860050,0xc8da000a,0x443e38ce,0x6e390034}},	//   _szko, _טקסט, át_, hywb
  { {0x6d58010b,0xe7b20086,0x6616079b,0xd2520015}},	//   ziva, _اميد, _tryk, منز_
  { {0x98a7003d,0x443e0085,0xa18a0004,0x443817a4}},	// [79e0] _zonā_, št_, ебаа_, syr_
  { {0x11d70029,0x6b5e0024,0x6d580251,0x637a0079}},	//   اولة_, rīgi, xiva, eïnt
  { {0xdfcf0029,0xa8a80008,0xa889000a,0x6fa50015}},	//   كيل_, דֹנִ, תָּ֥, لإنك
  { {0xcf7a0015,0xfe46006b,0x389a004c,0x6f660033}},	//   رصاص_, лнео, גיענ, ывез
  { {0xfe720029,0x539b000a,0x82360015,0xf777000a}},	//   حدا_, _ריכו, _إرجا, נעני_
  { {0xde930001,0x6d5838cf,0xa0a301e1,0x417a0058}},	//   љашњ, uiva, _гард, _أمسح_
  { {0x2bb70029,0x7c66002b,0x70560015,0x28dd000b}},	//   هاية_, داشل, _إنزا, _माजि
  { {0x6abb003c,0x7c650015,0xd838013f,0x6d5838d0}},	//   gbuf, جاهل, vyč_, siva
  { {0x0e6638d1,0x6d580201,0x69db38d2,0x0d861208}},	//   _скан, piva, grue, _блан
  { {0x4dfb004c,0xf20b000b,0x3ea9006f,0x090622c9}},	//   _אפמא, _सैफ़_, ľate_, учим
  { {0x50db0053,0x3ea920a3,0x7d930015,0xbae60015}},	//   עקטא, žate_, _اللؤ, _مكاي
  { {0xbaba0029,0xb0840033,0x56950a32,0xc053000a}},	//   _أداء_, ывiд, иант, מזת_
  { {0x66e6000b,0x6b5b004c,0x65750030,0x0f57000a}},	//   _कारक_, _אדאפ, tozh, ריכם_
  { {0x1dc6000b,0xd407004a,0x6f020125,0x3ce8000b}},	//   रीयत, ляби, heoc, च्चे_
  { {0x7a480048,0x27f70227,0x89630015,0xb4950054}},	//   sūtī, čená_, _دُون, ривљ
  { {0x290e0084,0x236d00bd,0x2d9e1ba8,0xa2b50612}},	//   _hafa_, čejo_, _lite_, рбач
  { {0x4155008f,0xdb0a2061,0xccf80089,0xa4d5022a}},	// [79f0] авас, ppfæ, _obě_, _копі
  { {0x6b5e003d,0x26cb16ee,0xa3ce0065,0x2d9e01f9}},	//   mīgu, laco_, _रिच_, _nite_
  { {0x659a000a,0x3ce8000b,0x6aa20034,0x51841886}},	//   _שיתק, च्छे_, _ogof, сута
  { {0x7ff4003b,0xcae3000b,0xb3ba000a,0x8db502a3}},	//   إسلا, _गाइड_, _שמרכ, аскі
  { {0x398b01f0,0x2d9e38d3,0x66e8000a,0x6b5e003d}},	//   løse_, _bite_, א֥וּ_, nīgu
  { {0x11da013a,0xabd52f8f,0xee380010,0xb0e2005d}},	//   _בחשב, ациј, ыні_, _पाएग
  { {0xf538000a,0x2d9e38d4,0x6b61003d,0xe538004f}},	//   רטור_, _dite_, lēgi, רטוט_
  { {0xb33b01e2,0x5458000a,0xfebb0015,0x2d9e38d5}},	//   _hiçb, טסון_, _سارت_, _eite_
  { {0xcce70086,0x89350015,0x0b420033,0x6abb0c4e}},	//   _مساي, لعدا, іньн, rbuf
  { {0xc27c0053,0x127c004c,0x69db0cf7,0x6abb0789}},	//   ערזי, עאזע, rrue, sbuf
  { {0x3ad50086,0xddc2002a,0x98be0091,0xe766031e}},	//   _نياز, czoł, antį_, ивоп
  { {0xaa560086,0x61fd38d6,0x69db0077,0x7d0338d7}},	//   الیا_, _opsl, prue, lens
  { {0x7d03016b,0xa2c9000b,0xb522000b,0xe5a615f9}},	//   oens, ़रन्, मालय_, риги
  { {0x60c706d5,0xfa34002b,0x7d0338d8,0xa50a00af}},	//   _nejm, _درمد, nens, њева_
  { {0x98790053,0xa879004c,0x7d0338d9,0x61fd38da}},	//   _באַט, _באַר, iens, _apsl
  { {0xa3d7000b,0xa3c7000b,0x70de000b,0xdce30046}},	//   _सिर_, _उबर_, मल्ल, toně
  { {0xdcfa0089,0xb77b0008,0x877b0135,0xd2a70033}},	// [7a00] _chtě, _שאפש, _שאפי, ркуе_
  { {0xa63b000a,0x6fb60015,0x79810034,0x201801d7}},	//   _סגיר, لمطا, nllw, _prri_
  { {0x98a70011,0xe8d6000a,0x8ffa0015,0x9ffa0015}},	//   _zonă_, שוער_, ضرار_, ضراء_
  { {0x2d9e38db,0x4079004a,0x91e60ded,0x7d030577}},	//   _site_, ущую_, _коме, eens
  { {0x10a60342,0xb2bb000a,0xcee90015,0x7d0305ed}},	//   _вигн, _במכר, ارمن_, fens
  { {0x463b0053,0xdd0e0064,0x5cf60036,0x7d0338dc}},	//   כענע, _dışi, ряду, gens
  { {0x60fb000a,0x61e438dd,0x2d9e38de,0x70fb000a}},	//   _שהלק, luil, _vite_, _שהלח
  { {0xcfb70008,0x60c70089,0x9be30010,0x8fa305e6}},	//   _כללי_, _zejm, цішк, _фате
  { {0x7d03018b,0xcb670001,0xeb970001,0xb9540036}},	//   bens, јање_, шић_, йвищ
  { {0xd91a004a,0x7d0338df,0x2d9e0045,0x2bf60033}},	//   тьи_, cens, _uite_, _вядр
  { {0xb8ce005d,0xdce10024,0xe7870004,0x98a5003d}},	//   _कल_, _eklē, иумо, eklē_
  { {0x79810026,0x290e0fc1,0x644e2495,0x61e438c2}},	//   allw, _wafa_, dzbi, kuil
  { {0x0a160086,0x2f97004c,0xdb0a0012,0x26cb38e0}},	//   _خوشح, יכטן_, rpfä, raco_
  { {0x6b5e0048,0x3857002b,0xe3b30021,0x61e4008c}},	//   rīgu, اشید_, قرر_, duil
  { {0x61e40152,0x09290015,0x93970015,0xd37b0572}},	//   euil, _حسني_, لجرا, вча_
  { {0x442d010b,0x389b0008,0x60c738e1,0x9f530061}},	//   će_, _ביונ, _sejm, üdür_
  { {0x443f0048,0x60f9004a,0x3374008b,0x644e0183}},	// [7a10] ņu_, лная_, ігур, azbi
  { {0x2b4608e0,0x867c0008,0x32d70016,0x067c000a}},	//   _lloc_, _ברחו, ủy_, _בנחל
  { {0xc6780086,0x644e005c,0xd01100e6,0x36e1000b}},	//   _محیط_, czbi, ثلا_, _काफ़ी_
  { {0x6b610048,0xdb01003c,0x7d0338e2,0x61e4153a}},	//   lēgv, _utlø, wens, buil
  { {0x25a90049,0x7afd007c,0x7d0338e3,0x79810034}},	//   _jual_, õstm, tens, yllw
  { {0x660d000c,0x3d11000b,0x25a901d7,0x7d030012}},	//   _msak, _धोखे_, _mual_, uens
  { {0x3209003e,0x2b4638e4,0x8d62004a,0x84d8000a}},	//   lway_, _bloc_, явше, שֵׂא_
  { {0x660d0458,0x99840007,0x2b460034,0xdcf70061}},	//   _osak, kymų_, _cloc_, ıcıy
  { {0x7d0338e5,0xec15002b,0x320938e6,0x1dc60065}},	//   pens, _گواد, nway_, रीदत
  { {0x5d85003b,0x998400df,0x7d54054f,0x6d4a06ad}},	//   _الطل, dymų_, _двух, chfa
  { {0x61e4003f,0x32090a46,0x070a0015,0x660d38e7}},	//   zuil, hway_, هيدي_, _asak
  { {0x2bf60008,0x25a901c2,0x5f05000b,0xfe670015}},	//   _למען_, _bual_, _रसोई_, كد_
  { {0xab74003b,0x9b74003b,0x25a90467,0x04b60010}},	//   _بالإ, _بالص, _cual_, йсвя
  { {0x61e4022d,0x98a5006b,0x2b81002a,0x7ae938e8}},	//   vuil, _уике, wóch_, lget
  { {0x39420048,0x98b8005c,0xa5050010,0x7ae9003e}},	//   īkst_, órą_, цяўл, oget
  { {0x3ea00a00,0x39420024,0x61e438e9,0xa256002b}},	//   žiti_, ūkst_, tuil, مپزش
  { {0xd9f9005d,0xcb1201d8,0x86e90002,0xa3e4000b}},	// [7a20] ्बित_, הלן_, _ضعيف_, _नमक_
  { {0xa617000a,0x409600a5,0x290538ea,0x1dab000b}},	//   _פקיד_, брет, nela_, _चढ़त
  { {0x5ea600c3,0x290538eb,0xca8b009a,0xdfa9009a}},	//   ممال, iela_, ﮔﺮﻭﻩ_, لطنه_
  { {0x57ca0053,0x487a0053,0x69d8000b,0x63a80046}},	//   רמײַ, אטעס, _मिली, ídnu
  { {0x98a70091,0x6d4a0034,0xbdf70015,0x61e438ec}},	//   _zoną_, thfa, مروا_, quil
  { {0xa5db0053,0x29051c97,0xd1750033,0x8bc617bd}},	//   אַהי, jela_, _дысы, бсид
  { {0x7ae900b8,0x343a0053,0x759b000a,0x60260aa1}},	//   fget, טײַע, ניצח, _удва
  { {0x7ae938ed,0xeb470033,0x441b000a,0x4fd7004f}},	//   gget, йчык_, רוקס, _לולב_
  { {0x733b0053,0xcf25002b,0xeaaf0015,0x290538ee}},	//   טעקס, _ظرفي, رعي_, fela_
  { {0x3cf1002c,0xa95401f3,0x795814c2,0xc7ba08f0}},	//   ľový_, ікні, риор_, лём_
  { {0x6c86003b,0x2d95005e,0x660d002a,0xd8b70015}},	//   _الام, _єрус, _ssak, حدًا_
  { {0x99840007,0x09e602c5,0x320917cd,0x501b000a}},	//   tymų_, _годн, yway_, אוטו
  { {0xa3cb005d,0xab770086,0x6b7b000a,0x25a938ef}},	//   रीन_, _امنا_, _גראנ, _qual_
  { {0x660d018c,0x9f410046,0x290538f0,0xbd03006f}},	//   _vsak, ruhé_, cela_, _gréč
  { {0xb8fc000b,0x8bd8000a,0x7bd8000a,0x395e38f1}},	//   तः_, יַּח, יַּק, mits_
  { {0x322b0484,0xb865002b,0x67241207,0x320900da}},	//   лізм_, _باهو, _gnij, tway_
  { {0x6d4803c0,0x660d000c,0xe6b5005d,0xd1350001}},	// [7a30] _olda, _usak, ंडीज, онаћ
  { {0x6b610024,0x98f50092,0x320938f2,0xe004000b}},	//   lēgt, hỉn, rway_, रबंद_
  { {0x3f1503fc,0xe4ee000b,0x0596002b,0x7feb0021}},	//   ждес, _जाति_, _بايگ, طراف_
  { {0xc7b30053,0xa6fb000a,0x6d4838f3,0x6d5a38f4}},	//   לבע_, רִ֑י, _alda, _amta
  { {0xa1950238,0xdca50499,0x5de502a3,0x0000006a}},	//   _мамч, оали, іжка,
  { {0x527a0008,0xfe700087,0x0bb5006b,0x4ca80015}},	//   _כנרא, ردن_, ощия, مُهُ_
  { {0x7ae938f5,0xd1300015,0x395e38f6,0x23690045}},	//   tget, _ثمّ_, dits_, onaj_
  { {0xa3cb014e,0x7ae90320,0x4aa90e4d,0xe9d909da}},	//   रीय_, uget, шкин_, аки_
  { {0xc9a60080,0x7ae938f7,0x19390015,0xaf340015}},	//   овые_, rget, لأدب_, _عرفت
  { {0xf8af0086,0xdce30024,0x7ae90028,0x395e38f8}},	//   رکت_, ilnī, sget, gits_
  { {0xa3cb005d,0x1cb80115,0xc689000a,0xc909000b}},	//   रीम_, _طالب_, _סא_, _वसीम_
  { {0xbf870092,0x8f190008,0xef12000a,0xda16000b}},	//   _điền_, בוֹת, ֵּר_, तिशत_
  { {0x7cdb0024,0x395e0f4b,0xaa5838f9,0x39350033}},	//   pārē, bits_, _лицу_, _мэкс
  { {0xaa880029,0x7e9a00a3,0x6d4338fa,0x6b5e003d}},	//   _انهم_, יסרו, nkna, līgp
  { {0x64a3088d,0x141a0015,0xfbc70067,0xf992000a}},	//   дара, جيزة_, بت_, _חרג_
  { {0x96ba0083,0x672438fb,0xb3860033,0x0000006a}},	//   _туку_, _unij, ілал,
  { {0xa3cb005d,0x13a80086,0x6d432c78,0x6b61003d}},	// [7a40] रीब_, _گنجی_, kkna, lēgs
  { {0x6d430079,0x601a2c63,0x28bf0065,0x0000006a}},	//   jkna, ицер_, _श्मि,
  { {0x9eaa0004,0xb11700c3,0xdeef0033,0x600a194c}},	//   авеа_, تقلا_, мы_, рнем_
  { {0x1e860083,0xdfcf00e5,0x63b301b2,0x6e46012c}},	//   олем, ئين_, žené, ينام
  { {0xdd8f0086,0x80e60015,0xc333000a,0x657c0079}},	//   چون_, _وأسل, _חור_, oorh
  { {0xdd8f04c9,0x8e20005e,0x395e33d0,0x30760138}},	//   نون_, лiв_, xits_, _дубс
  { {0x395e38fc,0xfbcf0015,0xb607001a,0xa2ce0065}},	//   vits_, نتي_, _kváð, तरप्
  { {0xaf03023e,0x3ce00061,0xcf26002b,0x5a340658}},	//   _опсл, şiv_, _برسي, знит
  { {0xa92a008f,0xf3f904f9,0x14bf005d,0x8d66000d}},	//   аіне_, ăţi_, ्रमण, _двае
  { {0x58860010,0x236912df,0xf8af0015,0xee0b004c}},	//   жыма, znaj_, َةٍ_, _כּבֿ
  { {0x8d770015,0x7793002b,0x395e0c90,0x37aa012e}},	//   _بملء_, ویتا, rits_, јтон_
  { {0x395e1ee1,0x28ac000b,0x2b4d0003,0x61f60535}},	//   sits_, _फ़्रि, chec_, ktyl
  { {0x8f9b000f,0x94ab3658,0xbf9b004c,0x657c0595}},	//   ייטי, итва_, ייטש, forh
  { {0x2369002a,0xa9230004,0x224002f2,0x3f860247}},	//   wnaj_, _одчл, dyik_, hlou_
  { {0x3f860046,0x61f60535,0x0000006a,0x0000006a}},	//   klou_, etyl,   ,
  { {0x7bdb013a,0xf1ab0015,0x27f3006f,0x7304056d}},	//   יקלו, لائه_, žaní_, мчуж
  { {0x657c003e,0x2127002b,0x3f860046,0x325538fd}},	// [7a50] borh, ييری_, dlou_, чвар
  { {0x34951673,0x2ec30065,0x4174009a,0x3f86005a}},	//   _напр, शर्त, والس, elou_
  { {0x98b8002a,0x898b000a,0x22520069,0xcf9b012e}},	//   órę_, בָא֔, azyk_, ајд_
  { {0xbf580036,0x63ba002d,0xcf58005e,0xfe73002b}},	//   орії_, ítne, оріч_, ودش_
  { {0x7bc80176,0xdd14002c,0x0f180015,0x2252157b}},	//   _awdu, _dĺžk, تغلب_, czyk_
  { {0xfe700029,0xf1c4005d,0x1d090063,0xbd450015}},	//   خدم_, _लौटन, секи_, ثنتي
  { {0x26c2005c,0xbc190010,0x6d4338fe,0x14dc000a}},	//   ybko_, сілі_, rkna, שַׂמ
  { {0x3f860251,0xe6b5000b,0x6d432e1f,0x49c90499}},	//   clou_, ंडोज, skna, блин_
  { {0x5d553162,0x5f140065,0x8d8700af,0x3ea00052}},	//   _екат, _नोट्_, _дужд, þitt_
  { {0x98750054,0x0000006a,0x0000006a,0x0000006a}},	//   зумљ,   ,   ,
  { {0x9f950008,0xdb01016e,0xbf19000a,0x657c347c}},	//   ּדָה_, _eulá, ֖וֹך, vorh
  { {0x98a50007,0xabfa0008,0xbb180015,0x2d8702dc}},	//   yklė_, _להער, _وزنا_, llne_
  { {0xf5b60036,0xae1e005d,0x64a638ff,0x1b780015}},	//   ясню, पियन_, зага, _بصلة_
  { {0xa3d7000b,0x19ba000a,0x7afb0030,0xdb08005a}},	//   _सिख_, _המסב, lfut, _rudé
  { {0xf7463900,0x186601da,0x232a0588,0xe73a1cd9}},	//   _неко, _наши_, бови_, _гей_
  { {0xd2aa008f,0x883a0008,0x21f40020,0x52aa006b}},	//   скае_, _לתצו, täh_, свам_
  { {0x7afb003f,0xe2970254,0x87250015,0x61f60091}},	// [7a60] ifut, зат_, _زعيم, utyl
  { {0xf8bd000b,0x865b000a,0x2252002a,0x40960402}},	//   ोरिय, _לדפי, rzyk_, прет
  { {0xdb180084,0xb53b0008,0xdb0a003c,0xa3cb000b}},	//   msvö, _הגיש, ppfø, रीद_
  { {0x2d873901,0x0000006a,0x0000006a,0x0000006a}},	//   elne_,   ,   ,
  { {0x9e650086,0xbb4400f2,0x539b00a3,0x1ea90015}},	//   واهن, äämä, _ליטו, زاني_
  { {0xdce3003d,0xebc60054,0x3f86013f,0x25d7000a}},	//   donē, пљин, slou_, לונן_
  { {0x69dd032c,0x6bd60015,0x6026055f,0x98be002a}},	//   ásen, ستغر, _эдва, chtę_
  { {0xf914000b,0x5fdb000a,0xf413000a,0x7afb0030}},	//   _थोड़ा_, _לחלק, תפה_, gfut
  { {0x05ac005d,0x64430064,0x38c80086,0xbb470015}},	//   _टूलब, _üniv, يادی_, ثلين_
  { {0x7afb000c,0x7dbb0008,0x753a00b8,0x3257000a}},	//   afut, _לצמצ, ötzl, פסים_
  { {0x6698004c,0xfcd30015,0x66043902,0x4cbb004f}},	//   גאָרי, _سينج, _apik, _הזבו
  { {0xa5f90080,0x61e402c6,0x98a70046,0x3982001a}},	//   оему_, kril, _koně_, eðst_
  { {0x5fce000b,0x95c83903,0x62863904,0x0000006a}},	//   _हौसल, зуса_, _nyko,
  { {0xda650086,0x1a9b000a,0xba9b000a,0x69c0082f}},	//   _تامي, _הידע, _הסדי, mpme
  { {0xe2a6002e,0x97ad0064,0x78fb0008,0xd40414dd}},	//   íðna_, üştü, _לפגו, няти
  { {0x62863905,0x98130015,0xd7f80045,0x53342658}},	//   _byko, _أبوا, mtă_, нест
  { {0xd7f80011,0xd6d9002a,0xb18404b2,0xddcb0046}},	// [7a70] ltă_, ółu_, _šťav, _žižk
  { {0x69c03390,0xd7f80045,0x63a6001a,0x315b0015}},	//   ipme, otă_, _eikn, حجرة_
  { {0xd7f804f9,0x7d0a0061,0x2ef501c6,0xdcf8036d}},	//   ntă_, defs, дзер, govč
  { {0xd7f80011,0x2bb5003d,0x39590030,0x61e43906}},	//   ită_, _nāca_, éssz_, bril
  { {0xf2040033,0x5d79004a,0x237c0030,0x61e43907}},	//   _пяро, ойдя_, _ívja_, cril
  { {0xc2120008,0xf1b20008,0xc1050029,0xa6180008}},	//   _שהם_, _בסך_, _توسي, פקוד_
  { {0x3b95000d,0x645502ad,0xf77f007f,0x0000006a}},	//   мјит, nzzi, koç_,
  { {0x79880079,0xdb18007c,0x49b500af,0x0000006a}},	//   eldw, ksvõ, мљоу,
  { {0x66090064,0x59750033,0x14bf000b,0x2d871d08}},	//   çekl, дыну, ्राण, plne_
  { {0xd9960067,0x8e140033,0x35d00065,0x68450a10}},	//   ونيت_, _ядуц, तीफ़, дноа
  { {0xd764002b,0x5ce40015,0x6f190034,0x66043908}},	//   فندی, _أكمل, odwc, _spik
  { {0x501a0008,0xa5b2000b,0xb75a005e,0x34c6000b}},	//   קורו, _इंदौ, ішнє_, वर्द
  { {0xd7f80011,0x6b8905d8,0xa3cb021e,0x3696005e}},	//   ată_, mleg, रीस_, ьшос
  { {0x61e43909,0xe918005e,0x6b89390a,0x4a44005e}},	//   vril, _ночі_, lleg, _янів
  { {0xd7f804f9,0x443e028d,0x67560015,0xe5a3118f}},	//   ctă_, ât_, _يخبر, тири
  { {0x37870063,0x6b89390b,0x61e4390c,0x9f600030}},	//   _общо_, nleg, tril, ésül_
  { {0x6f190176,0x61e430ea,0x63a6390d,0x6b89033b}},	// [7a80] ddwc, uril, _vikn, ileg
  { {0x93c50092,0x62860264,0x61e40dd3,0xe0da0033}},	//   _khắ, _vyko, rril, іве_
  { {0x62860050,0x6b89002e,0x7d0a002e,0xf3e60457}},	//   _wyko, kleg, vefs, _южно
  { {0xddc2005c,0x61e43406,0xbe66006e,0xf836000a}},	//   czoś, pril, وهاي, ונעת_
  { {0x6b89390e,0xf2d30643,0xbea30174,0xf1a70065}},	//   dleg, _בער_, вацк, _कंचन
  { {0x4c940080,0xd657000a,0xc0d6002b,0xfe43006b}},	//   нилс, וינת_, _زيرب, ънчо
  { {0x93c50023,0x64430064,0xf1a7000b,0x6b89390f}},	//   _nhắ, _ünit, _कूटन, fleg
  { {0xda140001,0x6b893910,0xdb0102dc,0xac250138}},	//   едињ, gleg, _nulä, эфік
  { {0xf1bf0125,0x98be0046,0x58d42060,0x314a004f}},	//   _grád_, chtě_, нопт, ַתֹּ
  { {0xd8f80191,0x0d4a0015,0x8297000a,0x69c000da}},	//   чної_, _بشري_, ודפס_, rpme
  { {0x93c50092,0x7988003e,0x2d4b0723,0xbc6a009a}},	//   _chắ, rldw, _køen_, _بمان_
  { {0xd7f804f9,0xdc8b000a,0x4a46067a,0x6b893911}},	//   rtă_, _וְדָ, _онев, cleg
  { {0xd7f804f9,0xdb0802c1,0x56940142,0x8b9b000a}},	//   stă_, _judí, кают, _ובאת
  { {0xd7f80011,0x6b803912,0x661d0ee6,0x0000006a}},	//   ptă_, lomg, rvsk,
  { {0xe7e5005d,0xb8e4000b,0x9999006f,0xdb1a0003}},	//   _किया_, ौर_, ásť_, _atté
  { {0xa7380015,0x75d50015,0x6b800cbf,0x442101a3}},	//   _يثير_, _كيبا, nomg, _vrh_
  { {0x92590004,0xb33b0061,0x76040030,0x290c059d}},	// [7a90] чаат_, _hiçk, _vízö, oeda_
  { {0xddc2005c,0xdb0100b8,0x44210227,0x99f7000a}},	//   szoś, _zulä, _trh_, וזמה_
  { {0xa3cb000b,0xd371006e,0x518402bb,0xdb08151b}},	//   रीश_, _مهد_, тута, _audí
  { {0xc2eb0029,0xc49a0008,0x290c291f,0x389b000a}},	//   _بعدم_, _משתת, heda_, קיאנ
  { {0xed4e0139,0x1622000b,0xa3cb000b,0x35b70065}},	//   го_, मियर_, रीर_, _इंफ़
  { {0x290c3913,0x867c000a,0xa0c5012c,0x6b89051e}},	//   jeda_, קרגו, _سيرو, wleg
  { {0x290c2f6d,0x98a5003d,0x6b893914,0x6b800079}},	//   deda_, rklī_, tleg, fomg
  { {0xdab90010,0x8fa50015,0x70942b9d,0xe7e5000b}},	//   чыкі_, _أمره, _расф, _किबा_
  { {0xe2fa000a,0x6b893915,0x61ed050d,0x1e1b0015}},	//   הִים, rleg, nual, _بغزة_
  { {0x290c0020,0xd102000b,0x54ee000b,0x6b893916}},	//   geda_, र्पण_, _जाइए_, sleg
  { {0x3cf80015,0x61ed3917,0x6b893918,0x1da80065}},	//   _تعقد_, hual, pleg, _छूटत
  { {0x4426032c,0x8c1a0008,0x61ed3919,0x290c007c}},	//   _čo_, _מועי, kual, aeda_
  { {0xd7c9002b,0x61ed1839,0x290c391a,0x9a470058}},	//   _کوبه_, jual, beda_, _تضاه
  { {0x93c50092,0x290c391b,0x61ed391c,0x9a3a000a}},	//   _thắ, ceda_, dual, _מתנק
  { {0xf1bf017e,0x232a10a6,0xc3960054,0xc976004f}},	//   _atá_, пови_, ејањ, _אגסי_
  { {0xc7960080,0xe73a009b,0x3ead02dc,0x0000006a}},	//   _ярлы, _хеи_, _nget_,
  { {0x74ba0342,0x91e31215,0x61ed0676,0x312602ed}},	// [7aa0] _нунс_, лоте, gual, ндаг
  { {0x96570008,0xdce30007,0x79810034,0x5283391d}},	//   _נשיא_, monė, nolw, الْك
  { {0xd3da0015,0x505a01c5,0x232a0054,0x60260033}},	//   _عبدا_, чшая_, _еони_, эджа
  { {0x60c30064,0xdfcf0018,0x79810026,0x03bb004f}},	//   ınma, صيه_, holw, _מצטל
  { {0xbd870086,0x7981005c,0x61ed0049,0x9476002b}},	//   کنون_, kolw, cual, _زدگا
  { {0x26d20297,0x3ead153c,0x3cfb000b,0x237f391e}},	//   _leyo_, _eget_, ल्ले_, čuje_
  { {0x0ba6005e,0xdee6391f,0x290c3920,0x79810034}},	//   ншим, _пови, veda_, dolw
  { {0x2d8501e2,0x6ffb0008,0xdb080046,0x7646008c}},	//   _ekle_, _מפלג, _tudí, kyky
  { {0xdee3005e,0xbab70015,0x7bc301c0,0x49740302}},	//   _щоти, رديء_, apnu, клис
  { {0xccf80089,0x79810026,0x9e630054,0x290c0077}},	//   _změn_, golw, _свуд, ueda_
  { {0x61ed04f9,0x31570053,0x290c3921,0xa157004f}},	//   zual, גיין_, reda_, גביה_
  { {0x290c018c,0x7d1a3922,0x0000006a,0x0000006a}},	//   seda_, _hats,   ,
  { {0x7d1a0c58,0x290c00e8,0x55070151,0xbebd003d}},	//   _kats, peda_, нчва, _snūk
  { {0xd90e0086,0xba17000a,0xb9780015,0xee2e00e2}},	//   _اید_, _נחוץ_, _تمتص_, рнi_
  { {0x23e4008f,0xc88500b8,0x15ed000b,0xf770002b}},	//   літв, ößte_, _जमकर_, _گاو_
  { {0x3ea901a3,0xe3b000e5,0x61ed03b0,0xf1bf0046}},	//   žati_, صرف_, tual, _ptá_
  { {0x61ed008c,0x5215006b,0x8f000033,0xb5a71eea}},	// [7ab0] uual, ъдат, зiў_, _прой
  { {0x35f80029,0xdb0100c0,0x7d1a3923,0x7bc301c0}},	//   _أريد_, _utlö, _nats, ypnu
  { {0xdcb10023,0x7f190036,0x61ed0901,0x351a004f}},	//   _bản_, ділу_, sual, _חותנ
  { {0x0cbb000b,0x22950015,0x7d1a0079,0xdcb10016}},	//   ॉर्म, _للجس, _aats, _cản_
  { {0x5f740002,0x82d6000a,0x61ed037e,0xb33b0061}},	//   دالر, _בורג_, qual, _niçi
  { {0x2bb90015,0x20d40015,0xc694000a,0x398b02de}},	//   وابة_, _متفج, נאס_, røsk_
  { {0x2ef5050e,0x8cd3000b,0x0000006a,0x0000006a}},	//   _извр, डरबो,   ,
  { {0xb33b01e2,0x3eb90064,0x6d4a118e,0x7981002a}},	//   _biçi, _üst_, akfa, wolw
  { {0xf2d40053,0x29550063,0xfe730002,0xc334000a}},	//   נעץ_, вънр, _صدر_, רופ_
  { {0x2903002e,0x7cd90086,0x98a51eb1,0x672d003f}},	//   ýja_, _آواز_, кипе, _anaj
  { {0x408c000a,0x798100e7,0xb17b02dc,0xdcb100a1}},	//   ּאכְ, rolw, _tvåf, _hảo_
  { {0x366a0800,0xfe6700c3,0x8c64302b,0xaac70015}},	//   дамо_, لد_, _студ, _أتان
  { {0xa3d4000b,0xeab0002b,0x0675006b,0x8e20005e}},	//   सीन_, _اعم_, гуря, кiй_
  { {0x6f1b0048,0x7dd8002d,0xd7c90015,0x63ba0046}},	//   _lauc, _húsá, _قوته_, ítno
  { {0xccf2000f,0x9479335c,0x0000006a,0x0000006a}},	//   יכם_, есту_,   ,
  { {0x6f1b12e1,0xa256009a,0x0000006a,0x0000006a}},	//   _nauc, نپزش,   ,
  { {0xa2b3000b,0xdcf80045,0x03a33924,0x65670079}},	// [7ac0] _अलर्, novă, рито, bijh
  { {0x25d700b2,0xd5b7014e,0x672d3925,0xdcb10092}},	//   _שוין_, _इंतज, _znaj, _sản_
  { {0xc0590036,0x4fa6006b,0x6f1b0012,0xd00f0015}},	//   нії_, вижв, _bauc, يلك_
  { {0xdcb10023,0x44770008,0x5477000a,0x13b7000a}},	//   _bảo_, _יעיל_, _יגיע_, _שהכל_
  { {0xa66d000f,0xfe720015,0x7db30015,0x7d1a3926}},	//   ּדוֹ, جدا_, لمنص, _pats
  { {0xde930001,0x365b000a,0x8db50033,0xe7f20065}},	//   јашњ, וכננ, усці, _अमला_
  { {0x98be0007,0x3f6a0a0b,0x6f1b3907,0x7dd8001a}},	//   nktą_, _живо_, _fauc, _búsá
  { {0x6f1b0152,0x9c450010,0x5b140658,0xdb67004a}},	//   _gauc, ыхіл, умит, крыл_
  { {0x7d1a3927,0xb60600bc,0xc333004f,0x3ea302ed}},	//   _tats, ndšč, שוח_, _витг
  { {0x35dc000b,0xde250015,0x672d2a47,0x729b004f}},	//   _बिज़, _حرفً, _snaj, וספס
  { {0xd6d5004a,0xb02a0033,0x6da3011e,0x96f90598}},	//   лжны, звiв, _тифа, нент_
  { {0xcbc50015,0x69db0077,0x98ac0091,0x3fdb004f}},	//   _إزلي, bsue, ykdė_, וקטב
  { {0xe664352f,0x867400ce,0x7bc1005a,0x37040138}},	//   атро, илює, _ztlu, шчэв
  { {0xda650087,0x19b90033,0x64bf000b,0x7ae2008c}},	//   _حامي, _чуць_, ्रेश, _hdot
  { {0x89370008,0x44250cb1,0x28370015,0x94d40033}},	//   _ברגע_, íl_, _لأية_, росц
  { {0x672d16d3,0x97a40256,0xd378005e,0x291c3928}},	//   _unaj, _крыл, вчу_, _hava_
  { {0xd6fa0008,0x291c0020,0x6f1b020d,0x291e00cb}},	// [7ad0] _אִיש, _kava_, _rauc, odta_
  { {0x291e00dc,0xf8b1000a,0x26d90ff0,0x6d8d0030}},	//   ndta_, ֶשׂ_, laso_, rúak
  { {0x7ae2022d,0x6b5e0048,0x29c20092,0x859a000a}},	//   _odot, lūgu, hưa_, _רשתו
  { {0xe3b00086,0x8d84002b,0xa857000a,0x291c3929}},	//   _گری_, یشون, כיבה_, _lava_
  { {0xdef8044e,0xfce505cb,0x2369002a,0x201e0085}},	//   тых_, голо, miaj_, _štit_
  { {0xe3b00086,0x0d840484,0x7ae2392a,0x1cb9006e}},	//   _دری_, алін, _adot, راتب_
  { {0x6f1b00b8,0x39990003,0x26d9392b,0xbfb8002b}},	//   _tauc, nèse_, kaso_, _لطقا_
  { {0xe4e3005d,0xdce30007,0x3a15006b,0x2369002a}},	//   कृति_, minč, гьос, niaj_
  { {0xdce3392c,0x2249013c,0x3a2600da,0x39990003}},	//   nonī, nyak_, _crop_, hèse_
  { {0x6ce4008f,0x22490035,0x69db1346,0x3a262570}},	//   _віце, iyak_, rsue, _drop_
  { {0x65e20053,0x3a260111,0x9af50015,0xc156000a}},	//   יפּער, _erop_, _مكات, רשתו_
  { {0xf0920008,0xdb0800dc,0xdcf80045,0x6d41392d}},	//   מני_, _tudá, povă, _hola
  { {0x09e50080,0x55f602bf,0x9b16000a,0x09e40033}},	//   _солн, ычну, _תחנה_, _воін
  { {0xdce310f4,0xfa34002b,0x60d52943,0x94aa0015}},	//   kinč, _خرمد, _nezm, ّارِ_
  { {0x6d410541,0x5faf000b,0xa2e60c31,0xf99205bd}},	//   _mola, _जंगल, ловд, _הרג_
  { {0x6441008c,0x26d9392e,0x8cca0157,0xe355066a}},	//   älia, caso_, _स्नो, атуэ
  { {0xb226008f,0x60d50ca3,0xb77b004c,0x422601b0}},	// [7ae0] ымал, _bezm, _ראפש, ыдав
  { {0x6705005d,0x6b5e0024,0x6d410eb6,0x2ecc000b}},	//   ष्ठक_, lūgt, _nola, ार्त
  { {0xdcb10023,0xd46a239c,0xb4fb0447,0x39990003}},	//   _cảm_, _чине_, _אפיי, cèse_
  { {0xf1bf392f,0x4f953930,0x35cb0065,0x2369013b}},	//   _irán_, арчу, ़ीक़, ciaj_
  { {0xdee30608,0x4379000a,0xde031111,0x6d413931}},	//   сочи, _יְשׁ, йпци, _bola
  { {0x645c002c,0x3f8f0020,0xa3cb000b,0x6d413932}},	//   ozri, algu_, रीक_, _cola
  { {0xab5c0048,0xfbaa033d,0x4f962372,0x69c22322}},	//   _atļa, нтий_, _брау, _stoe
  { {0x6d41017e,0x291c0048,0x3a262efb,0x600b000a}},	//   _eola, _sava_, _prop_, _אִמְ
  { {0x6d41002d,0x8f9b000a,0xdd8f002b,0x29c70015}},	//   _fola, _טילי, _کول_, هِيَ_
  { {0x02170008,0xa967000d,0x6d413933,0xdb0b0144}},	//   נחים_, лиња_, _gola, _ligè
  { {0x313701d8,0xb8dc005d,0xe7590036,0xe89404f7}},	//   אריך_, _अल_, вині_, рань
  { {0x3a26038d,0x7077004c,0x6d410079,0xa3b8000b}},	//   _trop_, רײטע_, _zola, _चढ़_
  { {0xb5fb0014,0xe6670809,0xe4e7005e,0x2b92002b}},	//   zzáf, утно, лівн, _پیکس
  { {0x2369002a,0x4a5b000a,0xf1bf005a,0x6d580052}},	//   wiaj_, _אדדו, _brán_, nhva
  { {0x88bb0053,0x3c780008,0x26d93934,0x03d5005e}},	//   _אזוי, דָּב, paso_, ржбю
  { {0xe3150001,0x8bd7004f,0x93970058,0xdce33935}},	//   јмањ, טולו_, اجسا, vinč
  { {0x32b80015,0x6234005e,0x522400ce,0x31a50369}},	// [7af0] ادفة_, бету, йффа, لمرف
  { {0x660d00b6,0x2369005c,0x7c283936,0xdce308a9}},	//   _ipak, siaj_, _ordr, tinč
  { {0xd0110087,0x60d50107,0xa3cb000b,0x224901c2}},	//   تلا_, _vezm, रीख_, syak_
  { {0x743a00b2,0xdce30007,0x60d5002a,0xb5c8002b}},	//   _סערװ, rinč, _wezm, _جویم_
  { {0x8e85000d,0xa91c002c,0x6d413937,0x7c283938}},	//   јгле, voľn, _pola, _ardr
  { {0x660d000c,0xd5bc00b2,0x64480012,0xfbc5005e}},	//   _mpak, עזול, ädig, абко
  { {0xeab10029,0x8cc1000b,0x251c000a,0x351c000a}},	//   يعة_, रुषो, גווא, גוונ
  { {0xdd050061,0x660d2e09,0xd5b5000b,0x6d413939}},	//   ısıy, _opak, ंदाज, _wola
  { {0x5f4400b0,0xa9c4002b,0xc334000a,0x7c2816a7}},	//   _انقل, یزیو, מוק_, _erdr
  { {0xaa080029,0x61ed0f8a,0xb902005e,0xf9910015}},	//   ازيل_, iral, озьк, غبة_
  { {0xec150015,0x61ed006f,0x660d393a,0x5b15029f}},	//   _خواد, hral, _apak, _вмет
  { {0x2d87393b,0xf6260937,0x4c3a000a,0x6e29393c}},	//   lone_, адмо, _בתעב, _kreb
  { {0x7f3a00b4,0x0ab40074,0xbb840029,0x04b60036}},	//   דערו, _احمد, _الني, исвя
  { {0xa979004c,0x2001172e,0x2d87393d,0x18a52c75}},	//   _שאַכ, kthi_, none_, _калм
  { {0x64a60803,0xdb0b002d,0x6f09037f,0x69c9393e}},	//   рава, _aigé, _obec, lpee
  { {0x58940015,0x987a000a,0xdc88000a,0x2d872345}},	//   _اجهز, _באצט, רְשָ, hone_
  { {0x42230080,0x2d87393f,0x52aa3849,0xd2aa0033}},	// [7b00] одтв, kone_, твам_, ткае_
  { {0xe3ba0080,0xf1bf0016,0xc0e61638,0x6f093940}},	//   _ибо_, _trán_, рожк, _abec
  { {0x46ba000b,0xd102000b,0xf1bf01c0,0x2fd70015}},	//   _इलाह, र्षण_, _hrál_, لولد_
  { {0xf1bf0089,0x3f7802c6,0x3fa50015,0x21210125}},	//   _král_, ačun_, مصنف, adhh_
  { {0x2d873941,0x63a400ed,0x6e293942,0x6d583943}},	//   fone_, mmin, _creb, thva
  { {0xb5fb0014,0xacf8022a,0xcbe60254,0x63a43944}},	//   szág, унку_, ации, lmin
  { {0x6ca30063,0x69c90409,0x2c08002b,0x317b004c}},	//   оръж, epee, اعتی_, _סאלד
  { {0xa3cb000b,0x501b000a,0x0b180054,0x63a40654}},	//   रीट_, _בולו, ужић_, nmin
  { {0x998202d5,0x4d16004a,0x238a0091,0x63a40961}},	//   íků_, _вьет, mėję_, imin
  { {0x63a401e2,0x8dfb0008,0x2d873945,0x238a0091}},	//   hmin, _בהמת, cone_, lėję_
  { {0x63a40c80,0xc053004c,0xb5fb0030,0x660d3946}},	//   kmin, ַזש_, zzád, _spak
  { {0xdce30024,0x7bca00b8,0x6f010030,0x8cca000b}},	//   minā, mpfu, mábó, _स्तो
  { {0xdce30048,0x63a40aa0,0xbb3b0c44,0x7bca3947}},	//   linā, dmin, _שעדי, lpfu
  { {0x89db000a,0x14c7002b,0xb866002b,0x61ed3948}},	//   _יחדי, شهری_, _پاتو, vral
  { {0xdce30048,0x6b550077,0xa99b000a,0x398b0789}},	//   ninā, _hága, _שבור, røst_
  { {0xe7380124,0x23bc00dc,0x8e200010,0x3ea00089}},	//   _већ_, _díj_, кiм_, žity_
  { {0x2d87003e,0xdcef0089,0x238a0091,0x2d9e007c}},	// [7b10] yone_, _řeče, dėję_, _ohte_
  { {0x61ed041c,0xdcf80024,0xa2b3000b,0x79880034}},	//   rral, ilvē, _अलक्, nodw
  { {0x2b81005c,0x6f0100dc,0x628f0305,0xdfa7000d}},	//   rócz_, jábó, _wyco, ајдо
  { {0xdce30024,0x8db50010,0x79880026,0x20011f22}},	//   dinā, бскі, hodw, rthi_
  { {0xfe7003c4,0xf1a7000d,0x539a000a,0x9f0400c3}},	//   وده_, _врвн, _תירו, تونو
  { {0xa5da0053,0x6b730045,0xbebd003d,0xa19400ce}},	//   אַקי, măgi, _saūd, _маяч
  { {0x2d873949,0x7afd0144,0xeb02000b,0xd1300015}},	//   rone_, òsto, लभूत_, _تمّ_
  { {0x44780008,0x2b150036,0x5478000a,0x6e29394a}},	//   יעול_, ськр, יגוע_, _treb
  { {0xaa490080,0xcdf40029,0x89350015,0x79880034}},	//   уппа_, _وأكث, معدا, fodw
  { {0x69c900f2,0xdce30024,0xc27c000a,0x63a4394b}},	//   rpee, binā, כרחי, zmin
  { {0xdce30048,0x644100f2,0x6c850029,0x7c9500a2}},	//   cinā, älil, _الضم, _الاص
  { {0x6b55002d,0x97560099,0x69c90e93,0x7c2e394c}},	//   _fága, стољ, ppee, _ábra
  { {0x4e790053,0xa909002b,0x9a870138,0x63a4007f}},	//   ראָצ, _ميشل_, _тужл, vmin
  { {0x63a40034,0x0446030e,0x6b890316,0xe4da0058}},	//   wmin, бегн, loeg, طورت_
  { {0x63a40005,0x85790063,0xdce80046,0xb4b80065}},	//   tmin, рсят_, _ajdě, _छली_
  { {0x67560086,0xdcb10092,0xf772002b,0xe8740015}},	//   _دختر, _cải_, _ژاک_, _باهظ
  { {0xdce30048,0x78c600dc,0x9757000a,0xe0d20015}},	// [7b20] zinā, _érvé, _לשקף_, كزا_
  { {0x63a4394d,0xdb080123,0x05b50065,0xe1650058}},	//   smin, _utdö, ंदरब, يدلي
  { {0xd8da0053,0x8ffa00c3,0x251b0643,0x63a430b6}},	//   רקער, طرار_, _גויא, pmin
  { {0x27fa003c,0xd00f0029,0x644e0007,0x7de60029}},	//   _åpne_, علن_, mybi, مستم
  { {0x656e0125,0xcf250040,0x238a0091,0x644e2cb6}},	//   oibh, ترلي, rėję_, lybi
  { {0xdce30024,0x8e200036,0x6f0100dc,0x61f60061}},	//   tinā, кiв_, tábó, muyl
  { {0x61f60064,0x60de003d,0x644e0091,0x238a0091}},	//   luyl, mapm, nybi, pėję_
  { {0x90770053,0xdce30024,0xf0630802,0x6f010030}},	//   _העלא_, rinā, _эксп, rábó
  { {0xdce30048,0x61f60064,0x6f0100dc,0xdd9200c3}},	//   sinā, nuyl, sábó, _فور_
  { {0xdce30024,0x644e0007,0x290a002c,0x26c20bba}},	//   pinā, kybi, ýba_, ecko_
  { {0x23810007,0xa71502a3,0x2bca096d,0x113b004f}},	//   lėje_, омні, _слеп_, אתיל
  { {0x644e0007,0x79880026,0x29020089,0x64410f7a}},	//   dybi, sodw, řka_, älim
  { {0x238100df,0x8f9b004c,0x8f8b000a,0xc66b394e}},	//   nėje_, טיטי, רְיֵ, ушне_
  { {0x656e002d,0xe3b30029,0xdce30011,0x67d42374}},	//   gibh, كرر_, mină, _доку
  { {0xf3970015,0x644e0091,0x93970015,0x6b550030}},	//   مؤرخ, gybi, مجرا, _mágn
  { {0x5b7b00b2,0x443f016f,0xa91c002c,0x92b70029}},	//   ָרמא, ću_, koľk, صحرا
  { {0xdb08002c,0xc2c40015,0xe820000b,0xb5fb0030}},	// [7b30] _budú, سيلي, यिका_, száb
  { {0xba9b0008,0x25d8000a,0x1a9b004c,0x32d70016}},	//   רסמי, _הוזן_, רימע, ầy_
  { {0xdcb10023,0x4427394f,0x0f35002b,0x644e051e}},	//   _tải_, _én_, يکرد, cybi
  { {0xd7fb0053,0xdddb0156,0x60c90061,0x1eea002b}},	//   רהאל, _využ, _şemd, لومی_
  { {0x6b890991,0x98a7005c,0xf1273950,0x877c004c}},	//   voeg, _inną_, _льво, נאדי
  { {0x60de0024,0xe1040033,0x629d003d,0x3cfe190e}},	//   capm, _нясп, _izso, _cctv_
  { {0x8c420063,0xd5b5000b,0xdcf80046,0xc19a000a}},	//   деще, ंदुओ, lově, _כששי
  { {0x39e93951,0x1b49067a,0x23810091,0x19c50850}},	//   адио_, рзии_, bėje_, обим
  { {0x44240092,0x644e002a,0xfaf9003d,0xdcf80046}},	//   ̉m_, zybi, rgū_, nově
  { {0x764f005c,0xb0c70033,0xb4b8000b,0xb1e8000a}},	//   dycy, апiс, _छले_, צֵחַ_
  { {0x8c190029,0xe73a017a,0x07a61402,0xdcf80046}},	//   _خيار_, аен_, жанн, hově
  { {0xc4c90dab,0xa088000a,0x3ffa004c,0x644e0091}},	//   _יג_, מְרִ, ספרע, vybi
  { {0x2bb50024,0x65a000b8,0x0f36000a,0x8f1a000a}},	//   _vācu_, höhe, קרשט_, בורת
  { {0xdcf80089,0x644e0870,0x7afb007c,0x89e8004f}},	//   dově, tybi, lgut, _הַקֵ
  { {0x442c002d,0xa34a3952,0xd91a000a,0x97c50021}},	//   íd_, азва_, _כוסל, _بقبو
  { {0xfbe700a7,0x644e0c89,0x7afb3953,0xe81e000b}},	//   _để_, rybi, ngut, _बनता_
  { {0xb5fb002c,0xcb12000f,0xf4b60015,0x7afb007c}},	// [7b40] rzác, ולן_, _وإدخ, igut
  { {0x21a30083,0x6724000c,0x50960001,0x23810007}},	//   диум, _haij, оређ, vėje_
  { {0xe0d50036,0x6726003c,0x61f60061,0x3cfe3954}},	//   яють, odkj, suyl, _rctv_
  { {0x25b70086,0x23810007,0x11d6017f,0x63ba0046}},	//   _دهید_, tėje_, _мігр, ítnu
  { {0xeda6023e,0x67241f8a,0x577b000a,0x2e160015}},	//   ошко, _maij, סטנצ, تباح
  { {0x23810007,0xc43a0008,0x61e43955,0xcd06005e}},	//   rėje_, ֹתֵי, msil, ічли
  { {0x6b5c0152,0x23810007,0xe819000b,0x764f002a}},	//   _lége, sėje_, _फैला_, zycy
  { {0x8cca005d,0x23810007,0xa03b004c,0x93b7000a}},	//   _स्रो, pėje_, _דעלפ, חלקו_
  { {0x61e41ae0,0xbb470015,0xde170015,0x7f590054}},	//   nsil, تلين_, _وقفت_, _ујрт_
  { {0x3237000a,0xc237000a,0x61e43956,0x3958001a}},	//   קטין_, קריו_, isil, órs_
  { {0x6d5a008c,0x60dc3957,0xb19b000a,0x61e40f0a}},	//   _ilta, _merm, שייכ, hsil
  { {0xaba50029,0x61e40604,0xd6db3958,0xbc1b000a}},	//   _فإنه, ksil, што_, _כובש
  { {0x6b5c3959,0xaa570029,0x3947395a,0x6d48395b}},	//   _végd, _ولما_, _fons_, _koda
  { {0xd5b8008f,0x65a000f2,0xda330033,0xdcf80046}},	//   ўся_, yöhe, _цешы, vově
  { {0x29c00023,0xc7970015,0x236b0054,0x764f002a}},	//   _hòa_, _وشعب, ајао_, sycy
  { {0xdce3002a,0x53990033,0x533424bf,0x6d48395c}},	//   miną, ёвая_, мест, _loda
  { {0x6d480020,0x60dc0d25,0x61e40035,0x6d5a395d}},	// [7b50] _ooda, _berm, gsil, _olta
  { {0xd7f80011,0x8cca000b,0xb81e000b,0x60dc0049}},	//   ouă_, _स्लो, _बनाम_, _cerm
  { {0xd7f80011,0x7ae00035,0xdef10015,0x04590015}},	//   nuă_, kamt, فًا_, _طلحة_
  { {0xdcf80089,0x441a0008,0xed590089,0x188b000a}},	//   pově, _פורס, _muže_, בְדּ
  { {0xfe710086,0x7dc40029,0x433a000f,0x60dc395e}},	//   رگر_, وتوك, _הערב, _ferm
  { {0xabd50180,0x8d65054c,0x91ba000a,0x85f8000a}},	//   пциј, явле, _למשי, קצוע_
  { {0x6d4809cb,0xdfd10015,0xaed502ed,0x7afb02ad}},	//   _doda, _سيء_, _новш, tgut
  { {0xb5fb0014,0x547c01ac,0xe9d90c71,0xa5bb002a}},	//   zzáa, יטוו, бки_, owód
  { {0x671f000b,0xde58005e,0x7afb395f,0x60c50012}},	//   यजनक_, _даті_, rgut, ochm
  { {0x6b5c01c4,0x60c50334,0x395e22a5,0x6f190034}},	//   _rége, nchm, ghts_, lewc
  { {0x7d7a0053,0x661d005c,0xc172000a,0x60c501f1}},	//   _פרעג, ewsk, תחי_, ichm
  { {0x6d480298,0x00560008,0x6f190026,0xed59016f}},	//   _zoda, פשרת_, newc, _duže_
  { {0x45d30010,0x44213562,0xe8ee17bd,0x3947082d}},	//   ноўс, _ash_, _пл_, _tons_
  { {0x1ddd005d,0x88bc0089,0x6b5c00dc,0x395e2259}},	//   नीयत, nděl, _vége, chts_
  { {0x6b550084,0x68e10005,0x03a6023e,0xd8da000a}},	//   _lágm, mald, зиво, _הקצר
  { {0x6b5c00dc,0x91b10092,0xe7690015,0x60dc31ea}},	//   _tége, _đáp_, _وحين_, _serm
  { {0xd29a0036,0x50ba0086,0x80d8000b,0x6f190034}},	// [7b60] стві_, مداد_, यरले, dewc
  { {0x11d70015,0x776d006f,0x64a60da9,0x9f41013f}},	//   سومة_, _zmax, _напа, ruhý_
  { {0x351b0008,0x14d70053,0x73e3004a,0x88bc0046}},	//   _פוטנ, _מויל_, _поэз, dděl
  { {0x68e13960,0xc7d60008,0xdfcf0031,0x6d483961}},	//   hald, פוני_, اين_, _soda
  { {0xf3f100a7,0xa3b5005d,0x68e103f6,0xd2b7000a}},	//   ợc_, _छूट_, kald, _מלכת_
  { {0x68e111ce,0x3c94004a,0x61e200bc,0xe6d9000b}},	//   jald, милё, šols, _भज्ज
  { {0x7ae00505,0x71a30033,0xccf80046,0x6d5a3962}},	//   tamt, _чарз, _směs_, _vlta
  { {0xad660086,0x7b630080,0xb40d0008,0x0b8a0001}},	//   _کاره, етье, ׁלוֹ, љски_
  { {0x23810007,0x7f3b000a,0x6d4808aa,0x68e13963}},	//   nėja_, _פעמו, _toda, fald
  { {0x68e13964,0x7ae03965,0x6d48008c,0x237f0046}},	//   gald, samt, _uoda, čuji_
  { {0xa91c032c,0x7ae0016f,0xbd290015,0x07e3005e}},	//   koľv, pamt, _بأقل_, нцям
  { {0x29c00092,0xdc3b000a,0xf8af0015,0x68e11c2c}},	//   _tòa_, _לעבר, دةً_, aald
  { {0xf1bf0092,0xc6a4004a,0x9f530003,0x60c52f6c}},	//   _trái_, ерри, édés_, ychm
  { {0x5e5700b2,0x4a530036,0x18740142,0x23810007}},	//   ליכע_, _якіс, _огля, dėja_
  { {0x43953966,0xdb1a0077,0x91790016,0xa99b000a}},	//   давс, _auté, _lận_, _הבגר
  { {0xa87b009d,0x88bc0089,0xdc370053,0x187b000f}},	//   _לאור, zděl, האלט_, _לטוב
  { {0x248d0050,0x7afd0144,0x88bc0046,0x23810091}},	// [7b70] łem_, òsti, yděl, gėja_
  { {0x865c000a,0x11d40040,0x30a70658,0x60c50012}},	//   _לדחי, عتقد, прев, uchm
  { {0xb4d90372,0xc9530053,0xb0a7000b,0x50190015}},	//   ारी_, עמע_, केंग, تياح_
  { {0x60c500b8,0x9f550010,0xfec40015,0x91790016}},	//   schm, ьвеч, ّينَ, _bận_
  { {0xe2ab0074,0xb5fb00dc,0x91790092,0xc0cb007e}},	//   _دادن_, zzán, _cận_, _губе_
  { {0x62800007,0xccf80046,0x518702b0,0xb5fb0046}},	//   _žmog, _směr_, _хума, yzán
  { {0xea000023,0x68e13967,0x0f35002b,0x69da000b}},	//   _đại_, vald, _يکصد, पीसी
  { {0xab790015,0xf414000a,0x68e137c0,0x49c90461}},	//   تمعا_, תפק_, wald, олин_
  { {0x320900b6,0x80e1005d,0x4ea70292,0x68e13968}},	//   ntay_, _फ़ाइ, _хрва, tald
  { {0x6e280008,0x57e9008d,0x3f8f1820,0x47c50974}},	//   _מֵעַ, одом_, logu_, мбов
  { {0x8cc80086,0x35b7000b,0x0889056d,0x68e13969}},	//   _رونق_, _इंज़, юбой_, rald
  { {0x7c940029,0x68e1396a,0x80a5000b,0x6008000a}},	//   _أشكا, sald, _करने, הִשְ
  { {0xb5fb00dc,0x69cb0123,0x68e1396b,0x98a50061}},	//   szán, _utge, pald, rhlı_
  { {0x64a63344,0x19ba000a,0x0000006a,0x0000006a}},	//   дага, _ומסב,   ,
  { {0x3f8f0005,0x141a0015,0xa507004a,0xb5fb0030}},	//   kogu_, غيرة_, ьера_, lzál
  { {0x130a008f,0x03a3396c,0x23810091,0xf772002b}},	//   ўнай_, висо, tėja_, _جات_
  { {0x2fcd016f,0xe29723e4,0xa5760015,0xb5fb396d}},	// [7b80] _čega_, дат_, _يُعت, nzál
  { {0x6b5c0003,0x23810091,0xc0760054,0xe57a0004}},	//   _méga, rėja_, мћењ, _фзо_
  { {0x7f460010,0x6b5c0152,0x653b0008,0x409605b3}},	//   межж, _léga, _ועיד, фрат
  { {0x2bc4000b,0x02d60015,0xdb1a1004,0xdce30535}},	//   _लंबा, _تتدخ, _tuté, minę
  { {0x6b5c0152,0xd1760010,0xe81d000b,0x2e47006b}},	//   _néga, _жывы, यौता_, дящо_
  { {0xdfd2003b,0x91790092,0x1ea900e6,0xf1bf0264}},	//   _ليس_, _vận_, ساني_, _práv_
  { {0xab940191,0x1d190010,0x55770053,0xbfc30010}},	//   никі, яюць_, ועסן_, _абск
  { {0x91790092,0x6b5c0003,0x9c7c396e,0xdb0200a1}},	//   _tận_, _béga, _neče, _khoé
  { {0x8bb3003b,0x29860138,0x0000006a,0x0000006a}},	//   خصوص, дынг,   ,
  { {0x6b5c0003,0xdb0b016e,0xdce30091,0x0000006a}},	//   _déga, _vigá, kinę,
  { {0xd0f70008,0x00f7009d,0x9cd70008,0xc0a9000a}},	//   ומית_, וזים_, _חובה_, ּירָ
  { {0xa91c002c,0xf1bf01c9,0x61f60188,0xa5bb001a}},	//   voľu, _krát_, kryl, kvót
  { {0xb7d80086,0x99660d87,0xf628005e,0xf98f002b}},	//   _کوبا_, _откл, міри_, طبی_
  { {0xb4d9014e,0x88bc0089,0xd7fa000d,0x1a9b000a}},	//   ारे_, zděj, _дуи_, _וידע
  { {0x734b005e,0x79b7000a,0xdce3002a,0x349401c5}},	//   очав_, _קלוד_, ginę, варр
  { {0x799a0026,0xed59049f,0x64430144,0xf1c3000b}},	//   lltw, _muža_, _ànim, _वंदन
  { {0xf1bf0023,0x61f90010,0x439410a0,0x65a0008c}},	// [7b90] _quá_, янаў_, татс, söha
  { {0x51f80802,0x65a00012,0x6d580c73,0x85740138}},	//   ьную_, löhn, jkva, _альх
  { {0x3f8f1c4e,0x703b0015,0x3209050b,0x6d58194e}},	//   togu_, غسطس_, stay_, dkva
  { {0x23810007,0xd4980010,0x30a410a1,0x0fd5000b}},	//   mėjo_, _юры_, трув, डीगढ
  { {0x23810007,0xa2f6000a,0x63ad23c4,0xdb08002a}},	//   lėjo_, _אמרה_, mman, _ludó
  { {0x237f016f,0x11da01d8,0x3e3200a2,0xdca51a56}},	//   čuju_, _מחשב, افور, нали
  { {0xaf07010f,0x940c000a,0x23810091,0x5bb50342}},	//   _очак, ַּהֵ, nėjo_, нсиф
  { {0xce95006b,0x73fa004c,0xeb990004,0x63ad396f}},	//   _забъ, פּצו, џии_, nman
  { {0x443e0023,0x8cca005d,0x7d2800f2,0x9c7c01a3}},	//   ̣t_, _स्को, össä, _reče
  { {0x29030020,0x23810007,0xa7fc0061,0x8e380015}},	//   üja_, kėjo_, rzın, _تسفر_
  { {0xa91c002c,0xb5fb00dc,0x2af50010,0x09020033}},	//   voľt, szál, _зялё, ыпэн
  { {0x23810007,0xdc030057,0x63ad3970,0xf7460a62}},	//   dėjo_, nčít, jman, хемо
  { {0xceb20053,0x63630020,0xcf56000a,0x7bc13971}},	//   ָים_, _mõnd, גברת_, _hulu
  { {0x18690063,0x7bc109e7,0x7afd001a,0x6b9b3972}},	//   _нали_, _kulu, óstf, llug
  { {0xe9460086,0xa8790053,0x9c7c2c11,0x7eb60061}},	//   _سروی, _מאַר, _teče, _küpü
  { {0xc32300d7,0x38580015,0x7bc10049,0x6363007c}},	//   лмск, _تشهد_, _mulu, _nõnd
  { {0x00da0029,0xe1fa0afb,0x7bc10049,0x877b004c}},	// [7ba0] كبات_, яга_, _lulu, _מאקי
  { {0xb2230033,0x7bc1008c,0x6b9b0012,0x23810091}},	//   ымул, _oulu, hlug, bėjo_
  { {0xdfcf0225,0xc0590036,0x64410f7a,0xf1bf016e}},	//   ميل_, мії_, älit, _brás_
  { {0xeaa7040b,0x5de61660,0x140b000a,0x7e2a0033}},	//   _مع_, ежда, _צִיּ, зіка_
  { {0xfe720031,0x6705000b,0x62830012,0xb2bb004f}},	//   ددا_, ष्टक_, ßnot, _ממכר
  { {0x7bc101e2,0xb60600bd,0xb504000b,0xd00f002b}},	//   _bulu, mešč, श्चय_, _گلف_
  { {0x6aa200dc,0x6d5817df,0xc4d3000a,0xb60600bc}},	//   _szof, rkva, נגה_, lešč
  { {0xa3e2014e,0x6b9b0084,0x67c80089,0x6fb60029}},	//   नीय_, glug, _něja, _أمرا
  { {0xc3330008,0xa7fc0064,0xe7e20065,0x4ad10065}},	//   רוח_, azıl, कीना_, _सभरव
  { {0x63ad189d,0x65a000b8,0x61eb00dc,0x7e970015}},	//   zman, wöhn, ágli, _أنكر_
  { {0x63ad3973,0x7faa000a,0xec130040,0xc908000b}},	//   yman, ּבָ֖, _مولد, वभौम_
  { {0xb5fb0014,0x63630020,0x23810007,0x3886003d}},	//   szám, _kõne, vėjo_, _ātrā_
  { {0x75e70010,0xf7100092,0x28d1005d,0xdb0900dc}},	//   эўне, _tầng_, _द्वि, _önál
  { {0x63630005,0xb524044e,0xd5b80080,0x20180011}},	//   _mõne, льск, есс_, _opri_
  { {0x24e40010,0xb5540029,0x657500dc,0x291e3974}},	//   ыцяг, دَّث, rizh, meta_
  { {0x6b553975,0x23810007,0xb89b000a,0x889b000a}},	//   _pági, rėjo_, _מבוש, _מבוי
  { {0xb5fb00dc,0x20182df7,0x9f5a0003,0xc175002b}},	// [7bb0] zzáj, _apri_, cupé_, نگست
  { {0x64410607,0x867c000a,0x291e2dfb,0x6458003d}},	//   älis, _מרחו, neta_, _ļviv
  { {0x4ae0005d,0x6b5c3976,0xc0ab00e6,0x70e1000b}},	//   नराव, _négo, سائل_, _फ़ील
  { {0x7ff40115,0x65a00012,0xb5fb01c0,0xadd50054}},	//   اسلا, höhl, vzáj, водљ
  { {0x5e580036,0xed4e0001,0x59b2005d,0x217b0015}},	//   ниця_, ао_, ीदार, _فحسب_
  { {0x212a002f,0x4df5000b,0x7bc11177,0x291e3977}},	//   _gabh_, ुंबई_, _pulu, jeta_
  { {0xac160001,0xf1bf19b4,0xf36b000a,0xd084004a}},	//   воју_, _trás_, ּדִּ, _быти
  { {0x6b5c0003,0x70e1000b,0x7f980077,0xdb4e0015}},	//   _dégo, _फ़ुल, fíqu, قَى_
  { {0xdcbb005f,0xd7f80045,0x89350015,0x6f840342}},	//   _еще_, eră_, نعدا, _сурж
  { {0x7bc13978,0x64480012,0xd7f80045,0x6b9b3979}},	//   _tulu, ädik, fră_, slug
  { {0x8cca005d,0xf7720225,0xd7f80011,0xebe4005e}},	//   _स्टो, لاح_, gră_, _боєп
  { {0xbbd6000a,0x1a65002b,0x6d53003d,0x7ae2397a}},	//   _יועץ_, _لیبی_, šdaļ, _geot
  { {0xd7f804f9,0xcb12000a,0xa6830342,0x291e397b}},	//   ară_, _כלא_, илюд, beta_
  { {0x5e5600b2,0xb60600bd,0xdce30089,0xd7f80045}},	//   דישע_, vešč, vině, bră_
  { {0xf9900196,0x79a405e6,0x68e3003f,0x9784002b}},	//   _ابن_, _срце, _iend, _میده
  { {0x6b5c0152,0x9326002b,0x27f804b2,0x68e3397c}},	//   _négl, خرسن, árne_, _hend
  { {0xe81d005d,0x98bc0089,0x68e3397d,0x558a0054}},	// [7bc0] यौरा_, _nově_, _kend, _обим_
  { {0x68e30273,0xc5fb000a,0xd2a70033,0xdfd20021}},	//   _jend, _קפיט, ткуе_, ليط_
  { {0x68e30849,0xd12f00e6,0xb69b0045,0x03b60015}},	//   _mend, تمل_, ngân, _لإحد
  { {0x20070251,0x4f660015,0x6363007c,0xdfcf012c}},	//   ània_, خاطف, _põne, زيه_
  { {0x33200251,0xad65002b,0x212a0125,0xde03135f}},	//   meix_, گانه, _tabh_, ипци
  { {0x7ae20005,0x68e3397e,0x33200251,0x6b550125}},	//   _seot, _nend, leix_, _mágu
  { {0x6b55002e,0xad650087,0xdfd2002b,0x291e23ed}},	//   _lágu, دانه, _خيز_, veta_
  { {0x33200251,0x8c430001,0x291e0573,0xd7f80045}},	//   neix_, реће, weta_, vră_
  { {0x68e30472,0x539b000a,0xef91002b,0xdce30061}},	//   _bend, ויקו, _ایند, alnı
  { {0xd7f80440,0xdbd9001c,0xa9670054,0x68e3397f}},	//   tră_, _açõe, киња_, _cend
  { {0x013500b2,0x31570008,0x1c390010,0xdd8f0029}},	//   אָרט_, דיין_, _пяць_, _بول_
  { {0xa5f90080,0xf093039e,0x291e3980,0x07d7002b}},	//   нему_, ינת_, seta_, کذیب_
  { {0x33200251,0xcf930008,0x8b650015,0x68e302e7}},	//   deix_, שטר_, _حالم, _fend
  { {0xd8760029,0xceb3000f,0xf98f0015,0x68e33446}},	//   _لاعب, ייר_, _وبو_, _gend
  { {0x478b0001,0x80e0000b,0x64740666,0xdc030046}},	//   _осим_, _पड़ें, агру, očát
  { {0x332008e0,0x68e317d9,0x490e000b,0xf7440054}},	//   geix_, _zend, त्रो_, _већо
  { {0x6b5c0152,0xc7b4000a,0x32540248,0x68e33981}},	// [7bd0] _régl, _דבק_, автр, _yend
  { {0xeab1004f,0x7199009a,0x0000006a,0x0000006a}},	//   זֹב_, رناز_,   ,
  { {0x2fe40029,0xe8d7000a,0x33200144,0xb604003d}},	//   لكلف, דובר_, beix_, ļšev
  { {0x11d70015,0xd436004f,0x4f9400ce,0x7f1800ce}},	//   _لتسد, _עטרי_, аріу, вішу_
  { {0xe3b200b2,0x6b5c00dc,0xdb02002d,0xb69b0045}},	//   _לױט_, _végl, _choí, zgân
  { {0x672d022d,0x865c0008,0xc694004c,0xac093982}},	//   _laaj, ודדי, סאס_, енка_
  { {0x68e32ab6,0x7d1e007c,0x6b5c0030,0x68e81351}},	//   _rend, õpsa, _tégl, dadd
  { {0x8c160029,0xfaa5005e,0x8de50015,0x61ed3983}},	//   ايير_, лайо, _مكره, osal
  { {0x68e80d4f,0x68e3397f,0x63bd3984,0xdb1a0030}},	//   fadd, _pend, _misn, _attó
  { {0x70e1005d,0x3af30092,0xcff5000a,0xdc030046}},	//   _फ़ोल, ợp_, ְצָה_, ačát
  { {0x20010049,0x9c7c0844,0x5c040033,0xdbd9016e}},	//   nuhi_, _teča, _вяча, _pçõe
  { {0x61ed3985,0xca74002b,0x68e31735,0xfe670067}},	//   ksal, انیک, _wend, مد_
  { {0xfa340086,0xd4f60033,0x68e306d7,0x7ae93986}},	//   _پرند, лявы, _tend, maet
  { {0x7ae90176,0x7a7a000a,0xca36000a,0x68e33987}},	//   laet, _ארנס, _תנסה_, _uend
  { {0x332008e0,0x6b55002f,0x63bd0d25,0x20010020}},	//   teix_, _fágt, _bisn, juhi_
  { {0x7ae90176,0x6e29018c,0x11da0015,0xb5fb0030}},	//   naet, _oseb, فورة_, zzái
  { {0x332008e0,0xd3870a2c,0x61ed0035,0xd3b90036}},	// [7be0] reix_, уйте_, gsal, турі_
  { {0x29c90016,0x91a70016,0x7ae93988,0x29053989}},	//   _múa_, _đĩa_, haet, ngla_
  { {0x29c90016,0x61ed0ad4,0x200101d7,0x6e2912a1}},	//   _lúa_, asal, guhi_, _aseb
  { {0x2fd70086,0x42d5017f,0x23fb004c,0x6db9006f}},	//   اوند_, _віру, _אפטמ, _dňam
  { {0x7ae90176,0x629d0026,0x6b55001a,0x61ed0030}},	//   daet, _gyso, _lágs, csal
  { {0x6c54000d,0x16c1005d,0x65360053,0x200101d7}},	//   иклу, _एल्ब, ראַף_, buhi_
  { {0x7ae90026,0xcd270180,0x50b503e7,0x94ba000a}},	//   faet, ужје_, _всту, ׂמְת
  { {0x29c90084,0x7ae90176,0x3b54080e,0x6437004c}},	//   _búa_, gaet, ркир, ראקא_
  { {0xee3a008f,0x8f8b000a,0x8f75005e,0x0f57000a}},	//   _яна_, _טְמֵ, _турі, _עימם_
  { {0x69cf002d,0x672d0209,0x2d960054,0x2d76002a}},	//   ícea, _saaj, _србс, ołem_
  { {0x88bc0089,0xe0fb0053,0x68e8398a,0x77640123}},	//   jdět, עלטל, radd, _blix
  { {0x80370053,0x70e1005d,0xdb1a00dc,0x48a704ab}},	//   אנטע_, _फ़्ल, _futá, ытым_
  { {0x628000df,0x9b93003b,0x6664006b,0xbb3b004c}},	//   _žmon, _النت, бърз, _רעדי
  { {0x1607000b,0x6664006b,0xaa570021,0x629d0244}},	//   वंबर_, съюз, _حلها_, _ryso
  { {0x672d008c,0xd91b000a,0x25e6000b,0x63bd3184}},	//   _taaj, _נוהל, जीबी_, _pisn
  { {0x4c9b0008,0x25660152,0x2d76002a,0x395e003d}},	//   גבלו, _rôle_, dłem_, lkts_
  { {0x91750010,0xcb37000a,0xe1f00015,0x2d76002a}},	// [7bf0] агац, נאמי_, كسل_, ełem_
  { {0x629d0156,0x20010375,0x25660003,0xe40c004c}},	//   _vyso, tuhi_, _pôle_, אַנדאַ
  { {0x629d0050,0xdef10029,0xc9170008,0xf8b1000a}},	//   _wyso, قًا_, רחבת_, ַשׂ_
  { {0x287b0053,0x28970053,0x3ce50293,0x20010049}},	//   ענאמ, נדאן_, _selv_, ruhi_
  { {0x26dc0008,0x51870036,0x2d76005c,0x3d09000b}},	//   תקדמ, _бува, ałem_, _सादे_
  { {0x6e290e6d,0xdd940010,0xf1a9000b,0x6b55001a}},	//   _vseb, бачы, _कठिन, _nágr
  { {0x7ae9398b,0xe057002b,0x14d8000a,0x1fa7398c}},	//   taet, _حیات_, נוהל_, _браг
  { {0x7ae90026,0x9c7c0f81,0xb17b0123,0x236901c2}},	//   uaet, _tečn, _tvås, nhaj_
  { {0xde670063,0x7ae90026,0x6925398d,0xdb240125}},	//   _съвп, raet, ампа, ásái
  { {0xa2d5000b,0xc8b5004a,0x91820016,0xdcf80091}},	//   युत्, исны, _iện_, dovė
  { {0x98a5023e,0x77860180,0xf649000a,0xe9a80015}},	//   рине, илоз, _קצ_, ددين_
  { {0xc7b90010,0x80480008,0x27f80069,0xab841a2d}},	//   лёў_, אֲשֶ, árna_, _лучк
  { {0xb5fb00dc,0xc603004a,0xeb900015,0x2d76398e}},	//   zzáv, озяй, _عظم_, złem_
  { {0x3ea2003c,0x2d76002a,0xcdb5000a,0x7bd9004f}},	//   _økte_, yłem_, יפָה_, ֻקּו
  { {0x63630005,0xf9920008,0xb97a000a,0x78fa000a}},	//   _sõna, _ורג_, _בנסי, _ספקו
  { {0xdb020092,0x2d76002a,0xc326012e,0xe3632ae4}},	//   _khoá, głej_, јмак, окси

  { {0x6d41398f,0x96950033,0x20d60015,0xb3390033}},	// [7c00] _onla, _грэш, لتاج, ыярх_
  { {0xb17b00c0,0xf6570008,0x25730015,0x6e46002b}},	//   _svår, _כספי_, _وهيس, ینام
  { {0x04460080,0xb4e2000b,0xaec60c1d,0xa6a9002b}},	//   _тенн, दरी_, абел, _لایق_
  { {0x6d413990,0x236902fa,0x6b5c0030,0x2d760535}},	//   _anla, chaj_, _végk, rłem_
  { {0xa5bb005c,0x2d76005c,0xdce10064,0x3e340015}},	//   dwój, słem_, _aklı, إفتر
  { {0xa1930010,0x91e320b9,0x0000006a,0x0000006a}},	//   _маўч, _форе,   ,
  { {0xbce90086,0x7b6600a4,0x9ce50010,0xed5700d7}},	//   ارهٔ_, итие, сціл, рој_
  { {0x6d410c07,0xf457000a,0x5c030033,0x3a06002b}},	//   _enla, ייצר_, цяша, لکتی_
  { {0x4efb0008,0x1efb000a,0x3212008c,0x1ab3004a}},	//   _שהמו, _שלמע, ntyy_, объя
  { {0x6b5c00dc,0x645c0007,0x8c7a0080,0x2918002e}},	//   _mégi, kyri, _ищет_, ýra_
  { {0x7afd0007,0x0137000f,0x313720c1,0x6b5c3991}},	//   ųsta, ברית_, בנים_, _légi
  { {0xdcf80007,0x3f860107,0x6c7b000a,0x290a002a}},	//   tovė, nnou_, _ברבד, żba_
  { {0x7bc8000c,0x3f863992,0xaac50015,0xe91800ce}},	//   _hudu, inou_, _اتمن, _болі_
  { {0x3f860089,0x645c3993,0xe947002b,0x19570033}},	//   hnou_, fyri, _پرهی, _вашы_
  { {0xdcfa0048,0xe7d20086,0xe516005d,0x3f860089}},	//   _aktī, _بمبگ, द्धि_, knou_
  { {0x8c1b0008,0x58bb0008,0x3f860107,0x88bb000a}},	//   כולי, _במוצ, jnou_, _במוז
  { {0x3f860107,0xf1ab0015,0xe1d901f3,0x11d90015}},	// [7c10] dnou_, نائه_, удзі_, اوئة_
  { {0xc1050029,0x9c7c0089,0xdb09002d,0xdfdb006b}},	//   صوصي, _pečl, imeá, въд_
  { {0x2fc70023,0x2d76002a,0x765d0696,0x3d00000b}},	//   êng_, ałek_, lysy, _राजे_
  { {0xfe73002b,0x27f10030,0x3f86016e,0x9c7c00bc}},	//   يدش_, ázni_, gnou_, _večl
  { {0x92940010,0x27780053,0x98a70024,0xd33600a3}},	//   _маюц, סעדש_, _manā_, _פרשה_
  { {0x645a00b8,0x200e0251,0xb5fb00dc,0x7bc83994}},	//   ätig, àfic_, lzás, _budu
  { {0xf1b20008,0xdd8e0015,0x24f8000a,0x3f860107}},	//   _מסך_, عوى_, שֶׂם_, bnou_
  { {0x765d00f2,0xdce70064,0xed5901b2,0x7f850021}},	//   kysy, ılın, _muži_, _الرن
  { {0x7c3a04de,0xdb23001a,0x997d0033,0x699500c2}},	//   _ertr, _þrív, етнi, йрох
  { {0x97d90839,0x670a000b,0x5e440015,0x9dab006b}},	//   льму_, _वाहक_, _بَكْ, _ръба_
  { {0x31580053,0x657c00f2,0x8bd9006b,0xb5fb0030}},	//   ייזן_, virh, _смес_, zzát
  { {0x321200f2,0xdb020092,0x501a000a,0x6363007c}},	//   ytyy_, _thoá, נורו, _sõnn
  { {0x98a501e2,0xceb2000a,0x2d873995,0x765d0034}},	//   rklı_, ֤ים_, onne_, gysy
  { {0xceb2013a,0xdce30024,0x69db26f1,0x6b5c3996}},	//   פים_, minē, mpue, _régi
  { {0x64a60010,0x2d873997,0x657c001a,0x87d50015}},	//   сава, inne_, rirh, _اغتا
  { {0x321200f2,0xed590085,0x765d0034,0xa6e6006b}},	//   ttyy_, _duži_, bysy, _ужил
  { {0x52aa05b3,0x3f860107,0x443a01d7,0xd2aa0033}},	// [7c20] увам_, vnou_, _wrp_, укае_
  { {0x636a002e,0x321200f2,0x6b5c00dc,0xd6d7002b}},	//   _sýnd, rtyy_, _végi, _پویش_
  { {0xe0d50036,0x321200f2,0x65570008,0x397a0053}},	//   юють, styy_, _הביא_, נטענ
  { {0x6606008c,0x4613002b,0x2d873998,0x67260c4e}},	//   oukk, _بویر, enne_, nekj
  { {0xf2d300b2,0xb1480074,0x539b0008,0x82360087}},	//   _מער_, _پیام_, _תיכו, _ارجا
  { {0x63b6002e,0xf98700a2,0x3f863999,0xbf16002b}},	//   lmyn, _رب_, snou_, _گورب
  { {0x3d09005d,0xc4d3000a,0x38c8002b,0x4fd8000a}},	//   _सारे_, הגו_, یادی_, _כַּד
  { {0xbf160086,0x2d870020,0xdce30024,0xb5fb00dc}},	//   _دورب, anne_, finē, izár
  { {0x6e3b399a,0x9f630030,0xc333000a,0x7bc801c2}},	//   _grub, _ívás_, לוה_, _wudu
  { {0xb5fb00dc,0xb0d60033,0x63b60034,0x7bc8399b}},	//   zzás, абiц, hmyn, _tudu
  { {0x319b00b2,0xcb0a0074,0x63b6002e,0xadb70015}},	//   רבינ, _ميان_, kmyn, _اهلا_
  { {0xd6db004a,0x103b004c,0x31af0061,0x7bcb000a}},	//   ыто_, אגטע, müze_, _עֶבֶ
  { {0x7a360015,0x65a00012,0xdb000030,0xb5fb0030}},	//   _دعائ, höhu, jlmé, ezár
  { {0xa4d4005e,0xb69b0045,0x63a4399c,0x49170065}},	//   зорі, ngâi, elin, ब्दो_
  { {0x8bf80008,0x4917000a,0x7bf8000a,0x31af0061}},	//   יִּפ, _הקול_, יִּה, nüze_
  { {0x63b6002e,0x62d90010,0xe3b00115,0xc2c40015}},	//   gmyn, рмаў_, فرق_, كيفي
  { {0xe800005d,0x41550010,0x31d50015,0x9c7c0085}},	// [7c30] लंका_, овас, زقاز, _bečk
  { {0x9c7c018c,0xf1c20024,0x23810091,0xb5fb0030}},	//   _večj, jošā_, vėju_, szás
  { {0x63a4399d,0x9c7c02d8,0x628a0012,0x0000006a}},	//   blin, _dečk, ßfor,
  { {0xceeb0074,0x645a022d,0x66fb005d,0x63a4052a}},	//   اران_, ätie, ्लिक_, clin
  { {0x67c80089,0x6440003d,0xf2040033,0x799a0535}},	//   _ději, āmie, _няро, kotw
  { {0xdd940010,0xabd500d7,0xdb09016e,0x0d8401c6}},	//   пачы, оциј, omeç, плін
  { {0x155c000a,0x1b49399e,0xf3f2000a,0x6b5c399f}},	//   רכוב, изки_, ֵ֣ה_, _légu
  { {0x88bc0089,0x442139a0,0x2d9e39a1,0x6f65002b}},	//   vděp, _mph_, _ekte_, _بهرم
  { {0x7afd0007,0xb5fb00dc,0xc3340008,0x4a45042b}},	//   ųsto, zzár, פוץ_, інов
  { {0x8f00005e,0x6606030a,0x69db0077,0x63a40b26}},	//   дiї_, vukk, rpue, zlin
  { {0xfd100029,0x69db02c1,0x63a4038b,0x67260e05}},	//   _سجل_, spue, ylin, tekj
  { {0xae0d005d,0x65a000b8,0x69db00f2,0x63a40123}},	//   _समान_, höht, ppue, xlin
  { {0xf3f10023,0x3f9f000c,0x8f9a103d,0x9ae8000a}},	//   ận_, _mkuu_, שירי, _הַצִ
  { {0xa50a0001,0x6b8939a2,0xd5750010,0x63a439a3}},	//   јева_, lneg, пусь, wlin
  { {0xd3480086,0x63a40abe,0xf1bf006f,0xf7720067}},	//   میده_, tlin, _fráz_, _ياب_
  { {0x03670080,0x69cb00b8,0xf8b2000f,0x69c3020d}},	//   оиск_, _kuge, _קשה_, _hine
  { {0x7aeb0014,0x63b60843,0x00da0029,0xb5fb00dc}},	// [7c40] _megt, rmyn, لبات_, szár
  { {0x85060074,0x6b9b003e,0x7aeb2f97,0x63a439a4}},	//   _بودن, houg, _legt, slin
  { {0x69cb0005,0x656e002f,0x9c7c00bd,0x9ffa0029}},	//   _luge, mhbh, _večk, شراء_
  { {0x80da014e,0xee3a0770,0x6b8905ce,0x69c3153a}},	//   _प्रे, ине_, jneg, _line
  { {0x6b89043f,0xe297022a,0xf773039e,0x9c7c0046}},	//   dneg, _маю_, וקא_, _tečk
  { {0xf3f10092,0x463b0053,0x69c308b8,0xc0aa002b}},	//   ợt_, יענע, _nine, _نازل_
  { {0x69cb00b8,0x7bc200da,0x5c060033,0xddce002a}},	//   _auge, _piou, іяка, ódła
  { {0x69cb04f9,0xba54023e,0x0b8a009c,0x799a002a}},	//   _buge, звиј, јски_, wotw
  { {0x1d0a0001,0xf77f0064,0x69c339a5,0x69cb0045}},	//   _вези_, viç_, _bine, _cuge
  { {0xad660086,0x6b5c0152,0xdc3e01cb,0x527b004c}},	//   _باره, _régu, líče, ינפא
  { {0x2d9c39a6,0x69d90079,0x6b9b39a7,0x68ea001a}},	//   move_, _etwe, boug, _vefd
  { {0x69c339a8,0x2d9c0263,0x6b8917eb,0xdc3e0046}},	//   _eine, love_, cneg, níče
  { {0x3a3d0176,0xf77f0064,0x2918007c,0x69c31103}},	//   _grwp_, riç_, õras_, _fine
  { {0x80da005d,0x04c90015,0x80aa000b,0x69c339a9}},	//   _प्ले, صوري_, _करूं, _gine
  { {0x69cb018b,0xa7fc0064,0xe967009c,0x8bd8000a}},	//   _zuge, azır, _фајл_, מַּח
  { {0x56950ac7,0x2d9c01a3,0xd6d10015,0x2769002b}},	//   _найт, hove_, _ثقة_, _دشتی_
  { {0x2d9c1007,0xc1eb0080,0x60f904ab,0xc398005e}},	// [7c50] kove_, рьбе_, йная_, ікує_
  { {0x98be0007,0x290c05d8,0x6b8905ce,0xb5c8002b}},	//   nktį_, ngda_, zneg, _گویم_
  { {0x2d9c049f,0x6b890034,0x442101d7,0xdb21005a}},	//   dove_, yneg, _uph_, _štír
  { {0x6b5c00dc,0xdefb0010,0x1eea002b,0x9f550033}},	//   _mégs, рыж_, مومی_, явеч
  { {0x7bda02d7,0x6b89018c,0x7aeb00dd,0x224d0064}},	//   _attu, vneg, _regt, _çek_
  { {0xa3e2005d,0x6b89005c,0x1fdb0029,0x69cb0f47}},	//   नीक_, wneg, _نظرة_, _ruge
  { {0x6b8939aa,0xe5720008,0x6c840015,0x6b9b0ff2}},	//   tneg, עַד_, ولهم, toug
  { {0xf1af005d,0x69c339ab,0x69cb39ac,0x26c900a1}},	//   _जीतन, _sine, _puge, _ngao_
  { {0xdb2100dc,0x256f00dc,0x6b9b39ad,0x3ead0085}},	//   _átír, _küld_, roug, _uzet_
  { {0x290c00c0,0xf9910015,0x4805004a,0x6b8939ae}},	//   ggda_, عبة_, ппов, sneg
  { {0xc7a60431,0x69c3248e,0xe73a0162,0xa2a2000b}},	//   зинк, _vine, бен_, _कुन्
  { {0xfb380029,0x69cb10cc,0x69c339af,0x3f9d002a}},	//   _وأنت_, _tuge, _wine, nowu_
  { {0x9c7c39b0,0x69c339b1,0x6b5c0030,0x656e0125}},	//   _reči, _tine, _végt, thbh
  { {0x89da000a,0x2eed0547,0xd5af0015,0xba740058}},	//   _החסי, _leef_, ُفَ_, _غانت
  { {0x80aa005d,0x443e1d98,0xa8480015,0x04430f5c}},	//   _करें, ít_, _ولهم_, нерн
  { {0x57fa013a,0xd7fa0008,0x1dcb005d,0x1876000a}},	//   _הלקו, _ההקל, ादात, _מעצר_
  { {0x9c7c018c,0x02060802,0x98a7002a,0x35fa0015}},	// [7c60] _veči, язан, _daną_, _اربد_
  { {0xdce300df,0x3cf7005d,0xe1f70484,0x867b000a}},	//   minė, ीलों_, ягу_, _לרפו
  { {0xf9920008,0xdce30007,0x155b000a,0x2eed00da}},	//   ערב_, linė, _הכיב, _beef_
  { {0x0dca39b2,0x62010061,0xa2630016,0xed58006f}},	//   буки_, üzlü, _khổ, _soľ_
  { {0xdce30007,0x433b0008,0x733b0053,0x2d9c39b3}},	//   ninė, _העכב, _העכס, tove_
  { {0x2d9c02b9,0x6b5c0003,0x237f0069,0x361b004f}},	//   uove_, _négr, ďuje_, מונד
  { {0xcb980029,0x1d190033,0xdee61021,0x2d9c39b4}},	//   ينتش_, ююць_, _нови, rove_
  { {0x2eed0298,0x1c02005d,0x67c80089,0xdce30007}},	//   _geef_, रूगल_, _mějt, kinė
  { {0x0e66008f,0x2d9c0b28,0x61f639b5,0xa2a20065}},	//   _экан, pove_, nsyl, _कुम्
  { {0x49731292,0xa9780036,0xdce30007,0x4ddb000a}},	//   ельс, ійну_, dinė, _לחמו
  { {0xa3ac000b,0x6b5c0003,0x53be000b,0x6ac60015}},	//   गता_, _dégr, ्दाश, _فقام
  { {0x290201e2,0xf3f10092,0x6b5c00dc,0x8cd8005d}},	//   şka_, ậm_, _végs, नुरो
  { {0xdce30007,0xda340080,0x8f9b0135,0xe800000b}},	//   ginė, _целы, מיטי, लूजा_
  { {0xe5c40080,0x6d5a00f2,0xca330001,0x85050029}},	//   ессо, _jota, _чешћ, بوسن
  { {0x8937000a,0xd91b000a,0xb33b0061,0x9da4000b}},	//   _מרגע_, _הוול, _akça, _चीज़ो
  { {0x637101d1,0xdce30007,0x657e1bed,0x26c90085}},	//   _mång, binė, _emph, _ugao_
  { {0x6d5a0020,0x637100c0,0xdce30007,0x2eed00da}},	// [7c70] _oota, _lång, cinė, _reef_
  { {0x63630020,0x6d5a39b6,0x02440015,0xc5f2000a}},	//   _mõni, _nota, عَلَ, _שדי_
  { {0x7feb006e,0x0f350033,0x63710123,0x9c7c39b7}},	//   صراف_, дэля, _nång, _keču
  { {0x6d4839b8,0xfe71009a,0x5f94009b,0x0000006a}},	//   _anda, پگر_, нихт,
  { {0x433a000a,0x6d5a39b9,0x333a004f,0x0000006a}},	//   _וערב, _bota, _ותרמ,
  { {0x4d640036,0xdca50e91,0xc537000a,0xdcf8003d}},	//   нків, мали, לָ֔ה_, tivā
  { {0x6d5a39ba,0x2bb90015,0xdce30091,0xaf090015}},	//   _dota, يابة_, zinė, _وقسم_
  { {0xa2b4005d,0x8d770086,0x79810026,0x6d4839bb}},	//   _आरम्, _کارا, wilw, _enda
  { {0x6d5a0827,0x7f491ef1,0x0000006a,0x0000006a}},	//   _fota, _ineq,   ,
  { {0x115a00b2,0x637139bc,0xceb20008,0xdce30007}},	//   ַדרע, _fång, _יין_, vinė
  { {0x6b5c0014,0x7c670029,0x637100c0,0xe7f6000b}},	//   _végr, _عائل, _gång, ूंगा_
  { {0xdce300df,0xfe6703c4,0x61f60026,0xf1c0002c}},	//   tinė, ند_, ysyl, čšiu_
  { {0x27e0016f,0xbef6000a,0x63710123,0x6d48001a}},	//   _čine_, וצרו_, _månd, _ynda
  { {0xdce30007,0xaa560054,0x1869176f,0x0000006a}},	//   rinė, _циљу_, _мали_,
  { {0xdce30870,0x64a339bd,0x98350033,0x65c3006b}},	//   sinė, вара, _цэлі, тбра
  { {0xdce30007,0x7afd001a,0xe6060015,0xc7960015}},	//   pinė, ósth, _قِبَ, _تشتب
  { {0x3aba00b2,0x256f0020,0x96fb000a,0xa3e2000b}},	// [7c80] ַמענ, _süle_, _ולפת, नीज_
  { {0xf3f10092,0x7e62003f,0x61f606bd,0xd6a90015}},	//   ợp_, vyop, rsyl, _عديم_
  { {0x443c00dc,0x6d5a39be,0x7f5b0493,0x299a004c}},	//   _év_, _rota, _bouq, קסעמ
  { {0x6d5a2c3e,0x1e860080,0xa2d6002b,0x27f81ad6}},	//   _sota, млем, _زيست, árni_
  { {0x87ad0053,0x637100c0,0xf1af005d,0x6d5a048f}},	//   זשאַ, _sång, _जीवन, _pota
  { {0x9c460036,0x6606008c,0x0000006a,0x0000006a}},	//   дхил, irkk,   ,
  { {0xa2d5014e,0xa2a2000b,0x7f5b39bf,0x3f6a1591}},	//   युक्, _कुत्, _fouq, _диво_
  { {0xd00f0115,0xf413000a,0x2bb70015,0x8c430054}},	//   _خلف_, דפה_, واية_, ђење
  { {0xedd30015,0x6d5a09e0,0x0000006a,0x0000006a}},	//   _ليقد, _tota,   ,
  { {0x588604f7,0x6d48235a,0xb16b000a,0x7c2a056d}},	//   дыма, _unda, ַ֣יִ, _мозг_
  { {0x660600f2,0x636a001a,0x17f70015,0xcc8a0015}},	//   erkk, _nýno, ورَة_, _بناه_
  { {0x95cb0083,0x09e60036,0xd7cf005d,0x63630020}},	//   жува_, _жодн, _संरच, _tõni
  { {0x9f650152,0xa5bb002a,0x9208003d,0x4433039f}},	//   étés_, dwór, ngāļ, _ssx_
  { {0x63710293,0x47d40015,0xe8941f61,0x2245005a}},	//   _måne, _كيتر, _паль, _člk_
  { {0x660600f2,0x399b000a,0xd5b80033,0x44251e83}},	//   arkk, _ויגד, ьсю_, ïl_
  { {0x57fb0008,0xd7fb004f,0xe00d0065,0x44250073}},	//   _ולהו, _וההל, ांसद_, įl_
  { {0xe1f000e6,0xa4d5005e,0xd7f80045,0x44250046}},	// [7c90] لسل_, _попі, lsă_, ůl_
  { {0xf652000a,0xb06b0015,0x44a70015,0x0000006a}},	//   _עצי_, يصال_, _يحدّ,
  { {0xd7f80011,0x7afd0091,0xb4eb000b,0xcf9b012e}},	//   nsă_, ųsti, मरी_, ојд_
  { {0x20df014e,0xb0df005d,0xd347002b,0x50df000b}},	//   _प्रध, _प्रग, _تیره_, _प्रष
  { {0xc2c50021,0x236900bc,0x518700ce,0x0000006a}},	//   _سيسي, mkaj_, _жува,
  { {0xee3802e5,0x7c650015,0x6ce700ce,0xdcf9009a}},	//   ьні_, فاعل, фіде, سرتش_
  { {0xdca20001,0x7cd60067,0x7c840054,0xac380033}},	//   лаши, رويز_, куће, дчых_
  { {0x7f4900da,0xdcf80045,0x6606008c,0x0000006a}},	//   _uneq, tivă, yrkk,
  { {0x99150010,0x1a65002b,0x9c7c0046,0x4b22004a}},	//   ньні, عیتی_, _sečt, умыв
  { {0xa3b6014e,0x7d790021,0xa1c900ce,0x0000006a}},	//   _चीन_, _عمار_, оцiа,
  { {0x2919002a,0xe73a0a0b,0xf8a90a31,0x6f0f0030}},	//   ęsa_, пен_, явок_, _öccs
  { {0xf09204dc,0xd6d20015,0x9bc80015,0x66002745}},	//   רנט_, طقس_, _قولك_, ámko
  { {0x8cc7005d,0xd7f80011,0x6a670029,0x6608005c}},	//   ाशको, asă_, _تطال, ądko
  { {0x236900bd,0xd5b20029,0x63630020,0x2566006f}},	//   ekaj_, افس_, _mõnu, _kôli_
  { {0xa5bb005c,0xf89b002b,0x7afd002a,0xa3ea009b}},	//   twór, _بخشش_, óstw, ядва_
  { {0xdce30024,0x636a0264,0x3d09000b,0x02c6110d}},	//   finī, _výno, _साझे_, ейбо
  { {0x3f8e001a,0xe29704e0,0x96950033,0x98a70535}},	// [7ca0] éfum_, еат_, _арэш, _ranę_
  { {0x6fd4005d,0x236900bc,0x409600ce,0x0000006a}},	//   _बंदू, akaj_, нрет,
  { {0xdce30024,0xc0a900c3,0xe3b20015,0xc4830088}},	//   ainī, وامل_, _مرح_, _блэк
  { {0x444439c0,0xf4570008,0x43860015,0x91e63122}},	//   _ir_, _ניכר_, _ألحق, _поме
  { {0x2492003d,0xa3bd000b,0xb17b0613,0x71660015}},	//   šamā_, इगर_, _ståe, _كاسك
  { {0xb8820089,0x3f8f003f,0xc5f3000a,0xa2c0000b}},	//   _říms, angu_, נדו_, लेण्
  { {0x61e2002d,0x67240e2a,0x444416be,0x61e439c1}},	//   íolf, _obij, _jr_, lpil
  { {0x44440495,0x501b000a,0x20070247,0x1fb50054}},	//   _mr_, _מולו, ánie_, _асур
  { {0x6d4b002d,0xaae6002b,0x6d53001a,0xb5fb0030}},	//   álaí, وسکو, ýjað, gyál
  { {0x44440bf5,0xc27b00f3,0x3dfb000a,0x8dfb000a}},	//   _or_, פריי, _מלמד, _מהמת
  { {0xe894008f,0xa7fc0064,0x645a00f2,0xc173000a}},	//   тань, ayın, ätil, רחת_
  { {0xd7f80011,0x93c70092,0x7c850054,0xf093000a}},	//   rsă_, _chặ, _руђе, טנת_
  { {0xcf93000a,0x09e30054,0x444439c2,0x6b820096}},	//   רטר_, _бочн, _ar_, _imog
  { {0xd7f80011,0xceb30135,0x34950010,0xb4eb000b}},	//   psă_, טיר_, вагр, मरे_
  { {0x77930086,0x7bdc0003,0xd4040c71,0x23690085}},	//   _میدا, _érud, ляти, tkaj_
  { {0xe3b300e5,0x57f3006b,0x64430077,0x2369035f}},	//   ارس_, _спът, _ánim, ukaj_
  { {0x69ca0014,0xd6e80008,0x61e40035,0xf7740135}},	// [7cb0] _kife, _אַתָ, gpil, _תקפ_
  { {0x444439c3,0x72040015,0x7c2839c4,0x236939c5}},	//   _fr_, اولم, _opdr, skaj_
  { {0x63630020,0x6b82065d,0xc1040015,0x69ca0573}},	//   _sõnu, _omog, طوني, _mife
  { {0x661d39c6,0x30a40784,0x69ca1350,0xb4bf000b}},	//   otsk, урув, _life, ेशी_
  { {0xf364008f,0x63ad049b,0x7c280024,0x8d74002b}},	//   _стэн, mlan, _apdr, گانا
  { {0x44440b7c,0x69ca0176,0xdb000152,0x63ad17e3}},	//   _yr_, _nife, lomè, llan
  { {0x98a70089,0x63ad39c7,0x6c320015,0x8d74002b}},	//   _daně_, olan, لفوا, دانا
  { {0x3f8633e3,0x661d02df,0x0b4507c1,0xa5bb0030}},	//   ciou_, ktsk, тнин, ltód
  { {0x826c000a,0xdb1a39c8,0xbdd5005e,0x27e006c0}},	//   ּ֣חַ, _autó, _розщ, _čina_
  { {0x7c2c0077,0x63ad39c9,0xdb1a002a,0xdc31002a}},	//   ñorí, hlan, _butó, eżąc
  { {0x2d871c23,0x61e40048,0x66e613ae,0x63ad39ca}},	//   mine_, zpil, кона, klan
  { {0x61e400f2,0xc052000a,0x69ca0ccc,0x27ee0034}},	//   ypil, ׁ֖ר_, _eife, _dwfn_
  { {0x2d87002f,0x7afd002e,0x6441002e,0x4b7a00a3}},	//   oine_, óstu, ælin, _קאנו
  { {0x444439cb,0x2ca90046,0xd9590033,0x6b8239cc}},	//   _pr_, řadu_, _ішлі_, _zmog
  { {0x7bcb003f,0x577a0029,0x61fd1edc,0x661d3828}},	//   _kigu, _يصبح_, _avsl, atsk
  { {0x6724044c,0x2240002e,0xa5bb006f,0x63ad39cd}},	//   _ubij, tvik_, etód, glan
  { {0x3f86001c,0x644500b8,0x23d2000b,0x61e439ce}},	// [7cc0] viou_, _erhi, _दूरद, upil
  { {0x7ae90064,0x444439cf,0x3c3c0046,0x2d870c1a}},	//   hbet, _tr_, nává_, jine_
  { {0xa2a2005d,0x2d8739d0,0xe3ba004a,0xd00f0015}},	//   _कुर्, dine_, _обо_, قلل_
  { {0x63ad0011,0x61e40ae5,0x2d8739d1,0x7497000a}},	//   clan, ppil, eine_, _ידיד_
  { {0x7ae900fb,0x63a439d2,0x268d000a,0x6d060015}},	//   dbet, moin, ּנוּ, نبثق
  { {0x7bcb0ad3,0x2d8730c5,0x4c94004a,0x63a4008c}},	//   _aigu, gine_, лилс, loin
  { {0x69ca02d7,0x2fda0086,0x3c3c0089,0xc4d3000a}},	//   _rife, _آورد_, dává_, סגה_
  { {0xdb1a0251,0x63a40df4,0x5b26005e,0xa037000a}},	//   _autò, noin, тька, _באלה_
  { {0x7bcb0375,0x2d8739d3,0x5e250015,0xa7fc0061}},	//   _digu, bine_, _معلق, ayıl
  { {0x637102ce,0x672f002a,0x9d460054,0x661d00bc}},	//   _måna, wecj, _шезд, vtsk
  { {0x63a400f2,0x99a400dc,0x63ad39d4,0x3d17000b}},	//   koin, étől_, ylan, _नाते_
  { {0x673d003c,0x63a40493,0x63ad10ad,0x661d39d5}},	//   udsj, join, xlan, ttsk
  { {0x96340010,0x661d39d6,0x672f002a,0x63ad39d7}},	//   аняц, utsk, recj, vlan
  { {0x58d3032e,0x660f39d8,0xb7d80015,0xceb3000a}},	//   _кошт, ruck, _كوتا_, שיש_
  { {0x672f005c,0x7bc039d9,0xdcf8003d,0xa2c0000b}},	//   pecj, ommu, lnvē, लेस्
  { {0x63a439da,0x320900da,0x2d8739db,0x63ad39dc}},	//   goin, tray_, zine_, ulan
  { {0xa7fc0064,0x2d870064,0xc1b93891,0xc2c40015}},	// [7cd0] zyıl, yine_, елах_, ليفي
  { {0x3f840020,0xdcee0089,0xdb002d34,0x32091c43}},	//   _ammu_, ěděl, llmä, rray_
  { {0x7ae90700,0x63ad39dd,0x31341c3f,0xe2f900fd}},	//   ybet, plan, рехр, _пені_
  { {0x8f140036,0x0eb90033,0x62080061,0xce190033}},	//   ифіч, нулы_, ürlü, ецкі_
  { {0xfe7003c4,0xaf040036,0x12870086,0x7bcb39de}},	//   يده_, рпіл, _شمسی_, _rigu
  { {0x2cac0176,0x7ae90026,0x7bc00061,0xb5fb0030}},	//   _bydd_, wbet, emmu, tyáj
  { {0x3c3c0089,0x2d8739df,0x41af000b,0x7ae939e0}},	//   vává_, rine_, _जीएस, tbet
  { {0x2cac0176,0x2d87266c,0x9c7c00bc,0xfc300369}},	//   _dydd_, sine_, _večp, تحه_
  { {0x2d871eae,0x7ae939e1,0x7bcb39e2,0x3c3c206e}},	//   pine_, rbet, _vigu, tává_
  { {0x2cac0176,0x7ae60064,0xa7fc0064,0x6c1b0015}},	//   _fydd_, ıkta, ayım, _يتضح_
  { {0x63a4003f,0xfb150031,0xa3b3000b,0xf7720015}},	//   yoin, _مواج, टता_, ماح_
  { {0xfbd2000a,0x1dcb000b,0x5bc7002b,0x3c3c0307}},	//   _התא_, ादकत, _شتاف, sává_
  { {0x79880035,0x63a43537,0x959a0054,0x8afa000a}},	//   bidw, voin, етву_, _נפסק
  { {0xd3480086,0x395800c0,0x2b9a003d,0x6b8939e3}},	//   چیده_, örst_, rīce_, lieg
  { {0xf99a00b2,0x141a0015,0xd348002b,0xe1ff016e}},	//   _אױסל, عيرة_, نیده_, _avó_
  { {0x6b893415,0xf772002b,0x69c139e4,0xd7ca0058}},	//   nieg, _دات_, lmle, _ثوبه_
  { {0x256f0005,0x637803af,0xc7a90225,0x6d5e0020}},	// [7ce0] _küll_, _líng, _جدول_, öpak
  { {0x63a439e5,0xdce30046,0xd2a70033,0x6619002a}},	//   soin, rhně, укуе_, żakó
  { {0x6b890050,0xf3f10023,0x4f0a03fc,0x63a41864}},	//   kieg, ật_, енен_, poin
  { {0xdfcf00b0,0x5f760029,0x2f1d0030,0x200730aa}},	//   سيه_, دائر, vágó_, ánia_
  { {0x2cac0176,0xef210048,0x6b8914f2,0x9daa006b}},	//   _sydd_, daļā_, dieg, нъка_
  { {0x6da31c35,0xa7fc0061,0xa0a61d34,0x0637000a}},	//   бича, azıy, _багд, טננט_
  { {0x251b0008,0x27e000bc,0x443a39e6,0x0000006a}},	//   תוצא, _čino_, _jsp_,
  { {0x4093003b,0x6b89005c,0xe4570053,0x4bd7002b}},	//   _الفر, gieg, טיצט_, دبود_
  { {0xb9980001,0x497439e7,0x298a030e,0x2cac0416}},	//   квих_, илис, есно_, _wydd_
  { {0x99d30015,0x3237000a,0xaac0000b,0xc171000a}},	//   حتيا, נטין_, शेषक, ַ֗י_
  { {0xa3c4014e,0x6b89005c,0x717b000a,0x98c6004a}},	//   एगा_, bieg, גניס, ысил
  { {0xa3d8005d,0x68e40064,0x7c3a39e8,0x6b5c0030}},	//   ादन_, _şidd, _istr, _légz
  { {0x7afd001a,0xd90f002b,0x5b2300c3,0x443a156f}},	//   ðste, _کیپ_, _طفول, _asp_
  { {0xda7b0008,0x443a11e6,0x1c180065,0x45d4144a}},	//   _אנדר, _bsp_, _धमाल_, сорс
  { {0xd8db000a,0x68fa0990,0xc953000a,0xad620016}},	//   _אקור, matd, _למס_, _đựn
  { {0x1dd4005d,0xf1a40036,0x75d50086,0xd90e002b}},	//   ददात, ґрун, _پيدا, _بیگ_
  { {0x8237002b,0x0f35002b,0x50f505aa,0x3255007e}},	// [7cf0] درزا, یکرد, изат, швар
  { {0x2fcd00b8,0x256f007c,0x3d0e000b,0xa5bb39e9}},	//   _sieg_, _külm_, सलों_, stób
  { {0xc0350180,0x491c000b,0x2fe40015,0x1048006b}},	//   рнеј, _मानो_, مكلف, ляци_
  { {0xe4480015,0xdce30091,0x7ed4002b,0x0000006a}},	//   _إلَى_, tinį, مزها,
  { {0x12fa000a,0x6b890024,0x69c10034,0x7bde001a}},	//   _בהרב, vieg, ymle, ípun
  { {0xe0d40001,0x3da9006b,0xe5f8000a,0x6b8939ea}},	//   _горњ, ъкло_, נזור_, wieg
  { {0x636a0084,0x6db9006f,0x6b8939eb,0xe809000b}},	//   _sýni, _kňaz, tieg, _विधा_
  { {0x98aa0089,0x290a00dc,0x8a050195,0x7c3a13c0}},	//   žbě_, óban_, азие, _dstr
  { {0xc95501d9,0x4af6002b,0xdea1002b,0x3f9c0003}},	//   атны, شکند_, _بیشی, évue_
  { {0x636a002c,0x7db70015,0x6b8939ec,0x80aa29ac}},	//   _výni, _إصرا, sieg, _जुडे
  { {0xb8dd005d,0x7c840286,0x91790016,0x7e6b0123}},	//   _आर_, _луце, _cẩn_, lygp
  { {0xc7a60036,0x366a0001,0x290b13cc,0x46f60033}},	//   римк, вамо_, şca_, шчот
  { {0x7afb022d,0xdb26002b,0xd7070033,0x9f5c0030}},	//   maut, _خونی, шняе_, évé_
  { {0x7afb39ed,0x6378002d,0xda78006b,0xb17b0123}},	//   laut, _míne, _щях_, _stån
  { {0x63780467,0x69db39ee,0x54970010,0x53c60015}},	//   _líne, lque, авёў_, لزرق
  { {0x7afb39ef,0xb89a000a,0x289a000a,0x74130015}},	//   naut, _שבקש, _שיקא, توفا
  { {0x42530015,0x2b9a003d,0x443a002a,0x69db39f0}},	// [7d00] ينفر, nīca_, _wsp_, nque
  { {0xc5fb01ac,0xd5fb00f3,0x8110000b,0x0577002b}},	//   _שפיט, _שפיר, ालेख_, _ناپد
  { {0x7afb1f90,0xc0590036,0x6b5c00dc,0x3fc6002b}},	//   kaut, лії_, _végz, لگری_
  { {0xf8b20008,0x888c0053,0x1ea9002b,0x93fb000a}},	//   חשב_, עראַ, گامي_, _בלטי
  { {0x44380176,0xee7a0087,0x7afb00c5,0xdb090030}},	//   lwr_, خصات_, daut, gleí
  { {0x100a0029,0xcd27005e,0x7c3a037c,0x1ea90058}},	//   _لترى_, ижче_, _pstr, دامي_
  { {0x7afb000c,0x998d005c,0x44380026,0x319b0008}},	//   faut, steś_, nwr_, _סבלנ
  { {0xe4570053,0x7afb2a1c,0x44380034,0x403b000a}},	//   שיקט_, gaut, iwr_, _בגלג
  { {0x7c3a005c,0x44380026,0x3f670659,0x6378001a}},	//   _wstr, hwr_, _тито_, _gíne
  { {0xd90e0074,0xf9920029,0x7cf8000a,0xd90d002b}},	//   ذیب_, تبع_, _תִּק, فیه_
  { {0x7c3a1981,0x7afb39f1,0x69db1e7b,0x96f92d3b}},	//   _ustr, baut, aque, лент_
  { {0x44380176,0xaa870086,0x61e6016f,0x8c1b000a}},	//   dwr_, انیم_, _otkl, _יובי
  { {0xdb0039f2,0x69db39f3,0x6b7b0643,0x9aeb000a}},	//   nomí, cque, _בראנ, _יַגִ
  { {0x1a7b0008,0x44380026,0x61e90061,0x8a7b000a}},	//   _שְׁמ, fwr_, _çeli, _שָׁק
  { {0x61e60024,0x44380026,0x9999002c,0x49bb000a}},	//   _atkl, gwr_, ísť_, _שמוס
  { {0x53980036,0x88770008,0xdce3005c,0x68f8003c}},	//   ався_, _כתוב_, mkną, _hevd
  { {0x44380026,0x3d17000b,0xd7bc000a,0x90e70015}},	// [7d10] awr_, _नाले_, _בצהר, لسان
  { {0x7afb00dc,0x9f5804ed,0x2fd800b8,0x256f0064}},	//   zaut, _avrà_, _burg_, _mülk_
  { {0x3ed50015,0x7afb0003,0x63780125,0x533505aa}},	//   مقار, yaut, _síne, _лент
  { {0x7535160a,0x201c0144,0xa857000a,0xa29502a3}},	//   lezz, àvia_, ייבה_, _гамі
  { {0x69db0999,0x7afb1a91,0xd356000a,0x035605bd}},	//   xque, vaut, _הירי_, _הירש_
  { {0x753502b9,0x0638004c,0x290a39e9,0x0d8401c6}},	//   nezz, ינדט_, óbal_, олін
  { {0x92a9002a,0x6e2239f4,0x709421b0,0x7afb11b5}},	//   bołó, atob, _дарф, taut
  { {0xf1db005d,0x753504ed,0xd498000f,0x7498000a}},	//   _बढान, hezz, יכות_, ידוד_
  { {0x75350014,0x8e850029,0x1e950053,0xcd2b0021}},	//   kezz, _الذه, _הכּל_, _لسان_
  { {0x7afb022d,0x77640152,0x753500dc,0xb9550001}},	//   saut, _soix, jezz, стић
  { {0x7ae20026,0x6d410213,0x7afb0df1,0x69db39f5}},	//   _ffot, _iala, paut, sque
  { {0xf0920008,0x2001003f,0x9056000a,0x6d4139f6}},	//   לני_, ishi_, צברו_, _hala
  { {0x254b0007,0xbb3a00f3,0x8f9a000a,0x6d410337}},	//   kėlė_, _תעני, רירי, _kala
  { {0xf1db005d,0x6d410375,0xdcb10016,0x75350030}},	//   _बढ़न, _jala, _kỷ_, gezz
  { {0xf3f10023,0x6d4139f7,0x69d939f8,0x2007013f}},	//   ập_, _mala, _huwe, ánil_
  { {0x44380176,0x6d4103ac,0x69d90fc3,0x9f580030}},	//   rwr_, _lala, _kuwe, özül_
  { {0xb77b0008,0x50d60015,0x20d60015,0x44380034}},	// [7d20] _תאפש, مزار, متاج, swr_
  { {0x865b013a,0x69d9003f,0x6d4139f9,0xb5fb0030}},	//   _עדיי, _muwe, _nala, tyáv
  { {0xa2b4005d,0x80a60086,0x636a001a,0x03a60bb1}},	//   _आरक्, حمان, _sýnu, _гино
  { {0xc7d60008,0x6d410035,0x66040e5f,0xaff70015}},	//   צוני_, _aala, _kvik, صفها_
  { {0x471b00b2,0x9e140036,0x69d900dd,0xde5802e1}},	//   רונג, ідкі, _nuwe, ралі_
  { {0x2fd80020,0xd2b70008,0x2d9a007c,0x463b004c}},	//   _turg_, _ללכת_, õpe_, טענע
  { {0x6fb60086,0xdc2a00b0,0xa1770053,0x6d410be7}},	//   _همسا, استه_, _פעלד_, _dala
  { {0x5f96040b,0xd0070124,0x6f960029,0xdb000107}},	//   _الرئ, _ћете_, _الرض, pomí
  { {0x7afd0084,0x386c0026,0x8d1a0087,0x6d4139fa}},	//   ðsta, wydr_, _مزار_, _fala
  { {0xa3d8014e,0xad650029,0xbd290029,0xdb1a016e}},	//   ादा_, _واله, _نأمل_, _autô
  { {0x2c0b0086,0x75353302,0xb900000b,0xdb000045}},	//   _معنی_, vezz, _थल_, româ
  { {0xb09b0008,0x80370053,0x27e30046,0x2d8e263b}},	//   ריטר, זנטע_, íjna_, life_
  { {0x7bda003f,0x753523b8,0x6d410061,0x6d670091}},	//   _hutu, tezz, _yala, žraš
  { {0x7bda39fb,0xdceb0085,0xd94304d7,0x2d8e39fc}},	//   _kutu, čići, _нечи, nife_
  { {0x7aed04f9,0x7bda0020,0xcc780008,0x69d900b8}},	//   _întâ, _jutu, בְּר, _zuwe
  { {0x657c00b8,0x2897000a,0x9bfb004c,0x7bda0738}},	//   ahrh, _לדון_, טהלט, _mutu
  { {0x5a9b000a,0x60f9004a,0x2258004a,0x98a50091}},	// [7d30] ְׁבו, иная_, биты_, delę_
  { {0x7bda001c,0x20070263,0x61550015,0xdb090125}},	//   _outu, šnim_, غنائ, ileá
  { {0x610b0048,0x60390033,0x99dd006f,0x72d505ab}},	//   vēlē, рпеў_, yvňo, _монф
  { {0x63780467,0x42990015,0x764d09cf,0x6d412796}},	//   _vínc, _ننجح_, _kray, _sala
  { {0x8f34008f,0x7bda39fd,0x7ed40015,0x2efd0034}},	//   яецц, _autu, أزما, rawf_
  { {0x6f190026,0x7bda00e8,0xdd9b0080,0xd5fc0008}},	//   sgwc, _butu, ыше_, נפור
  { {0x6d431156,0xfaf10015,0x251c0643,0x98a5002a}},	//   rdna, وثة_, טוגא, belę_
  { {0x69d900b6,0x99e50080,0x637830e6,0x6d4130e7}},	//   _puwe, ожид, _kína, _wala
  { {0x2ca9005c,0xa2a2005d,0xc334039e,0x6d4139fe}},	//   ład_, _कुञ्, לוק_, _tala
  { {0x63780084,0xdcb10092,0x672d02c1,0xd90f002b}},	//   _mína, _tỷ_, _abaj, ریع_
  { {0x764d01e2,0x660439ff,0xf649000a,0x6be40015}},	//   _aray, _svik, _שצ_, _فكلم
  { {0x22490111,0x02b9005d,0x69d9003f,0x501a000a}},	//   kvak_, _आरंभ, _tuwe, סורו
  { {0xceb20008,0x99d70115,0xe617033d,0x764d3a00}},	//   ֥ים_, _اتصا, одя_, _cray
  { {0x1a9a0053,0xd5af0015,0x61ed2abf,0xe4520058}},	//   _דינע, َفَ_, dpal, وضأ_
  { {0xdb001043,0x7c09000a,0x61ed3a01,0x93463a02}},	//   lomá, יִּ֔, epal, онве
  { {0x3f8f016f,0x03260033,0xb5fb0030,0x764d10eb}},	//   jigu_, ўдан, gyás, _fray
  { {0x61ed00b6,0x27e0016f,0xe6c60029,0xc20a002b}},	// [7d40] gpal, _čini_, _بتغي, شقان_
  { {0xa1c30127,0x3f8f0095,0x6f093a03,0x2ca00061}},	//   дбуд, eigu_, _adec, şidi_
  { {0x397a0053,0x61ed3a04,0x98a51ed6,0xcf46055f}},	//   סטענ, apal, telę_, жней
  { {0x7bda3a05,0xdd90002b,0xdce3002a,0x61ed112a}},	//   _rutu, کوت_, mknę, bpal
  { {0x6f090176,0x3df30033,0x63a10030,0xadf30033}},	//   _ddec, дзіс, élne, дпіш
  { {0x6f090064,0x98ac0011,0x63a903cd,0xcbe60661}},	//   _edec, nedă_, čene, оции
  { {0xdb0008e0,0xd00712d2,0xd47a004c,0xbf5a005e}},	//   tomà, _мере_, יאַל, _краї_
  { {0x63b60176,0xc4d3000f,0xdb093a06,0xdb001945}},	//   nlyn, וגו_, tleá, fomá
  { {0xd37b000a,0x63b60034,0xdb000144,0x6d360015}},	//   ירקט, ilyn, romà, _وفرض
  { {0x6f09005c,0x5d780008,0x3257000a,0x63b60034}},	//   _zdec, _פָּנ, קסים_, hlyn
  { {0x31370008,0x0137000a,0x91bb000a,0xdb090125}},	//   חנים_, חרית_, שמיי, sleá
  { {0x764d003e,0x478b08e8,0xa5bb0e51,0x0000006a}},	//   _pray, рсом_, atól,
  { {0xe7380010,0x61e2002d,0x8f9b000a,0x25740123}},	//   цеў_, íoll, שיכי, _täll_
  { {0x63b60034,0xd49b062f,0xf98f0058,0x764d01f6}},	//   elyn, арб_, _لبى_, _vray
  { {0x46150086,0x6378002e,0xb9c30002,0xa4d4005e}},	//   _کوخر, _sína, _تقوي, дорі
  { {0xe517014e,0x03c40127,0x22490111,0x764d3a07}},	//   _ताकि_, дсум, tvak_, _tray
  { {0xc1750063,0xbb3b0053,0x5215005e,0xa7fc0061}},	// [7d50] плащ, סעמי, ядат, ayıt
  { {0x3d04005d,0xdb0900aa,0x22493a08,0x3634002b}},	//   रणों_, toeë, rvak_, _آريس
  { {0xb6020089,0x80070256,0x22490079,0x61ed3a09}},	//   řáte, ючае, svak_, spal
  { {0xf4120053,0x61ed1581,0x7bc20079,0x200e0030}},	//   _אפט_, ppal, _nhou, áfia_
  { {0xf7740008,0x735a000a,0x249f0061,0x3f8f01d7}},	//   וקף_, _הכרח, ğumu_, rigu_
  { {0x11da013a,0x63ad0011,0xdb000f7b,0x249f0061}},	//   _לחשב, loan, vomá, şumu_
  { {0xc57c0008,0x7afd002e,0x69c80046,0xa5bb0030}},	//   שרות, ðsto, dmde, jtóm
  { {0xdb003a0a,0x649c000a,0xc052000a,0xc49c000a}},	//   tomá, יסוד, _אזל_, ישות
  { {0xdb0e002d,0x3eb9001a,0x1eea009a,0x0000006a}},	//   ódál, _ást_, _طولی_,
  { {0x8d770031,0xdb002918,0x888505aa,0x5982030c}},	//   _بارا, romá, злож, ельб
  { {0xa3bd014e,0xa5bb002e,0xdb0002de,0x77b6016e}},	//   ेगा_, rtól, domæ, láxi
  { {0x91790023,0x4cba000a,0xc052000a,0xdb00013f}},	//   _lần_, _המעג, ׂ֖ר_, pomá
  { {0x7f3a0053,0x200702c6,0xd4970016,0x64430091}},	//   זערו, šnih_, ồng_, _šnip
  { {0xe4da0086,0xe9a80015,0xdce3002a,0x79a40099}},	//   صورت_, _ودون_, tknę, _орје
  { {0x98790053,0x69c33a0b,0x6908000a,0x63ad0045}},	//   _לאַט, _ihne, _וּפְ, foan
  { {0x3f9f003f,0x46a6022a,0x96fa0015,0xd7890067}},	//   _njuu_, _найв, _اعثر_, _وخيم_
  { {0x171b013a,0x70f60015,0x63b63a0c,0x0000006a}},	// [7d60] _הופע, كسائ, rlyn,
  { {0x91790023,0xd299005e,0x69c30012,0x91b10016}},	//   _cần_, ітті_, _jhne, _đạp_
  { {0xb4d8000b,0x91790016,0x0ffa0015,0x04db000a}},	//   िशी_, _dần_, صعاب_, _לקיל
  { {0xf1a90053,0xdfcf00e6,0xe676000a,0x63ad3a0d}},	//   אס_, هيل_, ּתַח_, coan
  { {0x69c80026,0x69c30012,0x9f03002b,0x0000006a}},	//   ymde, _ohne, رووو,
  { {0x7bc2003e,0x91790092,0x70ca3a0e,0xb2bb004f}},	//   _shou, _gần_, _гггг_, _למכר
  { {0x31570053,0x317b000a,0x6db30033,0x0b8a009b}},	//   _צילן_, _פרלמ, эйшу, йсии_
  { {0x309b0008,0xaa540063,0x7c930015,0x62840d24}},	//   _השלמ, двиш, عشوا, ozio
  { {0x628402d7,0x257401d1,0xc3330008,0x5eeb0008}},	//   nzio, _välj_, תוח_, _הַבְ
  { {0x63ad000c,0x4e7b000a,0xcce50015,0x6f020125}},	//   zoan, _האמצ, _قسمي, laoc
  { {0x7bc2003e,0x63ad003f,0xac760029,0x6606007c}},	//   _thou, yoan, _عائش, eskk
  { {0xba2a0086,0xe6950080,0xa8a30010,0xa0970053}},	//   _هستم_, димы, эрык, לדיק_
  { {0xbaba0029,0xdb00063b,0x27e03a0f,0xc1db0065}},	//   _اداء_, tomæ, _činu_, _बढेग
  { {0xa2cd005d,0xd5b10092,0x6284005c,0x1dcc005d}},	//   _दृष्, ố_, dzio, ाषित
  { {0x63ad0011,0x19bb000a,0xb9bb000a,0x23bb0015}},	//   toan, _המגב, _הצגת, مدرب_
  { {0x97a40010,0x68b7000a,0x389b000a,0xb89b000a}},	//   _прыл, _מלוא_, _ליונ, _לבוש
  { {0xa2cd005d,0x6f020085,0xa3b80015,0x6234168a}},	// [7d70] _दृश्, daoc, سافر_, нету
  { {0x93270074,0x291e0007,0x64580007,0x201a003f}},	//   _کردن, ngta_, _švie, fupi_
  { {0x628402d7,0xf1c80029,0xf1bf002d,0xd92b000a}},	//   azio, أولى_, _spás_, מֵאָ
  { {0xdb0026a6,0xf2070033,0x6f023a10,0x27f801c0}},	//   nomä, _няго, gaoc, árny_
  { {0x32540010,0x7ed40010,0xa3aa005d,0x91790016}},	//   _звяр, нішч, खकर_, _tần_
  { {0xdd910806,0xee3805d1,0x361c000a,0x625a000a}},	//   ضوع_, яні_, מודד, _וכשה
  { {0xdbf10089,0x8c4205c4,0x251c004c,0xdb00008c}},	//   příj, веще, צוהא, komä
  { {0xdce10048,0xdb4e0029,0xa0c40029,0x291e138a}},	//   _dolā, لَى_, _سيقو, egta_
  { {0xdb0000c0,0x6b9b001a,0x7bc93a11,0x5e450058}},	//   domä, rnug, rmeu, _تَذْ
  { {0x98bc0048,0x644802de,0x9f580030,0xfe7000c3}},	//   _savā_, ædik, özöl_, _صدق_
  { {0x07a62962,0xc7a6170d,0x3859005e,0xe73a0162}},	//   данн, динк, ірою_, оен_
  { {0xd7ca0040,0x7d033a12,0x0000006a,0x0000006a}},	//   توجه_, lans,   ,
  { {0x69c30034,0xaa4505ab,0x63783a13,0x0000006a}},	//   _thne, _целл, _síno,
  { {0xa3b6000b,0xe00d000b,0x89da000a,0x7d033a14}},	//   _चीज_, _हिंद_, _וחסי, nans
  { {0x5fd9005d,0x33d6005e,0x98bc003d,0x2242003d}},	//   _बंगल, діат, _tavā_, _sskk_
  { {0xd7fa0008,0x2eff0152,0x7d032739,0xe3ba0484}},	//   _והקל, _neuf_, hans, іба_
  { {0x39470161,0x6f020085,0x7d030f99,0x71760015}},	// [7d80] _kans_, vaoc, kans, وهرا
  { {0x7644003f,0x62842a1a,0x1de1000b,0x7d033a15}},	//   _isiy, rzio, _पढ़त, jans
  { {0xdce30089,0x05770008,0xf8a50086,0x94060002}},	//   skně, _חגים_, اک_, _توجه
  { {0x91790023,0x7d030024,0x20073a16,0x44441083}},	//   _vấn_, eans, ânia_, _is_
  { {0x7d030026,0x0dca067a,0x201a01d7,0x644e0789}},	//   fans, оуки_, supi_, lvbi
  { {0x2d57004a,0x91790016,0xdce1003d,0x44443a17}},	//   дишь_, _tấn_, _polā, _ks_
  { {0x6724016f,0xac9700e5,0xebc60054,0x753c0dbc}},	//   _ocij, ونها_, мљин, ierz
  { {0x6f660010,0x8c430001,0xbf130015,0xd37b004c}},	//   _ўваз, теће, _لوفب, ַריט
  { {0xcb67000d,0x7d033a18,0x44443a19,0x6d260054}},	//   ќање_, bans, _ls_, _одаз
  { {0x8f000010,0x44443a1a,0x7d033a1b,0x79810034}},	//   вiч_, _os_, cans, ghlw
  { {0x39470b7a,0xab2a008f,0xa5bb002e,0x753c0ec2}},	//   _dans_, _можа_, stók, derz
  { {0xbc790053,0xc7ab0029,0x6d483a1c,0x657e0220}},	//   _צװײט, تدخل_, _hada, _alph
  { {0xe4e70036,0xa5bb002d,0x444435d7,0x97a40033}},	//   дібн, ltói, _as_, трэл
  { {0x79810026,0x44443a1d,0x2240002a,0x6d4a3a1e}},	//   chlw, _bs_, dwik_, ndfa
  { {0x17f70029,0x236b0001,0x6d48043a,0x91790016}},	//   _قرية_, ојао_, _mada, _lẫn_
  { {0xc2c50029,0x6d483a1f,0x69d81909,0x6f003a20}},	//   فيزي, _lada, _hive, _nemc
  { {0x7d03000c,0x21550010,0x5344006b,0x69d816a1}},	// [7d90] yans, нкаў, ъхра, _kive
  { {0x41b50021,0x753c002a,0xca480016,0x6d483a21}},	//   رمار, cerz, _mờ_, _nada
  { {0x69d80014,0x6d4a0026,0xca480016,0xe57000c3}},	//   _mive, ddfa, _lờ_, _خطي_
  { {0x7d030ec5,0x69d83a22,0x7ee50015,0x64453a23}},	//   wans, _live, ركتن, _ishi
  { {0x8db5008f,0x4279004c,0x6d481450,0x7ed40015}},	//   нскі, _זאָג, _bada, نزها
  { {0x91790023,0x444417bb,0x6d483a24,0xe466007c}},	//   _dẫn_, _ys_, _cada, ööga_
  { {0x8d740029,0xfc310087,0xabd5049d,0x999f002a}},	//   خانا, احت_, нциј, ytuł_
  { {0x3947038d,0xca480092,0x6445003f,0xfa69000d}},	//   _sans_, _bờ_, _mshi, заик_
  { {0xca480092,0x7d033a25,0xa5bb0125,0x2bdf000b}},	//   _cờ_, pans, atói, _पूरा
  { {0x661d0020,0x6d483a26,0x64de000b,0x394508e8}},	//   dusk, _gada, _मलेश, хног
  { {0xf1b20008,0x7b670404,0x673d3a27,0xe108000a}},	//   רסי_, _отде, fesj, וּרָ
  { {0x70dc005d,0xc0520053,0x307a0053,0x1bb80086}},	//   _बल्ल, אזט_, פארנ, _قانع_
  { {0x3947020a,0xab180191,0x661d0020,0x6d5a3a28}},	//   _tans_, _цієї_, gusk, _ynta
  { {0x7d010014,0xca960008,0x69d83a29,0x45d30033}},	//   _jels, _אדני_, _give, лоўс
  { {0xb97a000a,0xb8640015,0x64a330d6,0x78640015}},	//   _מנסי, _لايو, гара, _لديك
  { {0x29053a2a,0x11da0029,0x753c253e,0x3878079b}},	//   lala_, كورة_, serz, ørre_
  { {0xfbd2000a,0xb7c90015,0xf773000a,0xd2a7098b}},	// [7da0] רתן_, _تبوك_, _תקח_, екте_
  { {0x7ae90057,0xf1a90015,0x290507d4,0x2b9a003d}},	//   hcet, واله_, nala_, rīci_
  { {0x251b0053,0x44441ee1,0xc7b90085,0x6d483a2b}},	//   _צוטא, _us_, suđe_, _rada
  { {0x6d481825,0x29053a2c,0xdee63a2d,0x8520000b}},	//   _sada, hala_, ходи, _बाँट_
  { {0x7d0100dc,0xa2d60002,0x29053a2e,0x6d483a2f}},	//   _bels, _سيست, kala_, _pada
  { {0xcce60074,0x91790092,0xa3d8000b,0x569b004c}},	//   رستي, _vẫn_, ादक_, הינצ
  { {0x20070089,0x29053a30,0x69d82ba0,0xa0a607be}},	//   ánit_, dala_, _rive, _чавд
  { {0x5a342263,0x600b000a,0x7d01007c,0xa5bb0030}},	//   внит, _מִמְ, _eels, rtói
  { {0xa5bb002d,0x7d013a31,0x733b004c,0x7bd90375}},	//   stói, _fels, לעקס, _diwu
  { {0xf8ab0023,0xde350010,0x661d3072,0xbd8a0031}},	//   ười_, _шэсь, vusk, _عنان_
  { {0x6c56005e,0x69d83a32,0x4c16006e,0x673d0546}},	//   _ятає, _vive, _سباس, tesj
  { {0xca480092,0xcaf60029,0xf7950010,0x48a70010}},	//   _tờ_, _أساب, тамэ, этым_
  { {0x69d803af,0x95cb05b3,0x9b89006e,0x29053a33}},	//   _tive, зува_, _تخلف_, bala_
  { {0xceb30632,0xa967006b,0x661d3a34,0x082a0015}},	//   ריש_, _пича_, rusk, _فأبى_
  { {0x43950036,0xf4340010,0xf4840484,0x28020046}},	//   вавс, лерэ, гутн, ásně_
  { {0x58bb0008,0x88bb000a,0x661d3a35,0x63a90787}},	//   _ממוצ, _מזוי, pusk, čeno
  { {0xdb1b001c,0x7afd001a,0xd5bb009b,0x0000006a}},	// [7db0] fluê, ðsti, _нсо_,
  { {0xe29000a2,0x2007016e,0x518401c6,0x9a3b000a}},	//   حذف_, ânio_, луха, התמק
  { {0x05960086,0x6445003f,0x49170008,0xdef10015}},	//   _جايگ, _ushi, תקבל_, لًا_
  { {0x7d01079b,0x29fd006f,0x224d0069,0x290530b4}},	//   _sels, yňa_, _šeku_, zala_
  { {0xa91c006f,0x7d01337b,0x63a80046,0xf6ec000a}},	//   zhľa, _pels, édne, ה֗וּ
  { {0xa91c032c,0xaffd0033,0x6ab90034,0x2369036d}},	//   yhľa, _могi, _rywf, ljaj_
  { {0xae02000b,0x29050768,0x538b000a,0x20d70015}},	//   रीबन_, vala_, ּנִ֣, _ستسج
  { {0x660d016f,0xd9c9005d,0x257400b8,0x29053a36}},	//   _ovak, रष्ट, _hält_, wala_
  { {0x99dd006f,0x7ae93a37,0x29053a38,0x7d013a39}},	//   yvňu, rcet, tala_, _tels
  { {0x99d50029,0x290500d9,0x7ae93a3a,0x85200065}},	//   ختبا, uala_, scet, _बाइट_
  { {0xd7f8008f,0x660d00c0,0x78863a3b,0x29053a3c}},	//   нуў_, _avak, _révé, rala_
  { {0x2a390015,0x29fd006f,0x68360012,0x78860003}},	//   _يكاد_, pňa_, _südö, _sévé
  { {0x661a005c,0x29053a3d,0x23690085,0xe9ce0133}},	//   ątko, pala_, djaj_, _вк_
  { {0x9e76000a,0x98bc0091,0x290500aa,0x64a61301}},	//   דגשה_, _savą_, qala_, вага
  { {0x5fd1000b,0xd4150033,0xccf2000a,0x232a0442}},	//   तगाल, льты, שכל_, мови_
  { {0xe6960015,0xd7ca002b,0x4a5b004f,0x0000006a}},	//   _للعد, _توبه_, ּד֑ו,
  { {0x29c2002e,0xe2972387,0x788600dc,0x91e315d5}},	// [7dc0] iðan_, ват_, _tévé, иоте
  { {0x91a70023,0xd1830080,0x20d60015,0x4536006b}},	//   _địa_, алуй, نتاج, _рхит
  { {0x637808e0,0x30860029,0x757b000a,0x0000006a}},	//   _líni, خلاف, _חטיפ,
  { {0xbf130029,0xa3c90157,0xdb003a3e,0x443a3a3f}},	//   لومب, _लीप_, llmö, _ipp_
  { {0x3e340029,0x257400c0,0xcf250067,0x9daa006b}},	//   افتر, _fält_, ارمي, мъка_
  { {0x1ea90029,0x29c2002e,0xc5f3000a,0xa5bb016e}},	//   راني_, eðan_, סדו_, stóv
  { {0x50c6005d,0x659b0053,0xa2d6005d,0xab940036}},	//   _वरिष, ויסק, _मृत्, ликі
  { {0x60c30064,0x35b4000b,0x10a30342,0x443a13d2}},	//   ünme, ंकड़, _тисн, _mpp_
  { {0xdfa50029,0xaa630033,0xfd120015,0xf1a6000b}},	//   _صحفي, атэк, _نجا_, _खदान
  { {0x3f86001c,0x443a13e1,0x1e830484,0x49ba0058}},	//   lhou_, _opp_, _тлум, باعد_
  { {0x660d010b,0x3f860089,0x58860033,0x6378016e}},	//   _svak, ohou_, тыпа, _tính
  { {0xa3e6005d,0x68f50064,0x7c850001,0x3f863a40}},	//   _पढ़_, ızda, _суђе, nhou_
  { {0x443a3a41,0x5b7b000a,0x0f57004f,0xf62800ce}},	//   _app_, _קרדא, דיכם_, кіри_
  { {0xe8540029,0xea77000a,0xfe080016,0x443a01d7}},	//   _منتد, _בגדר_, iữ_, _bpp_
  { {0x984a0063,0xdb1b0251,0xfe080016,0x6b8202de}},	//   _цяла_, fluè, hữ_, _klog
  { {0xdb000843,0x31db000b,0x6443016e,0x443a2f8e}},	//   almö, बद्ध, _ânim, _dpp_
  { {0x6458001a,0xd2500015,0x236900bc,0x6b820034}},	// [7dd0] _ávin, ينِ_, rjaj_, _mlog
  { {0x3d1c005d,0x6b823a42,0xa698000a,0xfe73002b}},	//   नलों_, _llog, _שכזה_, یدش_
  { {0x4395097d,0xb4fa000a,0xdb000072,0x30151ea5}},	//   _банс, _אלתר, llmõ, удер
  { {0x289b004c,0x889b000a,0xa0c40015,0x91f70015}},	//   ויבא, ובבי, جيمو, _لأسا
  { {0xfe080092,0x3ea90251,0xb287054f,0x8de40015}},	//   gữ_, çat_, _рынк, لكنه
  { {0x6b823a43,0x067c01ac,0x867c000a,0xddc20046}},	//   _alog, ונדל, ורדו, ovoř
  { {0x6378002f,0xe8d90092,0xa19419bf,0x5bb50180}},	//   _síni, _đỏ_, _тарч, лсиф
  { {0x0c360015,0x04dc000a,0x2918001a,0x31710030}},	//   اكية_, וקול, óran_, _hozz_
  { {0x69ca002f,0xe9d90cfa,0x29c2001a,0xcf240058}},	//   _bhfe, нки_, rðan_, _خرّي
  { {0xd9450001,0xb2bc000a,0x9985012c,0xe8f6030c}},	//   ћени, ומחר, الدو, лль_
  { {0x63a9052c,0x9be70036,0x2d87002d,0xa3e3000b}},	//   čenj, _різк, mhne_, _फूल_
  { {0xeb740010,0x29190061,0xddc20046,0x645a0123}},	//   _вышэ, şsa_, dvoř, åtim
  { {0x645708e0,0x6378002e,0xd7070033,0x7afb27d2}},	//   _arxi, _kínv, ыняе_, mbut
  { {0x69ca014e,0xceb2013a,0x1a9a00b2,0x4a9a0135}},	//   _सीपी, צים_, _אינע, _אינג
  { {0x3ceb005d,0xc7b90085,0xa5bb001a,0x233601e1}},	//   _चलने_, suđa_, króf, лхар
  { {0x6e3b005c,0xb8760135,0xf772002b,0x0594002b}},	//   _opub, _תתקס_, _چاک_, _چادگ
  { {0xec090092,0xd1ca0151,0x211a002b,0xf772002b}},	// [7de0] hế_, елае_, فتاب_, _ناک_
  { {0x32170015,0x2d8700bc,0x61f60811,0x0000006a}},	//   ايلد_, jhne_, rpyl,
  { {0x443a3a44,0x200e002e,0x3f8600dd,0xef1a0718}},	//   _upp_, éfi_, thou_, еме_
  { {0x749b01ac,0x5f062f83,0x937a0015,0x3f860046}},	//   _טייפ, узда, _أصدر_, uhou_
  { {0x63a43029,0x3f8600aa,0x93b7000a,0xb6ad004f}},	//   mnin, rhou_, _תלכו_, ֽׁוֹ
  { {0x63a427a9,0xbc4a085d,0xfe080016,0xf98700c3}},	//   lnin, ечие_, rữ_, _طب_
  { {0x91bb000a,0xef1a0004,0x3f8600aa,0x63a43a45}},	//   _נמלי, _пмв_, phou_, onin
  { {0xe4570053,0x7afb0035,0xfba7004a,0xbc47004a}},	//   ריקט_, gbut, лтый_, учше_
  { {0xe8d90023,0x6b8200bd,0x3f840d25,0x63a40ab5}},	//   _đề_, _vlog, _ilmu_, inin
  { {0x63a401d1,0xdd8f0070,0x2d980400,0x7afb3a46}},	//   hnin, _فوق_, _öre_, abut
  { {0xa5bb0050,0x63a43a47,0xb19b000a,0x7dc40144}},	//   któr, knin, תייכ, lòso
  { {0x6b82016f,0xf0930008,0x8c1b000f,0x63a43a48}},	//   _ulog, מנת_, _טובי, jnin
  { {0x63a43a49,0xb7d9002b,0xa2b0000b,0xba170040}},	//   dnin, _یوتا_, _अँग्, _مينا_
  { {0x7d0a1498,0xddc20089,0xcdd4000f,0x63783a4a}},	//   nafs, tvoř, יךָ_, _mínu
  { {0x6378002e,0x63a439ff,0xa4d5022a,0x6672002b}},	//   _línu, fnin, рові, مگیر
  { {0x98130087,0x63a41003,0x7d0a3993,0x87070033}},	//   _ابوا, gnin, hafs, _сяке
  { {0x92b70015,0x7bc03a4b,0x753b0160,0xd7f800d4}},	// [7df0] احزا, ilmu, đuzb, lpă_
  { {0x61150036,0xa5bb3a4c,0x63a4043a,0x41770021}},	//   рджу, atór, anin, دارس
  { {0x31c40080,0x80a40015,0xc0580033,0x55bc000a}},	//   сств, ممكن, ліц_, _אמזו
  { {0xa857000a,0x30180015,0x889b004c,0x4423002a}},	//   טיבה_, اتلة_, עשאצ, muj_
  { {0xaf040191,0x11d90029,0x2d87002d,0x44231e32}},	//   спіл, _لوحة_, thne_, luj_
  { {0xac390036,0xc236000a,0xbdf80015,0xc1050015}},	//   вчих_, _דרשו_, ارنا_, _خوسي
  { {0x05780008,0xa5bb002e,0x5578000a,0xcc86005e}},	//   רגום_, próf, רעון_, ибше_
  { {0x543c0053,0x69ca005d,0x201c013f,0x799a02ad}},	//   געהא, _सीबी, ávie_, eitw
  { {0xa3d6005d,0xc334000a,0xad27006e,0x3b8201c6}},	//   िगत_, צוץ_, _مراو, ільг
  { {0x8e840029,0xf2410010,0x442317eb,0x661d10ca}},	//   _الكه, скiя_, kuj_, drsk
  { {0xfd100029,0x6ca70457,0xfb150015,0x661d3a4d}},	//   _رجل_, _сраж, _نواج, ersk
  { {0x9c82002c,0x7bdc0003,0x44233a4e,0x63a40123}},	//   účen, _érup, duj_, xnin
  { {0x63a428ab,0xd7f80045,0xe8ee19db,0x4b7a004f}},	//   vnin, apă_, _мл_, _שאנו
  { {0xa5bb005c,0x6378002d,0xca740067,0x6d433a4f}},	//   wtór, _línt, _دامغ, nena
  { {0x44230050,0xc3960001,0x33b60015,0x2d850618}},	//   guj_, ајањ, لمسأ, _mlle_
  { {0x6b8900dd,0x661d00bd,0xa3630015,0x63a43a50}},	//   nheg, brsk, يُّو, unin
  { {0xe5a60036,0x29073a51,0x21d60015,0x63a43a52}},	// [7e00] _випи, _kena_, لقرآ, rnin
  { {0x4423005c,0x63a4230f,0x6d433a53,0xa5bb3a54}},	//   buj_, snin, jena, stór
  { {0x6378002e,0x90e50029,0x69c10be1,0x4423002a}},	//   _sínu, إسكن, ille, cuj_
  { {0x2907002f,0x64c50086,0xc1690008,0x0836004c}},	//   _lena_, _ديپل, וח_, יװער_
  { {0x7d0a36bf,0x2bdf005d,0xdfcf006e,0xc7b3004f}},	//   tafs, _पंजा, ذيه_, חבא_
  { {0xd6570008,0xdb1b0144,0x7c230034,0x7ae20034}},	//   יינת_, fluï, funr, _sgot
  { {0x6b890084,0x3f9c0003,0xa06717bd,0xdcfa0045}},	//   fheg, évus_, _кара_, _altă
  { {0x2d85038d,0x27e0022d,0xda660015,0x5aaa0015}},	//   _elle_, _niin_, لاخي, َاةَ_
  { {0x6d430375,0x4423259a,0xeaaf0015,0x63a10030}},	//   bena, zuj_, ِعٍ_, élni
  { {0xc171000a,0x3237000a,0x3dfb000a,0x6d433a55}},	//   ִ֗י_, סטין_, _סלבד, cena
  { {0xe8d900a7,0x3ceb005d,0xd7f80011,0x23b6000b}},	//   _để_, _चलते_, upă_, ंवाद
  { {0x7ae2018c,0x77930086,0x6b893a56,0x2d9c3a57}},	//   _ugot, تیبا, cheg, live_
  { {0x799a003f,0x4423005c,0x29860010,0xaad2000b}},	//   pitw, wuj_, _выйг, देशक
  { {0x442331f5,0xb8660087,0xa6db002e,0x48970086}},	//   tuj_, _نابو, beðn, ائید_
  { {0x98a50007,0x98a30054,0x27e73a58,0xdb000061}},	//   delė_, _миље, _gunn_, komü
  { {0x4423005c,0x6d43001c,0xf8db000a,0xd8db000a}},	//   ruj_, zena, _בחומ, _בקור
  { {0x44230050,0x60e70036,0xa7870086,0xdb000077}},	// [7e10] suj_, ацез, _مشکو, lomó
  { {0xd49b2c0c,0x2d9c02c6,0xcad7000a,0x4423002a}},	//   _арм_, jive_, שומת_, puj_
  { {0x5067000d,0x6d4331e3,0x7f190033,0x290c3a59}},	//   штаа, vena, гілу_, iada_
  { {0x6d43013c,0x290c105d,0x1eea002b,0x62350132}},	//   wena, hada_, هومی_, _лему
  { {0x7d080134,0xef180127,0x8f340033,0x69c13a5a}},	//   _beds, рмі_, юецц, ylle
  { {0x2d9c00fb,0x637807cf,0xcc350015,0x31850015}},	//   give_, _fíns, مربع, _السِ
  { {0x661a002a,0x6d430dcb,0x290c3a5b,0xbd18005e}},	//   ątki, rena, dada_, рції_
  { {0xa6db0084,0x1b492a44,0x7c230012,0x6d4326c9}},	//   veðn, узии_, runr, sena
  { {0x69c10251,0x8ed80015,0x27e700cb,0x6d433a5c}},	//   tlle, _نذكر_, _sunn_, pena
  { {0x27e00005,0x8d7406e4,0x7d740029,0xe8f90139}},	//   _siin_, _والا, _والط, ыло_
  { {0x69c10176,0xf6490008,0x29073a5d,0x66e6006d}},	//   rlle, _רצ_, _vena_, йона
  { {0x903a0053,0x4c9a000a,0x103a004c,0x290c3a5e}},	//   נערה, _גבעו, נגרע, aada_
  { {0x2907000c,0xa1420024,0x6fda0089,0xeb900015}},	//   _tena_, šķie, _důch, _تظل_
  { {0x225e0046,0x5e56004c,0x290c0f9c,0x27180016}},	//   _čtk_, זישע_, cada_, ọn_
  { {0x63a80089,0x443e0251,0xf7f500e5,0x27ed002a}},	//   édno, ït_, _استد, ólną_
  { {0x087600b2,0x2d9c27f2,0x38780123,0x0000006a}},	//   _לעצט_, zive_, ärre_,
  { {0xae1c005d,0x98a50091,0xc64a0015,0x8f000138}},	// [7e20] _निधन_, telė_, _إجعل_, гiю_
  { {0x39451650,0xa06a121b,0x2d9c24bd,0x0000006a}},	//   nels_, лаза_, xive_,
  { {0x7ee60029,0x7d08052a,0x5577000a,0xa99a004c}},	//   مكان, _reds, _העין_, נבער
  { {0x543b0053,0x290c06d4,0xa116002b,0x3945086c}},	//   _געטא, zada_, _گوست, hels_
  { {0x3945020a,0x6eb60015,0x2d9c3759,0xbea30033}},	//   kels_, حصائ, tive_, пацк
  { {0xa1160074,0x463b0053,0xdd900115,0x290c3a5f}},	//   _دوست, רעסע, بوت_, xada_
  { {0x3086003b,0xe4fb005d,0xd47a0053,0x39450d52}},	//   _الأف, ्रति_, טאַל, dels_
  { {0x7d080150,0x207b0135,0xddc9002a,0x3945044d}},	//   _weds, _גאלא, _kreś, eels_
  { {0xdb1b195b,0x6e960029,0x290c3a60,0x531b000a}},	//   cluí, _الذا, tada_, אופצ
  { {0x48140142,0xd90e0086,0xa8140001,0xfdf7000a}},	//   омос, ریب_, одош, _לממש_
  { {0x91bb0135,0xc1bb004c,0x3157004c,0x290c3a61}},	//   רמיי, רמיש, זיין_, rada_
  { {0xda03000b,0xe61f016e,0x3212008c,0x15e1000b}},	//   _शौकत_, trô_, ksyy_, _गूजर_
  { {0x8f9b0008,0xfa330086,0x290c3a62,0xbb3b000a}},	//   ריכי, _فرود, pada_, _תעדי
  { {0xdb00002a,0xf4410033,0x29d30015,0x29d40015}},	//   pomó, могi_, _فينس, _بيتس
  { {0x499b039e,0x8937000a,0x8464006b,0x659406ff}},	//   _תשוב, _לרגע_, пъте, чару
  { {0x07a40e88,0xdc8b000a,0x439402ed,0x0000006a}},	//   _најн, רְךָ, пасс,
  { {0x52150457,0x90e70015,0x7dcd2fcb,0x16200065}},	// [7e30] юдат, مسان, núsc, _बियर_
  { {0x32b80015,0x35f80015,0x60e70033,0x8f0001f3}},	//   صدقة_, _اريد_, сцаз, гiя_
  { {0xa5bb12f7,0x9ee9012c,0xf8b1004f,0x29c20052}},	//   prób, لفضل_, ֵשׂ_, rðah_
  { {0xe7c9000b,0x201c1ecf,0xff0700e2,0x3945158f}},	//   रतिप, ávia_, сяжн, zels_
  { {0x7dcd0251,0x171c0053,0xa3d6000b,0x1d09006b}},	//   júsc, רודע, िगर_, аели_
  { {0xb4fb014e,0xdb020084,0xabf50248,0xed59058c}},	//   ्रिय_, _skoð, очищ, рок_
  { {0x3945069b,0x7db40015,0xc05800e2,0xe7c90065}},	//   vels_, أصنا, _літ_, रताप
  { {0x8f340033,0x39451710,0x1ee7002b,0x9f3400fd}},	//   _несц, wels_, _طوطی_, _несі
  { {0x6e990010,0xdb000144,0x394500ed,0xab920067}},	//   _твар_, tomò, tels_, بليغ
  { {0xe8df0023,0x39790080,0xdce8002a,0x3945005e}},	//   _giới_, рсию_, _podą, цног
  { {0xa3d9005d,0x0cab0063,0x7ce8000a,0x39451f91}},	//   ाषा_, _стаи_, _הַנֶ, rels_
  { {0x39453a63,0x0056000a,0x3212008c,0xc7960033}},	//   sels_, קשרת_, ysyy_, ірны
  { {0x70c6005d,0x05560063,0xa9691411,0x39453a64}},	//   _वर्ल, отвя, _вила_, pels_
  { {0x98a5003d,0xa5070681,0x0000006a,0x0000006a}},	//   nelī_, жера_,   ,
  { {0xa5bb005c,0xe7320029,0x97c60015,0x3c89000a}},	//   wróc, _قصة_, _وتعم, בָּ֑
  { {0xd25200c3,0xa2060033,0x59b30065,0xe28602ed}},	//   ونز_, жпад, ुतकर, олби
  { {0xe2a90015,0x7aac000a,0xe3b701f3,0xccf80046}},	// [7e40] ماكن_, ְׁבֵ, ібу_, _sněm_
  { {0x63f60015,0x71250015,0x04460432,0x602600e2}},	//   _وأجر, كرمل, _деон, жджа
  { {0xd12f0029,0xf21e005d,0x25e3000b,0x661a002a}},	//   ضمن_, यूज़_, _टूटी_, ątku
  { {0xddc90050,0x7dcd0077,0x4fa3006b,0xaec60c1c}},	//   _treś, yúsc, михв, обел
  { {0x98be0024,0xde580010,0x82360002,0x5e58005e}},	//   ietā_, салі_, _برجا, силя_
  { {0x7c660115,0xdd900015,0x865b004f,0x8c180058}},	//   قابل, عوث_, ידני, ميتر_
  { {0x0b8a05b3,0x70560058,0x200700d4,0x0000006a}},	//   исии_, _بنزا, ânit_,
  { {0x447b004c,0x0000006a,0x0000006a,0x0000006a}},	//   ינצע,   ,   ,
  { {0x9f4d00b8,0xe946004a,0xaa530033,0x5d1a0015}},	//   _hieß_, охно, двыш, _نتاج_
  { {0x6d230001,0x7dcd002d,0x2fc628ad,0x8c460b59}},	//   _одуз, rúsc, llog_, _мезе
  { {0x81570053,0x6c4a0031,0xeaaf002b,0x6f02002a}},	//   קסטע_, _خلاف_, فعی_, oboc
  { {0x69ca000b,0x290a002a,0x6f020c2e,0x7dcd2f61}},	//   _सीरी, źba_, nboc, púsc
  { {0xdb09018b,0x8bd70053,0x9f4d00b8,0x66020064}},	//   ließ, _וואו_, _ließ_, _çokl
  { {0x26c50024,0x64400011,0x94ab006b,0x2fc60125}},	//   ālo_, ămin, атба_, hlog_
  { {0xa5bb00dc,0x7dcd002d,0xe8d90092,0xdb090012}},	//   gróa, núsa, _đệ_, nieß
  { {0x6e223a65,0x8c1b000a,0x48a9005e,0x24e40033}},	//   krob, יולי, _утім_, ьцяг
  { {0xdb0900b8,0x51f8054f,0x623406b3,0xe6040015}},	// [7e50] hieß, жную_, мету, _قِيَ
  { {0xba57000a,0x6e223a66,0x1620000b,0x20c70190}},	//   חסמו_, drob, _बितर_, осег
  { {0xf4850086,0x6e220024,0x44270092,0x2fc60026}},	//   _رادی, erob, _ên_, flog_
  { {0x93270086,0x63a90057,0x2349002b,0x6f020030}},	//   _بردن, čens, _اسدی_, gboc
  { {0x4e040010,0xddc2002a,0x8d65031e,0x5187394e}},	//   дзіб, dwoł, звле, _дува
  { {0xc27a0008,0xf2d20135,0xd5fc000a,0x527a000a}},	//   _הרשי, _נעם_, ספור, _הנשא
  { {0x6018007a,0xe9ce0484,0x30a400d7,0x2fc63a67}},	//   _моря_, _якi_, _жртв, blog_
  { {0x6e223a68,0x0000006a,0x0000006a,0x0000006a}},	//   brob,   ,   ,
  { {0xbdf5000a,0x6e220051,0x539c004f,0xaa4500ce}},	//   _זֶ֣ה_, crob, ייהו, чепл
  { {0xacf40086,0x7e6d008c,0x5e440058,0xddc20535}},	//   _قسمت, äapu, _تَكْ, awoł
  { {0x7c590074,0xfc30006e,0xc8d50065,0x0000006a}},	//   _دلار_, _لحن_, डेंट,
  { {0x309a0008,0x7b640b18,0xe73a058f,0xba770015}},	//   משתמ, _отче, щем_, _واشت
  { {0x987700bd,0xb5aa0058,0x55f602ed,0x0000006a}},	//   _išče_, ماسك_, ячну,
  { {0x386a002d,0x2fc601a3,0x6eba000a,0xf9fa000a}},	//   óirí_, zlog_, מזרח, _ההסמ
  { {0x14590033,0x6e221835,0x3c89004f,0x0000006a}},	//   ошты_, zrob, זָּ֑,
  { {0x6d860084,0x3706004a,0xb69b0045,0x66160091}},	//   _aðal, _эпиг, mbân, _tvyk
  { {0xe8d90023,0x52760004,0x997c003d,0x46a6006b}},	// [7e60] _độ_, чуву, _dāņu_, _хапв
  { {0x6f1b0011,0x7dc40251,0x201c016e,0xa1c301fe}},	//   _aduc, pòsi, ávio_, ебуд
  { {0xd12f0029,0x757b0008,0xdefa004a,0xddc2002a}},	//   امم_, _הטיפ, был_, ywoł
  { {0x442a0005,0x98be0011,0xdfd20087,0x91e604fe}},	//   mub_, letă_, ريش_, _номе
  { {0x2fc60161,0x442a3a69,0x8e730015,0x44383a6a}},	//   rlog_, lub_, فاوض, ltr_
  { {0x763b0053,0x463b0053,0xc5f3000a,0x5ea3002b}},	//   מענג, מענע, עדו_, عمول
  { {0x443804f9,0x442a007c,0x2fc60085,0x44443a6b}},	//   ntr_, nub_, plog_, _jp_
  { {0xa037000a,0x6c830015,0x7dcd001a,0xbb980015}},	//   _מאלה_, عليم, rúsa, تنبؤ_
  { {0x442a3a6c,0x3f860107,0x645c007c,0xda7a0151}},	//   hub_, mkou_, hvri, сяй_
  { {0x44443a6d,0x3f8601b2,0x442a3a6e,0x8dfb000a}},	//   _op_, lkou_, kub_, _להמת
  { {0xdd8f003b,0x44440050,0xa3be005d,0xc1730008}},	//   _حول_, _np_, ेता_, תחת_
  { {0x442a0020,0x3f860057,0x478b004a,0x6d4a3a6f}},	//   dub_, nkou_, ссом_, lefa
  { {0x645c0064,0xf1be005d,0xab27042b,0xe91801c6}},	//   evri, ्तान, _хоча_, _долі_
  { {0xcaa503c4,0x89d80015,0xaadb000a,0x39890125}},	//   _تصمي, _بوتر_, _החדר, _túsa_
  { {0x69da018b,0xc9730029,0xa93b000a,0x4548005e}},	//   mmte, _ساوث, _התופ, ччям_
  { {0x69c800c0,0x6d4a007c,0x3f860069,0x44443a70}},	//   llde, hefa, jkou_, _dp_
  { {0x44380026,0x71790180,0x35b50805,0x3f8601c0}},	// [7e70] atr_, обар_, _обир, dkou_
  { {0x442a2d25,0x41b40015,0x6d580079,0x290e039f}},	//   bub_, ّمْر, jdva, _jefa_
  { {0x580b0643,0x7bc20046,0x69da0079,0x443824ff}},	//   ֶּאֱ, _okou, imte, ctr_
  { {0xe0d00029,0x69da00b8,0x99840046,0x6d580079}},	//   ازك_, hmte, kumů_, edva
  { {0xddc904f9,0x05960086,0x5f740015,0x8db50033}},	//   _creş, _رایگ, عامر, мскі
  { {0x7bc2010b,0xd6580008,0xdd940010,0xe1ff001a}},	//   _akou, פיות_, начы, _próf_
  { {0xbc190010,0xfd100031,0x7dcd001a,0x351c000a}},	//   цілі_, اجه_, búsn, מוגנ
  { {0x2d8c0064,0x3f8628cc,0x69c81692,0x291c0030}},	//   _elde_, ckou_, elde, _adva_
  { {0xddc90011,0x3f8d0026,0xa6db002e,0x6d4a0293}},	//   _greş, _ileu_, beði, befa
  { {0xdb00001a,0x888510b3,0x44380034,0x63ad3a71}},	//   rnmá, длож, ytr_, hnan
  { {0x8af9010f,0x61e73a72,0x6d411d31,0x290e0061}},	//   _днес_, _mijl, _ibla, _defa_
  { {0x44442a56,0xcb080015,0x96f90033,0x69c8355d}},	//   _rp_, _فيمن_, зэру_, alde
  { {0x2bb80029,0xff16000a,0x84fb000b,0x7bdb0bb5}},	//   _عامة_, וקרת_, ्रंट_, mmuu
  { {0x7bc9038d,0x290e0084,0x45d30010,0x7bc20089}},	//   lleu, _gefa_, коўс, _zkou
  { {0x61fd03eb,0xf4840086,0x63ad002e,0xf8d1005d}},	//   _atsl, راسی, fnan, _हरिय
  { {0x645c0298,0x98be0011,0x6d580085,0x7bdb01be}},	//   rvri, setă_, zdva, nmuu
  { {0x44383451,0x61e70111,0x442a0020,0xd2aa0010}},	// [7e80] str_, _bijl, sub_, цкае_
  { {0x7bc900b8,0xf8d1005d,0x44443a73,0x442a007c}},	//   hleu, _हराय, _tp_, pub_
  { {0xa6db0084,0x3f8d0152,0x7bc90150,0x44443a74}},	//   veði, _bleu_, kleu, _up_
  { {0xddc904f9,0xc3340008,0x6d412f97,0xd54a002b}},	//   _preş, _אוֹ_, _abla, _الگو_
  { {0x98a50007,0x7bc90026,0x69c80293,0x69c31e80}},	//   kelį_, dleu, ylde, _okne
  { {0xf9870074,0xa6970008,0x98be0007,0x3f863388}},	//   _شب_, וכנה_, letą_, skou_
  { {0x98a50007,0xdb00002d,0xa15700f3,0xfc2f0015}},	//   delį_, limé, _קבלה_, لحي_
  { {0xaa540775,0x109b000a,0xfc63006b,0x309b000a}},	//   евиш, _ובלב, тъшн, _ושלמ
  { {0xc27b00b2,0x727b0053,0xa5bb00dc,0x527b004c}},	//   ַרטי, ַנטװ, rtóz, ַנטא
  { {0x69c8003e,0x7bc90152,0x98a50091,0x63ad05d9}},	//   ulde, aleu, gelį_, znan
  { {0x69c800c0,0x63a400f2,0x6c860015,0x9f440003}},	//   rlde, kiin, _تلام, _aimé_
  { {0x29c2002e,0x96f8004a,0x25a30079,0x29053a75}},	//   gðar_, меют_, wijl_, abla_
  { {0x2918002f,0xb50a005d,0x86740036,0xa3c9021e}},	//   óras_, वरूप_, вляє, _लीग_
  { {0x63ad005c,0x7bc00a6d,0xdb1b0003,0x765d0123}},	//   wnan, lomu, voué, rvsy
  { {0x69cb005d,0x04c90029,0x63a40011,0x6672002b}},	//   हतरी, سوري_, fiin, نگیر
  { {0xcc57000a,0x394c0123,0x61f90033,0x46150015}},	//   ובלי_, leds_, знаў_, _كوبر
  { {0xe4eb0086,0xb6040089,0x61e70111,0xdce80089}},	// [7e90] _وعده_, tvář, _pijl, _podě
  { {0xef190050,0x64930007,0xab5d002a,0x765a002a}},	//   _może_, ežiū, może, łtyc
  { {0xfe700074,0x31c405ae,0x27e90509,0x25f5000b}},	//   یده_, тств, _kian_, _एंडी_
  { {0x660d000c,0x46d3005d,0x60c70089,0x61e70079}},	//   _kwak, _सराह, _vyjm, _wijl
  { {0x27e9002f,0xdb0010e0,0xbe4b0015,0x7bc03a76}},	//   _mian_, cimé, تشام_, domu
  { {0x660d000c,0xb5fb0014,0xc1050070,0xdd910015}},	//   _mwak, ováb, _سوري, طوع_
  { {0x55780053,0x6fca0264,0x7bc90012,0x6e2b02f2}},	//   ועגן_, kých, tleu, sugb
  { {0xef19005c,0xf092000a,0x7c840054,0x2d873a77}},	//   _boże_, _ענן_, ђује, skne_
  { {0x7bdb00f2,0xa5bb047e,0x0dcb0054,0x7bc93a78}},	//   rmuu, tról, _дужи_, rleu
  { {0x2dd4209b,0xaa850089,0x7bdb0604,0x6d4106f2}},	//   _ажур, jvýš, smuu, _ubla
  { {0x660d0a99,0x7bc93a79,0x1869030e,0x98a50091}},	//   _awak, pleu, чани_, relį_
  { {0x2918002e,0x1cb8012c,0xe1ff0144,0x27e93a7a}},	//   órar_, _غالب_, _otó_, _cian_
  { {0x29c20084,0x27e9308a,0x394c10ad,0xa6db001a}},	//   rðar_, _dian_, beds_, efðb
  { {0xc5d501f3,0xdb001f15,0x6b893a7b,0x0000006a}},	//   вісь, anmä, lkeg,
  { {0x98be0007,0xf8c6021e,0xc4c50015,0x660d002a}},	//   tetą_, _रुपय, نتفو, _ewak
  { {0x27e90023,0x69c13a7c,0xab5d002a,0xb4fb000b}},	//   _gian_, lole, boże, ्रॉप_
  { {0x69c13a7d,0xe7b3006e,0xe29a0004,0x3229005e}},	// [7ea0] oole, _حميد, чаа_, дієм_
  { {0xdb000152,0x63bb065d,0x7bc0003f,0xb6bb0008}},	//   rimé, čuna, zomu, _מצפי
  { {0x7bc0003f,0xf2c9000a,0x660d0079,0xa75a000a}},	//   yomu, צע_, _zwak, ּדְר
  { {0xd00f0087,0x2ea80086,0x69c13a7e,0x27e93a7f}},	//   صله_, وپای_, hole, _xian_
  { {0x649300df,0x59b1005d,0x63a80089,0xf57a000a}},	//   ržiū, ीकार, édnu, ּרֶך
  { {0x361b004f,0x0000006a,0x0000006a,0x0000006a}},	//   לונד,   ,   ,
  { {0x961d000b,0xe1ff002a,0x7bc03a80,0xcbe60663}},	//   _भट्ट_, _grób_, tomu, нции
  { {0xa3d0000b,0x69c10034,0xcc430058,0xaa850de4}},	//   षति_, eole, انيً, zvýš
  { {0x7fd700b2,0x394c0134,0x69c13a81,0x79a61017}},	//   _טולס_, teds_, fole, ерне
  { {0xc237004c,0x2914002b,0xe29b000a,0xd91a004a}},	//   עאיז_, خودآ, פשיר, чьи_
  { {0xa3d0005d,0x27e900f2,0x48aa005e,0xba73002b}},	//   षता_, _pian_, ятим_, نایت
  { {0x60da00dc,0xa08b000a,0x61be000b,0x6d5a3a82}},	//   _útmu, לְכִ, ्तुष, _hata
  { {0xdb0000c0,0x8f9b00f3,0xae2a000a,0x80a7000b}},	//   rnmä, ליטי, הוָ֛, _टेने
  { {0xdca6003b,0xca570053,0x9f4a02b9,0x2a57000a}},	//   لى_, _ניוז_, _subì_, _נבון_
  { {0xf3f10092,0xa6db002e,0x6d5a3a36,0x657e00aa}},	//   ệ_, veðu, _mata, _doph
  { {0x660d003f,0xe6950029,0x6d5a3a83,0x9cd7000a}},	//   _twak, _للبد, _lata, תולה_
  { {0xe1f30087,0x660d003f,0xa294005e,0x7bdb000a}},	// [7eb0] اسر_, _uwak, гаті, לקלו
  { {0x6d5a3a84,0xe1ff002a,0x6b8900bc,0x00e5002b}},	//   _nata, _prób_, zkeg, نتای
  { {0x2bac0089,0x30180015,0xc3b5006b,0x442700a1}},	//   pěch_, فتنة_, _айнщ, _ín_
  { {0xa0c40029,0x141a0008,0x441a000a,0x84fb000b}},	//   ديمو, _קורב, _קורס, ्रकट_
  { {0x69c1003f,0x69d8007c,0xfdeb004a,0xed593a85}},	//   yole, _ohve, чьей_, дол_
  { {0xa6db002e,0xe5f8000a,0x6d5a3a86,0x6a6b001a}},	//   leðs, עזור_, _cata, höfð
  { {0xe73f0005,0x21640805,0x69c10107,0xf532000a}},	//   lnõu_, _стяг, vole, ׁ֥ה_
  { {0x69c1005c,0xc43c000a,0xfaf10015,0x6d5a3154}},	//   wole, פתחי, جثث_, _eata
  { {0x69c13a87,0xe9d90e37,0x2bb2000b,0x7dcd0030}},	//   tole, мки_, ुक़ा, núsk
  { {0xd9450001,0x69c100f2,0x6d5a3a88,0x6b893a89}},	//   њени, uole, _gata, skeg
  { {0x69c12f44,0xd825006b,0xe72a1883,0x260f0065}},	//   role, ъдни, монд_, तीसी_
  { {0xf0ee005d,0x08d40010,0x7dcd002c,0x69c10100}},	//   _जल्द_, ыцыя, kúsk, sole
  { {0x98b101e2,0xaf760053,0x6d5a0aa5,0xb9b5006b}},	//   ızı_, דערס_, _yata, _искъ
  { {0x7afb16c4,0x68453a8a,0x26cc01ec,0x66033a8b}},	//   lcut, _анка, ādo_, рпра
  { {0x69ca014e,0x98350010,0x98be0007,0xf992000a}},	//   _सीटी, _рэлі, ketę_, _דרג_
  { {0xd6b60015,0x9c8201c0,0xc3231236,0x0000006a}},	//   _لإخب, účin, имск,
  { {0xf506010f,0xcb120632,0x9757000a,0x657e3a8c}},	// [7ec0] _изпо, ילן_, _ישקף_, _toph
  { {0x3cf0014e,0x41b30015,0x41030a23,0x45d301ca}},	//   _चलें_, لمقر, изув, _коњс
  { {0x3fc6002b,0x98bc0091,0xf1c20091,0x6d5a3a8d}},	//   نگری_, _davė_, _rašą_, _rata
  { {0x287a0053,0x8025002b,0x34b7000a,0x7f750033}},	//   ונעמ, ارلم, _יפים_, лучц
  { {0x8e370018,0xc33300f3,0x6d5a3a8e,0xa3bf000b}},	//   نسور_, _דור_, _pata, इवर_
  { {0xf6530008,0x569b0053,0xa2af000b,0x0dc7006b}},	//   יצד_, וינצ, ंपर्, кущи_
  { {0x6d5a0064,0xe8d90016,0xa0a6009b,0x71a300af}},	//   _vata, _đở_, _равд, _тарз
  { {0x6d5a306a,0xa2d9000b,0x7b63004a,0x6fd8016e}},	//   _wata, _मरम्, атье, fíce
  { {0x6d5a1640,0x4e0b000b,0x3a73006b,0x0000006a}},	//   _tata, सीआई_, илър,
  { {0x19740010,0x0e9b0008,0xce37000f,0x4974135d}},	//   угоў, _חשמל, _באמת_, улос
  { {0xe10b000a,0xdcf80046,0xdb4f0151,0x7d183a8f}},	//   וּכָ, zkvě, _кю_, mavs
  { {0xab5d002a,0x4b1a002b,0x7d183a90,0x501b004f}},	//   rożc, _آغاج_, lavs, ווטו
  { {0x07a4008f,0x95cb0083,0xda970015,0x38c8002b}},	//   раўн, дува_, _لخوض_, باکی_
  { {0x8a17000a,0x98be002a,0x7d182f93,0xcad7004f}},	//   _יחדו_, zetę_, navs, _סוגת_
  { {0x49920086,0x4395005e,0xa98b000a,0x2a66013f}},	//   _میکر, гавс, _קָדִ, _hrob_
  { {0x28490053,0x63bb0198,0x7d183a91,0x47350e3f}},	//   _נעפּ, čuno, havs, _снис
  { {0x61d90afa,0x9f440125,0x442a0125,0xa5bb0125}},	// [7ed0] емая_, _cimí_, arb_, hrói
  { {0x315900e6,0xdb000107,0xc1050015,0x90e70040}},	//   علاج_, dimí, اوضي, نسان
  { {0xdef10029,0xe572000a,0xa0c40015,0x661d2315}},	//   مًا_, _הַר_, ليكو, lssk
  { {0x44310064,0xdcfa0046,0xdb1b001a,0xff070248}},	//   muz_, _dotč, sluú, тяжн
  { {0x7afb0064,0xdb00002d,0x539a000f,0x079c004c}},	//   vcut, gimí, _נישו, וסאל
  { {0xaac6005d,0xbbcb000b,0x7db70067,0xed5801f3}},	//   _लड़क, ात्क, خصصا, коі_
  { {0x443101e2,0x0000006a,0x0000006a,0x0000006a}},	//   nuz_,   ,   ,
  { {0xddc2002a,0xdfd10015,0x9f040058,0x661d3a92}},	//   owoś, _طيء_, _نوفو, kssk
  { {0x991502e5,0xe8d90016,0xa6db001a,0x7dcd001a}},	//   льні, _đố_, yfða, húsi
  { {0x7dcd002c,0x7afb3a93,0x44310061,0x661d2d27}},	//   kúsi, scut, kuz_, dssk
  { {0x5fb7005d,0x3cf00227,0xbc380015,0x5b250015}},	//   _अदाल, ňové_, _لسنا_, _مفضل
  { {0x6f19005c,0x44313a94,0xddc9006f,0xa5bb002a}},	//   nawc, duz_, _speň, orów
  { {0xca08005e,0xe9ce0a1f,0x8f9a000a,0x63bb07c4}},	//   _аніж_, _гк_, תירי, čunl
  { {0x2bcb005d,0xfe0b000b,0x395c0123,0x98be0046}},	//   ातका, सीएस_, _gavs_, netě_
  { {0x28020089,0x5fb3000b,0x1866009b,0xdb00005a}},	//   ěrné_, ंचाल, _бащи_, zimí
  { {0x2b5f0045,0xf3e61e98,0xe7bb000b,0x1fcd0065}},	//   nduc_, ужбо, _उदयप, ़तोड
  { {0xe297010f,0x6f190050,0xb5fb3251,0x98be0046}},	// [7ee0] гат_, dawc, lván, ketě_
  { {0xd677000a,0x66043a95,0xa5bb002a,0xdcfa0085}},	//   _עתיק_, _itik, drów, _potč
  { {0x80a6002b,0x600a009b,0x113902ed,0x03a60e64}},	//   دمان, хнем_, ъяты_, _бино
  { {0x6d43002e,0xdb003a96,0x9836004c,0x3a3f0061}},	//   efna, timí, טרעף_, ktup_
  { {0xde58022a,0x539b000a,0xee200033,0x527508e8}},	//   талі_, _טיטו, целi_, _куру
  { {0xa3be005d,0xad660015,0x2b91006f,0x6c34012c}},	//   ेतक_, طاته, _ráca_, لفتا
  { {0xac940010,0xd1170008,0xa5bb002a,0x67240085}},	//   райш, _תקלה_, arów, _odij
  { {0x6c470029,0x395c0024,0x6d43002e,0xa2db005d}},	//   اليف_, _savs_, afna, पेक्
  { {0x2240013c,0x61ee3521,0xdfcf0058,0x7d18013b}},	//   ntik_, _kibl, _ريك_, pavs
  { {0x6e93003b,0x32570008,0x2fc63a97,0x44313a98}},	//   _الكا, נסים_, loog_, yuz_
  { {0xeaaf0086,0xab5d002a,0x6d4801d7,0x99630174}},	//   قعی_, możn, _ibda, стыл
  { {0x9cd70008,0x6af60015,0x44310061,0x661d3a99}},	//   _גובה_, _إثار, vuz_, tssk
  { {0x395c3a9a,0xc6a731d5,0xf98f002b,0x224001d3}},	//   _tavs_, урни, زبی_, jtik_
  { {0x1a9b0053,0xe1ff002d,0x3a37000a,0x2fc60111}},	//   _אידע, _brón_, _תרגם_, hoog_
  { {0x68fb0008,0x78fb0c44,0xc428004a,0xdb09016e}},	//   _אלוה, _אלופ, люте_, lneá
  { {0x443101e2,0x6b820fb2,0x69d8021e,0x8cdb000a}},	//   ruz_, _joog, _नीती, תחלת
  { {0x248d0024,0xc1150001,0xdb09002d,0x44310061}},	// [7ef0] ņem_, имај, nneá, suz_
  { {0x61ee0152,0x6b821e68,0x6f19002a,0x672400bc}},	//   _cibl, _loog, wawc, _zdij
  { {0xc94b000a,0x8467006b,0xb4fa000a,0x6f19002a}},	//   עֲמֹ, _съпе, _בפתי, tawc
  { {0x28370053,0x6d4800e8,0x547a00a3,0x91f70015}},	//   רנאך_, _abda, _סטרו, _مأسا
  { {0xb5fb28cc,0x6f19002a,0xb2870033,0x0000006a}},	//   zván, rawc, _сынк,
  { {0x320900b6,0x7c650029,0x6d430012,0x8de40015}},	//   mpay_, لاعل, ufna, مكنه
  { {0x91ba0008,0xfaf10029,0x6d43002e,0xdca203a9}},	//   _ימשי, يثة_, rfna, жащи
  { {0xba750029,0x3b850bb1,0x5f940b5c,0xdb090079}},	//   لاخت, рлиг, _лист, mieë
  { {0x7f840029,0x49990036,0xab5d002a,0x9f040058}},	//   _القن, втня_, bożn, _طولو
  { {0xb5fb0030,0xa9a5144f,0x3a3f0a1c,0x66043a9b}},	//   tván, риод, rtup_, _rtik
  { {0xe8d90023,0x3a3f3109,0x3829006b,0x66043a9c}},	//   _đồ_, stup_, ъжно_, _stik
  { {0x7c940015,0xe7b30015,0x6b823a9d,0x7e693a9e}},	//   _اشكا, ْمَد, _goog, _krep
  { {0x24f60054,0xceb2000a,0x25aa0040,0x96b92f72}},	//   ичвр, ֧ים_, ندسي_, гуру_
  { {0xceb201e4,0xdce10024,0x1a9a004c,0x6b820079}},	//   קים_, _nolī, _בינע, _zoog
  { {0x443e0152,0xb5fb00dc,0xf3ca0029,0xe7ef000b}},	//   ît_, lvál, نبره_, _घंटा_
  { {0x22400064,0x25aa0026,0x61ee0f21,0xe4d7002b}},	//   ttik_, sibl_, _sibl, شوقت_
  { {0x79830050,0x5725003b,0xdb003a9f,0xc5d601f3}},	// [7f00] _konw, _طريق, nimá, _вінь
  { {0xb5fb00dc,0x645a001a,0xa06a08d7,0xe1ff0428}},	//   ivál, ætis, каза_, _trón_
  { {0xef1a0083,0xb5fb04af,0x70530015,0xdb090079}},	//   вме_, hvál, ينكا, gieë
  { {0x7f460036,0xe1ff005c,0x7e2a0484,0x9e663aa0}},	//   редж, _król_, віка_, ивед
  { {0x5de6250c,0x7e56005e,0xd312000b,0x1ec727f6}},	//   ажда, ртец, ़रीब_, алци_
  { {0x7e693aa1,0x6b8200aa,0xdb090079,0xac2608d7}},	//   _drep, _soog, bieë, афик
  { {0x20b9005f,0x91bb0008,0xcf260086,0xdb090227}},	//   _быть_, _סמלי, _پرزي, šnýc
  { {0x4f9600d0,0xfca90040,0x7ac61114,0xc477004f}},	//   _тргу, داهو_, испе, שתקו_
  { {0xb5fb0014,0xfe720029,0xcb67050e,0xab5d005c}},	//   gvál, _بدأ_, рање_, możl
  { {0x79830335,0x3a09002b,0x19b30015,0xf98f0015}},	//   _conw, اکنی_, ْحَج, ِبَ_
  { {0xd0f70008,0x00f7000a,0xdddb003d,0x497301f3}},	//   ימית_, יזים_, _bruņ, ілюс
  { {0xdc3b000a,0xf8af0058,0x3f8401ec,0x0000006a}},	//   _יעבר, بةً_, _jomu_,
  { {0xa5bb002a,0xdb0000bf,0x96340138,0x0000006a}},	//   krót, cimá, оняц,
  { {0xd5b801c5,0xdb0902de,0x3f843aa2,0x79830034}},	//   асс_, gneæ, _lomu_, _gonw
  { {0xd5b80063,0x69c83aa3,0x89db000a,0x38570015}},	//   рся_, mode, _שחוי, _نشيد_
  { {0xdce10048,0xa2f50010,0x987b000a,0x2259004a}},	//   _solī, спач, _ירוק, либы_
  { {0x67540086,0xb7dc0008,0x764d0273,0x47d5002b}},	// [7f10] _ذخير, _בקהי, _upay, _پيکر
  { {0x91740010,0x69c700bc,0x25f4000b,0x69c83aa4}},	//   огуц, čjeg, ंदरी_, node
  { {0x212a002b,0xc1e8004a,0x55bc000a,0x64410144}},	//   طينی_, рьте_, _במזו, àlid
  { {0xdb090298,0xe4560053,0x7e693aa5,0xdcfa003d}},	//   rieë, _פירט_, _prep, _rotā
  { {0x6db20050,0xd37a00b2,0xdb0004af,0x8e490029}},	//   kład, _ערשט, ximá, التك_
  { {0xfd47008f,0xdb090234,0xd658000a,0xf658000a}},	//   рэдн, pieë, יידת_, יסדי_
  { {0x4095003b,0x3f84003f,0x7dcd11dd,0xc058008b}},	//   _الأر, _fomu_, dúst, _кіт_
  { {0x8f34008f,0xa3d7005d,0xb5fb00dc,0xdb1b001a}},	//   _месц, िति_, tvál, sluþ
  { {0xf9910015,0x7528002a,0x69c80d1e,0xea86009b}},	//   كبد_, ódzk, fode, йбъл_
  { {0x69c83aa6,0x63ad3aa7,0x6db2002a,0xf1c80046}},	//   gode, hian, gład, _tvář_
  { {0x6ca70124,0xa3d7005d,0xb5fb00dc,0x63ad3aa8}},	//   _траж, िता_, svál, kian
  { {0x2d850a99,0x6db2002a,0x63ad0d89,0xda350033}},	//   _hole_, aład, jian, _геды
  { {0xe8d90092,0xceb2000a,0x63ad2c93,0xba740015}},	//   _đổ_, ִיל_, dian, _واهت
  { {0x799a3074,0xf8a8002b,0x69c81692,0xeab00058}},	//   chtw, ادیه_, code, _تعم_
  { {0xdcfa0011,0xccf2000a,0x35a30033,0x63ad3aa9}},	//   _hotă, לכם_, чарг, fian
  { {0x969606b4,0xa4570061,0x03a31acb,0x7399153d}},	//   _грош, şağı_, писо, атус_
  { {0x70f60021,0x2d8502f7,0x69060030,0xa5bb0030}},	// [7f20] مسائ, _oole_, _érdé, trót
  { {0x42230036,0xe2b50010,0x667b0053,0x13a80086}},	//   ядув, істэ, _עטיק, _چندی_
  { {0x27e0052d,0x63ad3aaa,0x70560058,0x11d70058}},	//   _khin_, bian, إنصا, حولة_
  { {0x645e3aab,0x5e260029,0x8636000a,0x6db2002a}},	//   _ispi, معتق, ֶרֶב_, zład
  { {0xdfcf00b0,0x59c7000b,0x0219005e,0x7bc93aac}},	//   ريه_, रकार, _вісь_, doeu
  { {0x2d853aad,0xbbb20065,0x0000006a,0x0000006a}},	//   _cole_, ुक्क,   ,
  { {0x3f840107,0x7d230015,0xb60600bc,0x69c81e01}},	//   _tomu_, سفين, lašč, vode
  { {0xfc2f0015,0x09d0000b,0x69c8002a,0x6db2002a}},	//   رحى_, हत्य, wode, wład
  { {0xb9980809,0x3a74005e,0xc333000a,0x39ea00eb}},	//   ивих_, ілор, פוז_, льон_
  { {0xdd920002,0x69c80321,0x645e3aae,0x63ad3aaf}},	//   _عوض_, uode, _ospi, zian
  { {0x317b0053,0x23c8000b,0x69c80b15,0x6d8b000a}},	//   ארימ, लवाद, rode, _עָמְ
  { {0x69c8069e,0x6e22002a,0x8b6500c3,0x1bf7000a}},	//   sode, osob, _وانم, _הצאר_
  { {0x98b80064,0xa5f90080,0x3b630015,0x46a40033}},	//   ırı_, регу_, _رُوِ, заўв
  { {0x63ad005c,0xa3ab000b,0xe894124a,0x7d1a039d}},	//   wian, कोन_, _маль, _jets
  { {0x7d1a3ab0,0x291e3ab1,0x63ad3ab2,0x24190033}},	//   _mets, mata_, tian, робы_
  { {0xdb09001c,0x521503fc,0x8c1b000a,0x59d0000b}},	//   rneç, ждат, טולי, हतकर
  { {0xdb000601,0x63ad3ab3,0xb60600bc,0x645e0d29}},	// [7f30] mimä, rian, gašč, _espi
  { {0x63ad1dce,0xeab10008,0xdb0001be,0x291e3ab4}},	//   sian, וֹב_, limä, nata_
  { {0x6616005c,0x98a70064,0x2d853ab5,0xe4d9002b}},	//   _zwyk, _yanı_, _role_, _خودت_
  { {0xdcee0089,0xf7740053,0x2d85052a,0xa5bb3ab6}},	//   žděn, ּקס_, _sole_, prós
  { {0x28cf014e,0xdce800df,0x2d853ab7,0x733a004c}},	//   _सुनि, _kodė, _pole_, _דערס
  { {0xdb000020,0x7bc9002a,0x26dc000a,0x291e3ab8}},	//   himä, woeu, אקדמ, jata_
  { {0xef190050,0xcfe90029,0x6b9b002e,0x2fdf002d}},	//   _też_, _نفسه_, thug, _thug_
  { {0xd4980008,0xdb4e0015,0x6db2002a,0x3b0900af}},	//   מכות_, نَى_, głab, јепо_
  { {0xeab10029,0xfebb0029,0x6b9b021b,0x291e3ab9}},	//   بعث_, _صارت_, rhug, fata_
  { {0xc9a90080,0x7db70086,0x6b9b2822,0x27e00541}},	//   рвое_, _اصرا, shug, _shin_
  { {0xb901014e,0xc174000a,0x9f4b0125,0xb60600bc}},	//   _दर_, לחץ_, _ómós_, zašč
  { {0xe73a3aba,0x291e0e95,0xa3ae0065,0x7d1a0160}},	//   шем_, aata_, _औषध_, _zets
  { {0x4431005c,0x291e3abb,0xfbd5000b,0xa3bf0065}},	//   erz_, bata_, _डीएम, ेवन_
  { {0x291e23b9,0x29010020,0x6e24002d,0xb60600bd}},	//   cata_, _üha_, áibi, vašč
  { {0x27e0003e,0xe8d90092,0x6fc9000b,0x5fc9000b}},	//   _thin_, _đỗ_, िकां, िकाल
  { {0x130a0010,0x24530015,0x230a012c,0x6db2002a}},	//   рнай_, بنفس, شتري_, ołac
  { {0xd5e40023,0x42260063,0x645e005c,0x75d60015}},	// [7f40] _trì, юдав, _wspi, _ويعا
  { {0xa50a0001,0xb6061c40,0x854a005e,0x6b990034}},	//   _њена_, rašč, _тзов_, _llwg
  { {0x20b90010,0x645e016f,0xa067006b,0x7d1a3abc}},	//   быць_, _uspi, жаха_, _rets
  { {0x3cef005d,0xf8b20008,0x543b0053,0x291e3abd}},	//   ेखने_, ושב_, _דעטא, zata_
  { {0x7d1a00b6,0xb51e005d,0x44383abe,0x291e25db}},	//   _pets, _बजाय_, lur_, yata_
  { {0x44383abf,0xd5b3000a,0xdb020012,0xa4fa000a}},	//   our_, ֽׁה_, _bloß, ׁלְט
  { {0x44383ac0,0x6f1b3ac1,0xac9700e6,0x645c22d3}},	//   nur_, _feuc, ينها_, nwri
  { {0x9b6a000d,0x77640251,0x60970029,0x207b0135}},	//   ршка_, _naix, _بنفس_, _דאלא
  { {0x9e660086,0x7d1a00dc,0xdcfa0015,0x44383ac2}},	//   _بازن, _tets, _نفذت_, hur_
  { {0x291e003f,0x44383abe,0x59dd000b,0x6c760015}},	//   uata_, kur_, _नीदर, _وطائ
  { {0x2618014e,0x75e000dc,0x776429ab,0x6db2005c}},	//   बीसी_, közb, _baix, ałac
  { {0x77643ac3,0x645c0026,0xdcfa005c,0x291e3ac4}},	//   _caix, dwri, _dotą, sata_
  { {0x291e3ac5,0x44383ac6,0x9f580003,0xdce80091}},	//   pata_, eur_, _curé_, _podė
  { {0x6d580005,0x44383ac7,0x4431005c,0x645c0026}},	//   neva, fur_, trz_, fwri
  { {0x7764001c,0x2b910092,0x4c98000a,0xd795006b}},	//   _faix, _bách_, זֹּא, _никъ
  { {0x2b910023,0x6d583ac8,0x442d25b6,0x44442e9d}},	//   _cách_, heva, če_, _dq_
  { {0xdce800df,0xdb110014,0x44380024,0x444418d8}},	// [7f50] _todė, áfér, aur_, _eq_
  { {0x6d580198,0x306b0001,0xd5e40092,0x4438013c}},	//   jeva, ијен_, _trí, bur_
  { {0x8f750010,0x291c0251,0x44380faa,0x6d583ac9}},	//   зулі, _meva_, cur_, deva
  { {0x9ee90015,0xe8d7000a,0xdee10033,0x6d4a001a}},	//   مفضل_, חובר_, нулi_, effa
  { {0x644700dd,0xee380127,0xa3ab000b,0xce040015}},	//   ltji, жні_, कोण_, وذوي
  { {0xdd940010,0x2dcb0001,0x8638000a,0x0d84005e}},	//   мачы, шћен_, קרוב_, млін
  { {0x644700dd,0xeb910029,0xf532000a,0x6c350015}},	//   ntji, فظة_, ׂ֥ה_, أفعا
  { {0x94bc000a,0x6d58007c,0x2b910016,0x61fd09f5}},	//   ימות, aeva, _xách_, _kusl
  { {0x7c380003,0x6d353aca,0x5f4400c3,0x6d58334f}},	//   auvr, _неаф, _تنقل, beva
  { {0x3945087a,0x291c0011,0x39790080,0xde740015}},	//   чног, _ceva_, ссию_, _تدفع
  { {0x48b50063,0x7764168c,0xa5bb001a,0x5922002b}},	//   ящит, _paix, vróp, رکوف
  { {0xf0920053,0x6db2005c,0xb69b0011,0xa3db000b}},	//   גנט_, płac, rcân, _ढील_
  { {0xa5bb3acb,0x4444003e,0x96760010,0x77640251}},	//   rsón, _sq_, чыні, _vaix
  { {0x2b910023,0xd5750010,0x443813e5,0xa5bb163c}},	//   _sách_, мусь, tur_, uróp
  { {0x61fd00b8,0xb97a000a,0x6459002a,0x7c09000a}},	//   _ausl, _לנסי, _ćwic, מִּ֔
  { {0x61f50024,0x9f4600dd,0x44383acc,0xa2063acd}},	//   _aizl, rmoë_, rur_, зпад
  { {0xc73b0008,0xa5bb016e,0xa6db001a,0x2b910016}},	// [7f60] _התפת, próp, yfði, _vách_
  { {0x44440092,0x60260033,0x44383ace,0xc5ff003d}},	//   _tq_, зджа, pur_, ķēti_
  { {0x2b910092,0xd5e90015,0x2491002a,0x6d583acf}},	//   _tách_, _بعين_, cyzm_, veva
  { {0x20073ad0,0xd00f0067,0xd47b05bd,0x6d413ad1}},	//   ínia_, الن_, _האטל, _acla
  { {0x6fd8002c,0xc33300f3,0x6d583ad2,0xf1bf02e0}},	//   líck, _אור_, teva, _iván_
  { {0x61f501e2,0x24b60008,0x51550da6,0x6d580077}},	//   _gizl, ּהֵן_, _отсу, ueva
  { {0x6d4a1bb4,0x6bd3002b,0x291c00da,0xd47a004c}},	//   rffa, کتور, _reva_, מאַל
  { {0x291c3ad3,0x7bc40007,0x600b000a,0x2bcc000b}},	//   _seva_, čiuo, _לִמְ, ावधा
  { {0x8d1a0074,0xaa530080,0xbc6a0086,0xedd60015}},	//   _هزار_, евыш, _گمان_, _فيرد
  { {0xd90d0086,0x6d41002d,0x7e9b0008,0xd5ed0016}},	//   لیه_, _gcla, _הסמו, _trả
  { {0x07350036,0x2bcc0065,0xaab7009a,0xdce801ec}},	//   меню, ावदा, قدیر_, _modī
  { {0x7ceb000a,0x2907001a,0xf8af0015,0xabfb000a}},	//   _הַדֶ, _efna_, اةٌ_, _ההאר
  { {0x291c08e0,0x645a0064,0xf1cc000b,0xe1ff0016}},	//   _teva_, çtin, ़कान, _trói_
  { {0x24670089,0x61fd3ad4,0xea77000a,0x2491002a}},	//   jímá_, _rusl, _מגדר_, tyzm_
  { {0x38c8002b,0x58d33ad5,0x89db000a,0x98be003d}},	//   _باشی_, _пошт, _החגי, retē_
  { {0x61fd0780,0x58bb0008,0x644700dd,0x88bb0008}},	//   _pusl, _למוצ, rtji, _למוז
  { {0xd2510015,0x68080046,0x6fd80046,0xdd310091}},	// [7f70] ضنا_, _děde, mích, _lęši
  { {0xd1310029,0x660d21a0,0xe7e1000b,0xd6e8000a}},	//   ئما_, _itak, _गीता_, _מַתָ
  { {0xf99300b2,0xe2f90036,0xf8b1000a,0xd1b80015}},	//   ערע_, _мені_, ֣שׁ_, ساكا_
  { {0x63bb0796,0x9ed90180,0xdef10015,0x29050077}},	//   čuns, омет_, نًا_, zcla_
  { {0x8d740086,0xdef80010,0x64dd000b,0x926b067a}},	//   کانا, чых_, _यरुश, _урна_
  { {0xddc9005c,0x660d003f,0x527a000a,0xc27a000a}},	//   _speł, _mtak, _ונשא, _ורשי
  { {0x22493ad6,0xbd480015,0x41d9000b,0x23691b84}},	//   ltak_, سؤول_, _बीएस, odaj_
  { {0xdfd1003b,0xc49c000a,0x23693ad7,0x2bb90015}},	//   _شيء_, משות, ndaj_, غاثة_
  { {0xd9590010,0xeab10029,0x22493ad8,0x9dab006b}},	//   ошні_, ضعة_, ntak_, _лъжа_
  { {0x2fcf02d2,0xf9910015,0x8288000a,0x6d410085}},	//   logg_, ئبة_, לְתֶ, _ucla
  { {0xa3bf005d,0xdb510015,0x236900bc,0x660d3ad9}},	//   ेवा_, _لَا_, kdaj_, _atak
  { {0xbc380002,0xf529000a,0x6be40015,0x22493ada}},	//   _رسما_, _כץ_, _ككلم, ktak_
  { {0xd9450124,0x41bf005d,0xa50a0054,0x07a301f3}},	//   _жели, ्वास, жега_, таян
  { {0xe1ff0050,0x22493adb,0xa3ab000b,0x98b2003d}},	//   _osób_, dtak_, कोस_, ūdām_
  { {0x6db2002a,0x33f600fd,0x224901d7,0x660d3adc}},	//   kłan, дчас, etak_, _etak
  { {0xd8d60053,0xdce8003d,0x6b8b3add,0xdce1005a}},	//   _קוקט_, _sodī, _jogg, _nalč
  { {0x68080089,0x96950010,0xe6c60015,0xd29a005e}},	// [7f80] _věde, _зрэш, _تتغي, цтві_
  { {0x6b8b0078,0x23660085,0xa09a0015,0x765a002a}},	//   _logg, žoj_, يضاء_, łtys
  { {0x757b000a,0x031a0015,0xdfd2002b,0x6fd83ade}},	//   _וטיפ, _وتحت_, پيش_, líci
  { {0x6b8b00c0,0xf4130008,0x9ec6009a,0x130302ed}},	//   _nogg, _שפר_, وزشه, _изюм
  { {0x5e5a0029,0x2bcc000b,0x6fd83adf,0xde760058}},	//   تجاج_, ावसा, níci, بداع
  { {0x6db20050,0x205600a4,0x6f093ae0,0x417a0015}},	//   ałan, _отбр, _efec, _بمسح_
  { {0x6ca3006b,0x798a00aa,0x6f090003,0x6b8b3ae1}},	//   кръж, _rofw, _ffec, _bogg
  { {0x93fb000a,0x2bac002a,0x1ea9002b,0xc0e31bdf}},	//   חלקי, ości_, _کافي_, _роск
  { {0xc333000a,0x6d360015,0x6b8b3ae2,0xfe430499}},	//   דוח_, _يفرض, _dogg, _инто
  { {0xb33b0064,0xc27b00a3,0x6fd83ae3,0x99d60015}},	//   _ilçe, קריי, díci, بتعا
  { {0xe8df0023,0x3137039e,0x01370008,0x224900dc}},	//   _thời_, ונים_, ורית_, ztak_
  { {0x660d005c,0x2d8c00cb,0x6fd800be,0x6b8b3ae4}},	//   _ptak, _hode_, fíci, _gogg
  { {0x4ae2014e,0xaae2000b,0xa6db001a,0xd90e002b}},	//   _परिव, _परिक, yfðu, _پیج_
  { {0x28cf014e,0xa5bb002e,0xdcfa005c,0xe8df0092}},	//   _सुवि, msók, _potę, _giỏi_
  { {0xa4d40036,0x28c6000b,0xf957000a,0x2957000a}},	//   ворі, _रुचि, _חסות_, _חסוך_
  { {0x22493ae5,0x69da3ae6,0x2d8c3ae7,0x672d3ae8}},	//   ttak_, llte, _lode_, _udaj
  { {0xa3ab014e,0xe8df0023,0x45d515ed,0x660d0f58}},	// [7f90] कोष_, _khởi_, _поис, _utak
  { {0x3ea60024,0xe5e700e6,0x2007001c,0xa3e4000b}},	//   dzot_, _تثبي, ínio_, _पीठ_
  { {0x55760053,0x99840091,0x95830091,0xe588000a}},	//   _װערן_, lumų_, žąsi, _חָרָ
  { {0x2d9e274c,0x69da00b8,0x671f000b,0x9f050015}},	//   _alte_, hlte, परिक_, روتو
  { {0x1d090155,0x2d8c3ae9,0x6b8b3aea,0x539a004f}},	//   пели_, _bode_, _rogg, _זירו
  { {0x7bc2038d,0x6db20050,0xa3ab005d,0x6b8b04ed}},	//   _ajou, słan, कोर_, _sogg
  { {0x6fd8163c,0x351c000a,0x6db2002a,0xeb99033d}},	//   zíci, חוונ, płan, зий_
  { {0x99d5002b,0x69da2036,0xea89033d,0xbbe80067}},	//   کتبا, elte, збил_, وريم_
  { {0x3e350002,0xddc90045,0x6e9902ed,0xa5bb01d3}},	//   _سفار, _creţ, _эвар_, rsój
  { {0xdd150015,0x2d8c0cbb,0x8d77012c,0xc27a000a}},	//   _أواخ, _gode_, _تارا, פרתי
  { {0x2bcc005d,0xf7463aeb,0xe9a80040,0x6b8b3aec}},	//   ावशा, нено, بدين_, _togg
  { {0x6fd8122a,0x2bac005c,0x2d8702c6,0xc8920015}},	//   tíci, yści_, ljne_, الَة
  { {0x9f960008,0xf6d50036,0x98be0007,0x99840091}},	//   גדרה_, віря, ketė_, gumų_
  { {0xaab80015,0x6fd83aed,0xb5fb0030,0x8a160004}},	//   _تدمر_, ríci, evás, _џојс_
  { {0x64a6008f,0x68080089,0x2edc000b,0x6fd80046}},	//   хава, _vědc, _बर्त, síci
  { {0x86460036,0xe8d6000a,0xa3ab000b,0xdce80046}},	//   _зниж, _אוצר_, कोल_, _andě
  { {0x211a0029,0x5a0c0053,0x52aa006b,0x7bdb008c}},	// [7fa0] كتاب_, ַלאַ, чвам_, iluu
  { {0xf653000a,0x2bac002a,0xb5fb3aee,0x3f5a00a1}},	//   _עצת_, rści_, rvát, _ẫu_
  { {0xe8df0092,0xd00f0018,0x2d8c05d6,0xe58b000a}},	//   _khối_, ملل_, _rode_, _זָכָ
  { {0x6db2005c,0xc334000a,0xa8a8000a,0xcfa9002b}},	//   ałal, _בוֹ_, וֹנִ, وانم_
  { {0x2d8c03af,0x76410007,0xa3bf000b,0x69da0804}},	//   _pode_, ąlyg, ेवर_, ylte
  { {0x63b63aef,0x3ea63af0,0x63a43af1,0xf9870058}},	//   liyn, rzot_, lhin, _صب_
  { {0x71d70008,0x3fc8002b,0x2d8c0c1a,0x8fa60a13}},	//   _נולד_, _قدری_, _vode_, _заве
  { {0xddc90011,0x63a40a4c,0x69da00b8,0x8f000010}},	//   _preţ, nhin, wlte, аiх_
  { {0x2d8c00b8,0x8fa30684,0x672601d7,0x5e78000a}},	//   _tode_, _сате, dakj, _קָֽד
  { {0xddc90011,0x7a5300e6,0xd917004a,0x442a01c2}},	//   _vreţ, اضيا, нью_, ksb_
  { {0xc19b000a,0xb3b80065,0xb5fb01d3,0x610f01d3}},	//   פשטי, ्कफ़्, jvár, lőlü
  { {0xe8df0092,0xc053000a,0x4c9b000a,0xcb160015}},	//   _chối_, נזר_, _משבע, _أذاع
  { {0x63a4003f,0xd6db1fdb,0xeb97004a,0xebe30342}},	//   dhin, ято_, _яиц_, _соцп
  { {0xa6db002e,0xca7b000a,0x99840091,0xda7b000a}},	//   ggða, _מנדט, rumų_, _מנדר
  { {0x6fd802c1,0xa3bf005d,0xa96700d7,0x3c54000a}},	//   lícu, ेवल_, _чија_, כֹּל_
  { {0xa3ab014e,0x6c7b0053,0x7bc0003c,0xd80b0008}},	//   कों_, האלפ, nnmu, _צִוָ
  { {0x2d87005c,0x4438002d,0x8b570053,0xdcfa0046}},	// [7fb0] yjne_, arr_, עימס_, _potě
  { {0x63a40035,0xb6bc000a,0x690b000a,0x6519002b}},	//   ahin, _מצחי, ִּבְ, _تقدس_
  { {0x81440086,0x6fd802c1,0xa3ce005d,0x63a420d9}},	//   انمن, hícu, शकश_, bhin
  { {0x2a660089,0x6db2002a,0x50640033,0x33950033}},	//   _osob_, słal, ытуа, _рамё
  { {0x8e080036,0xaf040010,0x7ed40010,0x92940010}},	//   енів_, упіл, лішч, _баяц
  { {0x395e0152,0x200e0144,0x6fd80fa1,0x3d8b0a32}},	//   jets_, ífic_, dícu, ящен_
  { {0x395e3af2,0xcd280040,0x6fd8016e,0x7c2a3af3}},	//   dets_, رسون_, eícu, gsfr
  { {0x447c000a,0x27e90016,0x7d26003d,0x2b910030}},	//   לנוע, _nhan_, _ārsū, _rács_
  { {0xab760029,0x395e0999,0x8afd0046,0x78a80030}},	//   ئمًا_, fets_, ndři, ezdv
  { {0x7bdb0084,0x7bc000f2,0x645a0064,0x395e28e4}},	//   sluu, anmu, çtik, gets_
  { {0xddc9016f,0xe8df0092,0x07a6202c,0x63a40061}},	//   _greš, _phối_, ванн, yhin
  { {0x2918002e,0x00f60008,0x27e93af4,0xab5d002a}},	//   ðrar_, כמתך_, _chan_, rożs
  { {0x16630063,0x6d4300dc,0xfa370015,0x9f460012}},	//   авям, ogna, _أرصد, hloß_
  { {0x6d4300b6,0xceb201d8,0x2606001c,0xf8690015}},	//   ngna, שיך_, _vôo_, _يمشي_
  { {0xb5fb002c,0x98a20036,0x63a43af5,0x8d48000a}},	//   tvár, _вище, thin, עֲשֵ
  { {0x6b8900bd,0x04430001,0x6fd8002c,0xdb000003}},	//   njeg, јетн, níct, thmé
  { {0xb5fb0030,0x4438002a,0xb1460190,0x69c100c7}},	// [7fc0] rvár, srr_, кнал, onle
  { {0xd5af003b,0x63b60176,0x6db2005c,0x69c13af6}},	//   _وفي_, siyn, ałaj, nnle
  { {0x657e002d,0xd59b0008,0xcf8f00d7,0xf2c9000a}},	//   _inph, _חביל, ај_, קע_
  { {0x6604003f,0xd00f0002,0x90e50015,0xaf360015}},	//   _kuik, زله_, اسكن, ئرات
  { {0x7f830015,0x7e540015,0x6db2002a,0xf773015b}},	//   شلون, انتص, słam, יקא_
  { {0xdd8f0070,0xde930001,0x6d4300c0,0x6b8900dc}},	//   يون_, рашњ, ggna, ejeg
  { {0x75e000dc,0x6c840021,0x395e0d3d,0xe055009a}},	//   vözl, العم, vets_, _میلت_
  { {0x6fd80782,0xafe60036,0x6b8900dc,0xfbcf00e6}},	//   tícu, _робл, gjeg, يتي_
  { {0x27e90176,0x60270014,0x7d0f0016,0x61fc0061}},	//   _rhan_, _témá, _đcsv, _kirl
  { {0xddc93af7,0x69c1002e,0xec7a005e,0xddc2002a}},	//   _treš, gnle, _опз_, stoł
  { {0x6b89016f,0xa3e2005d,0x27e90b19,0xad1b000a}},	//   bjeg, धता_, _phan_, _חובר
  { {0x75e00061,0xe817002b,0x66040079,0x644e0012}},	//   sözl, کزیت_, _buik, dtbi
  { {0x395e3af8,0x0000006a,0x0000006a,0x0000006a}},	//   pets_,   ,   ,
  { {0xe5c40080,0x224000dd,0x6e200034,0x66042b99}},	//   ассо, duik_, _mwmb, _duik
  { {0x752700dc,0x27e90388,0xd4040229,0xb33b3af9}},	//   rajz, _than_, ияти, _alça
  { {0xd8e50033,0x61fc39a0,0x200301c2,0xf7730058}},	//   _сціп, _airl, _ruji_, _ضاع_
  { {0x61fc01e2,0xe5c73afa,0xd6d10015,0xc6f9005e}},	// [7fd0] _birl, _асно, _دقة_, _яних_
  { {0xb114005e,0x61bf000b,0x11d90015,0x200307c8}},	//   имуш, ्वेष, رواة_, _puji_
  { {0x351a0008,0x68010024,0x05b8002b,0x90450015}},	//   _אותנ, _pēdi, _جديت_, انصه
  { {0x6fd40036,0xff530115,0xff25002b,0x61fc0034}},	//   аціє, شخص_, ابای, _eirl
  { {0xdd9504ab,0x69c13993,0x61fc3332,0xdfb8006e}},	//   лады, ynle, _firl, خالص_
  { {0xdce801e2,0xb6da00b2,0x61fc08b8,0xdd9b03e7}},	//   _aldı, ײַנט, _girl, ьше_
  { {0xfd440010,0xabd503ae,0x6b893198,0x6f0400bc}},	//   рэчн, лциј, tjeg, žica
  { {0xdfd50080,0x2d9c0085,0x5f941045,0x69c10702}},	//   _собы, akve_, _кист, wnle
  { {0x6e200034,0x67243afb,0x1ad50138,0x6b893afc}},	//   _gwmb, _reij, ыўкр, rjeg
  { {0xef26007c,0x69c10125,0xa035000a,0x6b893afd}},	//   _üüri_, unle, ְאָה_, sjeg
  { {0x6aa900dc,0x68450010,0x66043afe,0xdb090123}},	//   szef, ынна, _suik, tieä
  { {0x66040007,0x9056000a,0x4fd5004f,0x6ca40d3c}},	//   _puik, נברו_, רוֹב_, _труж
  { {0x1a65002b,0xd764002b,0xba74002b,0x9b740021}},	//   _صیدی_, هنگی, _پانت, _خالص
  { {0x26de0024,0x6603077a,0x1dc3000b,0x04460aed}},	//   āto_, спра, वचित, легн
  { {0x64a3327e,0xc952000a,0x2618000b,0x644e0123}},	//   бара, _המו_, बीजी_, utbi
  { {0x38780134,0xe514000b,0xdcf80046,0x6604014b}},	//   ærre_, _त्रि_, ejvě, _tuik
  { {0xade3014e,0x3a2d034c,0xc7b3000a,0x70be000b}},	// [7fe0] गतान_, nsep_, _לבה_, ्थ्ल
  { {0xd5ed0092,0x2240049c,0xc5660076,0xc4863122}},	//   _trá, ruik_, _скок, _блок
  { {0x94760029,0xb5f70008,0xa99a004c,0x85f7000a}},	//   _إدخا, _תציג_, עבער, _תציע_
  { {0xdd2f0089,0x8f45005e,0xd0070033,0xe8d6004c}},	//   měři, ихід, уеце_, אוער_
  { {0x94760086,0xc7d70008,0x61fc0034,0x7e690307}},	//   _شدگا, נוני_, _tirl, _csep
  { {0x61fc017e,0x01da0015,0xdb00007c,0x60dc008c}},	//   _uirl, _أوسع_, simü, _tyrm
  { {0xa5bb3aff,0x2d9c0820,0x0704000b,0x98be003d}},	//   msót, rkve_, रखाव_, retī_
  { {0x5a3411fe,0x0ba30033,0x2d9c0c1a,0xab940054}},	//   анит, йшым, skve_, раиљ
  { {0x6f930029,0xdee32246,0xaec602ed,0x0000006a}},	//   _القض, _готи, _сбал,
  { {0x1a570015,0x996607ec,0x1d190138,0x0000006a}},	//   اشية_, утил, _аюць_,
  { {0x68080089,0x81570053,0x61d70053,0x23bf00f2}},	//   _vědo, נסטע_, רויף_, näjä_
  { {0xb8ec005d,0x5ba5005e,0xf6750033,0xdb00016e}},	//   _रख_, _кріз, агмэ, rimó
  { {0xba730015,0x0bd3009a,0x96f802ed,0x07a40138}},	//   _هاوت, _اينح, леют_, саўн
  { {0xad9d005c,0x8afb000a,0x2bcc000b,0xcad7004f}},	//   _luźn, _נהגי, ावका, _עוגת_
  { {0x2c34000a,0xb80b000b,0xf4840fea,0x4d7b004c}},	//   יָּם_, _संयम_, бутн, ערלע
  { {0xc2c5003b,0x28490053,0xdc8b000a,0x987b015b}},	//   ليزي, _סעפּ, תְךָ, _טרוק
  { {0x8afd0046,0x75e00030,0xd13b098b,0x0000006a}},	// [7ff0] peře, közh, ехе_,
  { {0xf654004f,0x0000006a,0x0000006a,0x0000006a}},	//   _הצץ_,   ,   ,
  { {0x45fa0008,0x15fa000a,0x6e3c003d,0x3d08000b}},	//   _שהתג, _שהתע, _ārba, िखने_
  { {0xe8d7000f,0x0eb902bf,0x58bb004c,0x7f27006e}},	//   נואר_, кулы_, עמאצ, اءال
  { {0xda660015,0x623500af,0x0000006a,0x0000006a}},	//   _بُ_, _његу,   ,
  { {0xa3bf000b,0xed593b00,0x51871d3b,0xc6b8004f}},	//   ेवक_, ток_, _сума, נהגי_
  { {0x9626003d,0xfce50004,0xbb45009b,0x0000006a}},	//   _ziņā, шоко, аейк,
  { {0x69c600dc,0x6fd8006f,0xab620072,0x0000006a}},	//   éken, sícr, üüpi,
  { {0x49c93770,0x0000006a,0x0000006a,0x0000006a}},	//   клин_,   ,   ,
  { {0x4995107c,0x0000006a,0x0000006a,0x0000006a}},	//   ршит,   ,   ,
  { {0xdd7a00b2,0x3854004a,0xdb000144,0xc68905bd}},	//   _שטעל, бъяс, rimò, _קא_
  { {0xdd2f0089,0xc5e9000f,0xe9ff0016,0x8c1a004f}},	//   věři, _חד_, huẩn_, _יועי
  { {0x959601c6,0xd876002b,0xa3e90065,0x0000006a}},	//   ашві, همیت_, यतन_,
  { {0x69070010,0x7ae60061,0xc4c60015,0xd9420d3e}},	//   _сядз, ükte, لتزو, _деши
  { {0x07a60010,0xe8df0016,0x232a1797,0x19ba000a}},	//   _вайн, _phổi_, кови_, _שמצב
  { {0xda080092,0x02c60033,0xd25200c3,0xe4c3005e}},	//   _hỏa_, айбо, ينز_, ійти

  { {0xe297019c,0x6db2005c,0x99dd01c9,0xb5da0015}},	// [8000] аат_, cław, stňu, _لبدء_
  { {0x23bf022d,0xdce1005c,0x21280086,0x869b004c}},	//   täjä_, _zalą, ايای_, _סייז
  { {0x71730029,0x11d70029,0x653b000a,0xb53b000a}},	//   تهلا, جولة_, _בעיד, _בגיש
  { {0xdfcf0196,0xc2c60029,0xe29f001a,0xf3ff0016}},	//   ويل_, _نيجي, _afðu_, _giã_
  { {0x3ea03b01,0xd337000a,0x9757000a,0xcfaa009a}},	//   áit_, _דרכה_, שינו_, _یارم_
  { {0x6e360007,0xb4e0000b,0x6c340015,0xad660058}},	//   šybo, _तरफ़_, مفتا, شاته
  { {0xbc670029,0xdc870063,0x3ea00089,0x4c940080}},	//   لمون_, исъл_, šit_, сийс
  { {0xa5bb016e,0xdb5a005e,0x6e2b0030,0xbe16002b}},	//   nsór, тюк_, ülbí, _نورع
  { {0xe8d90023,0xaab8002b,0xa9c631f2,0x2fc60085}},	//   _đỡ_, دگار_, исок, mnog_
  { {0x2fc6010b,0x98be0024,0x645e34fa,0x3257000a}},	//   lnog_, egtā_, _oppi, ססים_
  { {0xdb240086,0xab660a61,0xc19b000a,0x7189000a}},	//   _هوای, _ввел, דשיי, רְפַ
  { {0x2fc60026,0x4c9b000a,0x97c40015,0xcb6a0004}},	//   nnog_, _שבאו, ْقَو, _јаде_
  { {0xa507005e,0xf98f002b,0xc9c8002b,0x195801b0}},	//   иявл, سبی_, _مژده_, _балы_
  { {0xda7b000a,0x99d30015,0x2b980003,0xddc9006f}},	//   _שנגר, _وتوا, _vécu_, _treť
  { {0x89370008,0x6db2005c,0x6616005c,0xe5c80010}},	//   _כרגע_, sław, _etyk, рыял_
  { {0xf6990074,0x248d016f,0x7afd002c,0x2fc6016f}},	//   _منبع_, ćem_, ľstv, jnog_
  { {0x2fc6010b,0x6d5a003e,0x6b820a00,0x7afd0227}},	// [8010] dnog_, _obta, _mnog, žstv
  { {0xd5b803e7,0x865a000a,0x7583009a,0x11d400ce}},	//   _всю_, _עדתי, _بیسم, оієр
  { {0x6b82016f,0x997d0046,0xa3d50248,0x2fc6233b}},	//   _onog, zňů_, _гонч, fnog_
  { {0xd8b90053,0x02d90087,0xa857000a,0x6d5a0012}},	//   נצײכ, _موجب_, שיאה_, _abta
  { {0x443100dc,0xdb090046,0x6e6706b9,0xfe080058}},	//   lsz_, áníc, ртеж, لقني_
  { {0x69c600dc,0x10170086,0x9474002b,0xaaca000b}},	//   ékel, _نبرد, _ادیا, ापनक
  { {0xc5380008,0x4c920001,0x2fc6016f,0xa3ae000b}},	//   שָׂה_, зијс, bnog_, _कतम_
  { {0xc17e0007,0xdfd40010,0xc052039e,0xa3d7000b}},	//   šėte_, _досы, _מזל_, ाकि_
  { {0x29180064,0xe9d90734,0x0000006a,0x0000006a}},	//   ıran_, лки_,   ,
  { {0xd9450001,0xa9690001,0x31710738,0x2b980030}},	//   љени, ћина_, _jazz_, _bécs_
  { {0xa3d7005d,0x3c440015,0x66163b02,0x4431002a}},	//   ाका_, _وَكِ, _styk, jsz_
  { {0x3878002e,0x443100dc,0x6008000a,0x997d0046}},	//   ærra_, dsz_, יִשְ, pňů_
  { {0xeab3003b,0x44310eba,0x9c7c0227,0xba190015}},	//   _بعض_, esz_, _vyče, _صيغا_
  { {0x201a022d,0x2fc6016f,0xb21b02de,0x0000006a}},	//   yppi_, znog_, _kræf,
  { {0x443100dc,0xe4da0015,0x28cf000b,0x9c29000a}},	//   gsz_, اوزت_, _सुचि, טֵּ֥
  { {0x68130045,0x73061c55,0x389a000a,0xf772006e}},	//   _căde, спаз, _תיקנ, _راب_
  { {0xa3d7014e,0x2fc6010b,0x4431005c,0x68130045}},	// [8020] ाक़_, vnog_, asz_, _dăde
  { {0xe2450015,0xa5bb016e,0x0000006a,0x0000006a}},	//   تخفي, ssór,   ,
  { {0xc2090008,0x2fc6016f,0xef1a0001,0x2252005c}},	//   תה_, tnog_, гме_, styk_
  { {0x4386003b,0x7f460010,0x80250015,0xdb240061}},	//   _الحق, седж, تركم, ürüy
  { {0x7e560036,0x2fc6016f,0x529a006b,0xe7db004f}},	//   стец, rnog_, _съня_, נקנש
  { {0xd5b30008,0x2fc63b03,0xd47a000a,0xdb020003}},	//   ּׁה_, snog_, ָאֵל, _cloî
  { {0x3cf4005d,0x409600e6,0x2fc6016f,0x93fa000a}},	//   ेखें_, _الزر, pnog_, ְלִי
  { {0xa09b0053,0x764600f2,0xa037000a,0x79830034}},	//   _גילט, kuky, _לאלה_, _annw
  { {0xa92a0010,0xcb670001,0x0bb50086,0x539b00f3}},	//   ліне_, сање_, تجوگ, טיקו
  { {0x4431005c,0x7dc60015,0xb1160033,0x200a06c0}},	//   ysz_, _اترك, апiц, _kubi_
  { {0x3bd60839,0x1d17000a,0xec130040,0x22403b04}},	//   _людс, _הקבר_, _فولد, hrik_
  { {0x65ab08f5,0x96f904b9,0x478b01eb,0xe67900ce}},	//   _mühe, иент_, усом_, аймі_
  { {0x65ab0020,0x36d5005e,0xa302000b,0x200a002a}},	//   _lühe, іогр, लखोज_, _lubi_
  { {0xe5c70080,0xceb30053,0x443100dc,0xa2cc000b}},	//   ссмо, ליר_, tsz_, _सख़्
  { {0xe8d90023,0x200a04ed,0x28020046,0x69c80123}},	//   _đủ_, _nubi_, ísně_, mnde
  { {0x69c800b8,0xb4e9000b,0x67d4006b,0x69da3b05}},	//   lnde, _बरी_, _нощу, lote
  { {0x91b90063,0x443100dc,0x672f005c,0x4b7b004c}},	// [8030] агат_, ssz_, macj, נאמו
  { {0x672f0050,0x64410251,0x9f583b06,0x443113c3}},	//   lacj, àlis, _gurú_, psz_
  { {0xe5880008,0x63a30045,0x644100e1,0xc1e801c5}},	//   _הָרָ, _înno, álid, сьте_
  { {0x672f005c,0xce190010,0xcfab0015,0x8f340033}},	//   nacj, ацкі_, دائم_, зецц
  { {0x63ad002f,0x867c0053,0xdce80024,0x68080089}},	//   mhan, ָרוו, _radā, _dědi
  { {0xd6580008,0xdb1b0064,0xb21b0134,0x63ad3b07}},	//   ציות_, onuç, _præf, lhan
  { {0x672f0050,0x69da3b08,0xbca50015,0x200a0e2a}},	//   kacj, dote, تمثي, _gubi_
  { {0xdb000005,0xaf370086,0xeb993b09,0xcf27002b}},	//   himõ, _درست, рии_, _درآي
  { {0x672f005c,0xbfa805b3,0x64471437,0x69da3b0a}},	//   dacj, _утре_, huji, fote
  { {0x6447003f,0x63ad0519,0x499903ad,0xb21b063b}},	//   kuji, hhan, ртия_, _træf
  { {0xa3e9014e,0x77ca0180,0xb21b001a,0x63ad3b0b}},	//   यता_, илог_, _fræg, khan
  { {0xfe670074,0x672f0050,0x8b670806,0x9986005c}},	//   ود_, gacj, _دائم, _ktoś_
  { {0x6db2005c,0x75e000dc,0xa3d8000b,0xcf56000a}},	//   płat, közt, िवस_, חברת_
  { {0x22400061,0x67c40030,0x98a5053b,0x69da3b0c}},	//   vrik_, dője, _миле, cote
  { {0xe8850036,0xc3960001,0x98a50024,0x64a6070e}},	//   _єгип, ојањ, balā_, цава
  { {0x42260063,0x63060086,0x7bc9211c,0x63ad3b0d}},	//   ждав, زوئل, nneu, ghan
  { {0xa3bb005d,0xf11a0029,0x764b00b8,0x200a1d2c}},	// [8040] _अगर_, لغات_, _ägyp, _subi_
  { {0x65ab0020,0x42550457,0x45460015,0xf1aa006e}},	//   _pühe, ятст, _بندق, جاره_
  { {0x13a80086,0x106a0080,0x32270089,0x6026005e}},	//   _هندی_, рией_, _čtyř_, ідда
  { {0x69da003f,0x68e3158b,0x63ad2bb8,0xe3b2002b}},	//   zote, _mynd, chan, _آرد_
  { {0xa3d7005d,0x69c600dc,0x2007002e,0x69da3b0e}},	//   ाकर_, ékek, ínir_, yote
  { {0x672f0050,0xddb70010,0xa2d3005d,0x6441002c}},	//   zacj, огіі_, _भुट्, šlie
  { {0x8fa6008f,0x6d4a2061,0xfbaa005e,0xb21b02de}},	//   _даве, rgfa, итий_, _præg
  { {0x7bc90152,0x5b260010,0x63a40472,0x69c80e18}},	//   gneu, цька, nkin, wnde
  { {0xaa660036,0x69da3a15,0x539b000a,0x63a43b0f}},	//   ітик, tote, שיפו, ikin
  { {0x7ae2000c,0xb2bb0008,0x672f005c,0xad250086}},	//   _vyot, ימפר, wacj, _فرمو
  { {0x672f005c,0x69c800b8,0x63ad002c,0xcc360015}},	//   tacj, rnde, yhan, _ذراع
  { {0x290700c0,0x63a40111,0x6447003f,0x27f20034}},	//   _egna_, jkin, vuji, _chyn_
  { {0x672f0050,0xfa55002b,0x69da3b10,0x3ffb004c}},	//   racj, _فروگ, pote, יפטע
  { {0x1dbc000b,0x63a43b11,0x3e5e003d,0x661d3b12}},	//   ्चित, ekin, mātā_, rpsk
  { {0x63ad017e,0x7bc00020,0xe4e4005e,0x672f002a}},	//   than, oimu, дітн, pacj
  { {0x52150b03,0xb8e0005d,0x20043b13,0x7bc03b14}},	//   здат, ूप_, _nimi_, nimu
  { {0xd6280001,0x3e5e0024,0x63ad3b15,0x645506a8}},	// [8050] _доње_, nātā_, rhan, stzi
  { {0xddc20050,0x63a43b16,0x63ad3b17,0x3f770016}},	//   rtoś, akin, shan, _ểu_
  { {0x35f80029,0xddc2005c,0x2eed005c,0x7bc01a91}},	//   _بريد_, stoś, _szef_, kimu
  { {0x7bc000df,0x86080086,0x63a43b18,0x93470015}},	//   jimu, _دقیق_, ckin, _بخدم
  { {0xab5d0050,0xa77c0053,0x7bc003b7,0xa3e4000b}},	//   niże, יראפ, dimu, _पीट_
  { {0x98a504f9,0xcddb0001,0x7bc90026,0xfd110015}},	//   nală_, шње_, wneu, رجت_
  { {0xdd8e0029,0xb4e9000b,0x8d74002b,0x6605007c}},	//   اوى_, _बरो_, بانا, _mihk
  { {0xb21b0134,0xdb4e0015,0xe1ff002a,0x672d0045}},	//   _træd, هَى_, _psów_, _neaj
  { {0xa2c1000b,0x5e440015,0x68e33b19,0x7bc93b1a}},	//   लपट्, _يَفْ, _synd, rneu
  { {0x314b0008,0x27e00ce4,0x9c870015,0xae44002b}},	//   ׁתִּ, _skin_, _وشاه, _آپلو
  { {0xb33b0061,0xf6490c44,0x7bc0007c,0x18690c30}},	//   _elçi, _תצ_, bimu, щани_
  { {0x3e5e0024,0xf77200e5,0x0b780015,0xdce310cd}},	//   bātā_, راج_, _وصنع_, nenč
  { {0xa3c1005d,0xddc9065d,0xaac70067,0x68e304a9}},	//   ्चन_, _mrež, _بتان, _wynd
  { {0x98a50011,0xdb00001c,0x63a42fda,0x68e33b1b}},	//   gală_, rimô, wkin, _tynd
  { {0x07a60001,0x49b8002b,0x69c13b1c,0x63a43b1d}},	//   _накн, _باند_, mile, tkin
  { {0x883a0008,0x130a0010,0xccf2000a,0x63a43b1e}},	//   _התקו, снай_, תכל_, ukin
  { {0xc64a0029,0x98a50045,0xdb000012,0xfbd2000a}},	// [8060] _اجعل_, bală_, chmä, גתן_
  { {0x98a50011,0xb6bb0008,0xab5d005c,0x867b0135}},	//   cală_, _לצפי, roży, _פריו
  { {0x859b0008,0xa0670063,0x69c600dc,0x759b009d}},	//   _השיו, заха_, ékei, _הייח
  { {0xb21b0134,0xab5d002a,0xdce8002a,0x6e93002b}},	//   _dræb, poży, _jadą, کلها
  { {0x7bc000df,0x69c10562,0xc7b30008,0xff031070}},	//   vimu, kile, עבד_, няшн
  { {0x69c10064,0x3e5e003d,0x865b05bd,0x29180061}},	//   jile, vātā_, מדני, ırak_
  { {0x69c13b1f,0x7bc03b20,0x9b9404c5,0x0000006a}},	//   dile, timu, дийц,
  { {0xdb00022d,0x30570008,0x9057000a,0x0f34002b}},	//   yhmä, _משלך_, _מבלו_, _آکاد
  { {0xadc300a7,0xe9440086,0x6e290026,0x9d461006}},	//   _quản, وردی, _gweb, _неад
  { {0x69c10562,0x7bc03b21,0xd29b000a,0x3e5e01ec}},	//   gile, simu, משפט, rātā_
  { {0x660d0007,0x7bc009e2,0x98a50045,0xad1b004f}},	//   _suak, pimu, vală_, _הובר
  { {0x65b000f2,0xeb9718a9,0x69c11740,0x37ab2fff}},	//   _lähd, _них_, aile, стон_
  { {0x98a50011,0x8ae30036,0x69c13b22,0xcb070015}},	//   tală_, _пішл, bile, _عيون_
  { {0x65b0022d,0xf9c40086,0xaa3b0008,0xceb3000f}},	//   _nähd, _تحصی, _פתוח, גיש_
  { {0x98a50011,0xe7e8000b,0xd3a70033,0x6605019a}},	//   rală_, _टीका_, прап, _vihk
  { {0x443f3b23,0x8c1b000a,0x1819009a,0x439402ed}},	//   ču_, מולי, _بروک_, насс
  { {0xc73c0008,0x98a50011,0xe2f80036,0x2167006b}},	// [8070] _התחת, pală_, зеті_, зтег
  { {0x67d20024,0xb1d40058,0x0000006a,0x0000006a}},	//   māja, ّيْث,   ,
  { {0x80140036,0x155a000a,0x8f990015,0x67d2003d}},	//   ефіц, _וכתב, ينئذ_, lāja
  { {0x69c13b24,0x60f8005e,0x63bd0052,0x0000006a}},	//   zile, їнця_, _umsn,
  { {0x69c10064,0xee380127,0x6ee70015,0x67d2003d}},	//   yile, зні_, أسال, nāja
  { {0xe678000a,0x8d54006b,0x7ed40067,0xfce513d0}},	//   פתוח_, етъч, رزنا, моло
  { {0x8d74002b,0x24f7000a,0x69c13b25,0x224f0073}},	//   عاها, הֶ֗ם_, vile, šokę_
  { {0x67d20024,0x98a50007,0xa2c2000b,0x69c1002a}},	//   kāja, nalą_, _रेड्, wile
  { {0x75e000dc,0x69c13b26,0x5d55131f,0xde5900ce}},	//   közp, tile, _окат, _фазі_
  { {0x67d20024,0xbe64002b,0x09f60015,0x0000006a}},	//   dāja, _سهمي, وفية_,
  { {0x69c10482,0xe3c201e2,0x4b550063,0x98a50091}},	//   rile, lmış_, _жълт, kalą_
  { {0x08d40010,0x69c13b27,0x907a000a,0xcb690015}},	//   эцыя, sile, קטרי, _ذمته_
  { {0xe3c201e2,0x65b03b28,0x78a12652,0xb9b5006b}},	//   nmış_, _lähe, sylv, _оскъ
  { {0x65ab0020,0x9c7c00bd,0x8afa000a,0xbafa000a}},	//   _püha, _izčr, _והני, _והנש
  { {0x660303a9,0x65b00a83,0xf992000a,0xa5071e64}},	//   тпра, _nähe, _ברג_, дера_
  { {0x25b40007,0x67d20024,0xe3c20061,0x9f4600aa}},	//   _šalį_, bāja, kmış_, rloë_
  { {0x8afa0053,0x67d2003d,0xd5b20040,0xe6ac003d}},	// [8080] ַלעז, cāja, _لفظ_, _ērķē
  { {0x31a400dc,0x65ab0012,0xa0a601ca,0x71660015}},	//   _közi_, _hühn, мазд, بارك
  { {0xb21b0134,0x65ab0012,0xd12f006e,0x98a50091}},	//   _præc, _kühn, شمن_, balą_
  { {0x201c0024,0xdfd200e5,0xa3e9000b,0x2fd70015}},	//   īvi_, خيص_, यतः_, وولد_
  { {0x65b000f2,0xc333000a,0xaff70015,0x42d6005e}},	//   _tähd, _בור_, ذفها_, _ціну
  { {0x21ef007c,0xd6e9004f,0x6cd6009a,0x0000006a}},	//   püha_, הַצָ, وقشا,
  { {0x91030080,0x70560015,0x82fa002b,0x1d070054}},	//   _апре, _تنزا, _درگز_, мељи_
  { {0xda080023,0x8aa60036,0x69cf0152,0x67f6006f}},	//   _hỏi_, дрод, écen, nájd
  { {0x2614007c,0x65b00012,0x290a00bc,0x8cbe0065}},	//   _näo_, _zähe, žbam_, _वेरो
  { {0x67d20024,0xd90d0086,0x5e9b0008,0x6e9b000a}},	//   vāja, میه_, _ובמק, _ובמח
  { {0xbca60086,0x7640002e,0x65ab0012,0xda080016}},	//   _تماي, ámyn, _bühn, _mỏi_
  { {0x67d20024,0x8b230033,0xc7bb0033,0xf7950033}},	//   tāja, _адце, іён_, хамэ
  { {0x07a40010,0xabfb000a,0x1bfb000a,0xd6db006b}},	//   таўн, _והאר, _ולאב, юто_
  { {0x58d4006d,0x28140015,0x442b0033,0xdcfa003d}},	//   _полт, _كوتس, жцам_, _notī
  { {0x7c380111,0xab5d002a,0xe3c20061,0x89db004f}},	//   nsvr, liża, zmış_, _וחגי
  { {0xcc77000a,0x62090015,0x466b1377,0x8bf8000a}},	//   וגלת_, كْرِ_, _дром_, לִּפ
  { {0xdce30024,0x6234005e,0xab5d002a,0xd2510015}},	// [8090] ienā, кету, niża, طنا_
  { {0x2a6600d9,0xd13100e6,0x51f804ab,0x30eb006b}},	//   _mpob_, اما_, дную_, офен_
  { {0x753523ac,0x9f9c001a,0xa0c40015,0xda080016}},	//   mazz, tíð_, نيكو, _cỏi_
  { {0x65b00458,0x78fb0053,0xa295042b,0x75353b29}},	//   _vähe, קלאפ, _замі, lazz
  { {0x59de014e,0x85b80086,0x9f9c001a,0xdf360015}},	//   नकार, _رایس_, ríð_, ركوت_
  { {0x65b00005,0x62340001,0xe3c20061,0x75353b2a}},	//   _tähe, _јеру, rmış_, nazz
  { {0xe0e40010,0xfce2000d,0x75351c75,0xc0c80054}},	//   _аўто, лошо, iazz, _жуте_
  { {0x6aca005d,0xe3c20064,0x9f580077,0x798a0034}},	//   ापूर, pmış_, _duró_, _anfw
  { {0xeab10029,0xc9550256,0x99580046,0x9f580030}},	//   طعة_, нтны, láři_, _euró_
  { {0xf991003b,0xf1b20053,0x7bdc0030,0x75353b2b}},	//   ابة_, ָסט_, _írun, jazz
  { {0xfc30003b,0xdb510029,0x99580089,0xa3c1021e}},	//   _نحن_, _مَا_, náři_, ्चा_
  { {0xe0d20053,0xd77600e6,0xbb840015,0xc5e9000a}},	//   רײט_, راجع, _للمي, _הד_
  { {0x23ae0084,0x98c40024,0xa683202c,0x6b8b1177}},	//   _nýja_, ītām_, гляд, _ingg
  { {0xceb23b2c,0xf9c72031,0x753504ed,0x1a9a004c}},	//   נים_, _ющен, gazz, _מינע
  { {0xdb0b3b2d,0xab62007c,0x99580046,0xb956000a}},	//   _algé, üügi, jáři_, _ניקח_
  { {0xae0f000b,0x67d2003d,0x2407012e,0x0000006a}},	//   ादान_, mājo, енси_,
  { {0xe8df0023,0x65ab00b8,0x20110045,0xb7d30015}},	// [80a0] _khỏi_, _kühl, _auzi_, _حقيب
  { {0x99e9004f,0x0000006a,0x0000006a,0x0000006a}},	//   פַּ֥,   ,   ,
  { {0x25a500f2,0x65ab0359,0x67d2003d,0x99dd006f}},	//   ölle_, _mühl, nājo, hrňo
  { {0x3878002e,0x644e0024,0xa3ba002b,0xe3d60015}},	//   ærri_, mubi, _راجر_, _ستجع
  { {0x539b0008,0xdfcf00a2,0x9d56002b,0x92b60015}},	//   _זיכו, حين_, فنشت, _أحجا
  { {0x463b00b2,0xb21b0134,0x6b8b013c,0xdd900021}},	//   לענע, _kræn, _angg, شوب_
  { {0xb80b000b,0x9f5802b9,0x4c940a32,0x645c3b2e}},	//   _संगम_, _durò_, тийс, ntri
  { {0x645c3b2f,0x67d20024,0x7c38042f,0x9fe60015}},	//   itri, dājo, rsvr, _أسسه
  { {0x645c3b30,0xa3ae000b,0xdd8f002b,0x1af4006b}},	//   htri, _कतई_, _گول_, ъпия
  { {0x644e003f,0x6b8b013c,0x127b004c,0x9f580144}},	//   kubi, _engg, לאפע, _turó_
  { {0xd8f80191,0xf1b3013a,0xdd8f0029,0xb8660002}},	//   ьної_, רסת_, _دول_, رادو
  { {0x2fc60112,0x644e3b31,0x2ca1008c,0xab62007c}},	//   niog_, dubi, ähde_, üüdi
  { {0xe9a6008f,0x2d9e003f,0x65ab00b8,0x69c600dc}},	//   _падп, _kote_, _fühl, ékes
  { {0xb8940029,0x645c00b8,0x67d215e5,0xb21b0f47}},	//   _للتع, ftri, bājo, _bræn
  { {0xa4d40036,0xdb09002d,0xf99300a3,0x94d43b32}},	//   горі, mheá, _תרצ_, горц
  { {0x99580046,0x2d9e3b33,0x61fe3b34,0x0000006a}},	//   váři_, _lote_, empl,
  { {0x71790124,0x2d8c3b35,0x2fc60026,0x56950484}},	// [80b0] мбар_, _onde_, diog_, _рапт
  { {0xb21b001a,0x77a6016e,0x46580015,0x2d9e3b36}},	//   _fræn, _róxi, _أؤيد_, _note_
  { {0x03f900d0,0xb21b290f,0x764f002a,0x2937004c}},	//   _оној_, _græn, lucy, גאבן_
  { {0xc43a000a,0x43940033,0xb4ad000b,0x2d8c3b37}},	//   _קתרי, _баюс, कनी_, _ande_
  { {0x99580089,0x539a000a,0x290a00bc,0x765d2db2}},	//   sáři_, _חירו, žbah_, ntsy
  { {0x7bc23393,0xbea20484,0xdc29002b,0xdd9b006b}},	//   _amou, рашк, وسعه_, яше_
  { {0x69cf0152,0xabd5050e,0x10480080,0xdc750174}},	//   écem, кциј, _пяти_, тыль
  { {0x2d8c38dc,0xba75002b,0x67d2003d,0x4421050b}},	//   _ende_, ناخت, vājo, _mth_
  { {0x7e2b022a,0xc334004c,0x644e0012,0x67f60046}},	//   _хіба_, נוץ_, zubi, hájc
  { {0x4421002d,0xab66007c,0x8d740067,0x67d2003d}},	//   _oth_, _psüü, _ماما, tājo
  { {0xb6040089,0x65b00020,0x64410107,0x200c0003}},	//   ntář, _näha, álil, _édit_
  { {0x2d9e000c,0x2ca7002e,0x6b8b013c,0xdce80046}},	//   _zote_, mynd_, _ungg, _ladě
  { {0x2d9e000c,0x31a400dc,0xab5d005c,0xd5b70092}},	//   _yote_, _közt_, liżo, ắng_
  { {0xdce80089,0xdb09002d,0x645c3b38,0x88c50015}},	//   _nadě, cheá, ttri, _لتعل
  { {0xc5f80024,0x45190033,0x03aa002b,0x22492755}},	//   ķē_, эцяя_, ودرو_, erak_
  { {0x2c7c0089,0x645c3b39,0xc6d60015,0x9f520061}},	//   ládá_, rtri, _لتخت, öyü_
  { {0x3ce8005d,0x644e003f,0x715a05c4,0x6d413b3a}},	// [80c0] _चुने_, subi, дрес_, _odla
  { {0x7aeb00df,0x3f8d0251,0xb21b0f47,0x2fc60034}},	//   _mygt, _aneu_, _træn, wiog_
  { {0x20330029,0x2d9e3b3b,0x505a04ab,0xe58b000a}},	//   لفلس, _rote_, ьшая_, _חָכָ
  { {0xdce8002c,0x2249386b,0x6d412c97,0x889a000a}},	//   _podľ, brak_, _adla, ובעי
  { {0x6eb60015,0x8f000033,0xdee30054,0xa3c1000b}},	//   خصائ, пiс_, аоци, ्चर_
  { {0x2fc600df,0xd13200e6,0x6df40015,0x8d63005e}},	//   siog_, _خمس_, دكتا, ивче
  { {0x6da3050e,0x6aca005d,0x2ca70134,0x2d9e1915}},	//   рија, ाप्र, gynd_, _vote_
  { {0x2d9e000c,0x50db0008,0xc4d30008,0x65ab10cc}},	//   _wote_, _חקלא, יגו_, _rühm
  { {0xcb67009c,0x2d9e267b,0x7d56005e,0x7fd5005e}},	//   тање_, _tote_, _атеї, _сірі
  { {0x2d8c04f9,0x7aeb02de,0x9c7c0091,0xab62007c}},	//   _unde_, _dygt, _lyči, üübi
  { {0x31370008,0xe759005e,0x5c560099,0x99820030}},	//   כנים_, нині_, _штаф, ékű_
  { {0xdb09002d,0x69c30293,0x6c57000a,0x07e4005e}},	//   sheá, _emne, _ייבא_, ицям
  { {0xb866002b,0xcb670054,0xb7640033,0xaab70015}},	//   راگو, _јаче_, штэй, _لدور_
  { {0xa3820020,0xdce1003d,0xdbd1001a,0xdddb0729}},	//   öõnn, _galē, lýðs, _kruš
  { {0xd5b81e88,0xb4ad005d,0x98a30001,0xdce80089}},	//   тся_, कने_, _вије, _radě
  { {0x9cd70008,0x63b60026,0x21ef007c,0x88bc0046}},	//   דולה_, ghyn, rühm_, yběj
  { {0x69c800f2,0x61f90010,0x27e90049,0x70bd000b}},	// [80d0] oide, енаў_, _ikan_, ्प्ल
  { {0x4a5b0008,0x645a0251,0x69c83b3c,0x6115005e}},	//   ודמו, àtic, nide, уджу
  { {0xc1e80080,0x69c80604,0xe0d00067,0xe0e40033}},	//   тьте_, iide, يزم_, аўцо
  { {0x48150053,0x69c82da3,0x224912e2,0xa8ab000a}},	//   אַסן_, hide, prak_, וֹדִ
  { {0x25090086,0x69c83b3d,0xf7bc0053,0x3f810089}},	//   _ترکی_, kide, וזאמ, ěhu_
  { {0x8e080036,0x3d0d000b,0x3ea0007c,0x5434002b}},	//   внів_, िखें_, äita_, _حریر
  { {0x25a10089,0x61e50057,0xf1b2000a,0x3034004a}},	//   _mohl_, mohl, _פסל_, _весё
  { {0xfe730086,0x99840007,0xdddb052c,0xdb09001c}},	//   _پدر_, ksmų_, _druš, nheç
  { {0xdce10024,0x63ad3b3e,0x1a65002b,0xab760015}},	//   _palē, ikan, ایتی_, امًا_
  { {0x3eda0053,0x27e9013c,0x6d4102de,0x63ad2573}},	//   _אַבא, _akan_, _udla, hkan
  { {0xbb550074,0x65ab0020,0x63ad3b3f,0x07a61402}},	//   _مناب, _tühj, kkan, ганн
  { {0xa5bb002a,0x63ad3b40,0xebd9006b,0x69c83b41}},	//   spól, jkan, _ядеш_, aide
  { {0x200d0824,0xdddb0107,0x69c83b42,0xb5fb1793}},	//   _miei_, _zruš, bide, dtáb
  { {0x23a70020,0xcc12005d,0x6abb0012,0x69c816c4}},	//   _mõju_, _ढूँढ_, mzuf, cide
  { {0x98ac0011,0xa819000a,0x63ad00aa,0x63b60710}},	//   radă_, _אֵ֥י, fkan, thyn
  { {0xa6960292,0x7bc93b43,0x63ad3b44,0xd1380091}},	//   _број, nieu, gkan, _žą_
  { {0x6abb00b8,0x98ac0045,0xcb12004c,0x61e50012}},	// [80e0] nzuf, padă_, מלן_, fohl
  { {0x11da0029,0x0697000a,0x65b00012,0x201c016e}},	//   روضة_, _עדים_, _zähn, ívio_
  { {0x11d70029,0x9c7c0947,0xe936004c,0x6abb0012}},	//   دولة_, _tyči, רנעץ_, hzuf
  { {0xe29a085d,0xaf3600e5,0xcf260015,0x69c80104}},	//   _зам_, ارات, ارضي, zide
  { {0x657e00dc,0x975700a3,0x0ee7004a,0xdddb0085}},	//   _kaph, רינו_, льши_, _sruš
  { {0x6e870018,0x3eb2003d,0x69c8389c,0xdddb013b}},	//   انوف_, _čatā_, xide, _pruš
  { {0x80780008,0xbcaa0029,0x9078000a,0xbd870015}},	//   _בְּה, عدتك_, _בְּפ, طنين_
  { {0xafe60da6,0xbc670115,0x69c80c1f,0x7bc9157a}},	//   _собл, امين_, wide, gieu
  { {0x0d560015,0x69c83b45,0xb5fb3b46,0x62843397}},	//   _مخاد, tide, ntác, nvio
  { {0xad650086,0x63ad3b47,0xb33b3b48,0x9b94002b}},	//   _نامه, zkan, _moça, الکت
  { {0xbca603c4,0xa2cb000b,0x7bc90079,0x63ad1e08}},	//   _حماي, _सेन्, bieu, ykan
  { {0x64410048,0x7bc90152,0x8c1b0008,0xcb160029}},	//   šlik, cieu, _נודי, _إذاع
  { {0x78ba0014,0x88bc0089,0x69c83b49,0x1994176c}},	//   sztv, zběh, pide, _валя
  { {0x99840007,0x3eb90061,0x98a70091,0x8a7b000a}},	//   rsmų_, _üste_, _seną_, _נאות
  { {0x24190080,0x8937000a,0x69d80079,0x293705bd}},	//   тобы_, _גרוע_, _ijve, _גאון_
  { {0x25a100b8,0x68f50700,0x67f6002c,0x99dd0264}},	//   _wohl_, üzde, pája, suňt
  { {0x65ab0020,0xd14b002b,0x6d5a3b4a,0xa294005e}},	// [80f0] _lühi, فشان_, _octa, баті
  { {0xb5fb00dc,0xd29b0033,0x63ad3b4b,0x2bb10065}},	//   stáb, лiвы, skan, _जत्थ
  { {0x61e50089,0x3f150775,0x8e39002b,0xdb000123}},	//   rohl, адес, چستر_, lkmä
  { {0xa8570008,0xfe710015,0xdb000123,0x8e3900c3}},	//   ריאה_, قدت_, okmä, نستر_
  { {0x433a000a,0xef18005e,0x7bc90003,0xb5fb16ee}},	//   _בערב, умі_, vieu, ctác
  { {0xdcfa01e2,0xdca5250c,0xc537004f,0x4d6400ce}},	//   _altı, иали, אָ֗ה_, йків
  { {0x9f6b008f,0xbd18005e,0x6b9b0012,0x7bc90f29}},	//   _праз_, уції_, tjug, tieu
  { {0x747c0008,0x8a950015,0x4a4519a5,0x69d802d8}},	//   תנהג, لشخص, анив, _ajve
  { {0x7bc92a5c,0xdfd8006b,0xdb000012,0xe9d901c5}},	//   rieu, _сър_, chmü, кки_
  { {0x7bc9038d,0x79c50036,0xd9450001,0xc9a6004a}},	//   sieu, рйоз, јени, ивые_
  { {0xe8f6007a,0x6abb0012,0x8afd0046,0xab5d002a}},	//   иль_, szuf, teřs, niżk
  { {0x62830024,0xe73a0080,0x8c1a000a,0x62840091}},	//   ānoj, ъем_, _סוני, yvio
  { {0x2bb8003b,0x67d20024,0xf9d50010,0x8f9a000a}},	//   _حالة_, nāji, _кодэ, דירי
  { {0xc9870001,0x057a0015,0x69dd0030,0x4e16000a}},	//   _људи, خمسة_, ésed, יחשב_
  { {0xc9d40074,0x9961003d,0x0000006a,0x0000006a}},	//   _دموک, tīņu_,   ,
  { {0x65b000b8,0x67d20024,0xb21b02de,0xd8da000a}},	//   _zähl, kāji, _græk, _בקצר
  { {0x31160010,0x130a0010,0x42230063,0xd2a7239c}},	// [8100] афес, тнай_, ждув, акте_
  { {0xd24f0029,0xc0460029,0x67d20024,0x98ac002a}},	//   بنك_, لخصو, dāji, sadą_
  { {0x7e7b04f9,0x753c002a,0xdfcf002b,0xb5fb195f}},	//   _asup, marz, ژيم_, stác
  { {0x753c005c,0x6023005e,0x543b004c,0xdb000123}},	//   larz, ідча, _בעטא, lkmå
  { {0x471b00b2,0xee770029,0xfe720086,0x7e7b00dc}},	//   דונג, لصوت_, تدا_, _csup
  { {0x753c0647,0x644e3b4c,0x65ab007c,0x9c460d3e}},	//   narz, orbi, _pühi, ахил
  { {0xddc2002a,0x9b440015,0x10a612ab,0x4f96123e}},	//   troł, منغو, _тивн, _крау
  { {0xafe3243b,0x67d20024,0x207b0135,0xfba7004a}},	//   _досл, bāji, _באלא, итый_
  { {0x753c2029,0xa92a0033,0x8bd30033,0x999f0045}},	//   karz, кіне_, ўжыц, ârşi_
  { {0x201815ff,0x65ab0020,0xaa630010,0x1daa005d}},	//   _kuri_, _tühi, ітык, _कवित
  { {0x753c0050,0x3b460015,0xd117000a,0xb21b02de}},	//   darz, _نَاف, יקיה_, _præk
  { {0x65b000b8,0xdddb005c,0x22403b4d,0xab2a08d7}},	//   _wähl, _opuś, ksik_, _рода_
  { {0x2a760086,0x95cb0549,0x644e0ad4,0x7e623b4e}},	//   _خداح, вува_, erbi, ntop
  { {0x95cb0001,0x27350092,0x6703005d,0x6d583b4f}},	//   тума_, ấn_, रेषक_, ngva
  { {0xb21b0134,0x79fb000a,0x7e62008c,0x69fb000a}},	//   _træk, _שלוח, htop, _שלוק
  { {0x7e620bfa,0xf77f016e,0xdb1b001a,0xf8b70643}},	//   ktop, moço_, nnuð, _כפוי_
  { {0xb062008c,0xa7fd0061,0x224002f2,0x644e30bc}},	// [8110] äänl, atıc, gsik_, arbi
  { {0xdce100df,0xa6db002e,0xa2cb000b,0xad3a005e}},	//   _galė, taðf, _सेण्, _звiт
  { {0x23b5002b,0x74150067,0x20181d41,0x65750030}},	//   _همدس, _دوجا, _curi_, mezh
  { {0x9f05003b,0x67d20048,0x673d06f5,0x33950029}},	//   موضو, tāji, nasj, _الحز
  { {0x64553b50,0xd244004a,0xa6db001a,0x22400030}},	//   luzi, _мэри, saðf, csik_
  { {0x51873510,0xc27a004f,0xdd3a00d4,0x2b8300a1}},	//   _тума, _גרשי, răşi, _ực_
  { {0xb5b80008,0x673d3b51,0xdb1b002e,0x3a2600da}},	//   שלוח_, kasj, fnuð, _atop_
  { {0xdd3a0011,0x14d8004c,0x753c25d8,0xb33b016e}},	//   păşi, יוול_, zarz, _moço
  { {0x657500dc,0xcbc40015,0x7e623b52,0xbe150058}},	//   kezh, تزوي, ctop, _طواع
  { {0x499501b7,0xdcfa0046,0x3945030c,0x64553b53}},	//   сшит, _zatč, щног, kuzi
  { {0x49980010,0xe73a3b54,0xa9220033,0x480a0155}},	//   ртыя_, лен_, ядэл, леон_
  { {0x673d003c,0x753c2029,0x22400b0f,0x31af0061}},	//   gasj, warz, ysik_, _hızı_
  { {0x753c1515,0xa96902c4,0x96c5000b,0x31af0061}},	//   tarz, _била_, _लेआउ, _kızı_
  { {0xf77f001c,0x657500dc,0x64a6017f,0x59ab000b}},	//   boço_, gezh, бага, _छविर
  { {0xa34a0063,0x7bf90053,0x68130011,0xe8550015}},	//   лзва_, ָפּצ, _pădu, _انعد
  { {0xd4670001,0x753c005c,0x73950036,0x3219003e}},	//   љите_, sarz, ошує, _busy_
  { {0x1757013a,0x11da0015,0x2018299b,0x6d580123}},	// [8120] _הספר_, هورة_, _suri_, ygva
  { {0x645504ed,0xe1650015,0xf1aa012c,0x20183b55}},	//   buzi, قدمي, داره_, _puri_
  { {0x645504ed,0xf73a000a,0xe3b2012c,0x22400353}},	//   cuzi, ָתְך, _فرح_, ssik_
  { {0xa3bc005d,0xb5fb3b56,0x7e623b57,0x6fe9005e}},	//   _अति_, ntán, ttop, афів_
  { {0x0dca000d,0x7a12005c,0x44440e95,0xdddb002a}},	//   луки_, _ołta, _hv_, _upuś
  { {0x201800df,0x6283005c,0xa6db001a,0x5e430015}},	//   _turi_, łnoc, saðg, أَوْ
  { {0xad650086,0x7e623b58,0x5c74005e,0x3a263b59}},	//   تانه, stop, ілит, _stop_
  { {0xdce30089,0x2bba0015,0x7a12002a,0x44443b5a}},	//   leně, طاعة_, _ałta, _mv_
  { {0x67d20048,0xa5bb002d,0x539b000a,0x2a9a0015}},	//   nāju, spói, ריפו, ائعة_
  { {0x7c2a003c,0x7bde0003,0xc27b000a,0x63a6001a}},	//   ppfr, épub, נריי, _lokn
  { {0x673d06f5,0xd90d0086,0xc19b000a,0x21ef0012}},	//   tasj, نیه_, אשיי, müht_
  { {0xd0f7000a,0xda660015,0x00f7000a,0xf77f016e}},	//   ממית_, _هاتي, מזים_, roço_
  { {0x673d06f5,0x4444368f,0xcaf60015,0x6af60015}},	//   rasj, _av_, _اساب, _اثار
  { {0xb21b00fb,0x67d20024,0x673d3b5b,0x44443b5c}},	//   _kræv, dāju, sasj, _bv_
  { {0xb06200f2,0x65750030,0x673d3b5d,0x5dcb000a}},	//   ääll, rezh, pasj, רֶכְ
  { {0x645504ed,0xccab000a,0xcc3b004c,0xb5fb0077}},	//   ruzi, אֱמֹ, טעלט, ctán
  { {0x67d20024,0xc2090015,0xd7f90045,0x44443b5e}},	// [8130] tājv, لقرن_, ntăm_, _ev_
  { {0xf2040010,0x7a8b000a,0x76740088,0x7e99009a}},	//   пяхо, טָבַ, _эльф, ینار_
  { {0x72040015,0xac420138,0x0000006a,0x0000006a}},	//   أولم, _дзiк,   ,
  { {0x6d480176,0x6fd40036,0x1877000a,0xa2950033}},	//   _adda, пціє, מעבר_, _дамі
  { {0x2c61005c,0x67d20024,0xa77c0053,0x6e673b5f}},	//   wód_, cāju, טראפ, стеж
  { {0x2bb1005d,0x98ac005c,0xd658000a,0x98a70046}},	//   जस्थ, sadę_, מידת_, _ceně_
  { {0x65b0022d,0x4c920001,0xdca2006b,0xfc05030c}},	//   _sähk, дијс, дащи, опко
  { {0x5bc50029,0x2c61005c,0xaba9006b,0xa0240012}},	//   تقبل, ród_, рвиз_, stöß
  { {0x60250007,0xb21b02de,0x4999008b,0xcaa50015}},	//   _dėme, _usæd, атня_, تصغي
  { {0xfc330021,0x65ab0012,0x6845005e,0x65b0007c}},	//   _فحص_, _mühs, оноа, _vähk
  { {0x18693b60,0xf77200c3,0x718c000a,0xc689000a}},	//   шани_, واح_, רְחַ, _שא_
  { {0x2a350033,0x98ac0046,0xd70a0342,0xdc88000a}},	//   _дэкр, ladě_, инне_, _לְנָ
  { {0x69cf0152,0x88830086,0xd7f90045,0xd94510b9}},	//   éces, زیکن, ctăm_, _дели
  { {0x67d20048,0xb5fb34de,0x98ac0046,0x75d60015}},	//   vāju, stán, nadě_, زيزا
  { {0xb97a0008,0xb4b4005d,0x833a0184,0x06070033}},	//   _כנסי, झने_, ичат_, інск_
  { {0x67d20048,0x0457003b,0xa7fd0064,0x33660010}},	//   tāju, تلفة_, ltın, ўваг
  { {0x9f5f0092,0x65b00044,0xe29a0004,0xd1ca0033}},	// [8140] _thuê_, _lähi, шаа_, алае_
  { {0xa7fd0064,0xb5fb3a9f,0x4444350a,0x3ce00061}},	//   ntın, ntál, _tv_, şivi_
  { {0xdce10048,0x6e290026,0x67d20024,0x79830a4c}},	//   _dalī, _ateb, sāju, _manw
  { {0xf1bf0014,0xe8ec0053,0xb5fb002d,0xb4fb000a}},	//   _után_, נקאָ, htál, _כפיי
  { {0x6441032c,0x60250007,0x5de60d08,0xb5fb0307}},	//   šlit, _rėme, ожда, ktál
  { {0x7bcb0026,0xdce10024,0xac260461,0x26c200bc}},	//   _amgu, _galī, офик, izko_
  { {0x70570033,0x6cd3002b,0x93fa004f,0x2b91009a}},	//   _маёр_, وقها, ֱלִי, کینس
  { {0x6fb600e6,0x79830150,0xdee63b61,0x0b8a1944}},	//   _بمرا, _aanw, _доби, рски_
  { {0x2bc9000b,0x2903001a,0xdfcf0015,0x22523b62}},	//   िफ़ा, ýjan_, _شيك_, nryk_
  { {0x6d480134,0x65b000b8,0x36fe005d,0x88bc0046}},	//   _udda, _fähi, रेज़ी_, dběr
  { {0xe8940010,0x58860010,0x7c280cbf,0x69dd0003}},	//   чань, цыпа, _utdr, ésea
  { {0xc7c70036,0xd7f90011,0x3f863b63,0x225200aa}},	//   існи, ptăm_, ndou_, kryk_
  { {0xb9c60015,0x79830034,0x0a94006b,0x68fd0091}},	//   _وتته, _fanw, _халю, ęsda
  { {0x69ca00ca,0xa6db002e,0x79830026,0x3c91004c}},	//   _umfe, taðb, _ganw, קלאַמ
  { {0xd83a0010,0x93970015,0x4395005e,0xe3b30015}},	//   _тэл_, يجرا, павс, ورر_
  { {0xdce10024,0x3f860089,0x58bb000a,0x88bb000a}},	//   _salī, jdou_, _כמוצ, _כמוז
  { {0xdce10048,0x23ae0084,0x1ddb005d,0xe7320008}},	// [8150] _palī, _nýju_, _बदलत, _אֵת_
  { {0x69da3b64,0x09f4000a,0x7afd35b3,0x64413b65}},	//   nnte, פֶּר_, ýsti, ális
  { {0x6e2900df,0x65ab018b,0xdce3003d,0xc05b005e}},	//   _steb, _führ, rdnī, різ_
  { {0xd47a00b2,0x69da00b8,0x50c80010,0x547a000a}},	//   _פארל, hnte, цыум_, _פטרו
  { {0x539a0008,0x1df90080,0x639a000a,0x7ed4002b}},	//   _הירו, беды_, _הסרנ, وزها
  { {0xd6580008,0x0dc80036,0x367c000a,0xd67c000a}},	//   קיות_, олій_, שְׁע, שָׁכ
  { {0xa5bb002e,0x9f350127,0xdd8e0015,0x21ef0012}},	//   lpós, _неві, طوي_, bühr_
  { {0x65b00197,0x6e38002e,0x69da3b66,0x04dc000a}},	//   _vähi, ðabú, ente, יקול
  { {0x99f50010,0x98ac0089,0x798300e8,0xa7fd0061}},	//   зяні, padě_, _panw, ttın
  { {0x65b00020,0x5ce50029,0xfeb80086,0x49992ed2}},	//   _tähi, _فكذل, _بافت_, стия_
  { {0xb5fb00dc,0xa7fd0064,0xd8250036,0x79830161}},	//   rtál, rtın, ядни, _vanw
  { {0x2d853b67,0xa09a004c,0xb5fb3b68,0xf1bf01c0}},	//   _hale_, צירט, stál, _stál_
  { {0x19950063,0x2d853b69,0xa2cb000b,0x65ab0012}},	//   _надя, _kale_, _सेल्, _rühr
  { {0xa7fd0064,0x67d20024,0x2d8722fc,0x09f70015}},	//   ltıl, tājs, ndne_, _بأصد
  { {0x64a63b6a,0x291c002c,0x67f601b2,0x09f6000a}},	//   чава, ázať_, háji, _צמצם_
  { {0xa7fd01e2,0x22520134,0xa5bb002e,0x422605fd}},	//   ntıl, tryk_, fpós, здав
  { {0x27e000e8,0xab5d005c,0xe2970658,0x7bdb008c}},	// [8160] _ijin_, liżs, пат_, inuu
  { {0xb46609a8,0x225200aa,0xdb0a0030,0x3f843b6b}},	//   _екол, rryk_, ínér, _samu_
  { {0xe1ff03af,0xab5d0050,0x20560010,0x41dd000b}},	//   _após_, niżs, ятар, _मदरस
  { {0x3f860089,0xa6db002e,0x76460227,0x937a0015}},	//   udou_, laða, osky, _اصدر_
  { {0xa5bb002f,0x5f190010,0x3f863b6c,0x63b6001a}},	//   mpór, іццё_, rdou_, mkyn
  { {0xa6db0084,0x63b60084,0x62830024,0x2d853b6d}},	//   naða, lkyn, ānot, _cale_
  { {0xc0e30afb,0x8c96005e,0x3f84013c,0x63b601c0}},	//   _зорк, ярді, _tamu_, okyn
  { {0x69dd038d,0x50db0008,0xb21b0723,0xeb970054}},	//   ésen, _הקלא, _græs, зић_
  { {0xc9860124,0x539b000a,0xaa630010,0xcc8a0086}},	//   пуни, מיקו, нтэк, _گناه_
  { {0xdebb0008,0xa7fd0064,0x2d850472,0x69cf0003}},	//   _הממל, atıl, _gale_, écep
  { {0x69da0b0f,0x76463b6e,0xa6db0052,0x0000006a}},	//   rnte, esky, daða,
  { {0x3cfb00a3,0x8c1b000a,0xc053000f,0xbc1b000a}},	//   _פלאנ, _הואי, עזר_, _הואש
  { {0xa6db002e,0x49b7002b,0x63b60046,0x2d853b6f}},	//   faða, زاید_, dkyn, _yale_
  { {0x7afd10cc,0xca97000a,0xa6db001a,0xf1bf0046}},	//   üste, _מדדי_, gaða, _ptám_
  { {0xe1ff002a,0x79880034,0x14180015,0xa2bf000b}},	//   _opór_, mddw, كيّة_, लैन्
  { {0xa3bc005d,0xa2950010,0x08770053,0xf8db000a}},	//   _अतः_, мабі, _זעהט_, _לחומ
  { {0x5215005e,0xe3d40015,0x765a002a,0x79880034}},	// [8170] ддат, رتفع, ątyc, oddw
  { {0xa5bb002e,0x76bc000a,0xbba9000b,0x38c20003}},	//   rpós, _למחפ, _छक्क, _géré_
  { {0x7bdb005c,0xb21b0134,0xd91b000a,0xa3ea000b}},	//   ynuu, _præs, צואל, यवश_
  { {0x2d851ae0,0xa857000a,0x388c005a,0x0000006a}},	//   _sale_, ליבה_, _měr_,
  { {0x2d850705,0xceeb002b,0x6440002a,0xce6b018d}},	//   _pale_, حران_, ćmie, сред_
  { {0x929a000a,0x1638000a,0x64553b70,0x865c004f}},	//   _וישת, לנדר_, orzi, מדדי
  { {0x6da20063,0xac0902bf,0xc172000a,0xb5fb0030}},	//   тища, онка_, _שחל_, ttáj
  { {0x395e0024,0xd4980008,0x79880026,0x2d8519f4}},	//   egts_, לכות_, eddw, _wale_
  { {0xfe700086,0x2d853b71,0x8ed80015,0xa7fd0061}},	//   _مدل_, _tale_, _فذكر_, rtıl
  { {0xb5fb0014,0x3ce8005d,0x9588005c,0x395e0123}},	//   stáj, _चुके_, _krąż, ggts_
  { {0x3cf00264,0x6d433b72,0xa6db001a,0xf1b2000a}},	//   čové_, mana, vaða, דסי_
  { {0x2fdd0026,0x65b00356,0x395e0123,0xddc2002a}},	//   nnwg_, _läht, agts_, kroś
  { {0xb8f4005d,0x8f9a0008,0xa6db002e,0xdcfa0011}},	//   _से_, קישי, taða, _tată
  { {0x273c0023,0x76463b73,0x36150036,0x65b00209}},	//   ận_, rsky, еєст, _näht
  { {0xdddb016f,0x764600c0,0x94740086,0x69c13b74}},	//   _oruž, ssky, رگدا, mhle
  { {0x63a40007,0x6d433b75,0x76463b76,0x6b893b77}},	//   ujin, hana, psky, ndeg
  { {0x59e1005d,0xdb0b02c1,0xa6db0821,0xa5bb0533}},	// [8180] _पदार, _algú, paða, rpór
  { {0x5a0a0053,0xa5bb002d,0x50d60029,0x50ba0087}},	//   ַלײַ, spór, وزار, يداد_
  { {0x7bc700df,0x859b000a,0xa067006b,0xdb09008c}},	//   _įjun, _ושיו, даха_, lkeä
  { {0xdd8f0086,0x6d433b78,0x6283003d,0x9588002a}},	//   یون_, eana, ānor, _drąż
  { {0x79880176,0x6d43000c,0xdfcf00e6,0xdddb0820}},	//   yddw, fana, جين_, _druž
  { {0x657c00b8,0x6d433b79,0xf2d3000a,0x8445002b}},	//   nerh, gana, _יער_, _تخیل
  { {0x7bc00ecc,0x60230033,0x67f60030,0x657c086c}},	//   thmu, _адса, láju, ierh
  { {0x69c10012,0x03bb004c,0x657c0012,0xb5fb0030}},	//   ehle, ַציל, herh, tták
  { {0x53c6005d,0x0aea0029,0x657c3b7a,0x645c3b7b}},	//   रोएश, غربي_, kerh, huri
  { {0x79880026,0x69c101b3,0x645c3b7c,0x729b000a}},	//   uddw, ghle, kuri, קסיס
  { {0xad650086,0x81570053,0x79880026,0x31570008}},	//   _ساله, וסיע_, rddw, ויין_
  { {0x6e200c60,0x9b930029,0xb865002b,0xab930015}},	//   _kumb, _للمت, راپو, _للمغ
  { {0xdce800df,0x6e20000c,0xb5fb002d,0xd6280033}},	//   _padė, _jumb, ltái, моўе_
  { {0xceb3103d,0xb5fb002d,0x6e203b7d,0x6672002b}},	//   דיש_, otái, _mumb, اگير
  { {0xb5fb002f,0xb4b80015,0x645c3b7e,0x67d52374}},	//   ntái, وافذ_, guri, _поку
  { {0x6d4328f8,0x6283002a,0xdc8b000a,0xddc2002a}},	//   zana, łnom, חְמָ, troś
  { {0xf6e40010,0xb5fb3b7f,0x6e201844,0x6595124a}},	// [8190] _ацэн, htái, _numb, _запу
  { {0x15e9005d,0xc1eb0010,0xa7fd0061,0xc6f808f0}},	//   _फ़ीचर_, цьбе_, ktık, _юных_
  { {0xdddb121f,0x10480036,0x765d0035,0x645c248e}},	//   _pruž, дячи_, lusy, curi
  { {0x6d433b80,0x69c10046,0x6e203b81,0x0000006a}},	//   wana, zhle, _bumb,
  { {0x65b00458,0x69c10089,0xee3805fc,0x6d433b82}},	//   _täht, yhle, дні_, tana
  { {0xa2bf000b,0x6e920021,0xb65c000a,0x6b890034}},	//   लैण्, الوا, קדוש, wdeg
  { {0x6d433b83,0xfd440033,0x69dd19fe,0x44213b84}},	//   rana, тэчн, ésem, _juh_
  { {0x65b000b8,0x6e2006e8,0x6d433b85,0x6b891de9}},	//   _jähr, _fumb, sana, udeg
  { {0x645c0011,0xdef40010,0x6e2002c6,0x6d433b86}},	//   zuri, _апты, _gumb, pana
  { {0xa2f80008,0xa6db002e,0x0ae60033,0xff04005e}},	//   ומחה_, taðn, эдый_, _рясн
  { {0xab950001,0x68450033,0x67f60030,0x3e690030}},	//   _пажљ, энна, záju, lút_
  { {0xdc360053,0x90560008,0x6e20003f,0xf0920135}},	//   _נאנט_, עברו_, _yumb, אנט_
  { {0xe3c20064,0x3e69002c,0x6d410375,0x76f50033}},	//   nlış_, nút_, _kela, вярх
  { {0x9aa403c4,0xdb0900f2,0x6d410849,0x22490bfd}},	//   _جمهو, rkeä, _jela, dsak_
  { {0x6d410931,0xccf20053,0xa3bc005d,0x39453b87}},	//   _mela, ָכן_, असल_, mals_
  { {0x6d4115ba,0x58f6000a,0xb876000a,0x645c3b88}},	//   _lela, _אמצע_, _נתפס_, ruri
  { {0x22490035,0x394517d9,0x9f5f002d,0x645c2570}},	// [81a0] gsak_, oals_, _chuí_, suri
  { {0xe8890092,0x39451ee1,0x645c3b89,0x60260210}},	//   _kẻ_, nals_, puri, еджа
  { {0xdddb005c,0x6e200849,0x21f400b8,0x19b60053}},	//   _druż, _sumb, fähr_, עפער_
  { {0xa2cb005d,0xe8890016,0xfe460d88,0x6e201b03}},	//   _सेक्, _mẻ_, ендо, _pumb
  { {0xe8890092,0x224900dc,0xc7d7000a,0xaff70015}},	//   _lẻ_, csak_, עוני_, رفها_
  { {0xa7fd0064,0xdce10064,0xb5fb0030,0x62863b8a}},	//   ttık, _anlı, ttái, _isko
  { {0xc5f30008,0x91e3168a,0x3945235f,0x6d413b8b}},	//   אדג_, _соре, dals_, _dela
  { {0xb5fb002f,0x6d410005,0xdb1b002d,0x3e6907cf}},	//   rtái, _eela, bhuí, bút_
  { {0xb5fb216a,0x1a5a0015,0x6d413b8c,0x39450144}},	//   stái, أشعة_, _fela, fals_
  { {0xbe130070,0xa7fd0064,0xb5fb00dc,0x39453b8d}},	//   _موقع, ptık, ltáv, gals_
  { {0x81570053,0xc173000a,0x8881002b,0x22490061}},	//   עסטע_, אחת_, لیون, zsak_
  { {0xfa8800a7,0x765a005c,0x765d3b8e,0xb5fb016e}},	//   _từ_, ątyn, tusy, ntáv
  { {0xb5fb016e,0x996c003d,0x39453b8f,0xc6e4005e}},	//   itáv, vēņu_, bals_, гірп
  { {0x9a870029,0xc8f40063,0x39453b90,0x3d1e0065}},	//   _أَوْ_, _излъ, cals_, _पलों_
  { {0xd90e0086,0x62863b91,0x3e690030,0x89eb004f}},	//   _دید_, _asko, zút_, _מַהֵ
  { {0xc2c50015,0x22490808,0xdcfa01ec,0x0000006a}},	//   نيزي, tsak_, _antī,
  { {0x95c50015,0xd251006e,0x224901d7,0xc7d8004f}},	// [81b0] _ليظه, شنا_, usak_, _רוחי_
  { {0x65b0018b,0x4421138e,0x51f801b0,0x22493b92}},	//   _währ, _tuh_, еную_, rsak_
  { {0x41e40033,0xe8890016,0xd498004a,0x6d413b93}},	//   уіта, _xẻ_, _зря_, _rela
  { {0x9e3502bf,0x3e69002c,0x6d413b94,0x9837015b}},	//   ведч, tút_, _sela, גראף_
  { {0x69dd0014,0xf5ab0008,0x6d413b95,0x7f1800fd}},	//   ések, ּבֶּ, _pela, нішу_
  { {0xdce80048,0xddab006b,0x3e693b96,0x0000006a}},	//   _gadī, ятел_, rút_,
  { {0x2fd2002d,0xe58c000a,0x3e690030,0x23cb000a}},	//   úngú_, לָהָ, sút_, ּצִּ
  { {0x1adc014e,0x6d410026,0xe8890092,0xa6db001a}},	//   मपंथ, _wela, _rẻ_, taðl
  { {0xe8890092,0x6d41013c,0xeab10015,0x1cbb002b}},	//   _sẻ_, _tela, شعة_, _کاذب_
  { {0x798a0026,0x699514b5,0x6d5e03a0,0x0000006a}},	//   _cafw, трих, òpat,
  { {0xb9020036,0x39453b97,0xdb510015,0x39580125}},	//   изьк, rals_, _نَا_, órsa_
  { {0xe8890092,0xcb35006b,0x63af002a,0xdcfa002a}},	//   _vẻ_, _редъ, _nocn, _natę
  { {0x39452bbc,0x5fa6000b,0xe7370054,0xb9950015}},	//   pals_, कॉटल, ђер_, _للإب
  { {0xceb201e4,0xeab00029,0x798a0026,0xd5a2000b}},	//   סים_, _دعم_, _gafw, खाधड़
  { {0xddc20048,0xdce80024,0x232a005e,0x33f6005e}},	//   ntoš, _radī, доби_, вчас
  { {0x08760053,0x6b8b3b98,0x87d6009a,0xb5fb01d3}},	//   _יעצט_, _jagg, _جغتا, guáb
  { {0x6b8b02d7,0x61e20152,0x98be0024,0x798a003f}},	// [81c0] _magg, éolo, matā_, _yafw
  { {0x00da0115,0xb65b0135,0xa1c3017d,0x56b7000a}},	//   وبات_, _קדיש, абуд, _ספין_
  { {0xdce80024,0xb5fb0030,0x179a004f,0xd4160058}},	//   _vadī, ttáv, ֽיְב, _لبحث
  { {0x70530074,0x93c704f9,0xdfcf0031,0xa0670054}},	//   شنها, _plăţ, ييل_, ђача_
  { {0xddc20024,0x62863b99,0xde580033,0xb5fb2714}},	//   etoš, _usko, халі_, rtáv
  { {0x8d630124,0xe6260092,0xb5fb0107,0xdd900087}},	//   авље, _đôla_, stáv, صوب_
  { {0x8db50010,0x98be0024,0x3ea00011,0x6b8b38b7}},	//   ысці, katā_, ţit_, _bagg
  { {0xdca30054,0xcb670054,0xc0e31bb1,0x61fe3b9a}},	//   раћи, ваће_, _тоск, llpl
  { {0xd00f003b,0xfaa30010,0x93fb000a,0xf77f0061}},	//   _ذلك_, ашэн, ולקי, veç_
  { {0xb5fb0154,0x0c7a0015,0xfe37004f,0x0000006a}},	//   ntát, _يصاب_, _סרבי_,
  { {0x2d9e27a9,0x115b00f3,0x5fb6021e,0xeaaf002b}},	//   _inte_, ודיע, _अकाल, معی_
  { {0x2d8c3b9b,0xe8e00016,0x9cd7000a,0x61fe02ad}},	//   _hade_, _ngụy_, _בובה_, hlpl
  { {0xc9aa0292,0xf77f0064,0x195808f0,0xb5fb2654}},	//   _овде_, reç_, _залы_, ktát
  { {0xea770008,0xa4d50127,0x7bc20089,0x2d8c0d65}},	//   _סגור_, гогі, _hlou, _jade_
  { {0x2d8c003e,0x2923002c,0xb97b0447,0xf5e4005e}},	//   _made_, árať_, _חנוי, ріям
  { {0x6b800134,0x4917000a,0x88f7000a,0xd407004a}},	//   nemg, _בקול_, _שזהו_, тяги
  { {0xa3440010,0xf8e2000b,0xd90e002b,0x7bc20046}},	// [81d0] рэсл, _पशुप, _دیگ_, _mlou
  { {0x2d8c3b9c,0xc692004f,0x0000006a,0x0000006a}},	//   _nade_, _פאי_,   ,
  { {0x44270440,0x69dd0014,0xc953000a,0xa5d80015}},	//   _în_, ései, שמע_, _جبير_
  { {0xb4c1005d,0x2d9e3b9d,0x5f28005e,0x82370015}},	//   ्छी_, _ante_, воїм_, _لرسا
  { {0x6b8b02d7,0x4ea7010f,0x2d8c3b9e,0x0000006a}},	//   _ragg, ържа, _bade_,
  { {0xf2d20008,0x6b8b052a,0x1d090c1c,0xad58006b}},	//   _פעם_, _sagg, нели_, връх_
  { {0x6b8b00b6,0xb5fb0014,0x6c350029,0xaf760046}},	//   _pagg, ltás, دفعا, ížíc
  { {0xddc23b9f,0x7bc20b62,0x2fc60034,0x5e450015}},	//   rtoš, _clou, chog_, _مَرْ
  { {0xb5fb0014,0x7bc20089,0xee840139,0xfebb002b}},	//   ntás, _dlou, _выхо, _غارت_
  { {0xdcbb010f,0x7d74002b,0x2d8c3ba0,0x6283002a}},	//   _още_, _نامط, _gade_, łnow
  { {0x2dd8003b,0x7bc20bf5,0xf865004a,0x6b8b1037}},	//   _شبكة_, _flou, ывно, _tagg
  { {0xf7720070,0x62840b90,0xe73a0033,0x7ae40f81}},	//   حاد_, ywio, эем_, _žite
  { {0xa6db002e,0xb5fb00dc,0xeb98005e,0x44333ba1}},	//   naðh, jtás, _шиї_, _atx_
  { {0x7bc2016f,0x88c500e5,0x6994006b,0x29c00016}},	//   _zlou, _متعل, _връх, _hòan_
  { {0xa3ea0063,0xf8a80029,0x9879004c,0x4376071f}},	//   едва_, _لديه_, _טאַט, луат
  { {0xd4970092,0xb5fb002c,0x78fa0053,0x798100dd}},	//   ừng_, tuác, _אפצו, lelw
  { {0xe2450015,0xf6970015,0x65ba00ce,0x715a20b9}},	// [81e0] لخلي, _منيع_, _зунр_, ерес_
  { {0x10a60036,0x6d45002e,0x81460067,0x763b004c}},	//   лизн, ðhal, انان, _רעיג
  { {0xdce300df,0x98be0011,0x2fc60026,0x2d8c049f}},	//   menė, mată_, thog_, _rade_
  { {0xd5ed0023,0x98be0011,0xf1bf1d98,0x43fa005e}},	//   _trạ, lată_, _stát_, _їхня_
  { {0x98be3ba2,0xdcf8003d,0xb5fb0030,0x7981042f}},	//   oată_, devā, mtár, kelw
  { {0x7bc20089,0x98be0011,0xb5fb00dc,0xc046006e}},	//   _slou, nată_, ltár, _مخرو
  { {0x98be0011,0x6da300d0,0x7981233f,0x61eb0324}},	//   iată_, сија, delw, égle
  { {0x1faa0036,0xba54049d,0xb5fb3ba3,0x5c060033}},	//   _якби_, авиј, ntár, ыяла
  { {0x7dc6001a,0xae890015,0x79812ccc,0x6b803ba4}},	//   _aðse, _لخلق_, felw, remg
  { {0x644e0134,0x5eeb0008,0x79810313,0xc8f4006b}},	//   ksbi, _אַבְ, gelw, изпъ
  { {0x98be04f9,0xd9170080,0x29182b60,0x11f7000a}},	//   dată_, лью_, ära_, רזיל_
  { {0xa6db002e,0x69c3109a,0x6d4a3ba5,0x3ad4002b}},	//   laði, _elne, lafa, _پيتز
  { {0x7bdb0053,0x75d50086,0x8674005e,0xe667004a}},	//   _אקאו, ليحا, бляє, ытно
  { {0x98be0011,0x6d4a003f,0xe5c70080,0xb5fb16af}},	//   gată_, nafa, усмо, etár
  { {0xb4c1005d,0x69da3ba6,0xcc78000a,0x3c78000a}},	//   ्छे_, mite, כְּר, כָּב
  { {0xa3cf005d,0x9cd7000a,0xe3b30015,0x7e62008c}},	//   वों_, אולה_, حرس_, kuop
  { {0x5b7b0053,0x98be0011,0x69c800f2,0x4438002c}},	// [81f0] ערמא, bată_, ohde, apr_
  { {0x98be04f9,0xb5fb0f87,0x645a047e,0x6d4a1b26}},	//   cată_, rtás, átic, jafa
  { {0x69da0201,0xa4d80033,0x69c8008c,0x1ee7002b}},	//   iite, _бдэу_, ihde, گوشی_
  { {0xf43a0447,0x83ab004a,0xaf370015,0x798100aa}},	//   _שגרמ, _чтоб_, ارضت, zelw
  { {0x6d4a0b82,0xa6db002e,0x9758000a,0x8d750015}},	//   fafa, faði, רידו_, لاثا
  { {0xa159004a,0x41c40033,0x63ad3ba7,0xa6db001a}},	//   _шагу_, _лёса, ljan, gaði
  { {0xa7fd01e2,0x63ad0007,0x1089000a,0xa2d9000b}},	//   ntıs, ojan, _בָּֽ, _नेत्
  { {0x98be04f9,0x79810176,0x69da00b8,0x69c3002c}},	//   zată_, welw, eite, _slne
  { {0x69c3002c,0x79813149,0x3eb9001a,0x753c002a}},	//   _plne, telw, _æst_, ybrz
  { {0x27e900f2,0xb5fb00dc,0x69c8002d,0x98be0045}},	//   _ajan_, ztár, ghde, xată_
  { {0x98be0011,0x63ad002e,0x765d0035,0x61d6000a}},	//   vată_, kjan, ersy, שותף_
  { {0xc600005d,0x69c8008c,0xd62a007e,0x443800bc}},	//   ोग्य_, ahde, коме_, vpr_
  { {0x98be04f9,0xbb3a0053,0xc6330015,0x4a44005e}},	//   tată_, _סעסי, يفَة, _гнів
  { {0x7bc90152,0x69c800b8,0x7d1c002d,0x63ad2e05}},	//   lheu, chde, _úrsc, ejan
  { {0x98be04f9,0x644e0012,0xb5fb0030,0xfc270040}},	//   rată_, usbi, ttár, تح_
  { {0x7bc90152,0x98be0011,0x63ad0f3c,0xd46702d9}},	//   nheu, sată_, gjan, јите_
  { {0x661e02c6,0x57fb0447,0xd7fb000a,0x01360015}},	// [8200] _tipk, _בלקו, _בהקל, لعاد
  { {0xb5fb0307,0x63ad0209,0x39473ba8,0x50960054}},	//   stár, ajan, _jens_, иређ
  { {0xa3ea0010,0xa3af005d,0xb5fb00dc,0xcf8f0180}},	//   _адна_, _कवच_, ptár, ој_
  { {0x69da3ba9,0x9e660015,0x63ad002a,0x3947185e}},	//   zite, لاتن, cjan, _lens_
  { {0xe8e2014e,0xa6db002e,0xeda62791,0x6d4a3baa}},	//   _पश्च, taði, ишко, tafa
  { {0x7c960015,0x39470144,0x6d4a0125,0x32431d9e}},	//   لشعا, _nens_, uafa, _ферг
  { {0xdc550086,0xa6db002e,0x2bda005d,0xacf80010}},	//   مريک, raði, _बगदा, ынку_
  { {0xa6db0084,0x69da13e4,0xa0370008,0x7bc90034}},	//   saði, wite, _כאלה_, gheu
  { {0x3947168c,0xada60033,0xf1ba000b,0xab5d002a}},	//   _bens_, _каал, _इवान, niży
  { {0x78ba008c,0x9d530015,0x39473bab,0x49732565}},	//   tytv, _ونقت, _cens_, ольс
  { {0x58d80036,0xa9c30036,0xe9cf0029,0x3b86000d}},	//   удня_, іськ, بغي_, _влег
  { {0x3947016b,0x7bc93bac,0xb5fb04b2,0x69da3bad}},	//   _eens_, cheu, zrád, site
  { {0x8c1b000a,0x3d12000b,0x8707006b,0x2af6004a}},	//   _סודי, धेरे_, ряне, _тяжё
  { {0x6d48010b,0x4444003f,0x39470291,0x993a006d}},	//   _jeda, _bw_, _gens_, _ряду_
  { {0x63ad3bae,0xf77f11dd,0x6d483baf,0xd7f90045}},	//   tjan, ança_, _meda, luăm_
  { {0x394c0134,0x85570086,0xa7fd0064,0x63ad0007}},	//   lads_, دیگر_, atır, ujan
  { {0xcb130053,0xc2990892,0x24180892,0xadf6000b}},	// [8210] ַלע_, ыках_, роты_, इवान_
  { {0x6f090050,0x6d483bb0,0xddc2003d,0x645a006f}},	//   _rzec, _neda, lsoņ, štia
  { {0x04950015,0x26f8002b,0x6f093bb1,0x63ad0030}},	//   _الجح, _مریخ_, _szec, pjan
  { {0xfe710015,0x749a004c,0xb21b01d0,0x0000006a}},	//   كدت_, _עירפ, _spæd,
  { {0x8db5008f,0x42790053,0x9e64005e,0xc7d8000a}},	//   йскі, _גאָג, жвід, סודי_
  { {0x44440b7c,0xdef8008f,0xdce80061,0x7c283bb2}},	//   _yw_, шых_, _andı, _budr
  { {0xa6db002e,0xb5fb00dc,0x8d740031,0xef67006b}},	//   maðu, oráb, تانا, _възо
  { {0x1bb90015,0x39473bb3,0xa6db001a,0xcf9803ae}},	//   طابع_, _sens_, laðu, _кју_
  { {0x6d483bb4,0x7bc93bb5,0x394710d1,0x2a990058}},	//   _feda, rheu, _pens_, ائبة_
  { {0xa6db0084,0x7db40029,0xf2410033,0xdb0d006f}},	//   naðu, _وصلا, цкiя_, _škót
  { {0x5dfa0053,0xdce30024,0xa3e8021e,0x629b0091}},	//   _עפענ, ienī, _बदल_, _šuol
  { {0x5fc7005d,0x7c2e0003,0x6fc7000b,0x394708cf}},	//   लसिल, _ébra, लसिं, _wens_
  { {0xa7fd01e2,0xa6db002e,0x444406e8,0xbc1a000a}},	//   ttır, kaðu, _sw_, _עונש
  { {0x3eda0053,0x6e2100e8,0xab180036,0x6e290077}},	//   אַלא, _jilb, _тієї_, _mueb
  { {0xa7fd0064,0xf992000a,0x18350015,0x99d40015}},	//   rtır, _מרג_, _ارتح, _بتنا
  { {0xf1bf0092,0xf8140086,0xa7fd0064,0xd7760015}},	//   _quán_, _بستگ, stır, _طابع
  { {0xa7fd0064,0xa6db001a,0x69c13bb6,0x98be0b48}},	// [8220] ptır, faðu, okle, ratą_
  { {0x01d7003b,0xd1960001,0x98be0007,0xb5fb3bb7}},	//   موقع_, љшањ, satą_, nuál
  { {0x44440a9c,0x94760029,0x02190036,0x8eda0086}},	//   _uw_, _ادخا, ріть_, گذار_
  { {0x68fc00b8,0xb099005e,0xa856000a,0x4425002b}},	//   ürdi, штує_, מיעה_, _گریف
  { {0x319f0024,0xc333000a,0x6e213bb8,0x6d483bb9}},	//   _bāzē_, _מור_, _bilb, _peda
  { {0xc2910086,0x171b0053,0x3f580092,0xf677004c}},	//   _زیمب, אונע, ứu_, מײנט_
  { {0xb5fb0264,0x8d730015,0x394c003d,0x6d483bba}},	//   duál, ساوا, vads_, _veda
  { {0x6f00005c,0x649b004c,0x8c430054,0x3057000a}},	//   _tymc, ריקה, чеће, _לשלך_
  { {0x4fbb0008,0x442200dc,0x6d483bbb,0x64a5000b}},	//   _עצמא, _mik_, _teda, _ऑप्श
  { {0xce370008,0xad260015,0x2a643bbc,0x9854005e}},	//   _לאמת_, _طرطو, rumb_, окої
  { {0x0dc90004,0x7bde0003,0x7d010034,0x3e720003}},	//   _туѓи_, épus, _gyls, lât_
  { {0x29020024,0x69dd0152,0x44221c7a,0x5719005e}},	//   āka_, éser, _nik_, ижня_
  { {0x95cb000d,0x1bfb004c,0x645a001a,0x66c801e1}},	//   гува_, _גלאב, átin, бург_
  { {0xf1bf02c1,0x69c13bbd,0x38970045,0xe91800fd}},	//   _cuál_, ckle, _făr_, _колі_
  { {0x7c22003f,0x89db0008,0x645a04c6,0xb9db000a}},	//   _kior, _תחוי, štin, _תחוש
  { {0x44223bbe,0xdc370053,0x33750033,0x0000006a}},	//   _cik_, מאלט_, ўгар,
  { {0xa6db002e,0x65950010,0x7805000b,0x1758000a}},	// [8230] taðu, _дапу, रतीक_, _הסחר_
  { {0xe4e7022a,0xf2c40015,0xdb0b0030,0xd1bb0015}},	//   _гімн, أْكُ, _jogá, دارا_
  { {0x44220134,0xa91c002c,0x1dac000b,0x710b005e}},	//   _fik_, ieľo, चानत, ухав_
  { {0xdb0b002f,0x6e290467,0x44220bfa,0x6e213bbf}},	//   _logá, _pueb, _gik_, _silb
  { {0x6e293bc0,0x7d070030,0xda660015,0xa227002b}},	//   _queb, _újsz, _تُ_, _درجه
  { {0xb5fb0154,0xa6db001a,0x628f3bc1,0x6da22be2}},	//   xuál, laðs, _isco, диша
  { {0x0dc80001,0x7c223bc2,0x4c85005e,0xe612000a}},	//   ључи_, _bior, ілив, וִה_
  { {0xa91c032c,0x23c9005d,0xfbd10015,0x8d77002b}},	//   teľn, रसिद, بتت_, _گارا
  { {0x3e7204f9,0x49c903e3,0x6e211f70,0xb5fb3bc3}},	//   cât_, илин_, _tilb, tuál
  { {0x8d770074,0x09f60029,0xe9d91797,0x38970045}},	//   _دارا, يفية_, рко_, _păr_
  { {0xd7ea005f,0x49980010,0x999900dc,0x7c221dab}},	//   имое_, стыя_, ésű_, _fior
  { {0xdd0e01e2,0x7c223354,0x2d873bc4,0x69c13bc5}},	//   lışm, _gior, lene_, skle
  { {0x3ffa0053,0x60080008,0x26c40046,0xa2d9000b}},	//   שפרע, מִשְ, ámo_, _नेल्
  { {0x992b0080,0xdd0e0064,0x2d870af5,0xb5fb0046}},	//   _сюда_, nışm, nene_, vrác
  { {0x628f3bc6,0x2d873bc7,0x43da0033,0x629d3bc8}},	//   _asco, iene_, афаў_, _arso
  { {0xb5fb1754,0x2d873bc9,0x8406008b,0x8cb1000b}},	//   trác, hene_, іпаж, _अपनो
  { {0x2d873bca,0xdd0e0061,0xb5fb07f4,0x1757000a}},	// [8240] kene_, kışm, urác, _וספר_
  { {0x93c70023,0xe1660029,0x2d87060b,0xe10a0033}},	//   _hoặ, تدري, jene_, аезд_
  { {0x001a0010,0x30860002,0x44223bcb,0x2d873bc4}},	//   аўды_, تلاف, _tik_, dene_
  { {0x443a005c,0xb5fb0057,0xc209000a,0x987a004c}},	//   _itp_, prác, דה_, ירעק
  { {0x2e470063,0xe4d70086,0x2d870ced,0xb21b02de}},	//   оящо_, _هویت_, fene_, _psæt
  { {0x3e72028d,0x569b004c,0x443a01d7,0x869b000a}},	//   rât_, יינצ, _ktp_, יינז
  { {0xdfd20021,0xa6db001a,0x2903007c,0x7c223bcc}},	//   _قيس_, naðr, üjal_, _pior
  { {0xaa880015,0x2bba0058,0x3e7201f6,0x0000006a}},	//   منعم_, شاعة_, pât_,
  { {0xa91c032c,0xa3cf014e,0x7e980086,0xf413011f}},	//   teľo, वोट_, _دچار_, ופה_
  { {0x7dc60015,0xa6db001a,0xc27b000a,0xfbcf002b}},	//   _بترك, kaðr, סריי, ّتی_
  { {0x09b7003b,0x28f80484,0x5ce60015,0x28a6005e}},	//   تطيع_, сень_, _بكال, ішог
  { {0x5a460010,0x27c40015,0xc6a7249a,0x3ea9006f}},	//   _дэка, ِيَّ, орги, ťate_
  { {0xf98f0086,0x501b000a,0x87070015,0x645a00b3}},	//   ربی_, יוטו, تبدل, štil
  { {0x99d30029,0x383403ae,0x7e623bcd,0x63a6038f}},	//   _يتوا, _енкр, irop, _ankn
  { {0x66720086,0xa6db001a,0xc494005e,0x69ca047f}},	//   وگیر, taðs, мирщ, _ilfe
  { {0x08570008,0x798810bd,0xe2350054,0x5c5b015b}},	//   _ובהם_, ledw, знањ, ידלק
  { {0xa6db002e,0x2d8720df,0x24970091,0x6d5a3bce}},	// [8250] raðs, yene_, _žemė_, _odta
  { {0x92580015,0xed880091,0x6d5a02de,0x41e400e2}},	//   غشقر_, šųjų_, _ndta, міха
  { {0x96180029,0xf8ca005d,0x2d872d0f,0xdd2f0046}},	//   _بغير_, ानिय, vene_, těži
  { {0xf8b3039e,0xb4fa000a,0x6d5a0030,0xffd40058}},	//   ושע_, _לפתי, _adta, وغند
  { {0x2d87003c,0xdd0e0064,0x1ea80029,0xbe870015}},	//   tene_, tışm, قاوي_, تجاو
  { {0xa2ba0008,0xb2ba0008,0xa282002b,0xbd450058}},	//   _המשט, _המשר, _سیمو, أنثي
  { {0x3ea90011,0x9f5100dc,0xdd0e0064,0xc172000f}},	//   ţat_, óból_, rışm, _רחל_
  { {0x7e6200bd,0x5ba93aba,0x2d873bcf,0x6d5a02de}},	//   brop, ским_, sene_, _edta
  { {0x2d873bd0,0xe9d91725,0xdce70061,0x7c3a3bd1}},	//   pene_, йки_, ğlıl, _ettr
  { {0xa7fd0064,0x645500dc,0x4a420010,0xdce70061}},	//   yrıc, kszi, эньв, şlıl
  { {0xdcfa0024,0x91bc004c,0xfaf9003d,0x98a50965}},	//   _datē, ימזי, egūt_, чине
  { {0xe29f0084,0xfc64006b,0x69ca3bd2,0x645a006f}},	//   _orð_, _цъфн, _elfe, átim
  { {0xb902005d,0x79880026,0x62980024,0x7bcb2233}},	//   _ने_, bedw, āvok, _ilgu
  { {0xceb20e22,0x7c3a00c0,0x7afd00b8,0x6b891e30}},	//   עים_, _yttr, üstu, leeg
  { {0x64a302e1,0x2cc9000a,0x64553bd3,0xa50a1d8a}},	//   нара, זֶּ֑, gszi, сева_
  { {0xe8d60008,0x98be0046,0x3c310030,0x78bc3bd4}},	//   _מוצר_, hatě_, _máv_, ärve
  { {0x27370092,0x0000006a,0x0000006a,0x0000006a}},	// [8260] _ủng_,   ,   ,
  { {0x7e623bd5,0xa6db001a,0x64550030,0x020300af}},	//   vrop, paðr, bszi, езун
  { {0x55bb0008,0xdfcf0086,0x6e3b0035,0x6b890926}},	//   _המיו, گين_, _atub, keeg
  { {0x63a63bd6,0x7988002a,0x7e621882,0x6d430012}},	//   _unkn, zedw, trop, ebna
  { {0xdfcf0806,0x539b0008,0x639b000a,0x26c20091}},	//   دين_, _היכו, _הסכנ, nyko_
  { {0x22400213,0xf2d3004c,0xb5fb3bd7,0x2b980016}},	//   mpik_, _טער_, hrán, _ức_
  { {0xb5fb0084,0xa91c002c,0x4c94085d,0xa02400b8}},	//   krán, teľm, фийс, größ
  { {0x7ee60015,0x79880034,0x7b63004a,0x7e620d3a}},	//   _فكأن, wedw, нтье, prop
  { {0xdcfa0024,0x6d430030,0x64550030,0x98be0046}},	//   _patē, bbna, zszi, batě_
  { {0x6d5a0f47,0x1e57000a,0xfaf9003d,0x64550030}},	//   _udta, _משמר_, egūs_, yszi
  { {0x6d3b0008,0x79880026,0x7c3a0b56,0xeaaf002b}},	//   _התבנ, redw, _uttr, نعی_
  { {0xdc8b0008,0xec130015,0x61fe0e1d,0xb5fb19fe}},	//   _לְדָ, _كولد, hopl, grán
  { {0x0f57000a,0x2ba9000b,0xe3bf0077,0x9c0b000a}},	//   היכם_, कारा, _niña_, _הִגִ
  { {0x645516a6,0xba1800a2,0xba170015,0x997601c5}},	//   tszi, _بيتا_, _فينا_, _худш
  { {0xe97b0008,0xa97b0008,0xb5fb0107,0x151400a4}},	//   _הנוש, _האוכ, brán, едря
  { {0x61fe003e,0xd6d10115,0x656e0125,0xb5fb1945}},	//   eopl, _لقب_, agbh, ntáz
  { {0x645500dc,0xb7dc0008,0x92b70029,0x91b90661}},	// [8270] sszi, _לקהי, أحزا, огат_
  { {0x64550030,0x454b006b,0xd0ab01b7,0x6b891086}},	//   pszi, _учим_, йтед_, zeeg
  { {0x25d80053,0x0638002b,0x6e3b3bd8,0x212a002b}},	//   _מוזן_, _وسیع_, _stub, زينی_
  { {0xe29f0084,0xa3c3000b,0x0464005e,0x4f9402a3}},	//   _eyða_, ऍसओ_, _ятьм, ершу
  { {0x6ff50050,0x98be0089,0x539a0008,0x7dcf0293}},	//   jące, tatě_, _וירו, _løse
  { {0x6ff5002a,0x6b890079,0xdb070003,0xac3932b1}},	//   dące, weeg, _éléc, очих_
  { {0x6b890005,0x6ca70010,0x26c2002a,0xa0c5006e}},	//   teeg, ярдж, zyko_, _غيرو
  { {0xc478000a,0x2fc60085,0x5f9403fa,0xfaf10015}},	//   פתחו_, ckog_, _пист, َثة_
  { {0xc334013a,0xad270086,0x60180080,0x8d8703fc}},	//   עוץ_, _فراو, _хотя_, _нужд
  { {0x26c200df,0x9d55002b,0xd8750015,0x08c5029b}},	//   vyko_, _آنات, واجب, дбон
  { {0xb5fb099c,0x8d740086,0x3136000a,0x6b89007c}},	//   trán, _سالا, ונתם_, peeg
  { {0x66e6070e,0xe73704f7,0x3cfa000a,0xa09a004c}},	//   дома, мею_, _ולענ, קירט
  { {0xcf560008,0xab0b0086,0xd7f90011,0xb5fb02c1}},	//   וברת_, _اتاق_, crăm_, rrán
  { {0xb21b3bd9,0xe5e20033,0x34aa005e,0x69c6003d}},	//   _spæn, тымi_, овго_, ūker
  { {0x2fcd3bda,0x49da009a,0x61fe3bdb,0x0000006a}},	//   _oleg_, _بانگ_, vopl,
  { {0xf8b20008,0xf7720015,0xf7f60015,0xe3bf039f}},	//   _ישו_, _شاب_, _تستد, _piña_
  { {0x27f70015,0x422620ae,0x764b02de,0x29070034}},	// [8280] _تفيد_, ддав, _ægyp, _hyna_
  { {0x2fcd0011,0xe3bf0077,0xdb240030,0xe56a0058}},	//   _aleg_, _viña_, éséi, _بمدى_
  { {0xf2c90008,0xc0590010,0x6ff5002a,0x2fc60085}},	//   סע_, зіі_, zące, tkog_
  { {0x61fe00fb,0xb5fb0089,0x4f0a05aa,0x2240007c}},	//   sopl, hrál, онен_, ppik_
  { {0xa91c006f,0xdcf80046,0xa248002b,0xb5fb0de4}},	//   teľk, bevě, _ریال_, král
  { {0x7d780029,0xddc20089,0x2fc63bdc,0xb5fb002d}},	//   سمبر_, stož, skog_, tuái
  { {0x6da300d0,0xb5fb2654,0x27e0005b,0x0000006a}},	//   тија, drál, _omin_,
  { {0xcfaa0029,0x5e460015,0xeb970054,0x7ac6004a}},	//   _باسم_, _يَأْ, дић_, дсое
  { {0x298a0442,0xda7a0033,0x2907007f,0x0000006a}},	//   осно_, цяй_, _ayna_,
  { {0xb5fb3bdd,0x27e020fb,0x29070177,0xdebb000a}},	//   stáz, _amin_, _byna_, _וממל
  { {0x48aa005e,0xf1bf0016,0x394e001a,0x7afd007f}},	//   ітом_, _quái_, _vefs_, üstr
  { {0x5ba50036,0x29070026,0xa7fd0061,0x3cf101c0}},	//   _пріз, _dyna_, arın, ťový_
  { {0xbc1b0053,0xa7fd0061,0xb5fb0314,0x46a40033}},	//   _וואש, brın, brál, ваўв
  { {0x27e001e2,0x34951006,0xa2d9000b,0x1da40065}},	//   _emin_, нагр, _नेग्, _गोमत
  { {0xe4e40036,0x62860024,0x7dc6002e,0xa4d502a3}},	//   вітн, _apko, _aðsk, хові
  { {0xddc90046,0xe787005e,0x27e0002a,0x6c18000a}},	//   _dveř, _цуко, _gmin_, לֵּו
  { {0x6b82002d,0xe0d0002b,0x52150317,0x7d083bde}},	// [8290] _mbog, یزم_, едат, _lyds
  { {0x91e40001,0xdddb3bdf,0xeab1004f,0x69c83be0}},	//   вође, _opuš, נֹן_, nkde
  { {0x35f8003b,0x3cde0157,0x6b820b28,0x0000006a}},	//   _تريد_, _केले_, _obog,
  { {0x251a0008,0xd91b000a,0x2ef500d7,0x351a000a}},	//   _מותא, קואל, нзер, _מותנ
  { {0xde580036,0x733a0053,0xddc90089,0xa7fd0064}},	//   дачі_, _מערס, _zveř, yrın
  { {0x3e320029,0x41e70010,0x6b8226c6,0x248d002a}},	//   دفور, _ціма, _abog, łemu_
  { {0x63bd3be1,0x7d080034,0xa7fd0061,0xfd360015}},	//   _kosn, _cyds, vrın, ركيب_
  { {0x6aa20026,0xd9b9000b,0x6ab5006b,0x672d3be2}},	//   _brof, ेस्ट, есох, _ngaj
  { {0xb5fb16c9,0xba250719,0x6aa23be3,0x2907240e}},	//   trál, ндик, _crof, _syna_
  { {0xb5fb002d,0x9c870015,0x2a620030,0x5cc7006b}},	//   frám, _يشاه, ákba_, _осез
  { {0xe3bf02c1,0xf1b2000a,0xac740015,0xa7fd0061}},	//   _niño_, אסי_, _لانش, ltıy
  { {0x0b780015,0x78bc0123,0x4c9a000a,0x98160015}},	//   _يصنع_, ärva, _מבעו, عبدا
  { {0xa7fd01e2,0x0aeb0086,0x98ab0061,0xb5fb0077}},	//   ntıy, _براي_, ğcı_, arám
  { {0x99840015,0x69c80400,0x7bc93be4,0x6b821207}},	//   _للهو, ckde, lkeu, _zbog
  { {0x63bd3be5,0xc4c6006e,0x443e01f6,0x63863be6}},	//   _bosn, رتسو, ët_, нгва
  { {0xd91a0053,0x7bc900f2,0x42d6042b,0x97c60015}},	//   _צוקל, nkeu, нізу, _ستعم
  { {0x7bc9022d,0x443e231a,0x21a6004a,0xd1ca0033}},	// [82a0] ikeu, ūt_, ниам, плае_
  { {0x42070001,0x7bc9008c,0x6b9901f9,0x61e50052}},	//   енуо_, hkeu, _lawg, gihl
  { {0x7bc900f2,0x71730021,0xddc90046,0x1f660190}},	//   kkeu, اهما, _uveř, екем
  { {0x543b0053,0x6e280123,0x78bc0789,0x59a60065}},	//   _מעטא, _sidb, ørvi, _कोनर
  { {0x97570008,0xbea30010,0x62890024,0x6b9b0026}},	//   תינו_, лацк, _ģeog, ddug
  { {0xa2d9000b,0xf653004c,0x61e50061,0x63bd0417}},	//   _नेट्, נצו_, cihl, _zosn
  { {0x25f1000b,0xa7fd0061,0xac2601cf,0x100a0058}},	//   ँचती_, atıy, нфик, _فترى_
  { {0xe8df0016,0x6b9b02f2,0x6c830015,0x600a0046}},	//   _chửi_, gdug, اليم, kými
  { {0x60e000df,0x7b14006b,0x0d8624d2,0x0000006a}},	//   žymė, ъдих, _план,
  { {0x7d0800dd,0xc0c6002e,0x1e57000a,0xa7fd0061}},	//   _tyds, _óásæ, _נשבר_, arıl
  { {0x5fc4000b,0xeafa002b,0x764d04a9,0x6a130067}},	//   _वकाल, _کرات_, _sway, دبير
  { {0x2d9c00dc,0x4bda0021,0x98140015,0xd0060015}},	//   ldve_, _عباد_, ُبَا, شل_
  { {0xcf9300b2,0x63bd3be7,0xdce30535,0x0000006a}},	//   נטש_, _rosn, rgną,
  { {0x5b130036,0x63bd0bba,0xceb305bd,0x0ae90015}},	//   _сміт, _sosn, איש_, _ترمي_
  { {0x63bd00bd,0xc9530008,0x8937000a,0x2d8e0012}},	//   _posn, _עמק_, _ארוע_, iefe_
  { {0x4394004a,0xf4130058,0xf77f059d,0x672d013b}},	//   ласс, اؤس_, biça_, _ugaj
  { {0xe1670001,0x8c1b0008,0x57fc000a,0x2167009b}},	// [82b0] еђен, לולי, _מלהו, етег
  { {0x8cb1005d,0x0000006a,0x0000006a,0x0000006a}},	//   _अपलो,   ,   ,
  { {0xc9530053,0x63bd002d,0x7ff4002b,0xd5640033}},	//   רמע_, _tosn, گسلا, _стып
  { {0x60c500f2,0xe817005d,0xa7fd0061,0xfe7100c3}},	//   ryhm, _धीमा_, ttıy, لدت_
  { {0xee3813ae,0xd356009d,0xc7d8000a,0xa3e6000b}},	//   ені_, _שישי_, עודי_, _भगत_
  { {0x31350001,0x8d620080,0x7bc90111,0x61150033}},	//   _јевр, авше, wkeu, _адгу
  { {0x645a04c6,0xb5fb0030,0x853c004f,0x0000006a}},	//   štiv, tráj, הגוי,
  { {0xddc20007,0xa7fd0061,0x63a9001a,0x59a6000b}},	//   ruoš, ptıy, _óend, _कोबर
  { {0x89d50010,0x442b3be8,0x7bc93be9,0x7d040046}},	//   вінш, _mic_, rkeu, řisp
  { {0x3f8f002e,0x3cfa000b,0xddc20091,0xdd940021}},	//   legu_, _ऊँचे_, puoš, _مجمع
  { {0x99910014,0xa3c3005d,0xc2120008,0x442b0e2d}},	//   öző_, ्सा_, שהי_, _oic_
  { {0x3f8f0176,0xf77203c4,0x442b037f,0xe73a004a}},	//   negu_, جاد_, _nic_, ьем_
  { {0x4433038d,0x2f5a0008,0xa91c006f,0x77430015}},	//   _aux_, ודרנ, deľu, شَّم
  { {0x7d0401e2,0x67eb00f2,0xa8490015,0x1869009b}},	//   şise, töjä, _قلتم_, _жаки_
  { {0xdce10064,0x8ca4005d,0x05760086,0x80c0000b}},	//   _kalı, कियो, _یادد, _एथें
  { {0x2d9c00dc,0x739905e6,0x442b00a9,0x3f8f0085}},	//   zdve_, нтус_, _cic_, jegu_
  { {0x44330152,0x2ebd005d,0xa2061365,0x02c32ed2}},	// [82c0] _eux_, ्नोत, впад, айто
  { {0x06570008,0x602c0064,0xf62a0029,0x79810034}},	//   _שייך_, _aşma, _تسعى_, nflw
  { {0xe0d20029,0x27f70086,0xd6a90086,0xd12f00a2}},	//   جزء_, _سفید_, _قدیم_, زمن_
  { {0x2d850041,0x6e460010,0xbe8a0001,0xddce005c}},	//   _able_, ведз, дске_, żdża
  { {0xf6ed000a,0xd37b0033,0x7dd40144,0x44203bea}},	//   ּחוּ, зiцы, _làse, mmi_
  { {0x6143008f,0x3f8f0020,0xf1bf0092,0x44203beb}},	//   _вера, aegu_, _quát_, lmi_
  { {0x318300dc,0xdce10064,0x319b000a,0xac73002b}},	//   észő_, _balı, _קבלנ, لايش
  { {0xb4fb0008,0xd9ca005d,0x442012d7,0xb5fb163c}},	//   ופצי, िस्ट, nmi_, nuár
  { {0xa9340010,0xdf370015,0xdce10061,0xee260033}},	//   лепш, _شكلت_, _dalı, _амап
  { {0x98b8000d,0x79a60579,0x29d40015,0xba180015}},	//   елот_, трие, ايدس, عيدا_
  { {0xc1570008,0xb5fb00dc,0x6d583bec,0xbb860015}},	//   כשיו_, lság, mava, _للاي
  { {0x44201ea8,0xdcfa003d,0xa91c006f,0xbb46058f}},	//   jmi_, _latī, deľt, _редк
  { {0xb5fb0014,0x2902005c,0xb9960015,0xe667006b}},	//   nság, łka_, _للشب, ътно
  { {0x3f8f005c,0x44203bed,0x7dcf0293,0x6d583bee}},	//   zegu_, emi_, _løsn, nava
  { {0x645c00c0,0xe454004a,0x2a150033,0x3f9d002a}},	//   gsri, икры, _сьцё, ydwu_
  { {0xa3dd005d,0x63680bb9,0xa77500d7,0xb8e8000b}},	//   थों_, круг_, _слич, ोन_
  { {0xb5fb03d9,0xd234006b,0x6d5837df,0xd2510015}},	// [82d0] hrái, интъ, kava, صنا_
  { {0xb5fb0097,0x51f80080,0x6d583bef,0xcad7000a}},	//   dság, вную_, java, דומת_
  { {0x3c380014,0x442b130f,0xc1040015,0x3f8f007c}},	//   _név_, _tic_, لوكي, tegu_
  { {0xe4a40036,0x6f65002b,0xb5fb016e,0x6d583bf0}},	//   _трьо, اهشم, cuár, eava
  { {0x35a8005d,0xb5fb00dc,0x79810026,0x8e853bf1}},	//   _छोड़, gság, yflw, угле
  { {0x3e7b0152,0xed58002c,0xa3c3021e,0xdce10061}},	//   rêt_, _poľa_, ्सव_, _salı
  { {0xdb0b0152,0xc1720008,0x5c540033,0x24f7000a}},	//   _ingé, _לחם_, атыф, כֶ֗ם_
  { {0x6d580209,0x7c3e0057,0xbcd80015,0x1fa4021a}},	//   aava, ípra, خذها_, _круг
  { {0x6d581e8f,0x8d770015,0x7c2b0e05,0xeab10058}},	//   bava, _لاضا, _vigr, صعة_
  { {0x3c380003,0x6720004c,0x987e0061,0x6d583bf2}},	//   _fév_, גאַני, _açıp_, cava
  { {0x35c6005d,0x44203bf3,0xd7ea219d,0x7c2b3bf4}},	//   रॉफ़, ymi_, емне_, _tigr
  { {0xbbeb0015,0xa2b8000b,0x366a012a,0x9be400ce}},	//   _غرام_, ोहम्, намо_, _кічк
  { {0x200f0064,0x3fda000a,0xda65006b,0xaba80040}},	//   ilgi_, תקרב, _свли, _جهنم_
  { {0x645c3bf5,0xda5a004f,0x0000006a,0x0000006a}},	//   tsri, _טכנל,   ,
  { {0x2a7f0020,0xb5fb3bf6,0x69fa000a,0x48e5005e}},	//   ltub_, zság, _אלסק, _щокв
  { {0x6d580014,0x44203bf7,0xb882006f,0x8624002b}},	//   zava, umi_, číti, _چکسل
  { {0xdcfa0024,0xaa36004c,0x03a3004a,0x645c134d}},	// [82e0] _patī, ָטעק_, щито, ssri
  { {0xddd4002c,0xb5fb001c,0x76440035,0x7dd40144}},	//   _ťažk, suár, _itiy, _màsc
  { {0xd12f003b,0x2a7f0020,0x8fa61179,0x6d583bf8}},	//   أمم_, htub_, лаже, vava
  { {0x4444003e,0xb5fb00dc,0xb4c2021e,0x2a7f1d41}},	//   _it_, tság, ्नी_, ktub_
  { {0xa3c3005d,0x7de60010,0xf2c50010,0x6d583bf9}},	//   ्सर_, лікд, _ксён, tava
  { {0x27030092,0xb5fb3bfa,0x44443bfb,0x9fb8005a}},	//   ổng_, rság, _kt_, mčí_
  { {0xb5fb0014,0x44443bfc,0x6d58201f,0xbc670015}},	//   sság, _jt_, rava, همون_
  { {0xb5fb002f,0x7dc60084,0xcc870087,0xf77f016e}},	//   rrái, _aðst, انيه_, viço_
  { {0x0aea0029,0xfd760002,0x9fb80227,0x600b000a}},	//   عربي_, _مداخ, nčí_, _נִלְ
  { {0xa27b0053,0xfe37000a,0xf27b004c,0xbebd003d}},	//   עװיז, _ערבי_, עריש, _egūs
  { {0x28f80286,0x44443bfd,0x2d9e016e,0x62960034}},	//   тень_, _nt_, _iate_, hwyo
  { {0x2006020a,0x2d9e003e,0x2cfb0135,0x3cfb000a}},	//   nooi_, _hate_, _אלבא, _אלבנ
  { {0xa91c032c,0x44441a8d,0x858b01b0,0x2d9e08b9}},	//   teľs, _at_, нёва_, _kate_
  { {0xb5fb0057,0x5a9b000a,0x62960034,0xb4c2000b}},	//   hráv, _נשוא, dwyo, ्नू_
  { {0xa4d40036,0x19570008,0x0cd40008,0x94d403e3}},	//   борі, _גבול_, בֵּר_, борц
  { {0x2d9e0a99,0xd90e002b,0x44443bfe,0x261a0065}},	//   _late_, _ویک_, _dt_, _मीठी_
  { {0xe5e50086,0xfc3f0264,0x1155034e,0x2259004a}},	// [82f0] _نزدی, _čím_, икаю, тизы_
  { {0x44443bff,0x1154008b,0x600a0046,0x54552ae4}},	//   _ft_, йкую, kýms, _квот
  { {0x30a70010,0xa0a7004a,0x8f0001f3,0x6ee7002b}},	//   ырав, ышал, нiя_, گسال
  { {0xb4d1005d,0x200600dd,0x64453c00,0x900b0015}},	//   वनी_, gooi_, _ithi, رزاق_
  { {0x8db5005e,0x6ee7002b,0x44440030,0x7fb600c3}},	//   искі, دسال, _zt_, شهور_
  { {0xd658039e,0x60180089,0xdbde002e,0xada53c01}},	//   ניות_, tímc, _síðn, ракл
  { {0xdcf80048,0xeb99087a,0xabd50e88,0x2d9e352d}},	//   devē, вий_, ициј, _date_
  { {0x3ff900b2,0x9e95002b,0xdb4e0015,0x5ba913d0}},	//   _ספּע, _پارچ, وَى_, тким_
  { {0x2d9e052a,0x59a6000b,0x22490079,0x290e0061}},	//   _fate_, _कोहर, npak_, _ayfa_
  { {0x2d9e10b8,0x8d74012c,0xe885023c,0x88851673}},	//   _gate_, _هاما, агоп, алож
  { {0x6ce40036,0x2a7f0020,0x29020064,0xdbde002e}},	//   _ліце, stub_, şkan_, _tíðn
  { {0x44443c02,0x22490035,0xf8ae002b,0x4cba000a}},	//   _rt_, kpak_, بکه_, _במעג
  { {0xa3b9005d,0x44443c03,0x27f9001a,0xe9ce2fa0}},	//   चान_, _st_, érna_, _дк_
  { {0x9fb80089,0x98a50180,0x44443c04,0xe4da002b}},	//   včí_, _вике, _pt_, پورت_
  { {0xb4c2005d,0xf623005e,0xb4260015,0x2b4d002a}},	//   ्ने_, ідсо, لعرو, obec_
  { {0x44443c05,0xd3720015,0x82360015,0xa3a9000b}},	//   _vt_, تهر_, لرئا, _गोद_
  { {0x60180107,0xe61a0155,0x6d4109bb,0x64453c06}},	// [8300] jíma, _иди_, _ofla, _ethi
  { {0x673b002c,0xbbd2005d,0x5bd2000b,0x28ca000b}},	//   ľuje, _तत्क, _तत्व, ानचि
  { {0x4444069c,0x2d9e1844,0x69c33c07,0x7de6002b}},	//   _ut_, _rate_, _mone, یستم
  { {0xddc20048,0xc334000f,0x6d413c08,0x03a61921}},	//   droš, _לוֹ_, _afla, _тимо
  { {0x1e96030c,0x8d760058,0x6fdf0065,0x2d9e3c09}},	//   ррер, لاغا, पोइं, _pate_
  { {0xdb0b3c0a,0x69c300da,0x9f4f0030,0xcf250015}},	//   _logó, _none, fogó_, حرمي
  { {0xb5fb0f1b,0x8f76005e,0xdb1b0160,0x0000006a}},	//   práv, _вузі, ljuè,
  { {0x309b000a,0xdfd20015,0x0b8a0289,0x1d070054}},	//   _בשלמ, _بير_, тски_, јећи_
  { {0x6d410026,0xee370010,0x600b000a,0x69c308a2}},	//   _ffla, _вну_, _יִמְ, _bone
  { {0x4e7b013a,0x64430003,0xf9c60296,0x69c33c0b}},	//   _באמצ, _énig, рщин, _cone
  { {0x313704dc,0x291800c0,0xe7590036,0x6607016f}},	//   ינים_, åra_, лині_, vojk
  { {0x961f005d,0xe6950080,0x0aea004a,0x38330138}},	//   पष्ट_, бимы, _идей_, ўняр
  { {0x86740036,0xaaba0021,0x75d50015,0xe698006b}},	//   оляє, _جدار_, ميحا, авяш_
  { {0xb607005e,0x69c33c0c,0x3ea6055c,0x648b009b}},	//   рямк, _gone, ivot_, ксбг_
  { {0x19bb000a,0xb5fb3c0d,0x66073c0e,0xe4a42dfa}},	//   _במגב, drát, rojk, орто
  { {0x8335006b,0xb5fb0030,0x69c30c90,0x9cd7000a}},	//   снах, usáb, _zone, בולה_
  { {0x69da00f2,0xd7fc0008,0x8b57004c,0x64450034}},	// [8310] ohte, _שהחל, ייןס_, _wthi
  { {0xf5950015,0x6f0d002a,0xa0a7004a,0x683e003d}},	//   _الدج, żack, ишел, _zīda
  { {0xd1382cd4,0x6445003f,0xe1340033,0x69da1af8}},	//   рху_, _uthi, інцы, ihte
  { {0xb5fb00dc,0x6018002e,0x0000006a,0x0000006a}},	//   arát, tíma,   ,
  { {0x6d4100b8,0x27f200dc,0x25a10012,0xbea51b42}},	//   _pfla, ézni_, _kahl_, салк
  { {0x8e080036,0xddc201a3,0xb5fb0656,0xfde2000b}},	//   анів_, troš, crát, कोलस_
  { {0x27e93c0f,0x3c93002b,0x98be0091,0x25d8000a}},	//   _oman_, تیاز, matė_, שוון_
  { {0x351c0008,0x69da0020,0x251c004c,0x7c9400c3}},	//   כוונ, ehte, כווא, تشها
  { {0x93b80008,0x69c33c10,0xdb0b002a,0x0000006a}},	//   שלחו_, _pone, _rogó,
  { {0x69da0541,0xdef8054f,0x628f02b9,0x499901b7}},	//   ghte, _тыс_, _mpco, утия_
  { {0x07a60036,0x66680053,0x69c300b8,0xdd150087}},	//   банн, יפֿטצ, _vone, _اواخ
  { {0x69c30186,0x69da3c11,0x867a0033,0xb5fb3c12}},	//   _wone, ahte, лёгу_, krás
  { {0x69c33c13,0xcb36000a,0xa9a514c2,0xeaae056d}},	//   _tone, _האני_, _гилд, _эй_
  { {0x69da3c14,0xe6170080,0x99850015,0x601a0046}},	//   chte, йдя_, _طلبو, _důmy
  { {0x64a60063,0x04460292,0x4e16000a,0xb7d7002b}},	//   щава, себн, מחשב_, _گويا_
  { {0x083a0053,0x17e50015,0xdb0b002a,0xc3060015}},	//   _געקל, _وسيُ, _uogó, مبذو
  { {0x01360029,0xb7db000a,0xc7d7000a,0xb5fb3c15}},	// [8320] معاد, _תקפי, _לוקי_, grás
  { {0x79c9004f,0x0000006a,0x0000006a,0x0000006a}},	//   נֶּ֔,   ,   ,
  { {0x66250015,0x629d3c16,0x6f1b010d,0x7537000a}},	//   _بريك, _esso, _azuc, _לאיד_
  { {0x25a100b8,0x9e660015,0x00190033,0xb5fb0030}},	//   _zahl_, ماتن, аўчы_, brás
  { {0x69da00f2,0xdfa50015,0xdef40033,0x823600c3}},	//   yhte, تحلي, ўплы, _درجا
  { {0x63a43c17,0x3ea6008c,0x8ca4000b,0x443a3c18}},	//   ldin, rvot_, किलो, _kup_
  { {0x628400f2,0xf41f00f2,0x515b000a,0xb5fb016e}},	//   ltio, _yhä_, _תכלו, orár
  { {0x00f7000f,0xb33b0064,0x4f6500c3,0x443a34f3}},	//   _המלך_, _kaça, _واقف, _mup_
  { {0xfaa30010,0x62840220,0x7f3b000a,0x63a43c19}},	//   пшэн, ntio, _תעמו, idin
  { {0xf77f01e2,0x984a0063,0x69dd0007,0x729b000a}},	//   miçi_, ляма_, ūsen, נסיס
  { {0x8b660086,0xa7b90001,0xc1bb0053,0x41bb0053}},	//   _هاشم, алну_, אמיש, אציע
  { {0x63a40111,0x7bdb003f,0xaba50015,0x7a86002b}},	//   jdin, chuu, _وإنه, _هشتم
  { {0x6d5a0375,0xcb160015,0x7e623c1a,0x63a43c1b}},	//   _keta, _اذاع, nsop, ddin
  { {0xd6d80191,0x6d5a0003,0x4a7b000a,0x63a43c1c}},	//   стю_, _jeta, _ערוב, edin
  { {0xa4d40036,0xdce80064,0x443a3c1d,0xd7e7008b}},	//   порі, _kadı, _cup_, _гіпо
  { {0x25a100b8,0x36340086,0x395e3c1e,0x6d5a3c1f}},	//   _wahl_, _کريس, lats_, _leta
  { {0x82f80029,0x2418004a,0x601801c0,0xb33b1702}},	// [8330] مركز_, соты_, tímn, _caça
  { {0x7c3a3c20,0xb5fb3c21,0x6f1b005c,0x395e3c22}},	//   _outr, rrás, _rzuc, nats_
  { {0xceeb0086,0xa5d80086,0x93270086,0xb5fb002e}},	//   گران_, _دبير_, _گردن, srás
  { {0xdea10086,0xdef10015,0x395e0bed,0x3f1507bd}},	//   ویزی, وًا_, hats_, одес
  { {0x7c3a0b7a,0x9e640036,0x2cac0026,0x62840493}},	//   _autr, звід, _ardd_, ctio
  { {0x6d5a3c23,0x395e2262,0xdcf80091,0x365c000a}},	//   _ceta, jats_, nevė, נכונ
  { {0x9f5f00dc,0x59a6000b,0x7c3a15d0,0xa7fd0061}},	//   óról_, _कोइर, _cutr, nrıs
  { {0x8fc7002b,0x69d83c24,0xc43c004f,0x2bb90058}},	//   _ازآن, _alve, נתחי, شابة_
  { {0x7e620014,0x7bdb0079,0xe9d91372,0x395e3c25}},	//   csop, rhuu, ики_, fats_
  { {0x63a400df,0x395e24ef,0x7bc0002a,0xa9690054}},	//   zdin, gats_, ajmu, јина_
  { {0xc1720008,0xd7ca002b,0xfc65002b,0x63a43c26}},	//   וחי_, لوده_, _ذخای, ydin
  { {0xa3a9005d,0x907a00f3,0x69d80832,0x16aa0214}},	//   _गोल_, סטרי, _elve, авми_
  { {0xab640010,0x8f9a000a,0xdb38002b,0x7c3a0012}},	//   _хвіл, בירי, _اسمش_, _zutr
  { {0x395e357f,0xca360008,0xb33b016e,0x68e40046}},	//   cats_, _ונסה_, _raça, _řide
  { {0x6aa91ca2,0xb5fb016e,0x6e3b007c,0x64a309d3}},	//   lvef, trár, _luub, мара
  { {0x50ba0086,0x63a43c27,0xa3e4000b,0x69c10030}},	//   یداد_, udin, भों_, ljle
  { {0x98a50064,0xe2460029,0x628404ad,0xa7fd0061}},	// [8340] malı_, تخزي, utio, arıs
  { {0xe6930086,0x63a40007,0xc7230010,0x62840220}},	//   _کلید, sdin, _ідэй, rtio
  { {0xdbd10064,0x6d5a07fc,0x62841433,0x7056002b}},	//   _güçl, _reta, stio, زنشا
  { {0x98a50064,0x62840220,0x02460015,0x9eaa0004}},	//   nalı_, ptio, _وَجَ, ивеа_
  { {0xdfcf0029,0xde960029,0x4e9600e5,0x7bc63c28}},	//   خين_, تجاب, تشار, ökum
  { {0x3ead0251,0x471b0053,0x7c3a013c,0xed360033}},	//   _dret_, בונג, _putr, цэдэ
  { {0x98a501e2,0x395e0251,0xa06722d7,0x7e623c29}},	//   kalı_, vats_, _мара_, ssop
  { {0xdc2a0086,0x73fa000a,0x69c13c2a,0x7e62042f}},	//   جسته_, יּ֥ו, ejle, psop
  { {0x98f50023,0x395e3c2b,0x6d5a0375,0x98a50061}},	//   uản, tats_, _teta, dalı_
  { {0xddc2005c,0x395e0251,0x670e005d,0xd2b7000a}},	//   społ, uats_, _सड़क_, קלית_
  { {0x395e3c2c,0xeb9a06ac,0x2cac0026,0xdce80061}},	//   rats_, _вие_, _urdd_, _tadı
  { {0x569507c1,0xf8ad002b,0x395e3c2d,0x69c13c2e}},	//   памт, اکو_, sats_, ajle
  { {0x37073c2f,0x39490011,0x395e0333,0x59c60015}},	//   ючов, _şase_, pats_, _ويؤك
  { {0xe8ea002b,0x6ff5002a,0xda7b000a,0xd6270015}},	//   _پرتو_, rąci, _כנדר, تعجي
  { {0xf8aa002b,0xd7fb0033,0xd90f01f3,0x03c70b9b}},	//   _خدشه_, _вуп_, _ць_, осам
  { {0xedb7005d,0xb5fb0030,0xa774006b,0xb8080015}},	//   _इच्छ, csán, _жлъч, _ويوم_
  { {0x7c220026,0xe1f300e5,0xd14b002b,0x58040015}},	// [8350] _mhor, وسط_, لشان_, _تويك
  { {0x44220005,0x91b80080,0x764f3c30,0xa15900ce}},	//   _ehk_, огут_, mpcy, сажу_
  { {0xb8810089,0x91a80015,0x459a000a,0x759a000a}},	//   žíve, تهلك_, _הסתע, _הסתג
  { {0xf4940086,0x3ead3c31,0x764f0546,0x62353c32}},	//   _کشید, _pret_, opcy, _нему
  { {0xb3ba0008,0xe2980010,0x03d6000a,0x13ba000a}},	//   _המרכ, _даў_, _זורם_, _הזרע
  { {0x270a0023,0x7c220467,0x2ba70092,0x2d94006b}},	//   ờng_, _ahor, _ốc_, дръс
  { {0xc2120008,0x98a50064,0xc5f40053,0x8558000a}},	//   _נהל_, yalı_, ודס_, חשוב_
  { {0xe4fc0008,0x44293508,0x34fc0008,0x3ead0251}},	//   יפוש, nma_, יהוד, _tret_
  { {0xf4140008,0xe7af000b,0xb33b016e,0x3ead02de}},	//   ופק_, _जोधप, _laço, _uret_
  { {0x9b020010,0x6aa90e5f,0x44293c33,0x2b5f003d}},	//   эзыд, rvef, hma_, sauc_
  { {0x7c22002d,0x98a50064,0x8afd0046,0xc7a60674}},	//   _fhor, talı_, daře, пинк
  { {0xc5e9000a,0x44290ea1,0xddc2002a,0xad1a004f}},	//   _גד_, jma_, apoń, _הוער
  { {0x98ab01e2,0xbb3a0008,0x44290020,0x98a50064}},	//   ılık_, _העני, dma_, ralı_
  { {0x4422007c,0x7c2201c0,0x7c293c34,0x44293c35}},	//   _shk_, _zhor, lmer, ema_
  { {0xb5fb0089,0x98a50064,0x25080086,0x23d607be}},	//   psán, palı_, زرسی_, пцар
  { {0x44291640,0x28c4000b,0xc2463c36,0x7c293c37}},	//   gma_, _लॅटि, знак, nmer
  { {0xb77b013a,0x877b0008,0x813a002b,0x77f7000a}},	// [8360] _האפש, _האפי, مساز_, _ממקד_
  { {0xb33b3c38,0xa7fd0064,0x7c2900b8,0x21a30004}},	//   _faço, nsın, hmer, ниум
  { {0x80a60029,0x7c29272b,0x6557000a,0xb53b000a}},	//   ثمان, kmer, _מביא_, _לגיש
  { {0xa8560008,0xc209000a,0xc4d3004f,0x7c290160}},	//   פינה_, אה_, _נגר_, jmer
  { {0xa3b9005d,0xa7fd0064,0xb33b0061,0x7c291f20}},	//   चार_, ksın, _maçl, dmer
  { {0x7c22003e,0x1ea900a2,0xad660015,0x471b004c}},	//   _shor, غاني_, ساته, זונג
  { {0x7c291430,0x395c10ad,0x7c223c39,0xdfd20015}},	//   fmer, _revs_, _phor, _كيس_
  { {0x6c470029,0x8fa30010,0xf48d0008,0xdcf80024}},	//   أليف_, _пасе, ׁאוּ, levī
  { {0x63a63c3a,0x9a830088,0x7acd02ed,0x0000006a}},	//   _makn, нуэл, а́те,
  { {0xd8f80036,0xdca63c3b,0x63a60030,0x44293c3c}},	//   жної_, _нази, _lakn, zma_
  { {0xa319005d,0x7c220541,0x38c8002b,0x1799004a}},	//   _दर्ज_, _thor, زادی_, овны_
  { {0xd0f70008,0x7c22002c,0x4c3b000a,0x63a63c3d}},	//   למית_, _uhor, _התאב, _nakn
  { {0xdb000089,0x86270033,0x96f8006b,0xdaba002b}},	//   odmí, зьве, зеят_, _دهشت_
  { {0x1a9b01ac,0xdb0b002d,0x34950033,0xd6240015}},	//   _לידע, _ungá, магр, ّعِي
  { {0x25780088,0xdcf8003d,0x44293c3e,0xf1c2003d}},	//   ябрь_, devī, tma_, iešā_
  { {0x799a003f,0x8afd0046,0x44290a38,0xb8e2000b}},	//   letw, saře, uma_, ृह_
  { {0xa294005e,0x44293c3f,0x69ca3c40,0x960b0138}},	// [8370] наті, rma_, _kofe, _гэна_
  { {0x7c2912d7,0x52140342,0x764d02f2,0x05790015}},	//   zmer, едут, _itay, _بمدة_
  { {0x7c290026,0x44290064,0x66280089,0xb4670029}},	//   ymer, pma_, řské, _عدده
  { {0xc1040196,0xa7fd0064,0x08770053,0xb33b0061}},	//   روني, zsın, לעבט_, _kaçm
  { {0x82a40010,0xada500f4,0x6da507ec,0x996c01ec}},	//   _заўж, далл, дила, zēšu_
  { {0x69ca0026,0xb2ba000a,0x6b820077,0x2d8113aa}},	//   _nofe, _ומשר, _acog, ühe_
  { {0xdca20063,0x7c940010,0x63a6013c,0x6ca40015}},	//   ващи, ерыц, _yakn, فصيل
  { {0x4906005d,0x8d180015,0x04dc000a,0x7c293c41}},	//   _सँजो_, أزهر_, מקול, umer
  { {0xb33b0061,0xcf92000a,0x200f002a,0x7c293c42}},	//   _raçl, _בטן_, mogi_, rmer
  { {0x39e90191,0xbe640015,0x5c650015,0x9f4f0003}},	//   ідно_, _أهلي, _يُذك, digé_
  { {0xa7fd0064,0x7c293c43,0x764d0d40,0x6aa23c44}},	//   rsın, pmer, _atay, _esof
  { {0x6b82002d,0x7e690091,0x200f3c45,0x996c003d}},	//   _gcog, _kvep, nogi_, rēšu_
  { {0xceb20008,0x63a6002e,0x6f28000a,0x7b740058}},	//   ֣ים_, _rakn, ּ֥רְ, _أطما
  { {0x63a602ce,0x69b7000b,0x69ca0034,0x9e76000a}},	//   _sakn, _ऍचटी, _gofe, וגשה_
  { {0x7bcb0005,0x660e1a8f,0x764d0061,0x78480046}},	//   _kogu, robk, _etay, _pěve
  { {0x237a0015,0x42d600fd,0x200f0980,0x7bcb3c46}},	//   تمرد_, мізу, jogi_, _jogu
  { {0x7bcb3c47,0x63a605d7,0x9f600046,0x05560a32}},	// [8380] _mogu, _vakn, ásím_, _отня
  { {0x6b9b0111,0x70f60029,0x00da0015,0x7bcb3c48}},	//   heug, وسائ, يبات_, _logu
  { {0x55bb000a,0x8f090033,0x8888000a,0x142606da}},	//   _ומיו, нaя_, ּ֨עַ, _одом
  { {0x799a005c,0xef1a3c49,0x41170015,0x3fcb002b}},	//   zetw, оме_, ذينج_, يدنی_
  { {0xde580010,0x067b0053,0x27f900dc,0x539b0008}},	//   чалі_, ַנקל, érni_, _ויכו
  { {0x61ee1036,0x6b820363,0xbc4a0a32,0xdd1c0069}},	//   _umbl, _scog, очие_, _váži
  { {0x2075004a,0xf1c2003d,0x7c860004,0x7bcb3c4a}},	//   _путё, rešā_, фуле, _bogu
  { {0x69ca336e,0x7dcf0af5,0xdb5a09a0,0x0000006a}},	//   _sofe, _søst, цюк_,
  { {0x5a34085d,0x1eaa002b,0x0000006a,0x0000006a}},	//   ннит, _بازي_,   ,
  { {0xa7fd0061,0xdb1b001a,0x7e970015,0x61fe00cb}},	//   asıl, rkuð, _تنكر_, nnpl
  { {0x764d003e,0xd7f50080,0x7bcb3c4b,0x79a30033}},	//   _stay, езны, _fogu, трые
  { {0x6c060033,0x2fc60030,0x2d9c3c4c,0x7bcb2239}},	//   _ўздз, njog_, leve_, _gogu
  { {0xc6e7005e,0xfb87002b,0xeafa0067,0xcf57000a}},	//   фінп, _آدمی, _برات_, ובכת_
  { {0x7dd40251,0x9f4f0003,0x2d9c3c4d,0x4b37004f}},	//   _bàsi, rigé_, neve_, _חרדל_
  { {0x16340a61,0xe97b000a,0xa97b000a,0xf8070054}},	//   теря, _ונוש, _ואוכ, _очин
  { {0xaad2000b,0x2d9c2043,0x4394030c,0x0000006a}},	//   _तथाक, heve_, касс,
  { {0xd2510015,0xa7fd0061,0x9f4f00cb,0x4735005e}},	// [8390] انئ_, nsım, nngå_, _янис
  { {0xdbd60005,0x6b9b018b,0x2d9c044c,0xd6270002}},	//   _hääl, zeug, jeve_, _تعبي
  { {0xdb0b00c0,0x99610024,0x2d9c091d,0x200f0c84}},	//   _ingå, nūšu_, deve_, togi_
  { {0x4f94000d,0x7e6d0024,0x212a002b,0xb33b007f}},	//   вршу, šapm, سينی_, _maçk
  { {0x3376000a,0x217b0015,0x8f340033,0x41b50015}},	//   _אתרך_, _وحسب_, вецц, _كمحر
  { {0x0ea80191,0x4439003e,0xfe700087,0x8eb2002b}},	//   ькій_, _his_, شده_, اموش
  { {0x7bcb3c4e,0x443900dc,0x7ddd0144,0x200e001a}},	//   _pogu, _kis_, _cèsa, ókið_
  { {0x443900df,0xdc28002b,0x539a000a,0xf538004f}},	//   _jis_, وسيه_, ִיתו, וטור_
  { {0xeab10029,0x44393c4f,0x7bcb3c50,0x3f9d01d7}},	//   اعب_, _mis_, _vogu, mewu_
  { {0x3f9d005c,0x2d9c02b9,0xd256000a,0x44393c51}},	//   lewu_, ceve_, עשתה_, _lis_
  { {0x05c3000b,0x0ca8029f,0x2fdf0012,0xbca40015}},	//   शानब, _отци_, _klug_, _لملي
  { {0xf77204c9,0x29190024,0xddc20089,0xe73a0256}},	//   داد_, āsa_, dpoř, яем_
  { {0x96ba0124,0xa3b9005d,0xb5fb206e,0x2fcd00aa}},	//   чуну_, चाई_, osáh, _moeg_
  { {0x4439260d,0x64a6070e,0x6448016e,0x7bc61288}},	//   _ais_, нага, ídio, ökuv
  { {0x4439018b,0x4736002b,0xfd070067,0x89da000a}},	//   _bis_, برگز, اج_, _מחסי
  { {0x04570029,0xccf2000a,0xdb0b0123,0x93a90015}},	//   علقة_, אכל_, _engå, واقف_
  { {0x57fb000a,0xd7fb000a,0x74130015,0x44393c52}},	// [83a0] _מלקו, _מהקל, اوقا, _dis_
  { {0x6f16002a,0xdb0900aa,0x79810034,0x44393c53}},	//   życk, edeë, nglw, _eis_
  { {0x40960010,0x44393c54,0xb5fb0030,0x13a8002b}},	//   эрат, _fis_, zsák, _قندی_
  { {0x24f50010,0x7c390026,0x245e0046,0x8afd0046}},	//   _шчыр, _niwr, mům_, zařa
  { {0x245e02d5,0x433b000a,0x2d9c3c55,0x6441013f}},	//   lům_, _מעכב, teve_, íliv
  { {0x44390011,0x867b000a,0x828b000a,0x2d8e0003}},	//   _zis_, פרצו, _מְלֶ, uffe_
  { {0x245e0089,0x27e00e95,0x7c390034,0x2fdf0b2d}},	//   nům_, _olin_, _biwr, _flug_
  { {0x80260086,0x251b000a,0x2d9c3c56,0x2242007c}},	//   _سرزم, הוצא, seve_, _kukk_
  { {0x7c390176,0x539b000a,0x245e0046,0xab270054}},	//   _diwr, ליקו, hům_, ноћа_
  { {0x245e0089,0x2ca9005c,0x2c57005c,0x27e03c57}},	//   kům_, łada_, _będę_, _alin_
  { {0x29180084,0xdbd600f2,0x2242003c,0x245e0089}},	//   æra_, _pääl, _lukk_, jům_
  { {0x245e0089,0x1ae620ae,0x040e0016,0xf7440004}},	//   dům_, _поем, rưởn, леџо
  { {0x6d4a002d,0x7bc63c58,0x44393c59,0x0000006a}},	//   ocfa, ökuu, _ris_,
  { {0xb8660029,0xddc20046,0x27f20034,0x44393c5a}},	//   _كابو, hrož, _emyn_, _sis_
  { {0xd5b80080,0xdbd600f2,0x27e00026,0x24190010}},	//   хся_, _tääl, _flin_, довы_
  { {0xb5fb0089,0xe3b30002,0x9cbb000a,0x69c80123}},	//   zsáh, درس_, הצלח, ljde
  { {0x98ac01e2,0x46680010,0xb5fb002d,0x44393c5b}},	// [83b0] madı_, _прэм_, hsái, _vis_
  { {0x98ac0064,0x91e40054,0x7e6d003d,0x69da153c}},	//   ladı_, гође, šapk, nkte
  { {0x69c80111,0x44393c5c,0x245e0046,0x7d1a001a}},	//   ijde, _tis_, cům_, _nyts
  { {0xa8570008,0x83190015,0x98ac0061,0xddc202d8}},	//   גיאה_, _يقدر_, nadı_, grož
  { {0x2fcd1786,0x8d750015,0x63ad3c5d,0x2fdf042f}},	//   _voeg_, ناثا, mdan, _vlug_
  { {0x0c95006b,0x7c390034,0xc694000a,0x63ad3c5e}},	//   вшия, _siwr, ראס_, ldan
  { {0x301b0029,0x63ad3c5f,0xcfe9002b,0x628d3c60}},	//   _فترة_, odan, _قفسه_, ltao
  { {0xdf720086,0xae0f005d,0xac440086,0xeb9900a5}},	//   _نگهب, िवहन_, دئوه, фии_
  { {0x8b250063,0x628d3c61,0x8ca1000b,0xb5fb0125}},	//   ъдие, ntao, _कैरो, asái
  { {0xfe67002b,0x63ad26a6,0xb5fb0030,0x49990d3c}},	//   ید_, hdan, aráz, фтия_
  { {0x9b950029,0xac740029,0xba750086,0xaac4002b}},	//   _للات, _مانش, راکت, نتین
  { {0x79810026,0x245e0089,0xaa890015,0x366a0054}},	//   sglw, vům_, _ينضم_, мамо_
  { {0x63ad00f8,0x21e400b8,0x8bd6000a,0x4803009b}},	//   ddan, _höhe_, _שונו_, рпяв
  { {0x7ae90014,0x245e0089,0x69da3c62,0x7bdb01be}},	//   mzet, tům_, ckte, lkuu
  { {0xa806010f,0x7ae900dc,0xc952000a,0x32133c63}},	//   _изкл, lzet, _דמו_, doxy_
  { {0x6f16005c,0x245e0089,0x7bdb00f2,0x9f4f0125}},	//   życi, rům_, nkuu, angú_
  { {0x61460124,0xd5b10092,0x245e0046,0x628d02f2}},	// [83c0] веза, ốc_, sům_, gtao
  { {0x7ae900dc,0x867b000a,0x245e0046,0x63ad3c64}},	//   izet, _קריו, pům_, adan
  { {0x7bdb022d,0xa0670063,0x5577000a,0x21a3006b}},	//   kkuu, ваха_, _בעין_, рихм
  { {0x998500dc,0x9e660015,0x63ad007f,0x0000006a}},	//   illő_, ناتن, cdan,
  { {0x69da003c,0x6e9400a2,0xc7b3000f,0xffc90015}},	//   ykte, التا, יבא_, عظمى_
  { {0x44443c65,0x61460054,0xb5fb0125,0xe1650058}},	//   _ku_, _јева, tsái, _مدفي
  { {0xacf80010,0x9cb40029,0x7ae929ec,0x8cc40015}},	//   энку_, امبت, ezet, اقعه
  { {0xb5fb002d,0x3d16021e,0xc4d3000a,0x6d4a0125}},	//   rsái, _पुणे_, שגה_, scfa
  { {0x7ae93c66,0xda140004,0xb5fb0030,0xb9e6005e}},	//   gzet, лдињ, msáv, віни
  { {0xbda50225,0x44443c67,0x6e3a0161,0x63ad3c68}},	//   _محمو, _ou_, _uitb, zdan
  { {0x417b0008,0xddc2005c,0x44443c69,0x717b039e}},	//   וניב, zpoś, _nu_, וניס
  { {0xb5fb001c,0xd0060115,0x9cd7000a,0xaac60015}},	//   nsáv, صل_, _שואה_, _لتتن
  { {0x776429ab,0x2f5b0008,0x70bf000b,0x44443c6a}},	//   _deix, ודכנ, _एप्ल, _au_
  { {0x44443c6b,0xceb30008,0xee310008,0xd6d8005e}},	//   _bu_, ביש_, ֶֽם_, ттю_
  { {0x44440440,0x499b000f,0x657a03d9,0x299b000a}},	//   _cu_, _חשוב, ótha, _חסומ
  { {0x628d008c,0x14180015,0x4444220e,0x63ad3c6c}},	//   ttao, نيّة_, _du_, udan
  { {0x44443c6d,0x2ebe000b,0xb364006b,0xd6db005e}},	// [83d0] _eu_, ्होत, ръск, _іти_
  { {0x44443c6e,0xddc2005c,0x163b0029,0xa294022a}},	//   _fu_, groż, _تسعة_, рафі
  { {0x82340029,0x628d0020,0x94d53c6f,0x7ae93c70}},	//   شركا, stao, _сонц, zzet
  { {0x80140010,0x7ae90030,0xfe71006e,0xe0d00015}},	//   афіц, yzet, مدت_, غزل_
  { {0x44440bcf,0x6445003f,0xb2740010,0xce190033}},	//   _zu_, _huhi, _кляш, нцкі_
  { {0xee380191,0x7ae9018c,0x8d540063,0xbef3005d}},	//   вні_, vzet, атъч, _अधीन_
  { {0x64450020,0xc1050029,0x4444244a,0x65650020}},	//   _juhi, _صوري, _xu_, _mehh
  { {0x6445000c,0xac960806,0x4aa90345,0xbe65002b}},	//   _muhi, انيا_, екин_, _مهري
  { {0x7e600026,0x7ae9016f,0xd9450155,0xeaf90015}},	//   _gwmp, uzet, лепи, عربت_
  { {0xf2d20008,0x6018002e,0x2d830134,0xdce300f0}},	//   צעי_, símt, _øje_, lanč
  { {0x7ae900dc,0xe852002b,0x77640341,0xdbd1007c}},	//   szet, ینید, _peix, _küül
  { {0x907a0053,0x2cae0030,0xdce30104,0x7ae90dbe}},	//   עטרי, üldő_, nanč, pzet
  { {0x64450020,0xe9a80086,0xaa890015,0xddc2003d}},	//   _auhi, ردین_, _أنتم_, lsoš
  { {0x44443c71,0x0000006a,0x0000006a,0x0000006a}},	//   _pu_,   ,   ,
  { {0x44440b7a,0x999900df,0xdce300df,0x67e6005c}},	//   _qu_, ūsų_, kanč, _pójd
  { {0xdce300df,0x44443c72,0xf1aa002b,0xdd030091}},	//   janč, _vu_, کاره_, ūrėm
  { {0x6d4115eb,0xdce30007,0xddc2005c,0xe2460015}},	// [83e0] _ogla, danč, troż, اخري
  { {0x6d411f22,0x1138002b,0x2a6d0034,0x44443c73}},	//   _ngla, نتاژ_, iseb_, _tu_
  { {0x7fd60036,0xcf9a0180,0x44443c74,0x644502f2}},	//   ліді, ејл_, _uu_, _guhi
  { {0xd3da0029,0xbe8a239c,0x7f860015,0x4916004c}},	//   _أبدا_, еске_, الإن, אקעל_
  { {0x2d8a0064,0x48170053,0x643b0053,0x44200943}},	//   _öbek_, אַגן_, _רעכנ, mli_
  { {0xc6930008,0x6143021a,0xdb0000cb,0xcf250015}},	//   צאו_, _гера, ndmå, جرمي
  { {0xac730086,0x44203c75,0x44323c76,0xaf9a00fd}},	//   مايش, oli_, omy_, _птах_
  { {0x442001e2,0x6fb60015,0x3a740c45,0x8bd40054}},	//   nli_, _حمرا, алир, ржиц
  { {0xdd250007,0x8e0a005e,0x7fd7000a,0xe20b002a}},	//   rūši, _знав_, _עומס_, łóż_
  { {0x2a97003b,0x44203c77,0x3f86016e,0x0d750033}},	//   ائية_, hli_, lgou_, _выця
  { {0x0217013a,0x683e00df,0xbb860115,0x44203c78}},	//   רחים_, _būda, _ملاي, kli_
  { {0x3137000a,0x0137000a,0x64450012,0xb0b7004c}},	//   טנים_, טרית_, _ruhi, אפטס_
  { {0xdb19005c,0xeab20115,0xabfb004c,0x4bfb015b}},	//   _dowó, _دعا_, _אפאז, _אלאס
  { {0xceb300b2,0x4432005c,0xdb0000b8,0x045b0015}},	//   זיש_, emy_, rdmä, فجرت_
  { {0x44203c79,0xe535004a,0x0000006a,0x0000006a}},	//   fli_, ревь,   ,
  { {0x44203c7a,0xa775006b,0xb3550660,0xf3640d7f}},	//   gli_, _тлич, ркаш, йтун
  { {0xd2510015,0x644a0003,0x0000006a,0x0000006a}},	// [83f0] زنا_, _éfin,   ,
  { {0x44f50457,0x61f80033,0x44203c7b,0x44323c7c}},	//   _впос, гнуў_, ali_, amy_
  { {0x4395008f,0xdce30e67,0x8f550015,0x8b030046}},	//   _канс, tanč, لناش, ěřil
  { {0xb4c30231,0x4fc80015,0x8e5500fd,0x2a6d0034}},	//   ्ही_, ُولُ_, аткі, yseb_
  { {0x1f640010,0xea000092,0x8d653c7d,0xc0c6001a}},	//   скім, _giầy_, авле, _óánæ
  { {0x3f7500a7,0xc27a0008,0x127a0053,0xb5fb00dc}},	//   ều_, _ברשי, _באשע, csát
  { {0x463c0053,0xfbd10029,0x228f1daa,0xfbc5030c}},	//   געגע, قتة_, lük_, ибко
  { {0x7c640029,0x2a6d0020,0x0b45017a,0x0c250004}},	//   حاول, tseb_, шнин, јмин
  { {0x4a450e88,0x83b6000a,0xeab10015,0xf2d2004c}},	//   јнов, בִיא_, زعة_, ַעט_
  { {0x6d410263,0x63af006f,0x44203c7e,0x44323c7f}},	//   _ugla, _lacn, zli_, zmy_
  { {0xf1b205af,0x4432005c,0x97c63c80,0x2bc5000b}},	//   קסט_, ymy_, айне, वादा
  { {0xd5b10023,0x629d0409,0x5b150785,0x2d87007c}},	//   ốn_, _opso, _кмет, lgne_
  { {0x228f0014,0x25a30134,0x44203c81,0x0000006a}},	//   jük_, fejl_, vli_,
  { {0x4420002a,0x2ca70034,0xa50a0054,0xe8f5002b}},	//   wli_, ownd_, вега_, _پستخ
  { {0x33f60010,0x64a609fe,0x44203c82,0xdb003040}},	//   ачас, шава, tli_, rdmå
  { {0x44203c83,0x86461664,0xdb0b0781,0x240708a0}},	//   uli_, _книж, _pagè, анси_

  { {0xade5005d,0x51660036,0x44203c84,0xf3470254}},	// [8400] कसान_, иваб, rli_, рпул_
  { {0xd5a40086,0x63af002d,0xa1c31017,0x70560015}},	//   _الدی, _eacn, обуд, لنطا
  { {0x161f005d,0x757b000a,0xc57b000a,0x10a6194a}},	//   _मीटर_, _בטיפ, _ברית, риен
  { {0x99870007,0x1e0e000b,0x2896004c,0x2d873c85}},	//   _kinų_, ाक्ष_, ידען_, egne_
  { {0x63a42de8,0x7e980067,0xdf770033,0x228f0061}},	//   mein, انتر_, рбіі_, cük_
  { {0xdd900002,0x8d630054,0xde030674,0x63af0244}},	//   سوب_, овље, опчи, _zacn
  { {0x6cd40015,0x9c570054,0xcbe618dc,0x2c4e002a}},	//   إقبا, ашњу_, иции, _będa_
  { {0xa7fd0064,0xaf490015,0xfc2f0015,0x2d910061}},	//   nsıt, _مشكل_, وحي_, _özen_
  { {0x75e2002c,0x9f7b0008,0x6fb30015,0xee3a02b0}},	//   _rôzn, _שנמח, _بمقا, _ана_
  { {0xe61f0152,0x63a43c86,0x2a790030,0xdb003c87}},	//   ntôt_, hein, ásba_, nemé
  { {0x228f0a55,0x59d30015,0xfe37000a,0x1d07006b}},	//   zük_, تغير, _כרמי_, _кефи_
  { {0x61d3014e,0x228f01e2,0xdce8002c,0x200600f2}},	//   _दक्ष, yük_, _obdĺ, nnoi_
  { {0xdb000030,0xe1ff04b2,0xdce3003d,0xba540015}},	//   kemé, _kvót_, manā, _انتع
  { {0xadf8005d,0xb9b30015,0x63a401f1,0xaadb0643}},	//   ्चिन_, _ومنع, eein, _בחדר
  { {0xd4370029,0xb4c3000b,0xa957000a,0xa5c70030}},	//   لعرب, ्हे_, _דיוק_, _adóö
  { {0x228f00dc,0x63a43c88,0xf7f40015,0xe3b00015}},	//   tük_, gein, _وسيد, ورق_
  { {0xe695003b,0x809f014e,0x4df8000b,0x2d8c0524}},	// [8410] _الخد, _गैजे, ्चाई_, _ocde_
  { {0xc05b0127,0xf1a70180,0xe732000a,0xb5fb0030}},	//   від_, јран, _מֵת_, asár
  { {0xea000023,0x36340029,0x228f00dc,0xdce30024}},	//   _giấy_, _بريس, sük_, kanā
  { {0x5f740029,0x4f580015,0xa236003d,0xc7b2000a}},	//   قاهر, لجهد_, āršā_, ּ֑א_
  { {0xf1a7009c,0x539a000a,0x82a40033,0x1ea80015}},	//   _крвн, _גירו, _даўж, لاوي_
  { {0xd6580008,0x75eb0064,0xa1840256,0x1d093c89}},	//   סיות_, _düzg, _мысл, лели_
  { {0xddc904f9,0x5578000a,0x683f0091,0xac960015}},	//   _aveţ, בעון_, _rūdn, منوا_
  { {0x6e450086,0x3ff90053,0xf3f20008,0x60e90061}},	//   _هنرم, _עפּע, ּ֣ה_, ısmı
  { {0x75eb0030,0x0000006a,0x0000006a,0x0000006a}},	//   _küzd,   ,   ,
  { {0x7bc20041,0x2bc5000b,0x3ead02f2,0x6ff5002a}},	//   _enou, वाहा, _iset_, jącz
  { {0xa8890010,0x34b3000b,0x97c600c3,0x5db40015}},	//   ыйна_, ुमोद, مقدو, _بإقر
  { {0xa09a0053,0xeb900015,0x8a95002b,0xdb000030}},	//   נירט, _يظن_, _هشتص, zemé
  { {0xe9ce1e92,0x0a940033,0x07a300eb,0x6b890db6}},	//   _ек_, _мацю, чаян, mgeg
  { {0x63a41f4d,0x6b891217,0x67f600bc,0x4b36004f}},	//   wein, lgeg, išji, _פרסל_
  { {0xb4260029,0x8afd0089,0x69c33c8a,0x04b50294}},	//   معرو, daři, _inne, остя
  { {0x680b005c,0xa7660001,0xdd3a0045,0x6b892dd5}},	//   lędn, _укид, lăţi, ngeg
  { {0xb5fb001c,0x63a43c8b,0x06970015,0x6b890012}},	// [8420] rsár, rein, _هنية_, igeg
  { {0xb5fb03af,0x45860155,0x05aa3c8c,0x75eb0061}},	//   ssár, _угов, _свой_, _rüzg
  { {0xd05a005e,0x75eb0061,0x6b890c0d,0xe1ff016e}},	//   урзі_, _süzg, kgeg, _avós_
  { {0xd019005e,0x6b890079,0xa0670054,0x645c3c8d}},	//   афі_, jgeg, саца_, mpri
  { {0x840800dc,0x93b7000a,0x20060003,0x6437004c}},	//   _előá, _הלכו_, rnoi_, _לאטא_
  { {0x2d9101e2,0x244e002c,0x69d500dc,0x41c9000b}},	//   _özel_, _kým_, özel, राणस
  { {0xa3cc005d,0x2704000b,0x6b89059b,0x8f760033}},	//   लाप_, रपुर_, fgeg, _гузі
  { {0x656e002d,0xba54023e,0x69c33c8e,0xa4b7000a}},	//   habh, овиј, _anne, מלצה_
  { {0x6ff50050,0x75eb01e2,0xdd3a0011,0xa9c60015}},	//   jący, _yüzd, făţi, مزدو
  { {0xee372f87,0x1e57000a,0xd910002b,0x6ff5002a}},	//   _гну_, _לשמר_, ویش_, dący
  { {0x621b0008,0xc19b0008,0x23600079,0xbce50015}},	//   רויק, נשטי, kbij_, _وأمو
  { {0x61fe0064,0xa3cc005d,0x656e002d,0x69dc3c8f}},	//   hipl, लाफ_, eabh, öreb
  { {0xdce10024,0xa3cc021e,0x61fe0061,0xfc17000a}},	//   _ielā, लान_, kipl, _פקדי_
  { {0x15eb0036,0xdca60015,0xd554006b,0xdd3a0045}},	//   уємо_, وى_, зкръ, căţi
  { {0x3c780008,0x41dc000b,0x4ddb000a,0x6ff5002a}},	//   יָּב, _मक़स, נחלו, rącz
  { {0xb8de005d,0x6c57000a,0xb8ec0065,0x244e005a}},	//   ीम_, מילא_, रम_, _dým_
  { {0x61f90010,0x27e9191c,0xb7940015,0x290b0045}},	// [8430] анаў_, _ilan_, _رؤيت, şcat_
  { {0x645c3c90,0x4958000a,0x0000006a,0x0000006a}},	//   bpri, שֻּׁ,   ,
  { {0x463c00b2,0x185b0053,0xc1080010,0xa3d51032}},	//   _געזע, ָכדע, бэце_, _донч
  { {0x75eb01e2,0x680b005c,0xdb09002d,0xd5bf0024}},	//   _düze, zędn, hdeá, žādi_
  { {0x0f35002b,0xf41f008c,0x877c000a,0x8afd0046}},	//   زکرد, _ikä_, ראדי, obře
  { {0x27180023,0xe057002b,0x27e90034,0x75eb3045}},	//   ọng_, _هیئت_, _llan_, _füze
  { {0x27e901e2,0x75eb0064,0x68120024,0x6ff5005c}},	//   _olan_, _güze, lāde, zący
  { {0x5f940001,0x8c4209ef,0x3a99005e,0x4a990033}},	//   _нист, меще, атою_, атоў_
  { {0xdd3a04f9,0x6b893074,0xdb0b00b8,0x22430079}},	//   tăţi, rgeg, _ungü, _kijk_
  { {0x75eb0064,0x27e93c91,0x6b89237b,0xf9890015}},	//   _yüze, _alan_, sgeg, جندي_
  { {0xa3cc000b,0xdb23002b,0x224b3c92,0x18690004}},	//   लाम_, _کوشی, _luck_, јами_
  { {0xe73a05b3,0xb8d1000b,0x22430079,0x27e905ed}},	//   иен_, _ऑन_, _lijk_, _clan_
  { {0x501a0008,0xaaf2004c,0x69dc0061,0xc9f50015}},	//   שורו, _גאַסט_, örec, _وستع
  { {0x1a9a0053,0xcb360008,0x7f3a015b,0x69c300c7}},	//   _כינע, _ואני_, יערו, _unne
  { {0x656e002f,0x2ea6005d,0x9ce9000a,0x25a5007c}},	//   rabh, _गन्त, בַּ֖, õlla_
  { {0xfe080092,0xa6ca0002,0x27e93c93,0x200d0091}},	//   iữa_, _نوبل_, _glan_, _njei_
  { {0x23600298,0xe1fa3c94,0x68120024,0x645c3c95}},	// [8440] rbij_, ага_, gāde, spri
  { {0x645c3c96,0xd1750010,0xf6530008,0x244e0264}},	//   ppri, зыцы, _קצת_, _tým_
  { {0x397a0053,0x80a600e6,0x321a037f,0x3fc6002b}},	//   שטענ, تمان, ropy_, يگری_
  { {0xe3ba0010,0x7ee60015,0x389a004c,0x44243c97}},	//   _тбм_, يكان, ייענ, _óm_
  { {0x661c0150,0xddc91cf7,0x680b002a,0x2d5801c5}},	//   oork, _sveš, zędo, биль_
  { {0xddc90089,0x1cba0029,0x75eb0399,0x32530033}},	//   _kteř, لاعب_, _tüze, _цвёр
  { {0xc0c90083,0x9cca04f7,0x6da300d0,0xdfa60015}},	//   _луѓе_, рыла_, фија, _وحري
  { {0x2d800011,0x63b62029,0x00f7000a,0x9ad40663}},	//   şie_, ndyn, _ומלך_, зжич
  { {0xcb670124,0x49a60004,0x79a61045,0x661c3c98}},	//   цање_, ојна, орне, kork
  { {0x929b000a,0x63b60034,0xdca60461,0x661c3c99}},	//   סיית, hdyn, _мази, jork
  { {0xf2df0023,0xd917004a,0xdc390061,0x27e93c9a}},	//   _ngân_, жья_, açın, _plan_
  { {0xad1b0008,0x6ac60015,0x8ae6005e,0x8ba6033d}},	//   _דובר, _وقام, _мілл, _фидж
  { {0x63b60026,0xd6d8004a,0x6b9b000a,0x661c01de}},	//   ddyn, отр_, _כשאד, fork
  { {0xdcfa0064,0x63b6005c,0x680b002a,0x25570046}},	//   _hatı, edyn, pędo, dělí_
  { {0xdcfa01e2,0x22430111,0x200700dc,0x672d002a}},	//   _katı, _rijk_, énik_, _wzaj
  { {0x38570086,0x69d80293,0x9cd7000a,0x325501f3}},	//   _بشود_, _hove, חולה_, звар
  { {0xd2290029,0x8bd70008,0x661c3c9b,0xa294005e}},	// [8450] مكره_, קומו_, bork, маті
  { {0x68120048,0xd164006b,0x201f00aa,0x661c01c2}},	//   rāde, дъци, _skui_, cork
  { {0x69d83653,0xb4b50088,0x55bc000a,0xdb003c9c}},	//   _move, _эйнш, _כמזו, nemâ
  { {0x2bb6005d,0x6d480035,0xa267006b,0x22430079}},	//   _अफगा, _agda, _мъгл, _wijk_
  { {0x9e640036,0xed5930ee,0x0e640033,0xd356000a}},	//   двід, бол_, дкін, _מירי_
  { {0xbdc7004a,0x433a000a,0xdce10045,0xa37b007c}},	//   ющей, _לערב, _nelă, _slõh
  { {0x459c00b2,0xdcfa0064,0xd57c0008,0x6da20286}},	//   יסגע, _batı, שָׂר, хища
  { {0x2bb90029,0x6e950080,0x6eb3000b,0xce95006b}},	//   صابة_, _нибу, _इनपु, _набъ
  { {0x69d80298,0xa3cc005d,0x201d005c,0x661c0061}},	//   _bove, लात_, mowi_, york
  { {0xf2a70010,0x201d005c,0x69d83c9d,0xdce10045}},	//   скiх_, lowi_, _cove, _celă
  { {0xc6890008,0x6c490015,0xd7ca002b,0x69d83c9e}},	//   _תא_, _الصف_, موده_, _dove
  { {0x201d005c,0xf74605c4,0x2af50033,0x661c3c9f}},	//   nowi_, яемо, _нялё, work
  { {0xdce80089,0xf71a0010,0x661c1afe,0x0000006a}},	//   _oddě, сіны_, tork,
  { {0x2ca9005c,0x4a440010,0xdef6000a,0x69d81647}},	//   ładu_, _жнів, למרט_, _gove
  { {0xdcfa0064,0x201d005c,0x99d40029,0xc9520008}},	//   _yatı, kowi_, _تتنا, _אמו_
  { {0x487a013a,0x69d83ca0,0x201d002a,0x63b6002a}},	//   _הטקס, _zove, jowi_, udyn
  { {0x63b610ec,0x201d002a,0x764d3ca1,0x661c3ca2}},	// [8460] rdyn, dowi_, _guay, pork
  { {0x42230083,0x33190033,0xdb00059d,0x0000006a}},	//   едув, ціся_, lemã,
  { {0x62960035,0x94760015,0xa3cc000b,0x4fc60c31}},	//   styo, _عددا, लाद_, зсла
  { {0xa856000a,0x201d002a,0xa11300c3,0x61e53ca3}},	//   ליעה_, gowi_, رونت, akhl
  { {0xe81d000b,0x3ebf3ca4,0xdee324d2,0xff0702ed}},	//   नवता_, _crut_, ноци, пецк_
  { {0xdcfa01e2,0x61fc02c6,0x68e13ca5,0x64463ca6}},	//   _satı, _umrl, kyld, _hiki
  { {0xd5b10023,0x44220020,0x64580152,0x8afd0089}},	//   ối_, _kkk_, _évid, kařs
  { {0x75eb0064,0x69d80ae5,0x201d002a,0x683601d3}},	//   _müza, _sove, cowi_, ládf
  { {0x64460084,0x69d83ca7,0xbe66002b,0x5a340988}},	//   _miki, _pove, _رهاي, мнит
  { {0x68e10134,0x7c660087,0xe9f80127,0x64463ca8}},	//   fyld, _فاصل, інні_, _liki
  { {0x9b460086,0x6284130f,0x68e101f0,0x8d5b000a}},	//   _فناو, hrio, gyld, _הכבי
  { {0x644627ae,0x69d800da,0x683f0091,0x7529005a}},	//   _niki, _wove, _kūdi, řezk
  { {0x3bbb000a,0x9f4d0123,0x95cb067a,0xdb00038c}},	//   _למאד, _umeå_, бува_, ndmü
  { {0x26c00026,0x4a7b00a3,0xbb3b000a,0x7a7b000a}},	//   _drio_, _פרוב, _העדי, _פרוס
  { {0xc9b70008,0x2c550024,0xec090092,0xa99b009d}},	//   _זהות_, _kāda_, iến_, _הבור
  { {0x683f0048,0x671e000b,0x26c0016e,0x66a4004c}},	//   _līdz, _युवक_, _frio_, ופּלי
  { {0xe802005d,0x877c0008,0xe2930029,0xd14b002b}},	// [8470] _लगता_, _האחי, عذر_, مشان_
  { {0x64460007,0xda0c000b,0x201d002a,0xc2c400c3}},	//   _eiki, िचित_, wowi_, عيلي
  { {0x62840467,0xdb0b0014,0xb5fb21c5,0x31580015}},	//   ario, _magá, ppáb, سجلة_
  { {0x683f0007,0xd9a9000b,0xa857000a,0xfe710021}},	//   _būdi, _कस्ट, פידה_, ندت_
  { {0x4ea7008f,0x6284002d,0x201d005c,0x68120024}},	//   яржа, crio, rowi_, nāda
  { {0x6da20063,0x201d005c,0x644602e8,0x44293ca9}},	//   виша, sowi_, _ziki, lla_
  { {0x6114000d,0x201d002a,0xe508000a,0xd9a9000b}},	//   _здру, powi_, ּ֖וֹ_, _कसौट
  { {0x68120024,0x442920df,0x69dc3caa,0x9b450015}},	//   kāda, nla_, ören, ونثو
  { {0x5ac9005e,0x6b9b3cab,0x68e10034,0x44293cac}},	//   ілом_, rfug, wyld, ila_
  { {0x7c220213,0x44293b68,0x3ec40046,0xf2df0016}},	//   _ekor, hla_, ůstá_, _ngâm_
  { {0xc1720008,0x44293cad,0xc156004f,0xa156004f}},	//   כחי_, kla_, ושתו_, ובתה_
  { {0xad1a00b4,0x3f8f0d25,0x9d1a0053,0x48e2005e}},	//   _ווער, nggu_, _וועט, тоюв
  { {0x7c2901e2,0x4429347b,0x6008000a,0xa3cc000b}},	//   mler, dla_, לִשְ, लास_
  { {0x64a63cae,0xceb2000a,0xbb3a000a,0x5ee8000a}},	//   мага, דיך_, _ועני, פַרְ
  { {0x644600e8,0x8cc0005d,0x394e002c,0x44223caf}},	//   _piki, वियो, ájsť_, _pkk_
  { {0x7c2901e2,0x62842195,0x26c03cb0,0x7c3b3cb1}},	//   nler, trio, _trio_, nmur
  { {0xec090023,0x877b0008,0x41c9005d,0xb77b0008}},	// [8480] yến_, _ואפי, रांस, _ואפש
  { {0xea000092,0x7c293cb2,0xa3cc000b,0x64460267}},	//   _phẩy_, hler, लाह_, _wiki
  { {0x11d70029,0x7c2920df,0x64463cb3,0x44293cb4}},	//   بولة_, kler, _tiki, bla_
  { {0xe8d60053,0xc2090008,0xd0120015,0x2f56005e}},	//   ווער_, בה_, خلص_, єтес
  { {0x2c550024,0x7c290cd8,0x442000f2,0x4e9300a2}},	//   _rāda_, dler, moi_, نشور
  { {0xa3cc005d,0x7bdd00b8,0x7c292664,0x68360030}},	//   लाव_, ösun, eler, ládd
  { {0x7c2901e2,0x212c002d,0x0c730086,0xdb0002c1}},	//   fler, _ádh_, نديد, demá
  { {0xdfa6003b,0xbc370029,0xdb000251,0xfbc5000b}},	//   _تحسي, وسيا_, temà, वागम
  { {0x34ab000b,0xc9861944,0xb4ab000b,0x28b0000b}},	//   _चन्द, муни, _गन्_, _जनहि
  { {0x44290482,0x44203cb5,0xd8f8005e,0x7dc60015}},	//   zla_, hoi_, зної_, _تترك
  { {0x44293cb6,0x5ce60029,0xca480092,0x2c550024}},	//   yla_, _تكال, _mời_, _tāda_
  { {0xca480023,0xac97002b,0x44290123,0x44203cb7}},	//   _lời_, _زنها_, xla_, joi_
  { {0x683f0089,0x6bd70115,0xd5bb006b,0x44203cb8}},	//   jádř, _تونس_, осв_, doi_
  { {0x7c200014,0x2a690064,0x6812003d,0xe5c8004a}},	//   lomr, _çaba_, rāda, мысл_
  { {0xa5040010,0xb4470033,0x44293cb9,0xee2e0033}},	//   вятл, дэак, tla_, ынi_
  { {0x44201bb4,0x78530045,0x6812003d,0xa87b000a}},	//   goi_, _zăvo, lādn, _ואהר
  { {0xd7740086,0x44293cba,0x6d5a3029,0xdcef3cbb}},	// [8490] _شايع, rla_, _ofta, _čeče
  { {0x7c2901e2,0x4420002f,0xd9040086,0x68ed0089}},	//   zler, aoi_, لی_, _řadi
  { {0x96180029,0x7c293cbc,0xa3cc000b,0x65750030}},	//   _تغير_, yler, लाश_, mazh
  { {0x6d5a193d,0xca480092,0x75f0006f,0x02d90015}},	//   _afta, _dời_, _väze, _فوجب_
  { {0x7c292701,0x63ad3cbd,0xf5ab000a,0x1f640033}},	//   vler, mean, ַבֵּ, ткім
  { {0x69dc00c0,0x63ad3cbe,0xa2cc000b,0x8cb5006b}},	//   örel, lean, समर्, есич
  { {0x7c293cbf,0x4c920054,0xeb910015,0x6836013f}},	//   tler, гијс, هظة_, láde
  { {0x7c3b0024,0x7f850002,0x69ca06ad,0x7f840015}},	//   umur, _سلطن, _anfe, _للفن
  { {0x7c2901e2,0x41c9000b,0xdb000656,0x8e150033}},	//   rler, राऊस, temá, _здац
  { {0x63ad002f,0xe1ff005c,0x7c2922d2,0xe9d10029}},	//   hean, _swój_, sler, اغة_
  { {0x7c200c83,0xbc68003b,0xdc120064,0x7c293cc0}},	//   bomr, _يمكن_, aşın, pler
  { {0xcc560008,0x8cae000b,0x69ca3cc1,0xb8d7000b}},	//   _טבעי_, ूटरो, _enfe, _घई_
  { {0x63ad002f,0x6d4700dc,0x44203cc2,0x200f3cc3}},	//   dean, _újab, voi_, ingi_
  { {0xba390053,0xec090092,0xfa76000a,0x5fc60065}},	//   _צײַט, iếm_, _טענת_, _रोनल
  { {0xe1ff0050,0x07a60036,0x65c30256,0x64a31155}},	//   _twój_, _зайн, ыбра, лара
  { {0xca480092,0x4420151c,0x683f0007,0x52760015}},	//   _rời_, uoi_, _būdu, فائز
  { {0xb5fb00dc,0x6f16005c,0x44203cc4,0xd2a7004a}},	// [84a0] mpán, życz, roi_, нкте_
  { {0x171b0008,0x442000f2,0xd5b10092,0xdb0002de}},	//   _מופע, soi_, ốt_, bemæ
  { {0x442004f9,0x11d70029,0x7f860021,0x6812003d}},	//   poi_, عومة_, فلان, nādo
  { {0x14d70008,0xc2090008,0xf7bb000a,0xca480016}},	//   _נוכל_, זה_, ּ֖אמ, _vời_
  { {0x2bd3014e,0x3f9a005c,0xa2e3006b,0x7c2004d1}},	//   थाना, ępu_, _бояд, vomr
  { {0xd5b3000a,0x02460015,0xcee9002b,0x200f3cc5}},	//   ָׁה_, _سَأَ, برمن_, angi_
  { {0x7e7c0024,0x987e0089,0x93fa000a,0xc3fa000a}},	//   _ārpu, _péče_, ּלִי, ּלִש
  { {0xa2c4005d,0xc4d30008,0x2c7a0024,0x309b000a}},	//   रिप्, רגה_, rīd_, _משלמ
  { {0xa3e8000b,0xc43b000a,0xf43b000a,0x2006008c}},	//   _भवन_, התקי, התקש, mioi_
  { {0x4e7b0008,0xf65f002e,0x7bcb2200,0x7dc50015}},	//   _מאמצ, lvæg_, _engu, _لتمك
  { {0x79a30010,0x2bb8005d,0xa7fd0064,0xfaef002b}},	//   урые, _आसपा, msız, لثی_
  { {0xc02e0023,0x9cd70008,0x7c650115,0x5b260015}},	//   _điều_, _רואה_, _شامل, _كفال
  { {0xf8040010,0x95cb0254,0x09e60e60,0x6c33002b}},	//   учэн, пува_, _подн, _صفها
  { {0xa2c4014e,0x2d910064,0xa7fd0064,0xae20000b}},	//   रिन्, _özet_, nsız, मकिन_
  { {0x63ad002f,0x19bb000a,0xa25b016e,0x03c7140a}},	//   tean, _ממגב, _crôn, нсам
  { {0xdb000134,0xa7fd0061,0xb21b02de,0xa25b0416}},	//   remæ, hsız, _kvæg, _drôn
  { {0x63ad002f,0x59b7005d,0xa7fd0064,0x75eb0064}},	// [84b0] rean, _असमर, ksız, _yüzl
  { {0x63ad3cc6,0xdb00007c,0xda7b004f,0x6836005a}},	//   sean, memä, פנבר, ráde
  { {0xddc90064,0xdb0008b1,0xc61d000b,0x63ad3cc7}},	//   _ateş, lemä, पकीय_, pean
  { {0x66070a9c,0x200f04ed,0xd47a015b,0xa3cc0065}},	//   lijk, ungi_, _קארל, लाः_
  { {0xed4e0001,0x23690011,0xbfd20015,0x8e3900c3}},	//   ио_, mbaj_, شيوع, وستر_
  { {0xd6580008,0x7658000a,0x660706ed,0xada53cc8}},	//   עיות_, עבוד_, nijk, такл
  { {0x1fa7078f,0xdb000020,0xd2140054,0xf1b00015}},	//   _праг, hemä, _смрћ, _اءُ_
  { {0xdb0000f2,0xdb4e0015,0x3035004a,0xac380033}},	//   kemä, يَى_, _ребё, нчых_
  { {0x66070298,0x13c8000a,0xcf270015,0x59c20065}},	//   kijk, תּוֹ_, _أرأي, _वोहर
  { {0x7d790086,0x3ea20123,0xcaa40015,0xe1ff0125}},	//   _آمار_, _äkta_, اصيي, _dtóg_
  { {0x9be70036,0x66070546,0xdcea00d4,0x0000006a}},	//   _підк, dijk, rafă,
  { {0x68120024,0x66e60004,0x2fdf0003,0x443900da}},	//   rādo, вома, _joug_, _nhs_
  { {0xaae40086,0x26c40089,0x98a20024,0x79c90015}},	//   _مسوو, ímo_, ākā_, _يوصف_
  { {0xa25b0003,0xb5fb1f7f,0x6e2301d0,0x0000006a}},	//   _prôn, spán, nonb,
  { {0x2bb8000b,0xdce30046,0xdd03003d,0xa7fd0061}},	//   _आसमा, vaně, ērķi, mpın
  { {0x6f1e005c,0xe0d2002b,0xccf2000a,0xb8e5000b}},	//   ępcz, یزا_, בכל_, उट_
  { {0xe61a000d,0x200600f2,0xae21000b,0x23980046}},	// [84c0] _оди_, vioi_, यवान_, _nějž_
  { {0xf1aa0074,0xc64a0029,0xf1d2000b,0xa25b3cc9}},	//   باره_, _تجعل_, साधन, _trôn
  { {0xdce30089,0x27e001d7,0xb1430033,0xe1ff002a}},	//   raně, _koin_, анфл, _lwów_
  { {0x27e00b77,0xefd50010,0x7c390034,0x7fd5005e}},	//   _join_, лючэ, _nhwr, лічі
  { {0xa7fd0064,0x9757000a,0x2fdf31aa,0x69dc3cca}},	//   tsız, דינו_, _doug_, örek
  { {0x27e00152,0x27f20026,0x60860029,0x1ea90015}},	//   _loin_, _llyn_, _لشرك, عاني_
  { {0x200600f2,0x60260010,0xa7fd0064,0x7c930029}},	//   pioi_, _адва, rsız, لشيا
  { {0xeb970124,0x27e0022d,0x6ce30036,0x7c390034}},	//   вић_, _noin_, ріше, _chwr
  { {0xea000092,0x2d9609ef,0x8c430054,0x5bb70138}},	//   _nhảy_, _арес, шеће, тлыя_
  { {0x680400dc,0xf98f0058,0xada3009b,0x27f20416}},	//   sődl, يبٍ_, _вафл, _alyn_
  { {0x5a330010,0xab960015,0x645a0046,0x16cb000b}},	//   рнэт, _للضغ, ítil, ाम्ब
  { {0x66070111,0x27e00493,0x9b060004,0xa7fd0061}},	//   wijk, _coin_, _изед, apın
  { {0xa3cc005d,0xea000092,0x4ab6000b,0x7df2002a}},	//   लाई_, _chảy_, _अनिव, dłsz
  { {0x4b37013a,0x27e0002d,0x89d80015,0xa25b0003}},	//   _סרגל_, _eoin_, _سوبر_, _drôl
  { {0x66070298,0x48e3009c,0xc8b300c3,0x64740350}},	//   rijk, _војв, _نصيب, игру
  { {0xe4140191,0x27f20026,0x926b000d,0x6e2300dc}},	//   адсь, _glyn_, држа_, zonb
  { {0x6b82003f,0x98be0061,0x68e80827,0xe3b00015}},	// [84d0] _mdog, matı_, lydd, غرف_
  { {0x75d50029,0x1a9b0053,0x35b50457,0xe1f30015}},	//   _إيدا, וימע, _сбор, جسر_
  { {0x21a40191,0x68e80176,0xc058008f,0x3cec000b}},	//   риєм, nydd, віч_, जनों_
  { {0x6b82000c,0x6f950015,0x25b10046,0x98be0061}},	//   _ndog, الإض, lezl_, natı_
  { {0x68e80026,0xde58005e,0xe7a5000b,0xa2c4000b}},	//   hydd, вачі_, ग्यप, रिण्
  { {0x68e800c0,0x7e24005e,0x929a000a,0x63bd3521}},	//   kydd, адіж, _אישת, _hasn
  { {0x63bd060b,0x98be0061,0xe0d40054,0x7c390034}},	//   _kasn, katı_, _корњ, _phwr
  { {0x68e80026,0xf42a00f2,0x5f450115,0xa3cc000b}},	//   dydd, _isää_, _منزل, लाए_
  { {0x6b820026,0x63bd3ccb,0xda650015,0x59750033}},	//   _ddog, _masn, داعي, лыну
  { {0x68e80026,0x27e00152,0xd70d000b,0x63bd0d48}},	//   fydd, _soin_, सपैठ_, _lasn
  { {0x77940086,0x68e80026,0x27e000e8,0xdb000293}},	//   لیغا, gydd, _poin_, vemå
  { {0xf64901ac,0xcbc70002,0x8cc0000b,0xaa590054}},	//   _זצ_, _جزئي, विरो, _зиду_
  { {0x27e000f2,0x9bb6000a,0x4803106c,0xdb0b1115}},	//   _voin_, _תהנה_, спяв, _lagú
  { {0x68e80026,0x7a7a0008,0x7bdb007c,0xcb12000a}},	//   bydd, _טרנס, ljuu, _פלג_
  { {0xdb0038a0,0x94792a30,0x98be0061,0xc5630088}},	//   remå, ксту_, batı_, скск
  { {0x42d6017f,0x7bdd0fb2,0x63bd0d0c,0xc1780091}},	//   лізу, ösuh, _casn, _žė_
  { {0x070a0029,0x7afb0012,0x230a00c3,0xc106002b}},	// [84e0] _سيدي_, nzut, رتري_, گواي
  { {0x764b0152,0xc0aa0015,0x63bd0125,0x7ae90061}},	//   _égyp, فاصل_, _easn, iyet
  { {0x08760053,0x63bd0026,0x81360010,0x98a60085}},	//   ָענט_, _fasn, ухац, čiće_
  { {0xf1d2005d,0xa3e8000b,0xbf650015,0x63bd3ccc}},	//   साहन, _भवि_, لدهو, _gasn
  { {0x42d50010,0x7e2a02e5,0xd29a00fd,0xdb200061}},	//   _кіру, ніка_, _ятні_, ütül
  { {0xdcba0063,0xa3cc000b,0x7ae902f2,0x63bd136b}},	//   ещи_, लाक_, dyet, _zasn
  { {0x98be0064,0xa1160002,0xea000092,0x6da300c3}},	//   yatı_, _صورت, _nhạy_, صميم
  { {0x63a43ccd,0x7afb0012,0x0c730040,0x3b541079}},	//   nfin, fzut, حدود, шкир
  { {0x68e80b7c,0x63a4199c,0xdd960058,0x3eba01ec}},	//   wydd, ifin, _مجاع, āpts_
  { {0xa7fd0064,0x02b70053,0xd2b7000a,0x929b000a}},	//   apıl, נליך_, נלית_, עיית
  { {0xea000023,0xd90d0086,0x4815107c,0xe91800e2}},	//   _chạy_, ویه_, имос, тоні_
  { {0xad1b000a,0xcc360015,0x3c0c0046,0x68360125}},	//   _אובר, _صراع, těvu_, táda
  { {0x68e80026,0x6b7b00a3,0x75f0006f,0xe980008b}},	//   sydd, _טראנ, _väzn, _далi_
  { {0x63bd0048,0x6595000d,0xcdd4000a,0x2956006b}},	//   _sasn, јаву, ׁךָ_, _съдр
  { {0x6836013f,0x63bd3cce,0x63a43ccf,0xda4b004f}},	//   mádn, _pasn, ffin, _אֲהָ
  { {0x75eb0064,0xd1bb0086,0x78a50020,0x7bc0187b}},	//   _müzi, کارا_, _ähva, ndmu
  { {0x2ba6005d,0x92950457,0x53140015,0x9175014d}},	// [84f0] क्या, разц, مذكر, игац
  { {0xe1350033,0x67e6002a,0xe2a6001a,0xddc9036d}},	//   анзы, _wójt, æðan_, _svež
  { {0xfaf90007,0xb0f90029,0x559c0053,0x5fe70036}},	//   lbūt_, خفاض_, _טױזנ, лідж
  { {0xa295078f,0xdef10029,0x0000006a,0x0000006a}},	//   _камі, يًا_,   ,
  { {0x74150086,0xe37a000a,0x5319000a,0x6db5005e}},	//   _موگا, _שרשר, _יוֹצ, ийду
  { {0x7bc70048,0x644f02c1,0x7ae90061,0xee3800fd}},	//   ējum, _hici, vyet, гні_
  { {0x2c550048,0xc2120008,0xf1f40033,0x290a016e}},	//   _kādi_, _והם_, _узрэ, úbal_
  { {0x6a850063,0x7afb0012,0x75eb0061,0xddc90085}},	//   алиа, tzut, _düzi, _uvež
  { {0xde590036,0xedd50086,0xa7fd0061,0x7a3e0046}},	//   _разі_, _پياد, rpıl, _oště
  { {0x7bdb0020,0xb9550001,0x7afb2029,0x644f3cd0}},	//   sjuu, штић, rzut, _lici
  { {0xf1b2000a,0x2d8500c7,0x7cd900c3,0x7afb0eb3}},	//   חסי_, _idle_, _جواز_, szut
  { {0x644f1241,0xd7ef0015,0xacf40015,0xfd100015}},	//   _nici, ِكَ_, _اسكت, _عجل_
  { {0x9a880029,0xd736005e,0xe732002b,0xceb2004c}},	//   _مَنْ_, рхнь, تصد_, ֿיל_
  { {0x7ae600c0,0xa2c4005d,0x644f0024,0x8afa000a}},	//   äkte, रिस्, _aici, _שהסי
  { {0xda48000a,0x644f3cd1,0x399a000a,0xab5d002a}},	//   _עֲנָ, _bici, _ייסד, adże
  { {0x69c10084,0x3ead016f,0x69dc0061,0xd91a000a}},	//   ldle, _opet_, örev, _שוקל
  { {0xa2063cd2,0xfbd2000a,0xc1560054,0x63a43cd3}},	// [8500] апад, חתן_, ањењ, rfin
  { {0x667b0053,0x867b000a,0xf67b000a,0xe1f704ca}},	//   _שטיק, _שריו, _שאימ, агу_
  { {0xf3f10023,0x60260010,0x6f660015,0xc4e30033}},	//   ệc_, аджа, لهام, _джэй
  { {0x657c05d7,0xbe8a239c,0x90530033,0x644f0034}},	//   larh, вске_, івіц, _gici
  { {0x6812003d,0xdb090030,0x6e460033,0x44323cd4}},	//   gādi, ideó, аедз, mly_
  { {0x644400f2,0x44320495,0xe3b2002b,0xc693000a}},	//   lmii, lly_, _ارگ_, קאו_
  { {0xeb0e014e,0xed570124,0x69c13cd5,0xa2c4000b}},	//   ाप्त_, шој_, ddle, रिव्
  { {0x4432003e,0x317800b8,0x236000bc,0x8aa63cd6}},	//   nly_, _herz_, ncij_, арод
  { {0x69c10111,0xda660029,0x44323cd7,0x1ea900e6}},	//   fdle, جابي, ily_, _مالي_
  { {0x2c0b0086,0x7e9b0008,0x644400f2,0x44323cd8}},	//   _یعنی_, _בסמו, hmii, hly_
  { {0x236000bd,0xdcf60024,0x245c0057,0x44323cd9}},	//   kcij_, ācēj, _ním_, kly_
  { {0xcb6a3cda,0xfb87002b,0xfaa60033,0xb5fb0030}},	//   _раде_, _ندهی, _вадо, ppák
  { {0x6701005d,0xab5d005c,0x44320479,0x6836013f}},	//   _लेखक_, udże, dly_, pádn
  { {0x44320ce3,0xf6e4005e,0xceb3000a,0xfaf9121a}},	//   ely_, іцян, חיש_, rbūt_
  { {0x6ab6014e,0x245c0014,0x680400dc,0x2a3b000a}},	//   _अनुर, _cím_, ződi, _שעומ
  { {0x26c90092,0xdc8b000a,0x64570123,0xa3bb0015}},	//   _trao_, כְמָ, _vuxi, خاسر_
  { {0x644f0541,0xd2510002,0xa2c4000b,0x683d0030}},	// [8510] _vici, سنا_, रिष्, géde
  { {0x644f0026,0x51f80010,0xd14b0086,0x2ba6005d}},	//   _wici, аную_, نشان_, क्ता
  { {0x44322383,0x3ead00bd,0x2c55003d,0x644f3cdb}},	//   bly_, _spet_, _tādi_, _tici
  { {0x4432003e,0x1ab6005d,0x8fa50015,0x4035004a}},	//   cly_, _अनूठ, صمته, щеес
  { {0x683d038d,0xec090092,0x7a3d0152,0x69c137af}},	//   céde, iết_, lète, ydle
  { {0x68120048,0x44290c8d,0x8de40015,0xec090016}},	//   rādi, loa_, يكنه, hết_
  { {0x225901f0,0x7a3d0003,0xb47b004f,0xfbd10058}},	//   _husk_, nète, דָ֖י, كتة_
  { {0x3ea90251,0x2a7f0020,0x6a950036,0x44293cdc}},	//   çats_, tsub_, броє, noa_
  { {0x8d870074,0xeab10029,0x99d50021,0x4e940015}},	//   _نشان, سعة_, متدا, _وشكر
  { {0xcef40015,0x44293cdd,0x44320046,0xe9d93cde}},	//   _بأفغ, hoa_, zly_, уко_
  { {0x443208db,0x4429055a,0x69c13cdf,0x6444008c}},	//   yly_, koa_, rdle, ymii
  { {0x6be40029,0x17fa0015,0x98160015,0x37750033}},	//   _وكلم, اردة_, إبدا, жырс
  { {0x4429000c,0x290b005c,0xfaf90007,0x657c3ce0}},	//   doa_, ńca_, rbūs_, tarh
  { {0x4432003e,0x69dc00c0,0xd9990087,0xe5a60001}},	//   wly_, öret, _صنعت_, љиви
  { {0x4432003e,0xb97a000a,0x74160015,0x657c3ce1}},	//   tly_, _ענקי, موسا, rarh
  { {0x245c0046,0xdce3003d,0xa2c4000b,0x657c3c58}},	//   _vím_, lanē, रिल्, sarh
  { {0x4432003e,0x77f70008,0x6444008c,0x9f520046}},	// [8520] rly_, _למקד_, rmii, ícím_
  { {0x245c0107,0x44323cd8,0x2ca9002a,0x2259118e}},	//   _tím_, sly_, łady_, _dusk_
  { {0xef6501e2,0x2c550048,0x41590010,0xe1650015}},	//   ğını_, _kādu_, ршую_, تدقي
  { {0xea000092,0xef650064,0xc0a90029,0x14d7000a}},	//   _thầy_, şını_, شامل_, _הוטל_
  { {0x479b000a,0x317804ef,0x2bbd0065,0xb184005a}},	//   רינס, _terz_, ्यना, _íťov
  { {0x62960064,0x63b63ce2,0xc4c5002b,0x6dc3006b}},	//   muyo, leyn, _اتیو, зсъж
  { {0xec090023,0x763b0053,0x62960064,0xbcaa0015}},	//   yết_, װעקג, luyo, ادتك_
  { {0x447b0053,0x8fa3227a,0xcfaa0015,0xd117000a}},	//   אנקע, _насе, _حاسم_, _הקלה_
  { {0x62960064,0xfd9a0029,0x03d7000a,0xd9f8004a}},	//   nuyo, _مئات_, מוקם_, иниц_
  { {0xf2d30008,0xa2bb0053,0x7de50015,0x660e0049}},	//   פעת_, נמיט, _وسلم, jibk
  { {0xec13002b,0x7c293ce3,0xa8a3009b,0xe1ff039f}},	//   _کوند, boer, пряк, _otón_
  { {0x68120024,0x683600dc,0x313701d8,0x5bc50015}},	//   kādu, ládj, מנים_, _وتنف
  { {0x41c8005d,0x858b04f7,0xf7490015,0x44293ce4}},	//   रयास, лёва_, شلسي_, voa_
  { {0xa2ae0065,0x0000006a,0x0000006a,0x0000006a}},	//   ुबन्,   ,   ,
  { {0x44292018,0xb97b0135,0x25fa000b,0x0000006a}},	//   toa_, _גרוז, _उतरी_,
  { {0x7a3d0003,0xc917000a,0x4917000a,0xb8de000b}},	//   rète, _לחות_, _לקול_, ुट_
  { {0x62960035,0x44293ce5,0x816b2354,0xdcf800bc}},	// [8530] guyo, roa_, греб_, davč
  { {0xf77f0251,0x44293ce6,0xc692000a,0xbb3b004c}},	//   laç_, soa_, _קאי_, רעמי
  { {0x44292a34,0x02440015,0x60b50015,0xe1f00015}},	//   poa_, أَلَ, تمائ, رسك_
  { {0x389b0008,0x753a00b8,0xe0d00015,0x6e890015}},	//   ריאנ, ütze, عزل_, لنصف_
  { {0x539a0008,0x7c290384,0x4e8b004a,0x201c016e}},	//   _דירו, voer, ущем_, évia_
  { {0xdc3c0024,0x2ba6000b,0x6d470030,0xd57b000a}},	//   kšēj, क्सा, _újak, אָ֗ר
  { {0xd2500015,0x358c000a,0xf77f0061,0xdddb0045}},	//   _أنّ_, רְדֳ, kaç_, _avuţ
  { {0xd0100015,0x7bc20618,0x0000006a,0x0000006a}},	//   _كلّ_, _caou,   ,
  { {0x0ae60080,0x200f00bd,0xcb090086,0xe7dd000b}},	//   ждый_, migi_, شيدن_, यानप
  { {0x78a90001,0x3df40010,0x8a050127,0xf8a9034e}},	//   аког_, _езус, ізне, авок_
  { {0xdc3c0024,0xc19a000a,0xdb09039f,0x995801ec}},	//   gšēj, בשתי, rdeñ, kšņi_
  { {0xa09a00b2,0x4a750010,0x62960064,0x69dc3ce7}},	//   סירט, _дыкт, yuyo, örer
  { {0xddc20024,0x200f0020,0xe9d93ce8,0x63b60061}},	//   lpoš, iigi_, _вкл_, veyn
  { {0xf3f100a7,0xdce80089,0x3a24005e,0x6b9b007c}},	//   ện_, _nedě, _еміг, lgug
  { {0x49b80086,0x2c550024,0x5cac000a,0x2ba6000b}},	//   _داند_, _tādu_, ְׁמַ, क्वा
  { {0x69c33ce9,0xa3e5005d,0x6b9b048c,0xf77f0251}},	//   _hane, बॉल_, ngug, caç_
  { {0x2c550024,0x63b6002e,0x7e6902b9,0x68360046}},	// [8540] _kāds_, reyn, _ntep, hádk
  { {0xea000023,0x62960064,0x69c33cea,0xf626005e}},	//   _thấy_, ruyo, _jane, _єдно
  { {0x69c3330e,0x10a3005e,0x7f86012c,0x25d7004f}},	//   _mane, дихн, قلان, _ווין_
  { {0x888a00b2,0xe29a3ceb,0xe7dd000b,0x99850046}},	//   שרײַ, _кам_, यायप, kolů_
  { {0xf67600b2,0x13b7000a,0x6e2a0547,0xb21b0013}},	//   קײַט_, _והכל_, tofb, _kvæl
  { {0x8c660036,0x200f0091,0x7bc20618,0x6b9b007c}},	//   отид, aigi_, _saou, egug
  { {0xf77f0064,0x8cb70015,0xac94004a,0x8db50033}},	//   yaç_, قديس_, чайш, ясці
  { {0x7a3408e0,0x62840a6f,0xdfd2002b,0x26c0008c}},	//   màti, osio, _تير_, _osio_
  { {0x9e650029,0x6284103e,0x2ba6000b,0x6fb30015}},	//   _فالن, nsio, क्षा, _زملا
  { {0xc3330008,0x3ebb0008,0x62841519,0x094a28ae}},	//   ווח_, _דצמב, isio, ични_
  { {0xf8160023,0x61e300b8,0x999800dc,0x415b0053}},	//   ước_, önli, örű_, ידיג
  { {0x2fc60035,0x62843cec,0x6249005a,0x0000006a}},	//   ndog_, ksio, _užov,
  { {0x7a2f02e9,0xf77f3ced,0x3ea63cee,0x69c33cef}},	//   tøtt, raç_, ntot_, _fane
  { {0x3ea60024,0xfba6005d,0x2ba6000b,0x683f003d}},	//   itot_, क्रम, क्रा, _jūdz
  { {0xf77f0251,0xe5c80033,0x62843cf0,0xd37b3cf1}},	//   paç_, цыял_, esio, ича_
  { {0x683f03eb,0x94a80010,0xdce80046,0x3ea602f2}},	//   _lūdz, ўтра_, _sedě, ktot_
  { {0xec090092,0x27e93cf2,0xaabc000b,0x4abc000b}},	// [8550] iếp_, _ioan_, ्टिक, ्टिव
  { {0x27e90092,0xdb00242f,0xef650061,0xdb0b002a}},	//   _hoan_, lemó, ğımı_, _zagó
  { {0x55ba0008,0xef650064,0x3ea60024,0x7fd50010}},	//   _המתו, şımı_, etot_, зілі
  { {0xd91b000a,0x27e91669,0x9ed9004a,0x200f1a13}},	//   סואל, _joan_, ймет_, uigi_
  { {0xf65f002e,0x15ff005d,0x200f3cf3,0x33da00a3}},	//   kvæm_, _उतार_, rigi_, _החרד
  { {0x8e080036,0xdd910115,0x27e9162b,0x25de000b}},	//   онів_, روع_, _loan_, खायी_
  { {0x3fb70029,0xdc750033,0x69c5001a,0x7ae60123}},	//   _وإرس, чыль, _óhei, äktn
  { {0xcfb40063,0x251c00a3,0x351c000a,0xfebb002b}},	//   _обсъ, יווא, יוונ, _پارت_
  { {0x69c33cf4,0xdce1003d,0x68360264,0xad8b0015}},	//   _pane, _pelē, sádk, _نضال_
  { {0xbef80015,0x5d640058,0x0000006a,0x0000006a}},	//   _برفض_, _يُقْ,   ,
  { {0x69c30005,0xf8650036,0xfd560053,0xdb0b002a}},	//   _vane, явно, _זשעי_, _pagó
  { {0x2c630064,0x6d3a000a,0x29190045,0x2a6d007c}},	//   _gıda_, _התענ, ăsa_, ppeb_
  { {0x96ba0015,0x69c33cf5,0xeaae0033,0xdb0b3cf6}},	//   حاجز_, _tane, _яй_, _vagó
  { {0x2c550024,0xc5d5005e,0x249839ea,0xf993002b}},	//   _tāds_, місь, turm_, _آبش_
  { {0x8cce005d,0xb97a000a,0x89da000a,0xdb0b002a}},	//   थियो, _הנצי, _לחסי, _tagó
  { {0x62841c23,0x683d0089,0x74160015,0xa856000a}},	//   tsio, lédn, أورا, _ציפה_
  { {0x57fb0008,0xd7fb0008,0x62840007,0x26c0003f}},	// [8560] _ללקו, _להקל, usio, _usio_
  { {0xd1750010,0x2bb8000b,0x60c9003d,0x7a340144}},	//   дыцы, _आस्थ, _ņema, tàti
  { {0x55770008,0x70560029,0xd6250031,0x155b000a}},	//   _מעין_, أنصا, _تعيي, _לכיב
  { {0x788200dc,0x40790080,0xdfd20029,0x683f0024}},	//   _hívá, ющую_, عيش_, _sūdz
  { {0x78820014,0xcf260015,0x2fc63cf7,0x3ea605ff}},	//   _kívá, أرضي, rdog_, utot_
  { {0x2bd1005d,0x6f020111,0x645e3cf8,0x3ea63cf9}},	//   _दोबा, rzoc, _kupi, rtot_
  { {0x3ea6022d,0x32430036,0xa2c4005d,0x79810026}},	//   stot_, _черг, रिक्, dalw
  { {0xbc670029,0x22ae003d,0x64410046,0x73fa004f}},	//   أمين_, pēkā_, ůliv, מּ֥ו
  { {0x6b800084,0xf1e0000b,0x79810034,0xaab8002b}},	//   ramg, नापन, falw, تگار_
  { {0x3dc50026,0xeaaf00e6,0x4efb000a,0x657e1afa}},	//   _galw_, اعي_, _ההמו, _neph
  { {0xd795006b,0xd917004a,0x645e2888,0xa7b900af}},	//   минъ, зья_, _nupi, олну_
  { {0x1ae6017a,0xec4a004a,0x8bc5005e,0xd117004f}},	//   _ноем, _узел_, _осід, לקיה_
  { {0xa3c0014e,0xf3f10023,0xe66709ef,0xeb97006b}},	//   ंजन_, ệm_, ятно, _хич_
  { {0x38cb0086,0x09e3381e,0x657e17c4,0x3abb000a}},	//   _گاهی_, _почн, _ceph, _למדנ
  { {0x69c80026,0x680b005c,0x657e00e8,0xa4d4005e}},	//   mdde, iędz, _deph, норі
  { {0xc2c50086,0x03c40608,0x54540bbe,0x889b000a}},	//   ويزي, нсум, евст, _הבהי
  { {0x69c83cfa,0x92a4002a,0x683d0003,0xc7b4000a}},	// [8570] odde, ółpr, lédo, _טבק_
  { {0xc104002b,0x69c83cfb,0x0000006a,0x0000006a}},	//   کومي, ndde,   ,
  { {0xad3a0036,0xdb0b002e,0xc1e8004a,0x69c83cfc}},	//   _квiт, _lagð, чьте_, idde
  { {0xb5fb002e,0x6836001c,0xdbcb001a,0xc7d8000a}},	//   ppás, tádi, jóðf, ּֽׁה_
  { {0x9e64005e,0x62493cfd,0x2bbd000b,0xfe57002b}},	//   евід, _džor, ्यसा, سیاب_
  { {0xfe700087,0xa2f6000a,0x63ad3cfe,0xfd10009a}},	//   ادن_, _חמשה_, lfan, گجه_
  { {0x64580152,0x63ad003f,0x25de000b,0x79810547}},	//   _évit, ofan, खाती_, valw
  { {0x69d800fb,0xfd100086,0xeb993cff,0xf65f02de}},	//   _anve, دجه_, ции_, gvæk_
  { {0x680b002a,0xde940054,0x7f581d8a,0x79813d00}},	//   będz, _патњ, _хаус_, talw
  { {0xe2a6002e,0xa9e40029,0x0889004a,0x7d180125}},	//   æðin_, ّثَن, обой_, éasú
  { {0x02ba005d,0x394518a9,0x22a30024,0xf8af002b}},	//   _उन्न, ьног, lūkā_, اکت_
  { {0x6d413d01,0x645e3d02,0x69d81447,0xd9400033}},	//   _izla, _rupi, _enve, ыцыi_
  { {0xf8c600dc,0xd7070033,0x645e3d03,0x63ad2cd2}},	//   óért_, дняе_, _supi, dfan
  { {0x2bbd005d,0x645e1915,0x4abc000b,0x7bc93d04}},	//   ्यवा, _pupi, ्टरव, ldeu
  { {0xb80a0029,0x63ad0ab5,0x65c3006b,0x683d0003}},	//   _ويتم_, ffan, ъбра, cédo
  { {0x680b005c,0x645a0251,0x8936000a,0x487a000a}},	//   zędz, ítiq, _קרקע_, _וטקס
  { {0x11da0015,0xa7fd3d05,0xc1ea187f,0x9f4a0061}},	// [8580] يورة_, apıs, одаж_, ümün_
  { {0x63ad003f,0x42230004,0x0697004f,0x201d0416}},	//   afan, вдув, _קדים_, enwi_
  { {0xafe60036,0x106a0080,0x76400089,0xe5f70135}},	//   можл, цией_, ůmys, _חזיר_
  { {0xcf26002b,0xf1a9004c,0x680b002a,0xdfd0012c}},	//   ورشي, יס_, wędz, طيت_
  { {0x69c83d06,0x7de6005e,0x683d0030,0x6d412755}},	//   ydde, дійд, zédo, _azla
  { {0x7bc900b8,0xf1b8000a,0x7e7b002a,0x01da0015}},	//   edeu, _מֶֽל, _dwup, _بوسع_
  { {0xdb0b002e,0xbc670015,0xd1320021,0xd8390085}},	//   _sagð, ومون_, _شمر_, luče_
  { {0x69c80026,0x61430054,0x683d23b6,0x5f930015}},	//   wdde, _реса, védo, _للفئ
  { {0x680b005c,0x22583d07,0x4a540ac9,0x8c4300af}},	//   pędz, _kirk_, нкис, њење
  { {0x6d5a0125,0x69c80702,0x260d006f,0xca470040}},	//   _ugta, udde, ržok_, وليه_
  { {0x63ad090e,0x69c80313,0xc1bb000a,0x7e6004dd}},	//   yfan, rdde, חמיש, _hump
  { {0xb8e6014e,0x628b00dc,0x7e603d08,0xe695004a}},	//   _उन_, ágok, _kump, нимы
  { {0x29050064,0x19941006,0x2bbd000b,0xd8390085}},	//   azla_, _заля, ्यरा, juče_
  { {0xc1c8005d,0xbb3b0008,0x5eeb000a,0x7a340144}},	//   रयोग, _ועדי, חַלְ, tàtu
  { {0x63ad0084,0x7e600375,0xe534004a,0x399b000a}},	//   tfan, _lump, верь, _ויוד
  { {0xeac80023,0x4422005c,0x60c90024,0x63ad003f}},	//   _kỹ_, _cjk_, _ņemo, ufan
  { {0x26c50048,0x877c000a,0xd8390085,0xf1a7226f}},	// [8590] ālos_, _ואחי, guče_, дрен
  { {0xeac80023,0x63ad0084,0xa2c4000b,0xa29402a3}},	//   _mỹ_, sfan, रिज्, тафі
  { {0x63ad08e9,0xf1a4006b,0xa5070033,0x22583d09}},	//   pfan, ъртн, _цяпл, _dirk_
  { {0xfe710029,0x749a000a,0x7e6031aa,0xab63002a}},	//   هدت_, _צירפ, _bump, ążko
  { {0x644d038d,0x6d41005c,0x7e603d0a,0x661500bc}},	//   mmai, _szla, _cump, oizk
  { {0xc27a0008,0x0dc80001,0x661500bd,0xadd60054}},	//   _מרשי, дући_, nizk, емљу_
  { {0xdce30024,0x271b000b,0xc537000a,0xc57c000a}},	//   manī, नपुर_, וָ֗ה_, חרות
  { {0x7bc93d0b,0x6aa93d0c,0x644d3d0d,0x3339004f}},	//   udeu, ttef, nmai, ּתֻמ
  { {0x9dab006b,0x644d01be,0x7bc93d0e,0xa9270046}},	//   _мъжа_, imai, rdeu, _mužů
  { {0xdf44008f,0x89a903fa,0x6f250045,0x644d3d0f}},	//   _рэсп, чков_, ărcă, hmai
  { {0x6d41189d,0xf1b20135,0x07a62e5e,0x6aa9020b}},	//   _uzla, נסט_, нанн, stef
  { {0x60da00dc,0xcc76000a,0x7c222b04,0x0000006a}},	//   _átme, _נענה_, _gjor,
  { {0xbbbd014e,0xdce10007,0xdffa0053,0x8f9a000a}},	//   ्यीक, _pelė, פּטש, הירי
  { {0xd8390085,0x6a170067,0xaa080015,0x3ea20123}},	//   vuče_, _تبصر, _يزول_, _åkte_
  { {0x35d5000b,0x33d6005e,0xf9fa000a,0x7c3b007c}},	//   दाज़, ніат, _מהסמ, olur
  { {0x7c3b02f2,0xd4910016,0xf3ff016e,0x644d3d10}},	//   nlur, ờn_, _clã_, gmai
  { {0x130a008f,0x7c3b0011,0xd1960054,0x0000006a}},	// [85a0] чнай_, ilur, ешењ,
  { {0xe7ac014e,0x16770008,0x644d12bf,0xa2d30015}},	//   ट्रप, _רגיל_, amai, ديكت
  { {0x2258002e,0xdfda006b,0x7e603a62,0x757b000a}},	//   _virk_, зъл_, _sump, _מטיפ
  { {0xb7db004c,0x7e601e56,0x4ea6127b,0x0000006a}},	//   ּקסי, _pump, ерка,
  { {0x44203d11,0x61f30723,0x44323d12,0xf777004f}},	//   mni_, ådlø, moy_, געני_
  { {0x443200b6,0xf4870086,0xfcc60001,0x7176002b}},	//   loy_, _تایی, ељим, _سهرا
  { {0xeac80092,0x6143070e,0x7c3b002e,0xc5f300f3}},	//   _sỹ_, _бера, flur, רדו_
  { {0x2bba0029,0xcb0a0063,0x44203d13,0x7e602ddf}},	//   ساعة_, зход_, nni_, _tump
  { {0x61ee003c,0x03560053,0xb4bd000b,0x6ec50015}},	//   _kobl, עיִש_, _इन्_, _لتلق
  { {0xd8f80036,0x644d090f,0x7c3b0045,0xfce62b98}},	//   дної_, zmai, alur, _позо
  { {0x44320035,0x02170008,0x644d2134,0x44203d14}},	//   koy_, תחים_, ymai, kni_
  { {0x80f50008,0x7c3b0590,0x44323d15,0x27ff002e}},	//   דֶשׁ_, clur, joy_, óun_
  { {0x8c4307bd,0xab770015,0xd6d81f61,0x44203d16}},	//   _сеце, _أمها_, нтр_, dni_
  { {0x63a625ef,0xaacd000b,0x61ee0f4b,0xd8ba0015}},	//   _ackn, ़िरक, _nobl, _فدعا_
  { {0x442017ea,0xdce3003d,0xbe3b000a,0x644d2ff9}},	//   fni_, vanī, פעלת, tmai
  { {0x493b0008,0x69ca3d17,0x3c0c0046,0xa93b000a}},	//   _מגוו, _hafe, těvy_, _מתופ
  { {0x61ee0026,0xa294005e,0x92590004,0xe6980033}},	// [85b0] _bobl, латі, даат_, _звыш_
  { {0xd9040086,0x44203d18,0xe1f3002b,0xf20400fd}},	//   می_, ani_, دسر_, ляхо
  { {0x644d0024,0x82340015,0x6ee7002b,0x44203d19}},	//   pmai, ارقا, کسال, bni_
  { {0xe7e4000b,0x8eb90033,0xa283002b,0xffe401c6}},	//   गाया_, дыкт_, _میرو, лючн
  { {0x539a013a,0xcee80015,0xa3440033,0x91f70015}},	//   _קישו, فرون_, _бэрл, _كأسا
  { {0x44d100df,0xdce80048,0xa2a6000b,0x61ee3d1a}},	//   _ką_, _nedē, _चमत्, _gobl
  { {0x7c3b0011,0x6b821007,0xdce10024,0x44d10713}},	//   tlur, _beog, _ielī, _ją_
  { {0x04dc0008,0xa158022a,0xdce10045,0x7c6400c3}},	//   לקול, _часу_, _află, داول
  { {0x2fc00020,0x1ef80015,0xc3b8000a,0x0000006a}},	//   õige_, _كعكة_, תלחץ_,
  { {0x7c3b002e,0x44203d1b,0x69ca3d1c,0x98b306f2}},	//   slur, zni_, _cafe, žeči_
  { {0xaae4002b,0x44203d1d,0x443202f2,0x7c3b3d1e}},	//   نسیو, yni_, yoy_, plur
  { {0x5b1508a7,0x2d873d1f,0x7b080012,0x2b9a0061}},	//   _имет, lane_, ßstä, rücü_
  { {0xc0520053,0x442005f6,0xef12000a,0x2d870045}},	//   יזט_, vni_, ֹּר_, oane_
  { {0x7bcb08e0,0xa6e3002e,0xca960008,0x6ef60053}},	//   _hagu, æðas, _ידני_, דזשד_
  { {0x2aab00fb,0x7bcb349c,0x44323d20,0x61ee3d21}},	//   løb_, _kagu, toy_, _robl
  { {0x44201d7a,0x69ca0064,0x79830026,0x2d873d22}},	//   uni_, _zafe, _henw, hane_
  { {0xe6120086,0x6b840020,0x66060080,0x44320493}},	// [85c0] _نشد_, _õige, _аппа, roy_
  { {0x9f440251,0x60d5005c,0xd6eb000a,0x11da0015}},	//   _romà_, _brzm, _חַטָ, بوطة_
  { {0xd5fb000a,0x2d873d23,0xe058002b,0xc329000a}},	//   _חפיר, dane_, فیست_, קו_
  { {0xef1a0080,0x79830026,0x937a0015,0xdcfa003d}},	//   мме_, _lenw, _تصدر_, _netā
  { {0x5f060063,0x7e2a017f,0xa2c1000b,0xe7aa000b}},	//   ъзда, міка_, रौद्, _कानप
  { {0x998c0089,0x2aab02de,0xc333000a,0x2d873d24}},	//   vodů_, døb_, _כור_, gane_
  { {0x6abc014e,0x7bcb20fb,0x69ca3d25,0x60d5002a}},	//   ्ट्र, _bagu, _rafe, _grzm
  { {0x6e960029,0xab5d005c,0xfc2f00e6,0x63a403e5}},	//   _للرا, jeżd, يحي_, ngin
  { {0xf4130008,0x7bcb3d26,0xbda60015,0x5a343d27}},	//   יפה_, _dagu, _لحضو, лнит
  { {0xbd8a0074,0x998c0089,0x683d3d28,0xa022007c}},	//   _آنان_, rodů_, médi, _ööbi
  { {0xc19b000a,0x319b000f,0x7e290015,0x683d0003}},	//   ושיי, ובינ, _أسقف_, lédi
  { {0x63a40079,0x20060034,0x69ca3d29,0x3f843d2a}},	//   jgin, nhoi_, _wafe, _jemu_
  { {0x44d10050,0x63a4065b,0x99ea0015,0x683d0003}},	//   _są_, dgin, _يعتق_, nédi
  { {0x7bc00005,0x99160015,0x6aa03d2b,0x7bcb3d2c}},	//   lemu, _لبعض, mumf, _zagu
  { {0x6d5c002c,0xde880092,0x33950033,0xdb00007c}},	//   _úrad, hị_, лавё, remõ
  { {0x39570008,0x79881745,0x7bc00049,0xe7aa000b}},	//   _בשום_, ladw, nemu, _कायप
  { {0x36d52229,0xa3c7000b,0x83840033,0x6aa00012}},	// [85d0] _сопр, ोएब_, рысе, numf
  { {0x79880026,0x44d110da,0xe718000a,0x7bc01b03}},	//   nadw, _tą_, _שחזר_, hemu
  { {0x7bc0137f,0xab5d002a,0xdfd50033,0xa1150015}},	//   kemu, leże, ложы, دوات
  { {0x2d870050,0xf8b300b2,0x212a002b,0x7bc001d7}},	//   wane_, ישע_, رينی_, jemu
  { {0xf3f10023,0x8f34008f,0x539a013a,0x645d0035}},	//   ệu_, аецц, _אירו, _iisi
  { {0x3dcc0176,0xfe700086,0x98a2005c,0x7bcb3d2d}},	//   _cadw_, زده_, łkę_, _sagu
  { {0x645d0a9e,0x7988325c,0x2d870c1a,0xdd8e0021}},	//   _kisi, dadw, rane_, سوي_
  { {0x7bc02cf3,0x2b57002b,0x2d873d2e,0x5ac914c2}},	//   gemu, نیاد_, sane_, елим_
  { {0x79830026,0x7bcb0493,0x2d873d2f,0x44391788}},	//   _penw, _vagu, pane_, _mks_
  { {0x1ddb003b,0x3dcc0176,0xf9910015,0x645d3d30}},	//   _تبرع_, _gadw_, حبة_, _lisi
  { {0xa2ca005d,0x7a3d0251,0x63a43d31,0x7bc00030}},	//   _सैन्, nèti, ygin, bemu
  { {0x8ba4005e,0x2d8507ae,0x79830034,0x645d3d32}},	//   _виїж, _hele_, _wenw, _nisi
  { {0xa3e7005d,0xfc300015,0xdcf80091,0xfbd2000a}},	//   पान_, _بحل_, davę, _לתא_
  { {0x1a9a0053,0xaa920029,0x2bbd000b,0x2d850030}},	//   _ניצע, _الوث, ्यका, _jele_
  { {0x2d8504f9,0x5e560053,0x645d36f0,0x69c13d33}},	//   _mele_, טישע_, _bisi, mele
  { {0xb4250015,0x2d8501d7,0x69c13d34,0x94850033}},	//   لعقو, _lele_, lele, рыёд
  { {0xe2973d35,0xc68f0029,0xd36f0029,0x69c12d81}},	// [85e0] лат_, _فِي_, سهل_, oele
  { {0x645d214f,0xdb0a0152,0x44390293,0x2d853d36}},	//   _eisi, énér, _eks_, _nele_
  { {0xd5fb0008,0x5a160053,0x69fa0053,0x645d3d37}},	//   _נפטר, נקען_, עלעק, _fisi
  { {0xf3f10023,0x6b89003f,0xc169000a,0x69c13d38}},	//   ệt_, jaeg, לח_, hele
  { {0xa83700b2,0x877b0053,0x765e003f,0x69c13d39}},	//   אָגס_, גאני, _kipy, kele
  { {0x69c10014,0x2d853d3a,0xde880092,0x645d003f}},	//   jele, _cele_, rị_, _zisi
  { {0x61ea002e,0xad260015,0x69c13d3b,0xf65f00cb}},	//   öflu, درشو, dele, nvær_
  { {0xab5d005c,0x69c13d3c,0xeb970054,0x68280061}},	//   zeże, eele, гић_, yıda
  { {0xcff70008,0x69c13d3d,0xb21b0134,0x2d85050a}},	//   _עצמה_, fele, _ivær, _fele_
  { {0x60c90048,0xdcfa0011,0x2d850111,0x1a67002b}},	//   _ņemi, _cetă, _gele_, دیوی_
  { {0x79880176,0x32370643,0xb21b3d3e,0x6aa02d61}},	//   radw, רטין_, _kvær, sumf
  { {0x69c1003f,0x3157039e,0xb807002b,0xdc8b000a}},	//   aele, טיין_, ابده, _נְבָ
  { {0xcaf60196,0xddc90011,0x645d2baa,0x69c13d3f}},	//   _حساب, _uteţ, _risi, bele
  { {0x68280064,0x75eb0064,0x69c13d40,0x645d1636}},	//   rıda, _yüzy, cele, _sisi
  { {0x344b0124,0xe4e4192f,0x765e0026,0x5cb8000a}},	//   ечан_, бітн, _dipy, כֶּס
  { {0xe7870001,0x17fb0029,0xc94b000a,0xc6e7005e}},	//   _суко, _سرعة_, _אֲחֹ, _біоп
  { {0xdcf80007,0x52152263,0x645d3d41,0x44393d42}},	// [85f0] ravę, адат, _visi, _vks_
  { {0x94750074,0x91e40001,0x98a8000b,0x7a3d0144}},	//   _نگرا, бође, _कमाए, tèti
  { {0x628d0a8e,0xceeb002b,0x2d850045,0x02440058}},	//   ssao, کران_, _rele_, حَلَ
  { {0xe8d70008,0x628b00dc,0x547a000a,0x0574002b}},	//   טובר_, ágos, _שטרו, _پاید
  { {0x66f7005d,0x22590015,0x69c13d43,0xb21b02de}},	//   ुनिक_, _للحد_, yele, _dvær
  { {0x2bda005d,0xa0c50086,0xb8820107,0x7c9501dc}},	//   _मोबा, _پيرو, _číns, ариц
  { {0x06380053,0x69c13d44,0xdcf80046,0x6b893d45}},	//   אנגט_, vele, mavě, taeg
  { {0xdcfa04f9,0x06f7005d,0x69c10574,0x753a0012}},	//   _setă, ुनाव_, wele, ützi
  { {0xbda700e6,0x800409ef,0x3ae7002b,0xfeb8002b}},	//   _محاو, _учре, ابعی_, _مالت_
  { {0x6b890020,0xcef40001,0xc9550080,0x7c873d46}},	//   saeg, _упућ, итны, _буде
  { {0x69c13d47,0x7cdc0045,0xd9450fdc,0x98160058}},	//   rele, _cără, рени, لبحا
  { {0x31360447,0xc975002b,0x366a0054,0xe7dd000b}},	//   ירתך_, داکث, камо_, यागप
  { {0x2486002c,0x09e500a5,0x290c002a,0x69c13d48}},	//   _ňom_, _волн, azda_, pele
  { {0x7afb003f,0xaad2000b,0xa966007e,0x1da9000b}},	//   myut, तिरक, _киша_, च्चत
  { {0x765e000c,0x141a0015,0xd939004c,0x18a5058f}},	//   _vipy, نيسة_, _בײַש, _тайм
  { {0x3ced005d,0x7afb0061,0x070a0015,0x27e002f2}},	//   _अपने_, oyut, _ليبي_, _unin_
  { {0x883b000a,0x765e0026,0x3fc6002b,0xd1860fea}},	// [8600] _בתקו, _tipy, یگری_, илай
  { {0x41b30029,0x9f4d0251,0xb21b0293,0xe1ff3d49}},	//   يمقر, _lleó_, _svær, _stór_
  { {0x6f660001,0x661c3d4a,0x759b000a,0x859b000a}},	//   авез, mirk, _בייח, _בשיו
  { {0x661c3d43,0x61fe01de,0x28a80065,0xe0430d7a}},	//   lirk, skpl, _कमसि, онхи
  { {0x683d0152,0xdfcf0115,0x3ed40015,0x9f49001a}},	//   cédu, بين_, إقتر, óað_
  { {0x27350092,0x867b000a,0xe1650015,0x7cd60015}},	//   ụng_, דרסו, _هدفي, لتعذ
  { {0x6da3050e,0xb21b0134,0xfce80029,0x50f8000a}},	//   ција, _tvær, افعي_, _גִּד
  { {0x661c0509,0xcfaa00c3,0x60c2002a,0x6d4801c0}},	//   hirk, _جاسم_, łoms, _vzda
  { {0x15f8014e,0xbf9b0008,0x7cdc0045,0x6da60de9}},	//   ुसार_, _שימש, _sără, _виза
  { {0x7cdc0011,0x49d7004a,0x996601ca,0xd2b7004f}},	//   _pără, адью_, штил, סלית_
  { {0xd4910023,0x661c00e8,0x81fb000a,0x6d480e2a}},	//   ời_, dirk, דהיז, _uzda
  { {0xacf50015,0x09030033,0xd0060067,0x7ae60123}},	//   _اسْت, ючым, سل_, äkts
  { {0x63b60034,0xec13006e,0x661c1128,0xa9c5009a}},	//   dfyn, _بوند, firk, _گزنو
  { {0x18660124,0xfa330086,0x2abb000a,0x2cbe01c2}},	//   _књиг, _ورود, _סמוא, _kptd_
  { {0xe6540191,0xedf4014e,0xb8940029,0x63b60026}},	//   івсь, _अवैध_, _البع, ffyn
  { {0x53980036,0xab5d005c,0x98140015,0xd3780429}},	//   ився_, leża, _وبيا, ичу_
  { {0x24580080,0xe1670001,0x62d90010,0x52d90033}},	// [8610] рать_, ађен, ымаў_, ымаю_
  { {0xc73c0008,0xe2c80015,0xf1ab0015,0xea77000a}},	//   _בתחת, ؤولو_, ضائه_, יגמר_
  { {0x35f80086,0x8f000010,0xf4350010,0xa3e7000b}},	//   _خريد_, кiя_, _генэ, पाद_
  { {0x4e950029,0x8014005e,0xd347002b,0x7415002b}},	//   مشتر, офіц, _نیزه_, _چوگا
  { {0x1de2014e,0xc2570074,0x201c0251,0x645a3d4b}},	//   पांत, _نخست, èvia_, ïtie
  { {0xee3813ae,0x6e920029,0x92a9002a,0x248d003d}},	//   ані_, ألوا, agłó, ņemu_
  { {0xfca80015,0x9da8006b,0x70943d4c,0xbca80058}},	//   لايو_, ръча_, _марф, لديك_
  { {0xf412000a,0x661c3282,0x0be90058,0x0000006a}},	//   ּ֤ה_, zirk, افةً_,
  { {0xe7eb000b,0xa96909d9,0x539c004f,0xb4c40065}},	//   टाना_, липа_, דיחו, _एन्_
  { {0x1099000a,0x1a0500a5,0x201d002a,0xda0902be}},	//   ְבָב, спом, liwi_, ايده_
  { {0x63b60026,0x3860007c,0x99150033,0x661c171c}},	//   yfyn, _piir_, сьпі, virk
  { {0x661c00b8,0x7e69003f,0x7afb003f,0xd7ef0015}},	//   wirk, _kuep, pyut, ّكَ_
  { {0x7e6100f2,0x661c0c82,0xfc7d0046,0x6702000b}},	//   _kilp, tirk, žádá_, रैंक_
  { {0x99850029,0xbb3a0053,0x77430015,0xa2db000b}},	//   _الثو, _געני, سَّم, निन्
  { {0x661c0064,0x201d003f,0xf990002b,0xa5070245}},	//   rirk, kiwi_, _آبه_, бера_
  { {0xf3f10023,0x78fa0008,0x69de0251,0x644f1332}},	//   ệp_, _תפקו, _òper, _chci
  { {0x63b60176,0x38b13d4d,0xd455005e,0xc7b3000a}},	// [8620] rfyn, lár_, ітсь, _זבח_
  { {0xe3b204b6,0x6d410064,0x68ec0091,0x5fdd0065}},	//   _کرد_, _oyla, ţodţ, _नोबल
  { {0x04b60063,0x85f7000a,0xb5f7000a,0x7c2d00bc}},	//   _успя, _הציע_, _הציג_, čarj
  { {0xe7eb000b,0x4f0a0457,0xd12f006e,0xefb2002b}},	//   टाया_, лнен_, رمن_, ثیرگ
  { {0x248d0048,0x6e460010,0x6d410064,0x60c90024}},	//   ņemt_, бедз, _ayla, _ņemt
  { {0x44d80089,0x6d412758,0xdee50015,0x6fb6002b}},	//   _kč_, _byla, تأمي, _گمرا
  { {0xdd990036,0x9078000a,0x64440201,0x8078000a}},	//   рші_, _כְּפ, olii, _כְּה
  { {0x6d410335,0xb47b004c,0x6444008c,0xd0070937}},	//   _dyla, אָזי, nlii, _лесе_
  { {0x644400f2,0x93fb0008,0x539b015b,0x4ed5006b}},	//   ilii, טלקי, אספא, _мюфт
  { {0x98b8000d,0x3eb90123,0xbe130058,0x44d8005a}},	//   алот_, _ästa_, _فوقع, _oč_
  { {0x41bb0053,0xabaa0029,0x4ddb0008,0xeaaf002b}},	//   נצטע, _مهام_, _תחבו, وعی_
  { {0xfaa6008f,0x2fc6002d,0x39420024,0x50db004c}},	//   _гадо, neog_, āks_, אקטא
  { {0xab5d0050,0x19940010,0xa3e7005d,0xdc3b0053}},	//   leżn, _даля, पास_, _געאר
  { {0x6e24002d,0x201d003f,0x862708f7,0x38b13d4e}},	//   éibh, ziwi_, сьме, bár_
  { {0x4c98000f,0x9f440251,0x5559006b,0xda4b000a}},	//   יֹּא, _comú_, равя_, _עֲדָ
  { {0xcc770008,0x9d1b004c,0x2d8e0012,0x6444007c}},	//   מעלה_, אולט, hafe_, glii
  { {0x7a3d1df5,0xe3b00029,0x44d800bd,0x53471884}},	// [8630] mètr, عرف_, _eč_, схва
  { {0x320713ce,0xd678002b,0xdb19002a,0xd2510015}},	//   óny_, _احيا_, _zawó, ذنا_
  { {0x753a0012,0xe8160065,0x5f790369,0x61f5013b}},	//   ützt, दोवा_, لماس_, _vozl
  { {0x248d0024,0x9ed9004a,0x7a3d0003,0x251a000a}},	//   ņems_, имет_, nètr, _כותא
  { {0x26dc00b2,0x8e5505d1,0x38b100dc,0x8d651768}},	//   ָקומ, откі, zár_, овле
  { {0x201d003f,0x56b80008,0x999e0091,0x443b01c2}},	//   siwi_, צפון_, imtų_, loq_
  { {0xfbda005d,0xcc8609ef,0x2bda000b,0xd5fc000a}},	//   _मोहम, обще_, _मोहा, רפור
  { {0x251c0053,0x6b840020,0x9f35005e,0x7c560015}},	//   טווא, _õigl, _дебі, يلور_
  { {0xab293d4f,0x7e610cbb,0x6d413738,0x44293d50}},	//   ропа_, _tilp, _wyla, ina_
  { {0x38b10014,0x3ea0002d,0xa3c7000b,0x3f8f1ea0}},	//   tár_, áite_, ोएँ_, lagu_
  { {0x2903163c,0xf0cf0033,0xd7ea0432,0x44293d51}},	//   ája_, дзiн_, амне_, kna_
  { {0x290b005c,0x3ea0065d,0x38b1002e,0xc5e90008}},	//   ąca_, šite_, rár_, _בד_
  { {0xd4910023,0x34c2005d,0x290300bd,0x38b11a4b}},	//   ần_, शब्द, šja_, sár_
  { {0x2ca7003e,0x386a002d,0x1f5a0053,0x7c3b0f4b}},	//   ound_, úirí_, ידרא, lour
  { {0x44290084,0x46190010,0xa8060061,0x33f61017}},	//   fna_, сцяў_, _akış, очас
  { {0x6836002c,0x24070036,0xc952000a,0x44293d52}},	//   hádz, онси_, _קמה_, gna_
  { {0xa3c9000b,0xdb110003,0xab5d002a,0x6b8b1351}},	// [8640] ऊज़_, éfèr, zeżn, _megg
  { {0x7ae4002d,0x7c2900b8,0x79810026,0x64440607}},	//   _áite, hner, nblw, slii
  { {0x63af022d,0x64440fb2,0x55bb000a,0x44290fde}},	//   ännö, plii, _דמיו, bna_
  { {0x7c3b038d,0x1eaa0015,0x44293801,0x7e9a0015}},	//   jour, لاتي_, cna_, لنصر_
  { {0xa3e7014e,0xa857000a,0x539b000a,0x3dc70034}},	//   पार_, קינה_, _דיכו, fenw_
  { {0xa6e30084,0x44203d53,0x35b2000b,0xc6cb000a}},	//   æðis, lii_, _जाफ़, שֶׁ֛
  { {0x2ca70084,0x2d8e00b8,0xb148002b,0x05b2000b}},	//   gund_, rafe_, _ایام_, _जानब
  { {0x7c3b1151,0x44203d54,0xbc370015,0x8fe60015}},	//   gour, nii_, يسيا_, _بأسم
  { {0x9c87006f,0x44203d55,0x0000006a,0x0000006a}},	//   _počú, iii_,   ,
  { {0x442909cb,0x44203d56,0x7c292d24,0xa2bb000a}},	//   zna_, hii_, aner, סמיט
  { {0xc173000a,0x44293d57,0x67d50098,0xd8390085}},	//   וחת_, yna_, пону, luči_
  { {0x37740010,0x7c3b0493,0x442900c0,0x1ae6004a}},	//   дыёс, cour, xna_, _моем
  { {0x7764010f,0xcf93000a,0x442909cb,0xab69002b}},	//   държ, וטר_, vna_, _احمق_
  { {0x4429005c,0x2d8c00b8,0x6b8b0111,0xb9b30015}},	//   wna_, _jede_, _zegg, _يمنع
  { {0xa3e7005d,0x68fc00c0,0xa4d4005e,0xcc78000a}},	//   पाल_, ärdd, морі, מְּר
  { {0x2d8c29e2,0x78a802de,0x44203d58,0x427502a3}},	//   _lede_, mudv, gii_, згас
  { {0x416b0001,0x442902ce,0xd83902c6,0x69c83d59}},	// [8650] ајем_, rna_, juči_, oede
  { {0xdb110152,0xd9040086,0x2d8c01f0,0xd5b2000b}},	//   éfér, نی_, _nede_, _जायज
  { {0x6836002c,0x69c83d5a,0x44293d5b,0x672b003d}},	//   vádz, iede, pna_, ņojā
  { {0x64da0053,0x98b3016f,0x44203d5c,0x69c83d5d}},	//   _פֿיס, žeći_, cii_, hede
  { {0xb7dc0008,0x63ad0cd8,0x7c3b1447,0x2d8c3d5e}},	//   יקאי, mgan, vour, _bede_
  { {0x63ad0593,0x69c83d5f,0xdb0002de,0x667c000a}},	//   lgan, jede, ogmæ, סטוק
  { {0x7c3b3d60,0x6836006f,0x6b8b3d61,0x2d8c3d62}},	//   tour, rádz, _pegg, _dede_
  { {0x2ca73d63,0x3dc70034,0x73fb000a,0x63ad3d64}},	//   rund_, senw_, יּ֖ו, ngan
  { {0x2d8c3d65,0x63ad0855,0x83b6000a,0x5e450015}},	//   _fede_, igan, הִיא_, _فَرْ
  { {0xcce70086,0x7c3b1959,0x44203d66,0x63ad0012}},	//   _وساي, sour, zii_, hgan
  { {0x6b8b01c2,0x39450a31,0x63ad0012,0x7c3b3d67}},	//   _tegg, яног, kgan, pour
  { {0x2116004c,0xdcfa0046,0x9c820046,0x4cba004f}},	//   פֿיש_, _letě, áčen, _למעג
  { {0x63ad0b99,0x86750033,0xf6d5005e,0x1ae51c4d}},	//   dgan, дысц, міря, _холм
  { {0x9c823d68,0x4420051e,0x7bc90161,0x3f8d00aa}},	//   ščen, wii_, leeu, _leeu_
  { {0xb4c8000b,0x65c30033,0x44203d69,0x63ad3d6a}},	//   ोटे_, эбра, tii_, fgan
  { {0xb89a0008,0x68fc00c0,0x78fa000a,0x141a0015}},	//   _הבקש, ärde, _לפצו, حيرة_
  { {0x44203d6b,0x06970015,0xd387058f,0x9576004a}},	// [8660] rii_, _فنية_, яйте_, _нынч
  { {0x63ad05d0,0x9737000a,0xd6eb000a,0x44203d6c}},	//   agan, _מרפא_, _הַטָ, sii_
  { {0xb5fb0008,0xd5fb0008,0x2d8c3d6d,0x7f860015}},	//   _הליכ, _הפיר, _rede_, كلان
  { {0x69c806e7,0xd019008b,0x2d8c2a8c,0x35b20065}},	//   zede, офі_, _sede_, _जाड़
  { {0xf8a8005d,0x2d8c1ea7,0xf413000f,0x66fe000b}},	//   _कम्प, _pede_, _נפש_, ॉनिक_
  { {0x02460015,0xd8390085,0x69c8016e,0xa669004f}},	//   _رَأَ, ruči_, xede, חֻקִ
  { {0x69c809cb,0x7e7b008c,0x2d8c3d6e,0x0000006a}},	//   vede, _etup, _vede_,
  { {0x8cbd005d,0x69c83d6f,0x309b000a,0x109b000a}},	//   _शहरो, wede, _לשלמ, _לבלב
  { {0x8f000010,0x62960035,0x69c80293,0xbea31979}},	//   кiх_, nsyo, tede, _патк
  { {0x69c802c1,0x2006008c,0x7d270030,0x4e7b000a}},	//   uede, lkoi_, ársá, _לאמצ
  { {0xb4c8005d,0xdd7b0008,0x6d7b000a,0x7d7b000a}},	//   ोटो_, _הטבל, _האבח, _הנבו
  { {0x629600b6,0xd4910016,0x4c160067,0x80c4000b}},	//   ksyo, ầm_, _عباس, _रहने
  { {0xb866002b,0x5694006b,0x78a802de,0x41ac000b}},	//   _کاتو, наят, sudv, _चांस
  { {0xa2db005d,0x7afd3d70,0x0000006a,0x0000006a}},	//   निस्, äste,   ,
  { {0x49bb0008,0x19bb009d,0xa9bb000a,0x753a0012}},	//   _המוס, _המוב, _הזור, ützp
  { {0xe3c50015,0x2be5000b,0x63ad3d71,0x9c7c0160}},	//   بْرَ, काएं_, ugan, _grče
  { {0x979c0008,0xc6190080,0x479c0008,0x18380135}},	// [8670] _השחק, _моих_, _היחס, _מאהל_
  { {0x20c8014e,0x63ad3d72,0xc692000a,0x61f80138}},	//   रबंध, sgan, _שאי_, пнуў_
  { {0x7fd50036,0xf1a40010,0x30a70010,0x55ba000a}},	//   ділі, эртн, ярав, _ומתו
  { {0x2c713d73,0x0000006a,0x0000006a,0x0000006a}},	//   _rád_,   ,   ,
  { {0xdcf80024,0x8e390029,0x9ea9005e,0x2c71006f}},	//   kavē, يستر_, івка_, _sád_
  { {0x273c0016,0xf2d2000a,0x66e8000a,0x6da521a4}},	//   ửng_, _שעם_, ל֥וּ_, фика
  { {0xed560083,0x859c004c,0xd2500015,0xc172004f}},	//   мош_, זשוו, _إنّ_, _יחם_
  { {0xdfd40080,0x3a990342,0x5c540033,0x7ae40091}},	//   _посы, отою_, нтыф, _šita
  { {0xee840010,0x05dd000b,0x7bc90547,0xbdb5012e}},	//   _зыхо, मयाब, reeu, _обај
  { {0xe810000b,0xf2d4015b,0xaa560015,0x8d95002b}},	//   ासभा_, געץ_, وليا_, _آلاش
  { {0x07a61402,0x200d0079,0x6ce402a3,0xc7a63d74}},	//   манн, _klei_, _піце, минк
  { {0x7c940015,0xbb550015,0x6d3a000a,0x7d03001a}},	//   _أشلا, _قناب, _ותענ, myns
  { {0xc9f50029,0xac060036,0x6b650010,0xa3e7000b}},	//   _يستع, _інша_, _ўкла, पाई_
  { {0x200d0251,0x69250001,0xf1ac000b,0x09e4005e}},	//   _llei_, _омла, _चाइन, _поін
  { {0xb97a000a,0xdfde002a,0x9663096d,0xef650061}},	//   _ונצי, ółkę_, ткре, ğıyı_
  { {0x9c7c0107,0xd4350015,0xe3ba0033,0x0000006a}},	//   _urče, ّعْب, ўба_,
  { {0x43460004,0x6e2302f2,0xa7eb000a,0xe1fa2a6f}},	// [8680] феав, kinb, _וַיֻ, ога_
  { {0xf3e90053,0x62960035,0x27e910ca,0x81aa0015}},	//   ױף_, rsyo, _znan_, تطرف_
  { {0x2006008c,0x200d1033,0x6e2301f9,0x0000006a}},	//   tkoi_, _blei_, dinb,
  { {0xa2db014e,0xc0060033,0x629602f2,0xd928004f}},	//   निश्, ьпек, psyo, הֵנָ
  { {0xf1aa002b,0x20073d75,0x7d03001a,0xee3a0189}},	//   _واسه_, ênia_, eyns, онд_
  { {0xa2db005d,0x55bb004c,0x01660015,0x6e233d76}},	//   निर्, ַמפו, _يُحَ, ginb
  { {0xd5ed00a7,0x0caa0036,0x6c930015,0x0469000a}},	//   _quả, ітки_, نشيط, ֔יהָ_
  { {0x8af80b1a,0x711b000a,0xdfd20015,0x61fc3d77}},	//   знис_, _וולפ, _جير_, _horl
  { {0x6e230035,0x61fc3adb,0x3e7b0045,0xddea002b}},	//   binb, _korl, _câtă_, _ورطه_
  { {0x4efb0008,0xc3330008,0x1efb000a,0x3f863d78}},	//   _והמו, כוח_, _ולמע, lbou_
  { {0x9e650015,0xd917004a,0x7857002b,0xe7eb000b}},	//   _ساكن, дья_, ویتز_, टाला_
  { {0x0bd40015,0x3f863d79,0x0000006a,0x0000006a}},	//   _سيتح, nbou_,   ,
  { {0xe9da000d,0xdb2400f2,0xbbbc005d,0x61fc0161}},	//   _мкд_, äräy, ्जीक, _oorl
  { {0x8a030063,0x61fc3d7a,0x89d8002b,0xdb003d7b}},	//   _изче, _norl, _روبر_, rgmä
  { {0x443f0023,0x6ed5000b,0x7e6801f9,0x69da02dc}},	//   _ưu_, _मैनु, _midp, mdte
  { {0x889b000a,0xb89b000a,0x69d81b65,0x9cd7000a}},	//   _ובהי, _ובהש, _have, וולה_
  { {0xa294005e,0x69d83d7c,0xa3c0000b,0x8335006b}},	// [8690] каті, _kave, ूज़_, хнах
  { {0xe1d90010,0xf3ff0016,0x7127006e,0x45d501ca}},	//   ядзі_, _giãn_, ورال, _џонс
  { {0x0ef9000b,0x38b83d7d,0x78ba0118,0x7bc20046}},	//   ्न्स_, nér_, nttv, _obou
  { {0x6fd40036,0x155a0008,0x69d80293,0xa2a7000b}},	//   кціє, _מכתב, _lave, _चिप्
  { {0x9f400084,0x3d17005d,0x38b800dc,0x937a0008}},	//   ðið_, _भेजे_, hér_, _מטרת
  { {0xc332013a,0x61fc0b90,0x7bc20116,0x7d0314e9}},	//   _תוך_, _gorl, _abou, tyns
  { {0xeb9901c5,0x8c450302,0x6e233d7e,0x0000006a}},	//   пий_, неке, rinb,
  { {0x61fc0064,0x1bb90029,0x6e2300c0,0x7ae23d7f}},	//   _zorl, سابع_, sinb, _brot
  { {0x78ba003c,0x765c0026,0x8a050b08,0x39473d80}},	//   ettv, ymry, езпе, _syns_
  { {0x5d840029,0xa2a7005d,0x9c820844,0x7ae2366c}},	//   _للكل, _चिन्, ščan, _drot
  { {0x69d801e2,0x6d480026,0x38b80134,0x2d8700bd}},	//   _dave, _gyda, gér_, mbne_
  { {0xb6a6000d,0x68fc00c0,0xf6490008,0xe73a0afb}},	//   нимл, ärda, _הצ_, зем_
  { {0x7ae23d81,0xef12000a,0x69d81135,0x501a004f}},	//   _grot, ָּר_, _fave, פושו
  { {0x4c99000a,0x8afa000a,0x60d50e8c,0xbafa000a}},	//   ּבּו, _מהני, _oszm, _מהנש
  { {0xddc9044c,0xf992000a,0x7bd901d7,0x3f86013f}},	//   _otež, _גרו_, _kawu, ybou_
  { {0xe73a0080,0xb6020089,0xd91a0008,0xccf2000a}},	//   _ней_, _žádo, _מוצל, נכן_
  { {0x52aa0c55,0xc1e8002b,0xd2aa0033,0x43750249}},	// [86a0] явам_, وکسل_, якае_, туст
  { {0xa3ba0086,0xc73b000a,0x38690978,0xe7c1000b}},	//   _کادر_, _מתפת, _ziar_, ष्ठप
  { {0xa3ea0403,0x61fc1226,0x3f860264,0x3ea6002a}},	//   _една_, _vorl, tbou_, wrot_
  { {0xa3ba005d,0x6d480026,0x61fc3d82,0xfbae000b}},	//   _आउट_, _ryda, _worl, _टाइम
  { {0x6d4811bc,0x69c300bc,0x38b80030,0x60d50030}},	//   _syda, _obne, zér_, _eszm
  { {0xfe790046,0xf2d3000a,0x29050091,0x62840fb7}},	//   _trůn_, _געש_, kyla_, mpio
  { {0x8fa6008f,0x69d83d83,0xdc030046,0xc0e308fc}},	//   _паве, _rave, ačís, _йорк
  { {0x961d014e,0x38b81a4b,0x69d80398,0x6d480264}},	//   _नष्ट_, vér_, _save, _vyda
  { {0x6d480050,0x69d83d84,0xaf770053,0x7e6800c0}},	//   _wyda, _pave, _װעבס_, _tidp
  { {0x3869002f,0x38b83d85,0xe9f8005e,0x7afd2eaa}},	//   _siar_, tér_, єнні_, ästa
  { {0x0b8a005f,0x290a0014,0x7ae23d86,0x9f4402c1}},	//   _если_, ába_, _wrot, _tomó_
  { {0x69d8003e,0x998c0030,0x7ae23d87,0xb7eb000b}},	//   _wave, ridő_, _trot, टाइम_
  { {0x69d83d88,0xabfb000a,0x501b000a,0x7c223d89}},	//   _tave, _מהאר, לוטו, _imor
  { {0x8cd7005d,0x29050089,0x3b530010,0x44223d8a}},	//   _मनमो, byla_, _скір, _amk_
  { {0x248d016f,0x58d401b7,0xda65012c,0x43952333}},	//   ćemo_, _ройт, _شاهي, кавс
  { {0x2103002c,0x60c701d7,0x44220816,0xd92b004f}},	//   nčiť_, _rpjm, _cmk_, _מֵחָ
  { {0x6b840005,0x2d87006f,0xf4080015,0x2418055f}},	// [86b0] _õigu, ybne_, ريكى_, хоты_
  { {0x2103006f,0x78a83d8b,0x41740058,0x64460052}},	//   hčiť_, ordv, هامس, _ekki
  { {0xc0780036,0x625000f2,0x5f95017a,0x31c40033}},	//   есії_, päon, виет, ыств
  { {0xf8b3004c,0xf4070015,0xf1c00091,0x62500d4a}},	//   טשע_, _أبدً, ėšas_, läol
  { {0x6283010b,0xbfb4002b,0x2103006f,0x644d3d8c}},	//   ćnos, احمت, dčiť_, mlai
  { {0x62500020,0x171c0008,0x644d3d8d,0x9c7c0085}},	//   näol, הודע, llai, _srča
  { {0x6cd20029,0xdce1005c,0x25d80008,0x644d3d8e}},	//   لقوا, _oglą, גוון_, olai
  { {0x7c840054,0x8ca2000b,0x5f740015,0x62500012}},	//   ћује, _गिरो, _ماكر, häol
  { {0x3ced000b,0x68fc0123,0xdea4002b,0x7bdb053a}},	//   _अपके_, ärdn, _مینی, rduu
  { {0x644d002d,0x2fcf3d8f,0xf9910015,0x201c003d}},	//   hlai, legg_, جبة_, īvie_
  { {0x6abb198f,0xc172000a,0x6bd6002b,0x16ca000b}},	//   stuf, יחי_, رویس_, िब्ब
  { {0xa088000a,0x62840535,0x0000006a,0x0000006a}},	//   עְתִ, ypio,   ,
  { {0x9aa40002,0x8f9a00a3,0x78a83d90,0x44222028}},	//   _ممنو, וירי, ardv, _rmk_
  { {0xc5d502e1,0xceb2000a,0x64a60033,0x6e2d0125}},	//   лісь, ביך_, кага, éabh
  { {0x3667239c,0x2508002b,0x44221839,0x7c220034}},	//   таро_, ررسی_, _pmk_, _ymor
  { {0x644d3d91,0x62843d92,0x2fcf00cb,0x6b892075}},	//   glai, tpio, jegg_, nbeg
  { {0x62660015,0xe2973d93,0x91960054,0x6aa90dca}},	// [86c0] ناطق, кат_, вјеш, nref
  { {0x17570008,0xd1790010,0x6b890012,0x9757000a}},	//   _בספר_, есці_, hbeg, _ביפו_
  { {0x644d3c54,0xdfda006b,0x6aa90034,0x6b89303c}},	//   blai, дъл_, href, kbeg
  { {0x6aa906f5,0x78fa009d,0x600a0010,0x644d0b62}},	//   kref, ופעו, ьнем_, clai
  { {0x44320465,0x7ed30015,0x5ed300c3,0x6abd0065}},	//   mny_, لزوا, لتوز, ्बोर
  { {0x44320c09,0xa2a7021e,0x171b004c,0x6aa93d94}},	//   lny_, _चित्, וונע, dref
  { {0x7f860029,0x44321212,0x657c0034,0x61ee0e1e}},	//   _للأن, ony_, icrh, _inbl
  { {0x2cf2005d,0x44323d95,0x2bba0015,0xcb0a03fc}},	//   _अपील_, nny_, ذاعة_, дход_
  { {0x9c37006b,0x2103006f,0x8cd2000b,0x44322daf}},	//   ъпът_, rčiť_, _भैरो, iny_
  { {0xd8f80036,0x2a6a00dc,0xaa87002b,0xda660021}},	//   еної_, öbb_, کنیم_, خابي
  { {0x38c80086,0x47d50015,0x5bc60015,0xd795006b}},	//   رادی_, هيدر, _لقال, линъ
  { {0x27ff0084,0x4432066f,0x69c11862,0x4b26004a}},	//   ðun_, jny_, afle, _имев
  { {0xcc880074,0x96f80063,0x34cb000b,0xc6a7006b}},	//   _آنچه_, веят_, ाब्द, ърни
  { {0xb8823d96,0x08fa0015,0x27ed0030,0x443209fa}},	//   üíst, _يرغب_, űen_, eny_
  { {0xca470086,0x6b840020,0x644d3d97,0x4432002a}},	//   _جلوه_, _õigs, tlai, fny_
  { {0x44323d98,0x74340cab,0x61ee0b14,0x6250008c}},	//   gny_, ансф, _anbl, säol
  { {0xb3550010,0xfe790089,0x360500a2,0x9838000a}},	// [86d0] укаш, _prům_, _موظف, _שטחו_
  { {0x44323d99,0x52140342,0x644d3d9a,0xe1670058}},	//   any_, адут, slai, نداي
  { {0x2608005d,0x5f770029,0x644d0bf5,0x44321212}},	//   _सकती_, ناشر, plai, bny_
  { {0xa2830074,0x4432005c,0xd4910092,0x547a000a}},	//   _نیرو, cny_, ầu_, _רטרו
  { {0xceeb0074,0x44293d9b,0x69c10026,0x4255006e}},	//   بران_, mia_, yfle, _منحر
  { {0x3eaf1a93,0x44293d9c,0x63ab002a,0x6e920015}},	//   rugt_, lia_, łoną, حلوا
  { {0x7c940010,0xc5f4000a,0xfbd10015,0xa2db000b}},	//   арыц, ידס_, متة_, निक्
  { {0x44293d9d,0x249e006f,0x6aa93d9e,0x98580045}},	//   nia_, átmi_, tref, _măă_
  { {0x1b49004a,0x44290d48,0x69c10012,0x4a45011d}},	//   эзии_, iia_, tfle, лнив
  { {0x4432005c,0x44293d9f,0x4ea4006b,0xe8f93da0}},	//   zny_, hia_, _ърса, ело_
  { {0x44320050,0xabb50029,0xaad8000b,0x7c94002b}},	//   yny_, _مماث, _बैठक, _نشنا
  { {0xdb230086,0x44293da1,0x999e0046,0x9816012c}},	//   _پوتی, jia_, botů_, ابدا
  { {0x44320227,0xba770015,0x3912002b,0x69c1164d}},	//   vny_, _شاشت, لویز, pfle
  { {0x44320050,0x06560029,0x98e50029,0x7f5d0077}},	//   wny_, انسح, _مكتو, _úsqu
  { {0xd5b80024,0x44321332,0x03a6135d,0xf9920c44}},	//   ļā_, tny_, ливо, _פרה_
  { {0xd36f0015,0x7c293da2,0x44323da3,0x44293da4}},	//   كهف_, nier, uny_, gia_
  { {0x083b0053,0x2813002b,0x6250008c,0x66e60e7c}},	// [86e0] _רעפל, _دويس, säom, _сопа
  { {0x81a50029,0x36f7000a,0xc693004c,0x44323da5}},	//   لحمل, _עצים_, _האז_, sny_
  { {0xd00a085d,0x7c293da6,0x44293da7,0xd1320015}},	//   неже_, kier, bia_, حمض_
  { {0xc209000a,0x71590dfd,0x44293da8,0xb4c00065}},	//   הה_, трус_, cia_, ंझी_
  { {0x539b0008,0xdfcf0029,0xadf0000b,0xd6d3000a}},	//   _איכו, ثين_, चालन_, ֶׂה_
  { {0x12eb000a,0x63b60034,0x614612a2,0x61ee12a8}},	//   _אַלּ, lgyn, _бега, _unbl
  { {0x7c293da9,0x30d8000f,0x60d8000a,0xec6a07f7}},	//   fier, _בַּע, _בַּג, нрик_
  { {0x7c293daa,0x8f970015,0x63b60034,0xddc1003d}},	//   gier, _منفذ_, ngyn, _vilš
  { {0xaae600e6,0xee3a017c,0xcec30046,0x8c430054}},	//   اسبو, _зна_, ěří_, љење
  { {0xf2d30008,0x7dc50029,0x32bb0053,0x7c2900dd}},	//   צעת_, _نتمك, עזיד, aier
  { {0x7c293dab,0x9c7c002c,0x4c8615e6,0xd7f50892}},	//   bier, _krčm, _слев, азны
  { {0xaae606e4,0xb6060024,0x64c700bc,0x998c0091}},	//   _مستو, _lašā, nčiš, todų_
  { {0x95cb3dac,0xcc57000a,0x6b9d001a,0x3ea00125}},	//   нува_, _עבדי_, ðsge, áith_
  { {0x44293dad,0x998c0007,0xf1c6000b,0x7793002b}},	//   wia_, rodų_, र्मन, جیکا
  { {0xa2a7014e,0xe97b0008,0x44293dae,0x799a0c59}},	//   _चिह्, _אנוש, tia_, matw
  { {0x44290f85,0x8d5b004f,0x24f80138,0x76750766}},	//   uia_, תכלי, ынсы_, _клиф
  { {0xd2bb0015,0x284a004c,0x290d006f,0x38580015}},	// [86f0] عارض_, _שעפּ, čkať_, _حشود_
  { {0x7c293daf,0xcb57000a,0x44293db0,0x171c004c}},	//   zier, רסמה_, sia_, _רוזע
  { {0x60130064,0xcf270086,0xe0870015,0xc5f2000a}},	//   _açma, گراي, اجئي, _ודי_
  { {0x7c2900b8,0xb4fa039e,0x7416002b,0xa9f1000b}},	//   xier, _ספרי, _نوپا, _अच्छ_
  { {0x539a000a,0x6ec40029,0x7c293db1,0x44390079}},	//   _בירו, متوق, vier, _ijs_
  { {0x7c290050,0x867c0135,0xbe640015,0x9f5f0003}},	//   wier, ערוו, مهني, _joué_
  { {0x7c293db2,0x8079000a,0x88c70046,0xdfd50088}},	//   tier, _יְ֭ה, _kněž, _ковы
  { {0xa0c40029,0x7c290077,0x9f5f0003,0x4b86006b}},	//   _ديفو, uier, _loué_, айън_
  { {0x7c293db3,0xab62006b,0x0000006a,0x0000006a}},	//   rier, овъл,   ,
  { {0x7c293db4,0xa3cc000b,0xa969029b,0x2fdf3db5}},	//   sier, _शॉन_, кипа_, _haug_
  { {0xbe640015,0x7c293db6,0x5bb93db7,0xb1e8004f}},	//   _اهلي, pier, _алея_, רֵחַ_
  { {0xfc670063,0xb0b6000a,0x28b6000b,0x9b8b0015}},	//   _съзн, ספרס_, _अमरि, _أخاف_
  { {0xfaa50054,0x3b090054,0xf1c60065,0x6b9b01f9}},	//   _ђако, _јело_, र्डन, maug
  { {0x6b9b3db8,0x9816002b,0xb21b02de,0xda340138}},	//   laug, ابگا, _stæn, _лечы
  { {0xe9460086,0xf5030142,0xc396023e,0x9f5f0003}},	//   _پروی, озро, ијањ, _doué_
  { {0xf8140074,0x3ea00263,0xf7720015,0xb4250021}},	//   _دستگ, šiti_, _باث_, معقو
  { {0xf3f70023,0x27e000e8,0xb606003d,0xd46708b0}},	// [8700] ợng_, _iain_, _pašā, рите_
  { {0x63b60026,0x27e00e18,0x569b000a,0x2606016e}},	//   sgyn, _hain_, _שייצ, _vôos_
  { {0x6b9b166f,0x3c3a003d,0xdcf8003d,0x27e006a2}},	//   kaug, hīva_, ravī, _kain_
  { {0xe3b20074,0xc0590010,0x888c0053,0x4375022a}},	//   _برد_, гіі_, גראַ, _гурт
  { {0x2fdf00df,0x27e021e0,0x6b9b3db9,0xa3bb000b}},	//   _daug_, _main_, daug, _घात_
  { {0x7ae4002f,0xeca60001,0x3942005c,0x27e00375}},	//   _áiti, ајин, ększ_, _lain_
  { {0xadf70029,0x4c940080,0xf1c6000b,0x6250008c}},	//   شروط_, щийс, र्णन, jäoi
  { {0xa3c9014e,0xeca7005d,0xd0120086,0xef19005c}},	//   ल्प_, _गिरफ, _بلر_, _leży_
  { {0xf1c6005d,0xbc670067,0xb881016e,0x799a0034}},	//   र्थन, جمين_, üíne, tatw
  { {0xdb090064,0xdebb000a,0xc171000a,0x6b9b003d}},	//   zgeç, _בממל, ּ֗י_, aaug
  { {0xa3e60372,0x27e0002f,0xdd7b000a,0x99340015}},	//   पया_, _bain_, _סטאל, صفحت
  { {0xf1c6005d,0x98730010,0xa2a7000b,0x99850046}},	//   र्तन, ўляц, _चिल्, bilů_
  { {0x799a003f,0x8c1b000a,0xeafa002b,0x2c0b002b}},	//   patw, _בואי, _جرات_, _جعلی_
  { {0x59af000b,0x99840021,0x88c70046,0xb9940015}},	//   _फ़ायर, _الغو, _sněž, _الثب
  { {0xf5e40036,0x34270010,0x26c200f2,0xda5b000a}},	//   ціям, афав, atko_, _שכול
  { {0x200404ed,0xd3750001,0x2d9c07cc,0x27e002ff}},	//   _nomi_, слаћ, have_, _gain_
  { {0x91870015,0x8bd7000a,0x883c000a,0x2d9c07c4}},	// [8710] لجام, סומו_, _שתחו, kave_
  { {0x98da005d,0xf8da005d,0x41b50029,0x75d50029}},	//   _बनाए, _बनाय, إمار, _ايدا
  { {0xe4e4005e,0xa63c004f,0xf1c60065,0x68fc02dc}},	//   _діян, _בגזר, र्धन, ärdh
  { {0x0ee2000b,0xa25b0003,0x2d9c3dba,0x2ef51111}},	//   पिंड, _apôt, eave_, йзер
  { {0xa858000a,0x217b0015,0xa267006b,0xdfd8006b}},	//   ביאה_, _لحزب_, _въвл, ръх_
  { {0x9c7c016f,0x4d880015,0x2d9c179f,0x6b82016e}},	//   _grčk, لَهُ_, gave_, _afog
  { {0x4c920001,0x6b9b2061,0x20d40058,0x0000006a}},	//   пијс, taug, _وتفج,
  { {0x2d820014,0xf5380447,0x3c3a0024,0xe538000a}},	//   _őket_, ינוי_, tīva_, יטוט_
  { {0xa3c9014e,0xbda70015,0x27e03dbb,0x3f150256}},	//   ल्य_, _نحاو, _rain_, _удас
  { {0x6b9b3dbc,0x7528005c,0x27e03dbd,0x6b820030}},	//   saug, ździ, _sain_, _efog
  { {0x27e02d6c,0xf769000a,0x29111fa5,0xd945125c}},	//   _pain_, _נק_, áza_, сени
  { {0x7d560008,0xa3c9005d,0xa3e6005d,0x96ba0175}},	//   _היעד_, ल्म_, _यों_, лугу_
  { {0x27e0022d,0xdce301e2,0x103a0053,0x3954002c}},	//   _vain_, manı, רגרע, _časť_
  { {0xdce301e2,0xef120053,0xd615005e,0xe5e20033}},	//   lanı, פּר_, офсь, чымi_
  { {0x26c2005c,0x291e005c,0x5e56004c,0x9479163d}},	//   stko_, czta_, מישע_, исту_
  { {0x2d9c018c,0xdce30064,0x0555005e,0xccf2000a}},	//   zave_, nanı, ітря, הכל_
  { {0x38a301e2,0x26de0024,0xda7a004c,0xc356006b}},	// [8720] lır_, ātos_, ָנער, съвъ
  { {0x9c82018c,0x21760036,0xd24f0015,0xc693000a}},	//   ščin, суар, ّنك_, _צאת_
  { {0x999a00b2,0x38a301e2,0xdce30064,0x386000d9}},	//   רבעט, nır_, kanı, _khir_
  { {0xdfcf002b,0x68fc0123,0x40ab002b,0x212a002b}},	//   فيم_, ärdi, اخلی_, پيچی_
  { {0x9f490084,0xf67a0053,0x7e2a0484,0x6d5a0fce}},	//   ðað_, נאַמ, ліка_, _szta
  { {0x6b8204ed,0x9757000a,0xe3b2002b,0x38a30061}},	//   _sfog, זינו_, _برگ_, kır_
  { {0x557700b2,0xdce30064,0x6ce60033,0xc19b000a}},	//   זעצן_, fanı, сіле, _תשלי
  { {0x5b14005f,0x38a301e2,0x6d5a0089,0x2d9c00bd}},	//   жмит, dır_, _vzta, save_
  { {0xda7a008f,0x0aea0015,0xa3bb000b,0xea1801e9}},	//   ыяй_, اربي_, _घास_, ижиш_
  { {0xff170008,0x38a30064,0x38600144,0x290c0a02}},	//   _הקמת_, fır_, _ahir_, tyda_
  { {0x2bca0191,0x66050005,0xf8140023,0xa3c9005d}},	//   _було_, _rohk, ược_, ल्ड_
  { {0x3c770008,0xa1570008,0x3157000f,0x7ae40091}},	//   _התאם_, מביה_, מיין_, _šitu
  { {0x291e12e0,0xf1d8000b,0x0000006a,0x0000006a}},	//   szta_, ड़ान,   ,
  { {0xbb3b0053,0xe84c0089,0x7f2b0008,0x09e3004a}},	//   _געדי, ětší, אֵלֶ, _ночн
  { {0xe6540191,0xa99b000a,0xba3d0046,0x38600125}},	//   ївсь, _גבור, trův, _fhir_
  { {0x5455005e,0x2937000a,0x8937000a,0x3eaf001a}},	//   іват, _לאון_, _לרוע_, yrgt_
  { {0x24580080,0x27f4006f,0x69c80079,0xe2f800ce}},	// [8730] сать_, šaní_, ofde, беті_
  { {0xdce30064,0xdb1f0003,0x80cd0065,0xf1ab0058}},	//   zanı, évér, _सहदे, طائه_
  { {0xc0d50086,0xa25b002c,0xdce30064,0x4a5b000a}},	//   تياب, _spôs, yanı, נדבו
  { {0x58bb004c,0x9c7c00bc,0x9f551673,0x0000006a}},	//   רמאצ, _grči, овеч,
  { {0x38a30064,0x9f340036,0xdce30061,0x41e701c6}},	//   zır_, пеці, vanı, _ліва
  { {0x38a30064,0xee380036,0x26140020,0x1d09006b}},	//   yır_, бні_, _näol_, иели_
  { {0xdce30064,0xa3c9000b,0x1089000a,0xeb910015}},	//   tanı, ल्थ_, _כָּֽ, وظة_
  { {0xe0d200b2,0x6c350015,0x38a30061,0x6ca40015}},	//   _קײן_, تفعا, vır_, أصول
  { {0xdce301e2,0x539c000a,0xce94006b,0xf1c6000b}},	//   ranı, איחו, _натъ, र्वन
  { {0x38a301e2,0xdce30064,0x88c905c4,0x1a68002b}},	//   tır_, sanı, алов_, مینی_
  { {0xf1b20008,0x999e0089,0x5e440015,0xdce30061}},	//   וסי_, nitř_, _عَمْ, panı
  { {0x7e7b0005,0xb901005d,0x38a30064,0x4c570031}},	//   _kuup, _नई_, rır_, _اضطر
  { {0x38a30064,0xf7720087,0xf7190033,0x0000006a}},	//   sır_, باد_, біры_,
  { {0x644f3dbe,0x78c40030,0x7ae90123,0x442b3dbf}},	//   _akci, étvá, mvet, _amc_
  { {0xd4f5004a,0x7ae93dc0,0x38600034,0xd46a0058}},	//   пяты, lvet, _thir_, لحرم_
  { {0x69c5005d,0x7bc90012,0x69de3dc1,0x442b0a22}},	//   ़्री, nfeu, _óper, _cmc_
  { {0xfbd20008,0x7ae900f2,0xa20609ac,0x8723006b}},	// [8740] ותן_, nvet, опад, _омъж
  { {0xe2460029,0x915f0092,0xe1f7381e,0x4256008b}},	//   آخري, _sắp_, огу_, ітат
  { {0x60260484,0x30a5005e,0xe0da32b0,0x7c2b2494}},	//   оджа, зрів, рве_, _omgr
  { {0x9c7c0156,0xa3c9000b,0x2d853dc2,0x2eed3dc3}},	//   _urči, ल्द_, _afle_, _bref_
  { {0xaad8005d,0x64410003,0xb355002b,0x69c80034}},	//   _बैंक, élie, _فیفا_, yfde
  { {0x6ce5014e,0xf1c6005d,0x11d60029,0xb4fe005d}},	//   किंग_, र्शन, _بتحد, _उपाय_
  { {0x6fb60015,0x6c830015,0xb7bb016e,0xf3f2000a}},	//   _ومسا, ولوم, lhãe, ֵף֙_
  { {0x984d002a,0x8aa601e3,0xbc670040,0xddc80091}},	//   _iść_, ород, يمون_, _didš
  { {0x7ae900dc,0x79c80015,0xada60004,0x2eed0034}},	//   gvet, موظف_, _маал, _gref_
  { {0x82f7013a,0x91ba000a,0xdb090046,0xdd8f0058}},	//   קציב_, ׁמִי, énác, _لوك_
  { {0xb17b00b2,0xb21b002e,0x717b00a3,0x91bb000a}},	//   יטיר, _stæk, יניס, סמטי
  { {0xe7eb0065,0x0000006a,0x0000006a,0x0000006a}},	//   _जोशा_,   ,   ,
  { {0xeb910008,0x6250007c,0x76b80342,0x7ae907c4}},	//   _נָא_, näos, оляр_, cvet
  { {0xceb301ac,0xdcfa003d,0x60c53dc4,0x2f5b004f}},	//   ויש_, _netī, ythm, ידכנ
  { {0x80c9005d,0x4dfb0053,0x7afd060a,0x442b236f}},	//   _रहें, ספלא, ästv, _pmc_
  { {0xdc8b000a,0x9d1b000a,0xb867012c,0xe3b300c3}},	//   יְמָ, בולט, _باتو, برس_
  { {0xd7630086,0xe18b002b,0x95cb0249,0xd5b10058}},	// [8750] _تنظی, لئان_, _куна_, _كفة_
  { {0xd25100e5,0x20d6000b,0xc6920643,0x51f800e2}},	//   رنا_, ठबंध, _ראי_, оную_
  { {0x212700a7,0x7ae91754,0x71550015,0x7e7b0072}},	//   ành_, zvet, أناض, _suup
  { {0x69ca005d,0x60c50335,0xe4d4002b,0x3abb004c}},	//   त्ती, rthm, _کتیب, היפּע
  { {0xfd4c0092,0x23fa000a,0xa858000a,0x21b70015}},	//   _triề, _הפרמ, קידה_, _وإسح
  { {0xc27a0008,0x7ae90064,0xf2d2015b,0xfce50165}},	//   _לרשי, vvet, _רעם_, зоко
  { {0xba3d0046,0xdd8e0015,0x2fd70058,0x0000006a}},	//   zrůs, دوى_, _وترح,
  { {0x2eed3dc5,0x653c000a,0x69bd000b,0x853c000a}},	//   _tref_, יעוד, _शाही, יגוי
  { {0xeab10029,0x443b0003,0x93fc000a,0x8ca7000b}},	//   رعة_, inq_, שלחי, _घटको
  { {0x7ae933fc,0xba220342,0xa9253dc6,0xc27c000a}},	//   rvet, едьк, здол, ברזי
  { {0xf1b20053,0xbb7500d0,0x9a240015,0x7ae93dc7}},	//   עסט_, _егеј, بعين, svet
  { {0x7ae900dc,0xe8f600ce,0x7c2b02ad,0x0000006a}},	//   pvet, їля_, _umgr,
  { {0xf7720029,0x4b7a0008,0xa3e6005d,0xaa890015}},	//   عاج_, _האנו, _योग_, _انتم_
  { {0xa3c9005d,0x38ca002b,0x59c2000b,0x7afd3dc8}},	//   ल्स_, جایی_, _शायर, ästu
  { {0x38ca0074,0x18280074,0x3c89000a,0x7ae40125}},	//   _هايی_, _وقتی_, מָּ֑, _áitr
  { {0x7c3b3dc9,0xba3d005a,0x0000006a,0x0000006a}},	//   nnur, průs,   ,
  { {0x3cdd005d,0xc8650029,0x67bb000a,0x645600da}},	// [8760] _कैसे_, _تطوي, _המפק, rlyi
  { {0x7c3b00d5,0x614607f9,0xd2a70138,0x0000006a}},	//   hnur, пеза, якуе_,
  { {0xc5eb0008,0xc3290008,0x3d15005d,0x6456003e}},	//   _הַכֹ, נו_, तनों_, plyi
  { {0x1eaa00a2,0xd3da00c3,0xe716000a,0xb4fb000a}},	//   ماتي_, _ابدا_, ּחַר_, _הפטי
  { {0x0377000a,0xb77b000a,0x7053012c,0x0000006a}},	//   _מתכת_, צָאת, رنها,
  { {0xd2520029,0xf53601d8,0x7c3b0776,0x60e1008c}},	//   _أنس_, ּנֵי_, enur, äymä
  { {0x39a6002d,0x721b000a,0x621b000a,0x4420007c}},	//   hísí_, _פולח, _פולק, ohi_
  { {0x44200035,0x6bd60029,0xa08b000f,0xcd330015}},	//   nhi_, ستعر, _לְמִ, عروب
  { {0xade7005d,0xa06700e2,0x764e3dca,0xef1a226f}},	//   _टोकन_, _хата_, koby, _ума_
  { {0x39140124,0x2bac0016,0x7de50015,0x44203dcb}},	//   дмор, ớc_, _يسلم, hhi_
  { {0x764e0448,0x69bd000b,0x3ea6003d,0x2bf60033}},	//   doby, _शारी, lsot_, _нядр
  { {0xe7590036,0x0137000a,0x31370447,0x9a860054}},	//   жимі_, לרית_, לנים_, _еукл
  { {0x4420000c,0xe6670063,0x3885003d,0x3f86016e}},	//   dhi_, зтво, _pērc_, icou_
  { {0x68fc0123,0xaadb000a,0x7ae23dcc,0xa8a61411}},	//   ärds, _לחדר, _isot, _ерик
  { {0x644d3dcd,0x69da31d8,0x4a5b004f,0x2d9e3dce}},	//   toai, mete, _הדגו, _mete_
  { {0x9d1b00b4,0x39570008,0x2d9e3dcf,0x44203dd0}},	//   זולט, _משום_, _lete_, ghi_
  { {0x877c0053,0x69da1e30,0xc7fa000a,0x5c37000a}},	// [8770] _פאזי, oete, _וִיר, פרמן_
  { {0x644d001c,0xe1d90010,0x69da3dd1,0x59cf000b}},	//   soai, юдзі_, nete, त्पर
  { {0x320a0107,0xf485002b,0x69da0cbe,0xe588004f}},	//   _doby_, _تاخی, iete, _מָרָ
  { {0x98c50085,0x8f350033,0x69da3dd2,0x44203dd3}},	//   žući_, меец, hete, chi_
  { {0xa2a7005d,0xcee80015,0x69bd000b,0x3885003d}},	//   _चिट्, كرون_, _शाली, _mēra_
  { {0x41e40010,0xee380036,0x02fa000a,0x12fa000a}},	//   _піса, пні_, _ולשמ, _והשב
  { {0xd0d4010f,0x1d060063,0x3cdd005d,0x69da3dd4}},	//   _поръ, дещи_, _कैशे_, dete
  { {0x61e700dc,0x2b15005e,0x69da1de9,0xea891d8a}},	//   _hajl, дьор, eete, обил_
  { {0x3ea60030,0x2d9e387d,0x69da3dd5,0x7c3b3dd6}},	//   csot_, _fete_, fete, rnur
  { {0xb33b01e2,0xf8a9006d,0x02fc000a,0x5ee8000a}},	//   _geçe, овок_, מלחמ, _מַעְ
  { {0x186a0b1a,0x61e700d9,0x8d740015,0x7ae23dd7}},	//   жани_, _majl, _كاما, _esot
  { {0xf09200b2,0x7ad8000b,0x5b150054,0x5c040033}},	//   כנט_, _बैकअ, _омет, _пяча
  { {0x69da156e,0xddc110f4,0xf772006e,0x28a90065}},	//   bete, _milž, ضاح_, _किकि
  { {0x61e73dd8,0x8a7a000a,0xca7a000a,0x78ba2035}},	//   _najl, _ואסת, _ונסט, butv
  { {0xd4d50033,0xa3ea0151,0x44203dd9,0x764e1c65}},	//   нітэ, одва_, thi_, roby
  { {0xc9520008,0xe29a000d,0xb89a000a,0x889a000a}},	//   _שמה_, жаа_, _ובקש, _ובקי
  { {0x21a617b6,0x48e50065,0x44203dda,0x0000006a}},	// [8780] дизм, टिको_, rhi_,
  { {0x44200f4d,0xc1d8000b,0xf11a002b,0x41aa00ce}},	//   shi_, ड़ेग, يغات_, івен_
  { {0x2d9e02d7,0x25e7005d,0xd5fb000a,0x442020e3}},	//   _rete_, _छोटी_, _ופיר, phi_
  { {0xb33b01e2,0x69da3ddb,0x2d9e3ddc,0xdefa0033}},	//   _seçe, zete, _sete_, жык_
  { {0x63b9005c,0x61e7016f,0x3f86001c,0x63a43ddd}},	//   ówne, _fajl, rcou_, main
  { {0xdce8002c,0xdc8a0080,0x3f9f0077,0x7bc227f4}},	//   _vedľ, осил_, _eeuu_, _scou
  { {0xdb19005c,0xa1160015,0x69da3dde,0x50d20065}},	//   _obwó, _غورت, vete, _सहिष
  { {0xe10b0008,0x44c80012,0xab5d002a,0x61e70030}},	//   _וּמָ, iß_, leży, _zajl
  { {0xe4570008,0x5a460033,0xee3a27e3,0x69da0ebd}},	//   ויקט_, дэна, _дна_, tete
  { {0x63a43ddf,0x6ffe0011,0x7ae200bd,0x3cfa0015}},	//   hain, _făcâ, _vsot, _وعاد_
  { {0x29183007,0x28f803e7,0x2602000b,0x63a43de0}},	//   ára_, чень_, शानी_, kain
  { {0x63a43de1,0xc173000a,0x1c690015,0x78ba0795}},	//   jain, כחת_, _فإني_, rutv
  { {0x44c800b8,0xa3bf000b,0xcf93000a,0x78ba3de2}},	//   eß_, ूऍस_, כטר_, sutv
  { {0x7bc00134,0xaa570029,0xa7c9002b,0x7afd2215}},	//   lgmu, _قلنا_, _کژدم_, åste
  { {0x18970029,0x63a40026,0x49bb000a,0x8cc1000b}},	//   _قضية_, fain, _ומוס, रूपो
  { {0x69ca005d,0xc4540029,0x3ea902c6,0xe3b300c3}},	//   त्री, نَّب, šati_, ضرر_
  { {0x44c800b8,0x479c000a,0xf2070033,0x979c000a}},	// [8790] aß_, _ויחס, мяжо, _ושחק
  { {0xdb00038d,0xc2c4003b,0xd25b0010,0xdcea0061}},	//   ramè, ئيلي, іца_, hafı
  { {0xd131003b,0x31c40063,0xe7c6005d,0x63a43de3}},	//   دما_, ъств, _वामप, bain
  { {0xa295008f,0x95160008,0x27e90020,0x63a40493}},	//   _памі, _נקרא_, _jaan_, cain
  { {0x27e93de4,0x0f35002b,0x22840061,0x9ea9005e}},	//   _maan_, رکرد, _gök_, ївка_
  { {0x8e08005e,0x7bc00030,0xa2d8000b,0x212a002b}},	//   мнів_, egmu, _नैट्, _کيفی_
  { {0xddc10091,0x64480003,0xf41f0123,0x25a10012}},	//   _tilž, édig, _klä_, _mehl_
  { {0x5ba90001,0x3eb20007,0x3ff9004c,0xd4910016}},	//   чким_, šyta_, _צפּע, ầy_
  { {0xef540063,0x7bdb0353,0x3da73de5,0xfbd1009a}},	//   _акть, reuu, _жреб, نتک_
  { {0xbef80029,0xf41f00f2,0x7bdb007c,0xf9910015}},	//   _ترفض_, _llä_, seuu, دبة_
  { {0xf65f0134,0xe9a6002b,0xd7ea0004,0x27e908cf}},	//   rtæl_, رگون_, пмне_, _baan_
  { {0xab5d005c,0xc172000a,0x628f01c9,0x9f44013f}},	//   zeży, טחי_, _otco, _samé_
  { {0xcc3a00b2,0x27e90035,0x68360024,0x7d18002c}},	//   _צענט, _daan_, gšda, časť
  { {0xd945312e,0x63a43de6,0x64410fab,0xa50a0033}},	//   _пели, wain, élin, пега_
  { {0x228401d1,0xd46a0001,0x63a40472,0x44c80012}},	//   _sök_, зиве_, tain, uß_
  { {0x27e9049c,0x7dd30064,0x3c3a0024,0x6b893de7}},	//   _gaan_, lısı, tīvi_, nceg
  { {0x883b000a,0x24530015,0x083b004c,0x62660004}},	// [87a0] _מתקו, انقس, _מעקל, еваа
  { {0x7dd30064,0xa494002b,0x7a7a004c,0x6aa90990}},	//   nısı, _لیست, פרעס, isef
  { {0xf1c6005d,0xdb0001c4,0x659b00f3,0x69c116a6}},	//   र्गन, ramé, _מייק, igle
  { {0x40560029,0xa2b2005d,0x61430010,0x59cf005d}},	//   رئاس, ेंद्, ыеха, त्तर
  { {0xddc30030,0x201f0045,0x7dd3007f,0x5f9300af}},	//   elnő, _dlui_, kısı, ћишт
  { {0x6aa93d06,0xc73b000a,0x41c7000b,0x2d58004a}},	//   dsef, התנת, _लायस, миль_
  { {0x69c10085,0xace70004,0xf41f008c,0x3253004a}},	//   dgle, емја_, _ylä_, _свёр
  { {0x59c2005d,0x2c61002c,0x73fa000a,0xdee609da}},	//   _शाहर, tóda_, לּ֥ו, _поби
  { {0xdcea01e2,0x8bd30010,0x99a40046,0x6aa9001a}},	//   rafı, ужыц, átům_, gsef
  { {0x27e91b4a,0xf3ff0092,0xcf250015,0x1d950033}},	//   _saan_, _nhãn_, _شرقي, _арцё
  { {0x0dc90029,0x39580134,0x48a700ce,0x0000006a}},	//   _تبقى_, ærs_, нтям_,
  { {0xb8d8005d,0x69c13993,0x9d1b000a,0x38c7002b}},	//   _चि_, agle, _מובט, راپی_
  { {0x27e900f2,0x6a66001a,0x69c10012,0x68e10546}},	//   _vaan_, eðfe, bgle, awld
  { {0x7dd30064,0xba18002b,0x4992002b,0xdb02016e}},	//   cısı, _زيبا_, _حیدر, _adoç
  { {0x6441038d,0xf65f002e,0x69b9000b,0xa4d4005e}},	//   élio, ltæk_, _एफ़टी, лорі
  { {0xb6f5009c,0xb4e1000b,0x3c3a003d,0x55580033}},	//   _азиј, _धनी_, būve_, хася_
  { {0x6a66001a,0x57b4004a,0x200d042f,0xf6d4002b}},	// [87b0] aðfe, _сбыт, _roei_, _یزید
  { {0xa5070010,0x28c4000b,0xc73c000a,0xc3540054}},	//   _зямл, लंपि, _מתחת, укуј
  { {0x399b000a,0x999e0030,0xc05b00ce,0x6aa901d3}},	//   פיאד, nitő_, під_, zsef
  { {0x7dd30064,0xa3bb000b,0x80d2000b,0x6e9508b0}},	//   zısı, _घाट_, _ठहरे, виду
  { {0x7dd301e2,0xb364006b,0x64480003,0x30780015}},	//   yısı, _бърк, édie, رحمة_
  { {0xde940015,0xfe57002b,0x6d5a0123,0x7e7a01ec}},	//   اجنب, ریاب_, _byta, _citp
  { {0x6d5a002a,0xdb090012,0x3c3a003d,0x142b000a}},	//   _cyta, sgeü, hīvu_, ּוִ֑
  { {0x201f04f9,0xcec1005c,0x747c000a,0x2ef50cab}},	//   _ului_, _pięć_, הנהג, _избр
  { {0x69c10012,0x7dd30061,0x6b893de8,0x0000006a}},	//   tgle, tısı, rceg,
  { {0x5f440015,0xf2d2000a,0x6aa93de9,0x69c13dea}},	//   _إنكل, סעי_, rsef, ugle
  { {0x69c1018b,0x7dd30064,0x69a2005d,0x6e2100c0}},	//   rgle, rısı, _ग़री, _illb
  { {0x69c126af,0xf649000a,0xe73a08d7,0x68fc0123}},	//   sgle, _וצ_, дем_, årda
  { {0x96f90010,0x7dd30064,0xd3e10033,0xdb07008c}},	//   нэру_, pısı, зiўс, äläl
  { {0xf205000b,0x69c60030,0xa2b2000b,0xdb1b2ec8}},	//   राफ़_, őker, ेंस्, nguí
  { {0xf3ff001c,0x5dc8000a,0xba080015,0xe5a307f7}},	//   _chão_, עֶשְ, _ستوك_, риси
  { {0xe8d60008,0x88ba000a,0x38690125,0xd4670054}},	//   _יוצר_, _חזקי, _ghar_, висе_
  { {0x77990008,0xb33b001c,0x63b9002a,0xa3f50033}},	// [87c0] _אֹתו, _peça, ówna, ыярш
  { {0xb21b2144,0x42230561,0x813a002b,0x31160004}},	//   _stær, адув, وساز_, кфес
  { {0x21761055,0x3ead3deb,0x0000006a,0x0000006a}},	//   туар, _avet_,   ,
  { {0xdfd00086,0xdfcf00e6,0x6fb30015,0x6d5a0091}},	//   صيت_, قيم_, لمما, _ryta
  { {0x442201e2,0x3ed40029,0x8fc50086,0xdfcf0070}},	//   _ilk_, اقتر, ازمن, تين_
  { {0x6d5a0050,0xc693000a,0x01da0015,0xfe6f0015}},	//   _pyta, סאו_, _توسع_, يدو_
  { {0xa3c9014e,0x10a30036,0x3ead0064,0x71d7004c}},	//   ल्क_, _висн, _evet_, _שולד_
  { {0xdc2a0086,0x2167005e,0x6d5a3dec,0xcfaa002b}},	//   بسته_, _риси_, _vyta, _زارم_
  { {0x6ac30015,0x68260030,0x8c430054,0xfc2f002b}},	//   لقيم, _módd, јење, تحو_
  { {0x6cd60015,0xf65f001a,0x6d5a3ded,0x7e7a08cf}},	//   _لقطا, rtæk_, _tyta, _uitp
  { {0x91bb0008,0x23e2005d,0x21bb0008,0x2cb800dc}},	//   ומיי, _पसंद, וזיא, _írd_
  { {0x92a9005c,0x28c4005d,0x3c3a0024,0xc7f8005e}},	//   nałó, लंबि, tīvu_, внює_
  { {0xf8480010,0x8c1b000a,0x8f9b000a,0x64410003}},	//   тчэй_, _קודי, ויכי, élim
  { {0xb8f40029,0x7793002b,0x7c223dee,0xa9260058}},	//   _مكتب, دیکا, _hlor, _لعبه
  { {0x03c7008f,0x3869002d,0x4a7b000f,0x555809ef}},	//   ксам, _thar_, _קרוב, варя_
  { {0x99650036,0x9cd7000a,0x3424005e,0x972500c3}},	//   _стіл, כולה_, афув, _مفعو
  { {0x2458005f,0x62d90033,0xf1c70065,0xf1a70974}},	// [87d0] тать_, эмаў_, _लादन, врен
  { {0x44220991,0x9f440251,0xd5350029,0xe2c80067}},	//   _elk_, _camí_, _مفخخ, ئولو_
  { {0xe01e000b,0x3ead05e3,0xa848002b,0x2419055f}},	//   पसंद_, _svet_, _سلیم_, _зоны_
  { {0x251a05bd,0x50641bdf,0xa2c30065,0x0000006a}},	//   _נורא, атча, िंद्,
  { {0x539a0008,0x03d600f3,0xa3cc000b,0x3c3a003d}},	//   _רישו, _גורם_, _शॉट_, hīvs_
  { {0x7c22038d,0x51870684,0x0dc80054,0xc332004f}},	//   _alor, _шума, вући_, _פום_
  { {0x4e180086,0x6da203a9,0xb4b1000b,0xed5607f7}},	//   ختند_, щища, _ऑटो_, лош_
  { {0xc57c000a,0x30da004c,0x20f30085,0x68260247}},	//   ורות, _אַמע, _ići_, _kóde
  { {0xdd950033,0x0a3901b0,0x78ba3def,0x1a68009a}},	//   _базы, ечны_, ertv, چینی_
  { {0xf9d40036,0xb33b0003,0x20f30085,0xab760015}},	//   ацюю, _leço, _kći_, دمًا_
  { {0x07a60f22,0x8cc40015,0x7c2206d7,0xc7a607d1}},	//   ланн, _نقله, _flor, линк
  { {0x30da0053,0xc5e90008,0x7c2205fe,0xcaf50040}},	//   ײַטע, _מד_, _glor, _مستب
  { {0x9f8a0020,0x38b9002e,0xe71a0115,0x501a000a}},	//   _tööd_, _býrð_, ريست_, גורו
  { {0x2aba013a,0x7c2200bd,0x59a7000b,0x9f630033}},	//   _נמצא, _zlor, _ग़िर, ыфiк
  { {0x33d600fd,0x38b9001a,0xe5150033,0x70d20065}},	//   ліат, _dýrð_, афтэ, _सहेल
  { {0x80cd000b,0xf814002b,0xba3d0046,0x2602000b}},	//   _सहजे, _خستگ, jrůz, शाही_
  { {0x04570015,0x23270432,0xe1fa21a4,0x7c3e0003}},	// [87e0] القة_, готи_, нга_, épri
  { {0x55e62073,0x869b015b,0x44222f9e,0x23090058}},	//   _сооб, _רייז, _wlk_, ختفي_
  { {0xa988000a,0xe0850058,0x0000006a,0x0000006a}},	//   דָנִ, لجني,   ,
  { {0xe29a0191,0x6fb6002b,0x4f2600af,0x0000006a}},	//   _пам_, امشا, лдеб,
  { {0x66ad0008,0xdd920086,0x68260030,0x92a9002a}},	//   ֵיהֶ, موش_, _kódb, rałó
  { {0x69d3005d,0x90a60002,0xdfd2002b,0xc1e7002b}},	//   _बॉली, _محرم, _گير_, _مکمل_
  { {0x6e3801a7,0xb2230001,0xbca400e6,0x62860f47}},	//   rivb, _умрл, جمعي, _huko
  { {0xe4f7014e,0x61ee02c1,0x6abb26af,0x645606e8}},	//   ुमति_, _habl, fruf, noyi
  { {0xbc6706e4,0xa3c9005d,0x61ee3df0,0x6ec50015}},	//   دمين_, ल्ट_, _kabl, _نتلق
  { {0xd8f80191,0x3c3a0024,0x628616d3,0x05670046}},	//   вної_, tīvs_, _muko, _římě_
  { {0xeaaf0086,0x5bc60806,0x644400f2,0x61ee003f}},	//   يعی_, _مقال, knii, _mabl
  { {0x645600da,0xf8070033,0xdb000034,0xe852002b}},	//   joyi, учон, ramâ, يچيد
  { {0x62860007,0xb33b0152,0xcc570643,0x383401f3}},	//   _nuko, _reço, _גבאי_, сняр
  { {0x6ecc000b,0xa2c3000b,0x3495004a,0x27ed3bd5}},	//   _समनु, िंस्, иагр, žen_
  { {0xf993013a,0x55590063,0x63a60079,0x63b9002a}},	//   _פרק_, тавя_, _bekn, ówno
  { {0xf8b3000a,0x62863df1,0x43950033,0x3ea0013f}},	//   _השק_, _buko, раас, šity_
  { {0x92590083,0x3ce4005d,0x64480152,0x7655005c}},	// [87f0] ваат_, झौते_, édia, pozy
  { {0xbb3b0053,0xa535005e,0xbc840016,0xe1670015}},	//   געמי, _вноч, _ướn, هداي
  { {0xc5f80024,0x5f950015,0x21670033,0xd262003d}},	//   ķēt_, للائ, утаг, diņā_
  { {0x6b820026,0x3211002a,0xa283002b,0x7feb0015}},	//   _ngog, _wozy_, _هیرو, عراف_
  { {0xddc800df,0x69d8116e,0x4429002d,0x201d002a}},	//   _didž, _obve, mha_, rkwi_
  { {0x442903af,0xef18008f,0xb2ba0008,0xa2ba000a}},	//   lha_, ымі_, _במשר, _במשט
  { {0x999e0089,0x20f30085,0x7c940033,0x7c840054}},	//   entů_, _ući_, брыц, буње
  { {0x442911e0,0xbae50015,0x6ca40067,0xdb510015}},	//   nha_, لكبي, حصول, يَغ_
  { {0xcda9003b,0x1c420010,0x62800152,0x2616000b}},	//   _لهذه_, ўным, _émot, _नकली_
  { {0xd2620024,0xe8f90036,0x6444003d,0x999e0091}},	//   ciņā_, вло_, znii, dotų_
  { {0x5d840806,0x44293df2,0xc236000a,0xe108000a}},	//   _المل, kha_, שרתו_, ָּתָ
  { {0x67fb00f2,0xc156000a,0x3156000a,0xbc36008c}},	//   _räjä, ישתו_, ייתן_, äätö
  { {0x4429000c,0x8c1a013a,0x46e70191,0x2602005d}},	//   dha_, _שוני, адян_, शाली_
  { {0x7c293df3,0x4429183c,0xc987381e,0xaf76004c}},	//   lher, eha_, _суди, יערס_
  { {0x845a0877,0x62863df4,0x9f440077,0x63a6006f}},	//   врат_, _suko, _mamá_, _pekn
  { {0x44293df5,0xb8db005d,0x9346000d,0x6286016f}},	//   gha_, ें_, анбе, _puko

  { {0x935a0001,0x6456003e,0x61ee3df6,0x0877004c}},	// [8800] трву_, royi, _pabl, _דעקט_
  { {0xb33b01e2,0xc6930008,0x442922d2,0xc5f8003d}},	//   _geçm, _ואז_, aha_, ķēs_
  { {0x55bb0008,0xd5bb000a,0x61ee00bc,0x00e60c71}},	//   _במיו, _בזיל, _vabl, ржен
  { {0x1eaa0029,0xfa880092,0x44293df7,0xe424002b}},	//   ناتي_, _lừa_, cha_, _اکسي
  { {0xd9e5005d,0xd2620024,0xc7d70008,0x539b000f}},	//   क़ात_, tiņā_, שוני_, _ביכו
  { {0x471b0053,0xdb00001a,0x40960289,0x7c293df8}},	//   כונג, jamá, _врат, eher
  { {0xce190033,0xdb00001a,0xc536000a,0xcd060004}},	//   ыцці_, damá, יָ֤ה_, рчли
  { {0x01630036,0x1d070001,0x20e81d56,0xa3e6000b}},	//   _єкто, рећи_, _işi_, फ़ि_
  { {0x5a340063,0x8ff90015,0x787f003d,0xfa880016}},	//   йнит, _حرّر_, _būvn, _bừa_
  { {0x5cd60036,0xc211000a,0xf2d3000a,0xcb67009c}},	//   _відх, ִ֔י_, קעת_, шање_
  { {0xa3e6005d,0xa9540010,0x44203df9,0x621b000a}},	//   फ़ा_, скні, kki_, דויק
  { {0xb33b01e2,0x6d3b0008,0x442012df,0x7c29010c}},	//   _seçm, _בתבנ, jki_, cher
  { {0xaa940029,0x44203dfa,0xdce101ec,0x0000006a}},	//   _التث, dki_, _izlā,
  { {0x8afb0008,0xaadb0135,0xbafb000a,0xe937002b}},	//   _שהגי, _סחור, _שהגש, اسیت_
  { {0x44293dfb,0x2918007c,0x947700c3,0xa5f80054}},	//   tha_, ärad_, لدرا, јесу_
  { {0xe97b013a,0xb97b000a,0xa97b000a,0x69c83dfc}},	//   _בנוש, _בנוי, _באוכ, lgde
  { {0xf7730086,0x44293dfd,0x443b3dfe,0x0000006a}},	// [8810] _باغ_, rha_, riq_,
  { {0x91780092,0x44290553,0x82340015,0x69c80a3a}},	//   _sớm_, sha_, يرلا, ngde
  { {0x44203dff,0x91070033,0x44293e00,0xddd8016d}},	//   bki_, шчад, pha_, movň
  { {0xa3ce014e,0xfff90074,0x05960086,0x44203e01}},	//   _राय_, دکست_, _پایگ, cki_
  { {0xd9f8005d,0x161b021e,0x7ff40015,0x20e81d56}},	//   ्ञात_, _नकार_, تسلا, _eşi_
  { {0x7c29003e,0x6da20ea6,0x1f640033,0x63ad3e02}},	//   wher, пиша, цкім, laan
  { {0xa3ce005d,0x7c293e03,0x2c610030,0x44393e04}},	//   _राम_, ther, lódi_, _kms_
  { {0x40350063,0x44390020,0xe0d20053,0x61e53e05}},	//   _уебс, _jms_, _מײל_, lehl
  { {0x7c293e06,0xdb09002b,0x7c3b3e07,0xdb003e08}},	//   rher, ازعه_, riur, tamá
  { {0xc3320008,0x69c800c0,0x44203e09,0x6ecc000b}},	//   פוי_, ggde, zki_, _समतु
  { {0xfa880023,0x4420005c,0x7c290fed,0x6c850015}},	//   _vừa_, yki_, pher, _الصم
  { {0x6a25002b,0xa088000a,0x50da000a,0x69c822fb}},	//   _گفتم, יְשִ, נקרא, agde
  { {0x44200198,0xfc300015,0xceb2000a,0xfaa50004}},	//   vki_, _تحل_, ּיל_, _ѓако
  { {0x44200050,0x69dd00dc,0x7ae9003f,0xb9950015}},	//   wki_, őseb, mwet, _الغب
  { {0xfa340086,0x44203e0a,0x244a0015,0x29d2002b}},	//   _برند, tki_, هجري_, _رييس
  { {0x3eb200df,0x3f8000df,0xc916000a,0xb3860800}},	//   šyti_, žiui_, _לחצת_, слал
  { {0x61e500b8,0x44203e0b,0x74130015,0xa9230046}},	// [8820] fehl, rki_, أوقا, ěžuj
  { {0x7ae90026,0x7afd00f2,0x99850091,0x3246005e}},	//   iwet, ästy, milų_, щезг
  { {0x5a3a0053,0xf77f001c,0x6a3a0053,0xe058002b}},	//   נגעה, meça_, נגעפ, لیست_
  { {0x63ad3e0c,0xddc8002a,0x040f0016,0x935a0004}},	//   caan, _widż, _thêị_, _бргу_
  { {0x92f60036,0x3fcb002b,0x61e5006f,0x69c80bfd}},	//   _учні, ادمی_, behl, ygde
  { {0xe0860015,0xf77f016e,0x0000006a,0x0000006a}},	//   _هجري, neça_,   ,
  { {0x645d022d,0x80e50015,0x4439008c,0x20e80045}},	//   _yksi, _وأفل, _yms_, _uşi_
  { {0xcce50015,0xeb970054,0x1549000a,0x1e860da9}},	//   تسهي, бић_, ינוֹ_, _глам
  { {0xdfcf006e,0xd9aa009b,0xbea33e0d,0x0000006a}},	//   _سيل_, лънд_, _натк,
  { {0x98a701e2,0xef170001,0x23ad0007,0xb33b0064}},	//   _aynı_, _уму_, mųjų_, _seçk
  { {0x69c80079,0x2d950bb1,0x625b000a,0xfca9006e}},	//   rgde, _фрус, רכיה, _نانو_
  { {0xbb86003b,0x9b6a00fd,0x64480003,0x61e50012}},	//   _الإي, _йшла_, édil, zehl
  { {0x29180020,0xf1a8005d,0x2057004c,0x23ad0091}},	//   ärab_, गरान, מיטל_, nųjų_
  { {0x41c7005d,0x7afd0f47,0x44393e0e,0xf1c7000b}},	//   _लाइस, æste, _sms_, _लाइन
  { {0x25bf0061,0x7c390034,0x63ad3e0f,0x16341453}},	//   ğul_, _ymwr, taan, черя
  { {0x25bf0011,0x53990080,0xdc8b000a,0xa8cb000a}},	//   şul_, рвая_, טְמָ, _ע֖וֹ
  { {0xf77f001c,0xd2150001,0x44390a54,0x91870015}},	// [8830] beça_, омаћ, _vms_, مجام
  { {0xd2500015,0xd301005e,0x23ad0091,0x63ad3e10}},	//   ّنْ_, кiвс, dųjų_, saan
  { {0x63ad00b6,0x61e5002c,0x89db000a,0xd1b80015}},	//   paan, rehl, רחבי, صالا_
  { {0xfde1000b,0x1607000b,0xc05801f3,0x44393e11}},	//   फ़्फ, शावर_, біч_, _ums_
  { {0xa3ce005d,0x287c0053,0xa3e6000b,0xcebb0054}},	//   _रात_, אנאמ, फ़र_, уље_
  { {0xae03014e,0x2c4c0089,0x291e0007,0x7c95049d}},	//   लाइन_, věda_, kyta_, ориц
  { {0x7c840001,0x4109000a,0x78440030,0xdb0005ff}},	//   пуње, _דִּ֣, lőve, hamä
  { {0xa4b80008,0xfc310029,0x291e0007,0xff530015}},	//   צלחה_, بحت_, dyta_, _فخذ_
  { {0x7bc90743,0x9b0501c6,0xff07005e,0x78440030}},	//   rgeu, ізод, _уявн, nőve
  { {0x3945006d,0x7ae90409,0xaa560021,0xf7cb0046}},	//   жног, rwet, يليا_, ážní_
  { {0x0039000a,0xa9690cb0,0x7ae93e12,0xb4c80065}},	//   ֹתָם, рина_, swet, _ईमे_
  { {0xe8df0023,0x7d56000a,0xb33b007f,0x785201ec}},	//   hiệm_, _ויעד_, _teçh, kāve
  { {0x65690089,0x89d5005e,0x0000006a,0x0000006a}},	//   řehl, _дійш,   ,
  { {0xb33b01e2,0x38ca002b,0x78440030,0x291e3e13}},	//   _geçi, دایی_, dőve, byta_
  { {0xf77f08e0,0x7d29000a,0x8d29004f,0x0000006a}},	//   reça_, בֵּ֔, בֵּ֤,
  { {0xccf2013a,0xdb000020,0xb466022a,0xd8760015}},	//   וכל_, bamä, ікал, _باتب
  { {0x987b0053,0x41aa0efc,0x68260030,0x130a0033}},	// [8840] _דאקט, иван_, _hódo, шнай_
  { {0xfe650086,0x6826316b,0xf1a90015,0x23ad0091}},	//   _سگ_, _kódo, مامه_, vųjų_
  { {0x045a0015,0xbfaa1377,0xd7ba000a,0xd46a004a}},	//   _نجحت_, атле_, ֹצְר, _вине_
  { {0x68260014,0xd5b10023,0xc8da0053,0x23ad0007}},	//   _módo, ức_, יקעט, tųjų_
  { {0x087700b2,0xaedc02e1,0xf413000a,0x867c000a}},	//   קענט_, ублi, _חפר_, ְר֔ו
  { {0xdcba010f,0xf67a0053,0x10a6006b,0x23ad0091}},	//   ащи_, סאַמ, _мигн, rųjų_
  { {0x93fa000a,0x8cc1000b,0x7cdc003d,0xcc2a0597}},	//   ֹלִי, रंगो, kārš, ицид_
  { {0xb33b01e2,0x290000df,0x61e200dc,0x765c0335}},	//   _seçi, _čia_, őold, hory
  { {0x63b9005c,0xa2b2000b,0xba0a1528,0x2d961c80}},	//   ówni, ेंट्, ахне_, _дрес
  { {0x291e0007,0xee37239c,0xfce60784,0x5e260015}},	//   tyta_, _дну_, _мозо, _بعرق
  { {0xfa330029,0x8e750010,0x784400dc,0xed5a0036}},	//   بريد, _хутч, zőve, _тож_
  { {0xb0840036,0x291e3e14,0x3eb20073,0x2bc7116f}},	//   овiд, ryta_, šytu_, _душо_
  { {0xcb670033,0x291e0091,0x6d4d0061,0x765c028a}},	//   _даце_, syta_, şaat, fory
  { {0x765c3e15,0x7ae23e16,0x291e0bba,0xf20e0065}},	//   gory, _ipot, pyta_, साफ़_
  { {0xa99b000a,0x45d4006b,0x399b000a,0xe654005e}},	//   _דבור, ьорс, _דיוד, євсь
  { {0xdb003e17,0x04c80015,0x28380015,0x78440030}},	//   pamä, توفي_, _وأية_, tőve
  { {0xf77f001c,0x83350063,0x018b004a,0xc1b901c5}},	// [8850] meço_, чнах, ащей_, йлах_
  { {0xf1c30023,0xe1670001,0x69da00b8,0x1a9b004c}},	//   _giờ_, ођен, nfte, יימע
  { {0xd2580010,0x64410003,0x50cb0033,0xc0cb0033}},	//   іцу_, élis, рызм_, рузе_
  { {0x155a000a,0x104800ce,0x301500c2,0x7ae20417}},	//   _לכתב, оячи_, ядер, _opot
  { {0x06fb005d,0x5f38005e,0x63a20077,0x2fd60015}},	//   एटिव_, опця_, ñone, سوود_
  { {0xee380036,0x4279004c,0x609b0015,0x0000006a}},	//   оні_, _לאָג, _نخرج_,
  { {0xa2c3005d,0xc5bc000a,0x7ae23e18,0x0000006a}},	//   िंक्, שֶׂר, _apot,
  { {0xc10400e6,0x09b5000b,0xe50c000b,0x69da3e19}},	//   _توفي, ूल्य, हमति_, efte
  { {0x0b450142,0x7bf1004c,0x69da3e1a,0xa3ce0065}},	//   янин, וּנדע, ffte, _रास_
  { {0x0216000a,0xceb2000a,0x7dc5002b,0xfe550033}},	//   ִ֗ים_, _ניב_, _رقصن, _экзэ
  { {0x644f005c,0xd019002a,0x7a2d006f,0xb80a002b}},	//   _ojci, _koń_, _núte, ميدم_
  { {0x66e60805,0xdc88000a,0xbd440015,0x7c2d0227}},	//   пома, _וְסָ, _تنمي, ďars
  { {0x765c3e1b,0x249a01c2,0x661a0072,0x7c2b0052}},	//   tory, _stpm_, ötko, _ilgr
  { {0x8afa0008,0x915e0092,0xa3ce000b,0x77430015}},	//   _להני, hắm_, _राह_, رَّم
  { {0xd4d5008f,0xd46a0021,0x399a004f,0x765c3e1c}},	//   мітэ, محرم_, _פיקד, rory
  { {0xccf20053,0x58ba0008,0xc9520008,0x7afb0db0}},	//   עכן_, _המקצ, _רמה_, ovut
  { {0x3218005c,0xa2c3000b,0xf8db000b,0xe8db0065}},	// [8860] _pory_, िंग्, _बहुप, _बहुच
  { {0x1757013a,0xd5b10092,0xa3ce000b,0xe2460015}},	//   _מספר_, ứa_, _राव_, أخري
  { {0x361b000a,0xd12f0015,0x30a5005e,0xc0d30058}},	//   _הויד, همك_, дрів, فيلب
  { {0x1fd6005d,0x2896004c,0x44240016,0x442b172e}},	//   ठभेड, לדען_, _ôm_, _glc_
  { {0x61f50482,0x33fb0008,0xbea30004,0xdce800bc}},	//   _fazl, _ההכנ, еачк, čoče
  { {0xc3330008,0xcf250015,0x61f50061,0x7c2b001a}},	//   _טור_, برمي, _gazl, _algr
  { {0x63a4003f,0xe6a9000b,0xc5f3000a,0x1dd70015}},	//   obin, _कब्ज, גדו_, سبوع_
  { {0xeb970054,0x63a43e1d,0x0000006a,0x0000006a}},	//   пић_, nbin,   ,
  { {0xe7c6005d,0x7afc0024,0x298a0036,0x61f50061}},	//   _वाजप, ārto, йсно_, _yazl
  { {0xd3370008,0x831b0053,0x3f800007,0x98b8000d}},	//   פריה_, צויז, žius_, олот_
  { {0xdca30191,0xef1f007c,0x69da3e1e,0x3b8604bb}},	//   _захи, _üür_, rfte, _елег
  { {0x63a4036d,0x0000006a,0x0000006a,0x0000006a}},	//   jbin,   ,   ,
  { {0xf77f03af,0x7ae23e1f,0x682600dc,0xe7380010}},	//   reço_, _upot, _kódj, зеў_
  { {0x4b7b0008,0x8b450015,0xd6843162,0x0000006a}},	//   _האדו, _تضمن, еусп,
  { {0x7a2d02c1,0x61f5065d,0x682600dc,0xb9db000a}},	//   _fútb, _razl, _módj, _החוש
  { {0xfc490092,0xe414005e,0x6d4a0016,0xdcf80061}},	//   hận_, ндсь, _đoà, navı
  { {0x67bc0008,0x62090015,0x64410003,0x61f5036d}},	// [8870] _המחק, يْرِ_, éliq, _pazl
  { {0xdb0b02de,0xb18b004a,0x63a43e20,0x26cb039f}},	//   _udgå, ссаж_, abin, muco_
  { {0x21270023,0xb33b0152,0x40940036,0x1638000a}},	//   ánh_, _reçu, еріт, _מנזר_
  { {0xe3a5002b,0x26cb016e,0xa4b6000a,0x4174006e}},	//   _تشدی, ouco_, _קלרה_, رالس
  { {0x1ec90036,0x23fa000a,0xd00e002b,0xc3fa004f}},	//   ілки_, _והרא, شلو_, _ולרש
  { {0x9e34005e,0x8ee8005e,0x2f23003d,0x0dcb096d}},	//   нечч, ямів_, _rīgā_, суди_
  { {0x3cf9005d,0xac960029,0xcfb5006b,0x644d3e21}},	//   ्में_, ونوا_, _обвъ, onai
  { {0x628702c1,0xf205005d,0x30150033,0x73fb000a}},	//   _hijo, राक़_, _ўдар, מּ֖ו
  { {0xb33b0064,0xbe980015,0x6287002a,0x291804d6}},	//   _geçt, _فضلا_, _kijo, äran_
  { {0x7afb0020,0x644d002d,0xf2a70033,0xf9910015}},	//   rvut, hnai, цкiх_, خبة_
  { {0xd90f0074,0x5c070010,0xdb0b00dc,0x63a40007}},	//   ایع_, _няда, _megé, ybin
  { {0x7d1e007c,0x3e720045,0x629d008c,0xaba8002b}},	//   äpse, râte_, _otso, _فهمم_
  { {0xcfb60008,0xe9ce15f9,0xf71a0033,0xdc36000a}},	//   ולרי_, _ик_, ціны_, _קאנט_
  { {0xdb260086,0x59d4005d,0x5693004a,0xdb0b0144}},	//   _توهی, _दायर, таёт, _regè
  { {0x33f60036,0x26d900f2,0x21010085,0x98c1003d}},	//   мчас, atso_, nčić_, īpēt_
  { {0x644d3e22,0x68260030,0x628f3e23,0xd2aa0033}},	//   gnai, _módk, _buco, жкае_
  { {0x4b7a00b2,0xd6aa0029,0xf7d70008,0x434300a4}},	// [8880] ַטעג, _بدعم_, _חופש_, ветв
  { {0xb5ca0086,0x644d3e24,0x1dd20065,0x63a43e25}},	//   _بودم_, anai, _साधत, sbin
  { {0xb33b01e2,0x3cf9005d,0x8705002b,0x0219005e}},	//   _seçt, ्मों_, _قبیل, чіть_
  { {0x28c5000b,0x23b2000b,0x3e690125,0x5f46012c}},	//   _विनि, _ज़िद, lúth_, ونال
  { {0x987b0053,0x5f930054,0x62873e26,0xdd92009a}},	//   קאנט, њишт, _fijo, نوش_
  { {0xfc490092,0x62873e27,0x764e2626,0x64440312}},	//   uận_, _gijo, nnby, liii
  { {0xfc490016,0xe0d70004,0xb7ee000b,0x9e650040}},	//   rận_, _овр_, ज़ाम_, راهن
  { {0xa157000a,0x3c440058,0xb33b007f,0x0000006a}},	//   _חבלה_, عَظِ, _geçs,
  { {0x98460048,0x539b0008,0x6e930029,0x5e930015}},	//   _dēļ_, חיפו, _للقا, _للقط
  { {0x0377000a,0x4d76012c,0x39143e28,0xad970058}},	//   ותפת_, _قطار, емор, _ينقض_
  { {0xa3c0000b,0xa3ce0157,0x2bbd000b,0x644d0c84}},	//   ीला_, रला_, ोलशा, ynai
  { {0x3ea90045,0x7852003d,0xfaa609a0,0x0000006a}},	//   ţate_, tāva, _жадо,
  { {0xe6670036,0x77640063,0x2ba4000b,0xa7742e3b}},	//   дтво, върж, _ग्या, ключ
  { {0x1af30010,0x68fc09c0,0x7852003d,0x999e0046}},	//   _шпія, årds, rāva, mitů_
  { {0xa4d4005e,0x6672002b,0xd7fb0004,0x65942044}},	//   корі, دگير, _дуп_, тасу
  { {0xdb0b00dc,0x62870a6d,0x60c5006f,0xbc78000a}},	//   _segé, _sijo, vrhm, לְּט
  { {0x8c1b0008,0x65950010,0xeb910447,0xd3700015}},	// [8890] קומי, _папу, אָב_, لهِ_
  { {0x416b0001,0x644d3719,0xe5c70033,0x21f50015}},	//   ојем_, snai, _ўспо, عكاس
  { {0xc5f2000a,0x46580015,0x21670033,0x63af3e29}},	//   _גדי_, _تؤيد_, фтаг, _tecn
  { {0x8f750033,0x44323e2a,0xc7b2000a,0x63bd02de}},	//   нулі, chy_, ָ֑א_, _udsn
  { {0x28c5014e,0xceeb0087,0x539a000a,0x670f000b}},	//   _विभि, تران_, _מירו, ामिक_
  { {0xad250015,0x999e0046,0x4429340e,0xd0d5006b}},	//   فرعو, ditů_, lka_, _погъ
  { {0xbdf80029,0x442900f2,0x29180020,0x7a240144}},	//   برنا_, oka_, äral_, _gòti
  { {0xf3f20008,0xa3d7000b,0xb568000a,0x21010085}},	//   ָ֣ה_, _साफ_, וֹחַ_, rčić_
  { {0xa3d7000b,0xcb09002b,0x6ee70015,0x7876016e}},	//   _सान_, سيدن_, _تسأل, náve
  { {0xedd50015,0xa2c2000b,0xe9d9053b,0x44293e2b}},	//   _سيؤد, _लिस्, чко_, hka_
  { {0x3079004c,0x186a0a21,0x44293e2c,0x684632b3}},	//   ּאָנ, зани_, kka_, енна
  { {0xdb350004,0x44293e2d,0x764e0034,0x78760046}},	//   _пеењ, jka_, wnby, káve
  { {0xac380018,0x442905a1,0x7876016e,0x0b580033}},	//   _تسلط_, dka_, jáve, _оршы_
  { {0xf6520029,0x96750033,0x7c293e2e,0x44293e2f}},	//   ائح_, высі, lker, eka_
  { {0x44323e30,0xa966006b,0x66030033,0xfc490016}},	//   thy_, _пиша_, ыпра, hậm_
  { {0x98160015,0x1ddf000b,0x4429101b,0xe29a0004}},	//   _سببا, प्तत, gka_, заа_
  { {0x28c5005d,0x7c293e31,0x7876016e,0xd252002b}},	// [88a0] _विडि, iker, gáve, هنر_
  { {0x44322e9d,0x824a0015,0xe1f72a30,0x7c292327}},	//   shy_, أشرف_, нгу_, hker
  { {0x44320041,0xf205005d,0x7c29179f,0xb7fa000a}},	//   phy_, राज़_, kker, ּפְת
  { {0x768b0050,0xbe8a0001,0x7c290111,0x44293e32}},	//   _użyc, пске_, jker, cka_
  { {0x6fb30086,0x441b0053,0x68260e75,0x7876001c}},	//   امها, _זוכס, _códi, cáve
  { {0xdd8f0015,0x7c293e33,0x3f8d2ea8,0x0000006a}},	//   موه_, eker, _egeu_,
  { {0x3da50191,0xc43a000a,0x7c29042f,0x6c47009a}},	//   тріб, ּתִי, fker, کليف_
  { {0x7c293e34,0xd577000a,0x50db004f,0xdfa60058}},	//   gker, עתקה_, _מקלא, _سحري
  { {0x7852003d,0x59d40157,0x3e690030,0xee3a0e64}},	//   tāvn, _दादर, zúti_, _ена_
  { {0x6da60029,0x7c293e35,0x010a000a,0x8f7501f3}},	//   _أمام, aker, ִלָּ, _русі
  { {0x4429005c,0x3f8d0061,0xf65f001a,0x7876356d}},	//   yka_, şmuş_, fræn_, záve
  { {0xac970029,0x2fc0002d,0x6d0b000a,0x7d57000a}},	//   _أننا_, óigh_, _מִדַ, _איבד_
  { {0x44293e36,0xead40a31,0xbc1b004f,0x0000006a}},	//   vka_, _роль, _מואש,
  { {0xe9800010,0x4429005c,0x7876001c,0xef0e0036}},	//   _калi_, wka_, váve, рмi_
  { {0xd4910092,0x4429393f,0xa4070099,0xe4c4055f}},	//   ề_, tka_, нџак, лётн
  { {0x2c09014e,0x7876001c,0xd6db0a0b,0x8d77000a}},	//   वाएं_, táve, _ето_, תגלו_
  { {0x17f80029,0x86270010,0x07f80002,0xa3d7000b}},	// [88b0] _سرية_, _зьне, _سريع_, _साठ_
  { {0x51f80256,0x78763e37,0x229602de,0x44293e38}},	//   нную_, ráve, _dæk_, ska_
  { {0x7fd5022a,0x4a5b000a,0x78ba25b6,0x69d8000b}},	//   вілі, לדמו, nstv, _मानी
  { {0x9f980054,0x64483241,0xd3a700ce,0x68263e39}},	//   евцу_, édit, _яроп, _pódi
  { {0xdb0b0134,0x7c290030,0x141a0c44,0x4df5006b}},	//   _udgø, vker, _חורב, вяйт
  { {0xf77400b2,0x4f58002b,0xd167006b,0x554b000a}},	//   נקס_, رجند_, _зъби, ּעֵ֣
  { {0xf40204f9,0x91650086,0x28c5005d,0x78ba37e6}},	//   _faţă_, _شهره, _विधि, jstv
  { {0x78ba184c,0x5fd8000b,0x81880015,0x7c2931ec}},	//   dstv, _डायल, _أنفق_, uker
  { {0x3ed90015,0xce95004a,0x7c292490,0x3df50054}},	//   _زواج_, _разъ, rker, _изас
  { {0xaae40115,0x7c293e3a,0xef64006b,0x7852003d}},	//   اسيو, sker, _съсо, tāvo
  { {0x7c2900dc,0x07a61402,0x78ba3e3b,0xf9890058}},	//   pker, канн, gstv, بندي_
  { {0x7e633e3c,0xff47006e,0x661e3e3d,0x201f01f6}},	//   lonp, لخ_, _sopk, _joui_
  { {0xfc460107,0xcc3a004c,0x7c260123,0xe9a9002b}},	//   ších_, _קענט, ökre, _قدغن_
  { {0xceb2011f,0x2c4c0089,0x89350015,0xfe670067}},	//   שים_, vědi_, _لعبا, شد_
  { {0xdb0b00dc,0x31bc0046,0xfa880016,0xa9040015}},	//   _megí, hází_, _cừu_, _مبين
  { {0x2ae5005d,0xe8d60008,0xdb0b1a2a,0xa6ca0058}},	//   _कहाँ_, _סופר_, _legí, _قوبل_
  { {0x63b60064,0x7e63008c,0x6abd0125,0xd46708b0}},	// [88c0] rayn, konp, ásfh, тите_
  { {0x4253003b,0xa3d7005d,0x22960134,0x7d083e3e}},	//   لنقر, _साथ_, _væk_, _jérô
  { {0x64a604c2,0x3e6935b3,0x6abe000b,0x644801f6}},	//   _шана, nútu_, _एट्र, édis
  { {0xd91a0053,0xc9520008,0x6557000a,0x2296001a}},	//   וועל, סמא_, _יביא_, _tæk_
  { {0xa3d7005d,0x52860029,0x78ba0057,0x935a0054}},	//   _सात_, _للحك, zstv, _црну_
  { {0x77ee000b,0x0000006a,0x0000006a,0x0000006a}},	//   ज़ुक_,   ,   ,
  { {0x3253004a,0x6bd6006e,0x61fc3e3f,0x61460a2b}},	//   _твёр, نتظر, _iarl, _рева
  { {0xdfd200e5,0x31bc0046,0x61fc3e40,0x5f06025f}},	//   _خير_, bází_, _harl, _изба
  { {0xdb00002e,0xcec1002a,0x1ab30033,0x61fc3e41}},	//   samþ, _chęć_, абыя, _karl
  { {0x78ba06db,0x637b000a,0x68263e42,0x3ea63e43}},	//   tstv, ונפד, _módu, mpot_
  { {0x26c400dc,0x497303e7,0xd917004a,0x39130033}},	//   ámon_, ильс, вья_, амэр
  { {0xa3ce000b,0x78ba3e44,0xa3d7000b,0x9b43002b}},	//   _राग_, rstv, _साध_, انیو
  { {0xe29f002e,0xfbd3000a,0x6f020d29,0x8cca0065}},	//   _orða_, _כתף_, nvoc, संको
  { {0xa4d506b4,0x78ba06cf,0x3e69006f,0x67200123}},	//   логі, pstv, bútu_, ämja
  { {0xfa77000f,0xa3d7000b,0xa3ce000b,0xea77004f}},	//   _שעות_, _साद_, _राख_, _שגור_
  { {0x7876099c,0x5fd1000b,0x54541f67,0x9f440046}},	//   rávc, _हाइल, авст, _samý_
  { {0xa858013a,0x2d9e2b0e,0x61fc3e45,0x61fe0079}},	// [88d0] _שיחה_, _ofte_, _barl, fdpl
  { {0x9187002b,0xd14b002b,0x9f4f02de,0x41b50021}},	//   نجام, وشان_, ndgå_, امار
  { {0x61fc3e46,0x8978000a,0xdb0b0077,0x7bc200da}},	//   _darl, תָּה, _regí, _odou
  { {0xdb0b0014,0x61fc003e,0x6fd4005e,0x90550033}},	//   _segí, _earl, иціє, ывец
  { {0x78760264,0x645a0003,0x61fc3e47,0xdfd40033}},	//   náva, étie, _farl, рочы
  { {0x0e640484,0x6da40015,0x7bc21671,0xe8df0016}},	//   акін, لمهم, _adou, êịc_
  { {0xeb990a47,0x787631ab,0x68260030,0x7e633d45}},	//   ний_, háva, _kódt, ronp
  { {0x200d04f9,0x1bb90029,0x78763d73,0x2bb90015}},	//   _unei_, رابع_, káva, رابة_
  { {0x76450134,0x78760097,0x747c000a,0x28c5000b}},	//   _omhy, jáva, ונהג, _विहि
  { {0x78763593,0x1eea0086,0x7f580010,0x38693e48}},	//   dáva, _سومی_, _раус_, _akar_
  { {0x2ba4005d,0x0a460033,0xdce6002b,0xa035004f}},	//   _ग्वा, узэй_, _ميلی, ָאָה_
  { {0x2c09005d,0xb8eb005d,0xc1720008,0xab950036}},	//   वाओं_, _लि_, מחי_, _сиді
  { {0x44f50089,0x28c5021e,0x0056000a,0x78760030}},	//   _ať_, _विवि, רשרת_, gáva
  { {0xaf760053,0x7f3a0053,0x2bbd000b,0x38693e49}},	//   טערס_, געשו, ोलका, _ekar_
  { {0x6e21016f,0xc9840054,0x8899000a,0x6f02006f}},	//   _molb, _кући, _אֹ֥ה, zvoc
  { {0xc952000a,0x61fc3e4a,0x0443120a,0xda110065}},	//   _למו_, _sarl, бесн, ़ावत_
  { {0xb69b255e,0x61fc3e4b,0x6e213e4c,0x787601d3}},	// [88e0] lvân, _parl, _oolb, cáva
  { {0xf1a904b6,0x6fd1000b,0xc176012c,0x0000006a}},	//   نامه_, _हाउं, هدات,
  { {0x11d70029,0x3ebf0011,0x19b60053,0xc5f30008}},	//   اومة_, _avut_, רפער_, _הדת_
  { {0x68fc0134,0xdfcf0015,0x6f020079,0xbfb600c3}},	//   ærdi, كيم_, tvoc, احات
  { {0xc7d70008,0x78520024,0xf413000a,0x61fc3e4d}},	//   רוני_, tāvj, _הפר_, _tarl
  { {0xccfa0124,0x6cd40015,0xf777004c,0xa6e3001a}},	//   ећи_, لقتا, נעסי_, óðir
  { {0xf8c5021e,0xcce60115,0x6aa23e4e,0x44223e4f}},	//   _विषय, استي, _stof, _kok_
  { {0x682600dc,0x69c30026,0x78760030,0x628e01f6}},	//   _móds, _adne, yáva, _hibo
  { {0x4dd60086,0x628e3e50,0x2bd5000b,0x6ac30015}},	//   _متاس, _kibo, _धारा, مقيم
  { {0x2ba4014e,0xa3e4014e,0x28c5005d,0xa2d5005d}},	//   _ग्रा, प्त_, _विशि, यंत्
  { {0x8d93003b,0x7d93003b,0x442209f2,0x2907016f}},	//   _المش, _المؤ, _ook_, _crna_
  { {0x81570053,0x628e3e51,0x4c9b000a,0x3157004c}},	//   רסטע_, _libo, _נבדו, ריטן_
  { {0xa3ce005d,0x6aa2003f,0xdb003e52,0x91aa000b}},	//   _राज_, _utof, ramó, टरफ़े
  { {0x7c22016b,0x56940033,0x78760f19,0x45d50004}},	//   _hoor, сарт, ráva, јовс
  { {0x78760014,0x7a3604f9,0xd5b80010,0x98a30001}},	//   sáva, _câte, ыся_, _лије
  { {0x26de0011,0x9477002b,0x44220061,0xa98b000a}},	//   ător_, ادسا, _cok_, _נָגִ
  { {0x4422010b,0x27e93277,0x7c223e53,0xf1a71d9f}},	// [88f0] _dok_, _iban_, _moor, грен
  { {0xe7e1000b,0x7c22007c,0x628e3e54,0x7d083e55}},	//   ग्रा_, _loor, _cibo, _ords
  { {0xdb0b00dc,0x645a0656,0x61550015,0x7a360003}},	//   _megá, étic, جنائ, _gâte
  { {0xe8d70008,0x2ba4000b,0x44220079,0x44c10091}},	//   רואר_, _ग्ला, _gok_, mė_
  { {0xb3ba000a,0x44c10007,0x1ee7002b,0x7ff40015}},	//   _במרכ, lė_, اوتی_, إسما
  { {0x1be2005d,0x28c5000b,0x0dc80054,0x63ad3e56}},	//   क्सल_, _विलि, гући_, lban
  { {0x44c100df,0x442201e2,0x6e210089,0x78760057}},	//   nė_, _yok_, _volb, dávn
  { {0x63ad3e57,0x0c250680,0x999e008c,0x7c223e58}},	//   nban, рмин, vitš_, _coor
  { {0x9ed9008f,0x7c2205d6,0xf20a000b,0x10080015}},	//   _шмат_, _door, _होड़_, _حتّى_
  { {0x44c10007,0x63ad3e59,0x4a450de5,0xd32301f3}},	//   kė_, hban, рнов, лiку
  { {0x7c220005,0x63ad00b6,0xb69b0011,0x8e8400e6}},	//   _foor, kban, uvân, _الله
  { {0x44c10007,0x7bc70007,0xab9b0015,0x63ad3e5a}},	//   dė_, ėjus, _أخضر_, jban
  { {0xf77200b0,0x98aa0024,0x501a0008,0x37760033}},	//   تاد_, ējāt_, דורו, рынс
  { {0x44220014,0xbb3a0008,0x768b002a,0x63ad3e5b}},	//   _sok_, _בעני, _użyl, eban
  { {0x89da0008,0x44c10007,0x628e3e5c,0x6aa900cb}},	//   _יחסי, gė_, _ribo, lpef
  { {0x18760053,0x141a0015,0x53a60033,0xd87a0015}},	//   _דעֶר_, خيرة_, рааб, _جمعت_
  { {0x9676008f,0xa3d7005d,0x6aa40064,0xc2463e5d}},	// [8900] _выні, _सार_, _çift, анак
  { {0xb77b013a,0x15460001,0xb6bb0008,0xf992004c}},	//   _באפש, _веом, _שציי, ַרד_
  { {0xeaf2005d,0xe0da31df,0x44223e5e,0x73e62354}},	//   _अन्त_, тве_, _tok_, _конз
  { {0x4ea615ce,0x628e01d7,0x5577000a,0x35dc000b}},	//   арка, _wibo, _כעין_, _बाड़
  { {0x6f0902c1,0x8cd8000b,0x479b004c,0xe81e000b}},	//   _crec, नूनो, דינס, _बचना_
  { {0x6f09259d,0x7d0000dc,0x787d00dc,0x7c221c00}},	//   _drec, járá, méve, _soor
  { {0x7fd60010,0x787d00dc,0x6f091bd4,0xf536000a}},	//   _візі, léve, _erec, ינַי_
  { {0x6f093e5f,0x6456030a,0xf65f02de,0x6c8300c3}},	//   _frec, nnyi, træk_, يلوم
  { {0x7c2215d8,0xadba0029,0x44c10007,0xcc870015}},	//   _voor, _لهذا_, zė_, جنيه_
  { {0x7c2200f6,0xbae30010,0x992a0033,0x5a3400d2}},	//   _woor, іцый, вюма_, снот
  { {0xa3d7014e,0x01970053,0x787604af,0x6e3b000a}},	//   _साल_, יכיש_, rávn, _שתבד
  { {0x44c10007,0x3e7b0003,0x9b6a0054,0x35df000b}},	//   vė_, rête_, _ишла_, _पॉज़
  { {0x787d0030,0x624b0535,0x29053e60,0xc6f83e61}},	//   jéve, dżon, avla_, анях_
  { {0x44c100df,0xa3e4005d,0x5eeb000a,0xdce1002a}},	//   tė_, प्स_, כַלְ, _wylą
  { {0x8a7b0008,0x3a7b0053,0xda7b01ac,0x4a7b000a}},	//   _שאות, _שטוד, _שנור, _שרוב
  { {0xe3b30074,0x44c10007,0x35d3000b,0x64560030}},	//   ترس_, rė_, _ताक़, gnyi
  { {0x98ab005c,0x787d00dc,0x9259000d,0x44c10007}},	// [8910] ącą_, géve, гаат_, sė_
  { {0x44c100df,0xe7e8005d,0x63ad3e62,0xf426007c}},	//   pė_, ट्ठा_, sban, äära_
  { {0x2614005d,0x5f950029,0x3264005e,0x6f090085}},	//   दारी_, ملائ, ітув, _srec
  { {0x7d0000dc,0x78520024,0x389b000a,0x1957004c}},	//   zárá, tāvi, דיאנ, סבאל_
  { {0x84160008,0x7a2d002d,0x6698004c,0xd37b0e7c}},	//   _הקרב_, _fúth, לאַרט, _шчо_
  { {0xfc490092,0x3cf3005d,0x644d3e63,0x787d0030}},	//   hật_, ंबले_, liai, névb
  { {0x7d0000dc,0x6f0907c6,0x867c000a,0x30a400d7}},	//   várá, _wrec, דרגו, _мртв
  { {0x85580008,0x644d3e64,0x6f093e65,0x26c40eed}},	//   ישוב_, niai, _trec, ámok_
  { {0x7d0000dc,0x6f090045,0x1ddb0015,0x9f3400ce}},	//   tárá, _urec, _لبضع_, _деті
  { {0x78760014,0x6ce70036,0x89a90080,0x7c3e003d}},	//   távo, _віде, ыков_, īpra
  { {0x999e00df,0xa3d7005d,0x644d122e,0x787d0030}},	//   entų_, सला_, kiai, zéve
  { {0x9b950029,0x7afc0024,0xab950029,0x768b002a}},	//   _الإت, ārtr, _الإغ, _użyj
  { {0xbb85003b,0x38970011,0x7b140029,0x7c3b1843}},	//   _الشي, _mări_, _وبهذ, mhur
  { {0xceb2000a,0x0f7a004c,0x787d1b8e,0xab63002a}},	//   היך_, טארב, véve, óżuj
  { {0x2ba60089,0xf992000a,0xdce1003d,0x7a2d006f}},	//   síců_, _צרה_, _izlē, _núti
  { {0x88560008,0x2c61002c,0x787d0030,0xddc30046}},	//   _לֹ֥א_, tódy_, téve, konů
  { {0xd3b90558,0x130a0010,0x624b002a,0x6fe10030}},	// [8920] русі_, ынай_, rżon, zácó
  { {0x26c205ba,0x228d0091,0xca29000a,0x787d3e66}},	//   msko_, _užkl_, נֵּ֛, réve
  { {0x787d0014,0x26c2176d,0x1bf9000b,0x49ba004c}},	//   séve, lsko_, ्याल_, רמעס
  { {0x644d3e67,0x764e002a,0xcfa90015,0xbbe10065}},	//   ciai, liby, لاهم_, पभोक
  { {0x26c21658,0x44320057,0xddb80033,0x2f183626}},	//   nsko_, mky_, аглі_, роль_
  { {0x50960124,0x764e0026,0x44203e68,0x44323e69}},	//   _грађ, niby, lji_, lky_
  { {0x91bb0008,0x44203e6a,0x7a1a0024,0x717600e6}},	//   _תמלי, oji_, nātņ, _طهرا
  { {0x93c50092,0x44320264,0x8157000a,0x1d070054}},	//   _ngắ, nky_, _הסלע_, сећи_
  { {0xcf260086,0x26c23e6b,0x441b000a,0x44203e6c}},	//   _ارزي, jsko_, רופס, iji_
  { {0x24610091,0xdea4002b,0x26c21c97,0xdb00001a}},	//   mėme_, _هیچی, dsko_, kamö
  { {0xd7f50256,0xfe45002b,0x290a016e,0x764e01d7}},	//   озны, _بکنی, íba_, diby
  { {0xdb0b01d1,0xfc490092,0x26c20796,0x6fd8000b}},	//   _begä, uật_, fsko_, डलिं
  { {0x7c650029,0x95cb000d,0x44320156,0x644d3e6d}},	//   _بالل, лува_, dky_, viai
  { {0x9aa40086,0x44201573,0xf21c000b,0xb4950054}},	//   _همچو, eji_, नाफ़_, живљ
  { {0x94770015,0x3858002b,0x644d3e6e,0x59dd000b}},	//   مدرا, _گشود_, tiai, _मातर
  { {0xb4e9005d,0x915f0092,0x3957000a,0x69da3e6f}},	//   _यही_, _lặp_, _לשום_, lgte
  { {0x91b90063,0x86c40015,0x92b70015,0xc1b900f4}},	// [8930] игат_, _فيين, إحرا, илах_
  { {0x1a9b0053,0x1b7b0053,0xe3bf02c1,0x75d5002b}},	//   טימע, רטמע, _doña_, _بيدا
  { {0x7a8b0053,0xdce80089,0xa0c40015,0x44323e70}},	//   אָאַ, _vzdě, كيلو, bky_
  { {0x44200f9a,0x44323e71,0xe588000a,0xd8db004f}},	//   cji_, cky_, _לָרָ, רקאר
  { {0x4439038d,0xd7fc0053,0xf2070afb,0x24610091}},	//   _ils_, טהאל, _ляво, gėme_
  { {0x3cf90015,0x2d94006b,0xc0970058,0x3e880058}},	//   لعبد_, пръс, _هجرت, مَنَ_
  { {0xfe700074,0xac390036,0xc1050015,0x7d1e00cb}},	//   رده_, ичих_, _بوزي, øpsp
  { {0x69da00dc,0xded50015,0x26c2002a,0xf5380447}},	//   egte, _ويأخ, ysko_, מטור_
  { {0x63b9005c,0xb4d6005d,0xc0520643,0x09f5024f}},	//   ówny, _सम्_, _חזן_, очня
  { {0x5ce50029,0x4420005c,0x915f0092,0x672f005c}},	//   _وكذل, zji_, _gặp_, dycj
  { {0x35d3014e,0x26c2002a,0x261d000b,0x9d550015}},	//   _ताज़, wsko_, मानी_, _بنات
  { {0x7876002c,0xfb150015,0x186a0f5c,0x764e0034}},	//   mávk, _وواج, рами_, wiby
  { {0x28c5005d,0x443204af,0x96ba0054,0xdb0b0613}},	//   _विकि, vky_, јуму_, _begå
  { {0x44393e72,0x26c23e73,0xdb00001a,0x0000006a}},	//   _als_, rsko_, tamö,
  { {0x44320264,0x44203e74,0x25830003,0x91b00016}},	//   tky_, tji_, vélé_, _đàn_
  { {0xd5dc005d,0x17fa0029,0x768b002a,0x26c23970}},	//   _बावज, _ضربة_, _ożyw, psko_
  { {0x44203e75,0x27e00061,0x44323e76,0x42260189}},	// [8940] rji_, _icin_, rky_, одав
  { {0x44390b4c,0x44200050,0x6aa4002d,0x44323e77}},	//   _els_, sji_, _éife, sky_
  { {0x6a3a0053,0x5a3a004c,0x44320107,0xc617000a}},	//   סגעפ, סגעה, pky_, _וחיי_
  { {0xa2a2005d,0x24610007,0xe3b20029,0x23e1021e}},	//   _कंप्, tėme_, _ترد_, _फायद
  { {0xdfcf0074,0xa25b002c,0x9e660015,0x7680008c}},	//   ئيه_, _kvôl, ياتن, pöyd
  { {0x24610007,0xeca60054,0x63a43e78,0xc33305bd}},	//   rėme_, ојин, lcin, _חוש_
  { {0x672f0050,0x16b7005d,0xbfd60015,0xed87006b}},	//   zycj, _अब्ब, _ويسع, осък_
  { {0x20360074,0x2fda0086,0x04370053,0x3e7b0003}},	//   _بفرس, _خورد_, ַטיש_, rêta_
  { {0x63a436dd,0x6df60015,0xe80e000b,0x8ea5002b}},	//   icin, _وكرا, ियना_, _فصلن
  { {0x9a670018,0x69da0012,0x7bdb02f2,0x298a2ded}},	//   يميل_, ugte, aguu, исно_
  { {0xc19b0008,0x63a400f0,0xc27b00a3,0xdb000046}},	//   ישיי, kcin, שריי, icmé
  { {0x69da02f2,0x89d8002b,0x672f002a,0x8b6a0a24}},	//   sgte, جوگر_, tycj, _киев_
  { {0x61ee04ed,0x7c650031,0xdb20008c,0x63a4002a}},	//   _obbl, _عامل, ätäl, dcin
  { {0x63a40048,0xddda0030,0x7bc03e79,0x8e8a004f}},	//   ecin, _kitű, lamu, ינָ֔
  { {0xe4e405d1,0x05dc000b,0x65943e7a,0xc8670015}},	//   мітн, _बारब, дару, _وطبي
  { {0x320d0064,0x20043e7b,0xc399005e,0x7bc03e7c}},	//   _şey_, _nami_, скає_, namu
  { {0xa8740033,0xa3cd000b,0x22950015,0x17f80015}},	// [8950] _ільі, रणब_, سلاس, _ذرية_
  { {0xfc490092,0x8b8b000a,0x7bc03e7d,0x63a43e7e}},	//   hập_, בָבֶ, hamu, acin
  { {0xdfd100e6,0x31c43e7f,0x15fa000a,0xd5fa000a}},	//   فيا_, ьств, _ההתע, _הפתר
  { {0x75d50086,0xa295042b,0x7bc00f3b,0x20043e80}},	//   _بيگا, _намі, jamu, _cami_
  { {0xdefb005f,0x63bd0048,0x20040035,0x7bc03e81}},	//   рые_, _iesn, _dami_, damu
  { {0xa6fc0008,0x9e34042b,0xd6fc000a,0x6da500f4}},	//   שִׁי, мечч, שִׁש, чика
  { {0xfc31003b,0x629d003f,0xdfdb0063,0x66053e82}},	//   فحة_, _huso, _въз_, _mahk
  { {0x66050e6d,0x629d000c,0x69ca0026,0x155c000a}},	//   _lahk, _kuso, _adfe, יכוב
  { {0x768b0050,0x3da70063,0x6e280134,0x8ed80029}},	//   _używ, _дреб, _fodb, _وذكر_
  { {0x2bab005d,0x20d2000b,0x2ddb0015,0x63a42409}},	//   _ट्रा, दूकध, _خبرة_, zcin
  { {0xda090086,0xf7690053,0xa9693023,0x9b950021}},	//   ليکه_, _עק_, сина_, _فلات
  { {0xdb0b00dc,0x711a000a,0x7d7a000a,0xa136000a}},	//   _megú, צורפ, _הנעו, פארק_
  { {0x6605064e,0xdb0b00dc,0x26d90573,0x8b9a000a}},	//   _bahk, _legú, guso_, _הבנת
  { {0x8b050050,0x6d432692,0x80cc000b,0x7d79000a}},	//   _częś, ozna, _हिले, ֶנּו
  { {0xca360008,0x5e5601ac,0x19ba0008,0xd575005e}},	//   _מנסה_, לישע_, _המצב, дуть
  { {0x26d93e83,0x69c13e84,0x629d3e85,0x0000006a}},	//   buso_, lale, _buso,
  { {0x883b0008,0x62950694,0xb7db000a,0xe29f001a}},	// [8960] _לתקו, _bizo, _הקפי, _yrði_
  { {0x290e0026,0x69c13e86,0x63bd007c,0x6265002b}},	//   _yrfa_, nale, _eesn, والق
  { {0xdb00002d,0x6ab8000b,0x759b000a,0x859b000a}},	//   rcmé, _इब्र, _לייח, _לשיו
  { {0x38a1002f,0xd059005e,0x6a740144,0xd0260033}},	//   _mór_, орчі_, ràfi, ямей
  { {0x7bc00005,0x80250029,0x20041ea8,0x61420046}},	//   vamu, برلم, _vami_, _bílé
  { {0x9cf40010,0x9757000a,0x6556000a,0xdcba006b}},	//   дзкі, הינו_, ּבֵא_, бщи_
  { {0x69c116dc,0xd00a0054,0x69ce0030,0x60260076}},	//   dale, _леве_, óbem, _едва
  { {0x629d00d9,0xf8c5021e,0x515b000a,0x9ca70015}},	//   _yuso, _विजय, _הכלו, أهيل_
  { {0x69c136eb,0x2d960e4d,0x6d433e87,0x7bc03e88}},	//   fale, _ерес, azna, ramu
  { {0x7f3b0008,0xfaef0029,0xf1c30016,0x69340c9a}},	//   _העמו, اثي_, _nhờ_, дноу
  { {0x2489002a,0xd90e002b,0xc237000a,0x7bc60030}},	//   ymam_, ایب_, פרטו_, ókus
  { {0x7d7b00b2,0x4c9b0008,0x26d90007,0xa157000a}},	//   _פראג, _הבאו, tuso_, לביה_
  { {0x8b660029,0x63bd00bd,0x9b930029,0xddc300bc}},	//   _عاصم, _resn, _كلمت, lonš
  { {0xf1c30092,0x38a11faa,0x8a18198b,0x69c13e89}},	//   _chờ_, _fór_, _фокс_, cale
  { {0x19570010,0xab5d005c,0x29020024,0x78760057}},	//   _нашы_, raże, ākas_, závi
  { {0xab5d005c,0x26d902c1,0xdd3b004c,0xdd1000bf}},	//   saże, puso_, זעלכ, _výňa
  { {0xdb0b0467,0x26c400dc,0x63bd06d5,0x24893e8a}},	// [8970] _segú, ámot_, _vesn, rmam_
  { {0xdb0900dc,0x17580008,0x66bc000a,0x018b004a}},	//   nbeá, _מסחר_, _המזה, бщей_
  { {0x14d5000a,0x63bd1658,0xa3e5000b,0x787d3e8b}},	//   _קוֹל_, _tesn, _नाप_, névo
  { {0xe0d00115,0xaae3004c,0xddc32fd7,0x69c12005}},	//   ازل_, _לאַנד_, donš, zale
  { {0xe80e005d,0x8f340010,0x9f34005e,0x070d000b}},	//   ियता_, нецц, неці, िटिव_
  { {0x238a002c,0xdcf8000b,0x6d4301f1,0xf2040033}},	//   ňujú_, ंबंध_, tzna, _пясо
  { {0xc212013a,0x69c13e8c,0x6c85009a,0x0000006a}},	//   _בהם_, vale, ولتم,
  { {0x69c1005c,0x2ef50036,0x442b1b9e,0xff070033}},	//   wale, _озбр, _joc_, _нязн
  { {0xe821005d,0x69c13e8d,0x3e720003,0x765c0034}},	//   याना_, tale, gâts_, ynry
  { {0x442b04f9,0x88c903a9,0x6d68001a,0x69c13e8e}},	//   _loc_, олов_, árað, uale
  { {0xa3cd000b,0x69c13e8f,0x8c3c0061,0x88c70046}},	//   रणा_, rale, _buğd, _oběž
  { {0xbca40029,0xeb090015,0x442b0188,0x69c13e90}},	//   _أمني, _وقضى_, _noc_, sale
  { {0x96760010,0x57470010,0x260a000b,0x77830a31}},	//   дыві, дзям_, ायली_, клюз
  { {0xcb12000a,0x7a3f0003,0xf1ba0016,0x7ae93e91}},	//   _שלג_, _bête, ươi_, mtet
  { {0x6a7d0251,0xe29f001a,0x442b29aa,0xd4f508f0}},	//   lèfo, _auð_, _boc_, няты
  { {0x998300df,0x26c400dc,0xe8d6000a,0x58ba000a}},	//   ųjų_, ámos_, _חוקר_, _ומקצ
  { {0xf7460080,0x7ae93e92,0xa2d5000b,0x624b002a}},	// [8980] _цепо, ntet, यंग्, nżow
  { {0x7ae92188,0x2fcd0026,0x7c2b3e93,0x0576002b}},	//   itet, _adeg_, _logr, _يادد
  { {0x30a50036,0xc6930008,0x7ae91804,0x361b00f3}},	//   ерів, _שאת_, htet, _וויד
  { {0xdfcf0196,0xc0590033,0xe29f001a,0x7c2b003d}},	//   ليم_, піі_, _arðu_, _nogr
  { {0xbefa00b0,0x7ae900dc,0x2fcd0026,0xe29f002e}},	//   تراض_, jtet, _ddeg_, _guð_
  { {0x768b0050,0x2d9a003c,0x11d60029,0xf2d30053}},	//   _użyt, øpe_, _تتحد, _בעש_
  { {0xa3e5005d,0xddde00dc,0xdd900015,0xf657000a}},	//   _नाम_, övőb, دوث_, וססי_
  { {0x442b0144,0x7ae92c90,0xe29f001a,0x787d0046}},	//   _xoc_, ftet, _erðu_, vévo
  { {0xae1e005d,0x1ea90029,0x7ae900dc,0xdb0900dc}},	//   पादन_, _فالي_, gtet, tbeá
  { {0xe814000b,0xaa870067,0xddc3024d,0x1e830763}},	//   _तोबा_, ونيم_, ponš, _алум
  { {0x7c2b002d,0x71d7000a,0x7ae93e94,0xbd9b004f}},	//   _fogr, וויד_, atet, _וסבת
  { {0x5cc50015,0x787d0003,0x984b02a3,0xec69005e}},	//   _أغلق, révo, іяна_, _ерік_
  { {0x442b3cc4,0xdb090030,0x5b360040,0xeb360015}},	//   _roc_, pbeá, _تعار, _تراخ
  { {0x6b8200bd,0x4b7b000a,0x7f2b000a,0x442b3e95}},	//   _izog, _ואדו, חֵלֶ, _soc_
  { {0x442b0251,0xfa97000a,0xb9db000a,0x24190033}},	//   _poc_, _קדוש_, _וחוש, повы_
  { {0x443d005c,0x7a3f0152,0xb7e6000b,0xa3bb002b}},	//   ów_, _vête, _कायम_, تاسر_
  { {0x67bc000a,0x7d1c001a,0xd1bb002b,0x28df000b}},	// [8990] _ומחק, _ársf, قاضا_, पंथि
  { {0x7a3f0152,0x3e69002c,0xa29505d1,0xab5d002a}},	//   _tête, búty_, хазі, naża
  { {0x7ae900dc,0xc6920008,0x40350088,0xb06b0da4}},	//   ztet, _תאי_, нежс, ордж_
  { {0x7ae92955,0x84350053,0x64480251,0xa957000a}},	//   ytet, _נאָװ_, èdit, ויבק_
  { {0xca6b0033,0x7c2b3e96,0x7ae902dc,0xab5d0535}},	//   _фiзi, _rogr, xtet, każa
  { {0xa3cd000b,0xb2ba000a,0x7c2b16bc,0x0000006a}},	//   रणव_, _ממשר, _sogr,
  { {0xba3d02d5,0xdfd50080,0x7c2b3e97,0xa2bb000b}},	//   způs, _повы, _pogr, शीर्
  { {0xdde90086,0x7ae93e98,0x9b0508f2,0xfd650016}},	//   ترچه_, ttet, езид, _khuẩ
  { {0xa3e4005d,0x7ae900f2,0xed58002c,0xba3d0046}},	//   प्ट_, utet, _veľa_, dpůr
  { {0xdb0e00dc,0x21990008,0xe29f001a,0x0378000a}},	//   ájáh, ּבֹא, _urðu_, ותחת_
  { {0x61e10084,0x7ae93e99,0x6441003d,0x29113e9a}},	//   _öllu, stet, īlij, íza_
  { {0xc5e90008,0x7ae93e9b,0x644101ec,0x0000006a}},	//   _לד_, ptet, ūlij,
  { {0x6d640011,0xceb2000a,0x7655002a,0xb8d60065}},	//   ătaţ, ֨ים_, fizy, _चढ़_
  { {0xceb23e9c,0xa6e3001a,0x56930033,0x0000006a}},	//   רים_, áðas, лаўт,
  { {0xa8060064,0xe29f001a,0x6e3401d3,0x0000006a}},	//   _alış, _orðs_, _égbő,
  { {0x52aa0063,0x25e4005d,0x35dc005d,0xd2aa0033}},	//   звам_, ञ्जी_, _बाक़, зкае_
  { {0xa6960124,0xfd650023,0x63b60176,0x3d01005d}},	// [89a0] _прој, _chuẩ, rbyn, _वैसे_
  { {0x720600a2,0xdb09016e,0xa3e5000b,0xf65f001a}},	//   عوام, abeç, _नाथ_, nsæl_
  { {0x261d005d,0x78ab0011,0x0000006a,0x0000006a}},	//   मारी_, _învă,   ,
  { {0xdfd20074,0xa0670e44,0x7173002b,0x85ba002b}},	//   ايش_, наха_, دهما, _باکس_
  { {0x11d60036,0xe29a00d0,0xa857000a,0x0665002b}},	//   _півр, _хаг_, עינה_, _سایپ
  { {0xad260029,0xbf650015,0xdd920067,0x315a0015}},	//   فربو, خدمو, هوش_, _فجأة_
  { {0x61fe3e9d,0x787600bf,0x6b820e8c,0x62630597}},	//   mepl, návs, _szog, _свра
  { {0xcd030080,0xab5d005c,0xc4d3000a,0x64560061}},	//   учши, waża, אגה_, niyi
  { {0xeaaf0086,0xda7a0010,0xcb070029,0xfd9a0015}},	//   یعی_, зян_, فيين_, _فئات_
  { {0xc3330008,0x5a340608,0xf2d3000a,0x35dc000b}},	//   טוח_, тнот, נעת_, _बाग़
  { {0x76550064,0xab5d005c,0x6e2b000a,0xb08a000a}},	//   vizy, raża, _מֵאַ, ּנָ֖
  { {0x415b0053,0x5fb9005d,0x7655005c,0x9cd7039e}},	//   לדיג, आरएल, wizy, _טובה_
  { {0x7c260123,0x261d000b,0x78a40085,0x61fe21f0}},	//   ökru, माली_, _čivu, kepl
  { {0x2c4c0089,0x7b060024,0x320a00dd,0x68eb00dc}},	//   vědy_, ērtī, _naby_, éldá
  { {0xe821005d,0x61fe3e9e,0xfa77000a,0x2499002a}},	//   यादा_, depl, _רעות_, _pism_
  { {0x897b0008,0xa97b000a,0xb97b000a,0xe2ab0015}},	//   _מרוצ, _מאוכ, _מנוי, كائن_
  { {0xe2f80036,0x2be1000b,0x9404002b,0x320a3e9f}},	// [89b0] неті_, फलता, دوقه, _baby_
  { {0x7a360152,0x25b90015,0x61fe3ea0,0xeb91000a}},	//   _bâti, _تهدد_, gepl, בָב_
  { {0xcf270086,0x65950292,0x41e2000b,0xf8b1004f}},	//   کراي, _јану, _पारस, ֹשׂ_
  { {0xdfd50010,0x26d902b9,0x7a3f0016,0xfd6500a1}},	//   тоды, orso_, _mêta, _thuẩ
  { {0x61fe200b,0x22950015,0xe7f4000b,0x44293ea1}},	//   bepl, _للحس, ेजता_, mja_
  { {0xee38009e,0x20090007,0xdce1003d,0x44293ea2}},	//   нні_, žai_, _uzlī, lja_
  { {0x25e9005d,0x27ec00dc,0x9f9f0030,0x8d54006b}},	//   _जानी_, ődni_, _kéük_, лтъч
  { {0x351c0008,0x44293ea3,0xeb990294,0x251c000a}},	//   לוונ, nja_, мий_, לווא
  { {0xe7db005d,0xb436000a,0x9e670015,0x44293ea4}},	//   _भाजप, דָיו_, _كائن, ija_
  { {0xc3340008,0x44290209,0x999e0091,0x6444007c}},	//   רוץ_, hja_, ditų_, zhii
  { {0x44293ea5,0x26d902b9,0xa9220033,0x186a0719}},	//   kja_, erso_, адэл, дани_
  { {0x2c17005d,0x7bc200aa,0x3dc70034,0x2d850061}},	//   थाओं_, _geou, lanw_, _izle_
  { {0xf09200b2,0x7c29010b,0x44293ea6,0xf1e20157}},	//   ינט_, mjer, dja_, _पालन
  { {0x7d0300da,0xb0d1000b,0xdb0b0030,0x7c29220e}},	//   owns, _हिंग, _megü, ljer
  { {0x3aeb003c,0x4429002e,0xd942085d,0x141a0015}},	//   løp_, fja_, _вещи, ويسة_
  { {0x44293ea7,0x7c3b3ea8,0x999e0091,0x7c293ea9}},	//   gja_, nkur, bitų_, njer
  { {0x64440020,0x7c3b003f,0xe29a0004,0x7c291ce6}},	// [89c0] rhii, ikur, даа_, ijer
  { {0x5a0c0053,0x69c32cb4,0x7a360003,0x64560061}},	//   ּלאַ, _jene, _pâti, siyi
  { {0xa5d90053,0xc8790064,0x7c3b2438,0x61fe0c0a}},	//   _אַרי, luğa_, kkur, repl
  { {0x44290f9a,0xdb0b0012,0xdefa0033,0x53a62a91}},	//   cja_, _begü, дык_, _шамб
  { {0xab5d005c,0x3aeb00cb,0xdb0b0030,0x13b7004f}},	//   ważn, jøp_, _megó, _בהכל_
  { {0xcce60015,0x28c2000b,0x7c2902de,0x81fa0015}},	//   نسبي, वीडि, ejer, _تفسر_
  { {0x265b0053,0xc5f3000a,0x71760067,0x7c290013}},	//   וכסא, ידג_, _شهرا, fjer
  { {0xdb0b001c,0x7c29003c,0x1d070001,0xab5d002a}},	//   _negó, gjer, тећи_, rażn
  { {0x4e060124,0xbea6010f,0x629c3eaa,0xe7e6000b}},	//   _изаб, _разк, _kiro, कलना_
  { {0x69c30176,0x8f750036,0x44290ba8,0x3cfa0015}},	//   _cene, _сусі, zja_, _يعاد_
  { {0x7c3b0048,0x35dc005d,0x787d0152,0x69c33eab}},	//   bkur, _बाज़, lévi, _dene
  { {0xc1730008,0xfd57000a,0x8d55004a,0x7b07008c}},	//   יחת_, _בשבי_, _стуч, ärtä
  { {0xada2002e,0x7ad40015,0xac970015,0x44293eac}},	//   _þúsu, _إقتص, _شنها_, vja_
  { {0xcf93000a,0x06850015,0x260a000b,0x69c31993}},	//   יטר_, السُ, ायगी_, _gene
  { {0x64480048,0x69fb0008,0x44293ead,0xd5a6002b}},	//   īdin, _חלוק, tja_, الفی
  { {0x69c300dc,0x64a4000d,0xe8d70008,0x0ed2000b}},	//   _zene, раѓа, _סוחר_, _सिंड
  { {0x69c31622,0x1db4000b,0x34941bdf,0x629c3eae}},	// [89d0] _yene, ुरात, ратр, _biro
  { {0xe1f00029,0x44293eaf,0xa3e5021e,0x69c83eb0}},	//   قسم_, sja_, _नाव_, nade
  { {0xdb0b08e0,0x44290014,0xdce80089,0x645a0251}},	//   _segü, pja_, _vydě, ètic
  { {0x92b70029,0x645a0152,0xddd80089,0x629c268c}},	//   _لحسا, étit, livň, _eiro
  { {0x7c29010b,0x9e350010,0xde59005e,0x63ad0034}},	//   vjer, ледч, наді_, mcan
  { {0xab5d002a,0xf774000a,0x8ca4000b,0x69c83eb1}},	//   ważo, סקס_, _चूहो, jade
  { {0x69c83eb2,0xbcf50015,0xc694000a,0x69c33eb3}},	//   dade, استغ, באס_, _rene
  { {0x7c3b0007,0x63ad0375,0x69c3119c,0x6edb000b}},	//   ukur, ncan, _sene, _निपु
  { {0xc052013a,0x69c33eb4,0xab5d002a,0xa0680004}},	//   _הזן_, _pene, rażo, _раѓа_
  { {0xc3320008,0x7c29003c,0xab5d005c,0x69c83eb5}},	//   צוי_, sjer, sażo, gade
  { {0x61e53eb6,0x6a7d0144,0x4995004a,0x69c33eb7}},	//   ighl, nèfi, ышит, _vene
  { {0x1cba000a,0x7b15002b,0x69c8007c,0x50da004c}},	//   _נמנע, _مبتذ, aade, עקרא
  { {0x69c33eb8,0x85430091,0x69c83eb9,0xeaae004a}},	//   _tene, šėli, bade, _ый_
  { {0x69c3003f,0x68ec0030,0x2ca5104b,0xfe67006e}},	//   _uene, öldö, _kuld_, صد_
  { {0x33f60eaf,0xa904006e,0x629c013b,0x2aa9016d}},	//   лчас, _نبين, _riro, _húb_
  { {0x60da00c0,0xe8d6000a,0x629c3eba,0x37e60004}},	//   _åtmi, _עופר_, _siro, _соиг
  { {0x629c3ebb,0x57fb000a,0xe8210065,0x0000006a}},	// [89e0] _piro, _טלקו, यारा_,
  { {0x479b000a,0x63ad3ebc,0x68e100da,0x079b004f}},	//   _איפס, acan, ould, _אספל
  { {0x25e9014e,0xa4940086,0x68e10064,0x2aa9002d}},	//   _जाती_, _نیست, nuld, _lúb_
  { {0xf1a90053,0x63ad1f30,0x3d17005d,0x61e5002d}},	//   לס_, ccan, पटने_, aghl
  { {0x6f090030,0x200d01d7,0x657e00c7,0x68e13ebd}},	//   _csec, _daei_, _hyph, huld
  { {0x99850007,0xd2520086,0x3cb4005e,0xbea70015}},	//   nklų_, _طنز_, айкр, دهون_
  { {0x6f0904ed,0x867b0053,0x61460511,0x69c83ebe}},	//   _esec, ערצו, _сева, vade
  { {0x7e63002d,0x711b000a,0xb4fb000a,0x68e1232f}},	//   annp, _אולפ, תפקי, duld
  { {0x9f4a00f2,0x6edb005d,0x38a80152,0x245f008c}},	//   ämän_, _नियु, _sûr_, lämä_
  { {0x2ca50134,0x68e10134,0x6da60015,0x787d0030}},	//   _fuld_, fuld, _إمام, névv
  { {0x6e93003b,0x68e10024,0x5e930015,0x2ca511bc}},	//   _اللا, guld, _اللط, _guld_
  { {0x69c83ebf,0xcb67009a,0x0000006a,0x0000006a}},	//   sade, ئمیه_,   ,
  { {0xd90e0086,0xac970029,0x2057000a,0x69c83ec0}},	//   زیک_, _إننا_, ריכל_, pade
  { {0x1994008f,0xdd200089,0xdb9b000a,0x7a360003}},	//   _каля, _může, _נסגר, _pâtu
  { {0x68e1001c,0xdb0b002e,0x65952c0c,0x1634006b}},	//   culd, _hegð, раву, щеря
  { {0xa98b000a,0x24800085,0x63ad3ec1,0x0000006a}},	//   _אָחִ, glim_, ucan,
  { {0x57b4004a,0x95cb0054,0x2447007c,0x325508a3}},	// [89f0] _убыт, _пуна_, _nõme_, авар
  { {0x6fc7000b,0x05b6002b,0x24921d08,0x24803c56}},	//   ारभू, _نگفت_, amym_, alim_
  { {0xdfd10029,0x0eff000b,0x867c000a,0xdb0b001a}},	//   قيا_, ोट्स_, _ארזו, _legð
  { {0x98be005c,0x3f150155,0xd7b5000b,0x94ba004f}},	//   cztą_, идес, ंडिच, _שמרת
  { {0xfe710021,0x764b0091,0xe7e6000b,0xddc50fe4}},	//   يدت_, _įgyj, कलता_, абли
  { {0xfe6e0086,0x68e10061,0xc105002b,0x22da000a}},	//   وگل_, yuld, _پوري, _בחשא
  { {0x51840010,0x9d45007a,0xe7e6000b,0x361c000a}},	//   _гута, рейд, _काला_, תווד
  { {0x201f04f9,0x68e10159,0x3ff9004c,0x8558004c}},	//   _unui_, vuld, _שפּע, טשוב_
  { {0x5ac60033,0x4a4508e8,0x99850091,0x8a05006b}},	//   алым_, инив, yklų_, азпе
  { {0xf2d40053,0x38691bb9,0x5f440015,0x68e13ec2}},	//   זעץ_, _ajar_, _انكل, tuld
  { {0x8bd50087,0x5d670054,0x85430091,0xd8263ec3}},	//   _نقاش, _стаз, šėji, адни
  { {0x68e101e2,0xddc30030,0x69ce0030,0x6b8e0061}},	//   ruld, minő, óber, öngü
  { {0x7c3a0008,0xb6a60080,0xb887002e,0xd7070033}},	//   _שתנס, ригл, _smíð, аняе_
  { {0xbb840029,0xff16000a,0x9f96000a,0x86760033}},	//   _الهي, בקשת_, ידרה_, рымц
  { {0xf484002b,0xe47a0054,0x24801253,0xda5a000a}},	//   ماری, вљај_, tlim_, _בכסל
  { {0xf74a0015,0x03a314fd,0xe40600af,0xb30700af}},	//   _للبي_, жито, јзап, снoс
  { {0x645a0152,0x487b0008,0xb8650087,0xa2e60248}},	// [8a00] étiq, _בטקס, _داوو, розд
  { {0x171b0008,0x98be005c,0x41b6006b,0x245f008c}},	//   _יופע, sztą_, рсат, tämä_
  { {0x4fc6008f,0x765c0727,0x24800085,0x0000006a}},	//   асла, miry, plim_,
  { {0x50460001,0xf992011f,0x351b0008,0x58f60053}},	//   једб, קרא_, _סוכנ, יצען_
  { {0x2d8100b8,0x7680008c,0x64463ec4,0x44223759}},	//   ühen_, töyh, _ilki, _ink_
  { {0x5cd40015,0xddc30045,0x44220160,0x764b0073}},	//   مقتط, rinş, _hnk_, _įgyk
  { {0xdb0b002e,0x7d0d005c,0x9c460036,0xdce10091}},	//   _segð, łasn, ихил, _mylė
  { {0x10a30763,0xcff4009a,0x21670c4c,0x765c0416}},	//   _фитн, _ديرک, _тиси_, hiry
  { {0xab380080,0x765c0696,0xaa661d8c,0x309b004f}},	//   уппу_, kiry, иток, _ישלמ
  { {0x5cf60010,0xedd30015,0x4422275b,0x6f1d00e1}},	//   _вяду, _ويقد, _lnk_, _ásca
  { {0x0217000a,0x64463ec5,0x29183ec6,0x0000006a}},	//   בחים_, _olki, íra_,
  { {0xdb1900b8,0xdb090251,0x8d5b000a,0x6c330015}},	//   _bewä, cceï, _בכבי, _وفلا
  { {0x95cb05b3,0x29020046,0xe7871c3f,0x38a10045}},	//   кува_, ňka_, руно, tărî_
  { {0x7aef0144,0xbb3b000a,0x64463ec7,0xa8a607ec}},	//   àcte, _בעדי, _alki, _крик
  { {0xc8d3000b,0x03c70c9a,0x7c220c0c,0xcdb7004f}},	//   _थिएट, исам, _knor, שפלה_
  { {0x38690665,0x34480001,0x3cde000b,0x7127002b}},	//   _ujar_, ачун_, _गिने_, یرال
  { {0x49920074,0xd6d106e4,0xdb1900b8,0x44220b28}},	// [8a10] _دیگر, _عقد_, _gewä, _dnk_
  { {0xc2c40029,0xd9040086,0xe4e70036,0x20dd001a}},	//   تيكي, وی_, _кімн, _náið_
  { {0x7c2211c8,0x64410079,0x50cb0033,0x80f51bc8}},	//   _onor, ëlis, тызм_, спех
  { {0x7d1500dc,0x5f950ea6,0x442d007c,0x7c221ed6}},	//   _ázsi, биет, _õe_, _nnor
  { {0xa2820086,0xdfce00e6,0x93fa000a,0xa858000a}},	//   _کیلو, ريو_, _גלרי, סידה_
  { {0xc332103d,0x9f5600dc,0xd336000a,0x7c222973}},	//   _צום_, ágát_, _הרשה_, _anor
  { {0xbd440015,0x20dd001a,0x8c3c0061,0x26c40030}},	//   ينهي, _dáið_, _tuğl, ámoz_
  { {0xdb0b0030,0x44d31779,0x73fa000a,0x0c250588}},	//   _megö, ić_, ָּקו, смин
  { {0xdb0b00dc,0x9b450029,0xb4e4000b,0x753c002a}},	//   _legö, صندو, _नम्_, zyrz
  { {0xe29200b2,0x3e7b0152,0x2b4d005c,0x8e850015}},	//   ּװט_, rêts_, rzec_, _الطه
  { {0x49990080,0x3cf0006f,0x6fab0065,0x0000006a}},	//   ытия_, ľoví_, _छलां,
  { {0x321100da,0x6f1b3ec8,0x3cf80123,0x7c223ec9}},	//   _lazy_, _kruc, _ärva_, _gnor
  { {0xac740029,0x44d33925,0x66e3000b,0x501a000a}},	//   _بالش, eć_, कूलक_, אורו
  { {0x7f76000a,0xf7830015,0x6f1b002a,0x5ee8004f}},	//   מערב_, سلَّ, _mruc, סַרְ
  { {0x25e9014e,0xc8b50afa,0xfe9a000a,0x765c008c}},	//   _जारी_, _услы, טישמ, riry
  { {0x6f1b22f8,0x765c0d91,0x47c62c63,0x2258005a}},	//   _oruc, siry, _убив, _smrk_
  { {0x44d3005c,0x3211005c,0x23273eca,0x765c002a}},	// [8a20] ać_, _bazy_, боти_, piry
  { {0x17570008,0x15461d8c,0xc8b5004f,0x9757004f}},	//   _לספר_, _геом, ֶּ֣ה_, _ליפו_
  { {0xd179008f,0xdfda0063,0x21a3006b,0x2d81007c}},	//   асці_, гъл_, чихм, ühel_
  { {0xa988000a,0xd6cf002b,0x6446008c,0x4ea60004}},	//   בָנִ, _تقی_, _ulki, брка
  { {0x21d80074,0xd00f0029,0xa2a2005d,0xd47b000a}},	//   _نژاد_, عله_, _कंट्, _תאכל
  { {0x6f1b3282,0xcf250015,0x321108c6,0x7c223ecb}},	//   _druc, ترمي, _gazy_, _snor
  { {0xd13200e5,0xacf30015,0xc536004f,0x0000006a}},	//   _عمر_, كسيت, מָ֤ה_,
  { {0x98be002a,0x1ab4006b,0x6f1b3ecc,0xf0631021}},	//   cztę_, обия, _fruc, _експ
  { {0x6bd30015,0xf413000a,0x9a260015,0x6f1b002a}},	//   ستير, לפה_, معدن, _gruc
  { {0xd8f80036,0x44d3005c,0xd90e0086,0x9f59002d}},	//   аної_, yć_, فیت_, _úsá_
  { {0x5d86003b,0x28f80036,0xe8950010,0x2db7000a}},	//   _الال, шень_, жань, _הלבן_
  { {0x96eb008f,0x1799004a,0x673d008c,0x6cab000a}},	//   льга_, ивны_, tysj, _עֹבְ
  { {0x21270023,0x1dac005d,0x6c7b0053,0x9b960015}},	//   ̣nh_, _चलात, _גראד, _الشت
  { {0xef110008,0xe6672dfa,0x08f7009a,0x25a50c4e}},	//   וּל_, стмо, جریب_, øll_
  { {0x3211005c,0xf65f0134,0xe599005e,0xda5b000a}},	//   _razy_, dsæt_, ркві_, _תכול
  { {0x44d3002a,0x8d5b000a,0x94a805b5,0xf2110065}},	//   rć_, אכלי, стра_, _डोज़_
  { {0xf7f40074,0x8c1b0008,0x966b0018,0xb6070033}},	// [8a30] _رسيد, נומי, _مصدق_, _лянк
  { {0xdd210007,0xa3e5000b,0x69ca0077,0x22470030}},	//   _rįžt, _नाक_, _jefe, ónk_
  { {0x31c40010,0x82340029,0x21270092,0x30150098}},	//   яств, أرقا, ãnh_, ждер
  { {0x06ed005d,0x753a00b8,0x69ca36b5,0x2fcb0015}},	//   _जमाव_, ätze, _lefe, اباً_
  { {0x644d002f,0xf5ab0008,0xa2830086,0x171c004c}},	//   mhai, ְבֵּ, _فیرو, ָווע
  { {0x6615005c,0x6f1b0111,0x3e6b004a,0x98be002a}},	//   ndzk, _vruc, ышен_, sztę_
  { {0xa63c0008,0xd5cc0008,0xc212000f,0x067c000a}},	//   רגור, אֶחָ, _קהל_, אנגל
  { {0x4c920001,0x69d80106,0x6f1b3ecd,0x5ba903ae}},	//   мијс, _adve, _truc, шким_
  { {0x6f1b005c,0x6438004c,0x24610091,0x69ca3ece}},	//   _uruc, מאהא_, lėms_, _befe
  { {0x4f88000a,0xa2f6000a,0x644d007c,0xfa390054}},	//   _הָעֲ, קמתה_, hhai, рчић_
  { {0x24610007,0x61fa0a55,0x69ca1b65,0xfe700015}},	//   nėms_, _ötle, _defe, _أدق_
  { {0xc85a0036,0x3ff9004c,0x291c0085,0x50fa004f}},	//   ршої_, ױפֿע, _drva_, סִיד
  { {0x7bcb0024,0x644d1406,0x907a000a,0xa088000a}},	//   _iegu, dhai, שטרי, מְשִ
  { {0xfa370086,0xceb20135,0x8f9a000a,0x8afa00a3}},	//   _درصد, ויך_, יירי, _כהני
  { {0x2609005d,0x7bcb0509,0xe5a3067a,0xfa56002b}},	//   ाज़ी_, _kegu, дири, _برنگ
  { {0x644d017e,0xc486017f,0xf992000a,0x62853ecf}},	//   ghai, ілак, _קרה_, elho
  { {0xf65f0134,0x764b0007,0xe6c60015,0x389b000a}},	// [8a40] tsæt_, _įgyv, _بتعي, _דיקנ
  { {0x7bcb3ed0,0xe6570015,0x68e12e9d,0x7a3f0003}},	//   _legu, _وليث_, orld, _bêti
  { {0x644d017e,0xf65f0134,0xc106002b,0xc649002b}},	//   bhai, rsæt_, تواي, _دجيل_
  { {0x644d3ed1,0x79830026,0xef1a31a9,0x6edb000b}},	//   chai, _mynw, име_, _निशु
  { {0x63b4005c,0x6fcc000b,0xb1e60015,0x57fb000a}},	//   ągną, ारबं, _وأسه, שלנו
  { {0x7bcb0020,0x471b0053,0x6edb005d,0x78a40fb2}},	//   _aegu, יונג, _निरु, _liiv
  { {0x69dc005c,0xe0d70254,0x6cd40015,0x7bcb2574}},	//   órem, _мвр_, أقبا, _begu
  { {0x69ca0064,0x644400f2,0x78a40020,0x7ee60015}},	//   _sefe, nkii, _niiv, _وكأن
  { {0xcb070029,0x7bcb3ed2,0x93b7000a,0x9e663ed3}},	//   قيين_, _degu, חלפו_, _двад
  { {0xa9540001,0x291c01a3,0xa2dd000b,0x8f37000a}},	//   звољ, _prva_, _पिस्, _ואמו_
  { {0x644400f2,0xf1b3000a,0x7bcb001a,0x69ca001a}},	//   kkii, וסת_, _fegu, _vefe
  { {0x69ba014e,0x7bcb0007,0x6aa33ed4,0xcce500e5}},	//   _श्री, _gegu, _einf, _رسمي
  { {0xb09b000a,0x24610091,0x44c8140d,0xa7870015}},	//   ייטר, zėms_, eş_, تشدو
  { {0x79830026,0x69d8063b,0x6615002a,0x29180123}},	//   _fynw, _udve, udzk, åras_
  { {0x34950124,0x644d3ed5,0xa9670054,0x6aab0012}},	//   завр, thai, _миља_, _zugf
  { {0x68e800d9,0xa8340029,0x24610091,0x2cac00da}},	//   mudd, _يعيش, vėms_, _mudd_
  { {0x644d0ec8,0x6d5e006f,0x68e83ed6,0xd498005e}},	// [8a50] rhai, úpaj, ludd, ірс_
  { {0x644d04d2,0x24610091,0x65950cab,0x44f50a62}},	//   shai, tėms_, _напу, _епос
  { {0xdb09002f,0x68e8013c,0xc5f2000a,0x2fcf0123}},	//   iceá, nudd, _אדי_, tagg_
  { {0x26c9003f,0x80a8005e,0xa1280015,0x80270015}},	//   _kwao_, івів_, تكمل_, غرام
  { {0xd2470080,0x68e83ed7,0x545412ae,0x9f340033}},	//   _дэви, hudd, _цвят, меці
  { {0x68e8003c,0x539a0008,0x24610007,0x2cac0e18}},	//   kudd, _לירו, pėms_, _budd_
  { {0x1d19008f,0x2cac0026,0x44393ed8,0x6aa302b9}},	//   сюль_, _cudd_, _kos_, _rinf
  { {0x44393ed9,0xdfd10015,0xfbd10040,0x116a002b}},	//   _jos_, _سيئ_, رتب_, _الفی_
  { {0xcf27003b,0x9f4f02c1,0xec46006b,0x78a4014b}},	//   _برأي, regó_, язъл_, _riiv
  { {0x44390782,0x7e5500e5,0x68e8013c,0xce380015}},	//   _los_, _عناص, fudd, _وألا_
  { {0x443900dd,0x7bcb3eda,0x2cac0034,0xd90c002b}},	//   _oos_, _tegu, _gudd_, لیو_
  { {0x5b370029,0x186a034e,0x69c10012,0xb903000b}},	//   _وعشر, сами_, sble, _फट_
  { {0x78a40607,0x29180123,0x64440061,0x41cb0065}},	//   _viiv, årar_, vkii, िरास
  { {0x443903af,0x3aba000a,0xcb36000a,0x4e79004c}},	//   _aos_, _המסנ, _מאני_, מאָצ
  { {0x7ae9022d,0x78a40604,0x88c40015,0x3ead008c}},	//   luet, _tiiv, _قتيل, _luet_
  { {0x442602c1,0x44393edb,0x2d8500aa,0xe7e60065}},	//   ño_, _cos_, _myle_, _काटा_
  { {0x44390ab6,0x3eb800bc,0x443200aa,0x91e60054}},	// [8a60] _dos_, _črto_, rjy_, зозе
  { {0xd1960054,0x91960054,0x6444019a,0x7c39108d}},	//   пшењ, пјеш, skii, _lowr
  { {0xc0060191,0xe63b0008,0x44390251,0xa63b000a}},	//   зпек, _התיכ, _fos_, _הגיר
  { {0x3ea5002d,0xa4b7000a,0x44391a4f,0x2cac3edc}},	//   _ailt_, _מלטה_, _gos_, _rudd_
  { {0xdfcf0087,0xc7d7000a,0xd0070033,0x68e801c2}},	//   ايه_, פוסי_, яеце_, zudd
  { {0xb1460124,0x2d85002a,0x68e801c2,0x3ea50061}},	//   _енгл, _byle_, yudd, _cilt_
  { {0x7d78002b,0x4439050b,0xbdf70058,0xdb0901d0}},	//   غمبر_, _yos_, سروا_, nceæ
  { {0xbab80760,0x68e80123,0x248201c2,0x251b000a}},	//   огих_, vudd, _jkkm_, מוצא
  { {0xdee30709,0x3ead10ee,0x7c3900da,0x7ae93edd}},	//   _поти, _guet_, _dowr, guet
  { {0x78ad016f,0xdebb000a,0x6f79000a,0xb3560033}},	//   _čavr, _לממל, _וְעו, ўнiц
  { {0x6e2800fb,0xdb09002d,0xadb70015,0xddd80046}},	//   _indb, rceá, _رهنا_, lovů
  { {0x98c30033,0xa2dd000b,0x68e83ede,0x0000006a}},	//   эсьл, _पिल्, rudd,
  { {0x8c1b000f,0xfaf7002b,0xbebd0091,0xec35002b}},	//   _לואי, _فروغ_, _grūd, _تونگ
  { {0x76890084,0xdb9b0008,0x65950127,0x9aeb000a}},	//   mþyk, _הסדר, дагу, _הַהִ
  { {0x4439020a,0x79fb0008,0x99fb000a,0x6fcc000b}},	//   _pos_, _הלוח, _הפופ, ारां
  { {0xb867009a,0x443901f9,0x34953edf,0x0000006a}},	//   _ژاکو, _qos_, фабр,
  { {0x443905d4,0x18780053,0xe3b00031,0x81ab0015}},	// [8a70] _vos_, _מעהר_, ارف_, مطاف_
  { {0xe60300f2,0x52d8004a,0xc87f0012,0x8b0b004f}},	//   ätää, ямую_, loß_, מִבֵ
  { {0x44391d7f,0x15fa000a,0x45fa000a,0xb5fa004f}},	//   _tos_, _והתע, _והתג, _ולתכ
  { {0xaadd005d,0xdee10033,0xc1040015,0x645d0012}},	//   _मिलक, вукi_, عوني, _umsi
  { {0x3ea50020,0x765e008c,0x4e95002b,0x57fc000a}},	//   _pilt_, _ympy, وشتر, מלאו
  { {0xf7740053,0xc2c40015,0xef74002b,0x4f080033}},	//   עקס_, _سيفي, ردنظ, янін_
  { {0x3ea50084,0x7c390050,0xc8790064,0xa294005e}},	//   _vilt_, _powr, luğu_, _чарі
  { {0x3ea50298,0x3cde000b,0x4b25005e,0xe81d000b}},	//   _wilt_, _गिरे_, дмив, _बोला_
  { {0xadf50661,0xda64002b,0xcdcb0015,0x8de50015}},	//   _опаш, کايي, _هذان_, _يكره
  { {0x8f680029,0x2d85005c,0x39453ee0,0x7d16002a}},	//   _عملك_, _tyle_, дног, łysa
  { {0x24893ee1,0xb22b02a3,0x7e633ee2,0x16220065}},	//   klam_, раiн, minp, माघर_
  { {0x25c6000b,0x7d7a000a,0x7e633ee3,0x6d433ee4}},	//   वर्ण, _ונעו, linp, myna
  { {0xba550063,0xfa350015,0x44f70061,0x7ae93ee5}},	//   _откъ, _يرتد, eç_, quet
  { {0xc87901e2,0x7e6329de,0x6f040061,0x46a30342}},	//   duğu_, ninp, çici, каяв
  { {0x6d433ee6,0x19ba000a,0x7e63005b,0x441604b5}},	//   nyna, _ומצב, iinp, мфат
  { {0x78b303eb,0xd7ff0045,0x7a3f0003,0x0000006a}},	//   ēgvā, şări_, _vêtu,
  { {0x6d430026,0x64bc0085,0x44f70061,0xf835006f}},	// [8a80] hyna, _očig, aç_, úšťa_
  { {0x63b6002a,0xeb92000a,0x24893ee7,0xe2970138}},	//   scyn, דָע_, alam_, дау_
  { {0x50ba0015,0x7e63008c,0xe8e00016,0x6e3a0012}},	//   زداد_, dinp, _trụy_, _rotb
  { {0xc8790064,0xb7db0053,0xd6cf002b,0x7d1c001a}},	//   buğu_, ַקצי, _حقی_, _ársi
  { {0xc8790061,0x8fa30033,0xe29a008b,0xbf64009a}},	//   cuğu_, ваце, _мам_, رگرو
  { {0x6467005c,0xdcba03fc,0x9757000a,0xc757004c}},	//   ąpił, ощи_, וינו_, וינץ_
  { {0x100a0015,0xc693000a,0x91e300af,0x0000006a}},	//   _وترى_, דאג_, _јосе,
  { {0x4f660015,0x515b000a,0x25de000b,0x5b140317}},	//   _قاذف, _וכלו, कृती_, емит
  { {0xb9e60036,0x6d430064,0xa3c1000b,0x321823f0}},	//   міни, ayna, ुरत_, _kary_
  { {0x2fc60035,0x7f3b000a,0x6d430034,0x5e260015}},	//   lbog_, _ועמו, byna, _تعرق
  { {0xbfa30092,0x24893ced,0x321802ff,0xc87f0012}},	//   hiề, ylam_, _mary_, toß_
  { {0xb906000b,0x872b0033,0x7b66024f,0x2fc602de}},	//   _पि_, оўга_, _отле, nbog_
  { {0xd78b003b,0x44da0264,0x4c9b000a,0xc87f0012}},	//   تخدم_, eď_, _ובאו, roß_
  { {0x3eb902c1,0x38603ee8,0x0a570058,0x61fe0546}},	//   _éste_, _emir_, _يشوع_, jfpl
  { {0x7588004a,0xb8860046,0xa5f8004a,0x24892239}},	//   дств_, _smíš, ьеру_, tlam_
  { {0xc2c50015,0x88c40046,0xd4980924,0x0d17004f}},	//   فيري, _vděč, дру_, וקלט_
  { {0x6d43005c,0x64930061,0x2fc6063b,0x8e270033}},	// [8a90] zyna, eçic, dbog_, цiлi_
  { {0xd14b0087,0x82150015,0x66bc000a,0x24893ee9}},	//   يشان_, عواص, _ומזה, slam_
  { {0x248901e2,0xc6780015,0x32180ea7,0x0000006a}},	//   plam_, _تحيط_, _dary_,
  { {0xf8b10008,0x26d91728,0x859a000a,0x2fc602de}},	//   אשׁ_, osso_, _משתו, gbog_
  { {0xe45600b4,0xdb020023,0x7e63099a,0xb3ba000a}},	//   _נישט_, _ngoà, tinp, _ממרכ
  { {0xef180010,0x645a0024,0xee3805d1,0x32183eea}},	//   ьмі_, ītie, мні_, _gary_
  { {0x55da0053,0x645a231a,0x61ea001a,0x51840033}},	//   פֿסנ, ūtie, ófle, _аута
  { {0x6d433eeb,0xf412000a,0x25ff000b,0x80a50015}},	//   ryna, ָ֤ה_, श्ती_, _أمرن
  { {0x2ef4010f,0x99f5005e,0x6d433eec,0x0000006a}},	//   _изтр, няні, syna,
  { {0x1eea002b,0x08c50663,0x0000006a,0x0000006a}},	//   _رومی_, нбон,   ,
  { {0xa3c1000b,0xf1b2000b,0xf86610b9,0xf115005e}},	//   ुरा_, _जलसन, евно, ддiл_
  { {0xc689000a,0xad1a000a,0x9d1a000a,0xdb0b02de}},	//   _הא_, _מוער, _מועט, _afgå
  { {0x7c2b03b0,0xf092000a,0xdcb10016,0xec36004f}},	//   _ingr, טנט_, _hủ_, _ראנר_
  { {0x8b3a0008,0xbb3a103d,0x38ca002b,0x2480002a}},	//   _מתנצ, _מעני, _کاوی_, woim_
  { {0xf202005d,0xe8f50015,0x04960033,0x26d93eed}},	//   र्फ़_, _أستخ, ераў, asso_
  { {0xd019002a,0xc952000a,0x7afb02b9,0x61fd0065}},	//   _nań_, _תמה_, otut, र्सौ_
  { {0x2c01005d,0x42260010,0xae00000b,0x24800125}},	// [8aa0] व्यू_, ндав, ल्डन_, roim_
  { {0xb77b013a,0x877b0008,0x98d3005d,0xf8d3000b}},	//   _מאפש, _מאפי, _दबाए, _दबाय
  { {0xd7640086,0x7afb0020,0xaf360086,0x32180769}},	//   _سنگی, htut, کرات, _vary_
  { {0x67243eee,0xdfcf0225,0x10160021,0x321800da}},	//   _krij, ميم_, عباد, _wary_
  { {0xc7d7000a,0x94230138,0x0000006a,0x0000006a}},	//   תוני_, _смяе,   ,
  { {0x2fc60134,0xdb020092,0x7c660086,0x290705d8}},	//   sbog_, _ngoá, کاتل, _opna_
  { {0xa3e4005d,0x9cca0010,0x2fc602de,0x6ce60033}},	//   _नया_, чыла_, pbog_, хіле
  { {0x67243eef,0x60fb000a,0x629e3ef0,0x70fb004f}},	//   _orij, _מהלק, lmpo, _מהלח
  { {0x88bc0089,0x7afb0035,0xdb1900b8,0x7ee60029}},	//   zvěd, gtut, _gewü, _سكان
  { {0xef170010,0x629e02f2,0x7c2b3ef1,0x12eb004f}},	//   _яму_, nmpo, _engr, הַטּ
  { {0x753a00b8,0x7afb003f,0xbd290015,0x67243ef2}},	//   ätzl, atut, _يأمل_, _arij
  { {0xc1730008,0xbb860015,0xe787004a,0x67242acd}},	//   טחת_, _كلاي, еуго, _brij
  { {0x4c3b000a,0xe7380033,0x672420f6,0x26d91728}},	//   _מתאב, ееў_, _crij, usso_
  { {0x27e001e2,0x67243ef3,0x8b8b000a,0x6d583ef4}},	//   _edin_, _drij, _מָוֶ, ozva
  { {0x25a500c0,0xdcfa0024,0x69b70008,0x19b7000a}},	//   äll_, _iztē, _אלוף_, _אפור_
  { {0x68e7002c,0x6d583ef5,0xb7d9002b,0x629e3ef6}},	//   ájde, izva, _کوکا_, empo
  { {0x88bc0089,0x2458004a,0xe1d90033,0xdc8b000a}},	// [8ab0] svěd, хать_, ддзі_, פְלָ
  { {0x6d580107,0xf770002b,0xd9f0000b,0x68e80079}},	//   kzva, _چای_, चलित_, ordd
  { {0xa2dd005d,0x442b01c2,0x6aaa00da,0x27e0008c}},	//   _पिक्, _tnc_, _miff, _ydin_
  { {0xe5360008,0xe8d70008,0x33950015,0x7afb002a}},	//   _סטרט_, תואר_, _للجز, ytut
  { {0x42990029,0xa858000a,0x41e70033,0x7ff40021}},	//   _ينجح_, עידה_, _піва, اسما
  { {0x8e853ef7,0xa0c50015,0x51870128,0x2bc90065}},	//   خلته, _ليسو, _зуба, रर्थ
  { {0x92a6005c,0x93c60011,0xa3d5005d,0x7cc40015}},	//   _dołą, sfăş, _सजा_, هزيم
  { {0xcf7b0029,0x7afb04ed,0x0c25000d,0x6aaa0034}},	//   _فإذا_, ttut, тмин, _aiff
  { {0xa3b9000b,0x200f007c,0x32cf002a,0x68e80034}},	//   _चलन_, megi_, nży_, erdd
  { {0x4a4500a4,0x200f3ef8,0x6aaa02de,0x92a6002a}},	//   тнов, legi_, _ciff, _gołą
  { {0xf1b20008,0x7afb3ef9,0x6aaa0376,0x67240085}},	//   יסי_, stut, _diff, _srij
  { {0x200f3186,0x672405fb,0x0d64006b,0x6aaa3efa}},	//   negi_, _prij, _съум, _eiff
  { {0xc8f8002b,0xe737042d,0xddd800bc,0x68e83ccf}},	//   وویچ_, вея_, lovš, ardd
  { {0x63bd00fb,0x67243efb,0x7ae90af5,0x31cb000b}},	//   _afsn, _vrij, mret, िरोध
  { {0x7ae90cd8,0x32cf005c,0x99320015,0x798a0034}},	//   lret, eży_, _نفوت, _gyfw
  { {0xc952013a,0x15ee005d,0x3f890024,0x6aaa0012}},	//   _כמו_, _जाकर_, ļauj_, _ziff
  { {0xfbd20008,0x7af600f2,0x200f002e,0x64a31bc8}},	// [8ac0] יתן_, _äytt, degi_, рата
  { {0xd6aa0029,0x200f007c,0x9f5f001a,0xa1c30121}},	//   _تدعم_, eegi_, _rauð_, ибуд
  { {0x69ce0084,0xe5720029,0xc693000a,0xd24f0015}},	//   ðbei, _خطة_, _דאז_, غنم_
  { {0x14d70008,0x90e50029,0x6946016f,0xddd83efc}},	//   _בוטל_, اسلن, _učeš, dovš
  { {0x92a60050,0x8eb30015,0x7df3002a,0xa0670054}},	//   _połą, لمنش, zęsł, њача_
  { {0xad650086,0x68e80026,0x975b000a,0x375b004c}},	//   گاهه, yrdd, ודנט, וכנד
  { {0x8d630054,0x621b000a,0x721b000a,0x6fb60021}},	//   ивље, _קולק, _קולח, _لمزا
  { {0x6aaa3efd,0x6b8b3efe,0x5c06005e,0x6d58003d}},	//   _siff, _bygg, тяка, rzva
  { {0xa0670124,0x2d8100b8,0xda7a0805,0x4fa3005e}},	//   _рата_, üher_, дян_, _витв
  { {0x3eb90467,0x539b0053,0x5ea603c4,0xdb1b002e}},	//   _ésta_, ויפו, _شمال, rauð
  { {0x3eab006f,0xdb1b001a,0x67d50bbb,0x7ae93eff}},	//   žitú_, sauð, лону, aret
  { {0x4bda00b0,0x0137000a,0x64930061,0xdd8f006e}},	//   _آباد_, דרטת_, eçin, _بوم_
  { {0xf8040010,0x7ae903b8,0x97140033,0x2d8c1ca6}},	//   шчэн, cret, амяц, _hyde_
  { {0xe944002b,0x25bf000b,0xcf93000a,0x200f1116}},	//   _مربی, ्रेण, שטש_, zegi_
  { {0x984f005c,0xc7c700d7,0x45d401c5,0x2a790030}},	//   jęć_, _испи, росс, ésbe_
  { {0x31cb005d,0x3eac0134,0xa8a40033,0x2c7a003d}},	//   िर्ध, _lidt_, _крык, bīde_
  { {0xb27512d2,0x6672002b,0x2d8c02de,0xab65003d}},	// [8ad0] глаш, شگیر, _lyde_, peļņ
  { {0x7aef0251,0xa6e3002e,0x5398004a,0x32190015}},	//   àcti, íðus, твуя_, عياد_
  { {0x7ae93f00,0x82a4135f,0xf1a720e6,0xc05b008b}},	//   zret, рште, тран, мід_
  { {0x25ff000b,0xae00000b,0x7ae93f01,0x0000006a}},	//   श्री_, ल्सन_, yret,
  { {0x9f050015,0xff500015,0x200f3f02,0xa2dd0065}},	//   اوتو, يخه_, regi_, _पिट्
  { {0x644d022d,0x7c95002b,0x2d8c02de,0xa6db001a}},	//   lkai, گشتا, _byde_, tyðj
  { {0x644d2543,0xd0d4006b,0x62853f03,0x3134030c}},	//   okai, _восъ, moho, _керр
  { {0xc172013a,0x2fd90086,0xd9bd005d,0x8d740015}},	//   _החל_, _سوئد_, ोर्ट, جاها
  { {0xac960029,0x6a850080,0x644d0a6d,0xfa900064}},	//   دنيا_, ллиа, ikai, ğünü_
  { {0x3f7a00b2,0xfa900061,0x644d008c,0x7bc90028}},	//   _אָבע, şünü_, hkai, sbeu
  { {0x644d3f04,0x2ba4000b,0x186a06b5,0x7ae93f05}},	//   kkai, खेबा, еани_, sret
  { {0x7ae913e1,0x0000006a,0x0000006a,0x0000006a}},	//   pret,   ,   ,
  { {0xfc16000a,0x64930061,0xf7720015,0x3b090bb1}},	//   _תקני_, tçin, صاح_, _чело_
  { {0x75d60029,0xd5b20021,0x64bc0091,0x644d0091}},	//   طيرا, صفر_, _ačia, ekai
  { {0x29190024,0xdb0b0134,0x79fa000a,0x86750033}},	//   āsas_, _afgø, _נלקח, рыяц
  { {0x644d0035,0x88bc0046,0x7c3b3f06,0x63b80046}},	//   gkai, svěc, njur, ěvno
  { {0x28d7000b,0x33d5005e,0x645a0144,0x032601b0}},	// [8ae0] _भौति, ріст, ètiq, ыдан
  { {0x7e1d005d,0xe805005d,0x62330001,0xa75b000a}},	//   पयोग_, ष्ठा_, беђу, _נדיר
  { {0xb5fb000a,0x00e61acb,0x7c3b001a,0x4fea15ee}},	//   _אליכ, ужен, kjur, емен_
  { {0x984f002a,0x7d16002a,0xd0950033,0x9ec60058}},	//   ręć_, łysk, ашчы, هزته
  { {0x442001e2,0x9f340036,0x6e460010,0xb7db0008}},	//   mdi_, релі, ледз, תקני
  { {0x62850574,0x64930061,0x44203f07,0xd25202be}},	//   coho, hçil, ldi_, _انس_
  { {0x4118000a,0x0caa004a,0x64930061,0xcd06006b}},	//   _בֵּא, нтии_, kçil, учли
  { {0x3ed60087,0x661e2b3c,0x5b240015,0x44203f08}},	//   _مقرر, _lapk, لفعل, ndi_
  { {0x78ad04ed,0xba5407c1,0xcfb7000a,0x9b6a0033}},	//   _riav, ивиј, _תלמי_, эшка_
  { {0x8f990063,0x64930064,0xaa530010,0xc333000a}},	//   _ръст_, eçil, йвыш, מוח_
  { {0x3237015b,0x61e3001a,0x629c0034,0x099403ae}},	//   אטין_, ónli, _mhro, ранџ
  { {0x228f0020,0x4d7b0b7b,0x44203f09,0x38c8002b}},	//   tükk_, _ארבע, jdi_, _یابی_
  { {0xa2b0014e,0xead403be,0x44203f0a,0x629c0057}},	//   _अंग्, _толь, ddi_, _ohro
  { {0xda080086,0x44203f0b,0x8f8b000a,0x7afd0144}},	//   _شيعه_, edi_, גְלֵ, àste
  { {0xa4d50191,0x644d022d,0xa9bb0008,0x8aab000a}},	//   робі, tkai, _אזור, _אֹהֶ
  { {0x644d0321,0x645a00c5,0x69da0223,0x24180088}},	//   ukai, ūtin, late, лосы_
  { {0x629c002d,0x644d013c,0xe805000b,0x6d4a0034}},	// [8af0] _bhro, rkai, ष्णा_, hyfa
  { {0x644d3f0c,0x4b7b0008,0x51f80080,0x629c3f0d}},	//   skai, תאמו, лную_, _chro
  { {0x212700a7,0xffd5008f,0xf4850086,0x34950001}},	//   ính_, аўля, _ناحی, _ванр
  { {0xa3d6005d,0x69da3f0e,0xae1d0065,0x35bf0065}},	//   हरण_, hate, _योजन_, ्रक़
  { {0xcee80029,0x69da3f0f,0x7d1a3f10,0x62853f11}},	//   هرون_, kate, _asts, poho
  { {0xb6bc0053,0x20d70002,0x64930061,0x69da3f12}},	//   עצוי, _مترج, içim, jate
  { {0xa3b9005d,0x2dd80029,0xe5f80008,0x69da099e}},	//   _चला_, ابهة_, אזור_, date
  { {0x6ee70086,0x1c450286,0x629c0264,0xf3f2000a}},	//   _مسئل, рним, _zhro, ַ֣ח_
  { {0x6d4a01e2,0x69da0026,0x34d2000b,0x7d1a15e7}},	//   ayfa, fate, _तब्द, _ests
  { {0xf41f00c0,0xc332000a,0xb307005e,0x09053f13}},	//   _skäl_, קוי_, тнiс, апон
  { {0x64930064,0x44203f14,0x64bc0160,0x2738005a}},	//   tçil, ydi_, _ačin, _ožná_
  { {0x38ca0074,0x186a087a,0xc60e000b,0x49980033}},	//   کایی_, тами_, ाज्य_, ытыя_
  { {0x6c840029,0x91d8000b,0x903a004c,0x2bc8070c}},	//   _النم, यरमै, דערה, _сухо_
  { {0x69da0b62,0xe9a5018d,0xdb190012,0x0000006a}},	//   cate, _калп, _bewö,
  { {0xd46a000d,0x287602bf,0x3213013f,0xe5a601e1}},	//   виве_, _выпр, dexy_, риви
  { {0x2b09005d,0x629c3f15,0x44203f16,0x7bdb02f2}},	//   _वहाँ_, _shro, udi_, nauu
  { {0x629c0112,0x62663f17,0xa3c7000b,0xe3b73f18}},	// [8b00] _phro, аваа, _उभर_, рбу_
  { {0x80e60015,0x7bdb0012,0x91e60129,0x4420088a}},	//   لأصل, hauu, роже, sdi_
  { {0xdb1900b8,0x463b004c,0x6fb60015,0x7bdb007c}},	//   _gewö, _סעטע, لمضا, kauu
  { {0x3fc6002b,0xf992000a,0x69da3f19,0x7bdb0072}},	//   شگری_, חרב_, zate, jauu
  { {0x6d4a0026,0x629c19a8,0x60c900bd,0x11d6008b}},	//   wyfa, _thro, _čeme, _вібр
  { {0xa116002b,0x9ce60054,0xf57a000a,0x9df803a7}},	//   _پورت, ацил, ֣רֶך, ункт_
  { {0x06370053,0xdff604f7,0x69da3f1a,0xde57005e}},	//   ינסט_, _вязь, vate, ращі_
  { {0x6d4a0034,0x8c430054,0x69da3f1b,0x0000006a}},	//   ryfa, жеће, wate,
  { {0xe4570008,0x69da0939,0xa08b000a,0xfa900061}},	//   ייקט_, tate, _יְמִ, şümü_
  { {0x228f0020,0x1efb000a,0x79a601b7,0x4efb05bd}},	//   tüki_, _בלמע, ирне, _בהמו
  { {0xa3d6005d,0x7bdb0012,0x98be0091,0x69da2a97}},	//   हरा_, bauu, kytą_, rate
  { {0x69da3f1c,0xcb67002b,0x6f023f1d,0x228f0072}},	//   sate, امیه_, otoc, rüki_
  { {0x98be0007,0x69da3f1e,0xd90e002b,0x6f023f1f}},	//   dytą_, pate, سیک_, ntoc
  { {0x999800dc,0xa3aa000b,0xddc30045,0x386b0034}},	//   űrő_, गइन_, minţ, sicr_
  { {0x24920026,0x6a9b000a,0x65952044,0x1a9b000a}},	//   flym_, _ששונ, саву, _שיוע
  { {0x6f023f20,0x7d57004c,0x91ad0016,0x545412d9}},	//   ktoc, בילד_, _đè_, овст
  { {0x212a002d,0xddc30011,0xa87c0008,0x289c0135}},	// [8b10] _arbh_, ninţ, _שאחר, _ביהא
  { {0x78b80064,0x11d90015,0xa2cd000b,0x31c70aa1}},	//   _kuvv, اواة_, दीग्, рсав
  { {0xdfd10029,0x69d80251,0x24550115,0x867c000a}},	//   كيا_, _meve, _هندس, _ברזו
  { {0x5fe7005e,0x69d83f21,0x0000006a,0x0000006a}},	//   ріжж, _leve,   ,
  { {0x53350053,0xdefb0080,0x7bdb0020,0x4fe8042b}},	//   _האָב_, тые_, vauu, рмін_
  { {0xc33200b4,0x9e640191,0xb2840010,0xddc30011}},	//   _זוך_, овід, _дыск, dinţ
  { {0xc2120008,0x7ae20024,0xd658000f,0x38693f22}},	//   _מהם_, _avot, שיות_, _omar_
  { {0x5578000a,0xeb99168f,0x859c000a,0xddc30045}},	//   יעון_, лий_, כשוו, finţ
  { {0x69d83f23,0xc5ff003d,0x395e003d,0xd438004f}},	//   _beve, ļēji_, ezts_, שטחי_
  { {0xaa35004a,0x7ae206c0,0x38693f24,0x98be0535}},	//   схищ, _dvot, _amar_, zytą_
  { {0x8d950029,0x644200f2,0xc7a9000a,0x5d850015}},	//   _الاش, öoik, _נב_, _الضل
  { {0x3d010050,0xa85603f1,0xcd96000a,0xf649000a}},	//   mów_, стој, _הדעת_, _אצ_
  { {0x6e2100df,0x8b680191,0x0f790053,0x3d01005c}},	//   _kalb, _київ_, ראָב, lów_
  { {0x69d80991,0x65c318dc,0x8f9a000a,0xb6a6067a}},	//   _geve, збра, טירי, сигл
  { {0x3d010050,0x98be0007,0x7bd900d9,0xe820000b}},	//   nów_, tytą_, _kewu, _बसपा_
  { {0x69d80111,0xab5d005c,0x88c40015,0xa6db001a}},	//   _zeve, waży, _بتول, eyðu
  { {0x3aba0053,0x7bd90509,0x3d01002a,0x04432e88}},	// [8b20] ָמענ, _mewu, hów_, четн
  { {0x3d010050,0xd9f9000b,0x98be0091,0x244e0046}},	//   ków_, ्भित_, sytą_, _mými_
  { {0x3d01005c,0x0219005e,0x24893f25,0xe4520058}},	//   jów_, шіть_, boam_, _فضح_
  { {0x3d010050,0xb69b3a16,0x6ee60015,0x753a0012}},	//   dów_, ntân, مستل, ätzu
  { {0x6e213f26,0x6f023f27,0x0000006a,0x0000006a}},	//   _balb, utoc,   ,
  { {0x471b0053,0xddc30011,0x44223f28,0xd6fb000a}},	//   טונג, vinţ, _hak_, רִאש
  { {0x644600df,0x3d01005c,0x44223f29,0x7ae20085}},	//   _koki, gów_, _kak_, _svot
  { {0xa3cb005d,0x64461168,0x91770053,0x4422037f}},	//   रुप_, _joki, _העלף_, _jak_
  { {0x64460007,0x23603f2a,0x10a30001,0x4e2a006b}},	//   _moki, nzij_, _хитн, _йоан_
  { {0xc333013a,0xddc304f9,0x6e96003b,0x3d01005c}},	//   פות_, rinţ, _الطا, bów_
  { {0x3d01005c,0x4422003e,0xddc30045,0x69d83f2b}},	//   ców_, _oak_, sinţ, _veve
  { {0x764800f2,0x44221e69,0xad1b000a,0x64463f2c}},	//   ödyn, _nak_, _תואר, _noki
  { {0x76450057,0xec77005e,0x69d83f2d,0xe787030c}},	//   _pohy, _упц_, _teve, суно
  { {0xa5f90001,0x7aef0077,0x78a6001a,0x442203f8}},	//   јеву_, ácte, amkv, _aak_
  { {0xe5730029,0xfa970008,0x661500bd,0xf4970015}},	//   سطس_, _הדגש_, rezk, مشرد
  { {0xb69b3f2e,0xc8c7002b,0x92b70015,0x6355005e}},	//   ctân, _اوين_, محطا, овбу
  { {0x32bb0029,0x3d01005c,0x61d90080,0xe2f9005e}},	// [8b30] ادرة_, zów_, имая_, резі_
  { {0x765c028a,0xf1a70a0b,0x1758004f,0x65953be6}},	//   chry, брен, _לסחר_, _мапу
  { {0xd1310029,0xf6520008,0x104b106d,0x672d01b2}},	//   بما_, _חצי_, ляди_, _hraj
  { {0x442200e8,0x7c22016f,0x64bc0085,0xddc3006f}},	//   _gak_, _naor, _očij, dinš
  { {0x3d01005c,0xcf240015,0x5f770015,0x69c10f21}},	//   wów_, كروي, حاضر, ycle
  { {0x3d010050,0xd0d50063,0xd336000a,0x26dc004c}},	//   tów_, _могъ, _ורשה_, נקומ
  { {0xed5938d1,0x660a0061,0xd5fc000a,0xfbd10015}},	//   рой_, _öfke, אפור, وتة_
  { {0x3d010050,0x27e90064,0x69c10026,0x0ae900eb}},	//   rów_, _ndan_, wcle, адий_
  { {0x3d010050,0xf4140008,0x0a390010,0xddc3006f}},	//   sów_, לפק_, ачны_, ainš
  { {0xda650191,0x3d01005c,0xddc80046,0xe9d91797}},	//   івни, pów_, _oldř, шко_
  { {0xf9910015,0x69c10287,0xd9451a9d,0x8e840015}},	//   ببة_, rcle, цени, _علمه
  { {0x7aee0064,0x69c10541,0x48fb000b,0xa3aa000b}},	//   üntü, scle, लंबो_, गेड_
  { {0xb69b1224,0x765c0e18,0x09e5017a,0x501a000a}},	//   rtân, thry, _долн, בורו
  { {0xe9390074,0x8aa728d2,0xb69b3f2f,0x9ae8000a}},	//   _نسبت_, _уред, stân, _הַקִ
  { {0x64463f30,0x94aa0015,0xb69b0045,0x9ce9000a}},	//   _poki, لطرق_, ptân, יַּ֖
  { {0x23600111,0xe8d6000a,0x3912002b,0x22943f31}},	//   tzij_, _ווקר_, _آويز, mäki_
  { {0x44220111,0x64460007,0xddc300bc,0xd25200c3}},	// [8b40] _vak_, _voki, zinš, ونر_
  { {0x236000bd,0xd196009c,0xb69b0045,0x43750350}},	//   rzij_, ошењ, ntâl, чуст
  { {0x644600df,0x04460286,0x27e90034,0x44223f32}},	//   _toki, _денн, _ydan_, _tak_
  { {0xdfcf0086,0xd00a239c,0x859b004f,0xddc3005a}},	//   نيم_, реде_, _כשיו, vinš
  { {0x245c0014,0x187b000a,0x987b004c,0x2905007c}},	//   _címe_, סטנב, סאנט, htla_
  { {0x64810024,0x7c2239c7,0xe2973f33,0x479b000a}},	//   rķie, _saor, _мая_, בינס
  { {0xf98700b0,0x998c005c,0x6ce6005e,0x8e830067}},	//   _آب_, zedł_, ціле, بلوه
  { {0xa4b7000a,0xcb0a0033,0x9c3806b3,0x0000006a}},	//   חלקה_, аход_, спит_,
  { {0xcf260086,0x2905005c,0x6fd0000b,0x3cf60065}},	//   _برزي, etla_, _ड्यू, _एमके_
  { {0x764800f2,0xd8f80036,0xaa87002b,0x7c220573}},	//   ödyl, бної_, ينيم_, _waor
  { {0x41bb0053,0x91bb0008,0xc1bb0053,0x929b000a}},	//   יציע, ימיי, ימיש, שיית
  { {0xc8670036,0x672d3f34,0x9ca50015,0x1dc60065}},	//   ітни, _praj, _فإنن, रुरत
  { {0x67470010,0xda66002b,0xa92701c0,0xdd1e01c0}},	//   цэнз, _واتي, _poží, níže
  { {0x8f9b000a,0x98be002a,0xaa5800c3,0x2bd20065}},	//   ייכי, zytę_, _دلتا_, सरका
  { {0xe5990036,0x27f60046,0xe46b045f,0x394302de}},	//   скві_, ácné_, ашал_, øjst_
  { {0xd6db005f,0x672d05e3,0xe3b90138,0x0000006a}},	//   _кто_, _traj, слач_,
  { {0x8c1b0008,0x24580080,0x02d900c3,0x43940d7a}},	// [8b50] סומי, цать_, صواب_, датс
  { {0xc7b4000a,0xbebd0091,0xa2280054,0x245c006f}},	//   _קבץ_, _krūv, ожђа_, _ríme_
  { {0xc015005f,0x7d0d005c,0xe2a6002e,0x34950001}},	//   змещ, łasz, íðan_, _наор
  { {0x351a000a,0xa98b000a,0xc8b5004c,0x14f40033}},	//   _פורנ, בָדִ, פּעה_, _ўзяў
  { {0xf43a009d,0xce950063,0x4ada000b,0x543a004c}},	//   _הגרמ, падъ, _मौलव, _הערא
  { {0x82d6000a,0xb2ba000a,0x29050264,0xa2ba000a}},	//   _מושג_, _למשר, ytla_, _למשט
  { {0xdfd51561,0x365c000a,0x29053f35,0x11450058}},	//   _новы, שכונ, xtla_, _عَرُ
  { {0xc57c0008,0x8027002b,0x0b45006b,0xa3e3000b}},	//   ירות, _برآم, знин, _नजफ_
  { {0xfaf10029,0xf202000b,0xddeb0015,0x5ac60174}},	//   رثة_, र्क़_, _نراه_, плым_
  { {0x8f88000a,0xba750015,0x5d850015,0xb3650033}},	//   _וְעֵ, ثابت, _فلذل, ўнiч
  { {0xdcef0007,0xbd6b0ea6,0x6b82364d,0x0000006a}},	//   _įdėt, _трае_, _exog,
  { {0x31560053,0xc156000a,0x98160058,0x787601ec}},	//   פירן_, פשרו_, أبدا, kšve
  { {0x69cc005d,0xd5b80024,0x3bba000a,0xdc9a000a}},	//   _द्वी, žām_, _המנד, _פינל
  { {0xfe790089,0x7aba000a,0x35c70054,0x98e50015}},	//   _svůj_, _פצצו, згро_, _فكتو
  { {0x64a6008f,0xceb201e4,0x2cc9000a,0xae00000b}},	//   зава, תים_, מֶּ֑, ल्टन_
  { {0x98a3033d,0xd4670054,0xe73a004a,0x0000006a}},	//   _пище, писе_, _геи_,
  { {0xf8b3000a,0x91ba0015,0x0877004c,0xb8fe0157}},	// [8b60] _אשה_, مطار_, _מעקט_, दी_
  { {0x422309a7,0x0594002b,0x637901c6,0xc1d60065}},	//   ндув, _يادگ, істр_, धरेग
  { {0x9556002b,0xd00f0033,0xfe790046,0x55bb000a}},	//   _رخدا, нф_, _tvůj_, _למיו
  { {0xa06a0001,0xc6fa000a,0xd8d6004c,0xdd1e0046}},	//   љада_, ֶלֶך, פונט_, tíže
  { {0xddcf0089,0x90290015,0x13b7004f,0x93b7004f}},	//   _řeše, تألف_, _מהכל_, _מלכו_
  { {0xad260015,0x539b000a,0x225a0015,0xdd940174}},	//   كربو, _ליכו, _السد_, малы
  { {0x361b000a,0xbd18005e,0xfe090015,0xf2a3006b}},	//   מוסד, іжих_, تغنى_, _чирп
  { {0xd0070036,0x321a005c,0x9e660086,0x244e01b2}},	//   _несе_, lepy_, _کارن, _týmu_
  { {0xcb070029,0xaae60029,0x5d86009a,0xdc2a009a}},	//   كيين_, أسبو, _کلال, لسکه_
  { {0x5e250058,0x61fe3f36,0xc986226f,0x0000006a}},	//   _يعلق, ngpl, зуми,
  { {0x3ec20007,0xfe45002b,0xd257000a,0x0000006a}},	//   ųstą_, _تکنی, פשטה_,
  { {0x6d3b000a,0x4cbb000a,0xc19b000a,0xbb4604ae}},	//   _לתבנ, _המאג, משיי, _неек
  { {0x2bd2014e,0xc053000a,0x6afa004f,0x0000006a}},	//   _ध्या, גזר_, _הִ֔ו,
  { {0x0f57000a,0x19580174,0x95b80058,0x99160058}},	//   ליכם_, _малы_, كافأ_, _فبعض
  { {0x89eb000a,0xba9b000a,0xb4950054,0x0000006a}},	//   _הַחֵ, _הסגי, дивљ,
  { {0x95840050,0xe97b0008,0x3f9a005c,0x54990033}},	//   _łącz, _לנוש, ępuj_, іваў_
  { {0xa2b50191,0xe3bf0077,0x68fa3f37,0x0000006a}},	// [8b70] дбач, _caña_, lutd,
  { {0xe3b00029,0x93780015,0xc1e80033,0x51ab004a}},	//   طرق_, أصفر_, зьце_, бъем_
  { {0xa1670001,0xa1190015,0x41190067,0x02440015}},	//   чњак, تقاط_, تياج_, عَمَ
  { {0x68e7006f,0x90550033,0x0000006a,0x0000006a}},	//   ájdi, ьвец,   ,
  { {0x8ee80036,0x44293f38,0xaec4005e,0x44393f39}},	//   змів_, mda_, ебіл, _ins_
  { {0x999e0007,0x479c0053,0xef180484,0x44293f3a}},	//   nktų_, ציגס, ямі_, lda_
  { {0xc10500e5,0x7de40015,0x9e320004,0xcc890015}},	//   _توزي, رسوم, тејч, ينته_
  { {0xcac90080,0xbd180036,0xf5381282,0x81c70024}},	//   огие_, яції_, לטור_, _dzēš
  { {0x99f50010,0xdb090064,0x64930061,0x41e1000b}},	//   мяні, _önüm, lçis, _फ़ास
  { {0x442900f2,0x1dc6000b,0x99d4005e,0x1a65002b}},	//   hda_, रुआत, нююч, بیتی_
  { {0x442900b6,0x44390ec6,0xd5b80024,0x245c002e}},	//   kda_, _ons_, žāk_, _líma_
  { {0xc5e90dab,0xfb150029,0x2fdf00aa,0x644b007c}},	//   _כד_, _يواج, _jeug_, ögil
  { {0x61fe00c0,0xbebd0024,0x44293f3b,0x7c290034}},	//   ygpl, _grūt, dda_, mder
  { {0x3ebf022d,0x44393f3c,0xda0e0092,0x44292512}},	//   _muut_, _ans_, _hỏng_, eda_
  { {0xe96905ae,0x7afb0607,0xba280115,0x4439007c}},	//   _файл_, luut, _رسوم_, _bns_
  { {0xf99200f3,0x44293f3d,0xf4950248,0x44390059}},	//   _שרה_, gda_, ерую, _cns_
  { {0x7afb022d,0x3ebf00dd,0xae1d005d,0x2c0f000b}},	// [8b80] nuut, _nuut_, फ़ान_, थ्यू_
  { {0x44393f3e,0xda0e0092,0x44260060,0x7c29008c}},	//   _ens_, _lỏng_, žo_, hder
  { {0x27e0018b,0xa5d4005d,0x661c3f3f,0xf5060033}},	//   _kein_, _ब्यौ, merk, _ўзмо
  { {0x7afb022d,0x7c29230a,0xc2090008,0xe3fa002b}},	//   kuut, jder, יה_, _بعدش_
  { {0x27e000b8,0xcb1c000b,0x2d8500da,0x7afb008c}},	//   _mein_, _बैंड_, _axle_, juut
  { {0x27e00d4f,0xa2e30180,0xcfa9002b,0x9dba0033}},	//   _lein_, _јорд, سانم_, цыду_
  { {0xda0e0016,0xeca60004,0x2ee601c2,0xac94005e}},	//   _bỏng_, мјин, ssof_, накш
  { {0x32c40064,0x27e005f7,0x67243f40,0x81c8003d}},	//   _köy_, _nein_, _osij, spēļ
  { {0x1dcf021e,0x661c20a5,0x4e06004a,0xeb970054}},	//   _स्वत, kerk, _озаб, мић_
  { {0xdb220050,0x44293f41,0x314a000a,0x8d560e1a}},	//   _źród, zda_, ַתָּ, _отеч
  { {0xeaaf0029,0x44290690,0x61e1007c,0x67240046}},	//   جعي_, yda_, _õlle, _asij
  { {0x286b0036,0x7afb3f42,0x26c002b9,0xf1b3000a}},	//   ірно_, buut, _buio_, כסת_
  { {0x27e01579,0xe820000b,0xa2be000b,0xdc8b000a}},	//   _dein_, _बसरा_, _वूल्, _וְגָ
  { {0x4429005c,0x661c3f43,0x999e0091,0xdb9b000a}},	//   wda_, gerk, uktų_, _וסדר
  { {0xa3b1005d,0xceb8005c,0x245c002e,0x44390273}},	//   टेन_, _mię_, _síma_, _pns_
  { {0xd5b80a47,0x64930064,0x44293f44,0xb882006f}},	//   ься_, eçir, uda_, _žíva
  { {0xa3cb005d,0x6e3a016b,0x44390012,0x92590004}},	// [8b90] रुष_, _ontb, _vns_, паат_
  { {0x91e40054,0x64930061,0x6d4501be,0xeab4000a}},	//   кође, tçis, ähak, תִֽי_
  { {0x25d60008,0xeab10008,0x3ff50015,0x66740015}},	//   _אותן_, רֹן_, فكار, _جدير
  { {0x245c0084,0x603e0011,0x2c7a003d,0x44393f45}},	//   _tíma_, _rămâ, bīdi_, _uns_
  { {0xef0e0010,0x229400c0,0x69ca3f46,0x03d6000a}},	//   ым_, täkt_, _offe, _רושם_
  { {0xceb8005c,0x603e0011,0x7afb00f2,0xdce80061}},	//   _cię_, _pămâ, vuut, _azdı
  { {0xdc3a0064,0x7c290024,0xcce40015,0xbebd1147}},	//   _açıs, tder, نسيي, _prūs
  { {0x661c0014,0x229400c0,0x4c920001,0x61e5056c}},	//   zerk, säkt_, лијс, lahl
  { {0x8ed80029,0x3ed90086,0x7c290592,0x661c02f2}},	//   _يذكر_, _رواج_, rder, yerk
  { {0x7afb022d,0x27e03f47,0xfeb80029,0x39450c71}},	//   ruut, _sein_, _قالت_, еног
  { {0x2d8004f9,0x7afb3f48,0x661c146d,0xc236000a}},	//   şier_, suut, verk, גרתו_
  { {0xed5600b2,0x661c3f49,0x7afb0e95,0x5d640015}},	//   _אבער_, werk, puut, _جُمْ
  { {0xe81f000b,0x61e5001a,0x2cad3f4a,0x27e03f4b}},	//   यज़ा_, kahl, mmed_, _vein_
  { {0x443e00dc,0x7ae93f4c,0x27e00012,0xe3bf0077}},	//   _őt_, mset, _wein_, _baño_
  { {0xa9790053,0x7ae93f4d,0x845a067a,0x61e50d89}},	//   _מאַכ, lset, прат_, dahl
  { {0x46ea010f,0x7bc93f4e,0xa2d60015,0xe3bf0077}},	//   _един_, nceu, فيرت, _daño_
  { {0x2cad003e,0xd9f3005d,0xa87b0008,0xd38705c4}},	// [8ba0] imed_, _आयात_, _מרקח, ейте_
  { {0x99850014,0x2c7a003d,0x7ae93f4f,0x2cad3f50}},	//   lelő_, rīdi_, iset, hmed_
  { {0x2cad0020,0x7ae90ac0,0xf77f016e,0x6e3c0144}},	//   kmed_, hset, maça_, _òrbi
  { {0xceb80f9a,0x89960053,0x375a000a,0x68fc0144}},	//   _się_, ײכנס_, ּכַד, àrdi
  { {0x2cad0005,0xc7d7000a,0x8fa30033,0x645a003d}},	//   dmed_, גוני_, гаце, ūtis
  { {0x248001a3,0x877b004c,0x3860001a,0x2ca63f51}},	//   lnim_, האני, _llir_, _shod_
  { {0xcd930001,0xf6530135,0xe1950033,0x6e2800bc}},	//   лашћ, רצו_, _артэ, _vadb
  { {0x7ae9002e,0xa25b0016,0x91d80065,0x6b990416}},	//   fset, _tuôc, यरकै, _bywg
  { {0x7ae90084,0x6e2801c2,0xbd8a002b,0x3f810061}},	//   gset, _tadb, _کنان_, şhur_
  { {0x2cad00da,0x7e290015,0x9962006f,0x4a542f04}},	//   amed_, _يسلف_, ríža_, ткос
  { {0x67d50036,0x88bc0089,0x7ae93537,0x386002d2}},	//   кону, jvět, aset, _blir_
  { {0x61e500b8,0x81570053,0xa3b1021e,0x24800263}},	//   zahl, גסטע_, टेड_, jnim_
  { {0x41e1014e,0xdc8b0008,0x24802aef,0x61e50061}},	//   _फ़लस, _צְבָ, dnim_, yahl
  { {0xbb3b00a3,0x9bb7000a,0xcf93004c,0x38720034}},	//   _מעדי, _נהגה_, רטש_, _emyr_
  { {0xceb300b2,0x65952c0c,0x89330002,0x75880eaf}},	//   טיש_, таву, _معيا, еств_
  { {0x299b0008,0x38600026,0x999b0008,0xcd97000a}},	//   _מסומ, _glir_, _מבוט, גדלת_
  { {0x57f40010,0xdc8b000a,0x61e53f52,0x0000006a}},	// [8bb0] _спыт, לְמָ, tahl,
  { {0x7afd0251,0x2cad00bc,0x877c000a,0x24803f53}},	//   àsti, zmed_, _מאחי, anim_
  { {0xdfd10070,0x61e51430,0x24800263,0x15e6000b}},	//   ليا_, rahl, bnim_, _क़तर_
  { {0xf9930053,0x248006c0,0x8f7500e2,0xf8b2000a}},	//   ארע_, cnim_, кулі, ֑שׁ_
  { {0xd9ad005d,0x4f580036,0x442b002c,0xf0b8002b}},	//   _घण्ट, ницю_, _iac_, رامش_
  { {0x03760008,0x644f002c,0x998500dc,0x7ae92b60}},	//   _יתרת_, _hoci, zelő_, vset
  { {0xfc31003b,0x2cad0020,0x8d620080,0xbe980029}},	//   لحة_, tmed_, ивше, رضها_
  { {0x63a2005c,0x7ae93f54,0x442b3f55,0x8d74009a}},	//   żone, tset, _jac_, داها
  { {0x2cad0aa0,0x88bc0046,0x1c420256,0x7bc90003}},	//   rmed_, zvět, рным, rceu
  { {0x248001a3,0x442b3f56,0x644f221f,0x7ae93f57}},	//   znim_, _lac_, _loci, rset
  { {0x99850030,0xfe6e002b,0x7ae93f58,0x3a3c02ad}},	//   telő_, _بگن_, sset, _dnvp_
  { {0x442b0026,0x7ae93f59,0xc689000a,0x070a0015}},	//   _nac_, pset, _וא_, ويجي_
  { {0x24800a00,0x8c28000a,0x9b92002b,0xcc56000a}},	//   vnim_, _רֵעֵ, _پلوت, _שבני_
  { {0x7c2b0084,0xf1b1005d,0x2369005c,0x96760010}},	//   _hagr, जधान, dzaj_, тымі
  { {0x442b3f5a,0xf77f0527,0x24801367,0xd4f508f0}},	//   _bac_, raça_, tnim_, ляты
  { {0xccf20008,0x644f2ade,0x141a0015,0x03a6005e}},	//   יכל_, _coci, بيرة_, вибо
  { {0x130a008f,0x88bc0089,0x248001a3,0xa3e3000b}},	// [8bc0] ьнай_, svět, rnim_, _नजर_
  { {0xa6e2002e,0x248001a3,0x7c2b0613,0xd263005e}},	//   íðub, snim_, _lagr, акуй
  { {0x442b0011,0x24800263,0x236900bc,0x600a0418}},	//   _fac_, pnim_, azaj_, днем_
  { {0xc0590010,0xd0100029,0x7e610932,0x30a5005e}},	//   ніі_, صلت_, _allp, грів
  { {0xbe8a0001,0x44203f5b,0x2369002a,0x1eaa0015}},	//   мске_, mei_, czaj_, واتي_
  { {0xdce10064,0x765c00dd,0x9757000a,0x44203f5c}},	//   _aylı, nkry, כינו_, lei_
  { {0xc5f30008,0x9e650018,0xc0e6005e,0x27f20034}},	//   בדו_, دانن, _шовк, _odyn_
  { {0x91bf0023,0x6481003d,0x88bc0046,0x10a60585}},	//   _đủ_, eķij, zvěs, _рибн
  { {0xaf060127,0x7c2b0034,0xae160015,0x5b030015}},	//   _шпал, _dagr, _لذات, لِيم
  { {0x7c2b002f,0xdb1100dc,0x2c7a003d,0x5a33030c}},	//   _eagr, ágán, vīdu_, аньт
  { {0xdd1f002c,0xbd460087,0xa257000a,0x01fb000a}},	//   píšt, _جناي, דביק_, ופיל
  { {0x2c0b0086,0x6d790053,0x5d79004c,0x44203f5d}},	//   _يعنی_, _אָנװ, _אָננ, jei_
  { {0x6d580007,0x27f20026,0x442b002d,0xec13002b}},	//   lyva, _ddyn_, _rac_, _خوند
  { {0x7c202635,0x89d6005e,0x2c7a003d,0x7c2b2aef}},	//   lemr, _рідш, rīdu_, _zagr
  { {0xc1e0005d,0x25a500c0,0x241904ab,0x64c50015}},	//   _पड़ेग, åll_, новы_, ايرل
  { {0x44203f5e,0x629e0a64,0xe4a7012e,0x67650015}},	//   gei_, elpo, трго, _مُعل
  { {0x6d580091,0xe1d90033,0x52150449,0x644f3f5f}},	// [8bd0] hyva, едзі_, лдат, _voci
  { {0x91f40015,0x236909bb,0x7648008c,0x61f80033}},	//   لأما, rzaj_, ödyt, кнуў_
  { {0xf77004b6,0x21270023,0x44203f60,0x50f50001}},	//   _های_, ình_, bei_, узет
  { {0x3207005c,0x442008a5,0x3cf8000b,0xf8b2000a}},	//   żny_, cei_, ैंने_, ֖שׁ_
  { {0xd9e3005d,0xdd100107,0x1eea002b,0x33fa000a}},	//   _ग़लत_, výše, فونی_, _אהרנ
  { {0xfebb002b,0xa0c50040,0x3b0d3f61,0x7c2b3f62}},	//   ذاشت_, _ميسو, vteq_, _sagr
  { {0x7c2b18a6,0x0ffb0015,0x0000006a,0x0000006a}},	//   _pagr, _يعرب_,   ,
  { {0x6c350115,0x0c250658,0x201b0015,0x69da0012}},	//   افظا, умин, _تتسع_, ebte
  { {0x786602c1,0xf77f016e,0x765c002a,0xfe790046}},	//   _jóve, daço_, ykry, _dvůr_
  { {0x7866001c,0x6f1b0064,0x7d2800f2,0x1dc7000b}},	//   _móve, _ipuc, ässä, _ललित
  { {0x442011f9,0x37e600af,0x0000006a,0x0000006a}},	//   yei_, лонг,   ,
  { {0xbbeb0086,0xe43c0089,0x5b2500e6,0x5b350087}},	//   _آرام_, _příč, _مفصل, _معتر
  { {0xf0920008,0x7866001a,0xe7370174,0x8ae7005e}},	//   מנט_, _nóve, гея_, _ріел
  { {0x38ca0086,0x4420020d,0x59550015,0xa25b0016}},	//   بایی_, wei_, _مخبأ, _suôn
  { {0x0555005e,0x69fa000a,0xe8f50015,0x7cd1003d}},	//   аття, _טלסק, _إستخ, _dārg
  { {0x765c020a,0xd91a000a,0xb956000a,0x78660077}},	//   skry, _נופל, _תיקח_, _bóve
  { {0xa25b0092,0xf1fa0021,0xc7d7000a,0x0676005e}},	// [8be0] _vuôn, فعات_, _גופי_, _буня
  { {0x44203f63,0x26c40046,0x61463f64,0x0000006a}},	//   sei_, ímou_, леза,
  { {0xea760053,0xe3b20086,0x7d16005c,0x7afb002d}},	//   נגער_, _گرد_, łysz, hrut
  { {0xb4fb0135,0xd5b80024,0xd46a0001,0x7afb3f65}},	//   _אפטי, žās_, _чиме_, krut
  { {0xe3b20086,0x2611000b,0xcef603ae,0x7afb3f66}},	//   _درد_, द्वी_, учењ, jrut
  { {0x11da0029,0x6d580007,0x644b007c,0x6dc3006b}},	//   _سورة_, tyva, ögiv, бсъж
  { {0x2cc9002c,0xd29b000a,0xd24f0021,0xdd9000c3}},	//   _ľudí_, _נשלט, _عنف_, غوب_
  { {0xb69b0045,0x2c7a003d,0xeb4a0a23,0x7afb2dfb}},	//   ntâr, vīds_, ечок_, frut
  { {0xe4570053,0xa0670001,0x68f50057,0x307b000a}},	//   טיקט_, _сата_, ázdn, _נאמנ
  { {0x7bdb0035,0x6d580007,0x8f1b000a,0x69da3f67}},	//   abuu, pyva, _אומת, ubte
  { {0x69da0012,0x3cfa0015,0x7ea40144,0x0000006a}},	//   rbte, _سعاد_, lòpo,
  { {0xc173000a,0x7afb02d2,0x4bda0015,0x3ebe1ca2}},	//   מחת_, brut, _أباد_, _hitt_
  { {0x7c93003b,0x70e1000b,0xbbe0000b,0x87070033}},	//   _النص, _पब्ल, नरीक, ыяне
  { {0xcf930008,0xb604005e,0x6d49002a,0x26e5000b}},	//   מטר_, йяск, ślał, _कबीर_
  { {0xf77f001c,0x14c7002b,0x3ebe3f68,0x4a5b000a}},	//   paço_, اهری_, _mitt_, _אדגו
  { {0x13d50010,0x3ebe0f3e,0x7ae23f69,0x248d0796}},	//   ржаў, _litt_, _kwot, čemo_
  { {0x42750010,0xc7d8000a,0x94a80054,0xbec7003d}},	// [8bf0] агас, _עוזי_, утра_, olīš
  { {0x2bdb005d,0x7aef1a30,0x6b7b000a,0xc398005e}},	//   _ग्नू_, ácti, גרמנ, укує_
  { {0xe7960086,0x76ba000a,0x8a17000a,0xf1a72935}},	//   _مایک, _שמתפ, רחבו_, уран
  { {0x897b0053,0x8fb90029,0x7cd1003d,0x7fb900c3}},	//   עראצ, نهاء_, _jāre, نهار_
  { {0xb817005d,0x20090024,0x644d00dc,0x2aab02de}},	//   ध्यम_, ļai_, mjai, løbe_
  { {0xacf50001,0x62833f6a,0x62870030,0x7cc30030}},	//   ачиј, čnos, _ujjo, _lőre
  { {0xd658013a,0x3ebe3f6b,0xa63c0008,0x1d06006b}},	//   ריות_, _ditt_, תגור, аещи_
  { {0xeb9918a9,0x4c350010,0x7afb3f6c,0x3ebe05d8}},	//   кий_, рэкт, trut, _eitt_
  { {0x644d00f2,0xdb190026,0x50643891,0x7ae20034}},	//   ijai, _sgwâ, _утра, _cwot
  { {0x3ebe003c,0x6285003c,0x7cd10024,0x239c0053}},	//   _gitt_, nnho, _pārd, עבזײ
  { {0x4a420036,0x7afb01a7,0x68460256,0x6e3a000a}},	//   інюв, srut, анна, _שתעד
  { {0x78ad03af,0x7cd10048,0x628500b8,0x61e70134}},	//   _chav, _vārd, hnho, _lejl
  { {0xcf9200b2,0xe73a0001,0x7bda000a,0x644d1814}},	//   ַטל_, њег_, _סקסו, djai
  { {0x61e70089,0x5f08000b,0x62852123,0x75d60015}},	//   _nejl, _समस्_, jnho, شيرا
  { {0xa9660036,0x7d030e8a,0xca7a000a,0x69c32d2d}},	//   _вища_, nuns, _שנצט, _igne
  { {0xdd010089,0x644d00dc,0x26c409ae,0xa50703ae}},	//   _štěs, gjai, ímos_, јета_

  { {0xb89b0008,0xe29a000d,0x33d50010,0xa3b1021e}},	// [8c00] _בבקש, ваа_, сіст, टेल_
  { {0xc2430c9a,0xa75b000a,0xb69b0045,0x11d6005e}},	//   онук, _סדיר, luân, ріар
  { {0xd5fb0008,0x15fb000a,0x6aa13f6d,0x61e73f6e}},	//   _בפיר, _בהיע, illf, _dejl
  { {0xd0950033,0x644b007c,0x3ebe2b04,0xb69b0045}},	//   бшчы, ögit, _sitt_, nuân
  { {0x61e73f6f,0xe3b2002b,0x6e233f70,0x1df8004a}},	//   _fejl, _گرگ_, fenb, гелы_
  { {0x6e233f71,0x20060034,0x8cf40015,0x7ea40144}},	//   genb, sgoi_, مكتش, ròpo
  { {0xafe6008f,0xddc8005c,0xc5f30008,0x721b039e}},	//   _вобл, _podł, קדה_, _שולח
  { {0xe7f2005d,0x7c930021,0x44323f72,0x7cc30030}},	//   _आएगा_, يشيا, ndy_, _bőrb
  { {0xcb070029,0x15e6005d,0x6ffb000a,0x6e233f73}},	//   ليين_, करार_, _שהמפ, benb
  { {0xf1aa005d,0x2d96058f,0x44323f74,0x539b000a}},	//   _करान, _крес, hdy_, כיפו
  { {0x443228cc,0xc2370008,0x7cd10024,0xaab70015}},	//   kdy_, בריו_, _pāre, جدير_
  { {0xdd7b0008,0x69c30293,0xbd5b000a,0xd0f7000a}},	//   _בטבל, _egne, _שכאש, סמכת_
  { {0x7ad40225,0x62850026,0x44320ab0,0x629c3f75}},	//   _اقتص, ynho, ddy_, _okro
  { {0x44323f76,0xaa570432,0x7afd3f77,0x60c002dc}},	//   edy_, _вишу_, áste, _limm
  { {0xa4d50036,0x5887065e,0x644d03ff,0x61e70030}},	//   собі, _выпа, tjai, _rejl
  { {0x60c000b8,0x613000dc,0x443210ec,0x49bb000a}},	//   _nimm, zólá, gdy_, _במוס
  { {0xa3b1014e,0x644d00f2,0xb867002b,0x31c736d4}},	// [8c10] टें_, rjai, _ماکو, асев
  { {0xfe05005d,0xeb91000a,0x479c000a,0xcad7000a}},	//   _राइस_, הָב_, _ביחס, יומת_
  { {0x61e70134,0x61130089,0x644d00dc,0x7fd5042b}},	//   _vejl, dělá, pjai, білі
  { {0x9ef50029,0x27e90493,0x5be00065,0x7d03005b}},	//   مستش, _jean_, नरोव, vuns
  { {0xde590036,0x53340080,0x27e904d0,0x238a002c}},	//   ладі_, _деят, _mean_, čujú_
  { {0x8e080036,0x27e91740,0x98a80046,0x7ead006f}},	//   инів_, _lean_, _brně_, kúpe
  { {0x40350063,0xbd6b0063,0x60c0002e,0x998c00dc}},	//   _левс, ърде_, _fimm, kedő_
  { {0x7cd10048,0x213e002d,0x30850029,0x20850015}},	//   _pārb, _átha_, _الرف, _الرّ
  { {0x2010002c,0x98bf0091,0x7d032a00,0x6e233f78}},	//   íliž_, lytė_, suns, penb
  { {0x6aa1003c,0xaae40015,0x60c03f79,0x44321837}},	//   ullf, آسيو, _zimm, zdy_
  { {0x443229ea,0xd90c002b,0xb69b016e,0xbc1901c6}},	//   ydy_, نیو_, tuân, _білі_
  { {0x7d7a0053,0x245c002e,0x9f440003,0x0000006a}},	//   _גרעג, _tími_, _semé_,
  { {0x27e93653,0x443201c0,0x8c16012c,0x7783009b}},	//   _dean_, vdy_, _طيور_, зляз
  { {0xa3bd005d,0x6f7a0053,0x3f7a0053,0xfe67002b}},	//   ेखन_, אָלג, אָלע, سد_
  { {0xba740029,0x66030033,0x33f601c6,0xe5a6018d}},	//   _بانت, япра, йчас, сиви
  { {0x78760024,0x29051636,0x3958007c,0x232a0fea}},	//   kšvi, mula_, ärse_, лоби_
  { {0xcad5000a,0xc2e90015,0x61ea001a,0x29053f7a}},	// [8c20] מוּת_, لعلم_, ðflo, lula_
  { {0xd9f9005d,0x200d0045,0xb7d7002b,0x63a2002a}},	//   ूलित_, _acei_, _پویا_, żono
  { {0xd657000a,0x9657000a,0x62833f7b,0x290503f2}},	//   _היית_, _השיא_, čnop, nula_
  { {0x3a253f7c,0x629c002a,0x351b000a,0xcf46106c}},	//   help_, _wkro, _גוטנ, йней
  { {0xa6fa000a,0x11d6008b,0xa0670054,0x29053f7d}},	//   רִ֣י, _гібр, љача_, hula_
  { {0x412a0191,0x3a25003c,0x5be0005d,0x29053f7e}},	//   _його_, jelp_, नर्व, kula_
  { {0x60c001d1,0xc27b0053,0x30d8000a,0x64930061}},	//   _timm, _ערלי, _כַּע, eçiy
  { {0xbf4d0089,0x00f70008,0xd0f7000a,0xcefd0061}},	//   _šířk, _למלך_, _למלת_, üğün_
  { {0xfbcf00e6,0x6f66017f,0x09b2000b,0x7cd1003d}},	//   رتي_, _уваз, ुख्य, _pārc
  { {0x7f3b0053,0x27e93f7f,0x3e86002b,0x7ead006f}},	//   _געמו, _sean_, _اشرف, túpe
  { {0x27e90020,0x6da60087,0x6e930115,0x929b000a}},	//   _pean_, _امام, _علما, ריית
  { {0x48670063,0x6ca60087,0xc8673f80,0x41bb004c}},	//   съоб, _اصطل, стои, טציע
  { {0xac970029,0x27e91233,0x5bc30015,0x29053f81}},	//   _اننا_, _vean_, _عقول, aula_
  { {0x45d4096d,0xee2e00e2,0x29053f82,0x3cef0065}},	//   зорс, днi_, bula_, ींचे_
  { {0x7cf80008,0xba170008,0x27e93f83,0x28040046}},	//   יִּק, _החוץ_, _tean_, ásné_
  { {0x985d0050,0x73d9000d,0x94050086,0x9cd7000a}},	//   _błąd_, рдар_, توره, מולה_
  { {0xb7dc0053,0x672d003f,0x44980033,0x7bcb000a}},	// [8c30] _עקזי, _usaj, ёвую_, אֶבֶ
  { {0x754800dc,0x02a70174,0x332900da,0x98bf0073}},	//   ószí, ёрам, rwax_, tytė_
  { {0x50b90086,0xc05b008b,0x6115005e,0x38692e25}},	//   لگرد_, лід_, юджу, _klar_
  { {0x3e6b00cb,0x37fc000a,0xb7fb000b,0xf0b8006e}},	//   _møte_, ָּׁב, ्लिम_, مانش_
  { {0xddc50191,0x4e95002b,0x5f050033,0xa6fb000a}},	//   обли, يشتر, ізка, אִ֔י
  { {0xdce80064,0xc2c40015,0x6e94005e,0x539a000a}},	//   _aydı, _ريفي, пичу, _כירו
  { {0xe80a005d,0xb7fb005d,0xde940029,0x2489001c}},	//   _वाला_, ्लाम_, أجنب, onam_
  { {0xc57c000a,0xf8c90016,0x64930061,0x78760091}},	//   טרות, _bẩn_, tçiy, pšvi
  { {0xf8c90092,0x290500aa,0x248901ec,0x5ac900af}},	//   _cẩn_, wula_, inam_, јлом_
  { {0x38693f84,0xc87f0012,0xba750015,0xda09002b}},	//   _alar_, eiß_, تابت, جيده_
  { {0xc27a000a,0xc7a9000a,0x09020033,0xc9a90432}},	//   שרתי, _סב_, мпэн, рвне_
  { {0x76450026,0xf6490008,0x38693f85,0xcd96000a}},	//   _anhy, _בצ_, _clar_, _ודעת_
  { {0xda350010,0x29053f86,0x6be8004f,0xc016004f}},	//   _меды, sula_, _הַצַ, חקרו_
  { {0x9bb60008,0x24890095,0xda340033,0x245c001a}},	//   _והנה_, enam_, _нечы, _límt_
  { {0x1a9a004c,0xa8a60015,0x4a9a000a,0xc448002b}},	//   _דיסע, _وصعو, _דיסג, میدن_
  { {0x044311ea,0x60c90f28,0x9f4f001a,0xb2d60058}},	//   месн, _čemp, yggð_, قيرغ
  { {0xc889003b,0xd46723e4,0x1dc9000b,0x03a30840}},	// [8c40] _دخول_, ците_, िखात, дито
  { {0xae0e000b,0x25ad0046,0x76450034,0x0000006a}},	//   _साधन_, řela_, _gnhy,
  { {0x7cf0002d,0x361b000a,0x412600c3,0x70f6005e}},	//   _mórá, _דויד, تفاق, ючає
  { {0xdfd00031,0x91da000b,0xa3ee000b,0xa06a012e}},	//   ريت_, _प्रै, _ज़िप_, јада_
  { {0x888b004c,0x64463f87,0x3ed40058,0x8fc50058}},	//   ברײַ, _inki, أقتر, أزمن
  { {0x72c30080,0xccfa0001,0x3e87006b,0xee2a0015}},	//   _обяз, аћи_, ойчо_, شأته_
  { {0xf6530008,0xbbb4000b,0x68ed002a,0xc43a000a}},	//   וצג_, ुश्क, _ładn, ֹתִי
  { {0x245c002c,0x6ab2005d,0xcb540054,0xa3b10065}},	//   _tímu_, ँग्र, звић, _ओरम_
  { {0x3ce9016f,0x69cf0046,0x3e6b00cb,0xda2600ce}},	//   ćava_, ěcen, _søte_, оєно
  { {0x9e660115,0x5d1a005e,0xcf250015,0xc87f0012}},	//   _بارن, _відс_, _عرقي, wiß_
  { {0x6446008c,0xeb8f002b,0x7c6600c3,0xdebb000a}},	//   _onki, فظی_, _واصل, _כממל
  { {0x0b46250c,0x7afd0024,0xc87b0004,0x3b66009b}},	//   _мнен, šsta, рџо_, _мълв
  { {0xdce3002a,0xf8c90016,0x0000006a,0x0000006a}},	//   rzną, _uẩn_,   ,
  { {0x7aa60015,0x95c8006b,0x64463f88,0x91da0065}},	//   _بإصل, жута_, _anki, _प्लै
  { {0xe917005e,0x94d40033,0x6cd8000a,0xd7fb02b0}},	//   _дощі_, досц, מַּצ, _куп_
  { {0x6f02005c,0xd14b0086,0x88f7000a,0x88bd0046}},	//   kroc, یشان_, _וזהו_, hvěz
  { {0x44980033,0x61f90033,0x24893f89,0x22583f8a}},	// [8c50] івую_, йнаў_, rnam_, _bork_
  { {0x9388022a,0xf772000a,0x24890034,0x02a7008b}},	//   іста_, _נקי_, snam_, ірам
  { {0x7fd50010,0xa2820086,0x92680099,0xe63c004f}},	//   пілі, ریفو, црта_, _כתזכ
  { {0xc9530135,0xc078005e,0x859a000a,0x6b8d001a}},	//   ומע_, осії_, _לשתו, _þagg
  { {0x44293f8b,0xdf78005e,0x225831fb,0xbebd003d}},	//   mea_, обці_, _fork_, _osūt
  { {0xb3ba0008,0x44293f8c,0x8d55006b,0x13ba000a}},	//   _למרכ, lea_, зтич, _לזרע
  { {0x38b2002c,0x30850002,0x15fc000a,0xa1840033}},	//   láre_, _فلسف, שִׂמ, _жытл
  { {0x9f440089,0x68ed005c,0x44293315,0xbd18005e}},	//   _zemí_, _łado, nea_, юції_
  { {0x4ea7050e,0x6f020738,0xdef40033,0x22583f8d}},	//   _држа, croc, _опты, _york_
  { {0x28cf005d,0x44293f8e,0x220b000a,0x3256004f}},	//   _संदि, hea_, ׁפִּ, ִ֡ים_
  { {0x44293da1,0xd9453a2d,0xbb49002b,0x4ea402d9}},	//   kea_, чени, _گلشن_, _црта
  { {0x4429000c,0xa3bd005d,0xda1c005d,0x6fcb000b}},	//   jea_, ेखा_, ब्बत_, िशिं
  { {0xeb8e0191,0x3211005c,0x44293f8f,0xdd10006f}},	//   _чи_, _oczy_, dea_, _výťa
  { {0xc4c6003b,0xbb3a0008,0x41bd005d,0xaf760053}},	//   كترو, _לעני, ्खास, לערס_
  { {0xc1aa014e,0xceb2013a,0x04460036,0x5fcb005d}},	//   _करेग, גים_, певн, िशाल
  { {0xa5070001,0x58fa0053,0x6f023f90,0x7c293f91}},	//   џета_, _פּונ, yroc, neer
  { {0xc2c60086,0x7783006b,0x73060033,0x225817cd}},	// [8c60] سياي, _плъз, япаз, _pork_
  { {0x69de0005,0x7c290384,0xb77b0008,0x1ddd000b}},	//   _õpet, heer, _לאפש, नुमत
  { {0x2366010b,0x05940086,0x365b0008,0x865b000a}},	//   šoj_, _زادگ, _הכינ, _הדיי
  { {0x22580041,0x42560086,0x69c3005d,0xdfcf00e5}},	//   _work_, _کنسر, _रणनी, هيم_
  { {0xbea6009e,0xde580010,0x9e34006b,0xe457004c}},	//   падк, жалі_, делч, _זיכט_
  { {0x471b004c,0xdea2002b,0xde880016,0xaf490015}},	//   מונג, ریای, aịn_, تشمل_
  { {0xf9870015,0x7c291c2c,0xf8c90016,0x4c9412fd}},	//   _أب_, feer, _bẩm_, микс
  { {0x3f6a005f,0x2c7a0024,0x7ead002d,0x61ee0026}},	//   _либо_, līdz_, rúpa, _hebl
  { {0xda660015,0x0aea0015,0x6bd30015,0x61ee0351}},	//   كادي, حربي_, رتير, _kebl
  { {0x03770008,0x442912e7,0x3377000a,0xd8f8005e}},	//   פתית_, zea_, פעים_, оної_
  { {0xe8950010,0xbc670086,0x5bc60029,0x7c293f92}},	//   дань, زمین_, _فقال, beer
  { {0x7c290298,0xad250015,0x718b000a,0x27ed039f}},	//   ceer, _تركو, מְכַ, úen_
  { {0xb8d3005d,0xf1bf002c,0x629e18a2,0xeaaf002b}},	//   _जी_, čšie_, kopo, ضعی_
  { {0xcad7013a,0x3bbb000a,0xddc80046,0x5afb004c}},	//   _צוות_, _המדד, _podř, _פלוצ
  { {0x44293f93,0x58b8002b,0x08f7002b,0x746b34a8}},	//   tea_, تایج_, _فريب_, брав_
  { {0x89330015,0xc7c7004a,0x98a40054,0xd5b80088}},	//   _أعوا, _эски, _пије, яся_
  { {0x44290440,0xe7e3005d,0x24580a2c,0x20f8016f}},	// [8c70] rea_, _क्या_, чать_, eči_
  { {0x44293f94,0x9a78000a,0x7c293f95,0x02450058}},	//   sea_, קָּח, zeer, بَطَ
  { {0x30150c9c,0x51f40029,0xa3b1000b,0xd164006b}},	//   ддер, عسكر, टेज_, нъци
  { {0x7c290111,0xf1b00015,0x0000006a,0x0000006a}},	//   xeer, اءك_,   ,
  { {0xef0e0063,0xf43a000a,0x61ee0144,0x67f80030}},	//   ъм_, _וגרמ, _febl, lújí
  { {0xc33200f3,0x7c290161,0x9f440144,0x3211002a}},	//   _שום_, weer, _demà_, _uczy_
  { {0x7c293f96,0x38880030,0x7d030034,0x5ff515df}},	//   teer, lőre_, urns, _озву
  { {0xccf80089,0x69d83f97,0x6018006b,0x69c3000b}},	//   _dvě_, _afve, _нося_, _रणबी
  { {0xa0c40029,0x7c293f98,0x28cf000b,0x4b2500ce}},	//   _سيكو, reer, _संहि, ємов
  { {0xe8f93f99,0x7c293f9a,0xc96501f3,0x9b640058}},	//   оло_, seer, двой, عطيه
  { {0xac190036,0xb69b0011,0x382a1319,0x4995034e}},	//   _можу_, trân, ожно_, ьшит
  { {0x200f0d25,0x61e5002d,0x69ca0030,0xb69b0045}},	//   nggi_, hbhl, _egfe, urân
  { {0x28cf005d,0x629e003f,0xb904000b,0xcff6000a}},	//   _संवि, yopo, _पढ़_, וצרה_
  { {0x753c02d5,0xab640010,0x9f4f0003,0xa969016a}},	//   tvrz, _явіл, gagé_, _мила_
  { {0x845a387e,0x67f80030,0x6443003d,0xddd800b3}},	//   орат_, gújí, ēnin, nivš
  { {0x161f000b,0xd8770015,0x6d3a000a,0x39340033}},	//   म्बर_, _يموت_, חֲמו, _чэшс
  { {0x60ce3f9b,0xd7fb000a,0xf1fa00c3,0x64a32565}},	// [8c80] _subm, _והפל, قعات_, тата
  { {0x7cd10048,0x9f440227,0x60ce04a9,0x99850046}},	//   _pārl, _nemá_, _pubm, nelů_
  { {0x814600a2,0x24f60033,0x20f800bc,0x629e3f9c}},	//   بنان, _ўчор, uči_, ropo
  { {0x629e0014,0x61ee3f9d,0x7f86006e,0x20f82c11}},	//   sopo, _webl, ولان, rči_
  { {0x629e3f9e,0x61ee0061,0xed4f002b,0x7afd016d}},	//   popo, _tebl, یپه_, ástl
  { {0xa3bd000b,0x200f02b9,0x6df40015,0xf777000a}},	//   ेखर_, aggi_, ركبا, ועני_
  { {0xa06a017a,0xdd930033,0x99850046,0xc237000a}},	//   _дава_, кашы, delů_, _קרלו_
  { {0x7d0a00b8,0xdb220086,0xe04327f6,0x2905013b}},	//   rufs, نوعی, _инси, drla_
  { {0x6d4108e9,0xfc2f0015,0x4f660058,0x9f4f01f6}},	//   _erla, شحي_, _غارف, yagé_
  { {0x5a340063,0xd90e0086,0xddd800b3,0x78a43f9f}},	//   хнот, لیت_, bivš, _akiv
  { {0x388800dc,0x9f4f01f6,0x0000006a,0x0000006a}},	//   zőre_, vagé_,   ,
  { {0xbb4a0015,0xfe0e000b,0x6b6601e8,0x89d8009a}},	//   _ولان_, _साँस_, _океа, _کوثر_
  { {0x29053fa0,0xfb130058,0x98740138,0x0000006a}},	//   arla_, _لونج, тляц,
  { {0x1994008f,0x056b0004,0x7a37005e,0x38880030}},	//   _паля, ојби_, _опір_, vőre_
  { {0x200f002e,0xda650115,0x45d4004a,0x442201d7}},	//   yggi_, _ثاني, тосс, _bbk_
  { {0x78fb0008,0x290c3fa1,0xf993000a,0x38580015}},	//   _ולהפ, muda_, _שרק_, _يشيد_
  { {0x290c0020,0xddc8002a,0xa2b50800,0xfe0e000b}},	// [8c90] luda_, _podś, ебач, _सांस_
  { {0xe3b0003b,0x38b200dc,0x9b17000a,0x8c3d13cc}},	//   شرق_, mára_, וחמה_, moşe
  { {0x7cd10024,0x69dc002e,0x38b23fa2,0x7c220fde}},	//   _pārm, ðrey, lára_, _obor
  { {0x41df014e,0x5f9506ac,0xddd800b3,0x249f0052}},	//   _प्रस, ниет, vivš, _ðum_
  { {0xaff60015,0x645d0045,0x73c50015,0x926b012e}},	//   رفوا_, _iosi, _سيسم, _дрва_
  { {0x99850089,0x44392d24,0x290c3fa3,0xddd80085}},	//   xelů_, _has_, kuda_, tivš
  { {0x6da20036,0x44393fa4,0x6f190034,0x69c3000b}},	//   лиша, _kas_, stwc, _रणधी
  { {0x290c2a52,0x38b21754,0x44393fa5,0xddd80085}},	//   duda_, kára_, _jas_, rivš
  { {0x998502d5,0x38b20eed,0x44393fa6,0x539a000a}},	//   telů_, jára_, _mas_, ּיתו
  { {0x44390782,0xc332011f,0x60c900f2,0xae1b005d}},	//   _las_, נוי_, _hiem, प्शन_
  { {0x60c90014,0x7cd10024,0x290c0acf,0xee840033}},	//   _kiem, _mārk, guda_, _рыто
  { {0x60c90007,0x6a6d002c,0xe1080008,0x6d3a000a}},	//   _jiem, _dúfa, וּשָ, _מתענ
  { {0x60c93fa7,0x38b200dc,0xcc56000a,0xb69b016e}},	//   _miem, gára_, _רבני_, arâm
  { {0x786602c1,0x78bd22af,0xcb12000a,0x7e79004c}},	//   _móvi, amsv, _עלו_, לאָז
  { {0x645d0176,0x443936f8,0x290c0f0a,0x78a406c0}},	//   _bosi, _bas_, cuda_, _tkiv
  { {0x60c93fa8,0x44393fa9,0x141a0015,0x645d04bd}},	//   _niem, _cas_, ثيرة_, _cosi
  { {0x44393faa,0x7c390176,0xf4870086,0x33d50036}},	// [8ca0] _das_, _mawr, رافی, тіст
  { {0x6aa10176,0xae0e005d,0x60c900f2,0x44393fab}},	//   nolf, _साइन_, _aiem, _eas_
  { {0xe8530086,0x26d2003f,0xdfda006b,0x645d3fac}},	//   _شنید, _huyo_, пъл_, _fosi
  { {0x61e30064,0xc0590010,0xd8da0053,0x60c91164}},	//   ınla, міі_, לקער, _ciem
  { {0x9f340036,0x765e2bcc,0xb65a000a,0xd00f0015}},	//   телі, _kopy, ּדֶש, إله_
  { {0x44203fad,0xc3330008,0x290c02c1,0xc7b3000a}},	//   lfi_, _גוש_, yuda_, אבד_
  { {0x6143006b,0xad660021,0xbdf70015,0x44390f0a}},	//   _йера, عاته, رروا_, _yas_
  { {0x8fa60cfa,0x2b01000b,0x6aa10125,0x44203fae}},	//   _забе, _शिशु_, eolf, nfi_
  { {0x44203c9c,0x9b6a1301,0x16200065,0x0000006a}},	//   ifi_, яшка_, यभार_,
  { {0x4efb0008,0x38b21754,0x60c93faf,0x290c3fb0}},	//   _מהמו, vára_, _ziem, tuda_
  { {0x7c390026,0x6df30015,0x7994006b,0x290c007c}},	//   _fawr, _إكما, тинф, uuda_
  { {0xfd570008,0x7c22003f,0x38b21754,0x9cd7000a}},	//   _רשאי_, _ubor, tára_, _נודה_
  { {0x26d202c1,0xc6f8022a,0xab290015,0xf093000a}},	//   _cuyo_, ннях_, _يسهل_, רנר_
  { {0x7c39002a,0x38b21115,0xdd860040,0x645d3fb1}},	//   _zawr, rára_, لو_, _sosi
  { {0x24190010,0x44393fb2,0x4420165e,0x38b2163c}},	//   мовы_, _pas_, ffi_, sára_
  { {0x68fa0123,0x6e3a3fb3,0x9782009a,0x0000006a}},	//   mstd, _latb, اییه,
  { {0xe4ed005d,0xf8bf0152,0x7cd10024,0x44393fb4}},	// [8cb0] _जबकि_, mmé_, _pārk, _vas_
  { {0x44393fb5,0x60c93fb6,0x75d50015,0x69da3fb7}},	//   _was_, _siem, _جيدا, ncte
  { {0x60c90048,0x44393fb8,0x645d0f7a,0xeab1000a}},	//   _piem, _tas_, _tosi, בֹא_
  { {0x7afd0089,0xb4fa000a,0x645d008c,0x62853fb9}},	//   ástk, _קפרי, _uosi, siho
  { {0x60c91b86,0x7052002b,0xe80a000b,0x15e50065}},	//   _viem, شنوا, _वाघा_, _कभार_
  { {0x158b000a,0x60c9002a,0x6f640033,0x7c3b0034}},	//   ּנֵֽ, _wiem, ывіз, wdur
  { {0x6e3a0176,0x60c937fe,0xc1050015,0x6d320015}},	//   _datb, _tiem, _جوزي, لفوض
  { {0xdd8e003b,0x20d70064,0x1c450036,0x69da028d}},	//   توى_, _içi_, тним, ecte
  { {0xaed50191,0x7c3b3fba,0xaf390033,0x68fa3fbb}},	//   _розш, rdur, _юзаф_, estd
  { {0x3945087a,0x27f200b8,0xbf38005e,0x7c393738}},	//   вног, _seyn_, _язує_, _wawr
  { {0xdd1e0264,0x44203fbc,0x6d070015,0x26d20077}},	//   píše, yfi_, _سباق, _suyo_
  { {0xcc140087,0x7d560008,0x49980033,0x5c140015}},	//   _مذهب, _ביעד_, этыя_, _مظهر
  { {0x6c7a0053,0xfbd0002b,0x765e002a,0x2cbf007c}},	//   _קאנפ, _اتم_, _popy, mmud_
  { {0xa9250010,0x2cad19a8,0x2cbf3fbd,0x66e31977}},	//   _адкл, lled_, lmud_, рора
  { {0x29350053,0x8a16000a,0x48b6004a,0xe5a6144f}},	//   _יאַן_, _יחסו_, _ищит, тиви
  { {0x64be005d,0xb4ac000b,0x26d20077,0x0000006a}},	//   ्देश, गते_, _tuyo_,
  { {0x44203ea5,0x2cad3639,0x7afb0bfd,0xe3632dfa}},	// [8cc0] rfi_, iled_, nsut, акти
  { {0x2cad0089,0x91e60080,0x7afb0601,0x42070054}},	//   hled_, тоже, isut, кнуо_
  { {0xc0aa0029,0xa3ea034e,0x161b000b,0x6e3c026a}},	//   واصل_, _одна_, _पॉटर_, _órbi
  { {0x7afb0c8d,0x895a0008,0xa0670063,0x21a3006b}},	//   ksut, ודעת, каха_, шихм
  { {0xe3b20086,0x44fe0007,0xa78d000a,0xc7d7000a}},	//   _خرد_, lį_, ּאוֹ, דוני_
  { {0x249209f9,0x577b0008,0x38b90030,0x2cad17cd}},	//   lnym_, וטנצ, mére_, eled_
  { {0x44fe00df,0x35ba000b,0x2492002a,0x38b90030}},	//   nį_, _इरफ़, onym_, lére_
  { {0x2cad065d,0x38603fbe,0x24923fbf,0x628b0003}},	//   gled_, _noir_, nnym_, égov
  { {0x501b0008,0x38b900dc,0xcc330029,0x1fa73fc0}},	//   _קומו, nére_, شريع, _акти_
  { {0x44fe0007,0xf8ca0092,0x2cad17cd,0x4a542332}},	//   kį_, _mẩu_, aled_, укос
  { {0x7afb0005,0x987e0064,0x2cad11a9,0x0000006a}},	//   asut, _açın_, bled_,
  { {0x2492005c,0x38b900dc,0x3b860180,0x38600125}},	//   jnym_, kére_, _илег, _coir_
  { {0xf8bf0152,0x249209f9,0x38b900dc,0x7f423e8b}},	//   rmé_, dnym_, jére_, nvoq
  { {0xb7e3005d,0xaa580021,0x7aed06d1,0x3a7300fd}},	//   _क्रम_, _سلبا_, _çata, _клір
  { {0x7cd10024,0x7588030c,0x38720795,0x3eae02ad}},	//   _pāri, вств_, _flyr_, ilft_
  { {0xdd3b0053,0x481505a7,0x0d3b000a,0x1957000a}},	//   ועלכ, _смис, וגלב, _יבול_
  { {0x1da9005d,0x36d5005e,0x38b90030,0xe2f8005e}},	// [8cd0] _चुनत, _щопр, gére_, кеті_
  { {0x291e32da,0x2492002a,0x7ae20573,0x7afd3fc1}},	//   otta_, anym_, _mtot, ásti
  { {0xdfd10029,0x2492005c,0x2cbf0026,0xc4c70015}},	//   ميا_, bnym_, ymud_, _لتحو
  { {0x50b80086,0x2492005c,0xe588000a,0xb3eb0015}},	//   ندند_, cnym_, _יָרָ, _تعدل_
  { {0x2489016e,0x7d0a3677,0x644f0d3a,0x0000006a}},	//   miam_, erfs, _inci,
  { {0x42790053,0x2cad0f0c,0xee38005e,0xbec2003d}},	//   _טאָג, wled_, кні_, žīna
  { {0xc212013a,0xfc310015,0x2cad3fc2,0xf532000a}},	//   _להם_, محة_, tled_, ֶ֥ה_
  { {0x24893fc3,0x7afb1c7e,0x39491361,0x45b8004f}},	//   niam_, tsut, _čas_, כפול_
  { {0x1c4202bf,0x89f50484,0x99f50033,0x291e3fc4}},	//   сным, лянц, ляні, etta_
  { {0x24921e32,0x38601939,0x7ead006f,0x5ee8000a}},	//   znym_, _soir_, kúpi, _יַעְ
  { {0xe73c01e2,0x24890091,0x38b90030,0x7d790015}},	//   _küçü, kiam_, zére_, _ثمار_
  { {0x511a0008,0x05a7000b,0x47aa0015,0x7c841e92}},	//   עֵינ, _गड़ब, ّاسٍ_, _куче
  { {0x3860038d,0x41c3000b,0x2b460144,0x2492006f}},	//   _voir_, वेतस, _groc_, vnym_
  { {0x2492005c,0x44fe0007,0x38b900dc,0x644f0493}},	//   wnym_, tį_, vére_, _anci
  { {0x24921332,0x8aa8004c,0x2bb3000b,0x7ae20046}},	//   tnym_, _בֹקֶ, ुधवा, _ztot
  { {0x44fe0007,0x38b900dc,0x38960024,0xe3b20015}},	//   rį_, tére_, māro_, مرء_
  { {0x44fe0007,0x24921332,0xfbd2000a,0x93460033}},	// [8ce0] sį_, rnym_, מתן_, ынае
  { {0xe74711e0,0x44fe00df,0x2492005c,0x644f3fc5}},	//   ções_, pį_, snym_, _enci
  { {0x38b90014,0x600a007a,0x25a50012,0x61f50045}},	//   sére_, енем_, üllt_, _dezl
  { {0xd00f0029,0x24893fc6,0x38b90030,0xd01000c3}},	//   كلم_, ciam_, pére_, زلت_
  { {0xaff70021,0xee860088,0x44323fc7,0x93fb004f}},	//   افها_, лыко, mey_, _אלכי
  { {0x7e613fc8,0x291e02ce,0x2c710046,0xd9d2000b}},	//   _colp, ytta_, _ráda_, _सलेट
  { {0xf1c3005d,0x2fdf0026,0x7e6122d3,0xad2600c3}},	//   वेदन, _ffug_, _dolp, ارتو
  { {0x44323fc9,0x2b463fca,0xd12f012c,0x8c3d0045}},	//   ney_, _proc_, _عمق_, toşa
  { {0xeb970001,0x9a8a0063,0xe457000a,0xc43b000a}},	//   лић_, ещна_, ריפט_, תתפי
  { {0xc333013a,0x27e0038d,0x44320041,0x2489001c}},	//   צות_, _afin_, hey_, ziam_
  { {0x291e022d,0xdc540086,0xc27b0135,0x44323f4a}},	//   utta_, _پراک, גריי, key_
  { {0x7cd10048,0x291e2ea1,0x9be30138,0x0000006a}},	//   _pārv, rtta_, _лішк,
  { {0x24893fcb,0xfbd3000a,0xb607005e,0x36d515df}},	//   viam_, _התנ_, лявк, рогр
  { {0xbb3b00b2,0x60c200d5,0x7ead3fcc,0x2489002a}},	//   _רעגי, hmom, túpi, wiam_
  { {0x27e00026,0xceb30643,0x24893fcd,0x20d00065}},	//   _ffin_, מיש_, tiam_, _तंगध
  { {0xe4a73fce,0x44323fcf,0x67650058,0x998c005a}},	//   урго, gey_, _نُعل, ledů_
  { {0xe3b00029,0xf7730086,0x24893fd0,0xc2c50015}},	// [8cf0] كرك_, _داغ_, riam_, ليري
  { {0xbbd1005d,0x7cd10024,0x290c1259,0x24890091}},	//   _हल्क, _kārt, orda_, siam_
  { {0x7e6100dd,0x6d5e00f2,0x443237e7,0xd13100c3}},	//   _rolp, äpal, bey_, تما_
  { {0xd1380010,0x9f050029,0xd0ab0021,0xfafe003d}},	//   ыху_, لوصو, رطان_, _ķīna_
  { {0x6d480176,0x8e550036,0x93fa000a,0x8fa500d7}},	//   _arda, иткі, _שלשי, јале
  { {0x26dc0053,0x8d650459,0x60c20091,0x1d09033d}},	//   עקומ, ивле, amom, веки_
  { {0xed593fd1,0xbdf80031,0xfbd10015,0x7e6124f5}},	//   той_, ارها_, يتة_, _volp
  { {0xf0bb002b,0xbc651c4d,0xf412004f,0x3a27013b}},	//   _سازش_, рвик, ַ֤ח_, _sbnp_
  { {0xaae40086,0x290c0fc9,0x3f4e002e,0xd7c7000b}},	//   یسیو, erda_, rðuð_, रेमच
  { {0x44320064,0x92a6002a,0x3896003d,0xa9253771}},	//   zey_, _gałą, tāro_, адол
  { {0xf9910029,0xc4b5000b,0x2aab02de,0x3ea73fd2}},	//   تبة_, ंताओ, døbt_, mont_
  { {0x18a6005f,0x92a6005c,0xf7460457,0x98a608a6}},	//   рамм, _załą, аемо, риме
  { {0xbca40074,0xa3d9005d,0x4a750080,0x3ea70079}},	//   _امني, ाशन_, _выйт, oont_
  { {0x4b7a0135,0xddc10024,0xe737023e,0x7afd3fd3}},	//   _באנו, _nolū, јер_, ástu
  { {0xc6c30010,0xc4c60015,0xd4c60015,0xfa34002b}},	//   ійск, لترو, لغري, _درند
  { {0x7ae93fd4,0xd91a004c,0xfe790046,0x232a1377}},	//   opet, _סופל, _stůl_, коби_
  { {0xf677002b,0x3ea73fd5,0xd252006e,0x44323fd6}},	// [8d00] _چاپخ, kont_, ينر_, rey_
  { {0xf2df0092,0x232710a1,0x38b91112,0x67bb000a}},	//   _trân_, рофи_, méra_, _במפק
  { {0x69dc0091,0x2fe60015,0x7f4904a5,0xd29900ce}},	//   žreg, لكاف, _areq, утті_
  { {0x03a60191,0x628b0152,0xe612002b,0xd46a004a}},	//   _вимо, égor, _اشک_, _риме_
  { {0x3fcb0086,0x6d480085,0xa06703ae,0xc356006b}},	//   ندهی_, _srda, јача_, _тънъ
  { {0xadbc02a3,0x60c23fd7,0x2bc90065,0x9e340138}},	//   налi, smom, ाइना, секч
  { {0xc5f3000a,0xd657000a,0xcd3300c3,0x8e830058}},	//   חדו_, ייסת_, قريب, تلوه
  { {0x9c38004a,0x7f490d2d,0x290c00b3,0x3b0d3fd8}},	//   упит_, _freq, vrda_, freq_
  { {0x3ea70034,0xda6600c3,0x5c7302a3,0x7cd1003d}},	//   bont_, لادي, ільт, _sārt
  { {0x7cd10048,0x9df8000a,0xaa661cd9,0x3a741673}},	//   _pārt, _תִּז, ртик, слор
  { {0x672d044c,0x6d483fd9,0x02b7000a,0x88bd0046}},	//   _spaj, _urda, שהים_, jtěc
  { {0x245c006f,0xdd8f00c3,0x7cd1003d,0x998c0046}},	//   _tímy_, _توم_, _vārt, sedů_
  { {0xab830124,0x62800007,0xb71403ad,0x6c7b00a3}},	//   _мушк, _įmon, одящ, _בראד
  { {0xb88209f0,0xc9860086,0xaa2c008c,0x5f090065}},	//   _þína, _پشتي, äjää_, _सिस्_
  { {0xae1b005d,0x28d0005d,0xe9370029,0x3abb000f}},	//   प्टन_, _संचि, _نسيت_, _שמונ
  { {0x57f50001,0x6594005e,0xb8670067,0x3ea73fda}},	//   _упит, іату, _خاتو, zont_
  { {0x2bc9005d,0xb89c000a,0x88bc000a,0xaaba000b}},	// [8d10] ाइया, _שבחש, _בזהי, _उठाक
  { {0xa4f9002b,0xe796002b,0xa15900af,0x0000006a}},	//   _مکرر_, _چایک, лазу_,
  { {0xc5f20008,0x3ea70030,0x02440015,0xc05b0033}},	//   _מדי_, vont_, تَلَ, кід_
  { {0x7536004c,0x61ea0061,0x6aa80034,0x24550015}},	//   _פארד_, ıfla, hodf, _انحس
  { {0x28c8000b,0x3ea7047f,0x7ee40054,0xe7fa000b}},	//   रगति, tont_, оцје, ्णता_
  { {0xdc01000b,0x6ec40015,0xade80058,0x1e8400ce}},	//   ोल्ड_, يتوق, لفهم_, олім
  { {0x3ea71fca,0xc5f4000a,0x1d06006b,0xa158004e}},	//   ront_, קדק_, бещи_, _кару_
  { {0xae1c005d,0x1ee70086,0x5598000a,0xf0b80015}},	//   _नाथन_, _نوری_, ידוע_, _ناقش_
  { {0x7cd103eb,0x3ea73fdb,0x7f850015,0x4aa90f82}},	//   _pārs, pont_, _الذن, лкин_
  { {0xda090002,0xfc3f0107,0xca5507c1,0x7ae93fdc}},	//   ديده_, ží_, стињ, rpet
  { {0x7ae93fdd,0x38b2006f,0x4876002b,0x88ca0a32}},	//   spet, lári_, مدحس, ллов_
  { {0x385a0036,0x7ae932d8,0x442b3fde,0xa156000a}},	//   урою_, ppet, _nbc_, צברה_
  { {0x76890007,0xf772012c,0x23a7000b,0x38b230aa}},	//   ažym, ساح_, _कुलद, nári_
  { {0x442b3fdf,0xda340033,0x8bb40058,0x78ad0160}},	//   _abc_, _мечы, _بإما, _ekav
  { {0xd5b200a2,0xceb200f3,0xe4da002b,0x1a65002b}},	//   سفر_, פיל_, اورت_, _نیکی_
  { {0x475a0063,0x28d0021e,0x442b26d0,0x38b2123c}},	//   _броя_, _सूचि, _cbc_, kári_
  { {0x04570015,0xe29a0004,0x38b2006f,0xe3ba3fe0}},	// [8d20] حلقة_, гаа_, jári_, уба_
  { {0x6f04111e,0x21a600af,0x959600af,0x0000006a}},	//   šick, бизм, _грмљ,
  { {0x64a60010,0x64ac00b8,0x25d7000a,0xe1610033}},	//   _гана, ußis, _לוין_, мяцi_
  { {0x10160015,0xf2c9004f,0xb7fa0065,0x68f60535}},	//   إباد, גע_, ्णिम_, _łydk
  { {0xb4c4014e,0x14b5005d,0xbe8a0054,0xd007018d}},	//   एगी_, ंतरण, лске_, сече_
  { {0x7c2b00b8,0x66c00123,0x6fb30015,0xbea32cd1}},	//   _abgr, sökf, أمها, пачк
  { {0x21670891,0xa2a5000b,0xcd2a002b,0x61fe007c}},	//   _лири_, कवर्, استن_, mapl
  { {0xfd0f0029,0xd1970008,0xa4fb000a,0xc4d3000a}},	//   رجى_, _הכלי_, אלקט, הגה_
  { {0x7cd10024,0xcb070029,0x5b230015,0x3b5400fd}},	//   _pārr, ميين_, كفيل, ікор
  { {0x9e65003b,0x527b00b2,0xc333013a,0xc27b0053}},	//   _والن, ָנטא, לוח_, ָרטי
  { {0x7afd3fe1,0xacea0004,0x26120065,0x6f023fe2}},	//   ástr, _смеа_, _ताजी_, lsoc
  { {0xc19b0053,0x2db70053,0xb4b7000b,0xd7e40033}},	//   רשטי, _פלאן_, _छठे_, зіро
  { {0x6ac30086,0x48a80033,0x61fe3fe3,0xfaa61114}},	//   تقیم, стэм_, kapl, _ладо
  { {0xeb070015,0x3e7901f6,0x0000006a,0x0000006a}},	//   _اقوى_, _tète_,   ,
  { {0xe5c40063,0x5d78000a,0xcd78000a,0x4d78000a}},	//   зсто, בָּנ, בְּכ, בָּא
  { {0x38b90152,0x49170008,0xb4b3021e,0x644402f2}},	//   méro_, _הקהל_, टते_, gdii
  { {0x228f002a,0x999e0030,0x8afd0046,0xf2df0016}},	// [8d30] eżka_, mető_, tyři, _trâm_
  { {0x51f802bf,0x38b20030,0x999e0030,0x3eb9003d}},	//   йную_, vári_, lető_, _īsto_
  { {0xc1040015,0x3e6b00cb,0x6d4e0091,0x55591b42}},	//   كولي, _møtt_, _šban, _таня_
  { {0xdd000089,0x7ff40015,0x61fe02f2,0x38b230aa}},	//   štěn, كسها, aapl, tári_
  { {0x7ce70061,0x441a000a,0xc7b2000a,0x44293fe4}},	//   _kırg, _דורס, ֵ֑ד_, mfa_
  { {0x999e0014,0x8e390029,0x63bd0024,0x2c1b021e}},	//   hető_, شستر_, _izsn, _याहू_
  { {0x38b2002c,0xad240015,0xa282002b,0x6cc515fb}},	//   sári_, كريو, _تیلو, ойка
  { {0x44290026,0xa3d9005d,0x5578000a,0x26d3016e}},	//   nfa_, ाशि_, מעון_, _lixo_
  { {0x290a0014,0xb436000a,0xf092000a,0x44293fe5}},	//   ában_, חָיו_, _חנן_, ifa_
  { {0x09050191,0x44290026,0xd358000a,0xaae40015}},	//   опон, hfa_, משחק_, أسيو
  { {0xdd9b0a7f,0x38960024,0xc2120008,0xa3d90231}},	//   _сша_, lāri_, והי_, ाशा_
  { {0xc5e90dab,0x61fe0264,0x4998004a,0x6fd9000a}},	//   _יד_, zapl, стья_, יחֹח
  { {0x27ff0084,0x44290026,0xdd1e002c,0x903a0053}},	//   ðuna_, dfa_, _víťa, בערה
  { {0x44293fe6,0x0ac7030c,0x7c293fe7,0x4ac40058}},	//   efa_, _ущем, lfer, _فينق
  { {0x61fe0064,0x291100dc,0x261b000b,0xa9040015}},	//   vapl, ázad_, _बारी_, _فبين
  { {0x74160031,0x7c293fe8,0x26d3016e,0x13ea0033}},	//   تورا, nfer, _eixo_, рмай_
  { {0x61fe01e2,0xc2e90015,0xe1fa120f,0x26d3016e}},	// [8d40] tapl, معلم_, ига_, _fixo_
  { {0x44290ac1,0xd6d7002b,0x7ce70061,0x2724030a}},	//   afa_, _گویش_, _kırd, mön_
  { {0x27e5005c,0x27243fe9,0x6f020034,0x63f60015}},	//   ślne_, lön_, wsoc, _وأحر
  { {0x61fe01e2,0x7c290111,0xf9920008,0xf3ff0092}},	//   sapl, jfer, ורב_, _hoãn_
  { {0x2724022d,0xd00f0086,0x289b0053,0xaf360031}},	//   nön_, ئله_, סינא, ترات
  { {0xf7730008,0x999e00dc,0x25ad0045,0x7c293fea}},	//   וקד_, zető_, şele_, efer
  { {0xafe60036,0x7c293feb,0xd05a0033,0x7cd1003d}},	//   _мовл, ffer, _краі_, _pārp
  { {0x61fc3fec,0xcf260015,0x9cca0033,0x8c430054}},	//   _herl, _ورذي, шыла_, деће
  { {0x999e00dc,0x27240db2,0x261b000b,0x447b004c}},	//   vető_, jön_, _बाली_, ינקע
  { {0x60dc0717,0x76890007,0x61fc01c2,0xae78000a}},	//   _kurm, ržyk, _jerl, _פְּת
  { {0x44293fed,0xc237000a,0x999e0030,0x38b20046}},	//   yfa_, חריו_, tető_, háru_
  { {0xf8b00029,0xadb70029,0x6d3b000a,0xab2a0317}},	//   َةَ_, _بهما_, _כתבנ, _вода_
  { {0xa09b0053,0xd90e0086,0xaa460731,0xdc9b000a}},	//   שיכט, ریک_, _медл, _דיאל
  { {0xf98a002b,0xee2e01c6,0x25e60065,0x764a0052}},	//   _پخته_, енi_, जुली_, _ófyl
  { {0x45d41ced,0x05740015,0xf3ff0016,0x04670822}},	//   дорс, وافد, _doãn_, отам
  { {0xd5b80c6e,0x57f5004a,0xa97b004f,0x5fca0065}},	//   юся_, _эпит, _כאוכ, िधाल
  { {0x442906ce,0x61fc3fee,0x66950054,0xb275275e}},	// [8d50] rfa_, _berl, _наиђ, плаш
  { {0x66c0022d,0x656e00dc,0x44292b42,0xeab4000a}},	//   töke, ínhá, sfa_, פִּי_
  { {0x2fd90029,0x7bdc0046,0x61fc3fef,0x60dc0045}},	//   مواد_, ěruj, _derl, _curm
  { {0x79ab000a,0x653a004c,0x60dc3ff0,0xa4390054}},	//   בֹדַ, _פערד, _durm, _узму_
  { {0x61fc002e,0x9f40002e,0xdb070064,0x66c0379f}},	//   _ferl, úið_, ümüz, söke
  { {0xc332000a,0x8e850033,0x61fc3ff1,0xfe42005e}},	//   _רום_, ягле, _gerl, еншо
  { {0xc69400b2,0x6d4e002f,0x7c293ff2,0xe5f80008}},	//   ואס_, _ábal, tfer, חזור_
  { {0xd59c000a,0x61fc0012,0x2724008c,0x846b000a}},	//   יבול, _zerl, yön_, יכֶ֖
  { {0x7c2909f0,0x5f940191,0x61fc01e2,0xa3ce005d}},	//   rfer, _житт, _yerl, षेप_
  { {0x62800007,0x7c293ff3,0x61e53ff4,0xdb22009a}},	//   _įmok, sfer, nchl, روپی
  { {0xf2d40008,0x7c291a15,0xc7a9000a,0x386900da}},	//   ועץ_, pfer, _עב_, _boar_
  { {0x7e68099c,0x88bd0089,0x38b200dc,0x272401a0}},	//   _zodp, stěn, járt_, tön_
  { {0x386904f9,0x31b8005d,0xe73a0054,0x7bda000a}},	//   _doar_, _अर्ध, љег_, _הקנו
  { {0xab640036,0xe737049d,0x764501d7,0x2cad03f8}},	//   _ювіл, џер_, _cahy, loed_
  { {0x27243ff5,0xdeba000a,0xf9fa000a,0x9ce9004f}},	//   sön_, ממשל, _ההצמ, מַּ֖
  { {0x07a6017f,0x61fc3ff6,0x2cad0034,0xd3f400e2}},	//   _найн, _serl, noed_, вiст
  { {0x61fc0375,0xe61a05e6,0xa87b000a,0x487b000a}},	// [8d60] _perl, _лдп_, _לאקר, _לטקס
  { {0x2e2f0061,0x88bd0046,0x290515e9,0x320102f2}},	//   nıfı_, htěl, osla_, gahy_
  { {0xb5f70008,0x85f70008,0x2c71002d,0x463b0053}},	//   _מציג_, _מציע_, _tádh_, _פעטע
  { {0xb4d8005d,0xd0070010,0x76450107,0x60dc0061}},	//   ादी_, зеце_, _zahy, _vurm
  { {0x61fc013c,0xf413000a,0x6d413ff7,0x44220651}},	//   _terl, _אפר_, _asla, _ick_
  { {0x29053ff8,0x64463ff9,0x9f530033,0x60dc3ffa}},	//   ksla_, _haki, эвіч, _turm
  { {0x127b0053,0x427b0053,0x38960024,0xdb070f1b}},	//   _פאלע, _פאלג, lāru_, _člán
  { {0xc19b013a,0x64460d2f,0x2cad3ffb,0x219b000a}},	//   _השלי, _jaki, goed_, _הבלא
  { {0x8b230001,0x6446043a,0x3869118e,0x4f66006e}},	//   едње, _maki, _roar_, _عارف
  { {0x64461dce,0x38b20030,0x9d4605b5,0x49740350}},	//   _laki, zárt_, _незд, длос
  { {0x44220123,0x0000006a,0x0000006a,0x0000006a}},	//   _ock_,   ,   ,
  { {0x63a2005c,0x64463ffc,0xb7d90015,0x31bb004c}},	//   żony, _naki, توحا_, מזינ
  { {0x9969002c,0x1c2b000a,0x61e53ffd,0xaa5c0033}},	//   hŕňa_, _הֽוּ, ychl, _велi
  { {0x2c710089,0x6d4100dd,0x5eeb0008,0xcb57000a}},	//   _rádi_, _ysla, מַלְ, _מסדה_
  { {0x64463ffe,0xa2c0000b,0x3abb000a,0x38b20030}},	//   _baki, वतन्, _המגנ, tárt_
  { {0x6d5700b2,0xa8a4008f,0x2480002d,0x7645013c}},	//   הילף_, _прык, ghim_, _wahy
  { {0x32010089,0x27e90026,0x64463fff,0x3896003d}},	// [8d70] tahy_, _ifan_, _daki, gāru_
  { {0xf772000a,0x877c000a,0xdbf20046,0x82340067}},	//   _סקי_, _לאחי, dříz, فرما
  { {0x25090074,0x7c224000,0x61550015,0xe4e40033}},	//   _برخی_, _ocor, بنائ, _піян
  { {0x61e5018b,0xdfd10070,0x628e4001,0x644601d7}},	//   schl, نيا_, _embo, _gaki
  { {0x2cad0079,0x0000006a,0x0000006a,0x0000006a}},	//   voed_,   ,   ,
  { {0x171c013a,0x6d414002,0x7c224003,0xed591cc9}},	//   מודע, _psla, _acor, жок_
  { {0x27e90084,0xdca50063,0x3cc9068e,0xfc310015}},	//   _ofan_, маки, олко_, نحة_
  { {0xe81f005d,0x14bf005d,0x98720024,0xac990015}},	//   _भाषा_, ्षिण, kšā_, تنعا_
  { {0x200d0319,0x2bdc000b,0x1c420256,0x0a390174}},	//   _idei_, मख़ा, тным, очны_
  { {0x89f40010,0x9f040015,0xdcf70015,0xddc10045}},	//   няюц, _أولو, _فأصب, _colţ
  { {0x38960024,0xb17a004c,0xc4bf000b,0xddc80046}},	//   kārt_, ַטשר, ्षाओ, _ondř
  { {0x1620014e,0x7d1c0293,0x7c22002d,0x290505d8}},	//   _बाहर_, _årsa, _gcor, rsla_
  { {0x7c3b0152,0xb904005d,0x98720024,0xac1803e7}},	//   meur, _भू_, gšā_, _хочу_
  { {0x6446013c,0x7c3b4004,0xaada000a,0x38b20030}},	//   _saki, leur, _וחסר, társ_
  { {0xceb204dc,0x5fdd000b,0xb4d8000b,0x64461027}},	//   דים_, यशाल, ादे_, _paki
  { {0x88bd0046,0x3896003d,0xdbf20046,0x7c3b4005}},	//   htěj, tāru_, yříz, neur
  { {0x64464006,0xb5da0015,0x2327110d,0x55f602ed}},	// [8d80] _vaki, _وبدء_, моти_, _очну
  { {0x24801613,0xdce3003d,0x6446220f,0x7c3b4007}},	//   shim_, gznī, _waki, heur
  { {0x7c3b0991,0x05940086,0x865b000a,0x54c603fc}},	//   keur, _سادگ, _ודיי, _обоб
  { {0x7c3b4008,0xd61a002b,0xdfa60015,0x6e2d0030}},	//   jeur, _اتکا_, وحشي, őabl
  { {0xde580010,0xd3350010,0x38960024,0x9c7c0085}},	//   залі_, _пэры, lārs_, _juče
  { {0x44204009,0x7c22400a,0x9e330033,0x628e001a}},	//   lgi_, _scor, вешч, _umbo
  { {0xa2ab005d,0x4420400b,0x6143004a,0xe0da005e}},	//   जकर्, ogi_, _иера, _єва_
  { {0x547b004c,0xe47b004c,0x80660033,0xdbf20046}},	//   ַטיו, ַריכ, _ўваж, příz
  { {0x4420400c,0xfee90015,0xcf462ed2,0x9b6a15f4}},	//   igi_, _فعلى_, _юнай, юшка_
  { {0x66c000f2,0xf2df0045,0x0000006a,0x0000006a}},	//   yöka, _grâu_,   ,
  { {0x19580010,0x7c3b049c,0x0217000f,0x39a6005e}},	//   чаны_, beur, וחים_, ьшив
  { {0x3eb9003d,0x7c3b1112,0x0000006a,0x0000006a}},	//   _īsti_, ceur,   ,
  { {0xeaaf002b,0xab9a006e,0x6483007c,0xb69b01f6}},	//   طعی_, _بخار_, _hõig, ssâm
  { {0x64830005,0xf98f0074,0xddda0089,0x66c01f15}},	//   _kõig, ابی_, _potř, töka
  { {0xd8bb0015,0x7ce70061,0x08f70040,0x3ea20052}},	//   _ودعا_, _kıra, _قريب_, _íktu_
  { {0x4420400d,0x261b005d,0x98c70033,0x8d4b000a}},	//   ggi_, _बाकी_, _ўскл, חֲמֵ
  { {0x66c001d1,0x64830005,0xd7fc0008,0x83b9005d}},	// [8d90] söka, _lõig, _והחל, _आरओआ
  { {0x07380086,0x4420400e,0xa3ce000b,0x1756000a}},	//   _آسيب_, agi_, षेध_, _נסתר_
  { {0xb0150054,0x6f090085,0xc0150a32,0x7c3b3a79}},	//   емељ, _svec, емещ, yeur
  { {0x8c3d0011,0x0576000a,0xf8ca0016,0xc0cb0054}},	//   noşt, _נגרם_, _bẩy_, цузе_
  { {0xb4bd014e,0xcf240015,0xcee80021,0xa3b6000b}},	//   ेगी_, نروي, ورون_, _चुप_
  { {0xc2c50015,0x171c004c,0xfe71002b,0xa2d50015}},	//   _سيزي, קווע, دگر_, _سيأت
  { {0x7ce701e2,0x7c3b1650,0xddc1400f,0x0000006a}},	//   _bıra, teur, _bolš,
  { {0x88bd0089,0x7c940010,0xe572000a,0x7ff40015}},	//   stěj, крыц, טַח_, _لسكا
  { {0x7c3b028f,0xbf150067,0xf2df0016,0x9f61002a}},	//   reur, _سواب, _trâu_, ępów_
  { {0x7d2800c0,0xdb0e002d,0xcda90029,0x2c71006f}},	//   örsö, ádál, _فهذه_, _rádu_
  { {0x9c7c010b,0xa3b6005d,0x2d9a002c,0x49990457}},	//   _suče, _चुन_, ĺpec_, ятия_
  { {0x38a40061,0xc1dc000b,0x2c71013f,0x3896003d}},	//   fıra_, _बल्ग, _pádu_, vārs_
  { {0xd5b80024,0x4fac000a,0xf8ca0016,0x4420080d}},	//   ļām_, ַׁלְ, _xẩy_, vgi_
  { {0x9c7c0085,0x3896003d,0x5f060065,0xe9a500af}},	//   _vuče, tārs_, _सौफ्_, _палп
  { {0x44204010,0xd5b20015,0x38cb002b,0xda7a000a}},	//   tgi_, افز_, تایی_, _מנסר
  { {0x69c3016f,0x7791002b,0x44204011,0x0902006b}},	//   _izne, اییا, ugi_, _спън
  { {0xb89b0008,0x36360015,0xb8050015,0x44204012}},	// [8da0] _מבקש, _كردس, _شبيه, rgi_
  { {0x6629002c,0x63790036,0xc7d70008,0x44204013}},	//   ľský, єстр_, _אופי_, sgi_
  { {0x66c0022d,0x4420003c,0x00da0021,0x7cd1003d}},	//   löko, pgi_, سبات_, _dārz
  { {0x44fe0089,0xc2090008,0xd012002b,0xb77a015b}},	//   mů_, מה_, الش_, ּאַש
  { {0xddc8005c,0x44fe0089,0xd3b9005e,0x4f660015}},	//   łoże, lů_, _журі_, عاصف
  { {0x7ce701e2,0x2ce8002b,0x179b004c,0x97a9000a}},	//   _sıra, وظبی_, הינב, וֹצֵ
  { {0x44fe0089,0xc5f30008,0x765a008c,0x5c060033}},	//   nů_, נדה_, ötyy, няпа
  { {0x26da018c,0x31570008,0xf8ca0092,0x6483007c}},	//   _lipo_, _אילן_, _tẩy_, _võig
  { {0x44fe0089,0x343b0053,0x4fa3007a,0xfc2f0015}},	//   hů_, לײקע, _битв, صحي_
  { {0xdee306ac,0xd90e0086,0x44fe0089,0xeb3300c3}},	//   _софи, میت_, ků_, اريخ
  { {0x2d870050,0x44fe0089,0xc27b0008,0x66c00123}},	//   czne_, jů_, פרטי, tökn
  { {0x44fe0089,0x6fd60064,0x38a40064,0xb19b004c}},	//   dů_, _gücü, tıra_, לייכ
  { {0x6cd30015,0xc6a7153d,0x987403a7,0xc053004f}},	//   _إقنا, ерви, уляц, אזר_
  { {0x66c000c0,0x44fe0046,0xba2a006e,0xd6d82143}},	//   sökn, fů_, _رستم_, етс_
  { {0x44fe0089,0x3d34000a,0x38a40061,0x6d5c0030}},	//   gů_, כָּל_, sıra_, _árad
  { {0xf9690036,0x49bb000a,0xb9bb000a,0x1957015b}},	//   _юрій_, _ממוס, _מצות, _טבול_
  { {0x7cd10048,0x48140080,0xbec7003d,0xe3b3006e}},	// [8db0] _pārz, _смыс, lnīš, ارز_
  { {0x7ae2022d,0x64830005,0x979c0008,0x44fe0089}},	//   _muot, _sõid, _משחק, bů_
  { {0x7ae2022d,0xf1a74014,0x291e4015,0x45d50099}},	//   _luot, хран, nuta_, _јонс
  { {0xc0780036,0xf8b3000b,0xd91b000a,0x660700bf}},	//   нсії_, ीतिय, לובל, lajk
  { {0x7ae200df,0x64830020,0x8f690015,0x54541899}},	//   _nuot, _võid, ظمتك_, _свят
  { {0x88bd0089,0x291e4016,0xa282009a,0x644d4017}},	//   stěh, kuta_, _پیمو, ldai
  { {0xa3d9005d,0xd658000f,0x62850125,0xd1bb002b}},	//   ाशक_, תיות_, mhho, _راسا_
  { {0x2d87005c,0x4c350010,0x291e4018,0xd0d4006b}},	//   rzne_, тэкт, duta_, _босъ
  { {0x5ba90142,0x228f005c,0x7aa50063,0x44fe0089}},	//   ьким_, eżki_, кииз, zů_
  { {0x291e0f4d,0x644d1521,0xc3320008,0x7ed70029}},	//   futa_, hdai, סוי_, _أزرا
  { {0x60db003f,0x99d40127,0x60c94019,0xfe700015}},	//   _kium, лююч, _khem, _ادق_
  { {0x9b920086,0x44fe0089,0x66c0008c,0x6f190034}},	//   الیت, vů_, töko, orwc
  { {0x644d0026,0x291e401a,0x6ec50065,0x0000006a}},	//   ddai, auta_, ितपु,
  { {0x44fe0089,0xdb0b005c,0x09e22ccb,0x66c000dc}},	//   tů_, _wzgó, _кошн, röko
  { {0xceb2103d,0x69c310af,0x8c3d0061,0xa50a055f}},	//   ייך_, _uzne, anşe, ьева_
  { {0x44fe0089,0x6b960091,0xf49500ce,0x6b890535}},	//   rů_, _žygi, грую, ozeg
  { {0x44fe0089,0x91aa000b,0xe8490015,0xe1f200c3}},	// [8dc0] sů_, _जुड़े, _سجين_, لسا_
  { {0x645d401b,0x6f190026,0x44fe0089,0x644d1f22}},	//   _ensi, drwc, pů_, adai
  { {0x44e70092,0xc617000a,0x41b30015,0x2a6a0030}},	//   _gõ_, _בחיי_, لمكر, öbbi_
  { {0x68e32568,0x60c93461,0x60db401c,0x629716a3}},	//   _mund, _chem, _cium, aixo
  { {0xb60600bd,0x2006002d,0x27ff001a,0x38b90030}},	//   pušč, raoi_, ðuni_, mért_
  { {0x291e000c,0x60c900b8,0x7ae21d4c,0x527614f4}},	//   yuta_, _ehem, _ruot, _руму
  { {0x60db04ed,0x60260063,0x569b0053,0x7ae2008c}},	//   _fium, _идва, ויסצ, _suot
  { {0x7ce70064,0x69b5000b,0x291e401d,0xa3b80065}},	//   _tırn, _उड़ी, vuta_, _ज़रा_
  { {0xcb07003b,0xbcd70015,0x5b230015,0xeb970054}},	//   نيين_, خذوا_, لفيل, кић_
  { {0xd8f80036,0x7ae21d4c,0x68e3237c,0x7c2d0123}},	//   нної_, _vuot, _bund, _öarn
  { {0x38b90014,0x644d0176,0xaa630010,0x621b000f}},	//   kért_, ydai, ртык, וויק
  { {0x7ae2022d,0x44e70023,0xf1b30008,0xfca90015}},	//   _tuot, _rõ_, יסת_, _كانو_
  { {0x6b890050,0x291e06ef,0xda340139,0x6d5c0656}},	//   czeg, suta_, _белы, _árab
  { {0x38b9002c,0xd95400e5,0x68e3401e,0x27e0401f}},	//   véru_, _منتخ, _fund, _egin_
  { {0x68e34020,0x85b80015,0x44321042,0x66074021}},	//   _gund, نافس_, ffy_, rajk
  { {0xed100023,0x44e70092,0x38b90030,0x20044022}},	//   _đổi_, _võ_, gért_, _nemi_
  { {0x644d017e,0x92590004,0xe3740033,0x722b004a}},	// [8dd0] rdai, наат_, алты, дцев_
  { {0xf8bf1f05,0x644d0f21,0x25f6000b,0x60c94023}},	//   llé_, sdai, ्रणी_, _shem
  { {0x74be005d,0x64830020,0x60db3942,0xc104006e}},	//   _वीकृ, _võib, _pium, لولي
  { {0xcfe90087,0x33200144,0x645d4024,0x7d1c008c}},	//   رفته_, buix_, _unsi, _ärsy
  { {0x141a000a,0xe8e00016,0x20044025,0x238a006f}},	//   _אורב, _ướt_, _demi_, ďujú_
  { {0x877c004c,0x7ce70061,0x6f190034,0xf8bf013f}},	//   ואדי, _fırl, rrwc, hlé_
  { {0xcd350029,0xf8bf01cb,0x6d320015,0x60c927fc}},	//   ارتب, klé_, مفوض, _them
  { {0xcf270015,0xa0c50015,0x66050046,0x20040061}},	//   _لرئي, _إيرو, _lehk, _gemi_
  { {0x09e507c1,0xf8bf0046,0xdcf80046,0xf092000a}},	//   лопн, dlé_, ozvě, _הנן_
  { {0x38b900dc,0xce6b0010,0x6b8933db,0x20044026}},	//   zért_, _ўрад_, rzeg, _zemi_
  { {0x7ce70064,0x6b894027,0x8d740086,0x7c87004a}},	//   _kırm, szeg, _پالا, _иуде
  { {0xe8f60010,0x9b450002,0x2c20000b,0xf649000a}},	//   ылю_, _منصو, _याएं_, _מצ_
  { {0x68e300b8,0x9cd60008,0xc79604ab,0x0f79004c}},	//   _wund, _עונה_, урны, גאָב
  { {0xcb120053,0x68e34028,0x2cbf007c,0xae59000a}},	//   _פלו_, _tund, llud_, ׂכָר
  { {0x66c0002e,0x38b900dc,0x68e31f49,0xf8bf0140}},	//   lökk, tért_, _uund, blé_
  { {0x9c7c0f81,0xa976004f,0xf8bf01f6,0x0000006a}},	//   _lučn, _תתקנ_, clé_,
  { {0x74130086,0xd757002b,0x7ce70061,0x66c00030}},	// [8de0] صولا, _مليت_, _sırl, nökk
  { {0x38b900dc,0x443200da,0x2c780030,0xe6460004}},	//   sért_, sfy_, _védi_, _сеоп
  { {0xda7a0053,0x7a7a0053,0x7f490077,0x89c9004f}},	//   ענער, ערעס, _aseq, תֶּ֤
  { {0x50ba0087,0xd59b000a,0xa3f50033,0xdee60cab}},	//   رداد_, _טביל, _вярш, годи
  { {0x53760054,0xa3ba0015,0xd6a9009a,0x9c7c0160}},	//   _сунђ, _ساحر_, _سدیم_, _bučn
  { {0x0ef90010,0x9cf400fd,0x91e318dc,0x69dc003d}},	//   тэцы_, азкі, _горе, žrei
  { {0x11d50127,0xa2bb000a,0xdff60033,0x20044029}},	//   _вітр, _נמלט, _бязь, _temi_
  { {0x5b140608,0x115b004c,0x7b14006b,0x3ae90016}},	//   амит, _אדלע, адих, _búp_
  { {0x543b0053,0x3ae90016,0x8c43012e,0x0000006a}},	//   געפא, _cúp_, сење,
  { {0xfce60920,0xdb25009a,0x0000006a,0x0000006a}},	//   _божо, گویی,   ,
  { {0x02b70053,0xdea30086,0xd2b7000a,0x8c26006e}},	//   רליך_, _دیوی, רלית_, _مفاه
  { {0x2cbf0011,0xf8bf0003,0xd006006e,0x0000006a}},	//   clud_, ulé_, غل_,
  { {0xf8bf0152,0xec35002b,0xa2b9000b,0xda660015}},	//   rlé_, _خونگ, ्तम्, _ماثي
  { {0xf8bf0107,0xa3d8000b,0xe45f0123,0x3ea00125}},	//   slé_, ाधन_, _snö_, éith_
  { {0x66720086,0x6e350061,0x7793002b,0xed14000a}},	//   تگير, _özbe, شیگا, יַּת_
  { {0x7793002b,0x93f50033,0xd4980a3e,0xf3f5009a}},	//   _هیجا, рпац, гру_, شترک
  { {0xd5b1005d,0x6605007c,0xe796002b,0x44b40138}},	// [8df0] _आँकड़, _tehk, _پايک, ёбус
  { {0x6683002b,0xe29300c3,0xa1591e98,0xa1ab1208}},	//   _ایسل, حذر_, казу_, нтез_
  { {0x32b80029,0x4e95002b,0x31c701b0,0x3ff50015}},	//   ادقة_, یشتر, усав, لكار
  { {0xb4fa00b2,0x90990063,0x66c0008c,0x7f1902a3}},	//   _שפרי, ъвет_, yökk, віку_
  { {0x4f58005e,0xe8d8000a,0xdb460015,0x248901d7}},	//   лицю_, אואר_, _بَ_, mham_
  { {0x644f0467,0xd336000a,0x2489402a,0x29110030}},	//   _haci, _דרשה_, lham_, ázak_
  { {0x365c0008,0x7ce70061,0x4439172e,0x644f402b}},	//   תכונ, _tırm, _kbs_, _kaci
  { {0xaf340074,0x2489402c,0x2cbf007c,0xe508000a}},	//   _گرفت, nham_, ulud_, נ֖וֹ_
  { {0x5e270029,0xfd4c0092,0xbc480001,0x248902f2}},	//   _معاق, _khiể, учје_, iham_
  { {0x7f840029,0x644f0251,0xea59012e,0xdd9501b0}},	//   _الكن, _laci, триј_, _казы
  { {0x66c000dc,0x44391d31,0xf866402d,0xec15006e}},	//   sökk, _obs_, авно, _نواد
  { {0x9c820264,0x2bd2000b,0x644f402e,0x442b01f9}},	//   účto, देहा, _naci, _ncc_
  { {0xa088000a,0x661a002a,0x2489402f,0x66e60822}},	//   רְתִ, ótko, dham_, рога
  { {0x44390ecc,0xab8a000a,0x442b2ac8,0x1bb80015}},	//   _abs_, _שָׁ֖, _acc_, _صانع_
  { {0xa5070608,0x04960033,0xf4960280,0x644f4030}},	//   иера_, араў, араю, _baci
  { {0x3d08005d,0x38601af7,0x03a6004a,0x44394031}},	//   _सबसे_, _unir_, аибо, _cbs_
  { {0xb6a60036,0xa20618ba,0x58bb000a,0x020620ed}},	// [8e00] _випл, ипад, _במקצ, изан
  { {0x88bd0089,0xd37b0010,0x442b04ed,0xc1560001}},	//   stět, лiты, _ecc_, ињењ
  { {0x644f0390,0x600a0248,0x361b000a,0x442b32bc}},	//   _faci, внем_, _בויד, _fcc_
  { {0xd0100029,0xc0590033,0x443901c2,0x24894032}},	//   سلت_, ліі_, _gbs_, cham_
  { {0x33fb000a,0x8fa6004a,0x91e6007e,0x93fb000a}},	//   _בהכנ, шаде, _воге, _בלכי
  { {0x644f4033,0x97570008,0x2480005c,0x877b004c}},	//   _zaci, יינו_, lkim_, כאני
  { {0x27f20026,0x3f801aa1,0x644f0077,0x0178000a}},	//   _ofyn_, šiu_, _yaci, _גָּל
  { {0x00f7000a,0xbf6b0046,0x3ea00030,0xc0e3045c}},	//   _כמלך_, _šíři, őit_, _фотк
  { {0xfb860033,0x7c2f0144,0x9e66012b,0x8aa62b12}},	//   рыйн, òcra, _квад, ирод
  { {0xc33301e4,0xba180029,0x60c24034,0xfeba0015}},	//   קות_, ديدا_, llom, _شاءت_
  { {0xfc660063,0xc27b01ac,0xf27b000a,0xf98f0015}},	//   _вълн, דריי, דריש, ِبُ_
  { {0xdd7b004c,0x248900da,0x6d5a008c,0x9c7c4035}},	//   _שטאל, xham_, _irta, _kučm
  { {0x07a4008f,0x2bd2000b,0xd6b70015,0xfbd2000b}},	//   жаўн, देशा, لإسب, देशम
  { {0xda6600e6,0x4b7b05bd,0x6d5a002a,0x44394036}},	//   _خاصي, _באדו, _krta, _sbs_
  { {0x241904ab,0xcdf7000a,0xe4d70015,0x2489201c}},	//   ловы_, שמלי_, لترب, tham_
  { {0x58940015,0x6d5a0085,0x20e80061,0xb9db000a}},	//   _وجيز, _mrta, _eğik_, _בחוש
  { {0x228400c0,0xc2c50015,0x24891686,0xadf8000b}},	// [8e10] _söka_, ميري, rham_, ुरान_
  { {0x6d5a01e2,0x67bc000a,0x60c2013c,0x51f8004a}},	//   _orta, _במחק, elom, иную_
  { {0x75d50086,0xd5bb0004,0x26c300bc,0xa16703ae}},	//   _ديدا, _јсп_, mljo_, шњак
  { {0x00180010,0x248012e1,0x291e002e,0x4094005e}},	//   аўшы_, ckim_, irta_, оріт
  { {0xfd4c0092,0x543a0053,0x6d5a4037,0xb367006b}},	//   _thiể, _גערא, _arta, _тънк
  { {0x7c390176,0x52850029,0xc0b90089,0x7ce70061}},	//   _sbwr, _السك, _žádá, _hıri
  { {0xf2d2000a,0x6d5a0085,0x44294038,0x1638000a}},	//   _זעם_, _crta, oga_, ינגר_
  { {0xfc310029,0x44294039,0x8c490248,0xec4902ed}},	//   سحب_, nga_, упив_, узил_
  { {0x6d5c0084,0x66c00123,0x291e403a,0x29180030}},	//   _áran, söki, erta_, áran_
  { {0x8e740029,0xaa89002b,0xdb060030,0x2480403b}},	//   _والض, اندم_, émáj, zkim_
  { {0xd9450b18,0x5e8a002b,0x7d790058,0xbdf80058}},	//   щени, _حملۀ_, _حمار_, _خرقا_
  { {0x913a004c,0x442927a8,0x3cd5004a,0x66c00030}},	//   נערק, jga_, _ужес, nökv
  { {0x44290e1e,0x291e403c,0x2bec0065,0xf092004f}},	//   dga_, arta_, छुओं_, לנט_
  { {0xdb4e0015,0x4df9004c,0x7bcb403d,0x4429403e}},	//   _أَو_, טפֿא, _izgu, ega_
  { {0xe8f50070,0xc4c60015,0x6483007c,0xb60600bc}},	//   _استخ, مترو, _võin, vršč
  { {0x4d7a0053,0xdb23002e,0x4429403f,0x7c294040}},	//   אָמא, _þróu, gga_, nger
  { {0x38cb0086,0xf8b300f3,0x7c294041,0x32ba0015}},	// [8e20] _حاوی_, _משה_, iger, هدئة_
  { {0x24804042,0x7c290012,0x216a0e4d,0x6fce000b}},	//   skim_, hger, лизи_, _तरबू
  { {0xd6db0008,0xc6930008,0xd5b80024,0x27ed01a3}},	//   _תחיל, _מאז_, ļās_, žene_
  { {0x7c290079,0x3ea70012,0x2cbd0d24,0x53a607c9}},	//   jger, ennt_, _nkwd_, _гамб
  { {0xd6d7002b,0xe7f9000b,0x4fb6002b,0x7c291fb7}},	//   _خویش_, ंडता_, حصار, dger
  { {0x44ee0023,0x4f650015,0x60c2008c,0xeaa70015}},	//   _ký_, تامف, slom, _رع_
  { {0x7c2904de,0x50f8000a,0xb148002b,0xac94004a}},	//   fger, _כִּד, _خیام_, жайш
  { {0x317b0053,0x629e4043,0xbca40015,0x7ead006f}},	//   _גאלד, lipo, تمعي, tĺpc
  { {0x44ee0023,0xeaf70086,0xa3d8005d,0x66c000f2}},	//   _lý_, یریت_, ाधि_, löku
  { {0x33770008,0x493800fd,0x6af30021,0x6e930015}},	//   צעים_, азою_, أثير, _فلقا
  { {0x44ee0084,0xfdf7000a,0xb2bb004c,0xa2bb015b}},	//   _ný_, _הצבת_, רמיר, רמיט
  { {0xc1730008,0xa3d8000b,0x0000006a,0x0000006a}},	//   לחת_, ाधा_,   ,
  { {0xa09b00b2,0xeb970080,0xeb330086,0x872b0010}},	//   ריכט, _лиц_, _فروخ, ыўна_
  { {0x8bd70008,0x44ee002e,0xcf93000a,0x291e00bc}},	//   _הודו_, _bý_, לטר_, prta_
  { {0x34790033,0x5a9b000a,0x54450015,0x7a53012c}},	//   абвэ_, _תשוא, ينسك, _رضوا
  { {0xcd020050,0x98a40001,0x34940010,0x18a40e88}},	//   mość_, _није, паср, _најм
  { {0x24580080,0x660e0d25,0x41e70029,0x44292924}},	// [8e30] щать_, babk, مساف, rga_
  { {0x5b7b00b2,0x44294044,0xa5f90054,0x67200030}},	//   ארמא, sga_, _њену_, ámje
  { {0xcd020050,0x7ce70061,0x442900cb,0x6483007c}},	//   ność_, _hırv, pga_, _hõim
  { {0xf8c9005d,0x657a0b12,0x859a004f,0x0000006a}},	//   रतिय, äthe, _כשתו,
  { {0x1eea002b,0x629e007c,0x3f692333,0x0000006a}},	//   لونی_, bipo, рило_,
  { {0xcd020050,0xee380036,0xb3ba000a,0x629e016e}},	//   kość_, йні_, _כמרכ, cipo
  { {0x265a00b2,0x6483007c,0x91650021,0x7c294045}},	//   יכװא, _lõim, _ظهره, tger
  { {0xa2b9005d,0x7afb4046,0xcd02002a,0x7c294047}},	//   ्तव्, tput, dość_, uger
  { {0x200f007c,0x68ea0012,0x7c294048,0x15fb0065}},	//   magi_, _aufd, rger, ्रार_
  { {0x827600b2,0x78ad0e95,0x8fa400a2,0x7afb013c}},	//   ַערע_, _ajav, _عمله, rput
  { {0x9f460084,0xddab0080,0xcd02005c,0xb9c500e6}},	//   lboð_, _стал_, gość_, تقدي
  { {0xfd100029,0x200f0020,0xc1560008,0x7afb1581}},	//   _أجل_, nagi_, קשרו_, pput
  { {0xe73a0001,0x37760010,0x61c6021e,0xc1c6021e}},	//   јег_, цынс, _वर्ष, _वर्ग
  { {0x200f4049,0x66c000f2,0x96ba2df1,0xcd02002a}},	//   hagi_, yöku, руму_, bość_
  { {0x200f0020,0x7aeb002e,0x88c60015,0x7a88000a}},	//   kagi_, _hugt, _وتعل, _לָקַ
  { {0x07a60036,0x08c30063,0x7ae3404a,0x332002b3}},	//   _майн, _общн, _hint, trix_
  { {0x200f0005,0xc6d60015,0x8bac000a,0xdd3b002a}},	// [8e40] dagi_, _وتخت, ְׁבִ, nąłe
  { {0x66c0002e,0x6d4a0026,0xd3950033,0x78ad0816}},	//   töku, ywfa, мiтэ, _zjav
  { {0xb5ca0086,0x68e40020,0x4fea0579,0x629e404b}},	//   _خودم_, _kiid, амен_, ripo
  { {0x69c30176,0x200f0020,0x7f860115,0x7ae311ec}},	//   _myne, gagi_, يلان, _lint
  { {0xcd02005c,0x6d41404c,0x883b000a,0xa2cb000b}},	//   zość_, _apla, שתנו, _तीव्
  { {0x68e40005,0xddc100bd,0x32cf0064,0x7ae33653}},	//   _liid, _dolž, tüye_, _nint
  { {0xa2b9005d,0x4118000a,0x200f0273,0x6e030015}},	//   ्तर्, _לֵּא, bagi_, ذِين
  { {0x68e4022d,0x6d5c00dc,0xd197000a,0xddc8002a}},	//   _niid, _áram, _וכלי_, _padł
  { {0xcd020050,0xc4d30008,0x3ea609ef,0x7ae30d2c}},	//   wość_, וגה_, _диаг, _bint
  { {0xd90e0086,0xcd02005c,0x5a340608,0xbe860015}},	//   نیت_, tość_, чнот, _بجرو
  { {0x7ae304f9,0x15fb000b,0xec4a006b,0x6483007c}},	//   _dint, ्रसर_, _взел_, _sõim
  { {0x57f4010f,0x6c340086,0x69c3232a,0x7ae3404d}},	//   мпют, _رفتا, _dyne, _eint
  { {0x629c0079,0x69c30012,0x6d670091,0x9874071f}},	//   _omro, _eyne, įraš, фляц
  { {0x64830005,0x69c30026,0xaa570015,0x19943952}},	//   _võim, _fyne, _ولنا_, _наля
  { {0x80da005d,0x29111724,0x7cf8000a,0x29070034}},	//   बगाइ, ázat_, מִּק, _gwna_
  { {0xd7fb010f,0x7aeb02f2,0x7ae3404e,0x38a40030}},	//   _тук_, _yugt, _zint, tűre_
  { {0x53340063,0x7ae3003f,0x787a000a,0x78bd404f}},	// [8e50] метт, _yint, _הָיו, mosv
  { {0xd251003b,0x64830005,0xf2c70010,0x200f005c}},	//   عنا_, _kõik, ісан, wagi_
  { {0x75830086,0x61550015,0x00e5002b,0x8c3d0061}},	//   _غیرم, ثنائ, ستای, lişe
  { {0x66c000c0,0x78bd01a0,0xa2cb000b,0x55ba000a}},	//   sökt, nosv, _तीर्, _למתו
  { {0x64830005,0x6d5c00dc,0xaf0400fd,0xaf370015}},	//   _lõik, _áraj, дпіл, ترضت
  { {0xe7e3005d,0xa3d8000b,0x02450015,0x200f4050}},	//   _गणना_, ाधर_, _عَزَ, sagi_
  { {0xbf0b005d,0x661a005c,0xd37b0033,0xdcf8003d}},	//   _सौरभ_, ótki, лiчы, dzvē
  { {0x69c3005c,0x6d4100bd,0x20180015,0x8c3d0061}},	//   _ryne, _vpla, _وتقع_, kişe
  { {0x629c0026,0xbf670015,0x2d8a0012,0xb436000a}},	//   _ymro, _بدأو, _üben_, הָיו_
  { {0x8c3d0064,0xee780029,0x64ac0064,0xb9b5006b}},	//   dişe, _وصلت_, eğil, зсмъ
  { {0xf27c0053,0x6d4116e1,0x527c004c,0x2d98001a}},	//   ירזש, _upla, ינזא, _þrep_
  { {0x7aeb002d,0x7cd90080,0xdb39002b,0x69c30227}},	//   _tugt, _умер_, _هستش_, _vyne
  { {0x69c30026,0x68e40607,0x7783006b,0xba450046}},	//   _wyne, _viid, еляз, _průč
  { {0xfe670074,0xaa4100f2,0x8afa0008,0x24f600fd}},	//   رد_, ärää_, _הפסק, зчар
  { {0xf4840086,0x27ed3bd5,0x2a670c4e,0x68e40072}},	//   واری, žena_, _innb_, _tiid
  { {0x66c000f2,0xd91a000a,0xb97a000a,0x7ce70061}},	//   töks, _הוקל, _לנצי, _hırs
  { {0x03260010,0x7c3b003f,0x7ce70061,0x07a612ae}},	// [8e60] ядан, ifur, _kırs, _хапн
  { {0x66c00030,0x7ce70061,0x9c7c0085,0xaaa9004f}},	//   röks, _yırt, _vuči, צֹּ֖
  { {0xf67b0008,0x867b000a,0x66c00123,0x067b000a}},	//   _האימ, _הריו, söks, _הניל
  { {0x6aa100b8,0xd12f002b,0x62854051,0x0000006a}},	//   hilf, طمه_, akho,
  { {0xd00f03c4,0xbf130015,0xafba006e,0x79810034}},	//   اله_, فونب, حطاط_, hylw
  { {0x62854052,0x6d5c0030,0x29180030,0x629c01d7}},	//   ckho, _árak, árak_, _umro
  { {0x61430558,0x7c3b3c54,0xc695004c,0x6aa101c2}},	//   _пера, ffur, ואװ_, dilf
  { {0xd00f003b,0x399c006f,0x1d070054,0xdbf10046}},	//   _ملف_, násť_, чећи_, břík
  { {0x769000f2,0x3d08000b,0xa08b000a,0x7ce70061}},	//   _käyd, _सबके_, _פְלִ, _sırt
  { {0xd357000a,0x27e90034,0xbf130015,0x4efb000a}},	//   ליפי_, _sgan_, _أولب, _להמו
  { {0x6f0900b8,0xe8e00092,0xf237000a,0x8c4608d7}},	//   _zwec, _ngồi_, הריץ_, _неже
  { {0x64830005,0xab2a1561,0xdce30091,0x29020046}},	//   _võik, _года_, dynė, ďka_
  { {0xac970029,0x2bdb005d,0x6383002e,0x7ce70064}},	//   _عنها_, मेदा, _mínú, _fırs
  { {0x672000dc,0x7bdb000f,0xee2e005e,0x8c3d0061}},	//   ámja, _הקדו, внi_, rişe
  { {0x9a3b0008,0x2a3b000f,0x6a3b000a,0xaa3b000a}},	//   _התוק, _העומ, _הגופ, _התוח
  { {0xacfb000a,0x9862002a,0x79850015,0xddc8002a}},	//   מהלכ, _róć_, _تؤهل, _bodź
  { {0x3869002d,0x9cd7000a,0x389c000a,0x66c00030}},	// [8e70] _inar_, לולה_, _ליהנ, rökr
  { {0xedf8014e,0x47340015,0xf8bf0f66,0x66c02f34}},	//   ुरोध_, _أريز, loé_, sökr
  { {0xc5fb005d,0xc0cb0098,0xc0350054,0x34950822}},	//   ्रीय_, буде_, днеј, _жанр
  { {0xdbf10046,0xa3e7000b,0x0000006a,0x0000006a}},	//   třík, _पलट_,   ,
  { {0x3dc50026,0xef18005e,0xf2070033,0xb4d90065}},	//   _sylw_, змі_, _няво, ाषी_
  { {0x6e940784,0x1758000a,0x7e2b005e,0xa2e40033}},	//   ничу, פסור_, сіда_, _поўд
  { {0x2d8a0012,0x301501ca,0x3869089c,0x0000006a}},	//   _übel_, _одвр, _onar_,
  { {0xdbf10089,0x6aa10034,0x32134053,0x7e680383}},	//   přík, wilf, laxy_, _endp
  { {0xabc20053,0x2bb90015,0xdfd10015,0xe452000a}},	//   _האָבן_, غابة_, _شيئ_, דֶת_
  { {0x38690251,0x2736002e,0x38b9006f,0x89a91215}},	//   _anar_, væn_, méry_, жков_
  { {0x91f6000a,0xbc1900ce,0x280a0058,0x7e44009b}},	//   ומתו_, _ділі_, يْدَ_, _яхте
  { {0xc68900b2,0xe73a0afa,0x186a0146,0x49980033}},	//   _דא_, оем_, цами_, ятыя_
  { {0x9b450086,0x2cad3bd6,0xdc88004f,0xfb85009a}},	//   _آنتو, mned_, _צְעָ, _تدای
  { {0xcb120008,0xdce30007,0x49b8002b,0x2cbf34fe}},	//   _ילד_, tynė, _کاهد_, loud_
  { {0x2cad0041,0x66e3331b,0xc9920058,0x0000006a}},	//   oned_, тора, _للوظ,
  { {0x130a0010,0x2cad1844,0xd3f401f3,0x272a070c}},	//   жнай_, nned_, гiст, _джип_
  { {0x2cad0041,0xae0d000b,0xaad9000a,0x4e0d000b}},	// [8e80] ined_, हरान_, ַחֲר, हराई_
  { {0x0219008f,0x2cbf09f2,0x0caa000b,0x2cad0046}},	//   зіць_, houd_, _छद्म, hned_
  { {0x63a90084,0x74f60015,0xc5f3000a,0xe2a90015}},	//   _þenn, _تأخذ, _בדת_, ساكن_
  { {0xd0950010,0x601a02e1,0xd12f0015,0x7df8000b}},	//   ншчы, іцер_, ؤمن_, ुर्ग_
  { {0x7e7a010b,0x769000f2,0x37a9000a,0x64a50073}},	//   _potp, _täyd, ּדוּ_, rėit
  { {0xccfa0001,0x6726001a,0x7e53005e,0xce7700ce}},	//   оћи_, irkj, квіє, мбії_
  { {0xdd900029,0x0000006a,0x0000006a,0x0000006a}},	//   طوة_,   ,   ,
  { {0x2cad0041,0xcb540001,0xc19b000a,0xb19b000a}},	//   gned_, евић, _ושלי, _וילכ
  { {0x8c4300d0,0x200601c2,0x22583ded,0x93fb004f}},	//   тење, mboi_, _kark_, חלפי
  { {0x6f0202c1,0x2cad00da,0x69cf002a,0x9e660067}},	//   mpoc, aned_, ęcen, _تارن
  { {0x22584054,0x29184055,0xd9140033,0x2a970015}},	//   _mark_, éra_, эдны, بئية_
  { {0x64830020,0x3b860248,0xf7950033,0xdb19002a}},	//   _hõiv, _олег, еамэ, _czwó
  { {0xa774005e,0x6483007c,0x27ed4056,0x87070b9b}},	//   вляч, _kõiv, ženo_, ьяне
  { {0x3b530036,0x95fb000b,0x7afd24ac,0xda970015}},	//   _шкір, ्रेट_, íste, _يخوض_
  { {0x7aef032c,0x7ce70061,0xe4e7005e,0xfa33012c}},	//   íctv, _kırp, діан, _شرود
  { {0x94ab0033,0x20c7007c,0x2bdb000b,0x6483007c}},	//   ітва_, lõiv_, मेवा, _lõiv
  { {0x22581d4f,0xd4e402da,0xe3c40058,0xd25b0138}},	// [8e90] _bark_, тюри, نْفَ, жце_
  { {0xdcee0046,0x2b4601c2,0xc53900ce,0x0000006a}},	//   íděn, _mpoc_, _епох_,
  { {0x2258259c,0x49d4000a,0x41e40138,0x0000006a}},	//   _dark_, תֵּן_, віца,
  { {0x628e3639,0x2eb9000b,0x7fd501f3,0x2492002a}},	//   _elbo, ेत्त, нілі, chym_
  { {0x22580064,0x44f50123,0xaf4b0015,0x2898000a}},	//   _fark_, _hå_, تشال_, ודאן_
  { {0x2cad003e,0xe732000a,0x8c3d1d56,0x8d551208}},	//   wned_, רֵא_, dişa, етич
  { {0xc2c40029,0x20e80061,0x3f890091,0x2d94006b}},	//   _شيفي, _işin_, šau_, кръс
  { {0x44f5169b,0x8c3d0011,0xa2b9000b,0x6726001a}},	//   _må_, fişa, ्तक्, yrkj
  { {0x2cad003e,0xff280029,0x6615006f,0x5ba90248}},	//   rned_, _يكفي_, kazk, яким_
  { {0x17fa005d,0x8fa40054,0x8e990058,0x644d0416}},	//   ूर्व_, _рађе, _عناء_, heai
  { {0x44f54057,0xc7a9000a,0xa96918fc,0x24890072}},	//   _nå_, _פב_, чина_, kkam_
  { {0xf1b200a3,0x5c070033,0xddc80046,0x2d510085}},	//   רסט_, _цяжа, _nadř, _iše_
  { {0x8c3d0011,0xeb8e4058,0xe0d2004c,0x661501c2}},	//   cişa, _си_, טײט_, fazk
  { {0xba3900b2,0x20060011,0x24890024,0xad19000a}},	//   _זײַט, zboi_, ekam_, ּוּר
  { {0x49bb0074,0x6f020050,0xceb2103d,0x24920026}},	//   _باشد_, zpoc, אים_, thym_
  { {0x44f501d1,0x644d0152,0xa99a000a,0x225811ff}},	//   _då_, geai, _מבצר, _sark_
  { {0x67560029,0xd80b000a,0x2a39000a,0x225815fc}},	// [8ea0] _أخبر, _מִיָ, ּעֲמ, _park_
  { {0x44f518e0,0xc2c6002b,0x20060034,0x78a64059}},	//   _få_, رياي, wboi_, likv
  { {0x6483007c,0x44f51fbc,0x6b8d002a,0xe5a6405a}},	//   _rõiv, _gå_, _żagl, _чини
  { {0xb4fb004f,0x0000006a,0x0000006a,0x0000006a}},	//   _מפטי,   ,   ,
  { {0xde58022a,0xb4be000b,0xd5af002b,0x2258007c}},	//   далі_, ेती_, _نفی_, _tark_
  { {0x471b00b2,0x764e405b,0x171b004c,0x753c002a}},	//   לונג, neby, לונע, otrz
  { {0x02be005d,0x64830020,0x52be005d,0x6f020819}},	//   ्तीन, _võiv, ्तीस, spoc
  { {0xbd430029,0xc0e32044,0x764e0034,0x6f02405c}},	//   انيي, _боск, heby, ppoc
  { {0xd336000a,0x5b030015,0xab94005e,0x0b8a01c5}},	//   ׂרֵה_, هِيم, типі, яски_
  { {0x6fb30029,0xd8f80036,0xadba0029,0xb4be005d}},	//   _إمكا, мної_, _فهذا_, ेतु_
  { {0xe895008f,0xf8ac0092,0x66150089,0xd91709b1}},	//   вань, ưới_, vazk, нья_
  { {0x1010005d,0x60c2187b,0x27ed0293,0x6fd7000b}},	//   ारिश_, noom, øen_, _बरमू
  { {0xe7870036,0x44f5405d,0x753c08f8,0x6c7b000a}},	//   хуно, _så_, etrz, _מראד
  { {0x15eb005e,0x44f518e0,0x2284001a,0x764e0723}},	//   яємо_, _på_, _köku_, geby
  { {0x66150d55,0xb4be000b,0x08f70015,0x04671f61}},	//   razk, ेतू_, _كريب_, нтам
  { {0x39130063,0x6f190026,0x4432405e,0xa9570058}},	//   _смър, yswc, ggy_, _أجور_
  { {0x9259000d,0x644d0c24,0xd808000a,0x88bc000a}},	// [8eb0] маат_, reai, _אִתָ, _מזהי
  { {0x6d48405f,0x21250015,0x66d2001a,0x673d0079}},	//   _opda, َّذِ, lækn, mtsj
  { {0x672f005c,0x26c30007,0x644d3186,0x3015005e}},	//   lucj, mojo_, peai, вдер
  { {0x251a0008,0x351a000a,0xd058005e,0x7aea22a5}},	//   _קורא, _קורנ, ерші_, _lift
  { {0x84160008,0x673d0171,0x02d90015,0xa022007c}},	//   _בקרב_, ntsj, _يوجب_, ööaj
  { {0x6aba005d,0xf5ab000a,0x26c34060,0xc10500c3}},	//   ईकोर, ּבֵּ, nojo_, _لوسي
  { {0xd658039e,0x5ff50a0b,0xc5f4000a,0x6cd9029b}},	//   גיות_, _азбу, נדק_, мфис_
  { {0x2d510089,0x764e005c,0xd0d5006b,0x672f002a}},	//   _vše_, zeby, _робъ, kucj
  { {0x9e15008f,0xddeb002b,0x2d81007c,0x8c3d0045}},	//   _адзі, _فراه_, äheb_, bişn
  { {0x7b4400e6,0x26c30091,0x753c002a,0x09e522ff}},	//   ائيل, jojo_, ytrz, копн
  { {0x9e7a00b2,0x69ca0176,0xe9d905cb,0x3ea71718}},	//   _קנעפ, _cyfe, ько_, mint_
  { {0x64830005,0x69ca0026,0x8c3d0011,0x98a60fe4}},	//   _mõis, _dyfe, mişo, тиме
  { {0x7aea003e,0x764e0034,0x69ce006f,0x768b0061}},	//   _fift, teby, ýber, _tüyl
  { {0x64ac0011,0x3ea70251,0xb69b046d,0x60c24061}},	//   işie, nint_, spân, zoom
  { {0x69ca0176,0x291800dc,0x64a64062,0x6d5c001a}},	//   _gyfe, árat_, вава, _árat
  { {0x98a60024,0xb4be005d,0x29054063,0xccf2000a}},	//   bulā_, ेते_, mpla_, שכן_
  { {0x753c0050,0x443208b8,0x3ea70030,0xe2aa0015}},	// [8ec0] strz, rgy_, kint_, واطن_
  { {0x64830020,0xddc80085,0xe10a004a,0x020300ce}},	//   _sõit, _rodž, дежд_, изун
  { {0xc05a0036,0xa2b3005d,0x7bcb0007,0x3ea70251}},	//   діл_, _आदर्, _lygu, dint_
  { {0xfbc70087,0x2eca000b,0xb97a000a,0x3ea74064}},	//   _نت_, ित्त, ונעי, eint_
  { {0x64830020,0x27ad000a,0x60c24065,0x66d201d0}},	//   _võit, ּסוּ, room, næko
  { {0xeaa70029,0x6714000b,0x6d4802d2,0x3ea74066}},	//   _ضع_, तीयक_, _ppda, gint_
  { {0x90c6008f,0xdfd20086,0xc5f30008,0xc693000a}},	//   _абве, _چيز_, סדה_, שאו_
  { {0xdfd20074,0x69ca0026,0x70560115,0x3ea74067}},	//   _نيز_, _ryfe, _جنرا, aint_
  { {0xa03b0053,0x69ca00dd,0xda660015,0xee3a4068}},	//   _קעמפ, _syfe, نادي, _она_
  { {0x63a90944,0xaa66000d,0x78a400dc,0x3ea70537}},	//   _ženk, ттик, _amiv, cint_
  { {0x66d2002e,0x26c31283,0x0217000a,0x6d4825bd}},	//   tækn, vojo_, כחים_, _upda
  { {0x387f09f0,0xa9c30191,0x8c3d01e2,0x672f005c}},	//   ður_, рськ, nişl, tucj
  { {0x26c300df,0xba760015,0x66d202de,0xb87b0046}},	//   tojo_, _لاغت, rækn, emíc
  { {0x91790016,0x29180125,0x99661adc,0x02be0065}},	//   hớp_, áras_, _атил, ्तोन
  { {0xc986009c,0x7c2200bc,0x26c34060,0xcad7000a}},	//   _јули, _kdor, rojo_, _שוות_
  { {0x998c002a,0x3ea719bb,0x8d5b000a,0x79880034}},	//   padł_, zint_, וכלי, mydw
  { {0x03d50088,0x62d90033,0xd6db123a,0xe8d8004f}},	// [8ed0] ужаю, емаў_, _ото_, _בוהר_
  { {0xe3b00015,0xaab4000b,0xe2930015,0x8575052b}},	//   زرق_, ुविक, جذر_, _блох
  { {0x7690022d,0xb6020089,0x68ed00dc,0x3ea70ad3}},	//   _käyn, čáte, _kiad, vint_
  { {0x64830020,0x5f950661,0x9034005e,0x7c220045}},	//   _võis, лиет, ихіч, _ndor
  { {0x389c000a,0x98a60045,0xd024005e,0x96b8002b}},	//   ויאנ, lulă_, рмій, _سایز_
  { {0x0ccb014e,0x2bc6005d,0xaec4022a,0x645d4069}},	//   ात्म, _लड़ा, абіл, _hasi
  { {0x41e402e5,0x867c000a,0x3ea7406a,0xa1950fea}},	//   _віта, ורגו, rint_, _савч
  { {0x799a005c,0x25d80008,0x3dcc0026,0x3ea7406b}},	//   dztw, כוון_, _dydw_, sint_
  { {0x7c840001,0x645d015a,0x2d87406c,0x2a150174}},	//   рује, _masi, syne_, льнё
  { {0x6eda000b,0x645d25a5,0x1a050138,0x99770073}},	//   _पीपु, _lasi, ыпом, rąža_
  { {0x8c3d01e2,0x44391e23,0x68ed406d,0x645d406e}},	//   lişm, _ocs_, _biad, _oasi
  { {0x645d034c,0xe45f0123,0xccf2000a,0x98a40091}},	//   _nasi, _skön_, _הכא_, įjį_
  { {0x7bcb01e2,0x68ed013c,0x8c1a000a,0x2918001a}},	//   _uygu, _diad, _נוסי, árar_
  { {0x290500c0,0x8f9a000a,0x645d13e8,0x6a240067}},	//   ppla_, גישי, _aasi, _نفهم
  { {0x98a60011,0xceb2000a,0xd6cf0015,0x8c3d0061}},	//   gulă_, ציל_, سقف_, yişl
  { {0xa3ea13ab,0x645d3cd5,0x52be000b,0x64a315cf}},	//   едба_, _casi, ्त्स, баса
  { {0x6b9b00b8,0xe1f20015,0x6b89088a,0x232704d7}},	// [8ee0] nzug, مسا_, nyeg, лоти_
  { {0x645d003e,0x68ed003f,0x979b000a,0x60c90309}},	//   _easi, _ziad, _נשיק, _akem
  { {0xc1ba0015,0x645d406f,0x442201d7,0xa63b000a}},	//   رائط_, _fasi, _tdk_, _אגיר
  { {0x3dcc0026,0x60db2416,0x645d4070,0x1016012c}},	//   _rydw_, _chum, _gasi, اباد
  { {0x8c3d0064,0x69ca005d,0x1e140010,0x9e140033}},	//   rişl, _सुनी, амля, адлі
  { {0x645d4071,0xdfcf0015,0x527600e2,0x0000006a}},	//   _zasi, أيه_, _суму,
  { {0x765e003f,0x645d4072,0xc0aa0015,0xc536000a}},	//   _mapy, _yasi, _كارل_, אָ֥ה_
  { {0x100a0029,0x27ed37e6,0x6b9b0012,0x6aa80034}},	//   _سترى_, ženi_, fzug, widf
  { {0x68ed002c,0x7b760029,0x79880026,0x7c830080}},	//   _riad, اطعا, wydw, суще
  { {0x68ed4073,0xdee602ed,0x3dcc0416,0x7c2401ec}},	//   _siad, _сози, _tydw_, _ķiru
  { {0xaa630010,0x6277004c,0x6df30015,0xe873002b}},	//   стык, אגיא_, _اكما, مندگ
  { {0x23b4005d,0xbb5600a2,0x64b70085,0x219b000a}},	//   ंपाद, _منصب, ećin, תבטא
  { {0x2ca60134,0x96f8006b,0x57a72085,0x321a00aa}},	//   _imod_, леят_, ушна, kapy_
  { {0x68ed0050,0x645d003f,0x0000006a,0x0000006a}},	//   _wiad, _sasi,   ,
  { {0x6594000d,0xa2ba005d,0x68ed0213,0x645d1a37}},	//   бару, ्वन्, _tiad, _pasi
  { {0x7528032c,0x24580a2c,0x6d5a003f,0x69d84074}},	//   ádza, лась_, _msta, _izve
  { {0x291e0024,0x181a002b,0xa4e40033,0x98a60045}},	// [8ef0] lsta_, _شريک_, ёўск, sulă_
  { {0x645d4075,0x60c94076,0x8bd7000a,0x291e4077}},	//   _wasi, _skem, רומו_, osta_
  { {0xda4b000a,0xd5fa000a,0x4155006b,0x21670033}},	//   עֲמָ, _בפתר, рвес, ытаг
  { {0x765e005c,0x3cfb005d,0x291e094b,0x20cb0015}},	//   _zapy, _लंबे_, ista_, رباي_
  { {0x833500b2,0xd9d1000b,0x889c000a,0x441a000a}},	//   _דאָס_, _हर्ट, עבדי, _בורס
  { {0x291e4078,0x96fc000a,0x7ee40015,0x8c3d0061}},	//   ksta_, עלות, مكنن, rişm
  { {0xb638000a,0x10070033,0x69ce068c,0x60db4079}},	//   ארוס_, _бязм, übel, _thum
  { {0x9f050087,0xcf270029,0x291e00c0,0x27e5005c}},	//   _نورو, _مرئي, dsta_, ślny_
  { {0x8c3d0064,0x291e407a,0x30840015,0x6d5a0390}},	//   lişk, esta_, _القف, _esta
  { {0x39450036,0x6b9b00b8,0x7aa5017a,0xea86004a}},	//   аног, rzug, риоз, ибыл_
  { {0xade1014e,0x291e407b,0xd945058b,0x6b9b0012}},	//   गेशन_, gsta_, шени, szug
  { {0x29030024,0x7d7a015b,0x6cfa000a,0xb4bf000b}},	//   īja_, _ברעג, _ספנס, इवो_
  { {0x291e407c,0xb8fc000b,0x765e35e2,0xa6aa0058}},	//   asta_, _ती_, _papy, ناسق_
  { {0x6d5a0026,0xf50607be,0xcb9a004f,0x09e5011e}},	//   _ysta, изго, _בסנט, _колн
  { {0x4416000d,0xc8b6004a,0xe61701e1,0x54e60058}},	//   ифат, _вспы, рдс_, لسرق
  { {0x77860063,0x99d403c4,0x765e003f,0x19ba000a}},	//   _влиз, _اتها, _wapy, _במצב
  { {0xd6d20029,0xd3871d82,0xb87b016e,0x765e0091}},	// [8f00] _وقع_, айте_, omín, _tapy
  { {0x3860003e,0x769000f2,0x42070001,0xb7db000a}},	//   _hair_, _käym, инуо_, _בקפי
  { {0xf67b00b2,0x661c0ab5,0x321a3d86,0x867b000a}},	//   _סאטמ, mark, rapy_, _סרטו
  { {0x351b000a,0x50f30033,0x661c407d,0x504631d5}},	//   _בוטנ, ізіт, lark, редб
  { {0x44fc2a6e,0xdfcf00e5,0x386000e7,0x2d810353}},	//   _hí_, ويم_, _mair_, ähen_
  { {0x44fc0092,0xc7d7000a,0x66d202de,0x291e407e}},	//   _kí_, בוני_, dækk, ysta_
  { {0xb87b0089,0x44fc0089,0xc0e6005e,0x66d2001a}},	//   dmín, _jí_, _вовк, tækj
  { {0x44fc3167,0x661c00d9,0x6d5a04c0,0xcce60015}},	//   _mí_, hark, _vsta, جستي
  { {0x6d5a005c,0x44fc407f,0xa09b000a,0xb7fd000b}},	//   _wsta, _lí_, _סימט, _एलबम_
  { {0x7f3b013a,0x291e0020,0xaa580001,0x661c0509}},	//   _בעמו, tsta_, ћину_, jark
  { {0x44fc4080,0x3f420092,0x291e4081,0x6d5a4082}},	//   _ní_, _hưu_, usta_, _usta
  { {0x28a70036,0xaba70086,0x291e4083,0x3157004c}},	//   ршог, اهیم_, rsta_, ביטן_
  { {0x44fc2cdd,0x38604084,0xdc9b00a3,0x98b8006b}},	//   _aí_, _dair_, _ביאל, рлят_
  { {0x27fe0089,0x3f420092,0x29860080,0x273f0026}},	//   ětna_, _mưu_, _выиг, rîn_
  { {0x3f420023,0xaadb00f3,0x38600ab0,0x69d8003d}},	//   _lưu_, _שחור, _fair_, _uzve
  { {0x38600026,0x316d04c0,0x897b000a,0x98a40054}},	//   _gair_, _čez_, _ירוצ, _мије
  { {0x24580a61,0x7cf50007,0x661c0faa,0x88bc000a}},	// [8f10] шать_, _išre, bark, _שמחז
  { {0x8c3d0064,0xe5c7005e,0xe1670054,0x2167009b}},	//   tişk, _всмо, иђен, итег
  { {0xd5b100e6,0xd5b8034e,0xd0110015,0x66bc004f}},	//   _رفح_, _вся_, كلا_, _במזה
  { {0x3f420092,0x8c3d0061,0x27ed00b3,0xaffd005e}},	//   _bưu_, rişk, ženu_, ходi
  { {0xef0e01f3,0x6f650015,0x44fc04b2,0xe8d8000a}},	//   ям_, إهتم, _zí_, בואר_
  { {0xee380191,0xa1370086,0x51874085,0xa2f6000a}},	//   ині_, _پرسش, _куба, _למשה_
  { {0x8c3d0064,0x51950015,0x64ac0061,0x44fc0016}},	//   lişi, _الأذ, işin, _xí_
  { {0x45b80008,0xb5b8000a,0x40344086,0xa5b8000a}},	//   יפול_, ילוח_, _месс, ילוק_
  { {0xdd3b005c,0x8c3d0061,0xc478000a,0x661c089c}},	//   ląże, nişi, שתחו_, yark
  { {0x3860001c,0x66d20134,0x201d4087,0xd356004f}},	//   _sair_, rækk, lawi_, ציתי_
  { {0xec150086,0xb87b0107,0x661c0a6f,0x386002ff}},	//   _هواد, rmín, vark, _pair_
  { {0x44fc024b,0x6c840015,0x70a5000b,0x661c4088}},	//   _rí_, _وللم, _खगोल, wark
  { {0x2d8a018b,0x9cd6000a,0x44fc4089,0x7e61408a}},	//   _über_, _פונה_, _sí_, _kalp
  { {0x2cad408b,0xe9a8002b,0x66030354,0xaac40015}},	//   lied_, ادین_, зпра, _وتون
  { {0x38600026,0x04960010,0x201d1d41,0x6d43238f}},	//   _tair_, браў, kawi_, ntna
  { {0x3860002f,0x2cad003e,0x44fc408c,0x201d005c}},	//   _uair_, nied_, _ví_, jawi_
  { {0xd467250c,0x201d0375,0x4226005e,0xa2d60015}},	// [8f20] щите_, dawi_, йдав, ميرت
  { {0xfbd2000a,0x44fc408d,0x2cad02f7,0x7de20030}},	//   לתן_, _tí_, hied_, nísé
  { {0x3218003e,0x3f420092,0x44fc002d,0xcad6000a}},	//   _very_, _sưu_, _uí_, צועת_
  { {0x30a50036,0x69da004c,0xb1170015,0xcf260058}},	//   орів, אַדו, صقها_, مرتي
  { {0x6d430023,0x2cad003e,0x64560064,0x083b004c}},	//   etna, died_, meyi, רענל
  { {0x645601e2,0x2480016f,0xfd380015,0x26ca07cb}},	//   leyi, ljim_, لكتب_, nobo_
  { {0x2cad0041,0xf6530008,0x1ea90015,0x248010af}},	//   fied_, פצה_, جاني_, ojim_
  { {0x645601e2,0x24800263,0x67240085,0x91b7004f}},	//   neyi, njim_, _ovij, _הפלא_
  { {0x6d690048,0x9e3a0029,0x6d43002d,0x8e3a0029}},	//   _īpaš, _مساء_, atna, _مسار_
  { {0x6fb30115,0x539b000a,0x260a000b,0xb87b1702}},	//   _عملا, טיפו, ़ुमी_, amíl
  { {0x3d2b0086,0xf27b0053,0x7e7e002e,0x2cad0384}},	//   _متنی_, אריש, öppu, bied_
  { {0x91bb000a,0x63bb001a,0x8c3d0061,0x3eae408e}},	//   רמטי, _þung, yişi, lift_
  { {0xf8040010,0x27ed00f2,0x6724016f,0x248001d7}},	//   ячэн, äen_, _cvij, djim_
  { {0x6724016f,0x95cb0608,0x8b57000a,0x19940418}},	//   _dvij, губа_, _לידס_, _маля
  { {0xceb30632,0x59cf000b,0x04c90015,0x7655002a}},	//   ליש_, _सुपर, لوسي_, rezy
  { {0x8c3d0064,0x3eae408f,0x9727005e,0x6d8b000a}},	//   tişi, hift_, _льод, אָמְ
  { {0xf8b4000a,0x26ca04a5,0x320126d0,0x3eae0013}},	// [8f30] _משק_, bobo_, tchy_, kift_
  { {0xe7180008,0x8c3d0064,0x95c50015,0xe1d90033}},	//   _החזר_, rişi, _ويظه, адзі_
  { {0x6724044c,0x32014090,0x7e614091,0xf1550015}},	//   _zvij, rchy_, _ralp, تَاد
  { {0x228f0061,0x2d81007c,0xf993004c,0xdd3b002a}},	//   _sıkı_, ähem_, הרע_, rąże
  { {0x743a00b2,0x643a00b2,0x7ff40029,0x64ac0064}},	//   _דערװ, _דערנ, أسما, işil
  { {0x171c0053,0x8cab005d,0x999e0091,0x66d2001a}},	//   נווע, _जगहो, netų_, tæki
  { {0x41090008,0xcd280015,0x999e0091,0x201d02f2}},	//   _כִּ֣, مسين_, ietų_, pawi_
  { {0xcf2e0061,0x6d434092,0x7e614093,0x9b05256c}},	//   üğüm_, rtna, _walp, озид
  { {0x6287010b,0x2cad0495,0x6d434094,0x7e614095}},	//   _kojo, ried_, stna, _talp
  { {0x64560064,0xa9254096,0x3f8f0026,0x4ea705f8}},	//   zeyi, одол, mygu_, _урба
  { {0x3f8f0176,0x2cad003e,0x6724016f,0x69c60064}},	//   lygu_, pied_, _svij, şken
  { {0xdb510015,0xcd9a004c,0xe8f60033,0xd7ea1377}},	//   _يَا_, _דױער, ўля_, имне_
  { {0x6456007f,0x0000006a,0x0000006a,0x0000006a}},	//   veyi,   ,   ,
  { {0xd4910023,0xa96905b3,0x8e79000a,0xbae50015}},	//   ền_, _вика_, ׁנָה, _بكتي
  { {0x64560064,0x20c9000b,0xa2ba000b,0x248000bc}},	//   teyi, िकाध, ्वस्, tjim_
  { {0x7c3b4097,0x776d3b52,0xa4460033,0xdbd4039f}},	//   ngur, _frax, ўнад, _zúñi
  { {0x6724016f,0x64560061,0x2baf000b,0x52aa0d7d}},	// [8f40] _uvij, reyi, _जेमा, авам_
  { {0xd36f0029,0x64560064,0x2492006f,0xeab5004f}},	//   ضهم_, seyi, skym_, חִ֣י_
  { {0xf7720086,0xd677000a,0x1677004f,0xd4160058}},	//   _راک_, _ותיק_, _וגיל_, _وبحث
  { {0xb9cc00b2,0xd46a0001,0x36360086,0xe0d7005e}},	//   נזאָ, _тиме_, _ارکس, овх_
  { {0x44204098,0x3eae0dca,0xa116009a,0x4367009b}},	//   mai_, tift_, _ژوست, _даян_
  { {0xd2520029,0xc5fa000a,0xd4810054,0xddc10091}},	//   _تنس_, ׁפְט, _шeтњ, _galū
  { {0x867b000a,0xbea30004,0x3eae10c7,0x4c9400eb}},	//   ירסו, ќајк, rift_, зийс
  { {0xc5f30008,0xeb4a08fc,0xab5c004c,0x44204099}},	//   ודו_, ачок_, _מאַכן_, nai_
  { {0xee3a0036,0x61050007,0x69d50399,0x4420409a}},	//   _внз_, _vėle, üzen, iai_
  { {0x20e80064,0xfa8a0080,0x3377000a,0xcfa90015}},	//   _eşit_, рсий_, קעים_, _طاقم_
  { {0x32570008,0x4420409b,0x69ca000b,0xa3ac000b}},	//   חסים_, kai_, _सुशी, _केस_
  { {0x4420409c,0xd00600c3,0x776d409d,0x48ab13d0}},	//   jai_, عل_, _prax, ртом_
  { {0x7cf50007,0x0f57004c,0x999e0091,0x4420333e}},	//   _išra, ֿילם_, tetų_, dai_
  { {0x24550092,0x6f79000a,0xbb3b004f,0x0000006a}},	//   _ấm_, צְרו, _כעדי,
  { {0xbae30029,0x88c70015,0x94770015,0x999e0091}},	//   _تكوي, _وتبل, يدرا, retų_
  { {0x4420409e,0x4815004a,0x62873165,0x0000006a}},	//   gai_, _эмис, _sojo,
  { {0x8c3d062c,0xe3b00015,0xc7fa000a,0xddc11cfa}},	// [8f50] mişt, نرك_, _לִיר, _palū
  { {0x8c3d409f,0x416b0001,0x442000dd,0xd25b00d0}},	//   lişt, ијем_, aai_, јца_
  { {0xddc10024,0x27f40089,0x442040a0,0x865a000a}},	//   _valū, čanů_, bai_, _הדתי
  { {0x8c3d0011,0x6287002a,0xb97b000a,0xa9110030}},	//   nişt, _wojo, ינבי, _tööő_
  { {0xa2ba005d,0x547a0008,0x9f050015,0xd47a015b}},	//   ्वश्, _הטרו, أوتو, _הארל
  { {0xcee800e6,0x12fa000a,0x9738000a,0x0ea8005e}},	//   يرون_, _להשב, קרוא_, окій_
  { {0x78ad0005,0x8cc7005d,0xa2ba005d,0x8c3d0061}},	//   _omav, ावलो, ्वर्, kişt
  { {0x25bc000a,0x7c200030,0xec791528,0x7c3b40a1}},	//   יצומ, gamr, спи_, ugur
  { {0xbf1503c4,0xdaa9006b,0xbad50033,0x999e0030}},	//   _رواب, йвид_, зіны, detű_
  { {0x539c000a,0x3376000a,0x7c3b40a2,0xfe730015}},	//   ייחו, פעתם_, sgur, _تدر_
  { {0x644f005c,0x88ca0457,0x1eea002b,0x7690008c}},	//   _obci, йлов_, _اولی_, _käyv
  { {0x8c3d0045,0x0000006a,0x0000006a,0x0000006a}},	//   gişt,   ,   ,
  { {0xd5b70023,0xf77200a2,0xfc16000a,0x37760033}},	//   ống_, راح_, _זקני_, чынс
  { {0x442b02c1,0x442008c0,0x4df9004c,0x7ac40054}},	//   _adc_, wai_, מפֿא, _осје
  { {0x0496008f,0xd5b20029,0x75d60015,0x442040a3}},	//   праў, رفر_, سيرا, tai_
  { {0x2be2014e,0x8c3d40a4,0x442040a5,0x442b40a6}},	//   _परमा, mişs, uai_, _cdc_
  { {0xb89b0008,0x883b0008,0xf1fa00e6,0x386f0125}},	// [8f60] _לבקש, _התפו, معات_, _ógra_
  { {0x27e040a7,0xd4f60033,0x442040a8,0x2bce0065}},	//   _izin_, _нямы, sai_, _हँसा
  { {0x68e400d9,0xd5fb0008,0x15fb000a,0x9617000a}},	//   _khid, _לפיר, _להיע, _מקיף_
  { {0xe0d20087,0xe424002b,0x4fea2cb0,0xd0950138}},	//   رزا_, _زکري, бмен_, мшчы
  { {0x6726003c,0x6d5c00dc,0x29180030,0x68f60061}},	//   nskj, _áraz, áraz_, _miyd
  { {0x54360074,0x7c2b40a9,0x999e0030,0x425508a7}},	//   _برگر, _adgr, zetű_, _отст
  { {0x69d50061,0x6e030015,0xa06a0555,0x91e600af}},	//   üzel, رِين, _лава_, _хове
  { {0xc5f30008,0x91bb000a,0x59cf000b,0x63a440aa}},	//   עדה_, _המלי, _सुधर, ozin
  { {0x8fa340ab,0xe4570135,0x207b004c,0x8c3d0045}},	//   _зате, ליקט_, _פאמא, vişt
  { {0x7c2000c0,0x8f9b000f,0x5ea60015,0xd90e002b}},	//   samr, _הימי, _عمال, هیت_
  { {0xade8005d,0x1bb70086,0x8c3d1c8d,0x59cf000b}},	//   टेशन_, قایع_, tişt, _सुदर
  { {0x290a0048,0xdd7b000a,0x6d7b000a,0x7d7b000a}},	//   ība_, _לטבל, _לאבח, _לנבו
  { {0x63a40111,0xd4910092,0x68e4003f,0xe7380010}},	//   jzin, ềm_, _dhid, пеў_
  { {0x7cc115e5,0xf1be005d,0x63a440ac,0x27e040ad}},	//   mēra, ्थान, dzin, _dzin_
  { {0x661e00e8,0xc94f0010,0xa4d5042b,0x63a440ae}},	//   _depk, _яў_, дові, ezin
  { {0x68e40011,0xe45f002e,0x49bb000a,0x672600cb}},	//   _ghid, _mjög_, _למוס, bskj
  { {0xa3e7005d,0xa2f50033,0xdc9b000a,0xb8e30065}},	// [8f70] यें_, дпач, צימל, ौक_
  { {0x979c000a,0x92b70015,0x479c000a,0x76b900af}},	//   _לשחק, أحرا, _ליחס, _флор_
  { {0x2bbe0092,0x63a440af,0x81440015,0x66d2001a}},	//   ịch_, azin, فنلن, rækt
  { {0xa4d9005e,0x78bd00cb,0x21270016,0x7fd502a3}},	//   _фдму_, nnsv, ĩnh_, мілі
  { {0x5f940191,0x2fcb0015,0x644d01c2,0x0000006a}},	//   ницт, حباً_, mfai,
  { {0x7a2900dc,0x644d1f22,0x3e6d0030,0x0000006a}},	//   _kötő, lfai, kötő_,
  { {0xc1050074,0x5f77002b,0x8d540033,0x2ddb0015}},	//   _آوري, _کازر, етыч, حبشة_
  { {0x759c0008,0xfd5e0092,0x644d4067,0xd59c000a}},	//   מיוח, _huyề, nfai, מבול
  { {0x76900945,0xa0c40015,0xfbc5004a,0x68e40034}},	//   _käyt, _أيقو, ьбио, _rhid
  { {0x68e4000c,0x644d0125,0x7ff40015,0x090501d2}},	//   _shid, hfai, _أسفا, мпон
  { {0x8d950087,0x9f9c001a,0x6e231696,0x644d003d}},	//   _تلاش, læða_, manb, kfai
  { {0x672600cb,0x7bce0012,0x7c2b02de,0x78bd2626}},	//   tskj, ßbuc, _udgr, gnsv
  { {0x97da0015,0x644d0125,0x7783006b,0xddc30030}},	//   تبدأ_, dfai, вляз, menő
  { {0x76900945,0xddc30014,0x8afa0008,0x7afd04af}},	//   _näyt, lenő, _והסי, ístu
  { {0x6726158b,0xa50702da,0x644d40b0,0x0000006a}},	//   sskj, деса_, ffai,
  { {0xf9900015,0x843a0015,0x67260123,0x63a440b1}},	//   _حبه_, تكرر_, pskj, tzin
  { {0x661e0064,0x6e2300e8,0x93460033,0x7ce5059d}},	// [8f80] _tepk, kanb, ьнае, mórd
  { {0x236f0084,0xe1f20029,0x776400dd,0x63a440b2}},	//   ægja_, نسا_, _isix, rzin
  { {0x11390010,0x765c09bf,0xf67b000a,0xe45f0123}},	//   зячы_, mery, _ואימ, _bjöd_
  { {0x38ab005c,0x644d002d,0x765c27a8,0x753c002a}},	//   _górę_, cfai, lery, murz
  { {0x9f9c002e,0x9f040015,0x61050091,0x320d0061}},	//   gæða_, روغو, _vėla, _şeye_
  { {0x628300f2,0xc33300a3,0xb355002b,0x765c40b3}},	//   önot, _בוש_, _سیما_, nery
  { {0xadb70086,0x9103000d,0x753c002a,0x84080030}},	//   وهها_, _апсе, nurz, csőí
  { {0x8c430054,0x2baf000b,0x91e340b4,0x0000006a}},	//   веће, _जेहा, _росе,
  { {0xd00f0002,0x7f06002b,0x6af42be2,0x0000006a}},	//   _خلق_, _آذرم, нзиф,
  { {0xed5a005e,0x765c0061,0xee370432,0xd37b05bd}},	//   _моз_, jery, _ону_, קריט
  { {0xe8730086,0xc2370008,0x644d0e18,0xf9c6005e}},	//   نندگ, וריו_, yfai, ьщин
  { {0x9ce5005e,0xadb70058,0x753c0535,0x0000006a}},	//   _зціл, _تهما_, durz,
  { {0xfbe2005d,0xb905005d,0x68110089,0x765c06bd}},	//   _परिम, _बी_, vědč, fery
  { {0xdd860029,0x69ce0064,0xc7f8005e,0x644d0034}},	//   هو_, übes, ьняє_, wfai
  { {0x2a3b000a,0x15eb005e,0x6a3b000a,0x9a3b000a}},	//   _ועומ, юємо_, _וגופ, _ותוק
  { {0x690b000a,0x32d4008c,0x7ce5016e,0xfbe2000b}},	//   _וּזְ, käys_, córd, _पराम
  { {0x644d40b5,0xf8bf4055,0x7e7a0234,0xd81a000a}},	// [8f90] rfai, mné_, _ontp, _מֵיש
  { {0xfd5e0023,0x38690384,0x9f9c002e,0x644d0152}},	//   _quyề, _haar_, væða_, sfai
  { {0x673d40b6,0x75d50015,0xc616004f,0xa1140058}},	//   lusj, _سيحا, _אחתי_, َوْت
  { {0x9f9c002e,0x386900f6,0x61d8005e,0xf8bf40b7}},	//   tæða_, _jaar_, ємця_, nné_
  { {0x7690022d,0xe0d80191,0x386909f2,0x6d4a002e}},	//   _täyt, єві_, _maar_, etfa
  { {0xc332000a,0x9f9c002e,0x9e64042b,0xe732000a}},	//   _תום_, ræða_, квід, אֵה_
  { {0xa2cc005d,0xfaf90007,0x8c95005e,0x7690008c}},	//   तकर्, yvūs_, ерпі, _käyr
  { {0x38690a9c,0x6ac7014e,0x2b150063,0x50670010}},	//   _naar_, रक्र, ньор, _ўтва
  { {0xe452011f,0xf8bf0156,0x9f040015,0x9408004f}},	//   אֶת_, dné_, _لوقو, וּתֵ
  { {0x2eca000b,0xb87b001a,0x673d2f1f,0x89a9024f}},	//   ाकृत, nlíf, dusj, зков_
  { {0xe9d9010f,0x2360002a,0x69250033,0xbd68067a}},	//   яко_, zwij_, эмна, _орце_
  { {0x7cc10048,0xc19a0008,0xf8bf0152,0xf6490008}},	//   mēro, פשרי, gné_, _לצ_
  { {0x3869049c,0x69ce00b8,0x6e210007,0x9b450015}},	//   _daar_, über, _kelb, _أنتو
  { {0x2cbf0020,0x2bb80029,0xddda003d,0x753c40b8}},	//   lnud_, _تامة_, _datņ, turz
  { {0x69d800df,0xf8bf0264,0xe4da0015,0xe5a6011a}},	//   _gyve, bné_, كوست_, хиви
  { {0x2cbf0020,0x673d003c,0xf8bf0227,0x17fa0015}},	//   nnud_, busj, cné_, _عربة_
  { {0xccf20632,0x26d10077,0x7b0c004c,0xe29a012e}},	// [8fa0] רכן_, bozo_, ַפאַ, паа_
  { {0x32d400f2,0x7cc80046,0x2360002a,0x05662ad9}},	//   väys_, měre, rwij_, _звон
  { {0x7d010134,0x644b0144,0x91e6004a,0x6d4a03c1}},	//   _nuls, ògic, хоже, xtfa
  { {0x769000f2,0xd0070033,0xf5370c44,0x64a61368}},	//   _täys, ееце_, _אנטי_, _чама
  { {0x76450176,0xf1d0005d,0x2cbf0020,0x93fb000f}},	//   _ychy, _तुरन, dnud_, _מלכי
  { {0x11d60036,0xdfcf0087,0xf8bf0107,0xe733000a}},	//   _зібр, حيه_, zné_, רֵף_
  { {0xa0a60191,0xc693000f,0x44220375,0xbd870021}},	//   _завд, ראו_, _kek_, فنون_
  { {0x6d4a40b9,0x4d7300e6,0xa3e7000b,0x0ca7004a}},	//   rtfa, اطور, येक_, етьи_
  { {0xf8bf0264,0x6d4a23d8,0x6e210030,0x8eb60015}},	//   vné_, stfa, _felb, _كمرش
  { {0xc33301c8,0x610c0064,0x6e212112,0x0e690015}},	//   נות_, _eğle, _gelb, _يصلي_
  { {0x442200dd,0x2be2000b,0xf8bf40ba,0x76450091}},	//   _oek_, _परवा, tné_, _rchy
  { {0xdd8f0074,0x26f9014e,0x7ce5005c,0x44221e6d}},	//   _دوم_, ंद्र_, tóre, _nek_
  { {0xf8bf1fcf,0xb87b0046,0xeb920015,0x3869250d}},	//   rné_, dmít, _حظا_, _vaar_
  { {0x386900f6,0xf8bf0f1b,0x7c22002d,0x8f9b000a}},	//   _waar_, sné_, _heor, ליכי
  { {0xf1d0005d,0xf8bf0227,0x41d0000b,0x8d2b000a}},	//   _तुलन, pné_, _तुलस, ּ֥לֶ
  { {0x89db0008,0xc4d80001,0x7cc80089,0xb9db000a}},	//   _מחוי, еђу_, běre, _מחוש
  { {0x628e40bb,0x442240bc,0x66c9006f,0x2a7c0546}},	// [8fb0] _bobo, _dek_, eľke, _knvb_
  { {0xd019005d,0x44220020,0x52d80080,0xe3b00115}},	//   दर्भ_, _eek_, емую_, حرف_
  { {0xd13b0063,0xf2c4004a,0x628e1054,0xb87b001a}},	//   яха_, устн, _dobo, rlíf
  { {0x6e21018b,0x7cc10048,0xb4950001,0xa3b50033}},	//   _selb, vēro, _римљ, _абмі
  { {0x6e210b71,0x38180008,0x7d0100e8,0x57fc000a}},	//   _pelb, תקדם_, _suls, פלגו
  { {0x7bd90026,0x539a0008,0xed5940bd,0x7d0140be}},	//   _rywu, _חישו, док_, _puls
  { {0xdca50080,0x2cbf0020,0x6e920054,0x64ac0061}},	//   каки, tnud_, рију, rşiv
  { {0x0b190029,0x628e17eb,0x2cbf0034,0x6e211094}},	//   وقعة_, _zobo, unud_, _welb
  { {0x2cbf0020,0xcc080015,0x2296001a,0x916c0016}},	//   rnud_, رزين_, _sæki_, _tộc_
  { {0xb87b0089,0x2cbf0020,0x3da718a7,0x7cc80046}},	//   hlíd, snud_, _преб, věre
  { {0x89f40010,0x2b580011,0x98a640bf,0x3cfa0065}},	//   ляюц, ărca_, вине, _ऊंचे_
  { {0xf3ff0016,0xfb350033,0x9c64006e,0x91f6000a}},	//   _ngã_, _андэ, _مهمو, כמתו_
  { {0xfc16000a,0xfb85002b,0xeb8e118f,0xda6503ae}},	//   _סקסי_, _جدای, _ти_, _авли
  { {0xfe0e0023,0xceb20008,0x99850029,0x2296002e}},	//   hững_, ֑ים_, _للتو, _tæki_
  { {0xceb2011f,0x442240c0,0x9e48000a,0xa6db001a}},	//   בים_, _pek_, עֲשִ, fuðb
  { {0x161e000b,0x628e40c1,0x0000006a,0x0000006a}},	//   _बजकर_, _sobo,   ,
  { {0x4422049f,0xe8d7000a,0xd8d7000a,0x628e1619}},	// [8fc0] _vek_, _בוקר_, _שופט_, _pobo
  { {0x27fe0046,0x64ac0061,0xb87b0046,0x24890091}},	//   ětnu_, eşit, smít, ajam_
  { {0xa69b0008,0x442240c2,0x5117005e,0x67290046}},	//   _חשיפ, _tek_, воєю_, šejt
  { {0xdd92009a,0xc0570138,0x0000006a,0x0000006a}},	//   یوش_, віш_,   ,
  { {0xdfd2003b,0x8f540015,0xb033005e,0x78bd016e}},	//   جيش_, انتش, рніш, érvi
  { {0x5f93009c,0x6e9400e6,0x7c220375,0x66ad000a}},	//   ришт, طلبا, _seor, ּיהֶ
  { {0x3f800011,0xed570431,0xf6530008,0x11390033}},	//   ţiu_, вој_, יצג_, _пяты_
  { {0x61e301e2,0x7ce5016e,0xc0e6004a,0xdf2a0015}},	//   ünle, vórc, _робк, _يأذن_
  { {0x3dd2005c,0xd0750015,0x7ce5002a,0x8af8004a}},	//   ływ_, _حدّث, wórc, ннис_
  { {0xbbe2014e,0x7db60054,0x60c20def,0xa3e70065}},	//   _परीक, _исец, lnom, येट_
  { {0xe8950010,0x60c20003,0x69cf0045,0x5d86006e}},	//   гань, onom, şcen, _جلال
  { {0x60c206f5,0x6d5a01e2,0x64ac0064,0x2db7004f}},	//   nnom, _ipta, işis, _בלבן_
  { {0xab9a002b,0x60c240c3,0x0000006a,0x0000006a}},	//   _تخار_, inom,   ,
  { {0x3f86016e,0xf9920058,0x0000006a,0x0000006a}},	//   ixou_, _نبع_,   ,
  { {0xddda0089,0xec0f0092,0x8505002b,0xe4d700c3}},	//   _patř, iếng_, اورن, نترب
  { {0x24890024,0x0000006a,0x0000006a,0x0000006a}},	//   ujam_,   ,   ,
  { {0xd3700029,0x672d00bd,0x33750033,0x5347006b}},	// [8fd0] يهِ_, _uvaj, ыгар, ъхва
  { {0x22470014,0x27e40020,0x60c240c4,0x82340015}},	//   ünk_, ümne_, enom, لرما
  { {0xc6920008,0x98ad0007,0x7ce50125,0x96b8002b}},	//   _האי_, ardą_, hóra, _جايز_
  { {0xc9530053,0x60c240c5,0x80d400ce,0x0000006a}},	//   ימע_, gnom, ації,
  { {0xd4910023,0xc43a013a,0x7ce5002e,0x6d5a18a6}},	//   ều_, _אתרי, jóra, _apta
  { {0x4429022d,0x38a2002d,0xfe450036,0x7cf50007}},	//   laa_, _móra_, унко, _išri
  { {0xf2d20008,0xd6580008,0xb87b016e,0x290a06a9}},	//   _העם_, דיות_, ilíb, íbal_
  { {0x27ed0089,0x44290df8,0xd5fc000a,0xc5fc000a}},	//   ženy_, naa_, ופור, ופוט
  { {0xddc10089,0x7b750087,0x7ce50125,0x5fb7000b}},	//   _dalš, اطبا, góra, _अधिल
  { {0xc3340008,0x2fc0002d,0x442911c7,0xcda90015}},	//   בוץ_, úige_, haa_, _كهذه_
  { {0x442940c6,0x26c300bd,0x2b4d40c7,0xad670058}},	//   kaa_, dnjo_, stec_, _جاءه
  { {0x442940c6,0xe73a40c8,0x3156004c,0x3da41b5d}},	//   jaa_, нем_, נירן_, _труб
  { {0xa3b30231,0xb8cc000b,0x0076000a,0x9b74002b}},	//   _झेल_, _गत_, אתרי_, _پانص
  { {0xceb20008,0x98a6003d,0x5fb6000b,0xd9450bb1}},	//   ֖ים_, tulē_, _आइसल, _беки
  { {0x4429000c,0xceb220c1,0x64a640c9,0x610c0061}},	//   faa_, זים_, гава, _oğla
  { {0xb87b0264,0xc4c50015,0x26c300bc,0x64ac0045}},	//   smír, لتقو, anjo_, eşir
  { {0x38a2005c,0xb87b0046,0x78a40573,0x64441f76}},	// [8fe0] _góra_, blíb, _iliv, rgii
  { {0x7c290026,0x610c0064,0x60c2002a,0x672f0046}},	//   haer, _ağla, wnom, řijí
  { {0xd12f0015,0x7ce50030,0x64c600c3,0x99e9000a}},	//   كمل_, zóra, _ميدل, תַּ֥
  { {0xc2090008,0x673b40ca,0x2edc000b,0x00da00c3}},	//   לה_, šuje, यत्त, ربات_
  { {0x14d7013a,0x60c240cb,0x7c2940cc,0x0000006a}},	//   _תוכל_, rnom, daer,
  { {0x3fcb002b,0x0f350033,0xde580033,0xbd6a0783}},	//   ردنی_, рэця, такі_, ерие_
  { {0xc05a0010,0x66f7000a,0x42db000a,0xf9870040}},	//   _прац_, נמצא_, _נקלע, _اب_
  { {0x35db014e,0x69dc0061,0x7ce540cd,0x10a300af}},	//   _मुफ़, ürem, tóra, _лисн
  { {0x4093003b,0x60e6003d,0xb87b0046,0xda6600c3}},	//   _القر, ārmē, hlíc, هادي
  { {0xb3560033,0xc98603ae,0x78a440ce,0x629e1c01}},	//   тнiц, гуми, _aliv, nkpo
  { {0x78a440cf,0x2d980723,0x6d5a01f9,0x0000006a}},	//   _bliv, _ære_, _upta,
  { {0x7cc80046,0xb87b0046,0xe3bf0077,0x78a41ca6}},	//   běra, dlíc, _leña_, _cliv
  { {0x4429022d,0xfcd30086,0xb87b0077,0x872b0033}},	//   vaa_, _اينج, elíc, эўна_
  { {0x2d9800dc,0xdce10024,0x386d0de8,0x6e2a0546}},	//   _üres_, _islā, žer_, nafb
  { {0x442940c6,0x26c300bd,0x29030030,0x0000006a}},	//   taa_, rnjo_, íjat_,
  { {0x6e2a0026,0x89eb000a,0x89330015,0xb87b0046}},	//   hafb, _אַחֵ, _اعوا, slíb
  { {0x442900f2,0x26c300bd,0xa2b50010,0xe29f002e}},	// [8ff0] raa_, pnjo_, абач, _auða_
  { {0x7ce50084,0xb6030089,0x442940d0,0x62350165}},	//   jórn, část, saa_, режу
  { {0x442900f2,0x27ec005c,0x78a4008c,0x64ac0045}},	//   paa_, ędne_, _yliv, rşir
  { {0x657a02de,0x212a002b,0x98a6003d,0x0467261d}},	//   æthe, ئينی_, oslā_, _стом
  { {0x7ce5001c,0x8f690015,0x3aeb00cb,0x0fd80033}},	//   fórn, ئمتك_, løpe_, льшы_
  { {0x1eea0074,0x13ba000a,0x7cc1003d,0xbd4500c3}},	//   نونی_, _יזרע, mēri, لنتي
  { {0x200e002e,0xd3950033,0x41e401c6,0xf67c000a}},	//   ækið_, лiчэ, _гіта, תאומ
  { {0x3f15005e,0x68ed0034,0xf1b2004f,0x63ad013b}},	//   _вдас, _nhad, _וסל_, ozan
  { {0xbf150087,0x63ad40d1,0x4f580021,0x7c840054}},	//   _ضواب, nzan, _مجلد_, сује
  { {0xdfd8010f,0x60c90293,0xeab10015,0x78a428ea}},	//   _със_, _hjem, تعب_, _sliv
  { {0x7e6300f2,0x7cc80089,0x26c4002c,0x60c9003c}},	//   menp, měrn, émom_, _kjem
  { {0xe45f0123,0x68ed40d2,0xac191402,0x7d0e01c0}},	//   _sjön_, _chad, _роду_, žisé
  { {0x78a40089,0x6d4340d3,0x8c1a000a,0x501a000a}},	//   _vliv, luna, _סוסי, כורו
  { {0x63ad0d55,0x96ba0001,0xbb3a000a,0x7e6300c6}},	//   dzan, туму_, _יעני, nenp
  { {0x68ed002d,0x2aba000a,0xd627004a,0x6ecd000b}},	//   _fhad, _שמצא, росе_, _तदनु
  { {0xa7fb02c1,0x60c940d4,0x78a440d5,0x7e630012}},	//   seña, _njem, _uliv, henp

  { {0x7ae100b8,0x290716d3,0x9656006b,0xe3bf0077}},	// [9000] ollt, _huna_, _кънч, _peña_
  { {0x290740d6,0xb77b0008,0x7f860086,0x079b004c}},	//   _kuna_, _יאפש, یلان, _ססיל
  { {0x14c80086,0x29071784,0x6d4340d7,0x63ad40d8}},	//   _مهدی_, _juna_, juna, azan
  { {0x3ea509c9,0x26d840d9,0x67240079,0x290740da}},	//   _allt_, loro_, _kwij, _muna_
  { {0x63ad0050,0x1ea9002b,0x290740db,0x1fb601ca}},	//   czan, گاني_, _luna_, јсер
  { {0x8d760074,0x60c90467,0x6d43002e,0x69dc0061}},	//   لاعا, _ejem, funa, ürek
  { {0x7d780074,0xed870063,0x1ea900e6,0x6d4340dc}},	//   امبر_, исък_, داني_, guna
  { {0x7ae11d06,0x60c900cb,0xbf66002b,0xbf16006e}},	//   ellt, _gjem, _پدرو, _نورب
  { {0x7ac615e6,0x26d840dd,0xbb470015,0x6d4340de}},	//   исое, koro_, للين_, auna
  { {0x781f014e,0x239a0007,0x29071c8d,0x68ed0498}},	//   पर्क_, mąją_, _buna_, _shad
  { {0x63ad40df,0xeaf70015,0xdca60054,0x6aba07a3}},	//   zzan, جريت_, _кажи, ritf
  { {0x6d9b000a,0x7cc80046,0x63ad157b,0x8b66002b}},	//   _שבאפ, měro, yzan, _ناتم
  { {0x610500df,0xc0530008,0xf8040010,0x9cb30015}},	//   _vėli, חזר_, ючэн, _بمنت
  { {0xdb9b0008,0x26d800e8,0x9ad30015,0x25670034}},	//   _בסדר, goro_, _وتوض, _pŵl_
  { {0x98c70080,0x6e281d31,0xda650002,0x29070509}},	//   _вспл, _medb, _داني, _guna_
  { {0x7cc10048,0x63ad1f4b,0x79fb0008,0x69fb000a}},	//   tēri, tzan, _בלוח, _בלוק
  { {0xa87c0053,0x78bd0209,0x92590004,0x239a0091}},	// [9010] _יאהר, misv, лаат_, jąją_
  { {0x63ad40e0,0xb3c8000b,0x7d080150,0xa7fb0077}},	//   rzan, _रखरख, _ouds, leño
  { {0x2f0b00fb,0x63ad0fce,0x7cc80089,0x06f4002b}},	//   _søg_, szan, věrn, _بسيج
  { {0x7cc10024,0x61140036,0x78bd40e1,0xa49b0144}},	//   pēri, ідчу, nisv, _diòc
  { {0x7ae140e2,0x70520029,0x7e6340e3,0xbf680058}},	//   yllt, سنوا, tenp, لصوم_
  { {0x6d4340e4,0x7d080613,0x22950015,0xce49004a}},	//   tuna, _buds, _الآس, узке_
  { {0x6d430020,0x365c000a,0xfe7000c3,0x78bd001a}},	//   uuna, דכונ, بدن_, kisv
  { {0x60c9018c,0x60db003f,0x629500dc,0x4c8540e5}},	//   _ujem, _ukum, _hozo, слив
  { {0xa3d7005d,0x2900007c,0x78bd04d2,0x290740e6}},	//   िथि_, _riia_, disv, _suna_
  { {0x6d4340e7,0x29000020,0xfe700029,0x290740e8}},	//   puna, _siia_, _يدل_, _puna_
  { {0xf769013a,0x26d802d7,0x382a0080,0x66c9002c}},	//   _רק_, voro_, лжно_, eľko
  { {0x78bd001a,0x515a000a,0x2ca61b11,0xfc64006b}},	//   gisv, נכרו, _glod_, _мъчн
  { {0x29000020,0x6f0902c1,0x9b67002b,0x907a000a}},	//   _viia_, _juec, _خطاه, אטרי
  { {0xd63a008f,0xfb1a0008,0x87b90080,0xa3bd000b}},	//   ыямі_, _עוצמ, руют_, ेपन_
  { {0x26d8000c,0xaab40029,0x6f01194b,0x38a90003}},	//   roro_, _بإنش, _milc, _sûre_
  { {0x8936000a,0x67240079,0x39450144,0x26d840e9}},	//   _הרקע_, _twij, muls_, soro_
  { {0x60d900c7,0xccf2000a,0x26d840ea,0x6498001a}},	// [9020] dowm, לכל_, poro_, _síis
  { {0x7cc10024,0xe7b7000a,0x645600da,0x33d50033}},	//   mēru, _להפר_, sfyi, ціст
  { {0xb87b0125,0x6e2840eb,0x62950d64,0x0697004f}},	//   ilín, _redb, _dozo, _הדים_
  { {0xef860010,0x70560015,0x2419005e,0x7cc80046}},	//   йлеп, إنشا, _вірю_, věro
  { {0x7d08016f,0xf413000a,0x442040ec,0xd3350033}},	//   _suds, _מפר_, mbi_, _мэры
  { {0xf67a0053,0x97570008,0x442040ed,0xf773000a}},	//   ראַמ, מינו_, lbi_, פקו_
  { {0xb05b0046,0x4420205d,0x6e28063b,0x61431673}},	//   ížít, obi_, _vedb, _нера
  { {0x6295000c,0xa06a006b,0x3ebc0f94,0xbc4a007e}},	//   _zozo, _щаба_, sivt_, учке_
  { {0x44200064,0x43bb0053,0xcc330015,0x2087004a}},	//   ibi_, ָזיג, سريع, _уйти_
  { {0xaab40036,0x3f520026,0x7d080030,0x1d0a0054}},	//   ійні, mâu_, _tuds, _бежи_
  { {0x195804f7,0x7d08007c,0x3da50015,0x78bd40ee}},	//   шаны_, _uuds, _وإمّ, tisv
  { {0x2369005c,0xab2a05e6,0x8c1a0015,0x44200085}},	//   ywaj_, _бода_, _إيشر_, jbi_
  { {0x274b0080,0x98b80063,0x442002c6,0xdb000012}},	//   ычно_, слят_, dbi_, tzmä
  { {0x7bdc0064,0x442d40ef,0x07080015,0xa7fb0077}},	//   ğrud, _že_, صيفي_, seño
  { {0x3abb013a,0x6295002c,0x3f520092,0x27ec005c}},	//   _תמונ, _rozo, hâu_, ędna_
  { {0x442040f0,0x58d40063,0xd4980221,0x94191119}},	//   gbi_, _нощт, бру_, ржат_
  { {0xb87b002d,0xf838000a,0x99720046,0x62950771}},	// [9030] llío, _הנחת_, věře_, _pozo
  { {0x7d02002f,0xf8bf0152,0x44204011,0x0627004a}},	//   _lios, lié_, abi_, _уфим
  { {0xda5b0053,0xeab10008,0x44200c0a,0x212a002b}},	//   רכבל, וֹא_, bbi_, ليلی_
  { {0xe1f00029,0xb87b002d,0x55ba000a,0x7d02002a}},	//   رسل_, ilío, _כמתו, _nios
  { {0x289c00b2,0xc058022a,0xdb460015,0x7a430030}},	//   װיגא, сіх_, _تَ_, nítü
  { {0x236f002e,0xfd1100e6,0x8e5500ce,0x6f09039f}},	//   ægju_, وجب_, ітлі, _vuec
  { {0x31350124,0xcc890080,0xfe700087,0x442b40f1}},	//   _фебр, ибке_, عده_, _kec_
  { {0x80270086,0x7ce5005c,0xdfd50080,0x320d0061}},	//   _درآم, mórk, _добы, _şeyh_
  { {0xcec80092,0xf8bf0152,0x3b85005e,0x7d0240f2}},	//   uộc_, dié_, ілог, _dios
  { {0xcc89002b,0x3a99004a,0x539c000a,0x7cc1003d}},	//   انکه_, ртию_, טיחו, eērt
  { {0xf8bf0152,0x44391327,0x44200026,0xb87b40f3}},	//   fié_, _ods_, ybi_, rlín
  { {0xc8b60010,0x98a60007,0xc689039e,0x2d53016e}},	//   існы, kslą_, _בא_, mãe_
  { {0x2cad00fb,0x7a4300dc,0xd996002b,0x9056000a}},	//   mhed_, gítü, منیت_, חברו_
  { {0x44392e36,0x96b90010,0x0b160029,0x59d4000b}},	//   _ads_, бусу_, _بقوة_, _ठुकर
  { {0x66030219,0x98760054,0x94961923,0xa6e3001a}},	//   дпра, _дупљ, ошач, úðar
  { {0x03262cd4,0xf8bf0152,0x2cad0134,0xc952000a}},	//   ждан, cié_, nhed_, _חמה_
  { {0x72360029,0x7c2b0097,0x2bf6004c,0xb8fe000b}},	// [9040] قراط, _megr, ַמען_, तक_
  { {0x36c3004a,0x644f23ac,0xe2460015,0x442040f4}},	//   _обыг, _ecci, تخري, sbi_
  { {0x7c39005c,0x7ce5002a,0x2d930123,0xc04f00e2}},	//   _odwr, górk, äxel_, мі_
  { {0x8fa60086,0xf80d000a,0x6ee40144,0x3f520034}},	//   يماه, ְהוּ, mòbi, tâu_
  { {0xf8b3013a,0xbe8a12d2,0xa3bd000b,0xb65a000a}},	//   ושא_, иске_, ेपण_, ֹדֶש
  { {0xbea30124,0xfd380029,0x7d02005c,0x3f523cb5}},	//   мачк, مكتب_, _sios, râu_
  { {0x71760086,0x7d02005c,0xe7e1000b,0x0caa004a}},	//   _بهزا, _pios, _गुना_, итии_
  { {0x442b0251,0x2cad0838,0x7c66002b,0xc5fb000a}},	//   _xec_, ghed_, زابل, ספקט
  { {0x7cc10048,0x320d0064,0x7c2b2678,0x9e3a0021}},	//   vērt, _şeyi_, _degr, _نساء_
  { {0x7d02005c,0x2bb70029,0xdcea0064,0x236201c2}},	//   _wios, غاية_, ınır, _mpkj_
  { {0xf8bf0152,0xfbcf0086,0xc27b00a3,0x7dc60015}},	//   tié_, فتی_, בריי, _بقان
  { {0xb87b002f,0xbb8600e5,0x2cad22ec,0xe787004a}},	//   rlío, _ولاي, ched_, оуго
  { {0x07a4008f,0x291802fd,0xf8bf0152,0x442b40f5}},	//   даўн, ūra_, rié_, _rec_
  { {0xda660015,0xaa580015,0x8e8a000a,0xe4e3000b}},	//   _ذاتي, _طلبا_, ׁנָ֔, _कीजि_
  { {0xf98f0029,0x25db005d,0x25a500dc,0x442b40f6}},	//   _لبي_, _खुशी_, áll_, ицам_
  { {0x291e2bee,0x64c50015,0xc7ab0015,0x58940015}},	//   mpta_, أيرل, _ندخل_, _يجيز
  { {0xa6db002e,0x442b40f7,0x389c000a,0x889c000a}},	// [9050] arða, _vec_, _כיהנ, _כשהצ
  { {0x98a60007,0x7cd30011,0xe718000a,0xb87b0125}},	//   rslą_, măre, _וחזר_, ilím
  { {0x96f80015,0x4439210e,0x7cd30045,0xf6d40058}},	//   _بعير_, _tds_, lăre, _تزيد
  { {0x644f04ed,0x26c4002c,0x291e0091,0xf99305bd}},	//   _ucci, émov_, ipta_, ורע_
  { {0xb4d7005d,0xddc801c9,0x8416000a,0xbf670015}},	//   ाकी_, _radš, _מקרב_, تداو
  { {0xa1370086,0x23fa0008,0x7ce52682,0x539a000a}},	//   _ورزش, _להרא, móri, _הישו
  { {0xa63c000a,0x2cad09ab,0x644d0030,0x7ce540f8}},	//   בגור, thed_, ogai, lóri
  { {0x7cc10024,0x27180089,0x6aaa0034,0xfc310015}},	//   vērs, něný_, _alff, رحب_
  { {0x5f770074,0x2cad0134,0xe1040010,0xce6b004a}},	//   _بازر, rhed_, _цярп, _вред_
  { {0x8d770029,0x2cad14e6,0xa6db002e,0x7d770015}},	//   _واضا, shed_, yrða, _واضط
  { {0x25db005d,0xa96917bd,0xd0f5000a,0x7d790015}},	//   _खुली_, щина_, ּמָת_, _دمار_
  { {0x6615005c,0xd196000a,0x2904060a,0xddc30046}},	//   eczk, לכתי_, öma_, lenů
  { {0x291e0011,0x8bb70029,0x7cd30045,0x7ce5001a}},	//   apta_, _بإضا, găre, jóri
  { {0x6d4340f9,0xb81c000b,0xba39004c,0xe5060015}},	//   orna, _भ्रम_, _הײַט, كبري
  { {0xa6c70015,0x38cb002b,0x98a608ad,0xb4d70065}},	//   أوّل_, _گاوی_, _нике, ाकू_
  { {0xa93a0008,0x7cc80046,0x644d01d7,0x628740fa}},	//   _התקפ, věrk, ggai, _anjo
  { {0x63060086,0x7cd30011,0x7ce52540,0x14170015}},	// [9060] سوال, căre, góri, سيلة_
  { {0x96960001,0x644d40fb,0x67bb000a,0xd36f0015}},	//   _хриш, agai, _למפק, طهم_
  { {0xd24f0086,0xa00a0029,0xa69b0008,0x80660eb0}},	//   انم_, مقال_, _השיפ, звеж
  { {0xb9cc0053,0x6287148e,0xc5eb000a,0x765c0034}},	//   סזאָ, _enjo, _לַכֹ, lfry
  { {0x443240fc,0x98bf0045,0x6d432f49,0xb4fb000a}},	//   may_, lută_, erna, _לפטי
  { {0xcf890029,0x443240fd,0x7f4240fe,0xdb20001a}},	//   تضمن_, lay_, rroq, ðtím
  { {0xacf80010,0xb6ad0008,0x98bf0011,0xe1690015}},	//   онку_, שׁוֹ, nută_, _وصفه_
  { {0x443200b6,0x6eed00dc,0xc157000a,0x7f420003}},	//   nay_, rúba, _משלו_, proq
  { {0xcb98002b,0x6615002a,0x6d4340ff,0x9e5a004a}},	//   زندش_, yczk, arna, _греф_
  { {0x44324100,0x8f8b0008,0x139b000a,0xbf37000a}},	//   hay_, _לְבֵ, צביע, _מאמץ_
  { {0x28f90036,0x765c0026,0x644d0026,0x79a30080}},	//   жень_, dfry, ygai, еряе
  { {0x7cd30045,0x60c24101,0x48ab147f,0x44324102}},	//   tăre, niom, стом_, jay_
  { {0x765c0026,0xe7870001,0x443205b4,0x86270033}},	//   ffry, чуно, day_, зьбе
  { {0x7ad40015,0x291e0971,0xe7e1000b,0x69dc0061}},	//   _تقتص, ppta_, _गुणा_, üres
  { {0xda5b0008,0xa6db002e,0xddd80089,0x6d4a03d6}},	//   _הכול, nuði, tevř, nufa
  { {0x4432025c,0x7ce54103,0xb4d7005d,0x7cd30011}},	//   gay_, tóri, ाके_, păre
  { {0x883c0008,0x28580029,0x78ad0064,0xe8d80135}},	// [9070] _התחו, _رؤية_, _ilav, _מוהר_
  { {0x78ad04af,0x6d4a003f,0x67540029,0x6d430d75}},	//   _hlav, kufa, _أخير, yrna
  { {0x44320365,0x98bf0011,0xd1300029,0x7ce5016e}},	//   bay_, cută_, ُمْ_, sóri
  { {0x26c300bd,0xd138078f,0x7536004c,0x998c0046}},	//   lijo_, яху_, _קארד_, hadů_
  { {0x7eaf003c,0x6d58003d,0x6d430034,0xb4e9000b}},	//   _løpe, etva, wrna, यती_
  { {0x7fb6003b,0x26c300bd,0x78ad1eeb,0x6d430085}},	//   ظهور_, nijo_, _llav, trna
  { {0x78ad4104,0x6d434105,0x0000006a,0x0000006a}},	//   _olav, urna,   ,
  { {0x7ae8042f,0x5ba90342,0xe58c004f,0x6dc40058}},	//   eldt, жким_, מָחָ, عزول
  { {0x1ee70086,0x98bf0045,0x6d4a002a,0x8f55002b}},	//   _فوری_, zută_, aufa, _زناش
  { {0xa9a50415,0x26c300bc,0x78ad4106,0x3e35009a}},	//   диод, jijo_, _alav, _آفار
  { {0xa3e4005d,0x26c31283,0x5e440015,0x7bce0012}},	//   _पुन_, dijo_, _أَمْ, ßbur
  { {0x78ad4107,0x30790053,0x644a00dc,0xb4d7000b}},	//   _clav, קאָנ, őfiz, ाको_
  { {0x610c01e2,0x26c34108,0xa036000a,0x99d2002b}},	//   _işle, fijo_, וארה_, فقیت
  { {0x60c2005c,0x26c30060,0x78ad030f,0x4bfa000a}},	//   ziom, gijo_, _elav, _ולנס
  { {0x7cd304f9,0x99850074,0x88c60029,0x84e6005e}},	//   cărc, _آلبو, _يتعل, довж
  { {0x61fa002e,0x78ad065d,0x98bf0011,0xf992000a}},	//   _útli, _glav, rută_, _ירו_
  { {0xa8570008,0x26c300bd,0xc4c50029,0x4e0d005d}},	// [9080] _חיפה_, bijo_, رتفو, िखाई_
  { {0x26c3018c,0x44324109,0xf773000a,0x98bf0045}},	//   cijo_, say_, _יקח_, pută_
  { {0x211a0086,0x6d580123,0x60c2410a,0x4432410b}},	//   زتاب_, xtva, tiom, pay_
  { {0xf2c9000a,0x394500da,0x7cc8002a,0x4fea030e}},	//   בע_, irls_, ośre, омен_
  { {0x7ae80293,0x9ffa0015,0xdd8f002b,0x60c2410c}},	//   yldt, آراء_, یوه_, riom
  { {0xb7db0008,0xdfcf00e5,0xd2520002,0xa3bd000b}},	//   חקני, جيه_, _جنس_, ेपर_
  { {0x629c003f,0x63a4082f,0x68f6002a,0x68e40085}},	//   _ioro, lyin, _ohyd, _okid
  { {0x26c300bd,0x5ba60127,0x629c3ab7,0xa6db001a}},	//   zijo_, дроз, _horo, erðl
  { {0xcb67023e,0x63b6002a,0xd00b000a,0x5a460033}},	//   дање_, nzyn, _וּבֹ, мэна
  { {0x610c01e2,0x3b070152,0x6d5c007c,0x68e40509}},	//   _eşle, _cinq_, _ärao, _akid
  { {0x26c300bd,0xc27b0008,0x6da60031,0x78ad0787}},	//   vijo_, קרטי, _تمام, _plav
  { {0xa9c30191,0x63a400f2,0x7afd0007,0x68f63aef}},	//   тськ, kyin, įsta, _chyd
  { {0x2fc0002d,0xd7e40036,0x7afd0089,0x26c300bd}},	//   úigh_, віро, ůsta, tijo_
  { {0xeb970001,0x7cd30011,0x63a4003e,0xaab70015}},	//   _циљ_, măra, dyin, _يدور_
  { {0x95c50029,0x26c300bd,0xe7e1000b,0xddc30045}},	//   ريره, rijo_, _गँवा_, menţ
  { {0x63a4003e,0xddc30011,0x26c300bd,0x6b82410d}},	//   fyin, lenţ, sijo_, _krog
  { {0x26c300bd,0x18340015,0x92a6002a,0x629c410e}},	// [9090] pijo_, _شريح, _odłą, _boro
  { {0xd25b008f,0xddc30011,0x27e911ac,0xeb91000a}},	//   ўца_, nenţ, _iyan_, נָן_
  { {0x610c0061,0xa5d40033,0x629c410f,0xa6db001a}},	//   _oğlu, _ажэш, _doro, fuðv
  { {0x50b80086,0x672d4110,0x15fa000a,0x38a24111}},	//   ودند_, _kwaj, _מהתע, _fóru_
  { {0x63b60050,0x93b40010,0xf8b8000a,0x441a000a}},	//   czyn, _абяц, ופאי_, _מורס
  { {0xd3560008,0x1d090036,0x629c4112,0x4e8b004a}},	//   _אישי_, пеки_, _goro, ющем_
  { {0xddc304f9,0x61140010,0x20120125,0x6d5c007c}},	//   denţ, _адсу, íniú_, _äral
  { {0xf1b20053,0xc1050015,0x8b95004a,0x81880015}},	//   _עסן_, _أوري, ероч, _تنفق_
  { {0x68f60176,0x7c840001,0xff50006e,0x1eea002b}},	//   _rhyd, тује, _نخل_, _کولی_
  { {0xdd950010,0xddc30011,0x2ef403ae,0x6b824113}},	//   _пазы, genţ, _азур, _drog
  { {0xa6db002e,0x6b8202b9,0xdce3002a,0x6298008c}},	//   nuðu, _erog, ewną, övoi
  { {0x2d980251,0x6c840015,0xc19a000a,0x3bb9030c}},	//   _àrea_, _للمم, לשתי, _нулю_
  { {0xec36000a,0x6b824114,0xe7370d7f,0x7ba702be}},	//   _נאסר_, _grog, нея_, _تصام
  { {0xddc30011,0x9f5600dc,0xa6db002e,0x27e902f2}},	//   cenţ, égét_, kuðu, _dyan_
  { {0x24f60010,0x7ae14115,0x68f60034,0xf3f700a1}},	//   ечар, molt, _thyd, ệng_
  { {0x629c4116,0x63a40a8e,0x68e40085,0x98bf0091}},	//   _soro, tyin, _ukid, tutą_
  { {0xd8d70053,0x88bd0089,0x629c1058,0x434309ef}},	// [90a0] _רופט_, spěc, _poro, летв
  { {0x35db005d,0x63b6005c,0x7ae118d8,0xb7db000a}},	//   _मुक़, rzyn, nolt, _מקפי
  { {0x06570053,0x63b6005c,0xa87a000a,0x629c4117}},	//   _אייך_, szyn, ּרְח, _voro
  { {0xddc30011,0x69d50061,0x50650015,0xdcfa003d}},	//   zenţ, üzey, َانِ, _ortā
  { {0x3fc60086,0xdfd2012c,0xa6db001a,0x6eed31fc}},	//   رگری_, ديش_, auðu, públ
  { {0x7cd30011,0xfe6f0029,0x7f8300c3,0x629c0073}},	//   văra, مدى_, الون, _uoro
  { {0x6b82002a,0xddc30045,0x7ae12d3f,0x2a6c00bc}},	//   _srog, venţ, dolt, vedb_
  { {0x7ae1002d,0x1d070001,0x91e303c5,0x515b000a}},	//   eolt, неји_, _сосе, _מכלו
  { {0xddc304f9,0xc477000a,0x1fb50004,0xc0a90067}},	//   tenţ, תתפו_, _исфр, _غافل_
  { {0x394c0251,0x7f3b000a,0x220a000a,0x27e914ea}},	//   tuds_, _מעמו, ּפֹּ, _ryan_
  { {0x200d01e2,0xd2b70008,0xddc30011,0x02b70053}},	//   şmiş_, גלית_, renţ, גליך_
  { {0x0137013a,0x7cd30011,0xeb9a0403,0x35db000b}},	//   ערכת_, păra, _ние_, _मुग़
  { {0x28c0005d,0xfaa60cad,0x98c40033,0xd90e002b}},	//   शोधि, _падо, усэл, _گیج_
  { {0x38a2002d,0xcf930053,0x7ae14118,0xb9940015}},	//   _sórt_, אטש_, colt, _للتب
  { {0x7ce511d4,0x35db000b,0xba17004c,0x4d78000a}},	//   pórt, _मुख़, _אחוץ_, וָּא
  { {0x4277002b,0xa6db001a,0x0000006a,0x0000006a}},	//   کارآ, vuðu,   ,
  { {0x27e90064,0xf7840015,0xcb13004c,0x4e10000b}},	// [90b0] _uyan_, _مليَ, ָלע_, ाशाई_
  { {0x7e7a016f,0xa6db002e,0x6448003d,0x1db0000b}},	//   _natp, tuðu, _ēdie, जनात
  { {0x21670010,0x010b002b,0x35f51adc,0x3f840072}},	//   этаг, ستاو_, _шпор, _armu_
  { {0xc5f2011f,0x7ae100dc,0x90e70067,0xe588000a}},	//   _כדי_, zolt, رسان, _נָתָ
  { {0xef180036,0x64360053,0x44290553,0xce95006b}},	//   емі_, _בארא_, mba_, кадъ
  { {0x7bdc01e2,0x44293d84,0xa77c000a,0xfe42006b}},	//   ğrul, lba_, פרופ, аншо
  { {0x69170024,0xbe880033,0x29180046,0xa2ae000b}},	//   _aģen, эсце_, íral_, ंघर्
  { {0xfebb0086,0xb062007c,0x44293d4e,0x4c851acb}},	//   _کارت_, äätm, nba_, тлив
  { {0xe452000a,0x7ae10030,0xdb14001a,0x44294119}},	//   בֶת_, tolt, óaðr, iba_
  { {0x2b4d0144,0x7ae1008c,0x7afd0091,0xbdfb0021}},	//   ruec_, uolt, įsto, _فرضا_
  { {0x2d9a003c,0x4429411a,0x7ae100dc,0x98bf0c85}},	//   øpet_, kba_, rolt, lutę_
  { {0xbb850015,0x7ae1411b,0xddc3003d,0xcd96000a}},	//   _للصي, solt, cenš, _בדעת_
  { {0x98bf086a,0x28b3005d,0x442918f1,0xa03a004c}},	//   nutę_, ुफ़ि, dba_, וערפ
  { {0x442902c1,0x5ba80010,0x3f5b0092,0xfaa21ec9}},	//   eba_, _якім_, iêu_, _вашо
  { {0x8a140029,0x87070036,0x65c3411c,0x25ac0046}},	//   _إظها, терв_, абра, ádl_
  { {0x4429411d,0xa7d60015,0xf74a0015,0x7d1c0030}},	//   gba_, _لتخص, _قلبي_, _érse
  { {0x130a0010,0xb8e8000b,0x7c29411e,0x0000006a}},	// [90c0] днай_, ोच_, iber,
  { {0x4223000d,0x7c2918b8,0x96fa0015,0xc87f0012}},	//   идув, hber, _تعبر_, roße_
  { {0x98c6005d,0xa2a3005d,0xf8c6005d,0x644b0c98}},	//   _लगाए, _गवर्, _लगाय, ógic
  { {0x64a62b9d,0xf992000a,0xb87b001a,0x4fc6009b}},	//   _рама, ירב_, blíu, ксла
  { {0xd0070010,0xd3480086,0xdfcf0115,0x5f730015}},	//   веце_, _سیاه_, ييم_, لاور
  { {0xb87b0014,0x6d5c0020,0x7c29411f,0x7cf50091}},	//   llít, _ärak, eber, _išry
  { {0x127b00b2,0x628e4120,0xbea30180,0x7c2901f1}},	//   _קאלע, _inbo, рајк, fber
  { {0xb87b00dc,0x2918001c,0xcce6002b,0xfc66006b}},	//   nlít, íram_, خستي, тъкн
  { {0xe29f002e,0x0c730015,0xaf060033,0xb87b0125}},	//   _guðs_, شديد, _апал, ilít
  { {0xc333013a,0xa021002e,0x7c294121,0x99980004}},	//   סות_, _þörf, aber, екот_
  { {0x80bf000b,0x7c294122,0x7cd30045,0xa9540033}},	//   लोवे, bber, căro, ыкні
  { {0xa8a70294,0x8c430033,0xfd57000a,0xb87b0030}},	//   трок, _веце, _ישבי_, jlít
  { {0x58d403ad,0x35db000b,0x44294123,0x1d070054}},	//   роят, _मुज़, vba_, _реци_
  { {0xddda0007,0xef67000a,0x44290702,0x6d4a4124}},	//   _natū, כֹל֙_, wba_, orfa
  { {0xdce3005c,0xbb7c0086,0x8aab000a,0xba290015}},	//   ewnę, _ﻣﻴﻠﻪ_, _קֹדֶ, _أسهم_
  { {0xa6db001a,0x5d7b000a,0xadd7000a,0x628e4125}},	//   irði, ואלק, דולח_, _anbo
  { {0x6d4a00b8,0xd8d80135,0x93f508a3,0x44294099}},	// [90d0] hrfa, _שוחט_, упац, rba_
  { {0x7c291259,0xf195005e,0xf1a70709,0x442927c1}},	//   zber, лизь, крен, sba_
  { {0x25a500c0,0xd0110031,0xa9f8000a,0x6d5c007c}},	//   älld_, ملا_, תִּת, _ärah
  { {0x30a70063,0xf1c30007,0x6019004a,0x7fd50033}},	//   ързв, _rašė_, ходя_, лілі
  { {0x6f650029,0x6d4a00b8,0x7d0b2890,0xb4c1000b}},	//   اهتم, erfa, _rigs, ्ची_
  { {0x999c00dc,0x7d0b00aa,0x7c294126,0x4df5013e}},	//   _levő_, _sigs, wber, ляйт
  { {0xc694000a,0xe803000b,0xc537000a,0x7c294127}},	//   יאס_, रेता_, דָ֖ה_, tber
  { {0x7c294128,0x0000006a,0x0000006a,0x0000006a}},	//   uber,   ,   ,
  { {0x2d9a003c,0x4fd5004a,0x8b940033,0x7c290b9d}},	//   øper_, _сжат, арэч, rber
  { {0xb3650033,0x7c294129,0x80bf0065,0x9957005a}},	//   тнiч, sber, लोरे, _záře_
  { {0xf2d4000a,0xc7a9000a,0x20c70034,0xb87b026a}},	//   יעץ_, _צב_, nŵio_, roín
  { {0x31560053,0x1cbb0029,0x88bd005a,0x0000006a}},	//   װישן_, _غاضب_, spěn,
  { {0xf7720029,0xcb690010,0x4c9a015b,0xcc76000a}},	//   حاج_, _чале_, _רבנו, _תענה_
  { {0x2cad0c0a,0x1bb80002,0x8aa7412a,0xe9390058}},	//   lked_, _جامع_, _шред, _كسبت_
  { {0xd46a000d,0x44fa0010,0x2cad00da,0x96c3000b}},	//   ниве_, ехаў_, oked_, रफ़ॉ
  { {0x2cad0100,0xc952000a,0x88360033,0xa988004f}},	//   nked_, _המה_, _сэкц, _יָפִ
  { {0x577a0029,0xe61a000d,0xa2d60015,0x68fb004c}},	// [90e0] _أصبح_, _пдп_, هيرت, _אלקה
  { {0xb87b0057,0xe2450015,0xa6db001a,0x68e60046}},	//   slít, لخمي, yrði, lokd
  { {0x210e000b,0x673b2fd7,0x221501c5,0x2cad04f6}},	//   िदेश_, šujt, рфур, kked_
  { {0x25a5412b,0xbf0f000b,0x0000006a,0x0000006a}},	//   älle_, ादून_,   ,
  { {0xde58008f,0xe3b200b0,0xa857000a,0x10090015}},	//   валі_, _طرح_, רינה_, نتهى_
  { {0xb7db0053,0xf1240086,0x61050007,0xdee3034e}},	//   עקסי, _نظری, _mėly, бочи
  { {0xccf80089,0x81780008,0x91780008,0x0178000a}},	//   _opět_, _בְּק, _בְּח, _בָּל
  { {0x6e3800cb,0x6d4a031a,0x26ca02f2,0x2480412c}},	//   savb, rrfa, hibo_, ndim_
  { {0xe1f4000b,0x9bd4005e,0x9b430015,0x61ee0e63}},	//   _अरुण_, ржпі, منيو, _hybl
  { {0xee370010,0x6fb30029,0x9e650086,0x5a340254}},	//   _бнф_, _امكا, _نامن, шнот
  { {0xfbcf0086,0xd9170b9b,0xddc80f81,0x6da600c3}},	//   قتی_, лья_, _hadž, _حمام
  { {0x2cad04d0,0x91bb000a,0x1c0d000b,0x14c6000b}},	//   cked_, תמטי, _हलचल_, रोमण
  { {0xcc3b0053,0xdc3b0053,0xa3e4000b,0x999c0030}},	//   _טעאט, _טעאר, _पुल_, _vevő_
  { {0x4b7b00b2,0xe6100029,0xddc8412d,0x07090015}},	//   _נאוו, كشف_, _madž, ئيسي_
  { {0x56940054,0x999c0030,0x2dd8004f,0xb8030065}},	//   љаст, _tevő_, דַּב, रे़म_
  { {0xb4c1005d,0x895b0008,0x99f5005e,0xb87b412e}},	//   ्चे_, _נדחת, _тячі, rlís
  { {0x36d5005f,0x9259000d,0xdc8b000a,0x08f80015}},	// [90f0] _вопр, каат_, עְלָ, _حروب_
  { {0xccf80089,0x57fc000a,0x26ca0e51,0x394c2db0}},	//   _zpět_, _אלחו, cibo_, ords_
  { {0xc0cb0001,0xa4d90010,0xc692000a,0x98bf1ed6}},	//   нуде_, _адну_, _ואי_, artą_
  { {0x3aeb003c,0x19570053,0x61ee0026,0x659a000a}},	//   løpt_, רבאל_, _dybl, _סירק
  { {0xf43a009d,0xc43a0447,0x3869412f,0xbf0f0065}},	//   _בגרמ, _שתשי, _mbar_, ादेन_
  { {0x171c0053,0x8afd0089,0xa3d4000d,0xd7380008}},	//   עווע, otře, _ѓорч, נטות_
  { {0xd6580008,0xf2d20008,0x40350724,0x224e0046}},	//   איות_, _ועם_, _вебс, ímků_
  { {0xad880015,0x0b450c45,0xae190065,0x0000006a}},	//   اضول_, анин, नुजन_,
  { {0x2cad4130,0x88bd0046,0x7bc40091,0x1c420138}},	//   rked_, rpěl, _žiur, цным
  { {0x88bd0089,0x4e780806,0x2cad4131,0x38690091}},	//   spěl, _محمد_, sked_, _abar_
  { {0x67244132,0x9f040087,0xbd4b00e5,0xe803000b}},	//   _stij, _اولو, _سؤال_, रेसा_
  { {0x254100df,0xa3b5005d,0x9d1a000a,0x9c580067}},	//   dėl_, जना_, _סונט, _مجهز_
  { {0x26ca00b6,0x394c405c,0xbc380058,0x66e60058}},	//   tibo_, ards_, _إسما_, لأسق
  { {0xff160008,0xceb20008,0x49b900e6,0x61050091}},	//   יקשת_, ֗ים_, _لابد_, _vėly
  { {0xe506003b,0xceb2011f,0x6aa3002d,0x20b5000b}},	//   لبري, חים_, _ionf, ंसाध
  { {0x89da0447,0x26ca02f2,0x6aa301ce,0x1426318f}},	//   _שחקי, sibo_, _honf, рдам
  { {0xd4970092,0xa6db002e,0x0323250c,0x6d5c0020}},	// [9100] ờng_, erðu, ждун, _ärav
  { {0x23600111,0x7c3b4133,0x6d4106e6,0x57fb000a}},	//   rtij_, haur, _ovla, _בלפו
  { {0x50260015,0x78a40c50,0x442d1de1,0x6aa34134}},	//   لفاك, _koiv, _нe_, _monf
  { {0x351b000a,0xef860658,0xcfa60e3f,0xa00a0015}},	//   _שוכנ, илеп, ишли, نقال_
  { {0x7ccd0048,0x6fd60029,0x7f170021,0x7f760033}},	//   _mērķ, جزائ, لينز_, руец
  { {0x44204135,0x78a4008c,0x6aa34136,0x0000006a}},	//   lci_, _loiv, _nonf,
  { {0x61432b9d,0x50960054,0x4096016a,0x44204137}},	//   _мера, _крађ, _крат, oci_
  { {0x41b30015,0x44204138,0x78a4016e,0x0c860033}},	//   _بمفر, nci_, _noiv, рыкм
  { {0x3d16005d,0xa3d6005d,0x44200011,0xbca30029}},	//   _पूरे_, िपि_, ici_, تميي
  { {0xf1eb000b,0xc211000a,0xbae30015,0x9d46006b}},	//   _जुड़_, ּ֔י_, يكيي, _вежд
  { {0x02170008,0x44201e80,0x3f86016e,0x6446006f}},	//   יחים_, kci_, lvou_, _odki
  { {0x3f860247,0x442004a6,0xb4e00065,0xa3d60065}},	//   ovou_, jci_, दको_, िपा_
  { {0x274b0063,0x78a40152,0xfbd2002b,0x80f5000a}},	//   ъчно_, _doiv, _بتا_, מֶשׁ_
  { {0x44204139,0xbb3b000a,0xa6db001a,0xcb13000a}},	//   eci_, _יעדי, yrðu, _ולס_
  { {0x63a200f2,0xbafb0008,0x4a31002c,0x78b60293}},	//   äonn, _שהוש, äčší_, _flyv
  { {0x499b000a,0x999b000a,0x299b000a,0x61e20061}},	//   _ישוב, _יבוט, _יסומ, ğoll
  { {0x8afd02d5,0x43740036,0x68ed0085,0xa2270015}},	// [9110] stře, жуєт, _ikad, لراه
  { {0x7c3b1164,0xc20b0015,0x4420413a,0x567902ed}},	//   zaur, نغام_, aci_, _сбоя_
  { {0x27fe002a,0xe1f00015,0x7c220085,0x4420413b}},	//   ętne_, وسم_, _ofor, bci_
  { {0x212a0086,0xd91b000a,0x44201435,0xcee8002b}},	//   اينی_, דואל, cci_, یرون_
  { {0xb4fa0008,0x92030024,0xd4960135,0x4439413c}},	//   _תפרי, _šādi, _הכרת_, _ies_
  { {0x7cd304f9,0xaec405d1,0x8ee8005e,0x7d070030}},	//   mări, обіл, амів_, _éjsz
  { {0x7cd30011,0xddc8005c,0x44392028,0xddda0046}},	//   lări, _gadż, _kes_, _datů
  { {0x25d8011f,0xe5720008,0x2dd80015,0x88bd0046}},	//   יוון_, לַח_, جبهة_, spěj
  { {0xdcb100a7,0x7cd30011,0x60db003f,0x4439413d}},	//   _của_, nări, _ijum, _mes_
  { {0x4439413e,0xc3340008,0x2b4d0251,0x6aba003e}},	//   _les_, חוץ_, rrec_, ghtf
  { {0x7c220176,0x44390176,0x3a980033,0xa9690054}},	//   _ffor, _oes_, ртыю_, ћима_
  { {0xfdf60008,0x26de002c,0x44393e64,0xbca40015}},	//   _הצעת_, čtom_, _nes_, _وملي
  { {0xef190050,0x78a4022d,0x907a004c,0x442009cb}},	//   _już_, _voiv, נטשי, vci_
  { {0xfbd00029,0x63ad24a9,0x8f9a000a,0x7cd30045}},	//   _تتم_, dyan, אישי, dări
  { {0x3ea508e0,0x78a40604,0x6d5c007c,0x44200910}},	//   _molt_, _toiv, _ärat, tci_
  { {0x4439038d,0xbc190008,0x25a500c0,0x2d870020}},	//   _ces_, רוּש, älla_, ivne_
  { {0x7cd30011,0x4439413f,0x63ad4140,0x44204141}},	// [9120] gări, _des_, gyan, rci_
  { {0x22160010,0x44204142,0xe1640086,0x44391325}},	//   сфар, sci_, يگزي, _ees_
  { {0xc693013a,0x998500df,0x44390251,0x5a3a0053}},	//   _זאת_, malų_, _fes_, רגעה
  { {0x7cd30011,0x703a0018,0xe0da02bf,0xd7fa000a}},	//   bări, اساس_, ыве_, ְהַל
  { {0x7cd304f9,0x3ea50c0a,0x60630015,0x2d8702de}},	//   cări, _bolt_, سهول, evne_
  { {0x99850007,0x877b0053,0x44390111,0x8d760015}},	//   nalų_, טאני, _zes_, ماعا
  { {0x11da0029,0x44392664,0x6da30180,0x361b000a}},	//   _صورة_, _yes_, зија, נוקד
  { {0x29120035,0x3ce00d98,0x27ed002a,0x7c390034}},	//   _niya_, čivo_, żeni_, _cewr
  { {0xdfcf003b,0x99850007,0xbb4700e6,0x73fb000a}},	//   _كيف_, kalų_, ملين_, ְּחו
  { {0x9e660074,0x314a0008,0xac980086,0x68ed21f3}},	//   _دارن, ְתָּ, انکا_, _skad
  { {0x7cd30011,0x25ed000b,0x38c9002b,0x29000125}},	//   zări, _आँधी_, لاحی_, _bhia_
  { {0x29000023,0xa9c30033,0xed4f002b,0x07b90015}},	//   _chia_, ясык, _سپه_, لهجة_
  { {0x7cd30045,0x7d1a044d,0x38a90003,0x44394143}},	//   xări, _huts, _sûrs_, _res_
  { {0x44394144,0x99850007,0x7d1a4145,0x7cd30045}},	//   _ses_, galų_, _kuts, vări
  { {0x2ca60020,0x6a130067,0x443937ac,0x7d1a4146}},	//   _kood_, _عبور, _pes_, _juts
  { {0x7cd304f9,0x68ed003f,0xa507005e,0x35b3005e}},	//   tări, _ukad, сягл, обґр
  { {0x2ca64147,0x7eb40144,0x44394148,0xc399005e}},	// [9130] _mood_, _nàpo, _ves_, шкає_
  { {0x4439020a,0x7d1a003e,0x7cd30011,0x63ad2411}},	//   _wes_, _outs, rări, ryan
  { {0x7d1a020a,0x7cd30011,0x97d80086,0x63ad4149}},	//   _nuts, sări, _نظیر_, syan
  { {0x7cd30011,0x43950063,0xdfd100e6,0x3ea51631}},	//   pări, _дамс, ويا_, _solt_
  { {0x7c39003e,0x987c05bd,0xbea536d4,0x2d8c18cf}},	//   _rewr, טראק, жалк, _arde_
  { {0x9758000a,0x3da9030c,0xfe71009a,0x7d1a01f6}},	//   מידו_, икло_, بگر_, _buts
  { {0x3ea50014,0xfc310029,0x2ca60079,0x62950079}},	//   _volt_, وحة_, _bood_, _inzo
  { {0x60db0f4d,0xef19005c,0x3ea50012,0x60c90573}},	//   _ujum, _tuż_, _wolt_, _umem
  { {0x2d8c00b8,0xdb0000f2,0x2ca60161,0xc869000a}},	//   _erde_, kymä, _dood_, _ֹן_
  { {0x23ca0053,0x29120035,0x05670046,0x6285414a}},	//   יצפּ, _siya_, _číně_, ndho
  { {0x6ce70036,0x2ca63390,0xe80c000b,0xa3d0000b}},	//   _ліде, _food_, सेना_, _वेन_
  { {0x2ca62630,0x9b950015,0x61400030,0x7ce5002a}},	//   _good_, _ولات, _hálá, hórz
  { {0x99850091,0xaa4502ed,0x6d43414b,0x25a502dc}},	//   talų_, _делл, lsna, älln_
  { {0x6b89001a,0xceb2000a,0x6d430125,0x87b9004a}},	//   mveg, ֵין_, osna, суют_
  { {0x29180046,0x6b891de9,0x99850091,0x694400c3}},	//   írat_, lveg, ralų_, _فضيل
  { {0x7afd0007,0x842a0142,0x62850012,0x78bd0012}},	//   įstu, ржав_, edho, chsv
  { {0xd6d20029,0xd3870457,0x99850091,0x42ca0076}},	// [9140] _يقع_, ойте_, palų_, аган_
  { {0x7cd304f9,0x33d50036,0x7ce5005c,0x82f60033}},	//   măru, чіст, górz, ічац
  { {0x64a60124,0x998c0050,0x81d60010,0x69c105a5}},	//   _дана, wadź_, ццац, nzle
  { {0x3f8d0251,0x62950111,0x11090015,0xd5fb000a}},	//   _breu_, _enzo, مغني_, _כפיר
  { {0x3f8d414c,0x2ca60111,0xdf760015,0x7cd30045}},	//   _creu_, _rood_, تداب, năru
  { {0x1c0d005d,0xde930001,0xc7b30008,0x57fb000a}},	//   ाइनल_, дашњ, ובד_, בלנו
  { {0x2ca60020,0x6d4301a7,0x20d6005e,0xadb70015}},	//   _pood_, gsna, _діас, يهها_
  { {0x5c98010f,0xa3ae000b,0x6e3a0079,0xafe61d8a}},	//   ския_, _कथा_, _wetb, _добл
  { {0xae7a005f,0x3f8d414d,0xdb00008c,0x6d43233f}},	//   _всех_, _greu_, yymä, asna
  { {0x2ca60495,0xaa580054,0x44323163,0x7d1a414e}},	//   _wood_, љину_, hby_, _tuts
  { {0x4432005c,0xc9570010,0x02fb000a,0x79f4006b}},	//   kby_, оўя_, שלימ, язох
  { {0x6d580020,0x7bdc0012,0x8d63005e,0xd8380138}},	//   muva, ßrus, _івче, жэр_
  { {0xacd900b2,0xdb0000f2,0x6bd60029,0x7bdc0061}},	//   _פֿעי, tymä, _بتار, ğrus
  { {0x48140010,0x6d581ff3,0x98a60091,0x96eb004a}},	//   ьмяс, ouva, kslė_, рьма_
  { {0xa3d0005d,0x79a60004,0x610c0061,0x6283016e}},	//   _वेब_, _фрле, _eşli, ônom
  { {0x19bb0008,0xb4b5000b,0xda780046,0xdb00008c}},	//   _כמוב, झसे_, leď_, symä
  { {0x7cd30011,0x7ce5005c,0x6d5838a9,0x2bd00065}},	// [9150] căru, tórz, huva, _तेमा
  { {0x6d580c8d,0x291c00f2,0xd1310015,0x979c000a}},	//   kuva, _kuva_, ّما_, _כשחק
  { {0xa6960008,0x212a002b,0x6d583287,0xd1300015}},	//   _זכתה_, ميلی_, juva, َمْ_
  { {0x26d10a9e,0x6d580020,0x3f8d0251,0x50cb0033}},	//   lizo_, duva, _preu_, шызм_
  { {0xc49a000a,0xbfb80015,0x69c100c7,0x6d5800aa}},	//   _השרת, يطها_, zzle, euva
  { {0xc7d80008,0xf7d8000a,0x5758000a,0xb77c000a}},	//   חודי_, חודש_, קבוע_, שָׁת
  { {0x7d02002f,0xbd450015,0x6d58007c,0x31780015}},	//   _bhos, أنبي, guva, _وحفظ_
  { {0x1c450036,0x765c005c,0x6d430384,0x7d02174c}},	//   чним, zgry, rsna, _chos
  { {0x38a2005c,0x3af50010,0xfa53002b,0x26d10573}},	//   _góry_, зянс, وردگ, kizo_
  { {0x7cd30045,0x6d58007c,0x44320bc5,0x3a99004a}},	//   văru, buva, zby_, стию_
  { {0xe8e00092,0x7d02002d,0x6d580085,0x69250033}},	//   _ngợi_, _fhos, cuva, ямна
  { {0x765c0026,0x7d02414f,0x8dfa000a,0x8d740015}},	//   wgry, _ghos, _ההעת, _تاكا
  { {0x69c10014,0x7d094150,0x44320057,0xa823002b}},	//   szle, mmes, vby_, رکين
  { {0x7d094151,0x26d1003f,0x0ae80015,0xd62705ab}},	//   lmes, gizo_, _وروي_, зоре_
  { {0x443204af,0x2a3a000f,0x765c19c3,0x6603080e}},	//   tby_, _העצמ, rgry, епра
  { {0x03260c9c,0x7d094152,0x7ce5005c,0xf8bf4153}},	//   здан, nmes, tóry, ché_
  { {0xccf2013a,0x27ed0251,0x99870089,0x7d090f7a}},	// [9160] תכן_, üent_, _jenž_, imes
  { {0x7d0900b8,0xd6c4002b,0x3e6f0061,0xe3b70033}},	//   hmes, _آمدی, nıtı_, чбу_
  { {0x7d09075e,0x361b000a,0x867b000a,0xf67b000a}},	//   kmes, _לויד, _פרטו, _פאטמ
  { {0xd12f00e6,0x88bd0089,0x44240064,0xe7b6000a}},	//   امن_, spěv, _üm_, ּהַר_
  { {0x7d020034,0x7d094154,0x6ff60015,0x0000006a}},	//   _rhos, dmes, أساط,
  { {0x33fb0008,0xdfcf00b0,0x3f7d006f,0x61461eaf}},	//   _להכנ, ديه_, _dňu_, _нега
  { {0xda78002c,0x7d024155,0x20560033,0xbd870015}},	//   veď_, _phos, _нтар, كنون_
  { {0x672f005c,0x61db000a,0x11db000a,0x38a20046}},	//   ypcj, _הקלד, _החלב, _tóry_
  { {0x291c0020,0xd0e9000b,0xda780046,0x6d584156}},	//   _suva_, टकरण_, teď_, suva
  { {0xc33301c8,0x7d020041,0x760700dc,0x7d091f8b}},	//   עות_, _whos, nézé, ames
  { {0x7d024157,0x2eee4158,0x26d1059d,0xf8bf10b6}},	//   _thos, moff_, vizo_, thé_
  { {0xc7d50063,0xf8bf0089,0x2db7000a,0xd8280033}},	//   джмъ, uhé_, _מלבן_, зірк_
  { {0x26d1000c,0xdb4f0015,0x76070030,0x0000006a}},	//   tizo_, _مَن_, kézé,
  { {0xba17003b,0xe803005d,0x7cc80089,0x4b7b000a}},	//   _فيها_, रेगा_, věry, _לאדו
  { {0xcaa5003b,0x9608008f,0x7cd30011,0x65940892}},	//   _تصني, зэта_, părt, нару
  { {0x26d1003f,0x6aaa4159,0x2eee415a,0x0000006a}},	//   sizo_, _hoff, hoff_,
  { {0xd3710029,0xe803000b,0xe4540033,0x6d0b000a}},	// [9170] ضها_, रेखा_, экты, מִמַ
  { {0x67bc000a,0xd2510021,0xe3b0002b,0xc7d8000a}},	//   _למחק, ئنا_, درف_, _מוחי_
  { {0xf652000a,0x63080015,0x6aaa415b,0x2eee01f9}},	//   _בצי_, أقلّ_, _moff, doff_
  { {0x98a60011,0x7f753758,0x0000006a,0x0000006a}},	//   mplă_, дукц,   ,
  { {0xfaf80024,0x23e4005e,0x8e85009c,0xff24005e}},	//   klī_, _зірв, дгле, еміо
  { {0xd2290015,0xf412000a,0x139a000a,0x539a000a}},	//   _ذكره_, _שפך_, _ובשע, _וישו
  { {0xa3b5000b,0x2369151e,0x7d09415c,0xfce52e68}},	//   जनक_, ltaj_, tmes, моко
  { {0x6287415d,0x24f7000a,0x7cd30045,0xeb29008a}},	//   _hajo, הֶ֖ם_, vărs, ожил_
  { {0x7d09415e,0x2369415f,0x3f8b0003,0x6aaa19ad}},	//   rmes, ntaj_, _écu_, _boff
  { {0xeab10029,0xce380029,0xe9d90b08,0x6aaa02e7}},	//   ئعة_, _فأما_, жко_, _coff
  { {0xba160015,0x672d4160,0x62874161,0x7d09050a}},	//   ويًا_, _ataj, _majo, pmes
  { {0x8d740086,0x2b520064,0x62874162,0xf7460e4b}},	//   _ساما, üncü_, _lajo, мемо
  { {0xa49b0023,0x9b94004a,0x24894163,0x07a30d3c}},	//   _phòn, _пицц, ddam_, ваян
  { {0x6aaa4164,0xbae50015,0xfbd0002b,0x62873e2d}},	//   _goff, _تكتي, _حتم_, _najo
  { {0xd575030c,0x672d00d4,0x7b070073,0x0000006a}},	//   нуть, _etaj, ąstė,
  { {0xa93a004f,0x0000006a,0x0000006a,0x0000006a}},	//   _ותקפ,   ,   ,
  { {0x2486002c,0xd5b80024,0xf7720015,0x52aa0666}},	// [9180] ľom_, šā_, _شاة_, овам_
  { {0x24863387,0x63ab038f,0xd36f0058,0x0000006a}},	//   žom_, ägna, شهم_,
  { {0xa69b000a,0x569b000a,0xb2290015,0x8066024f}},	//   _ושיפ, _וייצ, سألك_, двеж
  { {0xd4160029,0x25870089,0x6aaa000b,0x26de0046}},	//   _يبحث, sílá_, _चक्र, čtou_
  { {0xcf7a0002,0xe3b20031,0x2eee4165,0xd47b000a}},	//   تصاص_, _شرح_, toff_, _ואכל
  { {0x5f930180,0x6700000b,0x998c0046,0xd132006e}},	//   тишт, ोगिक_, vadž_, _لمس_
  { {0xd43f0033,0xdd9000c3,0x2eee4166,0xdcfa01ec}},	//   вiшч, اوب_, roff_, _astā
  { {0x98bf0048,0x6aaa4167,0xeb4a0342,0x2eee01c2}},	//   kstā_, _soff, очок_, soff_
  { {0xda7a0c55,0x0e66131f,0xdb0e00bf,0x7eb403a0}},	//   оян_, _окан, ždím, _làpi
  { {0x63ab00fb,0x3ce9044c,0xcb070021,0x139b000a}},	//   øgni, čava_, ويين_, קביע
  { {0x32570008,0x28f9078f,0xc27b0008,0x672d1644}},	//   וסים_, зень_, חריי, _staj
  { {0x2369005c,0x7c930015,0x60c24168,0x672d0046}},	//   ytaj_, _للمص, nhom, _ptaj
  { {0xa08b000a,0x6aaa4169,0x0000006a,0x0000006a}},	//   קְטִ, _toff,   ,
  { {0xabfb000a,0xe9cf002b,0x1bfb000a,0x9f550003}},	//   _והדר, اغی_, _ולדב, égée_
  { {0xda5b000a,0x6287416a,0x7eb40144,0x4a5b000a}},	//   _וכול, _rajo, _càpi, _ודוו
  { {0xb4fb000b,0xd7fb0054,0x62871f1f,0xb87b00e1}},	//   ्षेप_, _муп_, _sajo, roís
  { {0x3d16005d,0x672d12e7,0x883c000a,0x2369002a}},	// [9190] _पूछे_, _utaj, _ותחו, utaj_
  { {0xc2c40015,0x52770040,0x2369416b,0xf2c40058}},	//   نيقي, بارز, rtaj_, نْقُ
  { {0x51840054,0x90550342,0x644425d3,0x6287416c}},	//   куца, евец, baii, _vajo
  { {0xf9930643,0xa0740033,0xc1050040,0xe80c0065}},	//   כרע_, вышш, روشي, सेवा_
  { {0x6287416d,0x4429416e,0x4e29011e,0x0000006a}},	//   _tajo, mca_, полн_,
  { {0x4429416f,0x69c5007c,0x998c0091,0x975c000a}},	//   lca_, _üheg, nadų_, קדוט
  { {0x3f840024,0x44294170,0x4ea4009b,0x60c201cc}},	//   _esmu_, oca_, ърца, bhom
  { {0x60c24171,0x5ba9030c,0xab350054,0x3b851d8a}},	//   chom, зким_, нхој, елиг
  { {0xfe75000d,0x98bf0007,0x6bd50021,0x7e88008c}},	//   _плаќ, lutė_, عتبر, öspä
  { {0xde970031,0x9e150033,0x539a000a,0x3eac2b0e}},	//   _تجرب, _здзі, פיתו, _godt_
  { {0x98bf00df,0x644f005c,0x7e7e0020,0xa2b2000b}},	//   nutė_, _odci, õppe, _आकस्
  { {0x7eb408e0,0xa1560008,0x18a6030c,0xb4e9000b}},	//   _ràpi, עברה_, хамм, मको_
  { {0xeb990661,0x4429066f,0x5bc40015,0x7eb40144}},	//   _хил_, dca_, _لتوف, _sàpi
  { {0x98bf0024,0x09e54172,0x5b56000a,0x8bd6000a}},	//   rstā_, _полн, _ניצב_, _אונו_
  { {0x99850015,0xc5d5005e,0x75d60015,0x7ae60030}},	//   _ألبو, віть, ريرا, ékte
  { {0x46190010,0x7c294173,0xf8a90015,0x141a0015}},	//   ьцяў_, ncer, _يديه_, سيطة_
  { {0x7c2904ed,0x42560a0b,0xa3d0000b,0x7d190034}},	// [91a0] icer, етет, _वेश_, _miws
  { {0xae0f005d,0xd2630080,0x0395006b,0x7b06001a}},	//   ाधान_, лкуй, ърся, rðug
  { {0x27260092,0x0594002b,0x60c24174,0x44294175}},	//   _hôn_, _شادگ, thom, bca_
  { {0x70f6003b,0x5a0c00b2,0xb87b0089,0x442916e4}},	//   رسائ, קלאַ, mníc, cca_
  { {0xb87b01b2,0x7ebd03a0,0x60c24176,0x0000006a}},	//   lníc, _sèpa, rhom,
  { {0x2fc60ecc,0x27262ab1,0x7c2b4177,0x63b6008c}},	//   rzog_, _môn_, _afgr, myyn
  { {0x27ec005c,0xb87b0089,0x27260026,0x365b000a}},	//   ędny_, nníc, _lôn_, לכסנ
  { {0xcb1b005d,0x916c0092,0x98bf0045,0x10160033}},	//   नदंड_, _gốc_, istă_, _зьзя
  { {0xdcfa0011,0x3eac4178,0x27260016,0x9b870058}},	//   _astă, _todt_, _nôn_, فنيل_
  { {0x44294179,0x2bb70015,0xae890015,0x7b730015}},	//   zca_, عاية_, _يخلق_, اطيا
  { {0x2d960010,0xad650029,0x44292062,0x010a000f}},	//   _ярас, _لانه, yca_, ּלָּ
  { {0xb87b0156,0xed350033,0xa9c300fd,0x60160061}},	//   dníc, _рэфэ, уськ, _gümü
  { {0x6f1a417a,0x27260016,0x629c0079,0xe7380033}},	//   _kitc, _côn_, _onro, неў_
  { {0x4429005c,0xdb9b000a,0xdcb10016,0x27260034}},	//   wca_, _מסדר, _rủi_, _dôn_
  { {0xfaf7000a,0x38c9002b,0x212d0046,0x79810034}},	//   _רצוי_, _يابی_, _čeho_, cwlw
  { {0x27260026,0xf9fb000a,0x79fb000a,0x629c0bfd}},	//   _fôn_, _מהומ, _מלוח, _anro
  { {0x98bf04f9,0x4429417b,0x6d5806c0,0x25ed000b}},	// [91b0] astă_, rca_, hrva, _आँकी_
  { {0xb87b01b2,0xa19504ab,0x4429417c,0x6235005e}},	//   bníc, казч, sca_, тежу
  { {0xa2b2005d,0x442b0011,0x395e2efb,0x2004172e}},	//   _आकर्, _tfc_, nuts_, _azmi_
  { {0x9f350036,0x6536004c,0x69c80061,0xc0c8005e}},	//   веді, _שארף_, izde, нуче_
  { {0x8ca4000b,0xc87f0012,0x2d9a00cb,0x92b70015}},	//   कानो, ieß_, åpen_, _كحسا
  { {0x03d6000a,0xf774000a,0x61470030,0x395e2ecb}},	//   _יורם_, רקס_, _célá, kuts_
  { {0xada50063,0x6f1a00da,0x5de5006b,0x916c0016}},	//   тайл, _ditc, ъжка, _tốc_
  { {0xeb99071a,0x3ce9036d,0x7db40138,0x0000006a}},	//   дии_, čavo_, ысіц,
  { {0x3f150010,0xb87b0227,0x69c81754,0x6d5817f8}},	//   _адас, zníc, ezde, arva
  { {0x8a380080,0x68f6417d,0x7c290901,0xe45f0123}},	//   няют_, _skyd, scer, _flög_
  { {0x60160064,0x27260026,0x395e0251,0x09e51b5d}},	//   _tümü, _sôn_, guts_, тонн
  { {0x2d980e57,0xb87b0107,0xdd8f002b,0x26c1059d}},	//   _área_, vníc, _پوچ_, _alho_
  { {0xfd100029,0xb90a005d,0xa3d0005d,0xf7720015}},	//   _اجل_, _मद_, _वें_, جاج_
  { {0x5b560008,0x32c40064,0xb87b0107,0x395e0ad3}},	//   _ישנן_, _köye_, tníc, buts_
  { {0x26c1002c,0xe6432c6b,0x395e1392,0x7bc902ad}},	//   _dlho_, респ, cuts_, lzeu
  { {0x27260092,0x98bf0011,0xb87b0057,0x97c60015}},	//   _tôn_, rstă_, rníc, _لقبو
  { {0x46ea0a7f,0x74130015,0x935908fc,0x7bc90012}},	// [91c0] _один_, لوفا, ерху_, nzeu
  { {0xea8c0053,0xa563002b,0xb87b013f,0xe61a006b}},	//   ּנאָ, دگین, pníc, _одп_
  { {0x11390010,0x106a004a,0x67240577,0x9657000a}},	//   еячы_, дией_, _huij, _בשיא_
  { {0x63b600f2,0x67241527,0x343a0015,0xd12f0115}},	//   pyyn, _kuij, _تسدد_, زمه_
  { {0x656e002d,0xc0a90115,0x6f1a2fa8,0x8afd0046}},	//   ltbh, عامل_, _pitc, atři
  { {0x6d580264,0x201f02b9,0x2ef301f3,0x8d760015}},	//   trva, _egui_, азір, ناعا
  { {0x6eb3000b,0x7b06001a,0x71a32818,0xf653000a}},	//   _अवरु, yðub, _карз, בצו_
  { {0x6f1a26e3,0x26d82a3a,0x6d4a417e,0xdf4a0058}},	//   _witc, hiro_, rsfa, _يؤذن_
  { {0x7bc900b8,0xc4d3000f,0xb4fb000a,0xcbe6006b}},	//   gzeu, יגה_, ופקי, ъцки
  { {0xbe850806,0x69c800b8,0xdd8f002b,0x98bf002a}},	//   _مجمو, tzde, _ژول_, istą_
  { {0x02b70053,0xfaa30010,0xf2d3000a,0x6aba0012}},	//   דליך_, ршын, שעת_, rktf
  { {0x98bf00df,0x98740010,0x26d809ae,0x67240079}},	//   kstą_, алюц, eiro_, _buij
  { {0x87e7006b,0x2480309a,0xcb540015,0x26d83548}},	//   тюне, deim_, _إنتظ, firo_
  { {0xbc1b0008,0xef11000a,0xb3c10016,0x89d60015}},	//   _חודש, ֶּם_, _ngýờ, _لتعط
  { {0xe9f80010,0xa5f83510,0x0467071f,0x569401ca}},	//   _янкі_, веру_, ктам, јаст
  { {0x5454033f,0xba17000a,0x24800030,0x09f7000a}},	//   ивст, _בחוץ_, geim_, _שמהם_
  { {0x42750010,0x26d8417f,0x63f40015,0xc2991e98}},	// [91d0] лгас, biro_, لأكر, нках_
  { {0xeab4000a,0xc6f8004a,0x079a004c,0x7583002b}},	//   נִּי_, _иных_, _נסתל, _پیرم
  { {0x9268006b,0xb0350004,0x2bd9000b,0x40590015}},	//   ърта_, гнеш, _बेना, فلاح_
  { {0x55ba000a,0x61fc01d0,0x0000006a,0x0000006a}},	//   _נמרו, _dyrl,   ,
  { {0xf207005d,0x764500f2,0x8afd0089,0x78bd0150}},	//   वेज़_, _kehy, stři, iksv
  { {0x0e640036,0x9e64005e,0x62341a9d,0x8afd005a}},	//   икін, ивід, _веру, ouře
  { {0x2e48005e,0x72d40128,0x27fe0535,0x5184112d}},	//   тячо_, _торф, ętni_, _кута
  { {0x7d760015,0xe572000a,0x7bc90012,0x0000006a}},	//   امير_, צַו_, tzeu,
  { {0xec760010,0x2b150805,0x26d8003f,0x7eb40144}},	//   упы_, льор, yiro_, _càps
  { {0xc9a90080,0x7bc900b8,0xdb14002e,0x93fc000a}},	//   евое_, rzeu, ðaðr, ולחי
  { {0x26d84180,0x7bc9166c,0xdd91009a,0x186a1c80}},	//   viro_, szeu, _دوا_, нани_
  { {0xa3b5005d,0x8176000a,0xfcab002b,0x98bf002a}},	//   ड़ना_, נגרס_, _تائو_, ystą_
  { {0x1cb80086,0x7c3b4181,0xcb690015,0xf2df0034}},	//   _جالب_, mbur, _أمته_, _gwâg_
  { {0xb9c50086,0xd63a0033,0x87b9004a,0xfaf90091}},	//   _متعه, эямі_, туют_, rtūs_
  { {0xdcfa005c,0x76454182,0xe9a80015,0x7ebd0144}},	//   _wstą, _dehy, _لدين_, _rèpl
  { {0xa9220063,0x66c2002c,0xa7d60031,0x93c50016}},	//   _удъл, _dôka, _متخص, _trắ
  { {0xe29a000d,0x78ad0089,0x130a0010,0xdcfa002a}},	// [91e0] наа_, žová, енай_, _ustą
  { {0x248000dc,0x42260033,0x98bf0091,0x21a615f7}},	//   seim_, уджв, rstą_, лизм
  { {0x02190010,0x3aba0053,0xcad6000a,0xf6b7004c}},	//   віць_, עמענ, נועת_, _תּחת_
  { {0x64a64183,0x34fa005e,0x705600e5,0xc5f3000a}},	//   _сама, _їхню_, انشا, _לדת_
  { {0xdfd00029,0x7c3b3181,0xc05900ce,0x64460073}},	//   غيت_, dbur, тіє_, _ieki
  { {0xee2a0015,0x3ce602de,0xbebd003d,0x644606d1}},	//   رأته_, _sjov_, _stūr, _heki
  { {0x72c30001,0x2b4d036d,0x628e02f2,0xdb00002a}},	//   _убрз, esec_, _iabo, zymó
  { {0x7c3b4184,0x628e0a4d,0xc19b000a,0xcb540054}},	//   gbur, _habo, _אשלי, авић
  { {0x28a8005d,0xe0d50080,0x644628b7,0x628e4185}},	//   गानि, _тюрь, _meki, _kabo
  { {0x386906f8,0x49743626,0xfa860054,0x628e4186}},	//   _scar_, алос, ућим, _jabo
  { {0x6d410176,0x628e4187,0xe9f90016,0xa2f7000a}},	//   _gwla, _mabo, _đả_, רמיה_
  { {0x02170008,0x628e4188,0x64464189,0x7c3b0061}},	//   טחים_, _labo, _neki, cbur
  { {0x78bd418a,0xa774005e,0x7c22418b,0x0000006a}},	//   rksv, бляч, _igor,
  { {0x442d0f9a,0x628e418c,0x644801f6,0x0000006a}},	//   _że_, _nabo, _œdip,
  { {0x64460298,0x05bb002b,0x4d78000a,0x6459002a}},	//   _beki, ردست_, כָּא, ówio
  { {0x69c50020,0x57b5005e,0x628e02f2,0x7435005e}},	//   _ühea, _вбит, _aabo, рнаф
  { {0xd25b008f,0x2d910046,0x7d00418d,0xd3db00c3}},	// [91f0] еце_, _ázev_, ilms, ربرا_
  { {0xf8bf0089,0x25a500c0,0x628e418e,0x7c3b418f}},	//   lké_, älls_, _cabo, zbur
  { {0xb87b002d,0x7bdc0061,0x628e4190,0x7c224191}},	//   nnío, ğruy, _dabo, _ogor
  { {0x644600dd,0x7c220026,0x3d0e000b,0x853a000a}},	//   _geki, _ngor, ागों_, _שגרי
  { {0xb87b002d,0xa8580008,0x0ed9000b,0x4918004c}},	//   hnío, רידה_, _भगदड, אקאל_
  { {0x7c224192,0xed5934a8,0xa9270046,0xf8bf0069}},	//   _agor, вок_, _ježí, hké_
  { {0x56b80053,0xfd110015,0xc537000a,0xf8bf4193}},	//   רפון_, يجب_, אָ֖ה_, kké_
  { {0x628e0211,0xa9270046,0x50b9000b,0xcd2800c3}},	//   _zabo, _leží, _आविष, دسون_
  { {0x4b250054,0x7c3b0dcb,0xf8bf013f,0x4b2202ed}},	//   јмов, rbur, dké_, омыв
  { {0x3b090001,0x6ab5006b,0x3d05000b,0x39e90015}},	//   ђено_, рсих, _हीरे_, َّةُ_
  { {0xceb80050,0xb0b9005d,0xa9690001,0x787c003c}},	//   _więc_, _आवाग, њима_, _nåvæ
  { {0x7d56000a,0x91f6000a,0xdcfa002a,0x6ce4005e}},	//   _כיעד_, ימתו_, _ostę, _ліче
  { {0x903a0053,0x27760010,0x64464194,0xfb85002b}},	//   כערה, шынё, _reki, _خدای
  { {0x98ab0048,0x7c22018c,0xf8bf0089,0xc016000a}},	//   ībā_, _zgor, aké_, יקרו_
  { {0x2cbf0089,0x2bd9000b,0xdcfa002a,0x64464195}},	//   okud_, _बेता, _astę, _peki
  { {0xc9520008,0xf8bf0107,0x628e4196,0x2508002b}},	//   _ומה_, cké_, _sabo, ارسی_
  { {0x628e0035,0x78fb0447,0x2bc8000b,0x14170015}},	// [9200] _pabo, _בפקו, ाईया, ليفة_
  { {0x8fa6002b,0xd1960004,0x91960054,0xe2c70054}},	//   یماه, ишењ, ијеш, алуд_
  { {0x86c60086,0x365b000a,0x60260004,0x81f70015}},	//   _ميکن, _בכינ, адеа, لفكر_
  { {0xdfda0063,0x4f660015,0xe165009a,0x0000006a}},	//   къл_, لاتف, صدمي,
  { {0xddd80089,0x2fc000dc,0xd6a9002b,0x29020c3d}},	//   devš, áig_, _شدیم_, ilka_
  { {0x6298002c,0x7c22165e,0xf8bf01b2,0x0000006a}},	//   ôvod, _sgor, zké_,
  { {0xbd870029,0x91e30142,0xf65300a3,0x7bdd001a}},	//   لنون_, _доре, קצה_, úsun
  { {0x7b06002e,0xfd0f0015,0x24b6000a,0x320a0244}},	//   gðun, وجي_, יהֶן_, _izby_
  { {0xef1a0c96,0x6489000a,0x5f2a00ce,0x8c4300af}},	//   _ама_, רְצְ, _розм_, цење
  { {0x657e003c,0x3377000a,0xb87b0125,0x63ab0400}},	//   _opph, סעים_, tnío, ägni
  { {0xd90f0086,0x5d860029,0xb2bb000a,0x4c86011d}},	//   ویت_, _خلال, דמיר, _влев
  { {0x7c220e8c,0x4ddb000a,0x91f7000a,0x26ef0065}},	//   _ugor, _בחבו, שמטו_, चक्र_
  { {0xdb02018b,0x69c50005,0x27ed0064,0x29050024}},	//   _groß, _ühen, çen_, ēla_
  { {0x26c502c1,0xf8bf0107,0x8bd7000a,0xb87b0046}},	//   ólo_, ské_, _דודו_, mním
  { {0x3a3700f3,0xb87b01cb,0xc5170021,0xd5b811bd}},	//   _דרום_, lním, لبرت, аст_
  { {0x0933002b,0xf9fb000a,0x98bf0b48,0xa98b004f}},	//   _بروج, _שההמ, ystę_, _יָחִ
  { {0x53990afa,0x04f4017f,0x63050015,0x4615002b}},	// [9210] ывая_, ізую, مورل, _گودر
  { {0x2d87005c,0xd7fc0008,0x4304005e,0x8afd0046}},	//   ywne_, _בהחל, оїха, ouřa
  { {0xdcfa005c,0x21270092,0xa698000a,0xc175006b}},	//   _wstę, ênh_, _ככזה_, слещ
  { {0x859a0008,0xd058005e,0xe0d000c3,0xa1580033}},	//   _עשרו, арші_, وزن_, рацу_
  { {0xa2830086,0x644d0209,0xdcfa002a,0x1f640033}},	//   _ویرو, maai, _ustę, жкім
  { {0x644d020a,0x141a0008,0xddc50036,0xb87b01b2}},	//   laai, _תושב, йбли, dním
  { {0xd6580008,0x63ad0011,0x1dc40015,0x6285103e}},	//   ביות_, ţină, يْهِ, meho
  { {0x2d87002a,0x0c22006b,0x62854197,0x9db80138}},	//   rwne_, пмън, leho, рышу_
  { {0x7b06002e,0x1c4204ab,0x2cad30b6,0x7ebd0144}},	//   rðun, чным, rjed_, _lèpi
  { {0x628506f5,0x2cad0085,0x99390138,0x2cbf01d0}},	//   neho, sjed_, ляму_, skud_
  { {0x24920026,0x66c2006f,0x5c75067a,0xa288004f}},	//   ydym_, _dôkl, _глет, בְר֖
  { {0x30790053,0x29020913,0xb87b0046,0x7c84058e}},	//   נאָנ, ulka_, bním, _муче
  { {0x8ca4005d,0xeaae4198,0x62854199,0x99d5002b}},	//   कारो, _ей_, keho, شتگا
  { {0xceb20008,0x6b890028,0x62851782,0xa9690a62}},	//   ֔ים_, mweg, jeho, _бика_
  { {0x628500fb,0xceb20b7b,0xe5060029,0x95950036}},	//   deho, הים_, مبري, ошті
  { {0x70b6005d,0x6b89005c,0x75d300c3,0xd5af0015}},	//   _अकेल, oweg, سيقا, رفق_
  { {0x6b890f55,0x083b0053,0xa5070076,0x67560015}},	// [9220] nweg, _געפל, сета_, _اخبر
  { {0x6285419a,0x06860015,0xa3e9000b,0x82660058}},	//   geho, _الدُ, _बशर_, إهان
  { {0x657e09c9,0xccf9002a,0xc329000a,0x6b8901f1}},	//   _upph, koś_, תו_, hweg
  { {0xe80f0065,0x60ea0138,0x0000006a,0x0000006a}},	//   _सरमा_, ымем_,   ,
  { {0x4432005c,0x7bdd0030,0x8cab000b,0x787b000a}},	//   mcy_, úsul, झानो, רָבו
  { {0x82360086,0xb87b0089,0xdfa50029,0x764e0026}},	//   _درحا, vním, تحمي, naby
  { {0x171b0053,0x2bd0000b,0x2d9a151b,0x4432051e}},	//   נוצע, _तेजा, ípe_, ocy_
  { {0xccf9005c,0xb87b0089,0x6cd40070,0x44320bf5}},	//   goś_, tním, تقبا, ncy_
  { {0xe81a005d,0x6c7700e6,0xab940036,0x28cc000b}},	//   नेमा_, صحيح_, ципі, ासनि
  { {0xa9540001,0xbf37000a,0x60c21590,0x8bd30033}},	//   овољ, _לאמץ_, lkom, яжыц
  { {0x69c50020,0xf2970008,0x7dc50015,0x753c002a}},	//   _ühel, זכיר_, _وتمك, jprz
  { {0x2360016f,0x66cb0064,0xb87b3524,0x60c21bbd}},	//   krij_, _müke, mník, nkom
  { {0x02fa005d,0x4432005c,0xb87b0107,0x6c060033}},	//   ्ताह_, dcy_, lník, _уздз
  { {0x98bf0007,0x2c17000a,0x99e3006f,0x78a41ee8}},	//   putį_, _הקדש_, ŕňaj, _eniv
  { {0xfa770008,0x60c20ac8,0xb87b0b7e,0xd6d80c71}},	//   _העות_, kkom, nník, стя_
  { {0xf98f003b,0xa4d4005e,0x66090046,0x60c2419b}},	//   _أبو_, посі, řeko, jkom
  { {0xdc9b0008,0x52d90010,0x43740036,0x644d0111}},	// [9230] נימל, амаю_, зуєт, raai
  { {0x3255042b,0x7afa419c,0x644d419d,0x60c2419e}},	//   івер, nott, saai, ekom
  { {0x644d00dd,0xda7b000a,0xb87b01b2,0x50b500fd}},	//   paai, רנבר, jník, жслу
  { {0x62850041,0xb87b0057,0xe04b002b,0x4432002a}},	//   seho, dník, اشاه_, ccy_
  { {0x68ed003f,0x7afa419f,0x212d003d,0x2ef50e16}},	//   _mjad, kott, _čehu_, оздр
  { {0xad5932d5,0x7afa1200,0x6e440015,0x60c241a0}},	//   арих_, jott, كنهم, akom
  { {0x7afa41a1,0xd658000a,0xb6bc000a,0x60c20012}},	//   dott, זיות_, רצוי, bkom
  { {0xa0c500e5,0xe81a000b,0x7ae80789,0x6b890aa8}},	//   _بيرو, नेडा_, endt, tweg
  { {0xb87b0089,0x8b940010,0x60c9003f,0x272f0064}},	//   mníh, прэч, _ilem, _nün_
  { {0xb87b0107,0x68ed007c,0x6b890b9d,0x6fb8000b}},	//   lníh, _ajad, rweg, ्नरू
  { {0x6b89059b,0x4432002a,0xb87b00bf,0xfc33002b}},	//   sweg, ycy_, cník, _فحش_
  { {0xb87b0089,0x88d60033,0x69c5007c,0xd7ca0021}},	//   nníh, іўні, _ühem, لوجه_
  { {0x9ad50015,0x66090046,0x3cf80030,0x69d90157}},	//   _وتتض, řekl, _írva_, _फेरी
  { {0x44320050,0x272f0064,0x6b9400dc,0x8f9a000a}},	//   wcy_, _dün_, üggő, בישי
  { {0x60c909e7,0xda0d0065,0x443241a2,0x60c241a3}},	//   _olem, _हरित_, tcy_, ykom
  { {0xa3ea000d,0x25a500c0,0xb87b0089,0x236041a4}},	//   адба_, ålla_, jníh, trij_
  { {0x272f01e2,0xb87b099c,0x60c241a5,0x753c002a}},	// [9240] _gün_, dníh, vkom, sprz
  { {0x4432005c,0x67bb000a,0x68ed002a,0x88050040}},	//   scy_, _כמפק, _zjad, _عظيم
  { {0xd1790010,0x4432002a,0xd12f0015,0x867b000a}},	//   йсці_, pcy_, نمل_, _דריו
  { {0x7afa00dc,0x20560036,0xdfd200e6,0xb87b0057}},	//   zott, ітер, ويض_, vník
  { {0x02460015,0x2bd9000b,0x7ae8063b,0x60c23046}},	//   _وَحَ, _बेला, yndt, rkom
  { {0x66cb19a2,0xb87b0107,0x60c241a6,0x394727c8}},	//   _tüke, tník, skom, _owns_
  { {0xb87b0089,0x7afa41a7,0x6da300d7,0x60860015}},	//   bníh, vott, дија, _وشرك
  { {0xb87b01c9,0x60c901f0,0x412723cc,0x61d7000a}},	//   rník, _glem, _фото_, _וולף_
  { {0x7afa0014,0x8e76054f,0x2aaa1797,0xb87b01c0}},	//   tott, _мужч, атно_, sník
  { {0x7afa00f2,0x6f79000a,0xd37b000a,0x6ec60015}},	//   uott, _לְעו, סריט, _بترق
  { {0xd8f90036,0xdce30089,0x60c9008c,0x729b000a}},	//   йної_, ntně, _ylem, בסיס
  { {0xa9c30036,0xb87b0046,0xad65002b,0xb834004a}},	//   фськ, diíc, _رامه, меющ
  { {0xdb240020,0xdc290029,0xc0530008,0x7afa41a8}},	//   öpäe, _اسمه_, וזר_, pott
  { {0x7bdb000a,0x2eaa000a,0xb87b41a9,0x89d60058}},	//   _דקדו, ׁשָּ, zníh, _وتغط
  { {0xc4db0001,0x344b0155,0x1515005e,0xe534005e}},	//   ађа_, ичан_, здвя, десь
  { {0xa5f8005e,0x8d5b000a,0xc8b40015,0x83351b42}},	//   цесу_, יכלי, _يصيب, знах
  { {0xb87b0089,0x28a8000b,0x7bc041aa,0xbec301ec}},	// [9250] vníh, गारि, nymu, _ņūme
  { {0x8c1b0008,0x2d9e00b8,0xe784002b,0x60c941ab}},	//   שומי, _orte_, _کلیپ, _slem
  { {0xb87b2af9,0xdb1100dc,0x66280046,0x60c941ac}},	//   tníh, égén, ňské, _plem
  { {0x397b0053,0x15fa0008,0x7bc00007,0x50b80086}},	//   שטאנ, _להתע, kymu, يدند_
  { {0x9028008f,0xb87b0089,0x7feb0015,0x9405002b}},	//   іцца_, rníh, جراف_, _روسه
  { {0x7bc00007,0xb3ba0008,0x59ca000b,0x57fc000a}},	//   dymu, _המשכ, ानार, בלדו
  { {0xf2d200b2,0x6b8241ad,0x30e7005e,0x067c000a}},	//   _װען_, _apog, _діаб, ינגל
  { {0x60db055d,0x29190085,0x60c941ae,0x24890045}},	//   _umum, jmsa_, _ulem, neam_
  { {0x9f05006e,0x629541af,0x2d9e02ad,0x0000006a}},	//   _فورو, _kazo, _erte_,
  { {0x0b42008f,0x69c50020,0x02b60008,0xdd950139}},	//   эньн, _ühek, ִ֔ים_, _назы
  { {0xe8fa0286,0xf76900a3,0x62951164,0x6abc0bc2}},	//   йло_, _תק_, _mazo, örfa
  { {0x629541b0,0xcd96000a,0x7d7a004f,0x8bb70058}},	//   _lazo, _מדעת_, _לנעו, _وإشا
  { {0x24890045,0x47c3006b,0x87b90054,0x672d0077}},	//   deam_, ебяв, оурт_, _cuaj
  { {0xdce3288e,0x3ffa004c,0x9bb6000a,0x62950d80}},	//   ytně, מפרע, _מהנה_, _nazo
  { {0xd575005e,0x64a60329,0x7e7e007c,0x7ae141b1}},	//   муть, пава, õppi, milt
  { {0x7ae100f2,0x19ba000a,0xb87b0046,0x6fbd000b}},	//   lilt, _למצב, riíc, ्नां
  { {0xe45f0123,0x2369006f,0x33660033,0x7ae1008c}},	// [9260] _glöm_, guaj_, яваг, oilt
  { {0x079b000a,0x7ae1008c,0x479b000a,0x741300c3}},	//   _פסיל, nilt, _פייס, رولا
  { {0x7bc0005c,0xb6bb000a,0x72060015,0xe9f90016}},	//   zymu, _הציי, أوام, _đẻ_
  { {0xdce30089,0xf8cc000b,0x32170015,0x24890045}},	//   rtně, ासिय, سيند_, ceam_
  { {0x4393008f,0xdce30089,0xa857000a,0xce94006b}},	//   _заўс, stně, פיסה_, далъ
  { {0x97570008,0x7ae100f2,0x877b0135,0xcf39005e}},	//   לינו_, jilt, מאני, іччі_
  { {0xb87b0089,0x28af000b,0x69c5007c,0x7ebd0144}},	//   mnív, टामि, _üheh, _rèpt
  { {0x7bc000df,0x515b0008,0x2124002d,0x2004005c}},	//   tymu, _לכלו, _uimh_, _tymi_
  { {0xfc3f02c1,0x66cb0020,0x5b14004a,0x69c10d40}},	//   ñía_, _lüka, ммит, eyle
  { {0x7f3b0008,0x2aaa0001,0x7ae141b2,0x6b8200bc}},	//   _לעמו, стио_, gilt, _vpog
  { {0xe29b0053,0x7bc00091,0xe9e6004a,0x0d86009b}},	//   זשיר, symu, яцио, _хлен
  { {0xab5d005c,0x2db5004c,0xd8380033,0x7ae141b3}},	//   wyże, _קלײן_, зэр_, ailt
  { {0x6cc324cc,0xab94005e,0x8c432791,0xfaa6053b}},	//   _яйца, _цилі, _чече, _надо
  { {0x8c1b0008,0x96eb0666,0x0ebe000b,0x7ae10046}},	//   _הודי, сьма_, ्सिड, cilt
  { {0x7a7b0008,0x67250201,0x4a7b000f,0x8a7b000a}},	//   _הרוס, _vihj, _הרוב, _האות
  { {0xb9250029,0x629541b4,0x0000006a,0x0000006a}},	//   _تفعي, _sazo,   ,
  { {0xa4d4005e,0xc2c5006e,0x248941b5,0x3375066a}},	// [9270] хоті, ويري, ream_, ьгар
  { {0x9736004c,0xd3d80015,0xa2cd000b,0x24890b95}},	//   _קרתא_, سبقا_, _दॄश्, seam_
  { {0x5fca000b,0x94d50033,0x7515006b,0xc4c70015}},	//   ़ैसल, _жонц, _омоф, _فتحو
  { {0xc5f2013a,0x2ec5014e,0x04670080,0xe81a000b}},	//   _ידי_, वस्त, _этом, नेवा_
  { {0x226801cb,0x46d1000b,0xa858000a,0x69c1002a}},	//   átké_, _हताह, ליאה_, zyle
  { {0xc7d80008,0xc3320053,0xbe650015,0x7d02006f}},	//   הודי_, _בוך_, ذهبي, _akos
  { {0xd1640063,0x644f013c,0x7ae141b6,0xdef80033}},	//   _пъти, _keci, vilt, чыц_
  { {0xd578000a,0xa2d9000b,0xdb1b0012,0x3f9f007c}},	//   פתחה_, फोर्, szuü, _truu_
  { {0x3af50036,0x3e5f0024,0xbe4b0029,0x5ba90484}},	//   дянс, tātē_, _هشام_, іком_
  { {0xfb160015,0x637f0045,0x69c141b7,0x0b160015}},	//   وقيع_, mână, tyle, وقية_
  { {0xbe640029,0x4439003f,0xc236000a,0xdc750033}},	//   _أهمي, _ofs_, ורתו_, _жыль
  { {0x7ae141b8,0xc19a000a,0x3dfa000a,0xd7f80045}},	//   silt, קשרי, _ולעד, şăm_
  { {0xe20a000b,0x0056000a,0x161b000b,0x9056000a}},	//   _वर्ण_, ושרת_, फेसर_, וברו_
  { {0x4df900b2,0x8cab005d,0x3ced007c,0x7d0941b9}},	//   ַפּא, झावो, lnev_, lles
  { {0xcb12013a,0x66d000f2,0x66030098,0x69c702de}},	//   _שלו_, _näke, впра, øjed
  { {0xe8f60029,0x656100dc,0xf50a017f,0x9729002b}},	//   _تستخ, álha, інал_, _کثيف_
  { {0x073a003b,0x644f06d7,0x03260a66,0x644441ba}},	// [9280] _بسبب_, _deci, ддан, rbii
  { {0x244c0092,0x2734008c,0x7d0941bb,0x59e10065}},	//   ếm_, _iän_, hles, _पधार
  { {0x2734022d,0xc04f042b,0x644f41bc,0xe0da005e}},	//   _hän_, кі_, _feci, овж_
  { {0x7d090014,0x644f0064,0x7bcd0024,0x09b6004c}},	//   jles, _geci, _ļaun, ופעט_
  { {0x7d0941bd,0x7d1b007c,0x5f73006e,0xdf7300c3}},	//   dles, dmus, ناور, ندوب
  { {0x273400c0,0xc7d7000a,0xc7b3000a,0x644f0045}},	//   _män_, ווני_, כבד_, _zeci
  { {0xdcb10092,0x273400c0,0x7d0941be,0xbbb8000b}},	//   _hủy_, _län_, fles, ेन्क
  { {0x8d170029,0x99720046,0x3ced007c,0x7d0941bf}},	//   وزير_, těže_, gnev_, gles
  { {0x9a8a009b,0x2d850c4e,0x765e41c0,0x0000006a}},	//   ощна_, _eple_, _odpy,
  { {0x80da000b,0x7d1b41c1,0x7d0941c2,0xc333004f}},	//   पोरे, amus, ales, ףות_
  { {0x7c390176,0x2d960010,0x7d0941c3,0x7e7e007c}},	//   _ffwr, _юрас, bles, õppu
  { {0x6d5841c4,0x2ba7005d,0x2bd9000b,0xab2a0054}},	//   msva, _औपचा, _बेका, _дода_
  { {0xad1b00b2,0xb33b03af,0x98040010,0x644f0c07}},	//   _וואר, _orça, вярд, _reci
  { {0x7d000014,0xfbd30008,0x5bb7017f,0x8b650015}},	//   loms, _בתנ_, _юлія_, _ساهم
  { {0xef0e0010,0x8afb0008,0xf98f0015,0xbafb000a}},	//   ымi_, _והגי, _نبي_, _והגש
  { {0x7d0041c5,0xf929004c,0xdcfa003d,0xc9832815}},	//   noms, _צופּ, _istē, _руши
  { {0x66d001d1,0xbf0e005d,0xd3710029,0x14190015}},	// [9290] _säke, िताभ_, طها_, سيئة_
  { {0x3207005c,0x7d1b00dc,0xd25100e5,0x6716000b}},	//   żnym_, zmus, انا_, _दीपक_
  { {0x35f40010,0x7d0041c6,0xe139005e,0x644f016e}},	//   _апэр, koms, їзді_, _teci
  { {0x9015042b,0xd0110015,0x66d0008c,0x645d02de}},	//   нфлі, هلا_, _väke, _udsi
  { {0x6d5a02d2,0x8e85120f,0xf43a000a,0xc43a000a}},	//   _avta, егле, _מגרמ, _מתרי
  { {0x6d58002e,0x63050015,0xa1590033,0x7d090c12}},	//   fsva, _أوسل, _нагу_, wles
  { {0xdce801e2,0xade80015,0x7d0941c7,0x7d1b41c8}},	//   _ardı, وفهم_, tles, tmus
  { {0xcf7b0029,0x9f5100dc,0x98bf0024,0x6aaa0026}},	//   _وإذا_, ából_, istē_, _anff
  { {0x7655005c,0x7d0941c9,0x7d1b41ca,0x6d58019a}},	//   kazy, rles, rmus, asva
  { {0xeab1003b,0xaad9014e,0x394505cb,0x3ced007c}},	//   اعة_, योंक, нног, snev_
  { {0x88e60080,0x8d740015,0xdce3003d,0x7d1b41cb}},	//   ежне, _لانا, aunā, pmus
  { {0x8d740058,0x6d4303a0,0xdd0301ec,0x0000006a}},	//   _جاكا, mpna, īrēj,
  { {0xfb680029,0xcbc70015,0xbbeb006e,0x6d430091}},	//   _قصوى_, _تزاي, _برام_, lpna
  { {0x273400c0,0x7655005c,0x8afd0046,0x0000006a}},	//   _vän_, gazy, kuři,
  { {0x99d70015,0xf9880015,0xb87b006f,0x98ad0061}},	//   _تتشا, _ينهي_, tnít, ardı_
  { {0x89da000a,0x88c60015,0x7a310030,0x273402dc}},	//   _מחצי, _ستعل, _fűté, _tän_
  { {0x3860002f,0xc32a0029,0xd7ca002b,0x29020091}},	// [92a0] _idir_, سكان_, _روده_, moka_
  { {0x6d5800f2,0x290241cc,0xd36f0015,0x68e641cd}},	//   ysva, loka_, صهم_, likd
  { {0x8066006b,0x5637004c,0xb89a000a,0xcd01005a}},	//   евеж, _ראטע_, ּבְש, _zvěř_
  { {0x25a50134,0x2615000b,0xab5d002a,0x0000006a}},	//   ælle_, _धरती_, zyża,
  { {0x70530074,0x1dd8005d,0xe3b20015,0xa857000a}},	//   انها, _भेजत, _صرح_, תינה_
  { {0x66cb0064,0x6d5841ce,0x645641cf,0x29021a0f}},	//   _nükl, tsva, layi, hoka_
  { {0xe9f90092,0x867b000a,0x6d58008c,0x657c0034}},	//   _đế_, פרקו, usva, ntrh
  { {0xdd99005e,0xe573004c,0xdddf0264,0x64563ec2}},	//   ьші_, אַץ_, ávšt, nayi
  { {0xaf490029,0x6f66002b,0x1e863d93,0x290241d0}},	//   _يشكل_, _سهام, _плам, doka_
  { {0xdce30024,0x539b0008,0x64560035,0x98a8003d}},	//   runā, ליפו, hayi, _runā_
  { {0xfbcf0074,0x28f90036,0xc27b000a,0xf2d3000a}},	//   لتی_, день_, הריי, רעת_
  { {0x657c0046,0x76550535,0x0000006a,0x0000006a}},	//   dtrh, wazy,   ,
  { {0x8ae6005e,0xbb430054,0x2fc602f2,0x3ebe3a77}},	//   _пікл, _бечк, nyog_, _kott_
  { {0xdb0604f8,0x6aaa0034,0x6561001a,0x0000006a}},	//   ämäk, _unff, álho,
  { {0x3a370053,0x5a9b0053,0xc8f5006b,0x758801c5}},	//   _ארום_, _זשוא, _изкъ, нств_
  { {0x68e6006f,0x47d5012c,0x26ca02f2,0xd4980e40}},	//   cikd, _ليبر, akbo_, нру_
  { {0x66cb41d1,0x78ad003f,0xad1b0008,0xc6f90001}},	// [92b0] _yükl, _inav, לולר, _оних_
  { {0x8234002b,0xa535004a,0x0000006a,0x0000006a}},	//   هرما, _иноч,   ,
  { {0xa5f90164,0x69c5007c,0x92680033,0x645602f2}},	//   _цену_, _ühet, эрта_, bayi
  { {0x645641d2,0x1ee7009a,0x307402ed,0x0000006a}},	//   cayi, کوتی_, гушс,
  { {0xf8b20008,0xee2e01d2,0x3ebe02dc,0x0000006a}},	//   ישׁ_, ин_, _bott_,
  { {0x7b06001a,0x5f740015,0xd738004f,0xb7dc004f}},	//   iðus, طاهر, עטות_, הקדי
  { {0xbe980015,0xc694000a,0x3ebe2a00,0x7d760015}},	//   عضها_, ראצ_, _dott_, نمور_
  { {0xb47b000a,0xa2a9000b,0x6b840045,0xdca10033}},	//   לָ֖י, घाक्, _ţiga, рскi_
  { {0x98a80011,0x66d00123,0x999e0091,0x29021c4e}},	//   _lună_, _läka, katų_, voka_
  { {0x6d430677,0x5d850015,0x23690085,0x64560061}},	//   ppna, _للطل, iraj_, zayi
  { {0x29020f4d,0x999e0091,0xac96002b,0x68e630b1}},	//   toka_, datų_, رنیا_, tikd
  { {0x2369044c,0x48e6017a,0x3c470015,0x8de40015}},	//   kraj_, томв, _أضاف, _حكمه
  { {0x5bc40029,0xda0d000b,0x2bd9000b,0x290241d3}},	//   _متوف, _हरकत_, _बेचा, roka_
  { {0x6f0341d4,0xdce304f9,0x98a804f9,0x80d8005d}},	//   nonc, bună, _bună_, _मतभे
  { {0xe5060015,0xceb2000a,0xb6a30054,0x7c3b41d5}},	//   نبري, סיל_, јисл, ocur
  { {0x7bcd0024,0x7c3b0faa,0x38c8002b,0x320a0771}},	//   _ļauj, ncur, _ساعی_, _ryby_
  { {0x24780089,0x6f030057,0x8bac000a,0xe29a0004}},	// [92c0] _němž_, konc, ּׁבִ, маа_
  { {0x69c50020,0xd707004a,0x6d410061,0x6f0341d6}},	//   _ühes, _иные_, _otla, jonc
  { {0xd1390033,0x645609cf,0x6f0341d7,0xc3050058}},	//   ехі_, payi, donc, ابقو
  { {0x00e60063,0xb5f7000a,0x85f7000a,0xc0aa0015}},	//   ъжен, _יציג_, _יציע_, باطل_
  { {0xcf77003b,0x7b06002e,0xd7ed0008,0x6d412e0f}},	//   نصوص_, iður, ּקוֹ, _atla
  { {0x1ee60086,0x6e940015,0xb7db000a,0x6f0341d8}},	//   ضوعی_, الثا, וקני, gonc
  { {0x8d7300e6,0x27fe002a,0x4d730015,0x180f0157}},	//   لايا, ętny_, لطير, _सर्व_
  { {0xd1970008,0xc5f30008,0x6aca005d,0xdb980818}},	//   _בכלי_, ידו_, िस्र, евич_
  { {0xcb672392,0x207b0053,0x09ca000b,0x4f260033}},	//   вање_, _קאמא, ान्य, _адаб
  { {0x60c041d9,0x0b180015,0x64bf000b,0x629c1837}},	//   _homm, عقدة_, _एक्श, _jaro
  { {0xddc80050,0x6c860029,0x3257000a,0x629c41da}},	//   _wedł, _للام, כסים_, _maro
  { {0xc1730008,0x7793002b,0x7c3b41db,0xac980015}},	//   סחר_, لیبا, ccur, _سنتا_
  { {0x48e40010,0x98a80045,0x999e0091,0x8bb30015}},	//   роўв, _sună_, tatų_, _نصوص
  { {0x98a80045,0x7b06001a,0x3a3a007c,0x60c01789}},	//   _pună_, rðus, _üpp_, _lomm
  { {0xd6d80191,0xa4d50036,0x999e0007,0x25a5002e}},	//   ття_, гові, ratų_, íll_
  { {0x236900bd,0x999e0007,0x442f0134,0x98750001}},	//   traj_, satų_, øg_, _слиц
  { {0x7b320050,0x59ca014e,0x629c41dc,0xebd4000a}},	// [92d0] _dług, ानकर, _baro, נֵֽי_
  { {0x4b7b000a,0x6b7b000a,0xab5d002a,0x5b7b000a}},	//   ואמו, ורמנ, zyżo, ורמא
  { {0xe1f00086,0x69da00b8,0x66cb0020,0x63a600cb}},	//   يسم_, nzte, _lükk, _erkn
  { {0x60c00376,0xdff501b0,0xf2df0034,0xfe000065}},	//   _comm, ляль, _stâd_, _लुइस_
  { {0x6f0302c1,0x6d41002c,0x3f890026,0xa3ad000b}},	//   tonc, _stla, ïau_, _कपट_
  { {0xaf040010,0x3ce5000b,0x69c802de,0x629c41dd}},	//   апіл, जोने_, kyde, _garo
  { {0x8d54008f,0xf2d20008,0xb6bc000a,0x7db4006b}},	//   атыч, _פעל_, וצגי, исъц
  { {0x7c3b0045,0xa5c3002a,0x629c05e9,0x69da003d}},	//   ucur, łóws, _zaro, dzte
  { {0x10e4005e,0xac960015,0x6f0341de,0x7c3b41df}},	//   _тюрм, انًا_, ponc, rcur
  { {0xa3bb000b,0x4a45004a,0x66cb0061,0x68e42318}},	//   _अपन_, ынов, _dükk, _smid
  { {0xaad9005d,0x59ca000b,0xbc75006e,0x201a002a}},	//   योगक, ानगर, _مهاب, ępie_
  { {0xf7463878,0xe9a6002b,0x0000006a,0x0000006a}},	//   лемо, اگون_,   ,
  { {0x69c80064,0x7b06002e,0x20f81de0,0x6b650605}},	//   ayde, rður, nčia_, _скла
  { {0x5a47008f,0x69c80134,0xdbd10020,0x7b32002a}},	//   _рэда, byde, _müüm, _sług
  { {0xba56000a,0x057a0015,0x98b9003d,0x6ed2002a}},	//   _עסקו_, عمرة_, ūrā_, głby
  { {0x97c60115,0x68e4035d,0x49b80067,0x629c41e0}},	//   _مقبو, _umid, _جاهد_, _saro
  { {0xdd030007,0xd91b000a,0xfe00000b,0x6ed2002a}},	// [92e0] ūrėj, _אוקל, _लुईस_, ałby
  { {0x1423004a,0xb7db000a,0xe45f0123,0x7bdb007c}},	//   сдум, _נקיי, _slöt_, izuu
  { {0x4a560053,0x20f80007,0x629c41e1,0x66090046}},	//   רשעל_, ečia_, _varo, řekr
  { {0xea160053,0xa09a0029,0xd12f0002,0x629c41e2}},	//   אַדי_, عضاء_, سمه_, _waro
  { {0x69c8005c,0x60370010,0x44240092,0x08770053}},	//   zyde, упіў_, _àm_, רענט_
  { {0xa2260086,0xf7730008,0xf8bf0152,0xf67a0053}},	//   _مرزه, מקד_, mmée_, גאַמ
  { {0x8d860086,0x63a430d7,0x067b000a,0x7ae80030}},	//   اشتن, lvin, תנצל, vidt
  { {0xbd8700e5,0x7ae800da,0xdb020003,0x63a441e3}},	//   انين_, widt, _croî, ovin
  { {0x66d000c0,0x69c800dd,0x5c060010,0xbb470015}},	//   _räkn, wyde, ыяка, هلين_
  { {0x69da018b,0xe37b0053,0x7afc00bd,0x4a54000d}},	//   tzte, עריר, črto, шкос
  { {0xd2b70008,0xa9c60086,0x26c10573,0x9d460004}},	//   אלית_, ازخو, _roho_, _сеед
  { {0x8dfb000a,0x66cb007c,0x69da0012,0xc8af000b}},	//   _אהבת, _tükk, rzte, टाइट
  { {0x69da0014,0x63a40298,0xf093000a,0xd7f80ea9}},	//   szte, jvin, זנר_, гур_
  { {0x98bf0007,0x99d60002,0xa9c6002b,0xef11000a}},	//   ystė_, _متعا, _مزبو, ַּם_
  { {0x58d50080,0xdce3005c,0x69c5007c,0x2a57000a}},	//   _войт, suną, _ühep, _גבון_
  { {0x84c4000d,0x20f80007,0xc517002b,0xddd80046}},	//   бљуд, yčia_, ابست, ravň
  { {0x395e0048,0x26c10156,0xbec70024,0xf6d4002b}},	// [92f0] lsts_, _toho_, ldīš, _گزيد
  { {0x52150010,0x22290086,0x212d0012,0xc7fa004f}},	//   адзт, نزای_, _sieh_, _יִיר
  { {0x46150086,0xf1a70033,0x24f90088,0xb0353f64}},	//   _خودر, ыран, _анны_, анеш
  { {0x5f750087,0xbec7003d,0x395e32bc,0x98bf0091}},	//   لاتر, idīš, ists_, rstė_
  { {0xb4c3021e,0x926b00d7,0x212d0012,0x644d41e4}},	//   ्सी_, _прва_, _vieh_, mbai
  { {0x395e0048,0x20f81e63,0xe81a000b,0xfe71002b}},	//   ksts_, rčia_, नेटा_, تگر_
  { {0xfc310029,0xc694000f,0xce580015,0x7e960015}},	//   يحة_, מאס_, اؤها_, شنير_
  { {0x999c00dc,0x644d0034,0x3d0f000b,0xab6501e8}},	//   _nevű_, nbai, ातें_, авил
  { {0x395e41e5,0xab760015,0xa0c40015,0xf8af000b}},	//   ests_, لميا_, _ايقو, टाईय
  { {0x752f0050,0x99d50029,0x644d01c2,0x62850125}},	//   _licz, لتجا, hbai, nfho
  { {0x395e003d,0x63a40bf6,0x7b060052,0x0000006a}},	//   gsts_, zvin, rðup,
  { {0x63a40007,0x752f005c,0xaad9000b,0xd8262b12}},	//   yvin, _nicz, योजक, идни
  { {0xb8ee005d,0x26d80e18,0xbec7003d,0xe8f724cc}},	//   _शक_, thro_, adīš, рля_
  { {0x5f36004c,0x644d41e6,0xaa450e41,0x0676009b}},	//   יטשע_, ebai, _текл, шумя
  { {0x2d5304f9,0x09e2000d,0x6285002d,0xc50a002b}},	//   nţe_, _мошн, dfho, نترل_
  { {0x8a1400b0,0x47c60036,0x397a000a,0xb97a000a}},	//   _اظها, _вбив, _סטפנ, _סנפי
  { {0x63a40011,0x68fd0030,0xb89b000a,0x0000006a}},	// [9300] uvin, érde, _יבקש,
  { {0xf8bf0152,0x55e60860,0x644d1634,0x3ce5000b}},	//   rmée_, _вооб, abai, जोते_
  { {0x765c051e,0x21a3006b,0xe4520015,0xe2970c39}},	//   mary, жихм, _وضح_, рах_
  { {0x39a503eb,0xe1690086,0x2167061e,0x20f801a3}},	//   _mēs_, اصله_, рици_, ačin_
  { {0xd0070010,0x98a60064,0x94d20065,0x9326009a}},	//   аеце_, nslı_, ससीआ, _نرسن
  { {0x8c9e005d,0x644c005c,0xfaf90091,0xf773000a}},	//   _खोजो, śnię, irūs_, קקו_
  { {0x69c70134,0xdce10064,0xf653000a,0x3d88002b}},	//   øjel, _aslı, חצו_, احتی_
  { {0x0ca70080,0x656e002d,0xc19b0008,0xf19b000a}},	//   атьи_, irbh, _בשלי, _בשלש
  { {0x22580161,0x0c73002b,0xdce3003d,0xafe6275e}},	//   _kerk_, زديد, urnā, _тоал
  { {0x0f7b0053,0x6fb30015,0x7ac6004a,0x2ac60054}},	//   _באמב, _بمكا, рсие, рљив
  { {0x765c00df,0x20f80007,0xc237000a,0x225841e7}},	//   dary, nčio_, יריו_, _merk_
  { {0x4d7b000a,0x6d4a0012,0x20f80091,0x765c0034}},	//   _ירבע, mpfa, ičio_, eary
  { {0x98bf0024,0x765c0026,0x394941e8,0x9be300fd}},	//   lstī_, fary, _čase_, _мішк
  { {0x8c1b039e,0x96eb005e,0xddc8003d,0x8f8b000a}},	//   _סוגי, тьма_, _vedņ, כְלֵ
  { {0x6abc001a,0xc6900015,0x7afd030b,0x95c80a3e}},	//   örfu, بِّ_, éste, аута_
  { {0xb4c3014e,0x04c90029,0xc4d80054,0x7b32002a}},	//   ्से_, دوري_, ађу_, _głuc
  { {0xe3b00029,0x284a0053,0x98bf0011,0x644d41e9}},	// [9310] ورك_, _געפּ, aptă_, rbai
  { {0xf6990431,0xf1a70840,0x752400bc,0x52d801b0}},	//   _свој_, ирен, amiz, амую_
  { {0x28cc005d,0x6285002d,0xd347009a,0x20f80160}},	//   ासचि, rfho, _چیره_, rčin_
  { {0x6285002f,0x0000006a,0x0000006a,0x0000006a}},	//   sfho,   ,   ,
  { {0x4fa50e44,0x351a000a,0x8fa53de5,0x0000006a}},	//   силв, _תורנ, сале,
  { {0xaaa6005d,0xdef40010,0x20180029,0x539a000a}},	//   _कोलक, опчы, جتمع_, _גישו
  { {0x02040010,0xad5804ab,0xf158006b,0xc537000a}},	//   _дзён, арых_, _висш_, בָ֖ה_
  { {0x85f81c6f,0x2d530011,0xe5f8000a,0xb5f8000a}},	//   יצוע_, rţe_, יזור_, יצוג_
  { {0x0ab50029,0xcce40029,0xa4b8000a,0xdfd40033}},	//   محدد, تسوي, שלחה_, _доты
  { {0x7b32005c,0x9f950020,0xadbd0033,0x0000006a}},	//   _słuc, _müüa_, _пазi,
  { {0x39e903fa,0xf2d2004c,0x9f95007c,0x7b32002a}},	//   удно_, פעט_, _lüüa_, _płuc
  { {0x6d3a000a,0x20f80046,0xfde30065,0x765c0535}},	//   _עֲבו, jčil_, _केएस_, wary
  { {0xfaa5008f,0xdc360053,0xd7f20015,0x6d5e0091}},	//   _гало, _האנט_, سكس_, špat
  { {0x2cbf0020,0x7d090026,0x501a000a,0x65680030}},	//   ljud_, loes, טורו, ádho
  { {0x765c02f2,0xd46a0248,0xddc80046,0x66d041ea}},	//   rary, ливе_, _bedř, _häkk
  { {0xd3ba0036,0xf99200a3,0xfaf90091,0x765c1c65}},	//   лузі_, _זרה_, prūs_, sary
  { {0xd4f50010,0x273d0016,0x225800aa,0xf7860015}},	// [9320] цяры, _gìn_, _perk_, _الخَ
  { {0xd7bb000a,0x2cbf007c,0x77bb000a,0x66d00c56}},	//   _עציר, hjud_, _עמיח, _mäkk
  { {0x98b90007,0xdce3002a,0x72060015,0x1637000a}},	//   ūrą_, sunę, حوام, _לניר_
  { {0x22581f29,0x649a005e,0x7109005e,0xc0570033}},	//   _werk_, _стор_, ахів_, біш_
  { {0x0eea0191,0x20f80007,0x987b0053,0x30830015}},	//   льки_, sčio_, ראנט, سلوف
  { {0xa2d60087,0xb77b000a,0x479b000a,0xdb02016e}},	//   _ايست, רָאת, טינס, _proí
  { {0x64430050,0xddc100dc,0x6e870015,0xbd870015}},	//   śnie, _belő, صنيف_, منون_
  { {0x84d6000a,0x6d4a03c1,0x0000006a,0x0000006a}},	//   מֵ֥א_, rpfa,   ,
  { {0xe4570053,0xdad80004,0x5ba30033,0x69160030}},	//   זיפט_, имиц_, прэз, ráel
  { {0xd90f0086,0x7bcd0024,0x63ab056e,0xfbcf0015}},	//   کیب_, _ļaut, ågni, عتي_
  { {0xd8f9005e,0x2d980003,0xddc10030,0x2cbf0123}},	//   иної_, _ère_, _felő, bjud_
  { {0x02170008,0x2d9e41eb,0x2eee100b,0x2db7004f}},	//   מחים_, _iste_, liff_, _ללבן_
  { {0x57f4009b,0x27ff007f,0x0000006a,0x0000006a}},	//   зпят, çun_,   ,
  { {0xeaf5014e,0x1a930033,0x35b5005e,0x2eee2d76}},	//   ीकृत_, _наіў, обгр, niff_
  { {0x2d9e0089,0x9f95007c,0x45d50e3f,0x04671884}},	//   _jste_, _süüa_, цовс, йтам
  { {0x2eee00b8,0xd7c90015,0x8505002b,0x8515005e}},	//   hiff_, _نوعه_, آورن, імає
  { {0xe4e40036,0x083c004c,0x9cd7000a,0xe4540033}},	// [9330] чірн, _געחל, צומה_, якты
  { {0x8c1b0008,0x24570016,0x290b0d29,0x2d9e41ec}},	//   רומי, ầm_, loca_, _oste_
  { {0x399a41ed,0x7feb002b,0xfb1b000a,0xeaf5000b}},	//   _jūs_, گراف_, נובמ, ीकॄत_
  { {0x399a0024,0x30150e77,0xb87b0046,0xd49b005e}},	//   _mūs_, одер, eníz, _сро_
  { {0x6d480024,0x4918000f,0x389c000a,0x188c000a}},	//   _atda, זקאל_, טיאנ, רְבּ
  { {0xa75c000a,0x62040030,0x9957013f,0x315b0058}},	//   נדור, étlé, _ráže_, _مجرة_
  { {0xe0570086,0x2cf6005d,0xd0d5006b,0x3ced006f}},	//   _هیات_, ुकूल_, _довъ, tiev_
  { {0x50d7002b,0x2eee0034,0x62970f85,0x2cbf07c8}},	//   _ازسر, aiff_, lexo, ujud_
  { {0x8c640806,0x2d9e41ee,0x78840030,0x2009003d}},	//   سطين, _este_, hívó, ļais_
  { {0x05ba014e,0x399a0048,0x38690026,0x5d850029}},	//   _उपलब, _būs_, _adar_, _ولذل
  { {0xc7a90008,0xc27a0008,0xda090015,0xad58005e}},	//   _שב_, ברתי, شيحه_, _гріх_
  { {0xa17a0008,0xb9260029,0x6abc00c0,0xa3d9005d}},	//   סטרט, تفجي, örfr, ़ना_
  { {0x981600e5,0xbc3800c3,0x4fac000a,0xe73a2658}},	//   تبدا, _اسما_, ְׁלְ, рег_
  { {0x9f96000a,0x59c50015,0xb4d2000b,0xf3ff016e}},	//   חדשה_, _ويشك, वस्_, _adão_
  { {0x845a0491,0xceb204dc,0x629704af,0x2b4d00bd}},	//   ират_, וים_, dexo, lpec_
  { {0xe9460086,0x6aa3232a,0x9e3c0227,0xb956000a}},	//   _بروی, _hanf, _maďa, _ויקח_
  { {0xd3f4022a,0xf71a0033,0x58bb000a,0xb6a604d7}},	// [9340] нiст, _віны_, _כמקצ, _дипл
  { {0xe1f200c3,0x221600ce,0x78a602dc,0x0000006a}},	//   وسا_, офер, ldkv,
  { {0x9e3c002c,0xab1a000a,0x78a401be,0x3f9f008c}},	//   _naďa, בֵאת, _kaiv, _asuu_
  { {0xa988000a,0x78a61696,0x7afc00bc,0x6aa341ef}},	//   מָנִ, ndkv, črti, _lanf
  { {0xdfd00074,0x9ffa0029,0x6443002a,0x5f06230b}},	//   عيت_, جراء_, śnic, озда
  { {0xaf1c0033,0x78a42581,0x33fb004f,0xbd6a3343}},	//   ыплi, _laiv, _כהכנ, арие_
  { {0x20d70482,0x2eee41f0,0x66cb0030,0xd657004f}},	//   _için_, riff_, _züks, קיקת_
  { {0x66cb01e2,0x0caa0286,0xdb0b016e,0x64440045}},	//   _yüks, ртки_, _urgê, ncii
  { {0xfb86008f,0x39490844,0xaa8800c3,0x6aa33759}},	//   цыйн, _časa_, منظم_, _banf
  { {0xcb1a0083,0x6aa30176,0xc27a000a,0x8f9b000a}},	//   јќи_, _canf, ׁרִי, _דימי
  { {0x09f8040b,0x44270023,0x6aa30176,0x3f86001c}},	//   صفحة_, ̀n_, _danf, ltou_
  { {0x7aef0896,0x28f9004a,0x2372002a,0x78eb005e}},	//   éctr, семь_, kryj_, рьов_
  { {0x3f8603af,0xaae60021,0x3cfb000a,0x6aa341f1}},	//   ntou_, _وستو, _דלאנ, _fanf
  { {0x6aa30176,0xa3ae005d,0x3f86001c,0xbb470015}},	//   _ganf, किन_, itou_, _بلون_
  { {0x99170015,0x58d50763,0x96f841f2,0x290b41f3}},	//   _وبعض, _нокт, церт_, poca_
  { {0x66cb007c,0x386941f4,0x628e41f5,0xe4e70138}},	//   _püks, _udar_, _abbo, цігн
  { {0xdc9b013a,0xe4480029,0x4374005e,0x33841d90}},	// [9350] סימל, تلقى_, дуєт, духв
  { {0x238e0024,0xcb37004c,0x0b14000a,0xf485002b}},	//   dējā_, קאבי_, פַּר_, _کادی
  { {0x21670033,0xc2c40015,0xf2c40015,0xa69a000a}},	//   ютаг, بيلي, بْلُ, _השתפ
  { {0x41740029,0xc1040086,0x82340015,0x3cf6000b}},	//   باكس, وولي, ذرلا, ुकों_
  { {0x8027006e,0x94ba000a,0xcf9b02d9,0x68ed02f2}},	//   آرام, _המרת, рје_, _mmad
  { {0x8ee8005e,0x6da51ad3,0x645d41f6,0xad59219d}},	//   омів_, зика, _hesi, брих_
  { {0xb1460074,0xd6580008,0x68ed0020,0x53340001}},	//   _فیلم_, חיות_, _omad, _церт
  { {0xd5fc0008,0xdd8e0029,0x66d000f2,0x645d2029}},	//   יפור, اوي_, _väki, _jesi
  { {0x2b4d1483,0x20840015,0x645d2b6e,0x3f860794}},	//   upec_, _تلقّ, _mesi, ctou_
  { {0x78a400f2,0x645d41f7,0x5e440015,0xbbe80015}},	//   _saiv, _lesi, _يَقْ, غريم_
  { {0xa9690124,0x4efa0053,0x98a641f8,0xaf080021}},	//   љима_, _פלעג, пине, _بقلم_
  { {0x71d6000a,0x645d41f9,0xa3ae000b,0xd7ca0021}},	//   פורד_, _nesi, किम_, موجه_
  { {0xa09a0053,0x3ea50f3e,0x9d1a000a,0xdc3a004c}},	//   זירט, _kalt_, _פונט, _הענר
  { {0x78a400da,0x68ed007c,0x60db1fc3,0x60c91c2c}},	//   _waiv, _emad, _llum, _loem
  { {0x60db0064,0xceb2039e,0x645d108e,0x78a441fa}},	//   _olum, עיל_, _besi, _taiv
  { {0x60c90161,0x27480045,0x93461f02,0x691d0003}},	//   _noem, _pînă_, знае, léen
  { {0xbb480053,0x2d870020,0x831a0029,0xa87b000a}},	// [9360] ַנאַ_, htne_, مقرر_, _האפר
  { {0xd36f00e6,0x691d0003,0x645d007c,0x3ea541fb}},	//   اهل_, néen, _eesi, _nalt_
  { {0x2a6a00dc,0x66cb00dc,0x68ed0026,0x6443005c}},	//   óbbi_, _tükr, _ymad, śnia
  { {0x238e0024,0x55bb0008,0xc9520008,0x2724002e}},	//   tējā_, _המטו, גמא_, föng_
  { {0x74160086,0x44630063,0x2d873ded,0x4f960033}},	//   _روسا, _явяв, etne_, яржу
  { {0xdee3005e,0xfe7a0033,0xc7f7000a,0x238e003d}},	//   ночи, сёды_, הזנת_, rējā_
  { {0x60c20024,0x3ea522fd,0x5e430015,0x3f8605e2}},	//   pjom, _dalt_, رَيْ, stou_
  { {0x2900000c,0xd1320029,0x238e0024,0x61230020}},	//   _njia_, _أمر_, pējā_, võlg
  { {0x613a0089,0x3ea500cb,0xbf16012c,0x2d8741fc}},	//   _důle, _falt_, _فورب, atne_
  { {0x8ea50015,0x3ea51ac4,0xda65002b,0x6123007c}},	//   _يصلن, _galt_, واپي, tõlg
  { {0x1ea900e6,0xdd8f0021,0xa7fb039f,0x0000006a}},	//   _باقي_, _مول_, daña,
  { {0x0ca90015,0xfce30120,0x3ea50012,0x6d3b004f}},	//   _وطني_, _похо, _zalt_, _התאנ
  { {0xcce50031,0x645d3957,0xdc8b004f,0xfc3f016d}},	//   _تسلي, _resi, _לְגָ, žíc_
  { {0xdb9b000a,0xdab80015,0xa7fb0077,0xc87f0012}},	//   _לסדר, _ذهبت_, gaña, eißt_
  { {0xa3e5005d,0x56780080,0x645d41fd,0x0000006a}},	//   _भेज_, ября_, _pesi,
  { {0xba170008,0xb4f9000b,0xb97b000a,0x99fb000a}},	//   _מחוץ_, ्केप_, _הנהי, _לפופ
  { {0xd90f0086,0x57f50036,0x60c9016b,0x8335091b}},	// [9370] _لیگ_, _іпот, _roem, днах
  { {0x82370029,0x60db307c,0x2d870227,0x60c91418}},	//   سرطا, _slum, ytne_, _soem
  { {0x60db16c8,0x60c90390,0x645d41fe,0x68fd2301}},	//   _plum, _poem, _tesi, onsd
  { {0x3ea541ff,0x68fd0c4e,0x0000006a,0x0000006a}},	//   _salt_, nnsd,   ,
  { {0x7bc600f2,0xd91c000a,0x2724001a,0xbea5070c}},	//   äkul, זואל, bönd_, далк
  { {0x7c390176,0x63ad00c0,0xa1590010,0x9758000a}},	//   _sgwr, mvan, _магу_, לידו_
  { {0x3ea5082e,0x60c900aa,0xa194312e,0x60db0dd2}},	//   _valt_, _toem, _парч, _tlum
  { {0x9f5f00dc,0xdcf90015,0x6aa80034,0x2d872c50}},	//   áról_, تفعت_, eddf, rtne_
  { {0xac160001,0x4c920001,0x2d8712d7,0xc1040015}},	//   моћу_, тињс, stne_, _أوقي
  { {0xa3ae005d,0xab5d005c,0x394508fc,0xdbd7008c}},	//   कित_, wyżs, мног, vääp
  { {0x6dd50086,0xf2d20008,0x691d0003,0x66d00123}},	//   _تقاض, דעי_, réen, _mäkt
  { {0x7e63008c,0x66d00123,0x394006c0,0x63ad4200}},	//   lanp, _läkt, _čist_, kvan
  { {0x691d0152,0xe79c0064,0xa3e00064,0x27240012}},	//   péen, _düğü, düğü_, höne_
  { {0x63ad4201,0x8f9a000a,0x38620f81,0x6b894202}},	//   dvan, חישי, sakr_, mteg
  { {0x044603ad,0x15b90033,0xa7fb0077,0xaac4012c}},	//   дебн, пыты_, raña, _ستون
  { {0x6443002a,0x98b2003d,0x2eda0065,0x8cc00065}},	//   śnin, īzē_, _भत्त, वायो
  { {0xccf20008,0xfa8e0092,0x61230020,0x38600034}},	// [9380] דכן_, _mừng_, kõlb, _ieir_
  { {0x3860003e,0xfa8e0016,0x7e63008c,0x6b894203}},	//   _heir_, _lừng_, janp, iteg
  { {0x2c0a005d,0xb6bb000a,0xd1320015,0x7e630085}},	//   _हुईं_, _וציי, نمط_, danp
  { {0x50ba0115,0x5a0a004c,0x657c008c,0x6b894204}},	//   غداد_, קלײַ, murh, kteg
  { {0x6aa80176,0x657c00a9,0xcf260015,0x38604205}},	//   yddf, lurh, ورتي, _meir_
  { {0xcdda0054,0x38604206,0x7e6302f2,0x24802b50}},	//   жњи_, _leir_, ganp, lgim_
  { {0xc693013a,0xadd80036,0x6b8903ff,0xfa8e00a1}},	//   דאו_, ямку_, eteg, _bừng_
  { {0xdc130064,0xc536004f,0x0000006a,0x0000006a}},	//   _ağır, וָ֥ה_,   ,
  { {0xfa8e0092,0x7f86002b,0xd0e7002b,0x10160033}},	//   _dừng_, _زلان, _تکلم_, _цьвя
  { {0x7b32005c,0xcdd60054,0x4d3a01c5,0xb270005e}},	//   _tłum, _оцењ, _дядя_, внiш
  { {0xa9c3106d,0x66d0014b,0xe919005e,0x929b000a}},	//   всяк, _läks, зоні_, חיית
  { {0xa3de005d,0x63ad0064,0x657c002e,0x38600026}},	//   तना_, yvan, durh, _ceir_
  { {0x3860002d,0xd8380010,0xd00600e5,0x0057000a}},	//   _deir_, дэр_, ال_, ושכת_
  { {0x7d0d10cd,0x8c1b004f,0x86c5009a,0x46480138}},	//   čase, _וודי, ريزن, дзён_
  { {0x79a30010,0x75880286,0x8a7b000a,0xee31000a}},	//   _арые, мств_, _ואות, ָֽם_
  { {0x63ad00f6,0x38600026,0x13a7002b,0x224d0046}},	//   tvan, _geir_, ونزی_, _řek_
  { {0x20f80007,0x6443005c,0x63ad4207,0xa7fb0077}},	// [9390] nčiu_, śnio, uvan, maño
  { {0x63ad00ed,0x98bf0046,0x27240012,0x20f80091}},	//   rvan, yptě_, töne_, ičiu_
  { {0x06560008,0xf6560008,0x6b8900bc,0x7e634208}},	//   _איתך_, _אסתי_, zteg, vanp
  { {0x6b89002a,0x909b0058,0x7c224209,0x0000006a}},	//   yteg, تضطر_, _ozor,
  { {0xfa8e0092,0x752d1a41,0x290300bc,0x919f0065}},	//   _rừng_, mmaz, čkah_, _गैरै
  { {0x752d0014,0xd3f40010,0x6fb20015,0xa77c000a}},	//   lmaz, нiцт, اموا, קרופ
  { {0x609b0015,0x31780015,0x0d64002b,0x394e420a}},	//   _وخرج_, _يحفظ_, نديپ, _ntfs_
  { {0x3135000d,0x752d0064,0xb638000a,0x4c850c31}},	//   _чебр, nmaz, ורוס_, хлив
  { {0xe452000a,0x6b89002a,0xfb84002b,0x7c22002a}},	//   נֶה_, uteg, نگوی, _czor
  { {0x20010064,0x1a65002b,0x6b89420b,0xf3fa000a}},	//   şhis_, ریبی_, rteg, לִיל
  { {0xfa8e0023,0x6b89420c,0x752d0061,0x9e48000a}},	//   _từng_, steg, kmaz, _חֲנִ
  { {0xc68901c8,0x6d410035,0xf1b201ac,0xa7fb0077}},	//   _לא_, _iula, אסט_, gaño
  { {0x7e61022d,0xbd2c00b2,0x291e0048,0x64430089}},	//   _kelp, _וואָ, ēta_, ěnil
  { {0x6d41420d,0x4ac50015,0x7d1b420e,0x0ae80015}},	//   _kula, _سيبق, llus, _يروي_
  { {0x5a440010,0x6d410553,0x236929b3,0xf5061092}},	//   _рэча, _jula, esaj_, езво
  { {0x20f80089,0x64a30cad,0x6d410332,0xa7fb0077}},	//   nčit_, ласа, _mula, caño
  { {0x4b4c0053,0x7d1b0321,0x6ec2000b,0x6d412ea8}},	// [93a0] ַגאַ, ilus, लामु, _lula
  { {0xe9ff0023,0x7d1b00b8,0x91e60805,0x245e0016}},	//   _giải_, hlus, нозе, ắm_
  { {0x365b000a,0x865b000a,0x3afa004c,0x7d1b420f}},	//   _מכינ, _מדיי, פּמע, klus
  { {0x2a650012,0x30a5005e,0x63bb0091,0xfc27006e}},	//   halb_, крів, _šune, _مح_
  { {0x7d1b0005,0xa857000a,0xb1170015,0xdc1e000b}},	//   dlus, גינה_, رقها_, _परेड_
  { {0xd00f0086,0xce94006b,0x6e940a68,0x6d411a70}},	//   حله_, такъ, тику, _bula
  { {0x7c22014f,0x1ea900e6,0x7d1b285f,0x629e4210}},	//   _szor, باني_, flus, mepo
  { {0xf8bf00dc,0x61e10020,0xe73f0020,0x7e610020}},	//   rmék_, _ülla, svõi_, _eelp
  { {0xa2c4014e,0xd10d000b,0xcb98005e,0xb09b000a}},	//   राप्, िकरण_, євої_, _צימר
  { {0x6d41000c,0x9f970008,0x7d1b0e95,0x4bd70015}},	//   _fula, _אדמה_, alus, عبيد_
  { {0x5cd60036,0x7c22005c,0x1e570008,0x8cc0005d}},	//   _підх, _wzor, _נשאר_, वादो
  { {0x660901e2,0x8d5b000a,0x629e04d2,0x995e0046}},	//   şekk, _זכאי, hepo, _téže_
  { {0x7c22016f,0x6d4100b8,0xfbd2002b,0x69c702de}},	//   _uzor, _zula, _حتا_, øjer
  { {0x66d000c0,0x629e0085,0xa2c4000b,0x0000006a}},	//   _säkr, jepo, राफ्,
  { {0x65940558,0xa2c4005d,0xa7fb1967,0x9aeb000a}},	//   лару, रान्, paño, _צַדִ
  { {0xb6340015,0x57b501b7,0xc7ab0015,0x88c70015}},	//   افِع, _абит, _فدخل_, _ستبل
  { {0x752d02d7,0xd3710087,0x3c470030,0x1878000a}},	// [93b0] rmaz, شها_, _hívó_, _נעזר_
  { {0xd7fc000a,0xa159027a,0x6aaa1254,0x752d4211}},	//   _מהחל, дажу_, _jaff, smaz
  { {0x0736000a,0xea77000a,0xc692000a,0x7d1b0034}},	//   _שאתם_, תגבר_, _דאי_, ylus
  { {0x6d410011,0x6aaa4212,0xe588004f,0xc1740058}},	//   _rula, _laff, _אָשָ, ادلت
  { {0xf77f0064,0x6d414213,0x268b000a,0xa858000a}},	//   nuç_, _sula, ִנֵּ, תידה_
  { {0xfe730087,0x6d412982,0xa3ae000b,0x2c7a0061}},	//   ادش_, _pula, किर_, yüdü_
  { {0xf2d200b4,0x7d1b0005,0xdcfa01e2,0xddc10048}},	//   _דעם_, tlus, _artı, _ielū
  { {0xb87b002d,0x01340015,0x20f80046,0xdb0b016e}},	//   dhío, _معقد, učit_, _orgã
  { {0x7e61003d,0x20f80046,0x6d4101d7,0x7d1b4214}},	//   _telp, rčit_, _wula, rlus
  { {0xccf80089,0xb36502e1,0x539c000a,0x6d414215}},	//   _svět_, хнiч, ליחו, _tula
  { {0x6d410035,0x7d1b0020,0x9f9b00f2,0x80d5000b}},	//   _uula, plus, säät_, _दवाइ
  { {0x629e002a,0xfd56004f,0xc236004f,0x97be0138}},	//   zepo, _ישעי_, כרתו_, оргi
  { {0x9cd6013a,0xa2c4000b,0x0056000a,0x62950678}},	//   _שונה_, राम्, כשרת_, _obzo
  { {0x2cad4216,0xca49002b,0xf1e1000b,0xddc1003d}},	//   lded_, _غلبه_, पनान, _nelū
  { {0x2cad00da,0xe7374217,0x5ee8004f,0xe9a50138}},	//   oded_, тер_, תַרְ, _райп
  { {0x2cad4218,0xa3ae005d,0x6aaa02b9,0x0000006a}},	//   nded_, किल_, _zaff,
  { {0xd70a000d,0x2cad4216,0x931600c3,0x9343249a}},	// [93c0] _оние_, ided_, نورش, инте
  { {0xf1fa00e6,0x6123007c,0xa77b000a,0xd36f012c}},	//   وعات_, võla, _קריפ, زهم_
  { {0xd6570008,0x16770008,0x29020ed5,0xcb1200a3}},	//   _שיטת_, _בגיל_, onka_, סלב_
  { {0x3d0b005d,0xe0da0010,0x2902002e,0xdbd2007c}},	//   हकों_, ьве_, nnka_, tüüp
  { {0x2cad0e46,0xe0850021,0xdb0b0144,0x8cc0000b}},	//   dded_, اجمي, _orgà, वासो
  { {0xf4130008,0x2cad003e,0xc7d7000a,0x3f13005e}},	//   _כפר_, eded_, כוני_, адіс
  { {0x7dc4003b,0x5d630010,0x6aaa4219,0x6dc3006b}},	//   اقعن, атыз, _raff, исъж
  { {0x63a4005c,0xfd0f0015,0x2cbd0034,0x6aaa421a}},	//   owin, يجي_, _cnwd_, _saff
  { {0x5b14006b,0x4e960015,0xfe72006e,0xda7a15fb}},	//   лмит, _لشار, _ندا_, мян_
  { {0x63ab0134,0x2cad421b,0x2902421c,0xb87b0125}},	//   ægni, aded_, enka_, thío
  { {0xc27b0008,0xfbcf0086,0x63a4421d,0x527b000a}},	//   וריי, متی_, hwin, וניא
  { {0x6aaa05c7,0x8157004c,0xb8670015,0x63a4421e}},	//   _waff, כסטע_, خادو, kwin
  { {0x6443005c,0x0a9401f3,0xb9240033,0xab75002b}},	//   śnik, _балю, рфэй, _مننژ
  { {0xb9b40015,0x6b80019f,0x09f60015,0x63a415fc}},	//   _ممتع, mumg, _لأعد, dwin
  { {0x59c30029,0xa9e3004a,0x63a4421f,0xba9b004f}},	//   _نيوك, _вещa, ewin, _חסוי
  { {0xba370008,0x47d5002b,0x27240123,0x3a37000a}},	//   _בטוח_, _ميبر, röna_, _ברום_
  { {0xd7c8002b,0x613a0046,0x394900bc,0xe5340248}},	// [93d0] _لويه_, _půln, _časi_, реть
  { {0x24730023,0x78ad0201,0x63a2016e,0x43940c45}},	//   ệm_, _haav, çona, рафс
  { {0x75d50029,0x78ad00f2,0x8c3d0064,0x63a41d0d}},	//   _إيجا, _kaav, leşe, awin
  { {0xf9930053,0xf2df0011,0x74150015,0xc0ab0015}},	//   ירע_, _atât_, _موجا, بائل_
  { {0x7f190010,0x747a0008,0x78ad0e95,0xaed5017f}},	//   ніку_, _אנרג, _maav, лодш
  { {0x753d062e,0xb7dc000a,0x6e950015,0x7e54006b}},	//   _hisz, וקדי, الغا, атъц
  { {0x753d00dc,0x644d0c24,0xfc3f0107,0x3e6a002b}},	//   _kisz, ocai, žím_, رجوی_
  { {0x24f7000a,0x6f65002b,0xd0d4006b,0x2cad00da}},	//   כֶ֖ם_, _مهرم, _косъ, uded_
  { {0x2cad4220,0x753d0e8c,0x5f450015,0x2cb10046}},	//   rded_, _misz, _إنطل, ězd_
  { {0x753d06e7,0xa175000a,0xfff6002b,0x62854221}},	//   _lisz, ְעָד_, _حکمت_, ngho
  { {0x5dd50029,0x63a4080c,0xa2c4000b,0xedd50015}},	//   _حقائ, zwin, रात्, _حياد
  { {0x63a400dd,0x753d005c,0x7c87000d,0xdce7003d}},	//   ywin, _nisz, _јуже, ēlēj
  { {0x8cc0005d,0xcbc7002b,0x68430015,0xccf90535}},	//   वारो, _جزاي, صَّل, miś_
  { {0x99d50021,0x1bfa000a,0xee45001a,0x5b56000a}},	//   _متبا, _אלנב, _þýdd_, _עיצב_
  { {0x66060063,0x753d13c3,0xa50a120a,0x0000006a}},	//   упва, _bisz, еева_,
  { {0xd5b70092,0x753d1022,0xf7f6002b,0x7cfe003d}},	//   ứng_, _cisz, _مسخد, tīri
  { {0x43860015,0x141a0015,0x753d2f97,0x29030046}},	// [93e0] طلاق, ريطة_, _disz, čkat_
  { {0x33d50036,0x82660067,0x753d0012,0x644d0125}},	//   шіст, اهان, _eisz, acai
  { {0x394f04f9,0xccf9005c,0x68e40089,0x0737000a}},	//   _însă_, kiś_, _klid, _תאים_
  { {0x7455010f,0x600a0010,0x6aa10028,0x211a002b}},	//   _върх, ннем_, helf, رتاب_
  { {0x33d60033,0xe3b2002b,0x79810012,0x6aa14222}},	//   _сінт, _ارج_, hulw, kelf
  { {0xf8bf00dc,0xe1660029,0x32430063,0x71660015}},	//   lmét_, _مدري, _герг, _مارك
  { {0x91e630e1,0x8cc0000b,0xa2f7000a,0x7d0d4223}},	//   _сове, वालो, _עמלה_, časn
  { {0x61d7000a,0x71d7000a,0x5ba64224,0x6b802905}},	//   _גולף_, _גולד_, гроз, tumg
  { {0xc006119f,0xcb670180,0x09dc000b,0x28af000b}},	//   _спак, гање_, मन्य, _जोगि
  { {0x78ad09e7,0xc27a0008,0xbda60087,0x8f9b00f3}},	//   _saav, ׂרִי, _محصو, _אימי
  { {0x527b0053,0xc27b0053,0x3a060086,0x78ad0604}},	//   ענטא, ערטי, دکشی_, _paav
  { {0x28af000b,0x27e6002a,0x8c460a0b,0xed360033}},	//   _जोखि, _żona_, _седе, _сэзэ
  { {0x48e40033,0x6d5800aa,0x765c02de,0x8c3d0061}},	//   соўв, lpva, fbry, teşe
  { {0x07e40033,0x7bc6008c,0xe7380033,0x8aa3006b}},	//   сцюм, äkuu, леў_, _гръд
  { {0x8c3d0011,0x753d12f7,0x1635004a,0x63a20003}},	//   reşe, _pisz, ревя, çonn
  { {0x7afa4225,0xa7b90004,0x545509fd,0x68e414dc}},	//   litt, _алиу_, рват, _glid
  { {0x753d00dc,0x7afa00f2,0x644d4226,0xa2f50033}},	// [93f0] _visz, oitt, rcai, апач
  { {0x35f50036,0x67540087,0x644d11d4,0x628500da}},	//   _впор, _اخير, scai, ugho
  { {0x7afa00f2,0x753d00dc,0x6115005e,0x69da4227}},	//   iitt, _tisz, аджу, nyte
  { {0x7afa022d,0x6aa10298,0x60640015,0x40c80015}},	//   hitt, zelf, مهمل, ُولَ_
  { {0x7afa00f2,0x08780053,0xddd001b2,0x6e240046}},	//   kitt, רעדט_, _češt, řibl
  { {0x7afa00f2,0xf8bf0251,0xd9f6000b,0xbdf8002b}},	//   jitt, omés_, ुपात_, گرها_
  { {0x7afa4228,0x6cc5009b,0x0000006a,0x0000006a}},	//   ditt, ийка,   ,
  { {0xeb992352,0x798100dd,0x7afa3c28,0xbdf80040}},	//   вии_, vulw, eitt, درها_
  { {0x7afa052a,0xc1040015,0xbe87012c,0x6aa14229}},	//   fitt, _طوكي, _مجاو, telf
  { {0x7afa422a,0x2909008c,0x68e41bea,0x2b460016}},	//   gitt, _ajaa_, _slid, _duoc_
  { {0x8a380080,0x5c970015,0xdeba000a,0xd7ca002b}},	//   ляют_, _مؤشر, _שמעל, چوجه_
  { {0x3c47003b,0xab950191,0x6aa11d63,0x7afa00f2}},	//   _إضاف, _виді, self, aitt
  { {0x7d041658,0xf7461372,0x394932f8,0x590701c5}},	//   čist, рего, _času_, реям_
  { {0xaa880029,0x4b7a0135,0x96fa0033,0x69da422b}},	//   _منهم_, _יאנו, тэму_, byte
  { {0x8afa0447,0xa2c4000b,0x48e6006b,0x98760054}},	//   _שהצי, रास्, _войв, _купљ
  { {0x2caf0012,0x765c3d94,0x613a0046,0x04430361}},	//   _jagd_, sbry, _půlm, жетн

  { {0x6266000d,0xd4550036,0x23480086,0xe8c7006b}},	// [9400] иваа, стсь, اسری_, _ъгъл_
  { {0x394700dd,0xb7db000a,0x23c8000b,0xf8bf0030}},	//   _kuns_, _סקיי, रमबद, smét_
  { {0xc693013a,0x61230020,0x21a603fa,0x867b0135}},	//   _ואת_, põll, рием, _בריו
  { {0xe7b30086,0x55bb0008,0x7afa0111,0x3849000a}},	//   _امید, _סמכו, zitt, ְאוּ_
  { {0x69da080c,0x4424422c,0xc897004f,0x80a30058}},	//   zyte, _ám_, שכנז_, زمون
  { {0xa2e60080,0xdd9a422d,0xdd900015,0xf2df0016}},	//   _тогд, вши_, كوت_, _huân_
  { {0x7afa022d,0xf8bf0152,0xa3ae000b,0xbd67004a}},	//   vitt, llée_, किक_, арые_
  { {0x61430b1e,0x7afa02a1,0x718b004f,0xc157004f}},	//   _фета, witt, _בְמַ, _כשלו_
  { {0x807b0008,0xeec6002b,0x6440016e,0x7afa422e}},	//   _שנמצ, _پياپ, _úmid, titt
  { {0xf2d300b2,0xf2df0092,0x1eaa00a2,0x7cfe003d}},	//   ַער_, _luân_, _جاري_, vīru
  { {0xc3330008,0xd2b7000a,0x3d8b002b,0x7b32002a}},	//   חוז_, בלית_, _لحنی_, _słus
  { {0x7afa022d,0x39490b28,0x69da422f,0x6d484230}},	//   sitt, _čast_, ryte, _iuda
  { {0xcb5403c4,0xbb540015,0xdfc60015,0x7afa4231}},	//   _انتظ, _انتب, أي_, pitt
  { {0xd7f80892,0xfaa3068e,0xcab30015,0x6d483e50}},	//   рую_, _мачо, _ومنظ, _kuda
  { {0x99840029,0x39473390,0x16380015,0x2611000b}},	//   _العو, _guns_, لسفة_, _दुखी_
  { {0xddc30011,0x9a3b0008,0xdb0b00b8,0x6a3b000a}},	//   lanţ, _בתוק, _ergä, _בגופ
  { {0xc299008f,0x59ae005d,0x026b0080,0x68fd20e9}},	// [9410] лках_, टिकर, вшей_, misd
  { {0xa2c4005d,0xcb570008,0x3869003e,0xddc30011}},	//   राष्, יסמה_, _hear_, nanţ
  { {0xe2980036,0x6f180107,0x4734002b,0x6123007c}},	//   рає_, dovc, _بريز, sõlm
  { {0x11280036,0x3d10005d,0xf8bf0003,0x5f750067}},	//   аючи_, ावों_, blée_, ماتر
  { {0x2d9e2bee,0x38690125,0x6d481166,0xa4b6004f}},	//   _apte_, _mear_, _auda, _פלשה_
  { {0xef18008f,0x6f180796,0x6d484232,0x03d6000a}},	//   амі_, govc, _buda, _הושם_
  { {0xa2c4005d,0x29194233,0xd13b07be,0xddb50058}},	//   रार्, kosa_, _аха_, إحتب
  { {0x6d480176,0x3947003e,0xf2df0092,0x386917ce}},	//   _duda, _runs_, _xuân_, _near_
  { {0xde590036,0xbebc003d,0x68fd4234,0x29194235}},	//   _базі_, _rhīv, disd, dosa_
  { {0x76450176,0x3940041c,0x0b420010,0xcac90139}},	//   _nghy, _siis_, яньн, угое_
  { {0xc7a904dc,0x3869162b,0xbe640067,0x186a04bb}},	//   _רב_, _bear_, _ذهني, лани_
  { {0xcd960008,0xc19a004c,0x6e3c0030,0x485a0033}},	//   _לדעת_, נשרי, _úrba, ыроў_
  { {0x39400020,0x38690556,0x27750010,0xe8f74236}},	//   _viis_, _dear_, жысё, сля_
  { {0xdc3600b2,0x501a0008,0x867a0010,0xddc30011}},	//   _פאסט_, רושו, ыёму_, canţ
  { {0x38690541,0xf77f0144,0xba56000a,0x68fd0546}},	//   _fear_, arç_, _פסקו_, bisd
  { {0xf2df0023,0x399108e7,0x38694237,0x63b60091}},	//   _quân_, más_, _gear_, tvyn
  { {0x39910014,0xe3ba01b0,0xa2c4000b,0xd3f4008b}},	// [9420] lás_, ыба_, राल्, мiст
  { {0x78a600dc,0x7b1d0144,0x16aa1eb8,0xa3da000b}},	//   lekv, cèut, _свои_, ़हब_
  { {0x38690041,0xf2df0092,0x02190010,0x39914238}},	//   _year_, _tuân_, аіць_, nás_
  { {0xdfcf0086,0x6d484239,0x3d21000b,0xf8bf0003}},	//   کيه_, _ruda, मतों_, plée_
  { {0x351b013a,0x78a60007,0xdefa0892,0xa4b700f3}},	//   _תוכנ, iekv, лык_, _הלכה_
  { {0x679b0053,0x3ce604af,0x39910030,0x6d48324d}},	//   רױסג, _slov_, kás_, _puda
  { {0x42e70001,0xddc30011,0xe45f00aa,0x39912b00}},	//   _умро_, vanţ, _koöp_, jás_
  { {0x4422020a,0x39910014,0xcb540001,0xb87b00dc}},	//   _kyk_, dás_, овић, lhív
  { {0xddc30011,0x75242e65,0x7cfe0007,0x3869240d}},	//   tanţ, iliz, gūra, _rear_
  { {0x6d48423a,0x2ca4002e,0x9998000d,0x41dc005d}},	//   _tuda, semd_, акот_, _यथास
  { {0xddc30011,0x442200dd,0xf8bf00dc,0x39911043}},	//   ranţ, _lyk_, jléc_, gás_
  { {0xa8eb0029,0x7aef0251,0xe8eb0040,0xe91900ce}},	//   اعدك_, èctr, اردو_, ромі_
  { {0x6c360086,0x3f86001c,0xddc3423b,0x9d1b000a}},	//   _افشا, nuou_, panţ, _גואט
  { {0x5b130036,0x3869003e,0x7b32005c,0x8c1b000a}},	//   _еміт, _wear_, _głup, _עוגי
  { {0x5d78000a,0xcb070015,0x386900da,0x9afb000a}},	//   יָּנ, _ديون_, _tear_, _תפוח
  { {0xddc30024,0xfb56000a,0x4dfb004c,0x613104d1}},	//   nanš, ֶׁ֣ר_, אפלא, målg
  { {0x69dc0123,0xf2c50015,0x7b1d0144,0x2489423c}},	// [9430] äref, يْرُ, pèut, rgam_
  { {0xb87b0014,0xdb090061,0xf8bf0030,0xa715005e}},	//   ghív, rveç, bléc_, _ємні
  { {0x66d0022d,0x1a9b0053,0x02440015,0xf484002b}},	//   _näky, ריבע, أَمَ, _کاپی
  { {0x63ae008c,0xddc300bc,0xd5fa004f,0x44a70058}},	//   ännä, janš, _כפתר, _احدّ
  { {0x3991423d,0x98b90007,0xe0d00015,0x8c4202ad}},	//   zás_, ūrė_, عزم_, äßli
  { {0x5e870033,0xb87b3bdd,0xc2c50067,0x8d550c02}},	//   судз, chív, _بيسي, отич
  { {0xed590892,0xad5804f7,0x26dc015b,0xc694000a}},	//   шой_, брых_, רקומ, פאק_
  { {0x399100dc,0x7cfe0cd4,0xd5fc000a,0x7b32002a}},	//   vás_, tūra, טפור, _słup
  { {0xe0e4008f,0x69dc01f0,0xe452000a,0x78a60030}},	//   _эўро, øren, וֶת_, vekv
  { {0x399107e6,0x0b160029,0x9b020010,0xdc1c0024}},	//   tás_, يقية_, дзьд, eņēm
  { {0xa9690124,0x3ea70c90,0xddc300bc,0x7524423e}},	//   јима_, ment_, banš, yliz
  { {0x3ea0016f,0x3ea7423f,0x2d874240,0x39914241}},	//   đite_, lent_, mune_, rás_
  { {0x7d24005f,0xcaf50015,0xdaf50015,0xe7d6005e}},	//   _эффе, _وستب, _وستظ, ціню
  { {0xaa680074,0xd7060036,0x917a0092,0xdc1c0024}},	//   _همهٔ_, ізви, hấy_, aņēm
  { {0x3ea7038d,0xba390053,0x7d09003f,0x6f04002d}},	//   ient_, _דײַט, ones, éici
  { {0x7524003f,0xb7da0015,0xd7ca002b,0x29170015}},	//   uliz, _نوعا_, _نوبه_, _وقود_
  { {0x8c360053,0x3ea74242,0xbbd5000a,0xb8ee000b}},	// [9440] ַטעס_, kent_, חוּץ_, रा_
  { {0x3ea74243,0x7d1b4244,0xe7320015,0x2d8701bc}},	//   jent_, hous, _تصب_, kune_
  { {0x752400b8,0x41aa0661,0x7d1b4245,0x3ea725c3}},	//   pliz, рвен_, kous, dent_
  { {0xa99a00b2,0x9f960020,0x3f86016e,0xc329000a}},	//   יבער, _tüüp_, tuou_, דו_
  { {0xbba8005d,0x027f0089,0x2b49002d,0x7d094246}},	//   _कनेक, _říše_, _éach_, dnes
  { {0xdc1c0024,0x3ea74247,0xdee3030c,0x7d094248}},	//   zņēm, gent_, мочи, enes
  { {0x2d870020,0xe801005d,0x9e330010,0xc0e60036}},	//   gune_, _लेना_, мешч, _довк
  { {0x7f860015,0x7d094249,0x3ea70034,0x0000006a}},	//   _ولأن, gnes, aent_,
  { {0xe7a9000b,0x0ba6005e,0x3ea7424a,0x6d420045}},	//   _चैंप, ішим, bent_, _vioa
  { {0x7e530015,0x2d87424b,0x212601d7,0x3ea7424c}},	//   _ينقص, bune_, lloh_, cent_
  { {0x6e930074,0x2d87424d,0x657a002d,0x39580150}},	//   _آلما, cune_, áthl, ërs_
  { {0x5bc60029,0xdcee0024,0xeb9a00c9,0x7d1b3a79}},	//   _وقال, ēdēj, _вид_, cous
  { {0x37e40033,0x8c3d0061,0xeaaf002b,0xdc1c01ec}},	//   доўг, neşl, رعی_, rņēm
  { {0x3f500092,0xfeca000a,0x7d00424e,0xddda0046}},	//   _màu_, ׁמָּ, lims, _setř
  { {0xfc3f0089,0xee2e0484,0xd5b8113a,0xe46b0004}},	//   žít_, ннi_, ост_, ишал_
  { {0x55070010,0x5d7b1282,0x395e0556,0x3ea7424f}},	//   ічва, ירלײ, mpts_, zent_
  { {0xa3ab005d,0x43940292,0x9cd7000a,0x3ea70003}},	// [9450] _कैश_, матс, קומה_, yent_
  { {0xb4db0092,0x6d5a4250,0x7d090a78,0x7d0d12d7}},	//   _giàn, _otta, znes, časi
  { {0x3ea70493,0x41b50015,0xc2c40015,0x15ab006b}},	//   vent_, ثمار, ظيمي, _тъпи_
  { {0x7655005c,0x3ea72004,0x7cfe0091,0x2d870072}},	//   lczy, went_, dūro, vune_
  { {0x8cce005d,0x54560053,0xef0e2b9f,0x6d5a0738}},	//   थानो, _מסרן_, ем_, _atta
  { {0x643a0053,0x05960086,0x7655005c,0x7d00002e}},	//   _לערנ, _بایگ, nczy, eims
  { {0x7d0925c4,0x69dc01f0,0x3ea704a8,0x367c000a}},	//   tnes, ørel, rent_, שְׂע
  { {0x63ad005c,0xeae3000b,0x3ea7296e,0x3cc90054}},	//   owan, गस्त_, sent_, слио_
  { {0xff530196,0x79810026,0xddc10089,0x63ad1fd5}},	//   _آخر_, wrlw, _delš, nwan
  { {0xdd000048,0x63a000c0,0x7655005c,0x2d870ee0}},	//   ētāj, _ämne, jczy, pune_
  { {0x63ad0c8c,0x7655005c,0xc8ca002b,0x3ced00cb}},	//   hwan, dczy, مودن_, phev_
  { {0x8c3d0064,0x6bd70015,0x7655002a,0x657a0125}},	//   leşm, _وتشر, eczy, áthm
  { {0x7c070015,0x5cd20015,0xdb02001a,0xbc640033}},	//   _بباك, _سقوط, _troð, _цвік
  { {0x501a0008,0xfc300015,0xe73a1adc,0x290b4251}},	//   מורו, _شحن_, сег_, anca_
  { {0xeaf800a2,0x63ad4252,0xd62a1f34,0x25be0046}},	//   _برنت_, ewan, сове_, ítl_
  { {0x63ad00b8,0x75d30018,0x7655002a,0x89da000a}},	//   fwan, ريقا, aczy, _לחצי
  { {0x29024253,0x577a0015,0x7655002a,0x03a300c9}},	// [9460] mika_, _اصبح_, bczy, нито
  { {0x78b60064,0xb87b002d,0xd7fb000a,0x1dbd000b}},	//   _hayv, bhís, _להפל, ्मात
  { {0x26db000a,0xd6db000a,0xb87b0077,0x7d000061}},	//   _הקימ, _החיל, chís, yims
  { {0xb6080107,0x98bd0091,0x6557000a,0x8c3d0061}},	//   alší, _buvę_, _מבטא_, teşl
  { {0x9f530010,0x94bb000a,0x2fd30015,0x6b890077}},	//   евіч, _המכת, فتوح, jueg
  { {0x7cfe0007,0x479b000a,0x9316002b,0x29024254}},	//   tūro, מינס, _روزش, hika_
  { {0x29023249,0x212600bc,0x6aa801de,0x7d004255}},	//   kika_, ploh_, vedf, tims
  { {0x3f500023,0xe0550086,0xdc130064,0x2902003f}},	//   _tàu_, _قیمت_, _aşır, jika_
  { {0x3f670063,0x7655005c,0x29020553,0x98b9003d}},	//   _нито_, yczy, dika_, ūrī_
  { {0xdea0002b,0x1fb50033,0xf9780099,0x61313bde}},	//   _شیعی, _ўстр, обој_, råle
  { {0x44270023,0xbc6a0074,0x7dc50029,0xfbcf0086}},	//   ́n_, _همان_, _يتمك, نتی_
  { {0x63ad0050,0x7655005c,0x395e00da,0x29024256}},	//   ywan, wczy, rpts_, gika_
  { {0xa09b0053,0xb4db0251,0x6123007c,0x0a94005e}},	//   זיכט, _diàl, põlv, _жалю
  { {0xa3c2005d,0xa3c0000b,0x4b7b000a,0xb87b0030}},	//   ्मन_, ंटन_, _פאוו, ghír
  { {0x26da02d7,0xcb1300b2,0x6a9b0008,0x7655005c}},	//   _dopo_, _אלס_, _השונ, rczy
  { {0xe81e005d,0xdb0d00dc,0xa4d402e1,0x391502e1}},	//   _युवा_, óköv, носі, _імпр
  { {0xa87c013a,0xe2c90015,0x2bb1000b,0x38c9002b}},	// [9470] _האחר, يورو_, ड़िया, _هاکی_
  { {0x6eef0bfa,0xe3c40015,0xddc80046,0x6746006f}},	//   _købe, عْلَ, _nedů, ľujú
  { {0xe801005d,0x41e40010,0x9b1701d8,0xa05b0015}},	//   _लेता_, ніца, לחמה_, مؤشر_
  { {0xf1c000a7,0x93c700d4,0x6eef064c,0x0000006a}},	//   ương_, _arăţ, _møbe,
  { {0x6eef0134,0x68ed05fb,0x94ba000a,0xcf390033}},	//   _løbe, _mlad, _ומרת, очкі_
  { {0x68ed0026,0xad5901e5,0x0ec7000b,0xada50937}},	//   _llad, орих_, लाइड, дакл
  { {0xfe704257,0xd6580008,0x533409ef,0x51844258}},	//   اده_, היות_, _черт, _пута
  { {0xa0c50015,0xf1b2000a,0x02440058,0x29024259}},	//   _تيرو, _בסל_, _أَفَ, xika_
  { {0x2d8a0134,0x1dbd000b,0x394e0012,0x93c70045}},	//   _åben_, ्महत, _aufs_, _frăţ
  { {0xa91d002c,0xe5780024,0xeaf90015,0x68ed425a}},	//   buľk, šķi_, تربت_, _alad
  { {0x6f0302d7,0x68ed425b,0x2902425c,0x8afd0046}},	//   minc, _blad, tika_, jpře
  { {0xae1a004c,0x6eef02de,0x6f03425d,0x68ed425e}},	//   _וועכ, _døbe, linc, _clad
  { {0x29021187,0xace60033,0x8afd0046,0xac740015}},	//   rika_, _імша_, epře, _سانش
  { {0x290212ea,0x68ed425f,0xceb2000a,0xb4db0144}},	//   sika_, _elad, ֛ים_, _diàm
  { {0xceb204dc,0x60c9184c,0x78b60061,0x290205f3}},	//   כים_, _onem, _tayv, pika_
  { {0xa3ea0ea6,0x60c90091,0xb87b0030,0x64a34260}},	//   одба_, _nnem, shír, каса
  { {0xa806005e,0xeb39000a,0x6f030061,0xe29a01b0}},	// [9480] _ізол, ַעֲש, kinc, жаз_
  { {0xc746002b,0x8959000a,0x0556006b,0x60c94261}},	//   _تضعي, ַדְת, _отмя, _anem
  { {0xf3e9000a,0x91aa0015,0xe44a0015,0x6f034262}},	//   סף_, تهاك_, _ولدى_, dinc
  { {0x2b470026,0x23600111,0xc0e6005e,0xc0c70054}},	//   _linc_, ppij_, ьоек, душе_
  { {0x6f0304ed,0x4f570115,0xef1f002a,0xde5801f3}},	//   finc, وجود_, ężna_, палі_
  { {0xd00f0074,0x934613ae,0x60c9029e,0x62090030}},	//   جله_, _інве, _enem, áplá
  { {0x1ea9003b,0x290000f2,0x6da3049d,0xe0860015}},	//   ثاني_, _omia_, вија, _يجري
  { {0x2d80002c,0x84a9000a,0x9be6005e,0xbdf70015}},	//   čie_, ִיתִ, діок, ظروا_
  { {0x6f0300d9,0xdca30054,0xbf16002b,0x2b470034}},	//   binc, тањи, _قورب, _binc_
  { {0xddc60001,0x2b470251,0x60c90107,0x6123007c}},	//   _обзи, _cinc_, _znem, sõlt
  { {0xe8950010,0x68ed0134,0x6d5e0156,0xeaf70369}},	//   нань, _plad, ípad, بريت_
  { {0x63a6042f,0xfd57004f,0xcce60058,0xf98f009a}},	//   _opkn, _חשאי_, _تسطي, گبی_
  { {0x59b0005d,0xc7b80010,0x274b0036,0x48e40010}},	//   _जनवर, мёр_, ючно_, тоўв
  { {0x68ed4263,0xf98f002b,0x7c2f0061,0x6ec70065}},	//   _wlad, دبی_, ücre, लाएँ
  { {0x442d018c,0xb6040484,0x59d30015,0xf628005e}},	//   _še_, вятк, _لغير, діти_
  { {0x3998357f,0x68ed002d,0xe5340010,0x7bc20046}},	//   més_, _ulad, весь, _krou
  { {0xe1f00086,0x39981f0f,0xe6670404,0x60db096f}},	// [9490] یسم_, lés_, _отно, _roum
  { {0x95cb010f,0x51870001,0x60db3869,0x35b54264}},	//   _дума_, дуда, _soum, _збор
  { {0x3f990024,0xa2c4005d,0xa29401f3,0x60db4265}},	//   _ūsu_, राज्, тахі, _poum
  { {0x6f03005c,0xa0c50015,0x30154266,0x4f950c9a}},	//   winc, عيشو, ндер, ерку
  { {0x39980152,0xdbd60209,0xa3c2000b,0x70760015}},	//   hés_, _jääm, ्मण_, رموز_
  { {0x8ca1005d,0xc6950053,0x217b0015,0x39980307}},	//   क्नो, גאַ_, _وحزب_, kés_
  { {0x7bc20041,0xed56006b,0x6f030a58,0x6e280034}},	//   _arou, нощ_, rinc, _cydb
  { {0x273600fb,0x8c3d0064,0x399801c4,0x7bc24267}},	//   mæne_, leşi, dés_, _brou
  { {0xe0d2004c,0x2b470034,0xdea1002b,0x6f034268}},	//   _גײן_, _pinc_, _میشی, pinc
  { {0xbda70029,0xa3c2000b,0x7bc21359,0x8c3d0061}},	//   _يحاو, ्मत_, _drou, neşi
  { {0x39983a3b,0xd9c9000b,0x39494269,0x7bc20045}},	//   gés_, िमेट, _bias_, _erou
  { {0xdc7500b2,0xf8bf0057,0x39490077,0x7bc2426a}},	//   _װײַז_, blém_, _cias_, _frou
  { {0x394903af,0x2b470251,0x7bc2426b,0x69ce0012}},	//   _dias_, _tinc_, _grou, äber
  { {0x7d79000a,0xbb76000a,0x98a5003d,0xfbd0012c}},	//   ּנּו, _טענו_, ēlā_, _ختم_
  { {0x3998357f,0x13c8005d,0x64a609d7,0xa2c3000b}},	//   cés_, रम्भ, нава, _रफ़्
  { {0x2cad0546,0x3f86426c,0x0000006a,0x0000006a}},	//   need_, yrou_,   ,
  { {0xccf20053,0x8ca1000b,0x6b9b001a,0x2d87005a}},	// [94a0] אכן_, क्यो, ntug, hrne_
  { {0x915e0016,0x2216426d,0x2cad426e,0x0000006a}},	//   _hẳn_, нфер, heed_,
  { {0x22930029,0x58ba000a,0xd51a0016,0x91e3006b}},	//   المس, ּמְצ, hẳn, лофе
  { {0xa3c2005d,0x70530086,0x3f86426f,0xa2c4000b}},	//   ्मद_, هنما, trou_, राङ्
  { {0x39980014,0x2cad003e,0x2d874270,0x73e30280}},	//   zés_, deed_, erne_, _бояз
  { {0x7bc400df,0x39980152,0xe5780024,0x877b0135}},	//   _šiuo, yés_, šķu_, לאני
  { {0xc6930053,0xf9870015,0xb4fa000a,0x61310123}},	//   טאג_, _حب_, ּפִי, måln
  { {0x71260029,0x61f20064,0xc19b0008,0x7bc24271}},	//   _أرسل, ıklı, _משלי, _prou
  { {0xdccf0092,0xa1370053,0x6b9b0035,0x02e4000b}},	//   _tỉnh_, _טאלק_, gtug, _गवाह_
  { {0x39984272,0x78a40020,0x7bc20161,0xc003006b}},	//   tés_, _abiv, _vrou, _спук
  { {0xdb0b002d,0x22f7000a,0x929b000a,0x7bc200da}},	//   _argó, גזין_, היית, _wrou
  { {0x2cad003e,0xfc640086,0x7cfe0007,0xdbd600f2}},	//   ceed_, _شخصی, kūri, _pääm
  { {0x39981f11,0xc7cb0010,0x2d9c00dc,0x69c34273}},	//   sés_, чыне_, ltve_, _erne
  { {0x39984274,0xfbb7000a,0x39d40015,0x9aa40015}},	//   pés_, _נפות_, _ليتأ, _شمعو
  { {0x2d9c00dc,0x7cf50046,0x62830533,0x7abb004f}},	//   ntve_, _dárf, ónom, _מצגו
  { {0x98a40001,0x612a001a,0x61e501c0,0x3eae0977}},	//   _биће, býli, vyhl, heft_
  { {0x889c0643,0xa2cd000b,0x47350923,0xe3b3006e}},	// [94b0] _זבחי, साल्, _инис, درز_
  { {0xd5bb000d,0x78a40085,0xddda0030,0x78bd24a0}},	//   _есм_, _zbiv, _lető, ldsv
  { {0x7d0202b9,0xc1e80033,0x0656000a,0x7afd0144}},	//   _omos, ньце_, _ביתך_, èsti
  { {0x3eae0111,0xd4790053,0x82340029,0x6295002a}},	//   eeft_, _קאָל, اركا, _wczo
  { {0xe9ff0092,0x5ff5006b,0x58f8004c,0xa858000a}},	//   _khải_, ъзду, עמדע_, גידה_
  { {0x752d0ede,0x7d022fee,0x6295002a,0x2d87006f}},	//   llaz, _amos, _uczo, trne_
  { {0x7db20029,0x62342440,0xcd28002b,0x2cad007c}},	//   لموص, _беру, کسون_, teed_
  { {0x752d0467,0x270e005d,0x26fe000b,0x7cf50077}},	//   nlaz, _सद्र_, _उग्र_, _márg
  { {0x78af0045,0x78bd00cb,0x2d8e0012,0x3af5107b}},	//   decv, ddsv, aufe_, вянс
  { {0x99d50029,0xc43c0008,0xdef80033,0x752d0046}},	//   نتجا, התחי, _пых_, hlaz
  { {0x2d9c006f,0x7bcd0091,0x6ce7005e,0xc3320c44}},	//   ctve_, _šaud, _піде, שוי_
  { {0x69c300bd,0xf1b2015b,0x7cf50125,0x612a0de4}},	//   _vrne, בסט_, _sárf, týli
  { {0x18670054,0x6d4b0030,0x907a05bd,0x442b4275}},	//   ђари_, _iiga, וטרי, _nyc_
  { {0x6f0d002f,0x79880034,0x6b894276,0x752d35f8}},	//   éach, brdw, mreg, elaz
  { {0x7d020026,0x6d4b003f,0xd6271179,0x66034277}},	//   _ymos, _kiga, воре_, апра
  { {0x7cfe1147,0x037a0015,0xc952000a,0x442b002a}},	//   tūri, ِحات_, _דמה_, _byc_
  { {0x6d4b0ed2,0x03262d90,0xe7b3002b,0xa44606b9}},	// [94c0] _miga, вдан, _نميد, тнад
  { {0x073a0029,0x6d4b3b35,0x752d2895,0xd36f0015}},	//   _تسبب_, _liga, alaz, تهك_
  { {0x63a90024,0x7b1c0061,0x61310123,0x7c2b0034}},	//   _ģene, _uçuş, råln, _lygr
  { {0x55770053,0x41b50010,0x6b890111,0x8ca1000b}},	//   _בעטן_, ысут, kreg, _कॉलो
  { {0xa857013a,0x4fb30029,0x60230080,0xd00f0002}},	//   דינה_, لصور, адца, يلم_
  { {0x57fb0008,0x61380089,0x2d8e1fd5,0xbf650015}},	//   ולנו, díle, tufe_, ادنو
  { {0x6d4b4278,0xdee30054,0xc333000a,0x3eae4279}},	//   _biga, роји, _כוש_, reft_
  { {0x5bb800a4,0x621b000a,0xbd55002b,0x69ab000b}},	//   елия_, _חולק, دروژ, _जनजी
  { {0xdfa50029,0x69c10064,0x28d6000b,0xd11f000b}},	//   _محلي, evle, धानि, यकरण_
  { {0x613101d1,0xc43b0008,0xb87b00dc,0x2ac60001}},	//   håll, ותפי, nkív, тљив
  { {0x4dda0015,0xa2c3000b,0xddda0030,0x765c0034}},	//   _توضح_, रयत्, _tető, dcry
  { {0x6138002d,0x78bd0079,0x7cf5427a,0x6d4b427b}},	//   bíle, udsv, _cárd, _giga
  { {0xe9ff00a7,0x61380089,0x7cf50f87,0xb8fb000b}},	//   _phải_, cíle, _sárg, _डच_
  { {0x6d4b0012,0x6d40389c,0x65950aa1,0x0000006a}},	//   _ziga, lmma, лагу,
  { {0x35e408fb,0x09e3050e,0xb87b0030,0x27ed427c}},	//   ацтв, _војн, dkív, šen_
  { {0x6d4e0152,0xe4a70063,0x65940099,0xfbb6000b}},	//   _ébau, ърго, јату, _अनाम
  { {0xe3b00029,0xe9ff0092,0xb8f7005d,0x6d400ac8}},	// [94d0] يرك_, _thải_, सा_, imma
  { {0x8c3d0011,0x660e0089,0xd370002b,0x7bdf016e}},	//   meşt, ánká, زهٔ_, _àque
  { {0x224701d1,0x2d580152,0x8c3d1c8d,0x7cf5001a}},	//   änk_, _née_, leşt, _háre
  { {0xf8bf0152,0x6601001a,0xf993000a,0xe588004f}},	//   ndé_, úlku, שרף_, _בָשָ
  { {0x8c3d0011,0xa3ab000b,0xb4fa000a,0x78fc000a}},	//   neşt, _कैच_, _נפשי, ופאו
  { {0x539a013a,0xa3c0005d,0x8c3d0011,0x5e870010}},	//   _אישו, ंटर_, ieşt, тудз
  { {0x69dc0020,0x3f8f007c,0x3f9d002a,0x4d890015}},	//   ärel, sugu_, stwu_, رَةُ_
  { {0x7cfe0007,0x7bdd008c,0xd138006b,0xbdf80015}},	//   kūru, äsuo, _аху_, خرها_
  { {0x6d4b427d,0x7bcd003d,0x7cf5006f,0x1b49427e}},	//   _viga, _šaub, _náre, нзии_
  { {0xe9d9427f,0x6b894280,0x6d404281,0xadbd0033}},	//   еко_, rreg, amma, _назi
  { {0x7c2b005c,0x61380089,0x39460080,0x48e6006b}},	//   _wygr, síle, лног, гонв
  { {0x6b894282,0xdcbb005e,0xbd010046,0xbc190033}},	//   preg, _іще_, _šéfe, _пілі_
  { {0x7cfe0007,0xae07000b,0x6c7a000a,0x7d094283}},	//   gūru, _वेतन_, _נאספ, mies
  { {0x2cbf0020,0xf8bf0003,0x7d094284,0x7cf5005a}},	//   ldud_, adé_, lies, _dáre
  { {0xe7370063,0x69dc0bad,0x0555005e,0x2cbf007c}},	//   уер_, øret, иття, odud_
  { {0x2cbf0020,0x7d094285,0x8c3d0045,0xf992000a}},	//   ndud_, nies, beşt, _הרה_
  { {0x8c3d0011,0x75240263,0x2cbf007c,0x7cf50030}},	// [94e0] ceşt, roiz, idud_, _kárb
  { {0x7bc40007,0xd36f0029,0x7d094286,0x82850015}},	//   _šiuk, سهم_, hies, لجمل
  { {0xea760053,0x869b0135,0xda76004c,0x7d094287}},	//   רגער_, _אייז, רגעט_, kies
  { {0x4f660029,0x50ba0115,0x7d09008c,0xcf9a012e}},	//   هاتف, عداد_, jies, ејк_
  { {0xe6120086,0xdee64288,0xc4d3000a,0x43750342}},	//   _خشک_, лоди, _הגר_, _вуст
  { {0x2d800024,0x8ca1000b,0x63b60034,0x7cf50125}},	//   ņiem_, क्सो, mwyn, _nárb
  { {0xc6930008,0x63b60026,0xf6570008,0x2cbd0026}},	//   צאה_, lwyn, נסקי_, _bawd_
  { {0xc5f30008,0xbd430086,0x7d0911a8,0x69dc0123}},	//   מדו_, مچني, gies, ärem
  { {0x4e9600e5,0x63b60034,0xfe720015,0x7cf50e51}},	//   _مشار, nwyn, _هدا_, _bárb
  { {0x8c3d0011,0xe39b0053,0xd00f0018,0xa3bc0065}},	//   veşt, עשיכ, _علل_, _आनन_
  { {0x63b60026,0x28f91aef,0x391506c3,0x7d094289}},	//   hwyn, вень_, имор, bies
  { {0x8c3d0011,0xecb8000b,0x3ebe2d60,0x2736001a}},	//   teşt, _आसिफ, _hatt_, væna_
  { {0xead4065e,0x6c7b0053,0xf8bf428a,0x3ebe0804}},	//   _воль, _טראד, rdé_, _katt_
  { {0xbb83003b,0x8c3d04f9,0x89d80086,0x87040033}},	//   _الوي, reşt, _لوتر_, бясе
  { {0x8ca1014e,0x8c3d0011,0x7e5701ac,0x4a5b039e}},	//   क्वो, seşt, רסלב_, _אדוו
  { {0xa99b0008,0xdb1900b8,0x99f7000a,0x628a16ee}},	//   _נבחר, _erwä, _תזהה_, ófon
  { {0x63b60026,0xa3d4004a,0x4395006b,0xc27503ae}},	// [94f0] gwyn, ботч, разс, илај
  { {0x7d0920f3,0x8c1b000a,0x53470033,0x883c000a}},	//   zies, תומי, ухба, _אתחו
  { {0x38600084,0x91f90015,0x90553e7a,0x611c428b}},	//   _yfir_, خفاء_, авец, zčle
  { {0x02440029,0xb97b0008,0x7cf51364,0x290b428c}},	//   حَمَ, תנאי, _márc, nica_
  { {0xdb09002e,0x44190008,0x248e0089,0x7d09428d}},	//   kveð, _יוֹס, íjmů_, vies
  { {0x7d09428e,0x41770040,0x7db50015,0xff50012c}},	//   wies, _مارس, لصبا, سخه_
  { {0x7d09428f,0x6e920054,0x1dc5000b,0x3ebe4290}},	//   ties, цију, विधत, _datt_
  { {0x99870046,0xdcf8003d,0x290b4291,0x6bd50058}},	//   _synů_, duvē, jica_, لتخر
  { {0x7d094292,0xe4a8000a,0x7cf50030,0x3ced40ca}},	//   ries, אֹתָ, _párb, rkev_
  { {0x7d094293,0x6eef02de,0x3ced00bc,0xb60800bf}},	//   sies, _købm, skev_, noší
  { {0x290b4294,0x186a0254,0x7cf5396d,0x1eea002b}},	//   fica_, кани_, _cárc, _جولی_
  { {0x61fa0005,0x7188000a,0x7de40015,0x7cf50046}},	//   _ütle, נְתַ, _اسْم, _dárc
  { {0x88360010,0x69dc0595,0x07a6009c,0x98360033}},	//   рэнц, ører, јагн, рэні
  { {0x0f56000a,0xabfa000a,0x8ca1000b,0xaa450b9b}},	//   יישם_, _שהסר, क्रो, _келл
  { {0x7ae3002f,0x649a008f,0xb87b00dc,0xd62a4295}},	//   _iont, ктар_, tkít, тове_
  { {0x7ae34296,0xb4660974,0x4466381c,0x05550681}},	//   _hont, ркал, рвав, стря
  { {0xe29a00d0,0x4256017a,0xdbd9016e,0x730601e3}},	// [9500] каа_, атет, _açúc, апаз
  { {0x577b00b2,0x8ccc005d,0xa77b0135,0x68e40e95}},	//   _שטיצ, _दोनो, _שריפ, _hoid
  { {0x98da000b,0xf8da000b,0x68e4007c,0x7ae31166}},	//   _बचाए, _बचाय, _koid, _mont
  { {0x68e4022d,0xda48000a,0xb637000a,0x3ebe4297}},	//   _joid, אֲנָ, _כריס_, _satt_
  { {0x684a0007,0xb6080046,0x3ebe15a6,0xf8bf01d3}},	//   būdž, boší, _patt_, mlét_
  { {0x68f60026,0xdfcf00e5,0x160b000b,0x6fb3002b}},	//   _llyd, بيه_, _हेडर_, تمها
  { {0x80c1005d,0x6df30015,0x36cb004c,0x8d630054}},	//   _रोके, يكها, פֿרעג_, овје
  { {0xbd430074,0x7ae3002f,0x3ea00089,0x628301c9}},	//   ينوي, _aont, řit_, ónov
  { {0x3ebe003c,0x2eb60c71,0x23c9000b,0x290b4298}},	//   _tatt_, _всес, रियद, vica_
  { {0x60c200df,0x8f9b0008,0xe801005d,0x1df8002b}},	//   ldom, _בימי, _लेगा_, _مکعب_
  { {0x60c20007,0x32570008,0xe873002b,0xc27b015b}},	//   odom, יסים_, يندگ, כריי
  { {0x60c0020a,0x8d740086,0x0907005e,0x2fc60085}},	//   _jamm, _ناچا, рчом, ovog_
  { {0x4bd70086,0x290b0e35,0xe801000b,0x68e4016e}},	//   _نبود_, rica_, _लेखा_, _doid
  { {0x8bfb000a,0x6b7b000a,0x7cf50030,0x60c04299}},	//   _שִׁפ, _ירדנ, _tárc, _lamm
  { {0xbbb6014e,0x94d50036,0x5bb6005d,0xbdf4000f}},	//   _अनुक, бовц, _अनुव, זֶּה_
  { {0x2fc6016f,0x89db0008,0x629c429a,0x54550461}},	//   kvog_, _יחוי, _acro, сват
  { {0xf7730015,0x7cf50030,0x61fe01c0,0x56950763}},	// [9510] _باع_, _jára, ezpl, _лапт
  { {0x326702e1,0xe2930029,0x8bd7000a,0x0b14000a}},	//   ртав, تذر_, בומו_, צַּר_
  { {0x60550029,0x31580029,0xb4db0251,0xc3480063}},	//   مناط, لجنة_, _diàr, ряте_
  { {0x6b82016f,0x60c0429b,0x7bdd007c,0x6138001a}},	//   _ovog, _camm, äsuk, tíla
  { {0xf8bf0999,0x7cf501c9,0x684a0091,0x30780015}},	//   llés_, _nára, pūdž, شحنة_
  { {0xaf040036,0x60c2429c,0x9f560030,0x629c0125}},	//   опіл, adom, ágás_, _gcro
  { {0x613802d5,0x645a0011,0x290900f2,0x28ca000b}},	//   síla, _ştii, _omaa_, ियमि
  { {0xa6180008,0xeb990df0,0x8b953014,0x60c02ecb}},	//   יקוד_, гии_, броч, _gamm
  { {0x69ca0176,0x7cfe003d,0x6f0d0125,0xf3f2000a}},	//   _arfe, tūrr, éacs, ּ֣ח_
  { {0x0358004c,0x6b8206f2,0xb436000a,0x7afa055e}},	//   ביזש_, _dvog, מָיו_, ghtt
  { {0x68e4429d,0x7ae30b4d,0xd51a0016,0xcdf40058}},	//   _poid, _vont, hắn, _وأمث
  { {0xa2c9005d,0xc212000a,0x61d6000a,0x7cf50030}},	//   _होस्, להי_, צורף_, _fára
  { {0x68e4022d,0x6b651398,0x26c102f2,0x7ae3429e}},	//   _void, _укла, _baho_, _tont
  { {0x7afa0ec2,0x60c2429f,0x4ac40015,0x9663006b}},	//   chtt, zdom, _وينق, зкре
  { {0xf8bf0467,0x68e40005,0xb9950029,0xa2db005d}},	//   glés_, _toid, _العب, नान्
  { {0xa9050029,0x62870c0a,0xe8f6002b,0x6ab7000b}},	//   _وبين, _adjo, _دستخ, _असुर
  { {0xb8de005d,0x7cfc00dc,0xf2560015,0xb8fc0157}},	// [9520] ुए_, _férf, مضاد, ठा_
  { {0xf8bf0003,0x290e002a,0x60c0153c,0x61fe0012}},	//   blés_, ślać_, _samm, tzpl
  { {0xe3b2002b,0x106a004a,0x9657000a,0x79810034}},	//   _کرج_, гией_, _לשיא_, nslw
  { {0x5a0a004c,0x69dc008c,0xf41f008c,0x614308f0}},	//   נלײַ, ärei, _idän_, пеха
  { {0x44240023,0x7bcd0007,0xbbb6000b,0x60c0008c}},	//   _âm_, _šaun, _अनेक, _vamm
  { {0x9f5f0030,0x63a442a0,0x2fc60085,0x60c23409}},	//   írál_, mtin, rvog_, sdom
  { {0xa3c2014e,0xdbf10089,0x6b8242a1,0x63a422a3}},	//   ्मक_, _dřív, _svog, ltin
  { {0xd217013a,0x915e0092,0xa3bc005d,0x3ea7001a}},	//   _הקלק_, _gắn_, _आना_, afnt_
  { {0x9b580004,0xfcaa002b,0xd00f0015,0xeb4a004a}},	//   јиот_, ناکو_, _كلف_, лчок_
  { {0x13bb0053,0x7cf500dc,0xf2d30053,0x2ee53f9b}},	//   נזיע, _vára, ִער_, _golf_
  { {0x58d90010,0x395800dd,0x5eeb000a,0x7bcb42a2}},	//   адня_, êrs_, _עַמְ, _ergu
  { {0x7cfc0084,0x63a442a3,0xc864006b,0xdc3c003d}},	//   _sérf, ktin, зтри, ašāk
  { {0xad250067,0x28b8000b,0x48140033,0x6d5a42a4}},	//   _برلو, इज़ि, змяс, _huta
  { {0x6d5a0f4d,0xef11000a,0x63a4007c,0xf8bf0030}},	//   _kuta, ֵּם_, dtin, tlés_
  { {0x7a7b000a,0x4b37000a,0x7a530015,0xef0e0033}},	//   _גרוס, _הרגל_, _عضوا, ьмi_
  { {0xa4f10064,0xf8bf00dc,0x6d5a42a5,0xba17000a}},	//   _dışı_, rlés_, _muta, _לחוץ_
  { {0x28d6014e,0x63a442a6,0x6d5a42a7,0xc87f0012}},	// [9530] धारि, gtin, _luta, maß_
  { {0x06b70086,0x3ce6007c,0x7cfc0030,0x7cf5016e}},	//   _اندک_, _loov_, _férg, _nárn
  { {0x7cfc0014,0x63a442a8,0x6d5a2876,0x41b50015}},	//   _kérd, atin, _nuta, تمار
  { {0x999b0053,0xd01100e5,0xc5e8000a,0x2ba9000b}},	//   רבאט, ولا_, _הַשֹ, _कहला
  { {0x63a42383,0x29193ce0,0xdbf10046,0x6d5a42a9}},	//   ctin, insa_, _přív, _auta
  { {0x39830064,0x628700dc,0x6d5a42aa,0x7cf510e5}},	//   yıs_, _udjo, _buta, _cárn
  { {0x7bc70048,0x3f76005c,0xc3320008,0x78ad1ff2}},	//   ājum, ału_, _חום_, _obav
  { {0x55780053,0x29190003,0xab653ee0,0x2ee527fc}},	//   זעהן_, éral_, овил, _wolf_
  { {0x7c840054,0xba750015,0x9f63008c,0x4ea70b1e}},	//   чује, يادت, övät_, _греа
  { {0x291942ab,0xc9a90174,0xf9850195,0x89a90a24}},	//   ensa_, авое_, огоо, аков_
  { {0xd946058b,0x7afd003d,0xdc3c003d,0x6d5a42ac}},	//   жени, ūsto, ršāk, _guta
  { {0x63a40084,0x28a5000b,0x7cf50030,0x39830061}},	//   ytin, ग्लि, _zárn, rıs_
  { {0xa803008f,0xe73a11d9,0x7cf51754,0x386d0077}},	//   дзял, ием_, _háro, ñera_
  { {0x78ad007c,0x7cf50030,0x2f5a000a,0x8c1a000a}},	//   _ebav, _káro, ידשנ, _דוני
  { {0x394003c2,0x954a0029,0x691600bd,0xb9920015}},	//   _this_, لشرق_, jšeg, _قلوب
  { {0x63a40c0a,0x8afd0046,0x68fd0028,0x0000006a}},	//   ttin, dpři, chsd,
  { {0x130a0010,0x23690029,0x03a300d0,0x08fa002b}},	// [9540] анай_, محلي_, мито, _مرکب_
  { {0x29f50092,0x78ad01b2,0x63a442ad,0x51f60040}},	//   óa_, _zbav, rtin, يسار
  { {0x0219008f,0x7cf50f1b,0x645a0045,0x15ba0033}},	//   біць_, _náro, _ştiu, _тыпы_
  { {0x7cfc0014,0x6d5a42ae,0x28dd000b,0x2fcd00bc}},	//   _kére, _ruta, यायि, _breg_
  { {0x6d5a42af,0x691600bd,0x4fb600a2,0xdfa60015}},	//   _suta, ašeg, تصار, تحضي
  { {0x2480002f,0x141b0008,0x7cfc00dc,0x3ce60020}},	//   laim_, _כוכב, _mére, _soov_
  { {0xccfa0001,0x3f76005c,0x98ca000b,0xaf070015}},	//   ићи_, słu_, ियाए, تقوم_
  { {0x9cca0010,0x2480002d,0xf653000a,0xfbaa056d}},	//   рыка_, naim_, וצו_, атой_
  { {0xd0120087,0x7d030015,0x4f650015,0x2fcd0d3a}},	//   _غلط_, بِيه, _فالف, _greg_
  { {0x3f800007,0x6d5a42b0,0x9b430040,0x79a60d7a}},	//   šius_, _tuta, ونيو, орме
  { {0xed5a008f,0x7cfc0656,0xa2db005d,0xdca605e6}},	//   _тое_, _pérd, नात्, _мажи
  { {0x248000dc,0x291942b1,0x7cfc0324,0x69c802dc}},	//   jaim_, unsa_, _bére, rvde
  { {0x7cfc016e,0x7cf52745,0x8ae601f3,0x1bd4005e}},	//   _cére, _záro, _мікл, _холя
  { {0x5c37000a,0xc87f0012,0xdb9b000a,0xdcf80091}},	//   _ורדן_, saß_, _כסדר, tuvė
  { {0x6d4200a7,0xa4d50191,0x8ca1000b,0x7cfc0030}},	//   _khoa, пові, क्को, _térd
  { {0x69dc00f2,0x248003d9,0x2458034e,0x99fb000a}},	//   äreu, gaim_, жать_, _כפופ
  { {0x2bcd005d,0x7cfc0152,0xd25b0cad,0x8ca2000b}},	// [9550] ़िया, _gére, аце_, _गानो
  { {0x026b0010,0xa2db000b,0x28ac000b,0xc2c40015}},	//   ршай_, नाध्, ट्ठि, ويقي
  { {0x116a0074,0x5184070e,0x76ba000a,0xd2510015}},	//   مللی_, дуча, _המתפ, ءنا_
  { {0x915e0092,0x2fcd00cb,0x0000006a,0x0000006a}},	//   _sẵn_, _preg_,   ,
  { {0x9f350036,0xa0c40015,0x44da004f,0xa2db0065}},	//   педі, بينو, _החרג, नाद्
  { {0x1fd80015,0xdfce00c3,0xc105002b,0xd7bc0c44}},	//   تظمة_, ايو_, _کوري, שֶׁך
  { {0xad580256,0x40870004,0x63b90061,0xa0b70015}},	//   орых_, _муаб, şanı, _وحرص
  { {0x7cf50014,0x20d70029,0xcd280015,0x2fcd00cb}},	//   _váro, _بتسج, يسين_, _treg_
  { {0x3ec4022d,0x2d9800c0,0x7bc40073,0x0000006a}},	//   östä_, _åren_, _šiur,
  { {0x7bc9038d,0x4fc40010,0x7cf500dc,0x9b020033}},	//   rveu, _ўста, _táro, езьд
  { {0xdcf70029,0x99d5006e,0x7cfc0030,0x9f0400c3}},	//   _وأصب, ستدا, _sére, _تولو
  { {0xecbb0015,0x5fbf000b,0x7cfc40fe,0x6131194e}},	//   _خططت_, _एनाल, _pére, måls
  { {0xd7f20015,0x7cf50030,0x7af60030,0x7d1b0030}},	//   ركس_, _járm, ágtó, mnus
  { {0xb8f30372,0xf6d50036,0xfe670115,0x6d49007c}},	//   _हो_, міся, عد_, lmea
  { {0x7d1b0064,0x248000dc,0xda7a000a,0x1fb8000b}},	//   onus, taim_, _הנצר, _इन्ड
  { {0x0457003b,0x7d1b0356,0x6d490125,0x7cfc01ce}},	//   كلفة_, nnus, nmea, _tére
  { {0xc953000a,0x389b000a,0x78fb000a,0x925a0015}},	// [9560] _אמה_, _היפנ, _לפקו, مشار_
  { {0x662700dc,0x6d490a11,0xc7b3000a,0x248042b2}},	//   érké, hmea, _טבח_, saim_
  { {0xc2190036,0x365b000a,0x217a0015,0x1677000a}},	//   оєї_, _לכינ, صحاب_, _מגיל_
  { {0x7cf50014,0x00e60080,0xc3290008,0xc5f3000a}},	//   _bárm, яжен, או_, _נדר_
  { {0x9f98005e,0xd059005e,0x6d49007c,0x28dd0065}},	//   івку_, ірці_, dmea, याति
  { {0x7d1b0020,0x083b0053,0x6e94049d,0xd00f00c3}},	//   enus, זענל, фику, دله_
  { {0x1ea900e6,0x434342b3,0xa1160058,0xcd33009a}},	//   تاني_, _черв, _فوست, کروب
  { {0xf6530008,0xa2b6000b,0x411a002b,0x50950054}},	//   עצה_, ैयक्, _ايرج_, _оруђ
  { {0xdd90002b,0x672e1de9,0x395c42b4,0x2e56009a}},	//   روک_, kobj, _suvs_, _فضاس
  { {0xfee90029,0x6ec50029,0xb4db0016,0xbea33a0e}},	//   _وعلى_, _يتلق, _nhàn, _паук
  { {0x6d420023,0x672e018c,0x6e930029,0xeaf70086}},	//   _thoa, dobj, _ألما, ثريت_
  { {0x02170008,0x2df7000a,0x4ddb000a,0xeb9a01b7}},	//   לחים_, _מצבך_, _לחבו, _гид_
  { {0x2c080086,0x57f40457,0x3f86016e,0xc7bb004a}},	//   _بعضی_, епят, nsou_, щён_
  { {0xddc80007,0xe5730015,0xaa570015,0xb4db0016}},	//   _medž, فطر_, _فلها_, _chàn
  { {0xa2db000b,0xca480015,0x5eef000b,0xdb09002b}},	//   नास्, _بلغه_, _अवस्_, _بزنه_
  { {0xa99b013a,0x2eb9014e,0x645a04f9,0xef22005c}},	//   _הבהר, _इस्त, _ştir, leżą_
  { {0x3f860089,0x69c5002e,0x98a40001,0x8ca1000b}},	// [9570] jsou_, _áher, _чиње, क्टो
  { {0xd7fc0008,0x57fc0008,0x2bcd005d,0xd25b04c2}},	//   _להחל, _ללחו, ़िता, сца_
  { {0xc6920008,0xf1c2003d,0x4aae000b,0x0000006a}},	//   _באי_, jušā_, ज्यव,
  { {0x7aea0ab5,0xdce3003d,0x80f50138,0x61310c4e}},	//   _loft, rsnī, ьпех, våls
  { {0x3ce0000b,0x926b0054,0x6f6401c6,0x8fa5067a}},	//   काने_, _грба_, евіз, фале
  { {0xe8da005d,0x2d510089,0xf778000a,0x315b0015}},	//   _बच्च, _všem_, לעדי_, _هجرة_
  { {0x1ea80029,0xb0f6002e,0xf2d2000a,0x3869001a}},	//   ساوي_, þýða, _בעם_, _ofar_
  { {0xed56010f,0x7cf500dc,0xd5fc000a,0xb5fc000a}},	//   мощ_, _zárj, מפור, מלוכ
  { {0x7cf5006f,0x6d4942b5,0x0b450588,0x7d1b42b6}},	//   _hárk, rmea, мнин, rnus
  { {0x799a000c,0xcda90029,0xff530029,0x31790053}},	//   futw, _وهذه_, _أخر_, ֿאָד
  { {0x260d000b,0xf8f90016,0x7aea42b7,0x0000006a}},	//   _डेली_, ượt_, _doft,
  { {0xc6890dab,0x7cf500dc,0x2bb6000b,0xe8f70033}},	//   _כא_, _márk, _अनचा, длю_
  { {0x99d50086,0xe9db0086,0xe9720086,0x69dc0400}},	//   ستگا, _گذشت_, _یهود, ärer
  { {0xe6120015,0xa3c1000b,0xfc30012c,0x9c08000a}},	//   نشأ_, ंबन_, _صحن_, _מִצִ
  { {0x7cfc42b8,0x35a301c6,0x64a642b9,0xe7371c80}},	//   _héra, карг, мава, фер_
  { {0x69260010,0x6eef02de,0x23c9000b,0x7cfc0003}},	//   _імпа, _købs, रिंद, _kéra
  { {0xb4db00a7,0xb4be005d,0xe947002b,0x61380046}},	// [9580] _thàn, _इसी_, _تروی, sílk
  { {0x7cf500dc,0xf1fa00e6,0x613811dd,0xc2c60015}},	//   _bárk, يعات_, míli, بيئي
  { {0xb97a00b2,0x02190010,0x7cf500dc,0xd6db000a}},	//   ַנסי, піць_, _várj, _וחיל
  { {0xdfda006b,0x7cf50046,0x31be0046,0x6aba0030}},	//   жък_, _dárk, _vůz_, zetf
  { {0x6ef40144,0x1438002b,0x61381756,0xddd80085}},	//   _hàbi, _ريسک_, níli, davš
  { {0xad660015,0x64430046,0xbd6a07be,0x3f86016e}},	//   وابه, řnic, орие_, rsou_
  { {0x3f860dc4,0x2cad00da,0x7cfc0003,0xa2db0065}},	//   ssou_, ffed_, _aéra, नार्
  { {0xb4fb0053,0x799a003f,0x67210796,0x40930015}},	//   ַליר, vutw, člji, _للفر
  { {0x70560015,0x28dd000b,0x8f970015,0x7aea0045}},	//   _آنذا, यासि, _ينفذ_, _poft
  { {0x7cfc0003,0xbb4700c3,0x2902013b,0x0000006a}},	//   _déra, ولين_, ehka_,
  { {0xdee3006b,0x7dc60015,0xd9150256,0xb2bb000a}},	//   _шофи, _تتذك, едны, חמיר
  { {0x61e300c0,0xf7950033,0x89340015,0x6cd3006e}},	//   änli, намэ, َعَا, _لقما
  { {0xacf70036,0xaae60015,0xeb06004a,0xcd02002a}},	//   _іншу_, _يستو, _очко, reść_
  { {0xaff90053,0xbbbc000b,0xa3d2000b,0x4c3b000a}},	//   פּרי, ्टीक, विन_, _ותדב
  { {0x3eae0026,0xf92b0029,0x7cf500dc,0x163403ad}},	//   ifft_, _وأبو_, _bárh, веря
  { {0x628e0026,0x3ea90085,0x6625003d,0xb8670058}},	//   _adbo, đati_, _ārkā, _غابو
  { {0xa87c0008,0x43740036,0xa2db000b,0x92a70054}},	// [9590] _ואחר, вуєт, नाल्, дјел
  { {0x28dd000b,0x98a21e7f,0x92b70058,0xddd80160}},	//   यावि, roką_, بحرا, zavš
  { {0x98a2002a,0x2cad0034,0x40950015,0x50b516db}},	//   soką_, yfed_, فلار, еслу
  { {0x1dc2000b,0x659a004c,0x8a17000a,0x8145002b}},	//   _वैधत, _צירק, וחבו_, رنشن
  { {0x7afd0024,0x3f890003,0xdfa40015,0x0000006a}},	//   ūsti, éau_, نحوي,
  { {0xf7740008,0x68ed42ba,0x2cad0034,0xed5934a8}},	//   דקס_, _load, wfed_, пок_
  { {0x8d84002b,0xddd80085,0x7cfc42bb,0x61381fbb}},	//   نشين, tavš, _séra, zíli
  { {0xd658013a,0x7cfc0003,0xdca10033,0x443942bc}},	//   ויות_, _péra, ускi_, _kys_
  { {0xfbd100e5,0x4034004a,0x6138016e,0x443900aa}},	//   اتب_, _аетс, xíli, _jys_
  { {0x628500b6,0x7c2e0012,0x7cf542bd,0x78a402b9}},	//   naho, ßbra, _mári, _sciv
  { {0x7cf5002d,0xfeb80029,0x443942be,0xc332000a}},	//   _lári, _زالت_, _lys_, רוי_
  { {0xb4be005d,0x60c9007c,0x7cfc001a,0x68ed42bf}},	//   _इसे_, _jaem, _hérn, _coad
  { {0xb8e8014e,0x68ed016e,0x7cfc0030,0x6d5902f2}},	//   _उस_, _doad, _kérn, _iiwa
  { {0x6d590035,0x645d02f2,0x290242c0,0x613842c1}},	//   _hiwa, _agsi, shka_, ríli
  { {0x6d59000c,0x7cf500dc,0x613842c2,0x8afa0447}},	//   _kiwa, _párh, síli, _מהסי
  { {0x045a0029,0x6b890e01,0xf9b6000a,0x07a60e60}},	//   سلطة_, oseg, _נהפך_, _заин
  { {0x442603af,0x2bd2005d,0x7cf500dc,0x28dd000b}},	// [95a0] ço_, तिया, _várh, यारि
  { {0x28ac005d,0x60db42c3,0xa8570008,0xacd90016}},	//   ट्रि, _anum, _איפה_, _đươị
  { {0xd3350010,0x290001c2,0x867b000a,0x8a45000a}},	//   тэты, _klia_, _מריו, תָּ֣_
  { {0x0136002b,0x897a000a,0x6b8942c4,0x2bd2000b}},	//   رعاد, פרנצ, kseg, तिमा
  { {0x08770053,0x703a0015,0xc953015b,0x628502f2}},	//   גענט_, أساس_, אמא_, baho
  { {0x8f750191,0x040b0016,0x9e660015,0xeea7006b}},	//   туці, _lưỡn, راتن, етък_
  { {0x6da30180,0x7ec8003d,0x6b892d5d,0x3243105a}},	//   гија, _rūpē, eseg, _берг
  { {0xed570124,0xf8ca000b,0x61d7004f,0x84a9004f}},	//   ној_, ियोप, _אולף_, ֵיתִ
  { {0x4f260010,0x68ed42c5,0xbd430015,0xbf160015}},	//   _здаб, _road, دنيي, _كورب
  { {0xf3f1000a,0x3dc9002a,0x8aa60bb1,0xda7715f4}},	//   ׁ֣י_, ława_, хрид, няю_
  { {0x1317013a,0xa3d2000b,0xdd8f0021,0xdb230030}},	//   תחיל_, विड_, _هول_, óság
  { {0x040b0016,0xf1b3000a,0x62853198,0x8b660058}},	//   _cưỡn, נסר_, zaho, _كاتم
  { {0xa8a40010,0x040b0092,0x7cfc00de,0x69c142c6}},	//   ырэк, _dưỡn, _héro, awle
  { {0x7bdb0008,0x78bd00aa,0xfde4000b,0xfbd3000a}},	//   _מקדו, sesv, _कपास_, _תתס_
  { {0x752100dc,0x6d59003f,0x7af500dc,0xcb370008}},	//   élzo, _yiwa, özte, _ראוי_
  { {0x62850026,0x7cf500dc,0xf98f0115,0x9a3b000a}},	//   waho, _pári, _ابو_, _מתוק
  { {0xb905005d,0x62850089,0x5455017a,0x69240085}},	// [95b0] ना_, taho, тват, ođen
  { {0x7cf503af,0x2d8c016f,0x8c2b000a,0x5187007e}},	//   _vári, _ovde_, הֵבֵ, еуда
  { {0x4439020a,0x39490b71,0x61380125,0x7cfc0003}},	//   _wys_, _khas_, hílu, _néro
  { {0x44391ed9,0x62850264,0x0576000a,0x35e40033}},	//   _tys_, saho, _שגרם_, _сцьв
  { {0x7cfc0152,0xc10400e6,0x31580015,0x6d590375}},	//   _aéro, دوني, رجمة_, _riwa
  { {0xa3c0005d,0xc6950053,0x9f40002e,0x877c0643}},	//   ूटर_, דאַ_, áið_, לאדי
  { {0xa928002c,0x6da2006b,0xde880015,0x9f05002b}},	//   nažé, аища, رضوه_, _یورو
  { {0x92582cd4,0x7cfc0152,0x2bcd000b,0xa0c50015}},	//   _част_, _déro, ़िला, _جيرو
  { {0x6d59003f,0xcf270015,0x8e850015,0x2d8c0061}},	//   _viwa, _كرئي, _للذه, _evde_
  { {0xa3d2005d,0xe6cb005d,0x7cfc1ff3,0x9e070785}},	//   वित_, ायोज, _féro, _пчел
  { {0x7cfc01bb,0x6d593df2,0xf2d2000a,0xb307005e}},	//   _kérl, _tiwa, בעי_, ьнiс
  { {0x6b8901bc,0xa3c1000b,0xdb0000bf,0x63ad42c7}},	//   pseg, ंबा_, rtmá, ktan
  { {0x63ad42c8,0x7bc7003d,0x7cfc01ce,0x0000006a}},	//   jtan, ājus, _mérl,
  { {0xf8c700dc,0x7c240091,0xdb1b001a,0x24820091}},	//   áért_, _žirg, lvuþ, _sekm_
  { {0xdcf80046,0x63ad0f96,0x7a88004f,0x0000006a}},	//   jsvě, etan, _נָסַ,
  { {0x2cbf0176,0x63ad42c9,0xe5230004,0x291901f6}},	//   neud_, ftan, адсп, érat_
  { {0x63ad42ca,0xa3d2021e,0x2937004c,0x8937000a}},	// [95c0] gtan, विध_, _שאפן_, _ברקע_
  { {0xc7d7000a,0x479b000a,0xe2970aa1,0xd455005e}},	//   _יופי_, _קייס, кау_, утсь
  { {0x4256000d,0x3f8d0003,0xe2b50033,0x0697000a}},	//   ттат, _aveu_, ыстэ, _בדים_
  { {0xa3d2005d,0x25d7000a,0x28aa000b,0x1138002b}},	//   विद_, _סוכן_, _काफि, رتاژ_
  { {0xc6fa000a,0x8cb7000b,0x6fb40067,0x10a32394}},	//   ֽלֶך, ्जनो, امتا, ричн
  { {0xcdda0001,0xf7730008,0xdd9000e6,0xf8bf0003}},	//   дњи_, סקו_, موت_, mnée_
  { {0xe2970083,0xc6930008,0x78b60057,0xbe850015}},	//   _јас_, באו_, _obyv, اجهو
  { {0x5f960029,0x80ca000b,0xc5f3000a,0x60970015}},	//   _للرئ, _सोचे, שדה_, _لنفس_
  { {0xfd0f0074,0x9eaa0083,0xf8bf0152,0x9be6005e}},	//   تجو_, _оваа_, nnée_, тійк
  { {0x38601a87,0x69160046,0x8c4301ca,0x69240085}},	//   _agir_, ušen, шење, uđen
  { {0x29fc0023,0x6924016f,0xbae30010,0x929b000a}},	//   ủa_, rđen, рцый, ויית
  { {0xd90f0086,0x63ad42cb,0xcdf70643,0x38c9002b}},	//   تیب_, ytan, _שמאי_, راجی_
  { {0x63ad42cc,0x69161b78,0xab94005e,0x7cd70040}},	//   xtan, pšen, _силі, _جونز_
  { {0x8c4315ed,0xd7f80c1d,0xc053000a,0xdcf80046}},	//   _тече, тую_, יזר_, ysvě
  { {0xf8bf00dc,0xe758005e,0xfa33002b,0x29190003}},	//   tnéd_, тирі_, _پرود, éras_
  { {0x6924016f,0x63ad42cd,0x5a55006b,0xcdb705bd}},	//   nđel, ttan, _съчу, כפלה_
  { {0xf8bf0152,0x1707002b,0x67d5004a,0xa9280046}},	// [95d0] gnée_, _لفظی_, _сопу, sažé
  { {0x7d0240f0,0x80d8000b,0x7cfc001a,0x63ad2baa}},	//   _llos, _नोबे, _sérl, rtan
  { {0xe2980036,0x32641a11,0xf8aa000b,0x867a000a}},	//   тає_, ртув, _कामय, _ארתו
  { {0x45fa0008,0x6735002a,0x7cf50030,0x291942ce}},	//   _נהרג, lozj, _járt, nisa_
  { {0x1419000a,0x7cf542cf,0x7173002b,0x838408f0}},	//   _טוֹב, _márt, اهچا, _высе
  { {0x2cbf0026,0x57fc0008,0xa858000a,0x248942d0}},	//   weud_, ולדו, דידה_, laam_
  { {0x62190053,0x609b0029,0xbda40015,0xddb50015}},	//   _װוּק, _يخرج_, لحيو, احتب
  { {0x7d02003e,0x24890384,0xa2db000b,0x365c004c}},	//   _clos, naam_, नाक्, וכונ
  { {0x7cfc0014,0x69dc0d2b,0x28aa000b,0x23c6000b}},	//   _kérj, åren, _काबि, रौपद
  { {0x7d021238,0xc43c000a,0x3f890091,0x7dc70015}},	//   _elos, ותחי, šaus_, _لتؤك
  { {0x20100091,0x29190573,0x7cfc0030,0x7d0242d1}},	//   ėlių_, fisa_, _mérj, _flos
  { {0xc19a0053,0x5dfa004c,0x2489007c,0x7cf53b06}},	//   עשרי, _אפענ, jaam_, _cárt
  { {0xfd56004c,0x511a000a,0x776442d2,0xe8f70280}},	//   _עשני_, תֵינ, _quix, уля_
  { {0x8c1a00f3,0xa3d2000b,0xa036000a,0x9b920015}},	//   _אוני, विस_, ראשה_, _الوت
  { {0x6446002a,0xd6270c96,0x291942d3,0x29d20058}},	//   _szki, горе_, bisa_, _هيوس
  { {0x291942d4,0xc5090021,0x248900aa,0x64990a96}},	//   cisa_, نتقل_, gaam_, ктур_
  { {0xe3ba008f,0x03262103,0x6138006f,0x93aa012c}},	// [95e0] эба_, гдан, zíls, عارف_
  { {0xf8bf353c,0x877b000a,0xa2db000b,0x36c6006b}},	//   rnée_, _ראיי, नाग्, _сбог
  { {0x71650015,0x1757000a,0xaaa6000b,0xe1650015}},	//   لانك, _תסיר_, _खासक, لدني
  { {0x459b00b2,0xd59b000a,0x40960021,0x30a5005e}},	//   _אױטא, _אבטל, الشر, ирів
  { {0xd12f003b,0xb4c0005d,0x3ce7000b,0xc4d3000a}},	//   أمن_, ंजी_, झाने_, _פגש_
  { {0xa3c1005d,0xa8570008,0xc7b3000a,0x7524003d}},	//   ंबर_, אינה_, צבו_, lniz
  { {0x3ce0000b,0x2327006b,0x7d0242d5,0x6b9b42d6}},	//   काले_, _сори_, _plos, erug
  { {0x7cfc1ad7,0x3fa600e5,0x7cd8045f,0x69160046}},	//   _térm, _مصطف, тмир_, ušel
  { {0x7bcd0024,0x9f510107,0x291942d7,0x691642d8}},	//   _šaur, žbám_, visa_, ršel
  { {0x24890111,0xba0a006b,0x0ac601c5,0x34d0000b}},	//   zaam_, ехме_, ущим, हयुद
  { {0x7cf500dc,0x2bd2000b,0xe29b004c,0x6ef40144}},	//   _párt, तिहा, עשטר, _fàbr
  { {0x7cfc00dc,0x6b9b2c3c,0x7d0200f2,0x0c7a0015}},	//   _mérk, brug, _ulos, _أصاب_
  { {0x07a40033,0x7cf50030,0x2fc60034,0x57a70033}},	//   баўн, _várt, nwog_, ышна
  { {0x6d40115b,0x291916ad,0xda15009a,0x7524007f}},	//   llma, sisa_, اسیک, eniz
  { {0xdb000020,0x29190263,0x2bd2000b,0x6d40019a}},	//   rtmä, pisa_, तिवा, olma
  { {0x7524259c,0x3ce7000b,0xe4750004,0x9564006b}},	//   gniz, झाये_, рлањ, сърд
  { {0x6d400c58,0xd3710002,0xe3150054,0x60c242d9}},	// [95f0] ilma, زها_, амањ, deom
  { {0x0bb50053,0xd3470086,0x722b0a61,0x8c1b000a}},	//   יִער_, ایسه_, нцев_, גומי
  { {0x5215000d,0xf770002b,0x26c300bc,0xc2c40015}},	//   јдет, _وای_, mejo_, إيمي
  { {0xe5c40036,0x26c30fc9,0x897b004c,0x4fd51e2e}},	//   _усьо, lejo_, גראצ, ижет
  { {0x7cfc00dc,0x8e8542da,0xafe501c5,0xd92c004f}},	//   _térj, агле, ролл, עֵבָ
  { {0x539a0008,0xa3d2005d,0x26c342db,0x6da50015}},	//   _בישו, विर_, nejo_, لمتم
  { {0xf4ba002e,0x7cfc00dc,0x26dc000a,0xd6dc000a}},	//   _þýða_, _kérh, תקומ, תחול
  { {0xcdcf0054,0x5bb50151,0x5bc50015,0x6b9b222a}},	//   тњa_, асоф, لقبل, trug
  { {0x69d80005,0x60c40020,0x628700d9,0x8ea70015}},	//   _arve, õime, _kejo, _مصان
  { {0x26c3018c,0x8d870a61,0xdb000144,0x691600bc}},	//   jejo_, _будд, numè, ršem
  { {0x62870467,0x69d8016f,0x26c300bd,0xf2d20053}},	//   _mejo, _crve, dejo_, קעט_
  { {0x69de032c,0xc2360008,0x69d8016f,0x6b9b016f}},	//   _špec, ירתו_, _drve, prug
  { {0xf7460a86,0x290c0091,0x629500bc,0x69ca0676}},	//   иемо, ėda_, _odzo, _esfe
  { {0x7cf50014,0x3ced0844,0x0c24005e,0x0056000a}},	//   _társ, ljev_, _умін, ישרת_
  { {0xa5160004,0xba39004c,0x94aa0015,0x2d98146d}},	//   аќај, _בײַט, َارِ_, _året_
  { {0x88830063,0xa3d2000b,0x94260bbe,0xc1780091}},	//   _длъж, विल_, амбе, _įė_
  { {0x6b950053,0x752442dc,0xf7720115,0x7afc0061}},	// [9600] יכּף_, rniz, _باب_, örtg
  { {0xa25a0029,0x75e8005e,0xa69603ae,0x7d1b42dd}},	//   نشاء_, _блоґ_, _триј, hius
  { {0xa2a7005d,0x7cfc00dc,0x7d1b42de,0xa69b000a}},	//   _चार्, _férh, kius, _בשיפ
  { {0x42550850,0x6143004a,0x19b6004c,0x53a62b43}},	//   стут, оеха, יפער_, _камб
  { {0x7d09000c,0x437542df,0xdfd200e6,0xe3b20031}},	//   dhes, _густ, تيش_, _برج_
  { {0x9ea70124,0x98ab0050,0xc7d70008,0xe29a0080}},	//   авља_, mocą_, יוני_, _шаг_
  { {0xb23a0029,0x7cfc0152,0xce890029,0x715a0054}},	//   _شكرا_, _héri, ائهم_, _арас_
  { {0x92a60050,0x7d09052a,0xd657000a,0x69c5001a}},	//   _wyłą, ghes, סיקת_, _áhey
  { {0x4ae60010,0x6d403ce2,0x63a442e0,0x515b000a}},	//   аўна, rlma, nuin, _יכלו
  { {0x2d9c0089,0x7cfc1fec,0xff24002b,0x69d833b9}},	//   prve_, _méri, _ابری, _prve
  { {0xf2d900b2,0x6ce60010,0xda340010,0x79a3033d}},	//   אַרל, _віле, сены, оряе
  { {0x5dfb0053,0x8dfb0008,0x1dd3000b,0x6d8b000a}},	//   _שפאנ, _שהאת, थिरत, _יָדְ
  { {0x31570053,0x39450024,0x8c4322a7,0xe6670fbd}},	//   ייטן_, ēls_, _деце, итво
  { {0x7cfc002e,0x63a442e1,0xabfb000a,0x3ad30015}},	//   _sérh, duin, _בהדר, _وينز
  { {0x26d10050,0xbb390053,0x7cfc0152,0xfa77000a}},	//   rdzo_, _געװי, _aéri, _דעות_
  { {0x3f8f0026,0x63a4024b,0x26c342e2,0xda5b000a}},	//   ysgu_, fuin, sejo_, _בכול
  { {0x3ce7005d,0x63a442e3,0xf2670054,0x26c342e4}},	// [9610] झाते_, guin, ађем, pejo_
  { {0x6e2d01e2,0x883c0008,0x7cfc0152,0xc7b200f3}},	//   şabi, _בתחו, _déri, _צבי_
  { {0x75d503c4,0x321900c3,0x7cfc0030,0xd25b0088}},	//   _ايجا, دياد_, _térh, тца_
  { {0xa0690054,0x7cfc3727,0x63a442e5,0x0000006a}},	//   ћала_, _féri, buin,
  { {0x7f19042b,0x28ac000b,0x63a40045,0x80270015}},	//   ліку_, ट्टि, cuin, جرام
  { {0x69160089,0x60080484,0x4177002b,0xa3f6000a}},	//   ašeh, шнім_, _نارس, _המשק_
  { {0x9294023e,0xcee80015,0x3ced0085,0x3cff007c}},	//   _фасц, شرون_, tjev_, tkuv_
  { {0x7d0902f2,0xf1b2000a,0x51842cb0,0x5ba900f4}},	//   uhes, _מסל_, _фура, гким_
  { {0x3ced018c,0xe4a8000a,0x7d1b42e6,0x3ec7005e}},	//   rjev_, בֹתָ, rius, _всеб
  { {0x5f450029,0xfe700115,0xfaa5023e,0x6a94005e}},	//   _انطل, _قدم_, љано, орює
  { {0x5dd50029,0x7d091491,0x63a442e7,0x0000006a}},	//   _دقائ, phes, zuin,
  { {0x0000006a,0x0000006a,0x0000006a,0x0000006a}},	//     ,   ,   ,
  { {0xeb9903e7,0xc052000a,0x50da004c,0xdb0b02de}},	//   _сил_, ּ֖ר_, אקרא, _opgø
  { {0xa3c1021e,0xda7b034e,0x68430015,0x63a442e8}},	//   ंबई_, _ряд_, سَّل, vuin
  { {0x7ae306f5,0x7afc42e9,0x7cfc42ea,0xe8d90016}},	//   _innt, örte, _séri, _giỏ_
  { {0x7cfc038d,0x99360029,0x6efd0251,0x63a442eb}},	//   _péri, _دفعت, _dèbi, tuin
  { {0x044a42ec,0xc953000a,0x21260160,0x0000006a}},	// [9620] упак_, _צמח_, vnoh_,
  { {0x7cfc038d,0x7c2e00b8,0x63a442ed,0x2902008c}},	//   _véri, ßbri, ruin, lkka_
  { {0xa75b0008,0x68f60064,0x28dd000b,0x2902008c}},	//   _תדיר, _koyd, याचि, okka_
  { {0x9479005e,0xd1390033,0x290201be,0xa3d20065}},	//   _всру_, ахі_, nkka_, विआ_
  { {0x29020604,0x8fa30286,0x1fb60a61,0x493b000a}},	//   ikka_, заче, ссер, נגנו
  { {0xb0330036,0x7bc90034,0xa3bd000b,0x5f93012e}},	//   чніш, dweu, _आहत_, чишт
  { {0x867b000a,0x0178000a,0x2175006b,0xad660015}},	//   ארצו, _כָּל, _мутр, حاته
  { {0xd1970008,0xbb740292,0x3fc8002b,0x0caa0342}},	//   _לכלי_, огиј, _پدری_, утки_
  { {0x30060036,0xc4d30008,0xa4fb000a,0xcfaa0021}},	//   _узаг, לגה_, טלקט, _حازم_
  { {0x539b004c,0x78ad0a45,0x68e442ee,0x7b730058}},	//   װיטו, _scav, _anid, أطيا
  { {0xdd920086,0x44270092,0x69cf005c,0x8db50033}},	//   _روش_, ̃n_, łcen, _мсці
  { {0x8c18002b,0xfd450033,0xe10b000a,0xd8430046}},	//   _پيتر_, _дэін, ָּטָ, _ničí_
  { {0x07a40010,0x383502a3,0x28aa0065,0x0000006a}},	//   паўн, інгр, _कारि,
  { {0x98be0024,0x28d9000b,0x2902001a,0x68e40f0a}},	//   ētā_, _बोरि, akka_, _enid
  { {0x95c50015,0x8aa5005e,0x4efb000a,0x5a9b000a}},	//   غيره, _фрід, נהלו, _עשהא
  { {0x44b50033,0xdcf801ec,0x0000006a,0x0000006a}},	//   ўбас, msvē,   ,
  { {0x36d51cf5,0x49180008,0x2bdb000b,0xdb090125}},	// [9630] _допр, _לקהל_, बिया, lteá
  { {0x44270092,0x8c410012,0x3267105a,0x76ab1068}},	//   ăn_, ößig, став, _стив_
  { {0x2bcf005d,0x611505d1,0xdb09002d,0x24802c1f}},	//   _तैना, оджу, nteá, bbim_
  { {0xdb09002f,0xda4b000a,0x753d002a,0x808b0015}},	//   iteá, אֲדָ, _uksz, اضاف_
  { {0xcf9b0124,0x60c40020,0x7cfc0152,0xff51002b}},	//   ује_, õima, _jéru, وخت_
  { {0x13ba0053,0xc43a000a,0xd2f6002b,0xdb090061}},	//   _דזשע, _כתרי, _وکلا_, önün
  { {0xace92246,0xd57b000a,0x28aa000b,0x61fe0535}},	//   имка_, אָ֖ר, _कालि, cypl
  { {0x28d9005d,0xc10500c3,0x8b954266,0x6916400f}},	//   _बोलि, _بوري, ороч, lšev
  { {0x5f740029,0xf8bf0030,0xfaa502db,0x0000006a}},	//   _فالر, tnén_, оапо,
  { {0x3dd2002a,0x2909008c,0x7f581886,0x68e442ef}},	//   ływa_, _alaa_, _гаус_, _snid
  { {0x0000006a,0x0000006a,0x0000006a,0x0000006a}},	//     ,   ,   ,
  { {0x7cfc113b,0x71d6000a,0xbd450058,0x2902005b}},	//   _sérv, קורד_, _بنصي, ukka_
  { {0x3c470225,0x290200f2,0xf8bf0030,0x61fe0535}},	//   _اضاف, rkka_, mnél_, zypl
  { {0x2bcf005d,0x7ae3003c,0xcc56000a,0xead4004a}},	//   _तैया, _unnt, _ובני_, _ночь
  { {0x9604005d,0x9663130e,0xa3cf000b,0x89360021}},	//   रनेट_, дкре, _वैब_, _وعبا
  { {0x681c0024,0x68e442f0,0xf8bf0030,0xd4670cab}},	//   tādī, _unid, nnél_, жите_
  { {0xd7ef003b,0x24800045,0xf8bf0030,0x3178002a}},	// [9640] _لكي_, rbim_, inél_, _strz_
  { {0x681c03eb,0x05760067,0x6b4f02de,0xc8aa000b}},	//   rādī, _واجد, bøge, _काँट
  { {0x7c2d0084,0xf8bf00dc,0x7cfc0030,0x673c42f1}},	//   _þarf, knél_, _kért, morj
  { {0xb9ac0053,0x11390033,0x0000006a,0x0000006a}},	//   רבאָ, бячы_,   ,
  { {0x7cfc00dc,0xa3ce000b,0x5f73002b,0x6749001a}},	//   _mért, _शनि_, واور, _ásjó
  { {0xb7db0008,0x644b007c,0xd00f012c,0xdd9a159d}},	//   יקני, ügie, خله_, аши_
  { {0xbd670080,0xa3d2005d,0x4c9409ef,0xd9a8000b}},	//   орые_, विक_, пийс, _कमेट
  { {0x61e10014,0x3ea042f2,0xe6280092,0x80e60015}},	//   _álla, şit_, _đồ_, _بأسل
  { {0x2f0b00fb,0x63b642f3,0x46ca000b,0x8c430054}},	//   _søge_, ntyn, ाजाह, меће
  { {0x39400091,0xfbcf0015,0xb3d80033,0x1b180033}},	//   _akis_, ئتي_, рмiр, ёжны_
  { {0x32db000a,0x63b6008c,0xbe160015,0x673c00bc}},	//   בחינ, htyn, _بوضع, dorj
  { {0x88b10074,0x26f5000b,0x6be60015,0x63b60c00}},	//   ریخچ, ीघ्र_, _وكام, ktyn
  { {0xc8640191,0xc1b7000b,0x6c36002b,0xdb090125}},	//   дтри, _इङ्ग, _بفشا, steá
  { {0x600b000a,0xf8bf0046,0xdcf8003d,0x673c42f4}},	//   בִלְ, mném_, psvē, gorj
  { {0xf8bf0089,0x2bd2000b,0x5d78000a,0xcd78000a}},	//   lném_, तिका, מָּנ, מְּכ
  { {0x92a90050,0x6b4f0134,0x27e60091,0x337542f5}},	//   kułó, røge, _šone_, згар
  { {0x6b4f00fb,0x026b0080,0xc29908fc,0xf8bf117d}},	// [9650] søge, ашей_, йках_, nném_
  { {0x32b80029,0x5b7b0053,0x7334002b,0x92a9002a}},	//   قدمة_, ירמא, ورلئ, dułó
  { {0xc1b9006b,0x69240085,0x691607c4,0x307504bb}},	//   слех_, rđev, ršev, пулс
  { {0x55da0053,0x657a00dc,0x3cda000b,0x7bc20046}},	//   _פֿינ, íthe, _खोले_, _opou
  { {0xf8bf0089,0xc8dc004c,0x3f69030c,0xdee50d3c}},	//   jném_, יקאט, щило_, золи
  { {0xef180036,0xf8bf0089,0xfe710015,0x644f3835}},	//   омі_, dném_, ردت_, _izci
  { {0xf8bf00dc,0xb6bc000a,0x69240160,0x0000006a}},	//   tnél_, יצגי, ođet,
  { {0x7d760029,0x673c07c4,0x3869001a,0x200e001a}},	//   أمير_, zorj, _ngar_, íkið_
  { {0xe0d200b2,0x764500f2,0xe49f0024,0x39520335}},	//   _אײן_, _lyhy, dēļā, _rhys_
  { {0x3869013c,0x7cfc1dc0,0xf8bf0030,0x7de70015}},	//   _agar_, _sért, snél_, _وسام
  { {0x752f005c,0x7af8006f,0x7afc0123,0xa155000a}},	//   _ojcz, _dovt, örta, ּבָה_
  { {0x63b600f2,0xf8bf0046,0x5d640015,0x2fdf42f6}},	//   ytyn, bném_, _قُلْ, _krug_
  { {0x673c018c,0xe7d50036,0x7d0b003d,0xf8bf0046}},	//   torj, мірю, _ilgs, cném_
  { {0xa3cf005d,0x2a350010,0x4e1f005d,0x4b7a000a}},	//   _वैध_, _нэйр, _बधाई_, _האסו
  { {0xec2d0024,0x386d06d5,0x954a0015,0xd54a0015}},	//   šķām_, žera_, مشرق_, مجرم_
  { {0x141a0029,0x63b600f2,0xa99a0008,0x673c00bd}},	//   ميزة_, ttyn, _הבקר, sorj
  { {0x644f005c,0xf42a002c,0x130a0010,0xdb000046}},	// [9660] _czci, _opäť_, бнай_, zumí
  { {0x4346006b,0x7bdb008c,0x9343004a,0x9694002b}},	//   чезв, ivuu, енуе, _زیرش
  { {0xd6fb000a,0x39650061,0x7bdb008c,0x02190033}},	//   _הפיכ, _üssü_, hvuu, оіць_
  { {0x2fdf00fb,0x26ca032c,0xa99a0053,0x92a9005c}},	//   _brug_, lebo_, מבער, tułó
  { {0x09a8005d,0x61e100dc,0x2cad42f7,0x60560015}},	//   _कम्य, _álln, dged_, أنشط
  { {0xf67a00b2,0x69c30111,0x290b0024,0xf8bf0089}},	//   זאַמ, _opne, ībai_, vném_
  { {0x6566003f,0x7bc23cd8,0x2fdf0234,0x629c42f8}},	//   _kikh, _spou, _erug_, _idro
  { {0xc19b0008,0x2cad0556,0x6e030015,0xf8bf2cac}},	//   _לשלי, gged_, عِين, tném_
  { {0x7cfc0084,0xcb67023e,0x628e0049,0x0aea0015}},	//   _sérs, пање_, _kebo, مردي_
  { {0x9998000d,0xf8bf0046,0x656642f9,0x7d0b0091}},	//   окот_, rném_, _likh, _elgs
  { {0x64460084,0x02b70008,0x19590010,0x7bdb00f2}},	//   _lyki, הליך_, жаны_, avuu
  { {0x63a442fa,0x68e9003d,0x628e42fb,0x27e042fc}},	//   krin, ķedo, _lebo, _brin_
  { {0x6916002c,0x63a40134,0xc6e7005e,0x7c5a0015}},	//   všet, jrin, півп, _الشر_
  { {0x7cfc00dc,0x27e0232a,0x628e42fd,0xf8bf0003}},	//   _térs, _drin_, _nebo, diée_
  { {0x3abb0008,0x7abb0008,0xd49b0afb,0xaabb000a}},	//   _המונ, _הצוו, йра_, _הזוכ
  { {0x629c0176,0xca470070,0xf8bf0152,0x63a422d0}},	//   _adro, _عليه_, fiée_, frin
  { {0x889c0008,0x24580080,0xdb0000dc,0x63a442fe}},	// [9670] _הבחי, зать_, ermé, grin
  { {0xd25b0080,0x628e16ee,0x26ca42ff,0x78bd02ad}},	//   бце_, _cebo, cebo_, lfsv
  { {0x3f800011,0x69160089,0x63a4043a,0x76ba000a}},	//   ţiul_, pšet, arin, _ומתפ
  { {0xf42a002c,0xf8bf0030,0x63a44300,0xe7b10065}},	//   _späť_, dnék_, brin, _जमाप
  { {0xf8bf0152,0x3fc90086,0x63a40fbf,0x752d4301}},	//   ciée_, تدای_, crin, mnaz
  { {0x8d750029,0x61e100dc,0x59cc000b,0x5f04005e}},	//   وابا, _állo, ़बार, нзіа
  { {0x752d04ed,0x30a70457,0xc332000a,0x0dc9005e}},	//   onaz, _нрав, _סול_, ілий_
  { {0x2fdf00b8,0x8d540010,0xa3d2000b,0xd0d4006b}},	//   _trug_, нтыч, विच_, _посъ
  { {0x752d003f,0x2cad108f,0x69dc079b,0xfb24002b}},	//   inaz, rged_, æren, کريپ
  { {0x78bd0084,0x1a050063,0x7c26001a,0xdcee003d}},	//   efsv, дпом, úkra, ādām
  { {0x6ce7005e,0x78bd0012,0x98a60302,0x7bdb005b}},	//   _ніде, ffsv, мине, svuu
  { {0x27e004f9,0xec6e000d,0x63a44302,0x6e3a000a}},	//   _prin_, _јп_, yrin, _ותעד
  { {0xcaf50015,0x87fa0033,0xeaae0121,0xac760015}},	//   _يستب, цэнт_, _ий_, _غموض_
  { {0x6d49311d,0xdb2300f2,0xf7190010,0x9a690015}},	//   llea, äräi, пісы_, _بمثل_
  { {0xe64304e0,0x15460004,0x628e4303,0xca7a004f}},	//   верп, девм, _rebo, _ונצט
  { {0x27e04304,0x752d04ed,0x6d49002d,0x63a44305}},	//   _trin_, gnaz, nlea, trin
  { {0xdb00002e,0x6d49002d,0x59d5005d,0xc9530008}},	// [9680] lumá, ilea, धिकर, _במה_
  { {0x752d003f,0x8979000a,0x67560015,0xf8bf0003}},	//   anaz, ַרְצ, _تخبر, riée_
  { {0xd00f002b,0x63a44306,0x5b3a004c,0x6d494307}},	//   یلم_, srin, קגעק, klea
  { {0xc5f30b7b,0x8fa6017a,0x63a44308,0x628e4309}},	//   _סדר_, даде, prin, _webo
  { {0xc057005e,0x4fb3006e,0x628e430a,0xb4ca0065}},	//   міш_, نصور, _tebo, लजी_
  { {0xf8bf00dc,0x877b004c,0x0efa000b,0x6d49430b}},	//   tnék_, קאצי, ्सेस_, elea
  { {0x82d7000a,0x90a60015,0xdee30054,0x672e001a}},	//   _קולג_, _يحرم, тоји, inbj
  { {0x621b000a,0xe8e00016,0xf8bf0030,0xed570099}},	//   _וולק, _trội_, rnék_, мој_
  { {0xaf2a0afb,0xefb3002b,0xe0431764,0x28d90065}},	//   _джаз_, _لینگ, _анти, _बोगि
  { {0xadba003b,0xe45700b2,0x6ffb000a,0x5ffb000a}},	//   _وهذا_, ויפט_, _והמפ, _והמה
  { {0xf2d301e4,0xdb00002e,0x6d491a8b,0x1bec000b}},	//   דעת_, gumá, blea, जमहल_
  { {0xd90f002b,0xc237004c,0xcb6a09dd,0xf1d1000b}},	//   شیخ_, םאיז_, _даде_, _सनसन
  { {0xac970074,0xbd5b000a,0x8d5b004f,0xdfc60058}},	//   _آنها_, _וכאש, _וכאי, دي_
  { {0xdc020046,0x6d40430c,0xdb000030,0x0000006a}},	//   nčíc, loma, bumá,
  { {0x6d4005ff,0xdb000533,0x752d02ad,0x0000006a}},	//   ooma, cumá, tnaz,
  { {0x57b50036,0x657a00dc,0x66f80064,0x63690091}},	//   _збит, ítha, _aşkı, _ažna
  { {0x752d04ed,0xf66b0029,0x73f80015,0xc3550054}},	// [9690] rnaz, _وحده_, وِّر_, екај
  { {0xa227002b,0xf2c50015,0x6d40430d,0x60cb0546}},	//   وراه, عْضُ, homa, wegm
  { {0xda0e005d,0xa7380015,0x23ab000b,0x224702de}},	//   ानित_, _تثير_, _चमकद, ænk_
  { {0x5576004c,0x798d002a,0x6d40430e,0x3519004f}},	//   _רערן_, _ławk, joma, _זוֹנ
  { {0x547a0008,0x6d40430f,0x28c1000b,0x25750123}},	//   _מטרו, doma, ष्यि, _hål_
  { {0x63ad0509,0xa5c50030,0x60cb4310,0x7afc15c8}},	//   muan, cióé, segm, örtl
  { {0x6d49002d,0x20090f28,0x63ad0375,0xc1050015}},	//   tlea, šai_, luan, _كوسي
  { {0xc537000a,0x2575230f,0xdfd508f0,0x6d494311}},	//   וָ֖ה_, _mål_, _побы, ulea
  { {0x6d494312,0x6d5b0375,0x317101c2,0xbab50033}},	//   rlea, rmua, _huzz_, нёны
  { {0xfaf1003b,0xa3e0005d,0xdb0030e6,0x6dc70015}},	//   اثة_, थित_, tumá, _يزال
  { {0x7db40015,0x6d494313,0x6d401e8a,0xf8bf1e61}},	//   _لصنا, plea, boma, ffé_
  { {0xdb0903af,0x6d400609,0x63ad3591,0xa3c1000b}},	//   nteú, coma, kuan, ूबा_
  { {0x6fe2000b,0xc7960033,0x63ad11b1,0x3b8402a3}},	//   पियं, эрны, juan, _аліг
  { {0x9ad50015,0x16660015,0x63ad4314,0x6a64002b}},	//   _ستتض, ّارَ, duan, عطیل
  { {0x7d090007,0x75560054,0x644b007c,0x63ad2ebe}},	//   okes, ењац, ügin, euan
  { {0x1da7000b,0x7c2406c0,0x7d094315,0x0000006a}},	//   _गिनत, _žiri, nkes,
  { {0x61e10030,0x130a0033,0x03a30a13,0x63ad4316}},	// [96a0] _állj, пнай_, лито, guan
  { {0xdbc60005,0x0686008f,0x77bb000a,0xe3b70033}},	//   _tööa, _ягон, _צמיח, эбу_
  { {0xd8da0008,0x7d094317,0x39424318,0xf8da000a}},	//   ּקְר, kkes, ooks_, ּחְמ
  { {0x26da000c,0x660100f2,0x397a0053,0xc329000a}},	//   _hapo_, älke, לטענ, זו_
  { {0xc6fa0008,0x43750001,0xe7e3000b,0xa1130015}},	//   ּלֶך, _ауст, खिया_, دونت
  { {0x7d09003f,0x479b000a,0x6d4000da,0xd6d3000a}},	//   ekes, לינס, woma, ָׂה_
  { {0x27420089,0x26da00bd,0x2d9a2cac,0xbe970015}},	//   méně_, _mapo_, épe_, رضوا_
  { {0x55db00b2,0x91bb0008,0xc5f30008,0x6d4000f2}},	//   פֿונ, _ממלי, רדה_, uoma
  { {0x5ce30080,0xa157000a,0x8fa60015,0x39424319}},	//   ующа, _טבלה_, _سماه, doks_
  { {0x6b4f00fb,0x2d6e0089,0x8f9b0008,0x600b000a}},	//   søgn, _před_, _מימי, _מִבְ
  { {0xddc8005c,0x6d40431a,0xc213004c,0x4c860033}},	//   _wzdł, poma, ָהר_, _злев
  { {0x69b1014e,0x8d77000a,0xcdf7000a,0x386d0723}},	//   _अमरी, _נגדו_, _רמאי_, øer_
  { {0xa2c1005d,0xf8bf3445,0xfca9006e,0xb8d90065}},	//   र्ड्, rfé_, _زانو_, _चा_
  { {0x26da04ed,0x3942007c,0x6b4f02de,0xe6670354}},	//   _capo_, aoks_, nøgl, етбо
  { {0x692b0089,0x394232be,0xf8bf0030,0x95c8011a}},	//   třed, boks_, dnév_, нута_
  { {0x290b0048,0xa4d40036,0x04c90029,0x799a002a}},	//   ības_, лосі, بوري_, mstw
  { {0x8d5b0008,0x799a002a,0x4374005e,0x94740040}},	// [96b0] לכלי, lstw, гуєт, ادفا
  { {0x5c37000a,0x63ad0f36,0xd25b1923,0x798d002a}},	//   תרמן_, ruan, пце_, _ławi
  { {0x692b0089,0x31c70010,0x41e40210,0x02d1000b}},	//   před, эсав, ліца, _हसीन
  { {0xa98b000a,0xdb00014b,0xc60d000b,0x659a000a}},	//   לָדִ, lumä, सनीय_, _קירק
  { {0x389c00f3,0x2489431b,0x63ad431c,0xdb0001c0}},	//   ליאנ, mbam_, quan, ermí
  { {0xf77400b2,0x2489002d,0x6da529f7,0xf3ff0016}},	//   אקס_, lbam_, вика, _ngãi_
  { {0x7d090209,0xd62c000a,0xdd910021,0xd3780085}},	//   tkes, ּ֥וֹ, جوع_, _čći_
  { {0x692b0046,0xa4bb000a,0xdb00007c,0xe572004f}},	//   hřeb, לֶ֖י, humä, בַז_
  { {0xdb000604,0x7d090c0a,0x8fb90015,0xeea90015}},	//   kumä, rkes, _زهاء_, _يُرى_
  { {0xf8aa014e,0x49b90015,0xda61005e,0x68ed431d}},	//   कल्प, واجد_, ичнi_, _anad
  { {0xc27a0008,0x799a0079,0x60db2069,0x7cd6002b}},	//   ורתי, gstw, _kaum, رویز_
  { {0x60db26da,0xdb26002b,0x9c870015,0x8d76000a}},	//   _jaum, _یونی, _أشاه, _סגנו_
  { {0x644b0020,0x9d1a0008,0x88360010,0x7d0600f2}},	//   ügil, _קונט, тэнц, ökse
  { {0xfaa50f2c,0x799a002a,0xa3e5000b,0x0b780015}},	//   _рако, bstw, पटन_, _أصنع_
  { {0xceb201c8,0xcb12000a,0x61e10030,0xd62a14c2}},	//   יים_, _דלג_, _állh, фове_
  { {0x68ed00b8,0x26da003f,0xe1f2002b,0x25a50030}},	//   _gnad, _wapo_, یسا_, álla_
  { {0x26da3cb3,0x036a01b7,0xf8bf0030,0xb46636d4}},	// [96c0] _tapo_, диак_, tnév_, ткал
  { {0x7d1e00dc,0x2900007c,0x68ed0085,0xb797000a}},	//   épsz, _hoia_, _znad, _שכיח_
  { {0x60db27fd,0x68ed0034,0x212616c2,0x0000006a}},	//   _baum, _ynad, tioh_,
  { {0x60660086,0xdcfe0024,0x6b9b0020,0x3239002b}},	//   نهال, īvīb, ksug, رينگ_
  { {0x08770053,0xa0670001,0xdefa056d,0x2fd30015}},	//   דענט_, ваца_, дый_, لتوح
  { {0xa3c1014e,0x799a005c,0x3cda000b,0xde58042b}},	//   ूबर_, ystw, _खोजे_, налі_
  { {0x5db30015,0x30860015,0x7db30015,0xa3e0000b}},	//   لإير, _للأف, لصيا, थिव_
  { {0x6d590176,0x9ce30033,0x60db431e,0x2900431f}},	//   _chwa, ацьл, _gaum, _noia_
  { {0xe873002b,0x50460c71,0xe4ab000a,0x799a3738}},	//   یندگ, _реаб, וֹיָ, wstw
  { {0x6d5900d9,0x68ed1e80,0x501b000a,0x6f66002b}},	//   _ehwa, _snad, _חומו, _شهام
  { {0x7c2d001a,0xe8950174,0x3f86016e,0xdb000bb5}},	//   _þarn, лань, lpou_, vumä
  { {0x799a005c,0xe8e00092,0x6e170015,0x5d75004a}},	//   rstw, _trời_, _جيمس_, _суфф
  { {0x692b0089,0xf8bf02c1,0xb809002b,0xc7f8005e}},	//   třeb, bién_, ريسم_, вняє_
  { {0x19ba0015,0xf8bf0077,0x644b007c,0x5b1300fd}},	//   _قطعة_, cién_, ügim, _кміт
  { {0xf6280036,0xdb0000c0,0x442d0045,0x5b57000a}},	//   віти_, rumä, _ţe_, _ששון_
  { {0xfe37000a,0x69d80061,0xdb00014b,0xe5340033}},	//   דרלי_, _isve, sumä, аесь
  { {0x545506fe,0xa938000a,0x8335006b,0x60db4320}},	// [96d0] уват, _שטחה_, гнах, _raum
  { {0xe3b00029,0x36d50080,0x179c000a,0x722b004a}},	//   ترف_, _соор, _חיזב, мцев_
  { {0x60db00b6,0x41740115,0xb807002b,0x7c36001a}},	//   _paum, لانس, _سبکه, _þyrf
  { {0x26d1000c,0x301509ac,0xf8bf0003,0xd479004c}},	//   lezo_, лдер, mnés_, _ראָל
  { {0xe8d900a7,0x443f0023,0x251a0008,0xd91c0053}},	//   _chỉ_, _âu_, _נושא, וואל
  { {0x69ca00b8,0x26d1003f,0xa3e0000b,0x141a000a}},	//   _opfe, nezo_, थिर_, _טורב
  { {0x2d940010,0xddda00dc,0xf8bf0152,0x29120091}},	//   арыс, _betű, nnés_, ūzai_
  { {0x3ea90011,0x26d1003f,0x92580180,0xd658000a}},	//   şat_, hezo_, _раст_, כיות_
  { {0x26d1000c,0xdc3101e2,0xfc050080,0x0b450004}},	//   kezo_, _düğm, уппо, лнин
  { {0xcf8e002b,0x692b0046,0x0f550015,0x6b820125}},	//   _رژه_, yřec, _صَاح, _dtog
  { {0x6b9b0020,0xa2ca000b,0x6f010034,0x6d5922d3}},	//   ssug, _सॉफ्, _iolc, _thwa
  { {0xc236000a,0xcd2b0015,0xdb1b0003,0x61f80c9e}},	//   טרתו_, _غسان_, itué, ävli
  { {0x60d60008,0x29000045,0x6f014321,0x69d84322}},	//   נושא_, _voia_, _kolc, _esve
  { {0x6295099c,0x9056000a,0xf7560058,0xe4da009a}},	//   _nezo, טברו_, انسج, کورت_
  { {0xf8bf0152,0x64a64323,0x6fd5000b,0x0000006a}},	//   gnés_, лава, _मैसू,
  { {0xa2c1000b,0xf484002b,0x98a2002a,0x2d5a0034}},	//   र्स्, شاری, ynkę_, rëeg_
  { {0x62953074,0xdce1003d,0xe7d5009a,0x0000006a}},	// [96e0] _bezo, _atlī, _نميگ,
  { {0x070a0029,0xdb004324,0xb4630763,0x77f7004f}},	//   _أيدي_, stmö, скул, _עמיד_
  { {0xd24f003b,0x8ffa002b,0xc0e600eb,0x42561161}},	//   كنك_, کرار_, ложк, утат
  { {0x19b60053,0xc0960015,0xe8d90016,0x0000006a}},	//   טפער_, اجات, _phỉ_,
  { {0x316d02c1,0x889b000a,0x351b000a,0x10a310cf}},	//   _diez_, תבני, _טוטנ, сичн
  { {0xa857013a,0x6ebf005d,0x62950ec2,0xc7d7000a}},	//   ניסה_, ल्लु, _gezo, טוני_
  { {0xdb1b0152,0x3da70029,0x6b8228b4,0xdcfa0024}},	//   ctué, هُوَ_, _stog, _attā
  { {0xd1320002,0x5d54000d,0x5c740a32,0x78a4233a}},	//   _امر_, јкит, шлит, _ndiv
  { {0x1016008f,0xa2c1000b,0x60c4007c,0xdb090079}},	//   _сьвя, र्व्, õimu, creë
  { {0xd5d4000b,0x2d960054,0x6f010034,0x03d7000a}},	//   दबाज, _брдс, _golc, נוים_
  { {0x22f7000a,0x26d100bc,0x9983002b,0x02c60065}},	//   אזין_, vezo_, یلیو, र्यभ
  { {0x644b0020,0x26d1003f,0x28150058,0xec774325}},	//   ügik, wezo_, لوجس, _бпц_
  { {0xe8d90023,0xdb00002d,0x6f010064,0x8157004c}},	//   _giờ_, armá, _yolc, טסטע_
  { {0x8c1b0008,0x3dd2005c,0x7d02082f,0x0000006a}},	//   _אודי, ływu_, _hoos,
  { {0x7d02041c,0x65951c64,0x05d5000b,0xda07002b}},	//   _koos, рабу, _डैशब, _ميوه_
  { {0x9983003b,0xa7750142,0x23e0000b,0xf8bf0f24}},	//   _اليو, _клич, निंद, rnés_
  { {0xd839000d,0x893400e6,0xdb00007c,0x241808f0}},	// [96f0] _шпиц_, _دعوا, stmõ, готы_
  { {0x7d024326,0x98a2003d,0x7bc04327,0x27e94328}},	//   _loos, mikā_, itmu, _iran_
  { {0xe8d90092,0x9475002b,0x62954329,0x3f520045}},	//   _nhị_, _نگذا, _vezo, râul_
  { {0x6f01018b,0x19b70053,0xd14b0086,0xd01100a2}},	//   _solc, רפאר_, رشان_, يلا_
  { {0xc49a000a,0xa0690054,0x35ab000b,0xb938000a}},	//   _בשרת, њала_, _छिड़, ננדו_
  { {0xaec40191,0x656f000c,0xa2c1005d,0xa77c004c}},	//   йбіл, _hich, र्श्, ערופ
  { {0x656f3712,0x41e4078f,0xe8d90092,0x7d022903}},	//   _kich, _літа, _chị_, _boos
  { {0xdb0900aa,0x656f077d,0x27e9432a,0x63ad432b}},	//   preë, _jich, _oran_, oran
  { {0x9ed9010f,0x656f1864,0x644b007c,0xdb090030}},	//   _имат_, _mich, ügih, lreé
  { {0x63ad432c,0x656f432d,0x4b250839,0x1605000b}},	//   iran, _lich, рмов, रहार_
  { {0x63ad053e,0x4cb901f3,0x69de0069,0x27e9432e}},	//   hran, _алею_, _šper, _aran_
  { {0x656f0bcf,0x3e550092,0x3dfa000a,0x5d7a004c}},	//   _nich, _ít_, _בלעד, _סאנק
  { {0x6d4b003d,0x63ad3817,0x2fcd432f,0xe4e90065}},	//   _ikga, jran, _jpeg_, _ऑफ़ि_
  { {0xcb3900b2,0x8c1a000a,0x09e50033,0x98630015}},	//   _שײַכ, _בוני, _вокн, زُّه
  { {0x98a20024,0x27e94330,0xf496006d,0x26de006f}},	//   aikā_, _eran_, ираю, ľto_
  { {0x7de00014,0x2a3a0008,0x656f005c,0x26de4331}},	//   lásá, _בעצמ, _cich, žto_
  { {0xb6020089,0x27e94332,0x63ad4333,0x656f4334}},	// [9700] _řádn, _gran_, gran, _dich
  { {0xa2c1000b,0xa79b000a,0x7de00030,0x656f4335}},	//   र्ल्, _ששיח, násá, _eich
  { {0x656f4336,0x69c14337,0x63ad4338,0x7cfc0030}},	//   _fich, ntle, aran, _vérz
  { {0x2ba6014e,0xe1650029,0x759b0008,0x3fe6009c}},	//   _खिला, مدني, _ביטח, ижев
  { {0x69c10020,0xb87b0077,0x7de00030,0x2246002a}},	//   htle, ndía, kásá, łok_
  { {0x656f0111,0xa3cf005d,0xa8570008,0xfda60001}},	//   _zich, _वैट_, בינה_, ајим
  { {0x7de00014,0x692b0089,0xdd970033,0x60c4007c}},	//   dásá, dřen, ашы_, õims
  { {0x9cca008f,0x5bb803fc,0x1da7000b,0xc536000a}},	//   тыка_, глия_, _गिरत, יָ֥ה_
  { {0x69c10050,0x2b77002b,0xa0670ffe,0x00830515}},	//   etle, لینگ_, _вата_, _флуо
  { {0xe8d90023,0xada60036,0xdb23002e,0x31782cd8}},	//   _thị_, _важл, ærði, _kurz_
  { {0xbca60074,0x257c002f,0xe29b000a,0xfe42002b}},	//   _نماي, _níl_, כשיר, _بکشی
  { {0xfc66006b,0x98a2003d,0xe7e3000b,0x63ad4339}},	//   _кълн, tikā_, खिला_, yran
  { {0x656f153a,0x7de00030,0x57b4006b,0x7bdc003d}},	//   _rich, básá, обят, ārus
  { {0x656f018b,0x69c100da,0x6564007c,0x257c001a}},	//   _sich, btle, emih, _bíl_
  { {0x656f0f4d,0x7afc002e,0x257c0089,0xf6e40010}},	//   _pich, örtu, _cíl_, ццян
  { {0xf9930008,0x7969005c,0x257c0046,0x63ad1a5f}},	//   _ורק_, _oświ, _díl_, tran
  { {0x656f000c,0xd37100e5,0xdc8b000a,0x9cd7000a}},	// [9710] _vich, سها_, דְבָ, סומה_
  { {0x656f09f8,0xb9da000b,0x8c1b000a,0x59da000b}},	//   _wich, _बनाऐ, דומי, _बनार
  { {0x644f005c,0x81a70086,0xc692000f,0xd2510015}},	//   _wyci, شحال, _מאי_, أنا_
  { {0x7de00014,0x692b0046,0x8f75005e,0x63ad433a}},	//   zásá, zřen, букі, pran
  { {0xd8ba0053,0x80a8005e,0x6b5d0003,0xe8d90016}},	//   טצײכ, рвів_, lège, _nhọ_
  { {0x2d950124,0x11670086,0x27d8000a,0x4f24005e}},	//   брис, _چلسی_, שֵׁם_, одіб
  { {0x692b0089,0x7de000dc,0xdb090020,0xf2d2000a}},	//   vřen, vásá, rteü, _מעם_
  { {0xdb090020,0x86380008,0x5bc50029,0x1638000a}},	//   steü, ירוב_, مقبل, ינור_
  { {0x7de00014,0x2ca60176,0x692b0089,0xfbd10015}},	//   tásá, _ddod_, třen, ستة_
  { {0xe9d9034e,0x69c1433b,0xc43c000a,0x98a20091}},	//   гко_, ttle, כתחי, tokį_
  { {0x7de000dc,0x6e450029,0x3946006d,0xe9a6002b}},	//   rásá, _انضم, йног, مگين_
  { {0x89360029,0xcdf40029,0x7969005c,0x1e56000a}},	//   إعدا, _بأكث, _yświ, _השער_
  { {0xbb850029,0x692b2af9,0x6d560053,0xcc76000a}},	//   _التي, mřel, _פינף_, _הגנת_
  { {0xba28002b,0xb87b202e,0xbae40058,0xd62a00af}},	//   اسیم_, rdía, _وكني, гоге_
  { {0xba9a0008,0x7d1b0020,0x057a0029,0x98ab0045}},	//   _עסקי, ohus, امرة_, uncă_
  { {0x6564433c,0x8936000a,0xdd1f0046,0xd9430238}},	//   umih, _לָ֥א_, tířs, _нещи
  { {0xe2920029,0x13ea0033,0xe45a0660,0x13a8002b}},	// [9720] كذا_, ымай_, ужа_, شنای_
  { {0x57fb0008,0xe2a90015,0x93250015,0x63ab0030}},	//   _עליו, لامن_, يرلن, ágna
  { {0x8b5600b2,0xe6120086,0xd36f00a2,0x1677000a}},	//   ציעס_, _رشد_, رهم_, _לגיל_
  { {0xd83f00bd,0x752d086d,0x14d6006e,0x0000006a}},	//   šček_, ciaz, _ازدح,
  { {0x9097005e,0x7d1b2035,0xd9a40065,0x0000006a}},	//   світ_, dhus, _खट्ट,
  { {0xd0070124,0x201a005c,0x6e93433d,0x70530015}},	//   сеље_, ąpi_, пишу, أنها
  { {0xacf8006d,0x644b007c,0xa3e0000b,0xc5ba000a}},	//   инку_, ügiv, थिक_, אֶ֥ר
  { {0xc5f30008,0x629e433e,0xa06a29f7,0x7d1b433f}},	//   לדו_, lapo, _баба_, ghus
  { {0x44204340,0x1eaa0015,0x7969002a,0x77e20065}},	//   nzi_, _ماضي_, _uświ, गटोक_
  { {0x5a340661,0xdfcf002b,0x44204341,0x7f46004a}},	//   жнот, _سيم_, izi_, _уезж
  { {0x9cca03be,0x6ce601f3,0xdb070030,0xaa5827e3}},	//   _была_, _гіле, ámáz, рину_
  { {0xe8d90016,0xc7bb0033,0xbce50015,0x7d1b4342}},	//   _thọ_, лёг_, _وأنو, chus
  { {0x395f0048,0x6ebf005d,0x442000dc,0x629e1437}},	//   ķus_, ल्कु, jzi_, kapo
  { {0x3bbb0008,0xdc3b0053,0x44204343,0x752d002a}},	//   _עמוד, _געדר, dzi_, wiaz
  { {0x75880080,0xc9860067,0x44204262,0x8e18000a}},	//   йств_, _اشتي, ezi_, בֵּח
  { {0xa3e5000b,0x25ac013f,0x7c2d06c0,0x629e0ca8}},	//   पटल_, ádla_, _žari, eapo
  { {0x93970029,0xc299007a,0x752d086d,0x4420166c}},	// [9730] إجرا, иках_, riaz, gzi_
  { {0x394b0251,0x692b0089,0x25ae0061,0x20d30016}},	//   locs_, zřel, üklü_, _ải_
  { {0x44200962,0xe5c70155,0x555915b8,0x272d013b}},	//   azi_, _успо, _ваня_, lžno_
  { {0x90550b08,0xe1f00015,0xb87b0125,0x1eea002b}},	//   овец, عسل_, idío, یونی_
  { {0x493c0008,0x692b0089,0x44204344,0x4034141e}},	//   נגדו, vřel, czi_, пецс
  { {0xa195008f,0xa858000a,0x079c000a,0x629e0cb6}},	//   _магч, ציגה_, נסול, capo
  { {0xe8d90023,0x692b0046,0x7d1b3bbd,0xbd4500c3}},	//   _nhỏ_, třel, thus, ينتي
  { {0x7d1b003f,0xddc8002a,0xdb8507be,0x394b0144}},	//   uhus, _bydł, огии, jocs_
  { {0xfc31003b,0x02c6005d,0x212f002d,0x660e005c}},	//   بحث_, र्वभ, migh_, zybk
  { {0x212f406b,0x8b25005e,0xaa49004a,0x7d1b2300}},	//   ligh_, ідне, иппа_, shus
  { {0x4420271e,0xb87b002d,0x212f002d,0x3e350015}},	//   zzi_, rdín, oigh_, _بفار
  { {0x212f002f,0xc6890dab,0xeaf90086,0xdb090077}},	//   nigh_, _יא_, ارکت_, rteñ
  { {0xfaa50033,0x684602a3,0xdce80046,0x69dc0013}},	//   _дало, інга, _ludě, ærer
  { {0x9f44016e,0x212f4345,0x4fd6000a,0x0000006a}},	//   _irmã_, high_, חושב_,
  { {0xe737008f,0x4da90008,0x75d60015,0xdb090077}},	//   цер_, יֹּ֣, غيرا, nreí
  { {0x44200389,0x7ae34346,0xf1fa002b,0x98a20b48}},	//   tzi_, _hant, یعات_, fiką_
  { {0x629e00b6,0x44260023,0x73060063,0x212f002d}},	// [9740] tapo, ào_, опаз, digh_
  { {0x6b84002d,0x2902044c,0x44204347,0xdce80046}},	//   _éige, ljka_, rzi_, _budě
  { {0x442000dc,0x629e3291,0x75460254,0x00e6004a}},	//   szi_, rapo, _мноз, жжен
  { {0xf4b60029,0x4fea0608,0x29020844,0x692b0046}},	//   _بإدخ, имен_, njka_, eřej
  { {0x7e9a003b,0x644b0020,0x68e40541,0x493b000a}},	//   لنشر_, ügit, _maid, סגנו
  { {0xf413013a,0x212f002f,0x7ae33ba5,0x26d8392e}},	//   _חפש_, aigh_, _nant, nero_
  { {0x629c0048,0x29190095,0x867b000a,0xf1c3006f}},	//   _iero, ūrai_, ברצו, ľší_
  { {0x7ae309f2,0x1d070001,0xa1160029,0x212f002d}},	//   _aant, жећи_, _بورت, cigh_
  { {0xa2ca005d,0x7ae3013c,0xa2c1000b,0x629c0e94}},	//   स्थ्, _bant, र्क्, _kero
  { {0x26d82c65,0x7ae34348,0xddc90045,0xbb4700c3}},	//   jero_, _cant, înţe, يلين_
  { {0xc27b0008,0x627b000a,0x527b000a,0xddc8002a}},	//   יריי, ינינ, יניא, _wydł
  { {0xa2ca005d,0x7c650086,0x2d8e00b8,0x7c060015}},	//   स्त्, _کامل, mpfe_, _وبشك
  { {0xd7e402e1,0xc7cb0033,0xcc360015,0x63a4053d}},	//   міро, шыне_, _براع, jsin
  { {0x629c4349,0x63a43af2,0x26d8434a,0x29020085}},	//   _nero, dsin, gero_, ajka_
  { {0xfb1b013a,0xc1c9005d,0x68e42d1b,0xd49b05b1}},	//   _דוגמ, _रहेग, _faid, ира_
  { {0x2fc60f75,0x692b0089,0x68e40024,0x98a20007}},	//   ktog_, zřej, _gaid, tiką_
  { {0x26d804ed,0xc7970015,0x212f0125,0x7ae3434b}},	// [9750] bero_, _بشعب, vigh_, _yant
  { {0x68e40f4d,0x660e0089,0xb87b0089,0x2fc60134}},	//   _zaid, ínká, zdíl, dtog_
  { {0x212f002f,0x63a4434c,0xe7e3000b,0x10f50033}},	//   tigh_, asin, खिका_, зяля
  { {0x6f1a0011,0x644b0020,0x3228005e,0xdb1b04b2}},	//   _altc, ügis, ціум_, ituá
  { {0x212f002f,0xb4fa0008,0xe4fa0008,0xdb09016e}},	//   righ_, _הפרי, _הפרש, queç
  { {0x212f002f,0x27e4001a,0xc7dc000a,0xaf0402a3}},	//   sigh_, æmni_, שַׁכ, мпіл
  { {0x6d441de0,0xf5ab000a,0x20d70015,0x7ae31ba2}},	//   čian, ׁבַּ, _وترج, _rant
  { {0xa63c000a,0x26d825b6,0x7ae3434d,0x250b000a}},	//   יגור, zero_, _sant, יהֶ֣
  { {0x26c102c1,0x692b0089,0x68e40472,0xcd280087}},	//   _ocho_, přej, _raid, تسون_
  { {0xb4360008,0x441c000a,0x68e40ca6,0x78bd0012}},	//   לָיו_, יוחס, _said, egsv
  { {0xfc460084,0x63a40064,0x26d8434e,0x2492002a}},	//   _þíns_, zsin, vero_, ybym_
  { {0x2ee5434f,0xef19005c,0x7ae308b8,0x26c1001c}},	//   _half_, _duże_, _want, _acho_
  { {0x9856005e,0x68e44350,0xdc88000a,0xf092000a}},	//   ятош, _vaid, _וְצָ, ענך_
  { {0xbbe90086,0x9af50015,0x69240030,0x25ac013f}},	//   _پرچم_, _ركعت, tőes, ádlo_
  { {0x8afa0008,0x6b4f0134,0x68e4029d,0xcb12000a}},	//   _להסי, søgs, _taid, _אלג_
  { {0xdb00005c,0x26d801ef,0x629c36f8,0xb4e6021e}},	//   bumó, sero_, _sero, पये_
  { {0xa5072aaa,0xd2aa0033,0x26d835f5,0x629c11b1}},	// [9760] чета_, йкае_, pero_, _pero
  { {0x63a44351,0x6441002a,0xa999000a,0x5999000a}},	//   rsin, _ślic, ֶבְר, ֶשְׁ
  { {0xf67b0008,0x63a40106,0xd6eb000a,0xc7450021}},	//   _לאימ, ssin, _הַכָ, _تضيي
  { {0xd5fb0008,0x2fc60123,0x62850188,0x63a44352}},	//   _הפטר, ttog_, acho, psin
  { {0xd5b10023,0x4abd005d,0x28c1005d,0x6f0807e9}},	//   ớc_, ्भाव, ष्टि, _podc
  { {0x121a0010,0xfe70002b,0x657e00aa,0x2ee500da}},	//   _любы_, نگا_, _kuph, _calf_
  { {0x39814353,0x2fc64354,0x6f08151b,0x6aa13d8c}},	//   _nós_, stog_, _vodc, dalf
  { {0x718b0008,0xb23b004c,0x823b004c,0xa3b3000b}},	//   _לְמַ, _העלז, _העלצ, _टिम_
  { {0xd1750033,0x61430aed,0x8bd30033,0x0000006a}},	//   _цыры, _чета, ежыц,
  { {0xef17005f,0x501b0008,0xfbcf00e6,0x692b0046}},	//   _ему_, _הומו, اتي_, přek
  { {0x98a20c89,0xa2c1000b,0xf2d3004c,0x58d90280}},	//   likę_, र्ट्, ײער_, одня_
  { {0x18a40180,0x7d7b000a,0x6aa11de9,0x62854355}},	//   наџм, _הנאו, aalf, zcho
  { {0x48e40010,0x98a2002a,0x8c3d0045,0xdb1b016e}},	//   хоўв, nikę_, taşe, stuá
  { {0x3981002f,0x05770015,0x87040033,0x6aa10144}},	//   _fós_, كارد, нясе, calf
  { {0x66140046,0xdb090123,0x1b290058,0xe3b3009a}},	//   _čeká, tteö, _بأني_, کرز_
  { {0x2a3b0008,0xe9450086,0x9a3b0008,0x6a3b000a}},	//   _לעומ, _ترتی, _לתוק, _לגופ
  { {0x98650015,0x57b40033,0x657e03f0,0x644a007f}},	// [9770] _تُظه, _збыт, _euph, şfin
  { {0xc3540001,0xf8380135,0x26c1037c,0x62854356}},	//   екуј, _מנחת_, _ucho_, ucho
  { {0xcb1300b2,0x62854357,0x69c84358,0x7b160045}},	//   עלע_, rcho, ntde, _râul
  { {0xf8bf0152,0x98a2005c,0x212a002b,0x62854359}},	//   ngé_, fikę_, ييلی_, scho
  { {0xf8bf0152,0xdb2300dc,0x9f84005e,0xdee51411}},	//   liés_, űség, егід, доли
  { {0x75280024,0x69c801a7,0x33fa000a,0x93fa000a}},	//   īdze, ktde, _והשנ, _ולשי
  { {0xf2d20008,0x78ad435a,0x6aa100aa,0x692b0046}},	//   _שעל_, _odav, valf, přeh
  { {0x6aa10034,0x85f8000a,0x78ad435b,0x0000006a}},	//   walf, למוס_, _ndav,
  { {0x1c450036,0xfc310029,0x94b6000a,0xa0c4002b}},	//   ьним, ضحة_, וִיד_, _سيلو
  { {0xc9a90080,0x3981001c,0xab29005e,0x89a90d22}},	//   овое_, _pós_, іона_, оков_
  { {0xd946058b,0xa96a09c4,0x6aa11694,0x0000006a}},	//   дени, жина_, ralf,
  { {0x398112b3,0xf8bf435c,0x31fa015b,0x7e08000a}},	//   _vós_, diés_, קִיע, _מִנֶ
  { {0xbbeb002b,0x200b0144,0x385a0015,0x69c80079}},	//   _درام_, _àcid_, تشدد_, atde
  { {0xab640036,0xdb093b2f,0xf8bf0152,0x4b7a000a}},	//   _звіл, breá, fiés_, _ואסו
  { {0xbb520002,0x28c6000b,0xc5d5005e,0xf8bf0003}},	//   _جنوب, _वापि, ніть, giés_
  { {0x2cbf0005,0xa99a000a,0x2d53016e,0x7d0b0030}},	//   ngud_, _ובקר, mães_, _jogs
  { {0x130a0010,0x644b0020,0x7bc9435d,0xf2a6006b}},	// [9780] онай_, ügip, nteu, дизп
  { {0xe8d900a7,0xa3cf005d,0x446313ab,0xe7b7000a}},	//   _thể_, _शहर_, твув, _קהיר_
  { {0x4256000d,0xf8bf435e,0xa50a05b3,0xaacf000b}},	//   фтат, ciés_, _дена_, त्यक
  { {0x7bc93828,0x98a20091,0xf4960015,0x0000006a}},	//   kteu, tikę_, _تشدد,
  { {0xdfd00074,0xd12f0074,0x10a33982,0x6ff60015}},	//   ايت_, جمن_, тичн, بساط
  { {0x6d440007,0xdee30054,0xaacf000b,0xdb090030}},	//   čiam, вољи, त्मक, yreá
  { {0x7d0b00fb,0xbd870015,0xf536000a,0x11b50033}},	//   _bogs, ونون_, ֽנִי_, _пётр
  { {0xfbaa004a,0xb87b0046,0xad26006e,0xf3b6004f}},	//   отой_, rdík, برتو, ֵּ֥י_
  { {0xaec60001,0x4d730015,0xbb740054,0x6283013b}},	//   _обал, خطور, нгиј, žnoe
  { {0x98a0005c,0x93fb000a,0x6e930015,0x69c8435f}},	//   _imię_, קליי, _للكا, ttde
  { {0x02b7009d,0x69350892,0x7d0b00dc,0x19590139}},	//   והים_, енну, _fogs, заны_
  { {0x27f20026,0x9da50015,0x38c80030,0x69c819dc}},	//   _bryn_, _أصله, víró_, rtde
  { {0x7bc92a5c,0xdbd8002e,0xf8bf211c,0x272d00bd}},	//   cteu, _gæða, rgé_, lžni_
  { {0xf8bf0003,0x52d80065,0x600b004f,0x38c801d3}},	//   tiés_, ड़ोस, חִלְ, tíró_
  { {0xb9e60036,0x3abb0008,0xa4d50484,0xcad7000a}},	//   _ціли, _ומונ, нові, _חוות_
  { {0x63b60026,0x8c3d0064,0xf8bf0152,0x04c90015}},	//   fryn, laşa, riés_, ثوري_
  { {0x24580080,0x29190cd4,0x889c000a,0x58040015}},	// [9790] дать_, ūras_, _ובחי, _لويك
  { {0xae1e005d,0xd25b4360,0xf8bf01f6,0x0000006a}},	//   बनान_, оце_, piés_,
  { {0x5184008f,0x673500bd,0x85750080,0xf2c4006b}},	//   вуча, mizj, _плох, ъстн
  { {0x33950010,0xa5d8002b,0x00db0058,0x67350535}},	//   _памё, _کبیر_, تبطت_, lizj
  { {0xf8bf0152,0x9f350036,0x24b600a3,0xdb00013f}},	//   chée_, неді, _אהרן_, esmí
  { {0x2f18005f,0x539a000a,0x3818000a,0xe7b2000b}},	//   мочь_, _מישו, וקדם_, _जिसप
  { {0xa3e7005d,0xc332000a,0xd1b80015,0x925800e2}},	//   भिक_, _עול_, _يافا_, _жарт_
  { {0xef19005c,0x50f40063,0xeb991a4d,0xde46002b}},	//   _duża_, _изст, пии_, رینو_
  { {0x24894361,0x7f840015,0x2cbf007c,0x7bc94362}},	//   icam_, _للقن, rgud_, uteu
  { {0x656d01c2,0xbc620033,0x7bc94363,0x2d53059d}},	//   hmah, ывык, rteu, tães_
  { {0xf2d20053,0xaf340029,0x656d01c2,0x99d50015}},	//   נעט_, _شركت, kmah, رتدا
  { {0x7bc90152,0x2d53016e,0x25f9000b,0xd82615be}},	//   pteu, rães_, _उपजी_, едми
  { {0x395e0024,0xdce10091,0x485a0033,0x3855006b}},	//   ēts_, _sulė, яроў_, върс
  { {0xdb090144,0x7d060123,0x656d1cdd,0x29194364}},	//   dreç, öksv, emah, aksa_
  { {0xceb2013a,0xfb1a0008,0x24f62103,0x6abd000b}},	//   טים_, _מוסמ, нчар, ्भीर
  { {0x63b60050,0x92a9002a,0xd5b10016,0xf8bf0003}},	//   tryn, ysłó, ớn_, thée_
  { {0xc2b60001,0xa93b000a,0xe3ba006b,0x6d5b008c}},	// [97a0] ељењ, _מתקפ, яба_, ilua
  { {0x656d0b63,0x20ec0016,0x248907c8,0x78a60052}},	//   amah, _ới_, acam_, lakv
  { {0x217a0029,0x569b0008,0xda0f000b,0xaac2000b}},	//   سحاب_, _מייצ, ाहित_, _शासक
  { {0x98ab0011,0x399a01ac,0xf8bf0003,0x6d441e63}},	//   mică_, פינד, phée_, čiak
  { {0x98ab0011,0xd47b000a,0x5577004c,0x8937004c}},	//   lică_, _מאכל, _רעכן_, ערנע_
  { {0xde5802e1,0x6d5b0509,0xdea2002b,0xbf660058}},	//   малі_, elua, ایای, ردشو
  { {0x98ab04f9,0xe3570008,0xc6930008,0x78a6016f}},	//   nică_, _נשלח_, נאה_, kakv
  { {0xe47b00b2,0xdb09008c,0x78a6001a,0xbebc003d}},	//   ּריכ, hreä, jakv, _slīd
  { {0xcf462e5e,0x8c3d0045,0xb87b0046,0xefb3002b}},	//   _знай, taşa, odív, _مینگ
  { {0x6d5b4365,0xbbd30015,0x60c23bb2,0x6bd30015}},	//   alua, ازيغ, lgom, اتير
  { {0xe895008f,0x8c3d0061,0x7e82003d,0xddb6012c}},	//   кань, raşa, ātpā, _سحاب
  { {0x98ab0011,0x6735005c,0xaa630010,0x28c6000b}},	//   dică_, wizj, ытык, _वाणि
  { {0xd7fb0124,0xac970029,0x7524006f,0x692b0046}},	//   чун_, _أنها_, dhiz, dřet
  { {0x98ab04f9,0xabfb000a,0xc051000a,0xd763002b}},	//   fică_, _מהדר, ׁ֖ם_, انسی
  { {0xaa574366,0x98ab0011,0x09e307c1,0x98a20061}},	//   _كلها_, gică_, _бојн, alkı_
  { {0x7aea3cbf,0x4a5b0008,0xda5b000a,0x6d404367}},	//   _haft, _מדוו, _מכול, nnma
  { {0x656d4368,0x7aef0125,0x24891194,0x60c23d94}},	// [97b0] rmah, _áitú, rcam_, dgom
  { {0xdbc70005,0x883c000a,0x2489016e,0x3dd2002a}},	//   _tööp, _מתחו, scam_, ływy_
  { {0x6b8204ed,0x6595017f,0x9758000a,0x69c5008c}},	//   _luog, _шану, _איזו_, _ähet
  { {0x8596000a,0xd5c8000a,0x9596000a,0x75244369}},	//   _שדרג_, _אֶשָ, _שכרו_, chiz
  { {0x3d04005d,0x6b820007,0x10080015,0xef0e436a}},	//   वाने_, _nuog, فتوى_, ам_
  { {0x44291f9a,0x141a000a,0x60c22888,0x6d40436b}},	//   mza_, _חושב, agom, enma
  { {0x40950029,0x1ea80015,0xe570002b,0xfce5005e}},	//   _للأر, راوي_, _خطی_, войо
  { {0x4429436c,0x5ff50ffe,0x25ac00bf,0x8d84009a}},	//   oza_, _избу, ádli_, دشون
  { {0x98ab0011,0x6d5b08c0,0x4429436d,0x69d810f4}},	//   zică_, rlua, nza_, _apve
  { {0x8e840015,0x8f88000a,0x692b0046,0x6d5b436e}},	//   _ملكه, _טְעֵ, zřet, slua
  { {0x27260092,0xfe090015,0x7aea1a07,0x3179000a}},	//   _hông_, _تقضي_, _daft, ֽאָד
  { {0x27260092,0xe8f70142,0xcd96000a,0x6d680015}},	//   _kông_, влю_, _ידעת_, _كملف_
  { {0x7d09016f,0x692b0089,0xb87b0089,0x69cd000b}},	//   mjes, vřet, zdív, _तहकी
  { {0x98ab04f9,0xcc3a0053,0x27260092,0x7d09436f}},	//   tică_, _קעסט, _mông_, ljes
  { {0x64a6008f,0x4d8c000a,0x27260016,0x7c290012}},	//   кава, ּאמַ, _lông_, lzer
  { {0x98ab0011,0x7d0902cd,0xe4da0015,0xf4da0015}},	//   rică_, njes, بورت_, بورغ_
  { {0xd4f5008f,0x27260092,0x03a60809,0x7d090085}},	// [97c0] ыяры, _nông_, тизо, ijes
  { {0x3ea74370,0x7d1b0020,0x18470053,0x6d440007}},	//   jant_, hkus, _יְיָ_, čiai
  { {0xf1a90086,0x02190010,0x7d1b4371,0x636b00b8}},	//   فانه_, ніць_, kkus, künf
  { {0x6ec4005d,0x60c20007,0x27260016,0xdfda006b}},	//   _राहु, ugom, _bông_, дък_
  { {0x272600a7,0x44290050,0x7c290111,0x3ea70287}},	//   _công_, cza_, jzer, fant_
  { {0x7d09005c,0xef19005c,0x9f530010,0x626600d0}},	//   ejes, _dużo_, авіч, _авга
  { {0x20000440,0x7afe0251,0xcf250015,0x52d7004c}},	//   ţii_, _òpti, درني, _שולע_
  { {0x6fb60029,0xb0fa0015,0x6d400061,0xfd120015}},	//   _لمرا, _تفرض_, unma, شجع_
  { {0xb87b0014,0x6aa34372,0x98ab002a,0x6d404373}},	//   ndít, _benf, nicą_, rnma
  { {0x2d6e0089,0x9998000d,0xdb00002e,0x7d1b3b8e}},	//   _přes_, нкот_, fsmá, akus
  { {0xc333011f,0x3f84003f,0x44294374,0xc212000a}},	//   שות_, _humu_, zza_, ׁה֙_
  { {0x6441002a,0xfe37000a,0x7c83009b,0x6aa30546}},	//   _ślim, _ברבי_, _куше, _eenf
  { {0xead403be,0x7c29005c,0x78a40095,0x27260016}},	//   _боль, czer, _deiv, _xông_
  { {0x692b0089,0xf7940033,0x7bc04375,0x39424376}},	//   třes, рарэ, mumu, anks_
  { {0x4b7b00b2,0x5b7b0008,0xaabe000b,0x6b7b000a}},	//   _קאוו, _קרוא, _एफ़एक, _קרונ
  { {0x442908e0,0x2a570008,0x39ae0091,0xaa65005e}},	//   tza_, _שבהן_, męs_, _стік
  { {0xf94a0053,0x83870010,0x3ea74377,0x4acf000b}},	// [97d0] _רעפֿ, тыбе, yant_, त्वव
  { {0x8c3d01e2,0x7d1b00bd,0x692b0089,0x3ea718b3}},	//   daşl, zkus, přes, xant_
  { {0x442910fe,0x27260092,0x39ae0007,0x7c290e6a}},	//   sza_, _sông_, nęs_, zzer
  { {0x7bc00048,0x361a000a,0x7c294378,0xdce90091}},	//   kumu, _נורד, yzer, tmeč
  { {0x7bc04379,0x7d09016f,0xa0540036,0xdfd10029}},	//   jumu, vjes, авці, صيغ_
  { {0xa2940036,0x05960086,0x657d00d9,0x39ae0007}},	//   _варі, _جایگ, _hish, kęs_
  { {0x63ad02d7,0x41e40010,0x39ae0007,0x43680010}},	//   lsan, _кіта, jęs_, _раён_
  { {0x1be9005f,0x27e900f2,0x61fa00dc,0x27260092}},	//   едии_, _osan_, _átla, _tông_
  { {0xa2ca005d,0x7d093de1,0x6aa30026,0x7bc0437a}},	//   स्क्, rjes, _penf, gumu
  { {0x657d003f,0x7c291cb7,0x539a000a,0x7d09437b}},	//   _lish, rzer, עיתו, sjes
  { {0x68ed000c,0x7c292ef0,0x636b08f5,0xd338000a}},	//   _baad, szer, münd, כרזה_
  { {0x8c3d01e2,0x657d06e8,0x3ea50a3a,0xdb00001a}},	//   laşm, _nish, _helt_, rsmá
  { {0xb8ec005d,0x78a4437c,0x68ed0079,0xdb00063b}},	//   _ला_, _veiv, _daad, dsmæ
  { {0x8afc0050,0x636b0064,0xbb450080,0x8c1a039e}},	//   ględ, nünd, _щелк, _רוסי
  { {0x657d0334,0xd62a15bc,0x49060021,0x3ea500da}},	//   _bish, хове_, _موثق, _melt_
  { {0xf4950080,0xaacf000b,0x4acf000b,0xf992000a}},	//   ирую, त्रक, त्रव, _פרח_
  { {0x44661a11,0x657d08b8,0x63ad437d,0x645d0034}},	// [97e0] ував, _dish, gsan, _cysi
  { {0x8c3d0064,0xb87b16c9,0xe3b10015,0xdc2f003d}},	//   vaşl, rdít, ترِ_, ežīm
  { {0x2b890023,0xe8d90092,0x657d437e,0x63ad437f}},	//   _lúc_, _nhớ_, _fish, asan
  { {0x215a0115,0xda7a004c,0x7a7a004c,0x8c3d0061}},	//   رجاع_, גנער, גרעס, taşl
  { {0x3ea5069b,0x63ad0f04,0x69c10df9,0x7e0c000b}},	//   _belt_, csan, hule, िङ्ग_
  { {0x7bc014b3,0x36e9004c,0x6d59002a,0x69c14380}},	//   vumu, פֿינט_, _akwa, kule
  { {0x3ea50293,0x6da3049d,0xed50002b,0xe8d90016}},	//   _delt_, бија, يپت_, _chớ_
  { {0x39ae0007,0x7e640089,0xed570001,0xad660015}},	//   vęs_, řipo, лој_, داته
  { {0x04370053,0x69c10003,0x70560015,0x3ea50aa0}},	//   ָטיש_, eule, _إنذا, _felt_
  { {0x68ed09e7,0x636b136c,0x7bc01353,0x4bd7002b}},	//   _saad, rüng, rumu, ابيد_
  { {0x68ed0020,0x28c6021e,0x69c14381,0x63ad2c83}},	//   _paad, _वाशि, gule, zsan
  { {0x63ad385b,0xea27005e,0xa9270015,0x39ae0091}},	//   ysan, уцьк_, اعده, ręs_
  { {0x9cd70008,0x2900005c,0x68ed0458,0x7ae14382}},	//   _תודה_, _dnia_, _vaad, belt
  { {0x6d440007,0x7ae136dd,0x248d002a,0xdc290015}},	//   čiau, celt, _żem_, _جسمه_
  { {0xaab70002,0x63ad0034,0xfa55002b,0x657d2ea6}},	//   _صدور_, wsan, _پروگ, _pish
  { {0x636b18b8,0xe53401f3,0x29124383,0xa8150923}},	//   zünd, бесь, _goya_, _вдиш
  { {0xb97c0053,0x2b890092,0xf8a8005d,0x63ad30d7}},	// [97f0] _אנהי, _xúc_, _कड़िय, usan
  { {0x6b5d0251,0x645d002c,0x63ad4384,0x657d3311}},	//   tègi, _vysi, rsan, _wish
  { {0x645d4385,0xcad7000a,0x8c3d0061,0x63ad4386}},	//   _wysi, רובת_, vaşm, ssan
  { {0x645d005c,0x7ae10064,0x2d8508b8,0x759a000a}},	//   _tysi, zelt, _rule_, _שסרג
  { {0x636b08f5,0xc94c000a,0x69c14387,0x8c3d0061}},	//   tünd, עֲבֹ, zule, taşm
  { {0xf43a000a,0xadb5004a,0xb3ba000a,0xdb00038f}},	//   _יגרמ, ащищ, _במשכ, nsmä
  { {0xdce80007,0x636b4388,0x01e9000a,0x7ae107eb}},	//   _judė, ründ, _בַּֽ, velt
  { {0x3ea500b8,0xa3b9005d,0xa3e9005d,0x7ae100b8}},	//   _welt_, _घटा_, _मना_, welt
  { {0xdcfa0048,0x7ae12cbc,0xf4120053,0xdb0017df}},	//   _attē, telt, ַפט_, ksmä
  { {0x2d850607,0x15f7000b,0x2b15004a,0x3949007c}},	//   _tule_, ुमार_, рьир, _ajas_
  { {0x8e84003b,0xa2ca005d,0x7dfc0011,0x4efa000a}},	//   _المه, स्ट्, _căsă, _שהעו
  { {0x09360010,0xdb000020,0x2b890092,0x69c14389}},	//   рхоў, esmä, _túc_, rule
  { {0x98ab005c,0x6d4414c4,0x47c3006b,0x3156004c}},	//   nicę_, čiat, обяв, שירן_
  { {0xf772003b,0xf8630036,0x98ab0024,0xab920015}},	//   تاج_, івро, ējās_, _بلوغ
  { {0xe8d90023,0xa2d8000b,0x692b0046,0xf7430e41}},	//   _giữ_, न्फ्, přep, церо
  { {0x77860054,0x04ca0015,0x29001f04,0xb87b0077}},	//   _клиз, ضوئي_, _unia_, seía

  { {0x636b00dc,0x895b000a,0xd3870238,0xe2ca438a}},	// [9800] züne, _בדקת, ийте_, клад_
  { {0x13030036,0xe29a1006,0xd9ec000b,0xdce20016}},	//   озум, таж_, _जनमत_, _khoă
  { {0xd62a0054,0x673c438b,0x9c82005a,0x0000006a}},	//   _роне_, mirj, áčko,
  { {0x316d038d,0x6fb60015,0xa8ad000a,0x0163027c}},	//   _chez_, لمصا, ֲבוֹ, окхо
  { {0xe8d90092,0xa8a9000a,0xee1e000b,0xdee601da}},	//   _nhờ_, רֹעִ, बन्ध_, иоди
  { {0x2f56000d,0x6b84002d,0x63790010,0x673c00bc}},	//   штес, _éigi, _бсср_, nirj
  { {0x3207022d,0x5f190010,0xb5b6000a,0x2ca6007c}},	//   änyt_, ыццё_, ׁלַח_, _peod_
  { {0x636b01e2,0xd197000a,0x9fe6002b,0x7dfc0045}},	//   rüne, _ככלי_, _پسره, _răsă
  { {0x6eb60029,0xe8d90092,0x673c09e7,0x8eea0004}},	//   _نصائ, _chờ_, kirj, _имав_
  { {0x8f9b0008,0x7dfc0011,0x03d7000a,0x661c0123}},	//   _סיבי, _păsă, סוים_, kyrk
  { {0xd5b10023,0x5a460010,0xb3560033,0x2ca6007c}},	//   ới_, рэпа, ынiц, _teod_
  { {0x7afd0024,0xdb000f47,0xd12600e6,0x6d441de0}},	//   ēsta, dsmå, سم_, čias
  { {0xab94003b,0x9b940029,0xdce80007,0x48e40010}},	//   _التغ, _التت, _sudė, цоўв
  { {0xd7240036,0x69cf0011,0x7bdb0135,0xdb0001be}},	//   офсп, ăcer, _סקוו, usmä
  { {0xdb00438c,0x74a70004,0x05770021,0xe45f008c}},	//   gsmå, ијае, لارد, _syö_
  { {0x8a7b013a,0x4a7b0008,0xd4981853,0x3860001a}},	//   _באות, _ברוב, иру_, _fyir_
  { {0xdb000123,0x62830073,0x0000006a,0x0000006a}},	// [9810] psmä, žnom,   ,
  { {0x395901f1,0xa37b016e,0x636b0359,0x0000006a}},	//   loss_, _opõe, dünc,
  { {0xeab1000f,0xa3b3000b,0x212a002b,0x98ab002a}},	//   לֹא_, _टिक_, گينی_, wicę_
  { {0xed46002b,0xe45f008c,0xe002000b,0x39590012}},	//   _رپ_, _työ_, लमंद_, noss_
  { {0x2f190036,0x2ef50033,0x629e0030,0x8fe71411}},	//   лодь_, йздр, bbpo, рцед
  { {0xc6950053,0x6fb20029,0x81890015,0x39590012}},	//   זאַ_, أموا, _منسق_, hoss_
  { {0xcdc80029,0x7de40015,0x8c3d0045,0x2dd90015}},	//   لذين_, قسيم, maşi, ابتة_
  { {0xf5320008,0xdcf90086,0xcd050a32,0xece90a24}},	//   ּ֥ה_, افظت_, спий, удил_
  { {0x7b160045,0x5f940248,0x3af501b0,0x9c59066a}},	//   _râur, _митт, бянс, ышку_
  { {0x7d0200bd,0x9b450015,0xb87b438d,0x1f140058}},	//   _enos, إندو, teín, _وبلج
  { {0x5d850029,0x6d44002c,0x49900086,0x5f740029}},	//   _الصل, čiar, ویور, _ذاكر
  { {0xe8d90092,0x7188000a,0xacf40015,0xb0790030}},	//   _thờ_, יְשַ, _وسنت, _íósá
  { {0xdb090077,0xed5910cd,0xf8bf013f,0xa2d80065}},	//   sueñ, mož_, chém_, न्ड्
  { {0x6b960008,0x2056000a,0x6370438e,0x7e61008c}},	//   _הכסף_, מירל_, mäng, _kylp
  { {0xdb090467,0xb9950087,0xd62712d2,0x63700b14}},	//   queñ, _اشتغ, боре_, läng
  { {0x2cad0026,0x63620466,0x6ab7000b,0x8a16000a}},	//   naed_, môni, _आयुर, _לחצו_
  { {0x138a0029,0x6362001c,0xc953000a,0x1bed000b}},	// [9820] اخرى_, lôni, _ממה_, जिटल_
  { {0xadf9005d,0xed590089,0x6d450046,0xb23a0015}},	//   ्मान_, hož_, éhaj, هكذا_
  { {0x6362001c,0x61460080,0xed590089,0x637008e9}},	//   nôni, бежа, kož_, häng
  { {0xf9920008,0xba3a0053,0xa2d8005d,0xfc270015}},	//   פרד_, װײנט, _नॉर्, _فح_
  { {0x80250015,0x63aa0046,0x33b508f0,0xb39b0016}},	//   يرهم, álně, _мёрт, _trýớ
  { {0x65640084,0x26d80026,0xc7d7000a,0xd132002b}},	//   llih, nfro_, מוני_, _کمر_
  { {0x3d04005d,0x877b0135,0x6da30180,0xf2a30054}},	//   वाले_, נאצי, пија, _хисп
  { {0x7db30029,0x637008e9,0x5bb803fc,0x712600e6}},	//   أصوا, fäng, алия_, _ارسل
  { {0x63701893,0xa3cb005d,0x7d0200bd,0x65640213}},	//   gäng, रूप_, _vnos, ilih
  { {0x49d80036,0x7b3901cb,0x59d80010,0xab38005e}},	//   адою_, lňuj, адоў_, рпоу_
  { {0xbca60086,0xfbcf0086,0xe8d90092,0x6f770015}},	//   _هماي, وتی_, _chở_, _املأ_
  { {0x6c860029,0xa2d8005d,0x19590010,0x7d0212da}},	//   _الإم, न्त्, рамы_, _unos
  { {0x39590041,0x26d80026,0x3157004c,0x7d1d1e9f}},	//   ross_, ffro_, מיטן_, össe
  { {0xcc77000a,0x98740033,0x65640509,0x5694110d}},	//   _העדה_, яляц, elih, зарт
  { {0xa3cb438f,0xd9ec000b,0xee31000a,0x3db8000a}},	//   रंभ_, _जनित_, ֵֽל_, יֶּא
  { {0x3eae04ec,0x54990033,0x656402f2,0x858801b0}},	//   haft_, рваў_, glih, сёра_
  { {0x61ee020a,0xb8cd005d,0x637000c0,0x7b3901b2}},	// [9830] _asbl, गर_, känd, dňuj
  { {0x8c1b0008,0xd3710015,0x5b3b000a,0x6aaa4390}},	//   אומי, ذها_, ְׂאו, _jeff
  { {0xd3700074,0x60990029,0xa3a9000b,0x2fc60034}},	//   رهٔ_, لناس_, _गौर_, euog_
  { {0x2ee1000b,0xc1050015,0xa0c50015,0xddd40061}},	//   फ़्त, توصي, زيتو, _şaşk
  { {0xa8cc000a,0xb367006b,0xb68b000a,0x6362016e}},	//   א֖וֹ, _гъвк, ְרֵ֥, zôni
  { {0xa2d8014e,0x7bdc0045,0x6aaa4391,0x2d951ce8}},	//   न्द्, ărul, _neff, орис
  { {0x171c0053,0x8d7500e6,0xed590046,0x471c000a}},	//   רווע, يابا, tož_, רווג
  { {0xa63c0008,0x637000c0,0x7b3900bf,0x5bb52dfa}},	//   טגור, täng, cňuj, ософ
  { {0x798a00b8,0x637000d5,0xeb750033,0x2cad0034}},	//   _aufw, bänd, жынэ, raed_
  { {0x6aaa0026,0x9dab0063,0x63621baf,0x637004d4}},	//   _ceff, _бъда_, tôni, räng
  { {0xc8690008,0x27e0153a,0x63701e9f,0x6b9b02b9}},	//   _סן_, _spin_, säng, spug
  { {0x6283002c,0x63700c77,0xf1b200f3,0x6362016e}},	//   ľnoh, mäne, וסט_, rôni
  { {0x6d494392,0xbf870092,0x29040064,0xd5b10092}},	//   mnea, _điển_, ıma_, ấn_
  { {0x907a0008,0xd5b80024,0x1ddd000b,0x28c6000b}},	//   יטרי, šām_, _महात, _वाकि
  { {0x6d490011,0xe5060015,0x6b8302f2,0x7e29004f}},	//   onea, يبري, _iing, בֵּ֧
  { {0x39b50048,0x62950111,0x05660127,0x6d494393}},	//   mās_, _afzo, іван, nnea
  { {0x6d49002f,0x39b50048,0x39a700dc,0x65640049}},	// [9840] inea, lās_, lős_, rlih
  { {0x70b4005d,0x6b834394,0xf772006e,0x6d4941fb}},	//   ुल्ल, _jing, _تاب_, hnea
  { {0x63704395,0x39b50048,0xe2970256,0x6aa7000b}},	//   vänd, nās_, цах_, _ग़ैर
  { {0x80660063,0x752d4396,0x63700012,0x69c10061}},	//   овеж, chaz, wänd, irle
  { {0xb4e6014e,0x69c100b8,0x63700497,0x7b390264}},	//   फ़ी_, hrle, tänd, rňuj
  { {0x39b50048,0xa8570008,0x6b834397,0xd5b10016}},	//   kās_, חינה_, _ning, ớt_
  { {0x39b50048,0x272f00b8,0x63700497,0x9257004a}},	//   jās_, _fünf_, ränd, _даёт_
  { {0x39b50048,0x637004d4,0x6d4901f0,0x6b8b0876}},	//   dās_, sänd, gnea, _bugg
  { {0x4ae6008f,0x75241480,0x69c14398,0x44204399}},	//   оўна, ikiz, erle, nyi_
  { {0xa3cb005d,0x6b83439a,0x63a90061,0x5a34261d}},	//   रंत_, _cing, _çene, знот
  { {0x39b50024,0x6aaa002e,0x8f75005e,0x6b5d0003}},	//   gās_, _veff, _хуті, tègr
  { {0x394d03af,0xe8d90023,0x6b83439b,0x48ab017c}},	//   ões_, _phố_, _eing, штом_
  { {0x1dc6000b,0x6b83383d,0x6d40439c,0x2d8c00bc}},	//   रूरत, _fing, mima, _hude_
  { {0x4432005c,0x39b50024,0x7bd50011,0x6b8302b3}},	//   dzy_, bās_, ăzut, _ging
  { {0x39b50024,0x6d4000f2,0xdce2002a,0x44200061}},	//   cās_, oima, _choć, eyi_
  { {0x6b832d81,0x6d40439d,0x2d8c016e,0xa2d8000b}},	//   _zing, nima, _mude_, न्स्
  { {0x6d40014b,0x69c811e7,0xd877002b,0x98a20091}},	// [9850] iima, lude, _باغب, eikė_
  { {0x2d8c0111,0xf367078f,0x78ad2732,0x69c80111}},	//   _oude_, ітан, _heav, oude
  { {0x7c200176,0x8c3d0064,0xdb09002d,0x6d40439e}},	//   hymr, laşt, nseá, kima
  { {0x6d4000df,0xdb09002d,0xc4c70015,0x7c201590}},	//   jima, iseá, _بتدو, kymr
  { {0x44320050,0x3ce3005d,0x394b00dc,0x6d401a37}},	//   czy_, कड़ों_, incs_, dima
  { {0x78ad003e,0xf3ff001c,0x637000f2,0x2d8c049e}},	//   _leav, _irã_, täne, _bude_
  { {0x6aa7005d,0x6d49002d,0xcee8002b,0x6b8b1103}},	//   _ग़ौर, tnea, زرون_, _sugg
  { {0x39b50048,0xdb1b0251,0x69c80020,0x63700dca}},	//   vās_, truï, dude, räne
  { {0x6b832169,0x7c200034,0x7ff7002b,0x1c45005e}},	//   _ping, gymr, _بسزا, яним
  { {0x39b50048,0x67c4004c,0x39a70030,0x49c908a6}},	//   tās_, טאַלי, tős_, блон_
  { {0xc4cb005d,0x69c8439f,0x6b8343a0,0xc332000a}},	//   िलाओ, gude, _ving, גוי_
  { {0x39b50048,0x39a700dc,0x6b830705,0x3cf80015}},	//   rās_, rős_, _wing, _وعند_
  { {0x39b50024,0x6707000b,0x3f8d0144,0x2bc2000b}},	//   sās_, शांक_, _jueu_, _शिया
  { {0x39b50048,0x6b83003f,0x69c843a1,0xdb090077}},	//   pās_, _uing, bude, rreó
  { {0xe73738a1,0x8c3d0045,0xd627007e,0x64a643a2}},	//   чер_, raşu, поре_, заба
  { {0x1a650074,0x49ba013a,0x78ad0111,0x442000f2}},	//   _ویکی_, _המקס, _geav, tyi_
  { {0x44260023,0x636b007c,0x39421a5e,0xf3c90058}},	// [9860] áo_, rünn, miks_, قبله_
  { {0x44321ad1,0x883b000a,0xd764002b,0x442043a3}},	//   rzy_, _לתפו, _زنجی, ryi_
  { {0x68f601e2,0x44320050,0x44261cdb,0x672100c0}},	//   _kayd, szy_, šo_, ölje
  { {0x66010134,0xd1390010,0x7d19005c,0x394243a4}},	//   ælke, охі_, _nows, niks_
  { {0x6d4000df,0xf3ff001c,0xa3cb000b,0xd12f0067}},	//   vima, _grã_, रूद_, دمن_
  { {0x39420020,0xdef30010,0x3da60296,0x2d8c0e51}},	//   hiks_, епшы, приб, _pude_
  { {0x10a60083,0xdd970010,0x91e31a0d,0x7ae80af5}},	//   _нивн, пшы_, _поре, vedt
  { {0x2cea0036,0xa2aa000b,0x69c82202,0xdff60033}},	//   сько_, टरव्, vude, _нязь
  { {0x7c930086,0x7bc90152,0xc0d30015,0x3942007c}},	//   رشيا, gueu, _سيلب, diks_
  { {0xab970029,0x600b0008,0x4f8b0008,0x8f9b000f}},	//   أخير_, _לִבְ, _הָאֲ, _לימי
  { {0x78ad0005,0x69c80e95,0x2d8c007c,0xddda002a}},	//   _peav, uude, _uude_, _wytł
  { {0xdb09002f,0x63b600f2,0x39420020,0xd5b10092}},	//   rseá, ksyn, giks_, ấm_
  { {0x07a40033,0x69c843a5,0x7ae80030,0xacfb000a}},	//   наўн, sude, pedt, _להאכ
  { {0xdb09002d,0xcb540015,0x8c3d0061,0x3942003d}},	//   pseá, _تنتظ, raşt, aiks_
  { {0x78ad0005,0x68f60064,0xaadb0008,0xa4d5022a}},	//   _teav, _fayd, _החור, мові
  { {0x9a670015,0x04c90015,0x661a014b,0xccf9002a}},	//   _عميل_, توري_, ätka, mośc_
  { {0xdcfa0024,0xe4540010,0x88bc0008,0x58bc000a}},	// [9870] _attī, екты, _המחז, _המחצ
  { {0xc7b2000a,0x6f1a00da,0x94040058,0xc6910058}},	//   _שבי_, _notc, عوله, _جِد_
  { {0xa3b9000b,0x91870015,0x81c7004a,0xf2c40138}},	//   _घटक_, سجام, ящае, эстн
  { {0xf993000a,0xda7b000a,0xf8bf000b,0x5274002b}},	//   גרף_, זנבר, ्लिय, رالز
  { {0x9f350036,0xb97c0053,0x636b0064,0xe0d00002}},	//   меді, צנדי, lünm, ازم_
  { {0xdb1b0f14,0x8237002b,0x7afd003d,0xfd990054}},	//   truí, _فرزا, ēstk, отић_
  { {0x7d190050,0x272f0064,0xb87b001a,0x98bf0065}},	//   _pows, _güne_, lfíd, ्लाए
  { {0xe8d90092,0x3b95000d,0x7bc90003,0x63700b1f}},	//   _khổ_, мјот, tueu, mäna
  { {0xab5d002a,0x394243a6,0x40340054,0x1025002b}},	//   erża, viks_, _зетс, _تکاپ
  { {0x80d9000b,0x5f740015,0x68f60061,0xab760015}},	//   फ्रे, _كالر, _sayd, وميا_
  { {0x39421cdb,0x6f7a000a,0x1dc6000b,0xdb200030}},	//   tiks_, _וְאו, रूआत, ótáj
  { {0x186a0142,0x7db40015,0xbd450015,0x7f4324a8}},	//   жами_, _أصلا, _تنصي, linq
  { {0x39420020,0x636b0064,0x7bc926ec,0xe8d90016}},	//   riks_, tünl, queu, _nhổ_
  { {0x39420020,0x59c5000b,0x0b940015,0x7c2600cb}},	//   siks_, _विपर, _أجند, økre
  { {0x212d013c,0x636b0061,0xb9560054,0x63700123}},	//   _oleh_, rünl, _отић, jäna
  { {0xa50707be,0x24f50248,0x28160058,0x63b643a7}},	//   меса_, нчур, _يوغس, tsyn
  { {0xc953000a,0xe8d90016,0x61e90085,0xd4670c45}},	// [9880] _שמח_, _chổ_, _ćela, дите_
  { {0xd5b10092,0xd7760115,0x5999000a,0x63b643a8}},	//   ớp_, _تابع, ַשְׁ, rsyn
  { {0x56b7000a,0x71ea0015,0xc693000a,0x7bdc0045}},	//   _קפטן_, تفاف_, _באת_, ărui
  { {0xd0460086,0x98b90011,0x9dc1000b,0x15fb000a}},	//   وپاي, misă_, रूज़ो, _והטע
  { {0x3849000a,0x7c2d002a,0xdb240030,0x6fd3009a}},	//   ּאוּ_, _żarn, _ősít, نزوئ
  { {0x2d860026,0xf837000a,0x6e230034,0xdd9a01e1}},	//   _sioe_, וננת_, fynb, оши_
  { {0xdd900029,0x66e0000b,0x77ea000b,0xbdf70015}},	//   دوب_, ख्यक_, टबुक_, ِرًا_
  { {0x7bc70091,0x91e30238,0xe73f016e,0x9bf42ae4}},	//   ąjun, _шосе, mpõe_, езич
  { {0x98b90011,0x6f930015,0xecbf0065,0x0c95009a}},	//   hisă_, _للقض, _एयरफ, رديگ
  { {0x39400152,0x7e970029,0x7f4302b9,0x5a460033}},	//   _amis_, _ينقر_, cinq, дэма
  { {0x8c180086,0x28f90484,0x8e4a0015,0xdd92002b}},	//   زيگر_, пень_, _بلاك_, _شوش_
  { {0x9c260004,0x0c26018d,0x25480061,0xfe37004f}},	//   _одед, _омен, oğlu_, _קראי_
  { {0x1bf2005d,0xd7f81114,0xcaf3009a,0x0000006a}},	//   _अनिल_, мур_, رسیب,
  { {0x3993001c,0x39400045,0x7bdf0012,0xf53f0cbb}},	//   _fãs_, _emis_, _äqua, _små_
  { {0x66f4006b,0x569408a0,0xa5f81034,0x7f3b004f}},	//   ъпру, таст, меру_, קעלו
  { {0x636b01e2,0xe8d90092,0x765b0064,0x2889002b}},	//   rünm, _phổ_, şuyo, _عصبی_
  { {0x57f40010,0x545515d5,0xa3c60157,0x2d9e21fc}},	// [9890] _апыт, хват, ईंग_, _ltte_
  { {0x026b0142,0xa3cb0231,0x59c5000b,0xf79c000a}},	//   ошей_, रूष_, _विमर, _ובזמ
  { {0x69cf005c,0x69da22dd,0x32670033,0x636b0030}},	//   ąceg, ntte, фтав, lünk
  { {0x69da0945,0xe8d90092,0xe165002b,0x3075004a}},	//   itte, _thổ_, رضای, нулс
  { {0x7feb00e5,0xc49a000a,0x6370039b,0x636b0030}},	//   تراف_, _משרת, männ, nünk
  { {0x98a50091,0x637007c2,0x7af843a9,0x69da17cc}},	//   ėlę_, länn, _navt, ktte
  { {0x6283002c,0xa3cb021e,0x212d00bc,0x5e450015}},	//   ľnos, रूर_, _tleh_, عَبْ
  { {0x61f50030,0xa0c50015,0x69da43aa,0x62831e25}},	//   _iszl, _سيطو, dtte, žnos
  { {0x5e590086,0x2d9e3e98,0x8b25006b,0x7ff40015}},	//   _کلاس_, _ette_, едпе, _لسلا
  { {0x8c9f000b,0x69da1490,0x6d5c0052,0x0000006a}},	//   _ग्रो, ftte, _íran,
  { {0x637000c0,0xb06200f2,0x38690064,0x4dd40015}},	//   känn, _ääri, _ayar_, _لتنس
  { {0x2014005c,0xfe6e0086,0x6370008c,0x9e3c0046}},	//   ścił_, _اگه_, jänn, _veďt
  { {0x636b0399,0x6370008c,0xdb0b0804,0xdb09008c}},	//   günk, dänn, _avgå, tseä
  { {0x61f500dc,0x7bdb002e,0xdb1b163c,0x8c1a000a}},	//   _oszl, mtuu, bruá, _מוני
  { {0x672100c0,0x66000024,0x7bdb43ab,0x6f7a000a}},	//   ölja, āmko, ltuu, לְלו
  { {0x2a3a000a,0x98b90045,0x386d0535,0x0000006a}},	//   _מעצמ, risă_, żera_,
  { {0x8cd7000b,0xf2a6006b,0x7bdb1c62,0x53ca0151}},	// [98a0] _यानो, еизп, ntuu, ягам_
  { {0x7bdb008c,0xb463006b,0x42563334,0x48dc0065}},	//   ituu, укул, нтет, ग्रो_
  { {0xf8bf0152,0xe8d90092,0x02190010,0x7bdb00f2}},	//   chés_, _chỗ_, міць_, htuu
  { {0xa99a0053,0x7bdb43ac,0x22570086,0x8c9f005d}},	//   לבער, ktuu, رلند_, _ग्लो
  { {0x251b0053,0x351b0053,0x451b0053,0xd4360015}},	//   _זוכא, _זוכנ, _זוכװ, _أعجب
  { {0x3cdd005d,0x69da0293,0x63a443ad,0xf1c30046}},	//   क्से_, ytte, mpin, ýší_
  { {0x4ea50036,0x63a40472,0x68e41927,0x636b0030}},	//   тріа, lpin, _obid, zünk
  { {0x2fc60134,0x61db000a,0x0ba6005e,0x63a4059f}},	//   prog_, _מקלד, ншом, opin
  { {0x27340123,0x63a443ae,0xcb4608d7,0x7bdb43af}},	//   _känd_, npin, ехни, gtuu
  { {0x30750ac7,0x7e6800dd,0x20190251,0xc43b000a}},	//   _русс, _tydp, _àsia_, פתיי
  { {0xc33343b0,0xfc2f0086,0xd3370008,0x2bc2000b}},	//   רות_, لحی_, גריה_, _शिवा
  { {0xf7950010,0x98a9002c,0xa3cb000b,0xdde90015}},	//   камэ, _tlač_, रूँ_, _تركه_
  { {0x7bdb0298,0x637043b1,0x1bd403fb,0x628e0079}},	//   ctuu, jäno, _роля, _ogbo
  { {0x999e00dc,0x636b00dc,0x61330061,0x63a443b2}},	//   sztő_, rünk, _içle, dpin
  { {0x637000f2,0x8afb000a,0x636b0030,0x63a44326}},	//   tänn, _מהגי, sünk, epin
  { {0x59c5014e,0x636b0064,0x9e77000a,0xc4cb000b}},	//   _वितर, müni, תגלה_, िलेख
  { {0x63a40035,0xa8a8000a,0x38690061,0x88a8000a}},	// [98b0] gpin, _אֹתִ, _uyar_, _אֹת֔
  { {0x69c80298,0x637000f2,0xd011002b,0x869901c5}},	//   orde, sänn, یلا_, _юкос_
  { {0xd251003b,0x200404ed,0xc2c400e6,0x06350180}},	//   جنا_, _armi_, طيني, _ренџ
  { {0x69c80014,0x25ba0008,0x51840010,0x629c0026}},	//   irde, _קצרמ, гуча, _efro
  { {0x69c800b8,0xa4b6000a,0x656d013c,0x629c0034}},	//   hrde, _שלשה_, mlah, _ffro
  { {0xf5cb000a,0xd0060190,0xdee50047,0x656d43b3}},	//   ִזִּ, теше_, токи, llah
  { {0xb3540b1e,0x8265002b,0x6df20015,0xed590fe4}},	//   _скрш, _شهرن, لكوا, мок_
  { {0x7bdb00f2,0x27340123,0x68fd3ba0,0x656d1d88}},	//   ttuu, _täng_, jdsd, nlah
  { {0x7f95010f,0xe508000a,0x6d040015,0x656d0061}},	//   _разх, ת֖וֹ_, طبيق, ilah
  { {0xeab10029,0x2bc2000b,0xdde30030,0x9b020033}},	//   جعة_, _शिरा, űrők, азьд
  { {0x7bdb43b4,0x656d1b51,0x98a61bb1,0x2fcf0c4e}},	//   stuu, klah, кине, lugg_
  { {0x9e48000f,0x672100c0,0x63a443b5,0x7c36002a}},	//   _אֲנִ, öljn, ypin, _żyre
  { {0xf8bf0089,0x69c843b6,0x3f8b0003,0x656d0069}},	//   ckém_, arde, _écus_, dlah
  { {0xec36000a,0x07a33028,0x7bdc0045,0xbb45004a}},	//   _באנר_, рарн, ărut, _шелк
  { {0x63bd01d1,0x9a690029,0x165903e7,0x3aba000a}},	//   _avsn, _تمثل_, ерть_, _חמצנ
  { {0x140d005d,0x7afd0024,0x656d0fa9,0x2be5000b}},	//   समूह_, ēstu, glah, _कहां_
  { {0xb87b12b3,0xc2b60054,0x63a443b7,0x7bc93381}},	// [98c0] rfíc, вљењ, upin, nreu
  { {0x577a0029,0x63a443b8,0x1877004f,0x0000006a}},	//   _تصبح_, rpin, _בעפר_,
  { {0x63a443b9,0xe0da41f8,0x7bc943ba,0x35a6096d}},	//   spin, две_, hreu, _шанг
  { {0xd5b80048,0x63a42c2c,0xd026006b,0x7bc90012}},	//   šās_, ppin, кмей, kreu
  { {0xb4c0000b,0xb4ce000b,0x6564008c,0x284d000a}},	//   ीली_, रली_, moih, ּעוּ
  { {0x8fa30001,0x2c6c002d,0x1eaa0015,0x6564008c}},	//   шаље, hódú_, ذاتي_, loih
  { {0xe1f70080,0x41aa042b,0x01da0015,0x40960015}},	//   _игр_, _іван_, _توزع_, _للزر
  { {0xed57050e,0x656400f2,0x7bc91439,0x69c8006f}},	//   кој_, noih, freu, vrde
  { {0x9f4d02c1,0xfeea0015,0x69c80034,0x44e6005e}},	//   _creó_, _يعطى_, wrde, iд_
  { {0x69c80085,0x2905003d,0xfe42002b,0x8f7600e2}},	//   trde, ēlam_, _پکتی, _рубі
  { {0xa3c6005d,0xf2d30008,0x27e94120,0xf8bf0089}},	//   ैंड_, בעת_, _span_, ském_
  { {0x91bb0008,0xf8bf00dc,0x6564008c,0xdca60cab}},	//   ומטי, mkék_, joih, _ради
  { {0xc7c7006b,0x272f0012,0xcc16012c,0xb8eb000b}},	//   ъсни, _dünn_, _جذاب, _लय_
  { {0xcf930135,0x2c37000f,0xaa58005e,0xa0720033}},	//   יטש_, _שָׁם_, _пилу_, ыхiл
  { {0x80d3005d,0xcb670001,0xee2e005e,0xd5b00015}},	//   _डाले, _шаље_, йнi_, ْفِ_
  { {0xdb1b001c,0x3dfb0053,0x850d005d,0x3f8c0046}},	//   truç, וללד, हाइट_, _lidu_
  { {0xa9580008,0x656d0509,0x33980015,0x439400eb}},	// [98d0] _שיחק_, rlah, نخلة_, иатс
  { {0x43040036,0x764e00dc,0x02450015,0x966b0015}},	//   иїха, ányá, هَذَ, _يصدق_
  { {0xc692000a,0xb147002b,0x672807e0,0x9756000a}},	//   _לאי_, نیسم_, ödje, _תשתף_
  { {0xd5b10092,0x415501b0,0xa0c40015,0x7bc90470}},	//   ấu_, ывес, ليمو, yreu
  { {0x2fe50058,0x4fc400af,0xdce9007f,0xef0e134a}},	//   اكتف, асја, emeğ, бм_
  { {0x543a00b2,0x6f6401f3,0x2fcf001a,0x7bc90da5}},	//   _טערא, авіз, rugg_, vreu
  { {0xc3320008,0x442943bb,0xf2d2000a,0x02af000b}},	//   _פול_, lya_, _לעם_, टरीन
  { {0x9f4d02b9,0x7bc943bc,0xc1050058,0x0000006a}},	//   _creò_, treu, _حوري,
  { {0xa055008f,0x7bc90152,0x7d760015,0xb87b0030}},	//   _сваі, ureu, دمير_, zeír
  { {0xa3d4000b,0xddeb0015,0x7bc943bd,0x442902f2}},	//   संत_, _يراه_, rreu, iya_
  { {0x5cd500e6,0x6564003f,0xa2d8000b,0xda090015}},	//   _مقاط, yoih, न्ट्, ريحه_
  { {0x89360029,0x7bc90011,0x798d01d7,0x07a61c31}},	//   اعدا, preu, _ciaw, ламн
  { {0x59c5014e,0x31560053,0x752d0057,0x3ff9004c}},	//   _विवर, רירן_, dkaz, עפֿע
  { {0xa03a0053,0x3cff007c,0x7d1b2c50,0x6d4943be}},	//   געשפ, lduv_, ljus, liea
  { {0x442901e2,0xceb2011f,0x656400f2,0x62810264}},	//   eya_, מים_, toih, _úloh
  { {0x442943bf,0xb4c0000b,0x3cff007c,0x69dc0144}},	//   fya_, ीले_, nduv_, àree
  { {0xeb960053,0x130a0010,0x6b8d002d,0x07fa0029}},	// [98e0] ָדער_, ннай_, _éags, _أربع_
  { {0x7d1b0005,0x57fb0008,0x0ed2005d,0x0594002b}},	//   hjus, _טלפו, _साइड, _پادگ
  { {0xd5b10023,0xf7720086,0x637000c0,0xdce204c6}},	//   ất_, _پاک_, länk, _skoč
  { {0xc329000a,0xa3d4000b,0x442943c0,0x0000006a}},	//   הו_, संद_, bya_,
  { {0xe807005d,0x7056002b,0xd8d7000a,0x78b60061}},	//   शिया_, دنشا, רונט_, _meyv
  { {0x7d1b2db1,0x0000006a,0x0000006a,0x0000006a}},	//   ejus,   ,   ,
  { {0x3d8a0080,0x316c0024,0x7de600e5,0x61f8000a}},	//   нщин_, _ūdzu_, استم, _בִּג
  { {0x867b00b2,0x067b004c,0x7c3b0012,0xe807000b}},	//   ערקו, ענקל, fzur, शिमा_
  { {0x8afc002a,0xdce20085,0x600a02a3,0x6441002a}},	//   klęt, _ukoč, _янам_, _śliz
  { {0x798d0034,0x752d0188,0xef8318dc,0x7e970015}},	//   _siaw, zkaz, _глуп, _منكر_
  { {0x6e93003b,0x5e93003b,0x8e560010,0xd91504ab}},	//   _الما, _المط, _стаі, адны
  { {0xe8d90092,0x286b0286,0x7c290035,0x7d1b002a}},	//   _khứ_, ерго_, byer, cjus
  { {0xac970029,0x7c3b002a,0x386d02de,0xab2a1528}},	//   _إنها_, czur, æer_, _пода_
  { {0x7bfb0008,0x4aba006b,0x442943c1,0xabfb004f}},	//   _נפוצ, _чудя_, vya_, _נהור
  { {0x63700ac8,0xe5730015,0x44290034,0xd90f002b}},	//   mänh, مطر_, wya_, _فید_
  { {0x6aba0014,0x442943c2,0x48390058,0x637043c3}},	//   latf, tya_, _لكبح_, länh
  { {0x2927005c,0xb8f9021e,0x93970031,0x394b3873}},	// [98f0] ętać_, ाल_, اجرا, mics_
  { {0x752d0445,0xdce904c0,0xd25b2e88,0x394b43c4}},	//   skaz, vleč, нце_, lics_
  { {0xdce9016f,0x32070107,0x442943c5,0x9aeb000a}},	//   zmeđ, íny_, sya_, עַמִ
  { {0x442921a0,0xbebc003d,0x394b43c6,0x6fb50058}},	//   pya_, _slīp, nics_, لمؤا
  { {0x94ba000a,0xe8d90092,0xa2950036,0xef22002a}},	//   _שמשת, _chứ_, _вагі, każą_
  { {0x394b08b8,0x0000006a,0x0000006a,0x0000006a}},	//   hics_,   ,   ,
  { {0xf2040063,0xad59006b,0x7c2943c7,0xef22002a}},	//   _лято, крих_, wyer, dażą_
  { {0x661a008c,0xdce90091,0xfbc5045f,0x6d2516db}},	//   ätki, pleč, абио, рдиз
  { {0x75ec0014,0xec790063,0x394b2efb,0xa3cb000b}},	//   _közö, ъпи_, dics_, रंट_
  { {0xef670063,0xbbe80086,0xff5300a2,0xf412000a}},	//   _събо, اريم_, _اخر_, קפי_
  { {0x394b2efb,0xff7a004c,0xc334000a,0x7c2902f2}},	//   fics_, _סטעמ, מוץ_, syer
  { {0x637000c0,0x394b027d,0x8d872079,0x71d6004f}},	//   tänk, gics_, _сузд, סורד_
  { {0x2cad43c8,0x2ba70054,0x5ba70a3e,0x644b0052}},	//   mbed_, _сјев, _срез, úgil
  { {0x637008e9,0x6995005e,0xfaa5171b,0xa3d40065}},	//   ränk, _крих, _тако, संस_
  { {0x2956010f,0x28a7000b,0x366a1377,0xf6233122}},	//   _въпр, _क्वि, таво_, одро
  { {0x636b43c9,0xd5870015,0x2508002b,0x75d30021}},	//   zünt, لَّه_, درسی_, تيفا
  { {0x93461833,0xdb000a88,0xe29a066a,0x0000006a}},	// [9900] анае, rsmö, ваз_,
  { {0xa87b000f,0x2d8f0364,0x487b000a,0x67bb000a}},	//   _באפר, _lige_, _בטפס, _שמיק
  { {0x4add005d,0x80a60031,0xaadd000b,0x5f190065}},	//   _मानव, لمان, _मानक, पान्_
  { {0x7a7a0053,0xdfa600d0,0x55bb000a,0x865b05bd}},	//   דרעס, ајко, _במטו, _ידיי
  { {0xdefa005f,0x636b1fad,0x2fc000dc,0x3d19000b}},	//   вый_, güns, éig_, भाने_
  { {0x2d8f002f,0xf4570008,0xeea70063,0xde580010}},	//   _aige_, _כיכר_, атък_, лалі_
  { {0x636b01e2,0x2dd70029,0x637000f2,0x1dd70015}},	//   rünt, لبية_, jäni, لبيع_
  { {0xe8d90023,0x2cea0036,0x60db002d,0xc617000a}},	//   _thứ_, тько_, _gcum, שחקי_
  { {0xdb0a0086,0x61e9016f,0xbd870015,0x5bb70033}},	//   نزده_, _ćeli, جنين_, алыя_
  { {0xbb540015,0xdfcf0015,0x7bc60091,0x69cf002a}},	//   إندب, _آيل_, škuo, ącen
  { {0x2bc2005d,0x2cad003e,0x33770008,0x0dc90029}},	//   _शिका, bbed_, שעים_, _مبنى_
  { {0x38c90086,0xdd8f0031,0xebe60033,0x6d5e0030}},	//   دادی_, _قول_, _водп, épad
  { {0x29050089,0xad1b000a,0x394b0b89,0x2d8400aa}},	//   ěla_, _שודר, rics_, mmme_
  { {0x28a7014e,0x2905005c,0x394b43ca,0x29023695}},	//   _क्रि, śla_, sics_, adka_
  { {0xdb7b0008,0x68930086,0xa3d4005d,0x35470010}},	//   _שנוכ, _ویدئ, सूस_, ахав
  { {0xef19005c,0x52af000b,0xfe37000a,0x02af000b}},	//   _duży_, टर्स, ברלי_, टर्न
  { {0x44980080,0x2d840ac8,0x3cde000b,0x99840015}},	// [9910] рвую_, imme_, _गाने_, _بليو
  { {0x27340020,0x63a2002d,0x48e3000b,0x60db43cb}},	//   _täna_, íona, ट्रो_, _scum
  { {0xa2dd014e,0xa2940036,0x636b00b8,0x62880107}},	//   _पाठ्, іаці, wüns, _údol
  { {0x7bc00007,0x30150142,0x8144002b,0x1bf8000b}},	//   ksmu, йдер, يپلم, ्टाल_
  { {0xcfe90002,0x83870139,0xf485002b,0x2d8f43cc}},	//   افته_, _выве, _دادی, _rige_
  { {0x2d8f43cd,0xcf44005e,0xb364006b,0x7bdf0012}},	//   _sige_, оній, _дъск, _äqui
  { {0x7bc20152,0xf159068e,0x78bd0607,0xd738000a}},	//   _avou, _бивш_, kasv, שטות_
  { {0x28a7005d,0xf6580008,0x067c0008,0x76580008}},	//   _क्लि, יסוי_, כנול, יבוד_
  { {0x2900003f,0x2cad3bd6,0x7bc0001a,0xf51a000a}},	//   _raia_, rbed_, gsmu, אֵיל
  { {0x7de70191,0x2d8400f2,0xada4002c,0x7bc20089}},	//   _відд, amme_, _spĺň, _dvou
  { {0xe8d90023,0xc3320008,0xca490067,0x2d8f1a8a}},	//   _chữ_, פוט_, الجه_, _tige_
  { {0x7c950029,0x9e76000a,0x6d9504b2,0x78bd001a}},	//   _الإص, _הגעה_, _všad, gasv
  { {0x6c85003b,0xfc67006b,0x5c140015,0xcc140015}},	//   _الشم, _тъжн, _وظهر, _وذهب
  { {0x39490375,0x6d50002a,0x46a30033,0xa6460015}},	//   _emas_, ądał, зарв, مخزن
  { {0x5b7a013a,0xd5b10023,0xf7430888,0x7bc20046}},	//   _גרסא, ấp_, черо, _zvou
  { {0x15430054,0x66d10030,0x58060058,0x0000006a}},	//   песм, tókü, _هوبك,
  { {0xd4690029,0xf484002b,0xdb9a004c,0x69c143ce}},	// [9920] لحكم_, زاری, ָסער, lsle
  { {0xa2dd000b,0x63700123,0x69c10d7c,0x0000006a}},	//   _पाण्, hänv, osle,
  { {0x3aba0053,0xdb09002d,0x2d8404b8,0xc0ca0033}},	//   רמענ, lseó, ymme_, гуле_
  { {0x7bc0008c,0x34f6002b,0x50ba002b,0xf77f0061}},	//   ysmu, _اسدآ, اداد_, rtçe_
  { {0x987a00b2,0xa87a0053,0xf8bf00dc,0x601808fc}},	//   װאַט, װאַר, mkét_, роля_
  { {0xc7b30008,0xdce00024,0x02d5006b,0x6f011470}},	//   לבד_, domā, _мюсю, _calc
  { {0xddea0029,0xa2dd000b,0xa3d4000b,0x8337004c}},	//   ارته_, _पात्, सूर_, _פאלס_
  { {0x7bc60007,0x5c98006b,0xf8bf0030,0x69c143cf}},	//   škum, шкия_, nkét_, dsle
  { {0x251b0008,0x6f0143d0,0x491c000b,0x69c143d1}},	//   רופא, _falc, यानो_, esle
  { {0x93fb00a3,0x7bc00091,0x4a54005e,0xf413000a}},	//   נליי, rsmu, жкос, פפת_
  { {0x69c143d2,0x99520089,0xb4c8005d,0x7c2d002a}},	//   gsle, lář_, _ईयू_, _żart
  { {0x48ab0088,0x7d1d0012,0x76030030,0x0000006a}},	//   ытом_, össt, hízá,
  { {0xc8670f13,0x672500f2,0xad6500a2,0xf7730015}},	//   стни, _pohj, _باله, كاس_
  { {0x0057000a,0x7bdb004c,0x78bd003d,0xb59504b4}},	//   משכת_, _עקוו, sasv, живш
  { {0x95770086,0x63a20125,0x99520046,0x7d0243d3}},	//   مدرض, íonn, hář_, _kaos
  { {0x55750036,0x3949016e,0xe8d90016,0x7d02014b}},	//   ігат, _umas_, _khử_, _jaos
  { {0x24180139,0x99520046,0xc2b9005e,0x68ed234d}},	// [9930] боты_, jář_, илає_, _ibad
  { {0x2b11005d,0xe3b00015,0x70d1000b,0x7d0243d4}},	//   ़ाएँ_, عرق_, हल्ल, _laos
  { {0x34950010,0xd095004a,0xf774000a,0x90991886}},	//   _манр, ошлы, _מקץ_, авет_
  { {0x82340015,0x7ff5002b,0x10750033,0x6f0143d5}},	//   أركا, قستا, олею, _salc
  { {0x67540086,0xe04b0086,0xa069023e,0x78fc004c}},	//   _ذخیر, دشاه_, јала_, טלאפ
  { {0xc7d80008,0x7a3f00dc,0x81c2003d,0x69c143d6}},	//   מודי_, _játé, ģērb, ysle
  { {0x0d850080,0x63ad43d7,0x26dc004c,0x6f0143d8}},	//   олкн, lpan, אקומ, _valc
  { {0xdce00048,0x6f01005c,0xbd450029,0x69c70089}},	//   tomā, _walc, تنبي, ájem
  { {0xeb990001,0x69c1065b,0x63ad43d9,0xb146002b}},	//   јио_, wsle, npan, _بینم_
  { {0x0ee0000b,0x7c260123,0xb178001a,0x61e500da}},	//   _नायड, äkra, _þórð, othl
  { {0x8d740086,0x61e5003e,0xf2d2000f,0x7b15002b}},	//   _کالا, nthl, ועי_, مبگذ
  { {0xa96a057e,0xa3ea000b,0xa88a006b,0x69c113e0}},	//   рима_, _महल_, ийна_, rsle
  { {0x3cde000b,0x9c65002b,0xe76a012c,0x63ad0079}},	//   _गाते_, _بهشو, لحسن_, jpan
  { {0x69c10293,0x6b96000a,0xf7460054,0x2cbf43da}},	//   psle, _וכסף_, цего, laud_
  { {0x60c90dd2,0x66033dc6,0xf506163d,0x63ad43db}},	//   _odem, мпра, озво, epan
  { {0x05560033,0x200d0045,0x2cbf43dc,0x95991c8c}},	//   ітвя, _orei_, naud_, стру_
  { {0xccf205af,0x63700123,0x63ad43dd,0x61e50034}},	// [9940] וכן_, känt, gpan, ethl
  { {0x60c90467,0x99520046,0x68ed0244,0x6370008c}},	//   _adem, vář_, _zbad, jänt
  { {0x5b3a0053,0x11d70015,0xf8bf0003,0xdb090077}},	//   סגעק, قولة_, ckés_, nseñ
  { {0xbfaa0001,0x99520046,0x200d19bd,0x600a0891}},	//   атке_, tář_, _brei_, инем_
  { {0xf1aa0086,0x65610030,0x60c90034,0x61e543de}},	//   _چاره_, élhe, _ddem, athl
  { {0x73f900b2,0x200d018b,0x60c90064,0xfda60001}},	//   _פּרו, _drei_, _edem, ојим
  { {0x64490084,0xdd970010,0x99520089,0x6462002a}},	//   _þeir, ошы_, sář_, źwię
  { {0x253700b2,0xe0d70036,0xc69300a3,0x200d43df}},	//   ַניש_, _мвс_, ואו_, _frei_
  { {0x853b0053,0x2bba0015,0xee94002b,0x0465000a}},	//   יגקי, جاعة_, _فداک, ּיתָ_
  { {0xba0a0063,0x7d02003f,0x9a8a006b,0x60c90bba}},	//   ахме_, _waos, ищна_, _zdem
  { {0x329b000a,0xdb0e0030,0x2a330033,0x729b000a}},	//   יביד, _újít, дэўр, יסיס
  { {0xe8d90023,0x63ad43e0,0xe8070065,0x0000006a}},	//   _thử_, ypan, शिला_,
  { {0x8707006b,0xb89a0046,0x7a3f0046,0x6370008c}},	//   ояве, _šťáv, _páté, näns
  { {0xcc77000a,0x61e50034,0xdbf80065,0x0000006a}},	//   _ועדה_, ythl, ्टीड_,
  { {0xda6f0036,0xbb830086,0xda660086,0x6d4b0026}},	//   _ця_, _تلوي, _باشي, _ymga
  { {0x29050024,0x68ed09de,0xa634005e,0x63700b1f}},	//   ēlas_, _ubad, єнті, käns
  { {0x637000c0,0x7339005e,0x63ad43e1,0xf74b0058}},	// [9950] jäns, бзар_, upan, _نجده_
  { {0xd3710806,0xc7b20b7b,0x8c1b0008,0x63ad43e2}},	//   رها_, _רבי_, בומי, rpan
  { {0x877c0053,0x63700b24,0x63ad43e3,0xdb000123}},	//   _דאזי, vänt, span, mpmä
  { {0x2608000b,0xc0cb0054,0x339501b0,0x25d6000a}},	//   हिरी_, руже_, _намё, _צורן_
  { {0x251a0008,0x637000f2,0xb4c9000b,0xc1040015}},	//   _הורא, tänt, ैली_, بوني
  { {0x7052003b,0xe3b200b2,0xa8580008,0x200d0011}},	//   عنوا, _אױך_, חידה_, _vrei_
  { {0x31c400d7,0x43940170,0x9f4e0030,0x6da2024f}},	//   _оств, _царс, ónát_, нища
  { {0x200d0011,0xb65c000a,0xc212000a,0x6370008c}},	//   _trei_, ידוש, _אהל_, sänt
  { {0xdb09002e,0x69bd000b,0xdfd1002b,0xdb1b016e}},	//   fseð, वीनी, _سيا_, ssuí
  { {0x0b42008f,0x539c004c,0xa296000a,0x4a450a13}},	//   еньн, בסזא, ּ֣יד_, знов
  { {0xce380029,0xc8690053,0x8f680015,0x7a691673}},	//   _وأما_, _ען_, _بملك_, синг_
  { {0x6d4b05c7,0xd7f10016,0x29040052,0x0000006a}},	//   _umga, ẵn_, þma_,
  { {0x4c9a000a,0x17fa0015,0x2c09002b,0xaba90015}},	//   _הבנו, حرجة_, _دعای_, _اهتم_
  { {0x63a20125,0xdbc6007c,0x2608000b,0x6008000a}},	//   íonm, tööj, हिली_, קִרְ
  { {0x2aba000a,0x4b36000a,0x06830004,0x3aba004f}},	//   _המצא, _מרסל_, егрн, _המצנ
  { {0xe9a803c4,0xccf9005c,0x6d5b3969,0x0000006a}},	//   _بدون_, neś_, nnua,
  { {0xf9930008,0x68fb0020,0xc9530135,0xc9850087}},	// [9960] _ארה_, õude, _רמח_, _تشوي
  { {0x6d5b002d,0xe8d90016,0x6370008c,0x66170030}},	//   hnua, _thợ_, väns, égkö
  { {0xa2dd014e,0x273401d1,0xa69b0008,0x569b0008}},	//   _पार्, _länk_, _לשיפ, _לייצ
  { {0x23670085,0x63700a64,0x79b6004f,0x0000006a}},	//   čnja_, täns, פלנד_,
  { {0x216703de,0xc4d3000a,0xc0e7002b,0x6b830012}},	//   чици_, _אגר_, سفون_, _ohng
  { {0x637001d1,0x43930010,0x9889000a,0xd47b000a}},	//   räns, _паўс, חָצֵ, _לאכל
  { {0xde930001,0xa3c6005d,0x4432008c,0x6d5b001a}},	//   нашњ, ैंक_, lyy_, fnua
  { {0xc5f300f3,0x20c90015,0xf8db000b,0x4c940342}},	//   גדה_, _وبقي_, _भाइय, мийс
  { {0x4e960086,0xdbf8000b,0x711b000a,0x70530015}},	//   _فشار, ्टेड_, _פומפ, _كنفا
  { {0xa03b00b2,0x44200251,0xbec20024,0x5a340608}},	//   _הײמז, ixi_, šība, днот
  { {0x6d950007,0xaadd000b,0xcf93000a,0x58d543e4}},	//   _išan, _मारक, _נטע_, монт
  { {0x443200f2,0x395f0020,0x60c2003f,0xfe37000a}},	//   kyy_, õus_, naom, _מרבי_
  { {0xd8380033,0xfc2f012c,0x2fc6001a,0x0000006a}},	//   пэр_, _محو_, nsog_,
  { {0x2c17000a,0xa037000a,0xaae6002b,0xabfb000a}},	//   _מקדש_, לאכה_, _رستو, _להדר
  { {0x7afa43e5,0x4b7b000a,0x25ba0034,0xaa57007e}},	//   mett, _האגו, _cwpl_, _нишу_
  { {0x3ebe43e6,0x60c20020,0xb4d7021e,0x4a5b000a}},	//   _lett_, jaom, सले_, _לדוו
  { {0x6d4a0092,0x25770061,0xdb0004d6,0xed5f013f}},	// [9970] _đoá, nçli_, ppmä, ížil_
  { {0x2bd4005d,0x883c0008,0x21fe0089,0x7afa43e7}},	//   _दिना, _לתחו, _bůh_, nett
  { {0x26c300bd,0x91f90015,0x69da06a5,0x6d5b002a}},	//   majo_, تفاء_, nute, ynua
  { {0x7afa0ddf,0x69da0020,0x26c300bd,0x98a50091}},	//   hett, iute, lajo_, ėlė_
  { {0x96c1000b,0x4add000b,0x7afa43e8,0x3ebe0b14}},	//   वरपॉ, _मालव, kett, _bett_
  { {0x7afa43e9,0x26c300bc,0x6d5e0003,0xb7dc000a}},	//   jett, najo_, épan, מקדי
  { {0x41770074,0xb4d7005d,0x69da43ea,0x27340123}},	//   _فارس, _साफ़_, jute, _sänk_
  { {0x92940010,0xa29405d1,0x69da0fb2,0x10070033}},	//   _часц, _часі, dute, _нязм
  { {0x7afa02d7,0x6f650086,0xdfd40010,0x26c300bd}},	//   fett, _قهرم, _поты, kajo_
  { {0x26c3018c,0x6fd2014e,0x7afa43eb,0x3ebe0123}},	//   jajo_, _सितं, gett, _gett_
  { {0x26c300bd,0x2d9e00b8,0x753d005c,0xc332000a}},	//   dajo_, _gute_, _olsz, דוי_
  { {0x273400c0,0x6d4043ec,0x7afa01be,0xb4c90065}},	//   _tänk_, chma, aett, ैलो_
  { {0xf8bf00dc,0x39430033,0xba77002b,0x2bd4000b}},	//   rkép_, тняг, _کاشت, _दिया
  { {0x7afa34a2,0xdb0b00c0,0x26c300bd,0x4df90053}},	//   cett, _avgö, gajo_, ֿפּא
  { {0x64a60010,0x55e30a61,0x69da0287,0x46a30937}},	//   даба, корб, cute, тасв
  { {0x443200f2,0x2bd4000b,0x19ba000a,0xe3ba249a}},	//   tyy_, _दिमा, _ומקב, жба_
  { {0x26c30467,0x73060010,0xb902000b,0xd3720021}},	// [9980] bajo_, мпаз, दल_, نهر_
  { {0x2b16005d,0x7d0900f2,0x32110089,0x753d00dc}},	//   ताएँ_, hdes, _brzy_, _elsz
  { {0x00e60191,0x443200f2,0x171b0053,0x3ebe13e1}},	//   джен, syy_, _וויע, _rett_
  { {0x3cf9005d,0x7afa43ed,0x3ebe43ee,0xe0d20015}},	//   ्यों_, zett, _sett_, ئزا_
  { {0x48e3005d,0x2d9e0011,0xe3b20086,0x7d0917e3}},	//   ट्टो_, _sute_, _جرج_, ddes
  { {0x43750191,0x69da02f2,0x7d090e90,0xddaa43ef}},	//   _зуст, yute, edes, отил_
  { {0x68e4001c,0x3ebe425f,0x7afa43f0,0x9f8a008c}},	//   _ocid, _vett_, vett, köön_
  { {0x26c300bd,0x1d070001,0x69da0604,0x272b0046}},	//   zajo_, дећи_, vute, _zóně_
  { {0x7afa43f1,0x3ebe43f2,0x3ed60015,0x2fd70058}},	//   tett, _tett_, _يقرر, _يوفد_
  { {0x20040064,0xcb67049d,0x6d4043f3,0x7afa43f4}},	//   _ismi_, мање_, shma, uett
  { {0x2d9e0020,0x26c300bd,0x8f8b000f,0x69da0f7a}},	//   _uute_, vajo_, _וְאֵ, uute
  { {0x7afa43f5,0x7d7a0015,0x673e0030,0x69da43f6}},	//   sett, _بمصر_, _alpj, rute
  { {0xb907005d,0x8d740086,0x8b26000d,0xd7e40210}},	//   _पा_, _قاچا, _одде, кіро
  { {0xab770029,0x60c03664,0x69da43f7,0x629c43f8}},	//   _قمنا_, _lemm, pute, _ngro
  { {0x26c3018c,0xf7940010,0xe5c4058b,0x2d860016}},	//   rajo_, тарэ, ксто, _khoe_
  { {0xab5d005c,0x200443f9,0x60c043fa,0x629c43fb}},	//   duży, _osmi_, _nemm, _agro
  { {0xc2cb0029,0x26c300bd,0x88bc000a,0xa9680021}},	// [9990] قبال_, pajo_, _ומחז, _تميم_
  { {0x32110050,0xd37b008f,0x7d0943fc,0xdb09016e}},	//   _przy_, іча_, zdes, mpeã
  { {0xd25b0558,0xe8d90023,0x7d09022d,0xd2510029}},	//   цца_, _chủ_, ydes, دنا_
  { {0x59df000b,0x69c8158f,0xa1580db7,0x6b9801ee}},	//   पंतर, isde, маху_, _livg
  { {0xf4090029,0x7d0943fd,0x2eee128a,0xb97c004f}},	//   _عيسى_, vdes, ffff_, קנדי
  { {0xaadd005d,0x3211005c,0x84160053,0x670f005d}},	//   _माइक, _trzy_, _אַלף_, ायिक_
  { {0x60c01fda,0xd0d50063,0x7d0900bc,0xddc00033}},	//   _femm, _повъ, tdes, атыi_
  { {0xd5b10023,0x60c000fb,0x7d0900f2,0x8d540010}},	//   ấy_, _gemm, udes, ктыч
  { {0xe4a80008,0x7d0943fe,0x0000006a,0x0000006a}},	//   וֹתָ, rdes,   ,
  { {0x26c1002c,0xeab10015,0x3a25058e,0xba2543ff}},	//   _neho_, دعة_, емог, едок
  { {0x9f8a022d,0x99590046,0x6e040058,0x7c64009a}},	//   töön_, léř_, _لِلن, فایل
  { {0xfe36000a,0x186a0121,0xcdb6000a,0x0000006a}},	//   _ארעי_, зами_, _נפנה_,
  { {0xdd940010,0x66054400,0x6aaa128a,0xab5d0535}},	//   _рацы, _ashk, _ffff, zuży
  { {0xdb090020,0x9f8a00f2,0x613a0251,0xcc56000a}},	//   tseõ, söön_, _aïll, _אבני_
  { {0xa3e2005d,0xfe670087,0xd62a0c55,0xe6171fdd}},	//   नून_, اد_, чове_, ндр_
  { {0x68e40045,0x629c0034,0x0000006a,0x0000006a}},	//   _ucid, _sgro,   ,
  { {0xb3860080,0xb7960001,0x32d60937,0x7bc94401}},	// [99a0] елал, _проћ, ецес, nseu
  { {0xe8d90023,0x60c01238,0xd83f01cb,0x661b0046}},	//   _phủ_, _semm, íček_, ácký
  { {0xda1f005d,0xb6bb0008,0x599a0008,0xf772002b}},	//   यमित_, _מציי, ִשְׁ, _لاگ_
  { {0x7bd5005c,0x0657004c,0xc1760067,0xab5d002a}},	//   ązuj, _טייך_, ردات, ruży
  { {0xf9930053,0x7bcf0c98,0xcff2002b,0xed50002b}},	//   ארא_, ácul, ايتک, یپت_
  { {0xe8d90023,0xe45700b2,0x629c4402,0x2d8600da}},	//   _thủ_, _װילט_, _ugro, _shoe_
  { {0x7a460152,0x60c04403,0x33630054,0x7bcb3c3d}},	//   _mété, _temm, _сврг, _avgu
  { {0xe2972bb2,0x127b004c,0xd43f0033,0xe06a0015}},	//   _час_, _זאלע, лiшч, _فإذن_
  { {0x1be70124,0xa2b4000b,0x6143243d,0x6fb60058}},	//   едњи_, इडप्, _сета, _أمطا
  { {0x39404404,0x6fb30015,0x3e860046,0xdfcf0015}},	//   _alis_, _إملا, _cítí_, _ديك_
  { {0x7f2b000a,0x418a000a,0x9f2b000a,0x68fd4405}},	//   _מֵאֶ, ּנָ֑, _מֵא֖, tesd
  { {0xfc66010f,0x224501e2,0xdca30a9d,0xf1c70046}},	//   _пълн, _ülke_, _баци, _žáky_
  { {0xd0060029,0xcc330015,0x4864006b,0x6d0b004f}},	//   جل_, _مروع, гърб, _מִגַ
  { {0x8c1b0008,0xb9c60015,0x99d3002b,0x39404406}},	//   _מודי, _كتبه, ختیا, _elis_
  { {0x8f8b000a,0xbdf4000a,0xee2e005e,0x7a460003}},	//   לְלֵ, כֶּה_, инi_, _dété
  { {0x4a7b0008,0x8a7b0008,0x25ac0264,0xda7b000a}},	//   _מרוב, _מאות, ídla_, _מנור
  { {0x28b40029,0x98170015,0x34950033,0x26c14407}},	// [99b0] _صحيح, _أبعا, таар, _teho_
  { {0x8627008f,0x26cc0030,0xb6040091,0xa2d50040}},	//   _зьме, ódot_, ššau, ئيات
  { {0xcad7013a,0x32670010,0x32190015,0x54b9004a}},	//   תובת_, хтав, بياد_, _огня_
  { {0x7fd5005e,0x4155006b,0xd0d5006b,0x41740040}},	//   вікі, ъвес, тодъ, هانس
  { {0xb4cd005d,0xe1340010,0xf8b2000a,0x33950015}},	//   रणी_, ынцы, ׁשׁ_, _للحز
  { {0xbec20024,0x25770061,0xbdf50054,0xd25b0891}},	//   šīna, rçlu_, вчић, _ецб_
  { {0xfd110029,0xc332000a,0x7bc90016,0xee09006b}},	//   لجة_, _דום_, wseu, фейл_
  { {0xfe7000b0,0x2d9919e4,0x3e860046,0x7e6d0045}},	//   حده_, öse_, _sítí_, şapo
  { {0x2d8d0384,0x273400c0,0xfc310015,0x752f002a}},	//   rmee_, _känt_, شحة_, _mocz
  { {0x78ad0144,0x7bc924d9,0x89a9008a,0x71d5004f}},	//   _afav, rseu, мков_, ֣וֹד_
  { {0x7bc94408,0xa96a1972,0xd94605aa,0xba220033}},	//   sseu, дина_, вени, адэк
  { {0x9c390001,0x7db40029,0xbdf8002b,0xf769000a}},	//   _опет_, _إصلا, _سرما_, _וק_
  { {0x69de003c,0xeb8e05c8,0xc052004f,0x0000006a}},	//   _åpen, _ви_, ֹ֖ר_,
  { {0x4b7900b2,0x41d1005d,0x661a00c0,0x48030004}},	//   _קאַו, _हिंस, åtko, јпрв
  { {0xc8b60080,0x752f005c,0x6dac000a,0xceb2000a}},	//   _испы, _bocz, ּׁמֶ, שיל_
  { {0xe8d90023,0xc56305c4,0x250b002b,0x56590058}},	//   _phụ_, акск, ورقی_, رشّح_
  { {0x7d0b00b6,0x130a0010,0x752f002a,0xf74a0015}},	// [99c0] _mags, мнай_, _docz, _يلبي_
  { {0xe73a0001,0x9343070e,0x7d0b2749,0xfbd4000b}},	//   _цео_, ануе, _lags, _दिसम
  { {0xb6d900b4,0xb87b016e,0x558a00ce,0xddc80535}},	//   _אַרט, ngín, _обом_, _wydź
  { {0x7d0b00b6,0xe8d90092,0xa3e2000b,0xdfd20015}},	//   _nags, _thụ_, नंद_, ليص_
  { {0xc0e30fa5,0x3ff40058,0x71650058,0xd0070138}},	//   рочк, اكتر, دالك, кеце_
  { {0x27340020,0xdbdb001a,0x3033004a,0xf837000a}},	//   _tänu_, _ráðg, решё, כננת_
  { {0x7d0b02de,0xa2f7000a,0x68f64409,0xe16a0058}},	//   _bags, _שמלה_, _obyd, _قصره_
  { {0x90a50029,0x68f60034,0x0000006a,0x0000006a}},	//   _محكم, _nbyd,   ,
  { {0x7d0b440a,0x6be30015,0xbb740180,0xac180033}},	//   _dags, لكيم, лгиј, хопу_
  { {0x2019001c,0x7d0b0125,0x3eaa0012,0x78ad02b9}},	//   _ásia_, _eags, _übt_, _sfav
  { {0x1b770029,0x2bd4000b,0xd337000a,0xc333000a}},	//   خصية_, _दिवा, דריה_, יוז_
  { {0x0e57000a,0xdd96012c,0x7e57000a,0xe945002b}},	//   _בשבט_, _شجاع, _בסבב_, اردی
  { {0xdb09002f,0x1b2a0029,0x752f005c,0xf7730087}},	//   speá, _يأتي_, _rocz, لاس_
  { {0xec370008,0xf093000a,0x7a53002b,0xc5ff003d}},	//   _באדר_, ינר_, اضیا, ņēmu_
  { {0x752f0050,0xa4d5192f,0x7e860089,0x5e78000a}},	//   _pocz, лові, _úspě, גָּד
  { {0x35440036,0x7d00440b,0x27340123,0xca97004f}},	//   ахув, nems, _sänt_, _בדוי_
  { {0x2458005f,0x6ab10030,0x286b005e,0x28a8000b}},	// [99d0] вать_, _éjfé, _юрко_, _गलति
  { {0x7d1d00dc,0xa2950033,0xdce00046,0x7d00440c}},	//   össz, газі, tomě, hems
  { {0x10d50010,0x752f002a,0x4874002b,0x49180065}},	//   гілё, _tocz, _مدیس, _बोडो_
  { {0x69da002f,0x28a7000b,0xde880033,0xdce00046}},	//   irte, कुचि, _ўсiх_, romě
  { {0x69da00b8,0x63a2002d,0x7d0b0030,0x7d00440d}},	//   hrte, íont, _rags, dems
  { {0xaed20001,0xda660015,0x6d420045,0x0f35002b}},	//   бољш, _هُ_, _aloa, دکرد
  { {0x7d0b00b6,0xb06200f2,0xfd990054,0x69da02de}},	//   _pags, _ääni, нтић_, jrte
  { {0x2bd4000b,0x644a002a,0x6d4201fd,0x15fc0065}},	//   _दिशा, źliś, _cloa, _उईघर_
  { {0xa1580001,0xeb9911d9,0x91b00092,0x69da440e}},	//   _рату_, нии_, _đảo_, erte
  { {0x4add005d,0xe452000a,0x4b2509ac,0x629a0046}},	//   _माओव, מֶת_, умов, _útoc
  { {0x2bc4005d,0x7d0b0c19,0x6d423858,0x3e35002b}},	//   लीबा, _tags, _floa, _حفار
  { {0x4a420036,0x2e3a0053,0x48e3005e,0x4c150015}},	//   снюв, _אגענ, боюв, _مبتس
  { {0xed590046,0x0303000b,0x69da440f,0x0000006a}},	//   miž_, रजाह_, arte,
  { {0x25ac0107,0xcc3a004c,0xc7a3029b,0x0676006b}},	//   ídlo_, _רעסט, сирк, губя
  { {0x7af40030,0x39594410,0x36670d7a,0x290401f6}},	//   égtő, biss_, гаро_, ômas_
  { {0x69950010,0x2cad225f,0xf8a8000b,0xca36000a}},	//   _крых, nced_, _गलिय, _תנקה_
  { {0xc9530008,0xf2da0015,0x6d5e0003,0xc7a60d3c}},	// [99e0] _למה_, فظات_, épai, _щипк
  { {0x290212e7,0x37061305,0x27340123,0xdc88000a}},	//   leka_, _спог, _väns_, דְעָ
  { {0x6fc1000b,0x9a89000a,0x8b56004c,0xe0da4411}},	//   रीसू, תָּ֗, ניעס_, еве_
  { {0x9fca0080,0x2bd4005d,0x106a004a,0xea76004c}},	//   егда_, _दिला, нией_, אגער_
  { {0x43860015,0xed590046,0x29020073,0x0000006a}},	//   _ملحق, diž_, ieka_,
  { {0x643b0053,0xde580210,0xd00f0015,0x1eaa00c3}},	//   _טעכנ, калі_, ثله_, راتي_
  { {0x7bdb00f2,0x38970046,0xd357000a,0x6564007c}},	//   eruu, měrů_, _עילי_, onih
  { {0x6564002e,0x2902016f,0x69da0089,0x1d34085d}},	//   nnih, jeka_, vrte, рния
  { {0x65640035,0x69d50089,0x68fb007c,0x63a601d7}},	//   inih, ázen, õudm, _jukn
  { {0x69da00bc,0x2cad00da,0x39590383,0x3eb70046}},	//   trte, aced_, wiss_, četí_
  { {0xfbcf0086,0x03770008,0x657600f2,0x3377000a}},	//   يتی_, רתית_, koyh, רעים_
  { {0x637000b8,0x69da0012,0x98a50091,0xd7e700e2}},	//   gänz, rrte, ėlį_, ліго
  { {0x3f9e4412,0xdce90064,0x31570053,0xb9540146}},	//   _kitu_, lleğ, ריכן_, свящ
  { {0xe945002b,0xb4cd000b,0x69da00bc,0x0a9402a3}},	//   ارگی, रण्_, prte, _калю
  { {0x3f9e0020,0x63a6002e,0x99ea0015,0xf990002b}},	//   _mitu_, _aukn, _أعتق_, تبی_
  { {0x44b500ce,0x3f9e0052,0x0000006a,0x0000006a}},	//   рбас, _litu_,   ,
  { {0x54990010,0x2605000b,0x13b40015,0x44990033}},	// [99f0] тваў_, _हैरी_, مصلح, тваю_
  { {0x94740029,0x98be0091,0x34940099,0xd49829b7}},	//   صدقا, ėtą_, саур, урс_
  { {0x05790029,0xaadb0008,0x798d00e8,0x70b50029}},	//   _لمدة_, תחבר, _khaw, لماض
  { {0x1fb50010,0x11280063,0x82340015,0xf8b5000b}},	//   аскр, лючи_, حركا, ंडिय
  { {0xf105000b,0x8d75002b,0x14f40033,0x9102005e}},	//   _रसीद_, یابا, _узяў, іпше
  { {0x3f9e0048,0xddc80007,0x29020fcd,0xa3f6000a}},	//   _citu_, _dydž, zeka_, _דמשק_
  { {0xddc20457,0xed590107,0xd738000a,0xdcfa0061}},	//   общи, tiž_, רטות_, _attı
  { {0xd658013a,0x9658004c,0x7946002a,0x7bdb4413}},	//   טיות_, טשוא_, _mówc, truu
  { {0x2d5304f9,0x6ee70086,0x2cad3396,0x644d0003}},	//   nţei_, _مسال, rced_, nzai
  { {0x2902000c,0xab35009c,0x3f9e013c,0x7d25002b}},	//   weka_, рхиј, _gitu_, افکن
  { {0x7bdb0209,0xa155000a,0x29024414,0x69262b44}},	//   sruu, ֹבָה_, teka_, амна
  { {0x273d0023,0xb33b0064,0x49b90086,0x60cb4415}},	//   _hình_, _suçl, _یابد_, nagm
  { {0x6d49002d,0x29020375,0xb4db0144,0x752d2f19}},	//   mhea, reka_, _plàn, djaz
  { {0x6c840015,0xc016000a,0xdcfb0091,0x9f95000a}},	//   _الهم, בקשו_, iluč, ידָה_
  { {0x273d0023,0x26ca018c,0x6f030077,0x6576008c}},	//   _mình_, rabo_, ienc, toyh
  { {0x6f030ccc,0x6d494416,0x63a60160,0x0000006a}},	//   henc, nhea, _pukn,
  { {0x7c3b013c,0xb97b000a,0xb9930015,0x6d49008c}},	// [9a00] nyur, _בנקי, _بليب, ihea
  { {0x60cb002d,0xdcfb016f,0x224d0046,0xf7460054}},	//   eagm, dluč, _řeka_, _ђено
  { {0x02190010,0x6b8138c5,0x6f03164a,0xd6db000a}},	//   ліць_, illg, denc, _בחיל
  { {0xf9930053,0x61460001,0x3f9e0375,0xc05a005e}},	//   ַרג_, једа, _situ_, кіл_
  { {0x273d0023,0x6f03003e,0x205605e6,0x94bb000a}},	//   _bình_, fenc, јтер, _במכת
  { {0x69c34417,0x9f530210,0x6dd40015,0x2d930144}},	//   _owne, овіч, مقتض, ïxen_
  { {0x3f9e000c,0x69d50089,0xde180018,0xbd6a0254}},	//   _vitu_, ázel, اقبت_, крие_
  { {0x6d492f78,0x2fda0015,0xc0e31560,0x78a4063b}},	//   ghea, _لورد_, _моск, _ngiv
  { {0xdee600d7,0xc19b000a,0x6f030a3d,0xdce90061}},	//   _вози, _ישלי, benc, sleğ
  { {0x637000f2,0xef17005e,0x798d4418,0x752d002a}},	//   täny, _кму_, _shaw, zjaz
  { {0x6d49002d,0xc987000d,0x798d0034,0x9999067a}},	//   bhea, иуми, _phaw, лкот_
  { {0x6d494419,0x5a33005e,0x6b810030,0xd83f006f}},	//   chea, інят, allg, íčok_
  { {0x58870010,0x386d0064,0x2bdd000b,0x6722000b}},	//   рына, çer_, _मिया, मांक_
  { {0x1bfb0008,0xba180015,0x79a60190,0x6ffa003d}},	//   _סלוב, _ميتا_, _крие, mācā
  { {0x69c30176,0x8b8b000a,0xd90f002b,0x7aef0227}},	//   _gwne, _בָהֶ, _قید_, žitý
  { {0x4a9b0008,0x44290251,0x6a9b000a,0xd5b8005e}},	//   _ביוג, txa_, _בשונ, рср_
  { {0xf8bf08e0,0x7946005c,0x6d400111,0xd6db000d}},	// [9a10] mbé_, _wówc, ikma, _итн_
  { {0xec7100b2,0x442908e0,0xa87c0008,0x2d530045}},	//   פֿן_, rxa_, _באחר, rţei_
  { {0x55590063,0x41e7005e,0x92b40021,0x644d0030}},	//   _баня_, різа, تحقا, szai
  { {0x5555002b,0xd1780033,0x6d400079,0xa134002b}},	//   _چپگر, асіі_, jkma, يرنش
  { {0x6b810026,0xa0540036,0xf8bf0125,0x1007033d}},	//   yllg, овці, ibé_, ряем
  { {0x6d49055e,0x6d40441a,0x8ee800ce,0x6da50204}},	//   whea, ekma, имів_, бика
  { {0x6d49311d,0x6f03164a,0xed5939e7,0x6e440015}},	//   thea, renc, лок_, ينهم
  { {0x7c290251,0x6f03164a,0x9f5f001a,0xc537000a}},	//   txer, senc, _eruð_, יָ֖ה_
  { {0x273d0023,0x6d49441b,0x7c3b0061,0x7c29016e}},	//   _tình_, rhea, uyur, uxer
  { {0x6aa401e2,0xefb30086,0x3b090001,0x2bdd000b}},	//   _şifr, _هیچگ, ћено_, _मिठा
  { {0xdce90085,0x39e9004a,0xbe150015,0x3a99004a}},	//   sleđ, ыдно_, _دواع, ытию_
  { {0xa3e2000b,0xfc33006e,0x6d403bbd,0xc95602ed}},	//   नूँ_, _وحش_, ckma, ётны
  { {0x7d740029,0x8d740806,0x3c440029,0x2cbf0134}},	//   _بالط, _بالا, _وَمِ, mbud_
  { {0xf1a7014e,0x60c900dc,0x8c1a0008,0x2cbf01f0}},	//   गदान, _leem, _תוסי, lbud_
  { {0x78a9018c,0xf8bf00dc,0xe6430286,0x19b500e6}},	//   ževa, bbé_, перп, _احتج
  { {0x60c90111,0x6d950091,0xc5690058,0xf9920369}},	//   _neem, _tšau, لحقل_, _عبث_
  { {0x442603af,0x23980086,0x04460054,0xc3c90015}},	// [9a20] ão_, لمرگ_, љезн, لظلم_
  { {0x2912441c,0xd24f0086,0xe29a0354,0xe64619db}},	//   _haya_, کنم_, газ_, _геоп
  { {0xf1a90087,0x291220fb,0x113a01b0,0x0000006a}},	//   لانه_, _kaya_, ляды_,
  { {0xc6930008,0xda7a0053,0x29120509,0x908a0015}},	//   _מאת_, אנער, _jaya_, هناك_
  { {0x8ff70029,0x69d50089,0xdfcf0115,0x60c94216}},	//   مرور_, ázej, فين_, _deem
  { {0x42530086,0x389b000a,0x291202f2,0x6d590c48}},	//   _کنفر, איננ, _laya_, _amwa
  { {0x2dd70015,0x1dd70015,0x200d01c2,0xf1b8004f}},	//   مبية_, مبيع_, _esei_, _כֶּל
  { {0xfc46013f,0x7d1c003d,0x6d402891,0xebd8009b}},	//   šími_, ērso, ukma, адиш_
  { {0x3cf70015,0xcbc60015,0x6d400108,0x705600c3}},	//   صعيد_, حزبي, rkma, _انذا
  { {0x6e930086,0x9b58000d,0x68ed11c8,0x60c9441d}},	//   _کلما, риот_, _scad, _zeem
  { {0x8e8600e6,0x3f9b0152,0x7c240007,0x29122c36}},	//   _الاه, ïque_, _šird, _baya_
  { {0xa8990001,0xdd8f0015,0x0000006a,0x0000006a}},	//   икну_, _كول_,   ,
  { {0x29120665,0xdfc60015,0xf8bf0003,0xe0ce005e}},	//   _daya_, بي_, rbé_, євi_
  { {0xf8bf00dc,0xec67000a,0x0000006a,0x0000006a}},	//   sbé_, _ל֑וֹ_,   ,
  { {0x99d30015,0x6d590034,0x5dd8000a,0x2dd8000a}},	//   _فتيا, _ymwa, יַּס, יַּב
  { {0x291205f3,0x142b005e,0x0000006a,0x0000006a}},	//   _gaya_, лізо_,   ,
  { {0x99480225,0xe534005e,0xb8df000b,0xf487005e}},	// [9a30] _دليل_, четь, ेर_, сувн
  { {0x60c93bd6,0x39490107,0xe3c40015,0x02a71d8a}},	//   _seem, _hlas_, سْمَ, срам
  { {0xe5350080,0x8afc005c,0x51870010,0x6fc6000b}},	//   _день, międ, буда, रीसं
  { {0xf992004f,0x49ab004f,0x0000006a,0x0000006a}},	//   ֵ֨א_, אשׁ֑,   ,
  { {0x9516000a,0xa98c000a,0x60c9441e,0x3dc50034}},	//   _וקרא_, נָבִ, _veem, _swlw_
  { {0x8afc005c,0x4394006b,0x60c91e8a,0xf1a71f54}},	//   nięd, _наяс, _weem, _гран
  { {0x60c9041c,0x39490ab3,0xcd2902ed,0x0000006a}},	//   _teem, _olas_, ижке_,
  { {0x2bd4014e,0x1c45005e,0xdce0003d,0xa4bb000a}},	//   _दिखा, жним, domē, נֶ֔י
  { {0x6fe0005d,0x291208c0,0x2bb90015,0x5ba90054}},	//   _नियं, _raya_, جابة_, јком_
  { {0x6d5e0152,0x2912013c,0x9b920021,0x3949441f}},	//   épar, _saya_, وليت, _alas_
  { {0xfeb80015,0x39494420,0x29124421,0x7cd9012c}},	//   _طالت_, _blas_, _paya_, _نواز_
  { {0x6fe0005d,0x7c24016f,0x78a901a3,0x5e440015}},	//   _निमं, _šire, ževn, _عَنْ
  { {0x291202c1,0x224d0089,0x8d740015,0x317a004c}},	//   _vaya_, _řekl_, _عاما, שארד
  { {0x409a0008,0x39494422,0xf863005e,0xda090015}},	//   יברס, _elas_, євро, _نيته_
  { {0x0b780029,0x9ae8000a,0x4b7a000a,0x46a30033}},	//   _اصنع_, _הַפִ, _דאסו, дарв
  { {0x91b00016,0x785c003d,0x458602a3,0x39494423}},	//   _đào_, tāvī, ігав, _glas_
  { {0xe577042b,0xd9970015,0xe2ca005e,0x78ad0046}},	// [9a40] ізу_, _بنيت_, илад_, ťová
  { {0x7c24002f,0x82f60033,0xf77f016e,0x7dd00030}},	//   _áire, ўчац, puça_, _jósá
  { {0x8afc005c,0x321c01c9,0x64a64424,0xd62a0da9}},	//   sięg, ívy_, _мана, _тоне_
  { {0x2eb4000b,0x10a603ea,0xa8ad004f,0x90460058}},	//   ुर्त, цидн, ְבוֹ, يناه
  { {0xee02014e,0x34a70036,0xc9530008,0x25e6000b}},	//   लब्ध_, _євро_, ומא_, जूरी_
  { {0xcdda009c,0x2cb2002a,0xf8bf0030,0x6fdb000b}},	//   ањи_, _żyd_, ljét_, _निरू
  { {0x79460050,0x1219008f,0x7f750010,0x7e2a005e}},	//   _równ, _люты_, чуцц, ріла_
  { {0x628e065d,0xf8bf00dc,0x9103009c,0xf8b6000b}},	//   _izbo, njét_, _опсе, ूरोप
  { {0xddce005c,0xeb060e77,0xa4b7000a,0x60c24425}},	//   ódło, очно, חלפה_, mbom
  { {0x60c20007,0xba54049d,0x2aaa0054,0x798600aa}},	//   lbom, звој, штио_, elkw
  { {0x8f9b0008,0x39491af2,0x670e000b,0x298b0684}},	//   _כימי, _plas_, ाजनक_, исмо_
  { {0xd126002b,0x8ba6024f,0x60c22b33,0x0000006a}},	//   رم_, _дидж, nbom,
  { {0xcb6a0083,0xd87e009a,0xf8bf01d3,0x7aeb01d3}},	//   _каде_, ﻳافت_, djét_, últá
  { {0xdb2000f2,0x3b07006b,0x0000006a,0x0000006a}},	//   ätäm, _мечо_,   ,
  { {0xcf570008,0x4db8000a,0xb595131f,0x65950174}},	//   קבלת_, מֶּנ, зивш, заву
  { {0x93b51923,0x394901c2,0xa5dc0065,0x8afc0535}},	//   збац, _ulas_, _फिरौ, sięd
  { {0xe8730074,0xb2ab0080,0x54550661,0x91b00016}},	// [9a50] _زندگ, атеж_, чват, _đáo_
  { {0x2bdd005d,0x60c2003c,0x23740067,0x0000006a}},	//   _मिसा, ebom, والح,
  { {0xa2ad0372,0xd3780010,0xc4c70015,0xdb0300aa}},	//   जशब्, ічу_, _وتحو, _binê
  { {0x7ff50029,0xa1590001,0xdd860087,0x26d14426}},	//   كستا, љаду_, _سو_, lazo_
  { {0x6fc6005d,0xf4842565,0xf1180058,0xf770009a}},	//   रीलं, _журн, تغلت_, _سای_
  { {0x26d1003f,0xc43a000a,0xf43a000a,0xc49a000a}},	//   nazo_, _התשי, _הגשמ, _לשרת
  { {0xc3320135,0xa2a2000b,0xbea21833,0xfe45027a}},	//   _אום_, _कृप्, нашк, янко
  { {0x0000006a,0x0000006a,0x0000006a,0x0000006a}},	//     ,   ,   ,
  { {0x399b03eb,0x69dc00dc,0x26d1003f,0xdd8e0015}},	//   _jūsu_, áren, kazo_, دوي_
  { {0x399b0048,0x26d1003f,0xdb07007f,0x0000006a}},	//   _mūsu_, jazo_, _ölün,
  { {0x98b00085,0x26d10077,0x4c15002b,0xd195004f}},	//   šača_, dazo_, زبکس, ּכָי_
  { {0xf9920029,0x8dfa0008,0xa96a057e,0x5dfa000a}},	//   عبد_, _להעת, сима_, _לפענ
  { {0x31560053,0x6d4b4427,0xe76a0015,0x7d094428}},	//   פישן_, _ilga, محسن_, mees
  { {0x26cc03af,0x907a039e,0x26d12e65,0x3bba000a}},	//   údo_, מטרי, gazo_, _המסד
  { {0x65c60063,0xd9461179,0xf8bf0030,0xba770015}},	//   ябва, _неки, tjét_, _باشت
  { {0x2a3a0008,0x89da0008,0xb33b001c,0x7d094429}},	//   _לעצמ, _החקי, _muçu, nees
  { {0x26d1000c,0x43460004,0xd4090015,0xf8bf0030}},	// [9a60] bazo_, пеав, يتكم_, rjét_
  { {0x7d09022d,0x8afc005c,0x629a0057,0xe819000b}},	//   hees, mięc, _útok, दिरा_
  { {0x7d09008c,0xc16f005e,0xdb000123,0x4256158e}},	//   kees, еї_, ppmö, чтат
  { {0xd1300015,0x7d09008c,0xfaf8003d,0x628e0046}},	//   ضمت_, jees, lnīt_, _vzbo
  { {0x8afc0050,0xc9530008,0x351b000a,0x7d09007c}},	//   nięc, עמד_, _הוכנ, dees
  { {0x6d4b1a6a,0xc7d7000a,0xb33b0061,0xff230054}},	//   _alga, לוני_, _buçu, емљо
  { {0xa91b002e,0xfaf80024,0xb74d000a,0xbdf70015}},	//   amþy, inīt_, שׂוֹ, كريا_
  { {0x6da300d7,0xd1320087,0x5e430015,0x3f870085}},	//   нија, _ثمر_, عَيْ, alnu_
  { {0x6fb600e5,0x5bb70033,0x404a0054,0x61eb002a}},	//   _رمضا, плыя_, _упао_, ągle
  { {0xff240086,0x49d80036,0x29000011,0x2b55002b}},	//   _تبری, одою_, _abia_, ویند_
  { {0xf1c30092,0xc33301d8,0x22f7000a,0x9a260015}},	//   _nhớ_, תות_, הזין_, سعدن
  { {0x26d1003f,0xce050015,0x0000006a,0x0000006a}},	//   wazo_, _تذكي,   ,
  { {0x26d1003f,0x315701ac,0xac9a002b,0xcc290015}},	//   tazo_, ליטן_, _انشا_, _وأهم_
  { {0xd7f8155e,0x4c9b000a,0x8beb004f,0xdc9b004f}},	//   чую_, _הבדו, _הַה֗, _הידל
  { {0x8afb0008,0xb87b00dc,0x50cc005d,0xb604022a}},	//   _להגי, egít, ाराष, нятк
  { {0xe5340033,0xe8d90016,0x8505002b,0x84e90369}},	//   несь, _thự_, بورن, تفرق_
  { {0xf74b002b,0x8afc002a,0x73390788,0x67650058}},	// [9a70] _هجده_, cięc, озар_, _يُعل
  { {0x43740015,0x722b01c5,0xe9ff0016,0xc7b4000a}},	//   ّهْر, йцев_, _hoại_, _אבץ_
  { {0x224700dc,0x32b80029,0xdb0b02ce,0xd2510015}},	//   ánk_, سدلة_, _utgå, خنا_
  { {0xe2980036,0xa3b50036,0x2bdd021e,0x260a000b}},	//   чає_, _обмі, _मिला, ाबरी_
  { {0x29d80023,0xdb1b0467,0x351a000a,0x3d10000b}},	//   hĩa_, spué, _וורנ, ढ़ने_
  { {0xe9ff0023,0x7d090111,0x69d804ed,0x40320001}},	//   _loại_, wees, _ovve, тељс
  { {0x7d09022d,0x8afc005c,0xed5902bf,0x8e09005e}},	//   tees, zięc, жой_, інив_
  { {0x9e640021,0x7c2400b3,0x656d442a,0x290b0085}},	//   عاون, _šira, nnah, jeca_
  { {0x46bf005d,0x69d8442b,0x656d0035,0x96bf000b}},	//   ्राह, _avve, inah, ्राउ
  { {0x9906005d,0xdb03442c,0x7d090044,0x5f450015}},	//   षज्ञ_, _xinè, sees, _تنطل
  { {0xdb030089,0x63a70111,0x8afc005c,0x02b6000a}},	//   _jiné, _mijn, więc, ולתך_
  { {0xdce00007,0xe6c6005d,0x63a70111,0xd95a0036}},	//   domė, वर्ज, _lijn, ішні_
  { {0x7d5600b2,0x0c250010,0x5b350029,0xdb030003}},	//   _קינד_, _імкн, _يعتر, _liné
  { {0x4c9a0008,0x9b45002b,0xfbd20643,0xab29012f}},	//   _ובנו, _زنبو, _יתד_, _фока_
  { {0x8afc0050,0x656d00b8,0x2aba000a,0x64b30046}},	//   sięc, fnah, _ומצא, křič
  { {0x19870063,0x2900003f,0x8afc002a,0x69c10ebc}},	//   _общи_, _ubia_, pięc, mple
  { {0x7984000c,0x63a70111,0xf993000a,0x69c1442d}},	// [9a80] _ikiw, _bijn, _ברה_, lple
  { {0xdb0902c1,0x656d442e,0x7d1c003d,0xf9040091}},	//   mpeó, anah, ērsi, ūšės_
  { {0xdb031fec,0x5f18000b,0x656d0012,0xd5e60214}},	//   _ciné, _योग्_, bnah, _южни
  { {0xa87a00b2,0x69c127a4,0x66290069,0x9c820069}},	//   ֿאַר, iple, šský, íčko
  { {0x41170015,0x63a70079,0xb4db0144,0xdb0b442f}},	//   بينج_, _fijn, _clàu, _eugé
  { {0xcfa90029,0xa857000a,0xce94006b,0x670e000b}},	//   ساهم_, וינה_, налъ, ाजिक_
  { {0x53a7014e,0x90e60015,0x4dd30058,0x776901f6}},	//   _कूटश, _يسرن, نتيس, éexi
  { {0xa2c6005d,0x63a70111,0x69c10159,0xc5f3000a}},	//   िरक्, _zijn, dple, דדה_
  { {0xcd330029,0xa2a2000b,0x6fb30015,0x00830054}},	//   ضريب, _कृत्, _لمقا, _алто
  { {0x7984003f,0x5a34017a,0x442207c4,0x69c10546}},	//   _akiw, енот, _mrk_, fple
  { {0xcf93004c,0x6e460015,0x290b0992,0x0000006a}},	//   _סטע_, _تنام, teca_,
  { {0x1c460001,0x4cd60086,0xdb1b001a,0x79960034}},	//   _онем, _آغاز, ssuð, _chyw
  { {0xfc2f00e6,0xb8d7005d,0xc07b004c,0x6d9b000a}},	//   _نحو_, _जल_, ַטלש, _ובאפ
  { {0x290b01a3,0xfc67002b,0x39920125,0x0b180015}},	//   seca_, _تخمی, tásc_, _رقبة_
  { {0x63a7158f,0x656d0012,0xd9f2000b,0x44224430}},	//   _rijn, tnah, _अमित_, _ark_
  { {0x994401e2,0x63a70079,0x61e50069,0x63af0085}},	//   mış_, _sijn, vrhl, _pucn
  { {0x7d02002f,0x78ad0020,0x99440064,0x656d3282}},	// [9a90] _mbos, _igav, lış_, rnah
  { {0x8c1b0008,0x656d4431,0x39920030,0x61e5013f}},	//   חומי, snah, mása_, trhl
  { {0x39920014,0x64b30089,0x442229e2,0x9045002b}},	//   lása_, třič, _erk_, کنشه
  { {0xe4eb0029,0x63a70079,0xa69a000a,0xe9ff0016}},	//   _بعده_, _wijn, _משתפ, hiếm_
  { {0x80270029,0x399200dc,0xb822000b,0xe822000b}},	//   برام, nása_, मियम_, मिया_
  { {0x99440064,0x84ef000b,0x6fe0000b,0x39b70045}},	//   kış_, _छाँट_, _निरं, _lăsa_
  { {0x753d0050,0xc1770002,0xce49004a,0xcee80015}},	//   _kosz, _قدرت, язке_, ذرون_
  { {0xa294008f,0xcce50015,0x39920030,0xfe70012c}},	//   _расі, رسعي, kása_, جده_
  { {0x79960176,0x10140015,0x3af5027a,0x8c160015}},	//   _rhyw, _لبلد, нянс, فيير_
  { {0x7d020176,0x39920014,0xfeb80029,0x0f180015}},	//   _ebos, dása_, _قامت_, _يغلب_
  { {0xc3320008,0x7c220011,0xdcfb0089,0xc869000a}},	//   אוי_, _eror, louč, _פן_
  { {0x753d172d,0x6283002a,0x6c750054,0xdc75056d}},	//   _nosz, żnow, _пулх, _пыль
  { {0x291e0089,0xc052000a,0x39920030,0x69c14432}},	//   ěta_, ָ֖ר_, gása_, sple
  { {0x7d1b0005,0xcc3a00b2,0x7946005c,0xb5aa0015}},	//   ldus, _מענט, _mówi, كارك_
  { {0xceb200f3,0xc9f50015,0x7d1b007c,0xd5b200e5}},	//   ריל_, _أستع, odus, افر_
  { {0x7d1b1c23,0x7984003f,0x6fe0005d,0xdb0902c1}},	//   ndus, _ukiw, _निलं, mpeñ
  { {0x753d005c,0x6d4900f2,0x27e64433,0xf772002b}},	// [9aa0] _dosz, ikea, _íon_, _ماد_
  { {0xe2920029,0x7d1b00f2,0x7d19003e,0xa2bb000b}},	//   هذا_, hdus, _laws, शुल्
  { {0xb4db0144,0x6146070e,0x6d4900f2,0x00e62003}},	//   _clàs, нежа, kkea, ежен
  { {0x61e30014,0xe0d2012c,0x05760021,0x6b814434}},	//   ánla, ازا_, _ساجد, holg
  { {0x14d70008,0xd083004a,0x7d1b4435,0x673e4436}},	//   _אוכל_, лыши, ddus, _kopj
  { {0x4420003f,0x99440061,0x7c2406ca,0x1ee6002b}},	//   mvi_, yış_, _širo, روعی_
  { {0x39920014,0x6b660152,0x6b814437,0xa2f7000a}},	//   zása_, _légè, dolg, _רמלה_
  { {0x21a30001,0x39ac0089,0x7d190026,0x7c224438}},	//   _бисм, _měst_, _caws, _pror
  { {0x6b81018b,0x44200251,0x60d70008,0x307600c9}},	//   folg, nvi_, _רומא_, _чувс
  { {0x7d1b0020,0x99440064,0xf063017c,0x2fd70015}},	//   adus, tış_, _скуп, _أولد_
  { {0x44200005,0xb3560033,0x0a6a02ed,0x20190052}},	//   hvi_, ьнiц, ярии_, _ásir_
  { {0x39920014,0x99440064,0x6c860029,0x6d4600c0}},	//   tása_, rış_, _كلام, ökad
  { {0x3d19000b,0x753d002a,0x87070033,0x6d85001a}},	//   _मोटे_, _rosz, няве, róat
  { {0x07a4008f,0x7d19005c,0x399200dc,0xdca30001}},	//   лаўн, _zaws, rása_, _сачи
  { {0x753d4439,0xd5b10092,0x399200dc,0xa4d5017f}},	//   _posz, ế_, sása_, кові
  { {0x69da1d76,0x6f1a22d3,0xdce018df,0xe5090058}},	//   mste, _latc, domī, بيرو_
  { {0xb97c0008,0x88c8000a,0x69da059f,0x97a718fc}},	// [9ab0] _מנהי, _אֶתֵ, lste, _прол
  { {0xb4db0144,0x69da443a,0x6f1a443b,0xe4a41cc9}},	//   _plàs, oste, _natc, урсо
  { {0xeb91000a,0x20cc000b,0xcad7000a,0x69da443c}},	//   בָא_, ारूढ, גובת_, nste
  { {0x6b810014,0x7bdd0030,0xd4c7005e,0x69da443d}},	//   zolg, ásuk, _ясоп, iste
  { {0xf9940053,0x69da00b8,0x808b0015,0x12e7005e}},	//   ארף_, hste, أضاف_, _півг
  { {0x6f1a02fc,0x82370015,0x23650123,0xc7b4015b}},	//   _catc, _كرزا, _ölj_, אבס_
  { {0x7ed40086,0x2eb40010,0x69da443e,0xdcfb0046}},	//   ازها, усіс, jste, souč
  { {0x69da443f,0x6db1003d,0xdc3404b2,0x387e002a}},	//   dste, _jāai, aúčt, ętrz_
  { {0x6d494365,0xeb9900a5,0x69da4440,0x7d1b4441}},	//   rkea, мии_, este, rdus
  { {0xaab70086,0x26d30533,0x69da15f6,0x6d494442}},	//   رگتر_, _nexo_, fste, skea
  { {0x628b005c,0x2bd1021e,0x9b44002b,0x69da4443}},	//   ęgow, _दौरा, انپو, gste
  { {0x8afc0050,0x6e640010,0x44200007,0x186a034e}},	//   wnęt, _стуж, yvi_, дами_
  { {0xdd94008f,0x2d8d00d9,0x8c45023e,0x50da000a}},	//   _сацы, mlee_, _јеле, וקרא
  { {0x69da0838,0xcc56000a,0x62950030,0x6a85004a}},	//   bste, _בבני_, _ozzo, _илла
  { {0x9a2400e6,0xf77f016e,0xa95a0015,0x966302ed}},	//   _معين, arço_, _يجبر_, акре
  { {0x44200582,0xa2a2021e,0xa3b6000b,0xfa76004f}},	//   tvi_, _कृष्, _चंद_, _בעצת_
  { {0x28130074,0x7bdb0209,0x2d8d008c,0xe5a30b0c}},	// [9ac0] _نويس, nsuu, ilee_, рити
  { {0x7bdb00f2,0x212d013c,0x232a005e,0x741300c3}},	//   isuu, _aneh_, ьози_, ؤولا
  { {0x2d8d00dd,0xcb120008,0x44204444,0x6f1a3ef1}},	//   klee_, שלב_, svi_, _ratc
  { {0x106a004a,0x41e50015,0x7bdb01be,0x26d84445}},	//   мией_, اسلف, ksuu, laro_
  { {0x39400152,0x212d00bd,0x5fb30029,0x6fb30115}},	//   _mois_, _dneh_, لمنط, لمنا
  { {0x69dc0048,0x39520026,0x39401a8b,0x26d84446}},	//   šrei, _llys_, _lois_, naro_
  { {0x6704014e,0x39990014,0x2dd70029,0x216a1c35}},	//   श्यक_, lése_, نبية_, _живи_
  { {0x6f1a08b8,0x4c9403fc,0xbd6701b0,0xe2970513}},	//   _watc, лийс, крые_, _рас_
  { {0x399900dc,0x8bd30010,0x315701d8,0xe086002b}},	//   nése_, ажыц, _סימן_, _شجري
  { {0x3940002d,0x69da11a6,0x9b26004a,0x26d80077}},	//   _aois_, tste, тфил, jaro_
  { {0x28f90036,0x26d82bf8,0x39402114,0x69da4447}},	//   нень_, daro_, _bois_, uste
  { {0x26d30a40,0x69da4448,0x29e7001a,0x39400125}},	//   _sexo_, rste, _síað_, _cois_
  { {0x39403c20,0xdb03001c,0x69da4449,0xa130005e}},	//   _dois_, _dinâ, sste, рцiй
  { {0x399900dc,0xe6bf005d,0x7c6500e6,0xdb0c008c}},	//   dése_, ्रेज, _حامل, öhäs
  { {0x3940038d,0x3f42002e,0x98c700d7,0x2d84007c}},	//   _fois_, _yður_, _испл, oome_
  { {0x7aea0053,0xb7d90029,0xd8470033,0x2d84444a}},	//   _אַװעק, _كوبا_, _ахоп, nome_
  { {0x7c2400bc,0x6d5e0003,0x5399056d,0x61fe444b}},	// [9ad0] _širj, épay, евая_, etpl
  { {0x61e300dc,0x83190015,0x64a40054,0x4498004a}},	//   ánlo, عقار_, рађа, твую_
  { {0x6d5c00df,0x2d84444c,0x61eb002a,0x99520069}},	//   _įran, kome_, ąglo, láš_
  { {0xe5350080,0x2d840007,0x7bdb008c,0x0000006a}},	//   _семь, jome_, ysuu,
  { {0xb4c1000b,0x00e4005e,0x00c80033,0x8596000a}},	//   ुरी_, ржін, тлік_, _תדרג_
  { {0x20d10023,0xf4120008,0x7fb60015,0x996d0046}},	//   ại_, _הפך_, دهور_, _něž_
  { {0x62340036,0xfd110029,0x81d415e6,0x7bc20003}},	//   _керу, مجة_, _восх, _atou
  { {0x2d8d00f2,0x7bdb008c,0x2b990003,0x99520046}},	//   ulee_, tsuu, ièce_, káš_
  { {0xfc310029,0x39400152,0x3b85004a,0x20750033}},	//   صحة_, _rois_, ллиг, _слаў
  { {0x8fa40001,0x7c840001,0xb4c1000b,0xa0680054}},	//   _вађе, јуће, ुरु_, _рађа_
  { {0x39990014,0x3940444d,0xa96a0054,0x2014002a}},	//   zése_, _pois_, еина_, ęcił_
  { {0x2d840041,0x09360033,0x7bdb008c,0x0000006a}},	//   come_, ухоў, psuu,
  { {0xeb8e444e,0x2bdd005d,0x39400152,0x0d16004f}},	//   _ги_, _मिटा, _vois_, _תקנט_
  { {0x1a65002b,0x39990030,0xe9d90058,0x0000006a}},	//   _میخی_, vése_, _كذبت_,
  { {0xb4c1005d,0x6b7a000a,0x84e6005e,0xa50a261d}},	//   ुरू_, _ארסנ, ловж, нева_
  { {0x399903c0,0x291e0048,0x23b5000b,0x25a0007c}},	//   tése_, ētas_, _अंशद, umil_
  { {0xdce00048,0xb8f8005d,0x94260010,0xb4e4000b}},	// [9ae0] nimā, िर_, ымае, _नयी_
  { {0x46f60229,0x399900dc,0xa2e50015,0xa2630016}},	//   _счит, rése_, لأمن, _tuổ
  { {0x399900dc,0x60ea006b,0x82660058,0x7296009b}},	//   sése_, емем_, دهان, ушах
  { {0xdb09016e,0x39990030,0x3ce2000b,0x7986002a}},	//   mpeõ, pése_, _गयें_, nokw
  { {0xe3b20086,0x7f4602e1,0x2d8400f0,0x33d5005e}},	//   _درج_, ледж, vome_, _віст
  { {0x1f73008f,0x6df40029,0x765c002a,0x29d1444f}},	//   блія, لكتا, ozry, kša_
  { {0x5fe0005d,0x29d100bd,0x7bc24450,0x6283002a}},	//   _निकल, jša_, _stou, żnor
  { {0xf653000a,0x0000006a,0x0000006a,0x0000006a}},	//   מצו_,   ,   ,
  { {0x69c30f28,0x219b000a,0x2d844451,0x9b6a06a6}},	//   _atne, _טבלא, rome_, ешна_
  { {0xdd040064,0x93fb0135,0x2d841864,0x990d000b}},	//   ırıy, עליי, some_, िज्ञ_
  { {0x1959044e,0x69350080,0xdb030251,0x996d0046}},	//   ваны_, анну, _dinà, _věž_
  { {0x628e1521,0x9f4f0123,0x798600aa,0x63ae005a}},	//   _mybo, rtgå_, gokw, _libn
  { {0x68e40026,0xf77300e5,0x4ccb000a,0xdce0003d}},	//   _ddid, ماس_, _נֶאֱ, cimā
  { {0x1bf7000a,0x2bf7000a,0x6d42007c,0x8c1b000a}},	//   _עצור_, _עמון_, _hooa, _נווי
  { {0xe5c40063,0x3abb00f3,0xde78000a,0x27e00061}},	//   йсто, _אמונ, דְּך, _evin_
  { {0x08fb0015,0x63a20003,0x2b9901f6,0x69c82a6a}},	//   _أرغب_, ïonn, rèce_, mpde
  { {0x24580080,0x53a50015,0x7afd0085,0x98170015}},	// [9af0] гать_, لمرك, đstv, _إبعا
  { {0x2b990152,0x45d50001,0x6e280ebd,0x95cb011e}},	//   pèce_, _коос, _ordb, _пума_
  { {0xc2c40029,0x6db10024,0x86270033,0xf0d50033}},	//   صيني, _jāat, _сьпе, аўлю
  { {0xf8bf0152,0xdd860029,0x7ff5002b,0x463a004c}},	//   ncé_, _ذو_, لستا, _סערע
  { {0xc978000a,0x0000006a,0x0000006a,0x0000006a}},	//   נגדי_,   ,   ,
  { {0xddc5005e,0xd347002b,0xc7d8000a,0x8fa50015}},	//   абки, _حیطه_, רוגי_, جمته
  { {0x93c60011,0xde350033,0xb3540432,0x6e160015}},	//   rtăş, рэль, _укрш, ليوس_
  { {0xf1a41aef,0xdce0003d,0x29d106c0,0x0000006a}},	//   _грун, timā, vša_,
  { {0x3201003e,0x6e280012,0x1c4204ab,0xa1580054}},	//   lthy_, _erdb, жным, _сату_
  { {0x3b090001,0xcc08006e,0xdce0003d,0xdb034452}},	//   њено_, ازين_, rimā, _biná
  { {0xdce00024,0x29d11253,0xf2410033,0x4a750033}},	//   simā, uša_, йкiя_, рыпт
  { {0xfe70003b,0xb4e4005d,0xa96a23dd,0x80ac005d}},	//   _عدل_, _नये_, тима_, ुँचे
  { {0x61e300dc,0x2f2400dc,0x3855006b,0xd116000a}},	//   ánlj, ségű_, бърс, בקרה_
  { {0x7bc94453,0x6d420079,0xfaa54454,0xdb030069}},	//   mpeu, _zooa, _кало, _finá
  { {0x8afc005c,0x5976054f,0xdb03016e,0x69c300cb}},	//   zięk, _выпу, _giná, _utne
  { {0xda7a009d,0x2c09005d,0x7c2401a3,0x7bc9008c}},	//   _שנקר, _वहां_, _širi, opeu
  { {0x33660010,0x25a50144,0x9599098b,0x9423005e}},	// [9b00] аваг, ïlla_, утру_, омте
  { {0xb7db0008,0xa2e603a9,0x42c70342,0x389b000a}},	//   _שקיי, рожд, игун_, _ביפנ
  { {0x8b5600b2,0x8afc005c,0x11d70015,0x200d0045}},	//   סיעס_, więk, لولة_, _apei_
  { {0xb4db0023,0x55bb000a,0x4fc64323,0x98be0091}},	//   _hoàn, _שמכו, аска, ėtė_
  { {0x628e4455,0xb6a30016,0x44244456,0x3f874457}},	//   _wybo, huẩ, _ém_, fonu_
  { {0x7c24002f,0x6fd50033,0x61eb0061,0x3f874458}},	//   _áiri, сіцц, ümlü, gonu_
  { {0x4367007e,0x91e304bb,0xd6e9004f,0x9737004f}},	//   _тарн_, _море, אַפָ, ירסא_
  { {0x2d9d0026,0x1d34006b,0x22470012,0xbd180098}},	//   _chwe_, сния, änke_, ужих_
  { {0xf8bf0152,0x9c370063,0xef1a113a,0x20090003}},	//   ndée_, ипът_, _има_, çait_
  { {0xd00f003b,0xda260036,0xf2d30053,0xbb830021}},	//   _تلك_, аємо, ֿער_, يليي
  { {0xd2b70008,0xdebb004c,0x4a730033,0xda660015}},	//   ילית_, _סמאל, жыўт, شادي
  { {0xed590089,0xdb1b0152,0xbc67002b,0xaa630033}},	//   chž_, nquê, امین_, ітэк
  { {0xf8bf11a7,0xdca60076,0xdcfb0061,0xdd3b000a}},	//   rcé_, _тади, lluğ, _שעדכ
  { {0x5bc30029,0xe7874459,0xdc9b000a,0x69c8156a}},	//   _بقول, румо, _סיגל, ppde
  { {0xdcfb0064,0xaa57005e,0x6b9b000a,0xf9c4002b}},	//   nluğ, _вищу_, _ששוד, _احتی
  { {0x48670063,0x2419056d,0x2988005e,0x3f87445a}},	//   _въоб, лобы_, _всьо_, zonu_
  { {0x96270048,0x3f870064,0x3f9e0020,0x798d0b63}},	// [9b10] _saņē, yonu_, _ohtu_, _ikaw
  { {0xf2c70418,0xdcfb0061,0x9627003d,0x5c37000a}},	//   рсан, kluğ, _paņē, ברמן_
  { {0x877c0053,0xd1b80031,0x2555002b,0xb8220065}},	//   _באזי, لانا_, _هندآ, मिअम_
  { {0xe6100086,0xc1040029,0x320104dd,0xc1050015}},	//   _کشی_, قومي, rthy_, صوتي
  { {0xf5360008,0xb5a40033,0xc1040040,0x656d1839}},	//   _הנרי_, _фрэй, توني, miah
  { {0x20e70092,0x442b0ad0,0x83840010,0xa858000a}},	//   ối_, _irc_, _дысе, סיגה_
  { {0x5758000a,0xb6aa000a,0x644d008c,0x7db40033}},	//   שבוע_, ְׁפֹ, lyai, осыц
  { {0xe6780008,0x387e0011,0x9f46002e,0xc1050029}},	//   יתוח_, ştri_, stoð_, _دوري
  { {0x7ff40015,0x644d445b,0x3f87445c,0x2bb90058}},	//   _وسكا, nyai, ponu_, دابة_
  { {0xdce00011,0x798d445d,0x5ac90132,0x0000006a}},	//   timă, _akaw, ылом_,
  { {0x39920014,0x5e950029,0x63a5002d,0x7219000a}},	//   lási_, _الاط, imhn, נוֹח
  { {0x7bc91e14,0x644d008c,0xb9560054,0xe8f708f7}},	//   ppeu, kyai, стоћ, блю_
  { {0xe81b005d,0x20790053,0x17fa0029,0x2bbb0015}},	//   _पैदा_, ראָא, درجة_, _شاشة_
  { {0xfbd0002b,0xceb2000a,0x7c94012c,0xf79a0058}},	//   _آتن_, ֜ים_, _بشما, انسب_
  { {0xceb243b0,0x75d60029,0xa6e3002e,0x636b002a}},	//   לים_, إيرا, íðar, eżno
  { {0xba740015,0x39920046,0xe8fa00af,0x0000006a}},	//   _باهت, kási_, _сли_,
  { {0x64a30010,0xdcfb0061,0x3957000a,0x6d5b007c}},	// [9b20] зата, zluğ, _לשקם_, ihua
  { {0x399200dc,0xf8bf0003,0xdce00091,0x2002003d}},	//   dási_, rdée_, mimą, _īki_
  { {0xd12f002b,0x6d5b01c2,0xf1fa0015,0x636b002a}},	//   کمن_, khua, طعات_, ażno
  { {0x9fe60029,0x00da0806,0x63a5002d,0x10a60894}},	//   مسته, ابات_, amhn, биен
  { {0xdb1b016e,0xdce00091,0xb87b16ee,0x39920030}},	//   rquê, nimą, caíd, gási_
  { {0xe2aa0015,0x212006f2,0xdee30054,0x7524445e}},	//   _مازن_, žih_, пољи, ldiz
  { {0x0ef9008f,0x7c2b0026,0x5e260015,0xdb03008c}},	//   рэчы_, _argr, إعتق, _minä
  { {0x2fda0074,0x6fb60074,0x39b70011,0x6d5b002d}},	//   _مورد_, _همرا, _găsi_, ghua
  { {0x7524000c,0xdc2a0067,0xdce00091,0xe0430099}},	//   idiz, اسبه_, jimą, _енти
  { {0x60c2069b,0x20570053,0xd00f00c3,0x656d006f}},	//   lcom, _הימל_, _سلم_, ziah
  { {0xd9150802,0x7c2b00b8,0x6d5b0125,0x60c22ac8}},	//   одны, _ergr, bhua, ocom
  { {0xf53f00c0,0x127b0053,0xfe37000a,0x61e30046}},	//   _ihåg_, ראטע, _לרבי_, ánli
  { {0xbfb60023,0x718b000a,0x752402b9,0x58870033}},	//   _điểm_, רְיַ, ddiz, сына
  { {0xac970115,0x4aba004a,0x5c730033,0x60c200da}},	//   _انها_, _судя_, _эліт, hcom
  { {0x39920014,0x656d002c,0xef110008,0x20dd0091}},	//   zási_, tiah, וּן_, lšių_
  { {0xb5980029,0x6db10024,0xea77000a,0x9e4b000a}},	//   مَّا_, _jāap, _לגור_, אֲמִ
  { {0xb4b9005d,0x52d9004a,0x656d18cc,0x82d901e9}},	// [9b30] _चली_, имаю_, riah, идас_
  { {0x656d002c,0xb8cc000b,0x9888000a,0x60c21e35}},	//   siah, के_, _לָתֵ, ecom
  { {0xf1c80029,0xfbda000b,0x82150015,0x50b50c71}},	//   مولى_, _मौसम, تواص, ослу
  { {0x6d46022d,0x39920014,0x91050036,0xdb0b00b8}},	//   ökal, tási_, іпле, _zugä
  { {0xd91c0008,0xa2d50015,0x80240015,0x442b0034}},	//   טואל, _ويحت, كروم, _urc_
  { {0x399200dc,0xf41f008c,0x44290306,0x7c2d0ea1}},	//   rási_, _isä_, mva_, _šaro
  { {0xe81b005d,0xbea20210,0x539a000a,0x96fc000a}},	//   _पैसा_, машк, _כישו, אלות
  { {0xd6580008,0xdd9100e6,0x463c004c,0x1be9033d}},	//   מיות_, بوع_, רעהע, адии_
  { {0x764e005c,0xd045002b,0xc05b005e,0x4429445f}},	//   zyby, _بپذي, _сів_, nva_
  { {0x3d290086,0xdce90091,0x75240061,0xd438000a}},	//   اتژی_, mieč, zdiz, מרחק_
  { {0x44290e95,0xdce90fcb,0xc334000a,0x7f840015}},	//   hva_, lieč, לוץ_, _علمن
  { {0xdb03008c,0x44294460,0xa2f70065,0xc4b80065}},	//   _sinä, kva_, ुभुज_, _अलेख
  { {0x764e0026,0xdce90007,0x26da003f,0x3ea90046}},	//   wyby, nieč, _pepo_, žitě_
  { {0x44294461,0x7c294462,0xdb23002b,0x5ba7098b}},	//   dva_, mver, _روبی, _урез
  { {0x657a0003,0xcb12000a,0x65c6006b,0x7c2919fa}},	//   étho, _חלו_, юбва, lver
  { {0xdce90007,0x44290b1f,0x27ed0d0e,0x7c294463}},	//   kieč, fva_, šena_, over
  { {0xdce90007,0xf993000a,0xe4d7002b,0x44294464}},	// [9b40] jieč, _קרח_, زولت_, gva_
  { {0xb2960001,0x6be80008,0x752402b9,0xd9b5000a}},	//   ојећ, מַעַ, sdiz, ַּ֣ח_
  { {0x8afc0050,0xe822005d,0xa3d6000b,0x201f008c}},	//   mięt, मिका_, _सबक_, _asui_
  { {0x7c294465,0x629c0ccd,0xf1a90087,0xc329000a}},	//   kver, _vzro, مانه_, כו_
  { {0xb4d6005d,0x629c005c,0xcfa60180,0xb97b000a}},	//   हरी_, _wzro, ошки, סנני
  { {0x8afc0050,0x6d591a89,0xdd900086,0x60c24466}},	//   nięt, _alwa, کوب_, scom
  { {0x629c016f,0x7d0928b1,0x11d5008b,0x7c294467}},	//   _uzro, ffes, _нітр, ever
  { {0x6da300d0,0xd1320015,0x7c294468,0x7d092aaf}},	//   мија, _تمر_, fver, gfes
  { {0x8b660029,0x61e30030,0x2d98003d,0x7c294469}},	//   قادم, ánlv, ēre_, gver
  { {0x3f760050,0x501b0008,0xa3dc000b,0x20dd0091}},	//   dług_, _דומו, णीय_, ršių_
  { {0x2b47038d,0x44293bdd,0x09e30004,0x139b000a}},	//   _donc_, zva_, моќн, שביע
  { {0xedd30074,0xa9c30191,0xb4b9005d,0x2c830007}},	//   _آيند, ьськ, _चले_, _būdą_
  { {0x6c760015,0x2006446a,0x8b660058,0xc7f800ce}},	//   _بطائ, ntoi_, _واتم, оняє_
  { {0x46e8004a,0x8afc002a,0x39920030,0x4429446b}},	//   ждён_, gięt, dásu_, vva_
  { {0xf41f00f2,0xb4d6021e,0xc4db0054,0xdce90091}},	//   _ssä_, हरू_, иђа_, zieč
  { {0xe5340010,0xb87b016e,0xda5b000a,0x4429446c}},	//   месь, raíb, _ככול, tva_
  { {0x6908000a,0xd7fb006b,0xa715005e,0x4429446d}},	// [9b50] _וּתְ, _туй_, _емпі, uva_
  { {0x8afc005c,0x60db0375,0xdce90091,0x6f1806c0}},	//   cięt, _seum, vieč, jevc
  { {0x55950083,0xa2dc005d,0x7c293267,0xb1152a0b}},	//   _наоѓ, _फ़र्, zver, змеш
  { {0xdb0b00c0,0xdce90007,0xa3b6000b,0xdb1b446e}},	//   _utgö, tieč, _चूक_, rqué
  { {0x67250005,0xc9540053,0x2bda000b,0x25a9446f}},	//   _kahj, ומף_, _मौला, mmal_
  { {0x399200dc,0x60db003f,0xa81c000a,0x7c294470}},	//   lást_, _weum, שֵׁי, vver
  { {0x67254471,0xf774000a,0x63bd4472,0x02450058}},	//   _mahj, וקס_, _husn, _عَرَ
  { {0x25a900b8,0x1c450036,0x67250604,0x867c000a}},	//   nmal_, зним, _lahj, ירוו
  { {0x291908e0,0xcf270029,0x25a900b8,0xc10400e5}},	//   desa_, _ورئي, imal_, _توقي
  { {0x25a900b8,0xa088000a,0x02b6000a,0x63bd4473}},	//   hmal_, _וְעִ, ּ֔ים_, _musn
  { {0x3949001c,0x7e99002b,0x29194474,0x25a94475}},	//   _boas_, _انار_, fesa_, kmal_
  { {0x291900d9,0x8afc005c,0x7e9a000a,0x7c292dcc}},	//   gesa_, więt, _הסעו, pver
  { {0x399200dc,0x88360010,0xbd9a000a,0x4cba000a}},	//   dást_, чэнц, _פסנת, _המנג
  { {0xf7560015,0x25a94476,0x63b52f34,0x0000006a}},	//   أنسج, emal_, _nizn,
  { {0x63bd00b8,0x8f9a0008,0x3f76002a,0xe5a61adc}},	//   _ausn, מישי, sług_, зиви
  { {0x63bd0176,0xf99203c4,0xb4d6005d,0x29194477}},	//   _busn, _ثبت_, हरे_, cesa_
  { {0x29c10023,0xf484002b,0x8afc002a,0x63b54478}},	// [9b60] _hóa_, ذاری, pięt, _bizn
  { {0x94790127,0x7ae12eb3,0x25a91703,0x29e70160}},	//   істу_, nalt, amal_, ođa_
  { {0xb6bb0008,0x3d1c005d,0x7ae14479,0x171b004c}},	//   _לציי, _मसले_, ialt, _פוטע
  { {0x7ae1018b,0x2d80002c,0x63bd0026,0x200600f2}},	//   halt, čiek_, _fusn, ttoi_
  { {0xaedc0010,0xa4b7000a,0xc4d3000a,0x7ae1447a}},	//   аблi, _מלכה_, _רגש_, kalt
  { {0x7ae100f2,0x200600f2,0xc49b000a,0x2919002a}},	//   jalt, rtoi_, _לשכת, zesa_
  { {0x20060ed5,0x7e2a02a3,0x7ae1447b,0xc87f02ad}},	//   stoi_, сіла_, dalt, maße_
  { {0x63600014,0x7cf60064,0x427b000a,0x4f66002b}},	//   _böng, dürü, _האלג, _کارف
  { {0x8e86002b,0x6eb60015,0x7ae1447c,0x2919447d}},	//   _کلاه, _فصائ, falt, vesa_
  { {0x399200dc,0x7ae1002d,0x63600064,0xba54009c}},	//   zást_, galt, _döng, двој
  { {0x44270023,0xc33301d8,0x2919447e,0xa3dc000b}},	//   ̉n_, גות_, tesa_, णीत_
  { {0x79a70010,0x7ae10e95,0x1e57000a,0x984b006b}},	//   ярпе, aalt, _משבר_, бяга_
  { {0xbd430029,0xdc54002b,0x6360001a,0x39920030}},	//   _سنوي, _تراک, _göng, vást_
  { {0x4e20000b,0x27ed3e44,0x4df0000b,0x29191d0d}},	//   _मनाई_, šeno_, _घटाई_, sesa_
  { {0x39920014,0x4422421b,0x9aeb000a,0xb5950724}},	//   tást_, _ask_, _הַחִ, дивш
  { {0x69fb0008,0x6360002e,0x8a7b0008,0x4a7b000a}},	//   _הלהק, _lönd, _לאות, _לרוב
  { {0x18680001,0x399200dc,0x68ed447f,0x05740015}},	// [9b70] _наћи_, rást_, _idad, رافد
  { {0x4374005e,0x798f0034,0x02a7011a,0x92a70054}},	//   нуєт, locw, прем, пјел
  { {0x29c10023,0x2b0e000b,0x3219002b,0x39920030}},	//   _xóa_, त्यु_, تياد_, pást_
  { {0xe1f000e6,0x7ae12442,0x41550033,0xf8bf0003}},	//   اسل_, zalt, ьвес, idéo_
  { {0xe134008f,0x656f002d,0x7ae10fda,0x63600123}},	//   энцы, _imch, yalt, _bönd
  { {0xf2070033,0x6360001a,0x7d024480,0x0000006a}},	//   _нябо, _röng, _acos,
  { {0x7ae1022d,0x63601cf9,0xfd110015,0x6ee400c3}},	//   valt, _dönd, نجة_, رسول
  { {0xe7ee005d,0x27e900c0,0x7ae119b7,0x301500d7}},	//   _जिला_, _ovan_, walt, _одбр
  { {0xc1040015,0x2af50033,0x3af5055f,0x636b002a}},	//   _سولي, мянё, мянс, eżni
  { {0x63600482,0x7cf60064,0x224d0089,0xc43c000a}},	//   _gönd, türü, _řeky_, מתחי
  { {0x7c224481,0x9870006f,0x7ae14482,0x0000006a}},	//   _esor, rúča_, ralt,
  { {0x29e70085,0x7d020125,0x7cf60061,0x7ae14483}},	//   rđa_, _gcos, rürü, salt
  { {0x68ed0026,0x63600064,0x7d1b4484,0x7ae14485}},	//   _ddad, _yönd, meus, palt
  { {0x26de002c,0x656f002d,0xb905000b,0xb6a60054}},	//   úto_, _amch, _पड़_, дигл
  { {0xab2806e4,0x9b920067,0xd627007e,0xdb1b030b}},	//   _رسول_, _جلوت, море_, nquí
  { {0xe5a34486,0x99f6000f,0x6d4b4487,0xf77f0061}},	//   виси, _חזקה_, _joga, rsça_
  { {0x9f5f1ae8,0x6d4b4488,0xb7d700c3,0x63600123}},	// [9b80] _aquí_, _moga, _قويا_, _löne
  { {0xb8050015,0x225a0015,0x98a9002a,0x6d4b4489}},	//   _أبيه, يجاب_, _snać_, _loga
  { {0x97570008,0x61460010,0x7d1b00f2,0xc87f00b8}},	//   _חייו_, межа, keus, raße_
  { {0xc4fa0086,0x6360448a,0xd1300015,0x6d4b448b}},	//   _بعدا_, _sönd, طمت_, _noga
  { {0xd0100225,0xbfaa004a,0x1047006b,0x7d1b448c}},	//   الت_, отке_, дящи_, deus
  { {0x20ee0092,0x3eba003c,0x7d020a2d,0x2f5601c5}},	//   ội_, øpt_, _scos, ьтес
  { {0x656f0176,0x44200026,0xa3c8000b,0x6d4b448d}},	//   _ymch, lwi_, ैठक_, _boga
  { {0x636001e2,0x6d4b002f,0xad660021,0x4420002a}},	//   _döne, _coga, باته, owi_
  { {0x44200026,0x6d4b052c,0xaf06448e,0xa91b001a}},	//   nwi_, _doga, _опал, nnþe
  { {0xba0a006b,0x8e3a0015,0x7e56448f,0x0000006a}},	//   охме_, _وسار_, _отец,
  { {0x6d4b0014,0xad620092,0x399900dc,0x7d2700c0}},	//   _foga, _đươn, lési_, örsä
  { {0xbfa30092,0x7de50015,0x7afd0091,0x6d4b0034}},	//   hiế, _أسلم, ėsta, _goga
  { {0x399900dc,0xf7730070,0x984b0010,0x4420003f}},	//   nési_, ناس_, цяна_, jwi_
  { {0x636001e2,0xc0530053,0x4c9b000a,0x07a40033}},	//   _yöne, דזש_, _ובדו, каўн
  { {0x7dc70064,0xe7eb000b,0xbafb000a,0x569401e5}},	//   _kısa, _झटका_, _והוש, варт
  { {0x3999117d,0xe945002b,0x7c2d4490,0x0000006a}},	//   kési_, _سربی, _šari,
  { {0x6d4c0092,0x8afc005c,0xb87b002d,0x2d580152}},	// [9b90] _đoạ, chęc, maío, _réel_
  { {0xb87b002f,0x399900dc,0x25090086,0xdb0103d9}},	//   laío, dési_, _کردی_, omlá
  { {0x2fcd4491,0x50f50661,0xe3b00015,0x7d1b0003}},	//   _steg_, езет, شرك_, yeus
  { {0xb87b002f,0x63600061,0x02a43050,0xea77004f}},	//   naío, _röne, трум, וגבר_
  { {0x442d435c,0x63604492,0x39990030,0x6d4b4493}},	//   _ée_, _söne, gési_, _roga
  { {0xb87b002f,0x6d4b00b8,0x92f40015,0xde050e3f}},	//   haío, _soga, _لأفض, епки
  { {0xed59004a,0x3eb30123,0x6d4b4494,0x7d1b4495}},	//   зой_, äxt_, _poga, teus
  { {0xdb1b02c1,0x56b8000a,0x6da20238,0xb1a40033}},	//   rquí, ופון_, лища, _ашук
  { {0xb87b002d,0x7d1b4496,0x3ff50015,0x2fd90015}},	//   daío, reus, _سكار, _رواد_
  { {0x03d6000a,0x3ed50015,0xd498000a,0xf1b900bc}},	//   עותם_, _أقار, וכחת_, _hiš_
  { {0x8f680029,0x4420005c,0xa3e6005d,0x6d4b23d1}},	//   _تملك_, zwi_, _यौन_, _toga
  { {0xdc33002c,0xb87b0bd7,0x9734002b,0x2904007c}},	//   lúče, gaío, چکدا, üma_
  { {0xa156000a,0xc4a9000b,0x9734002b,0x3156004c}},	//   גברה_, कधोख, نکدا, גירן_
  { {0x636000b8,0xa9240091,0x6d46007c,0x0000006a}},	//   _mönc, _ąžuo, ökav,
  { {0x39990014,0x59c6005d,0x9f560003,0x69962333}},	//   zési_, _रूपर, égés_, _прих
  { {0xb87b002f,0x4420002a,0xf1b90085,0xa2cd000b}},	//   caío, twi_, _niš_, दुस्
  { {0x95830588,0xa989004f,0x27b600af,0x0000006a}},	// [9ba0] улте, _קָצִ, _пљос,
  { {0x14230010,0x68b7000a,0x7626005e,0x44204497}},	//   ыдум, _אלפא_, _змоз, rwi_
  { {0x764100f2,0xb87b002d,0x7655005c,0x26db000a}},	//   älyt, haíl, cyzy, _מקימ
  { {0x399903c0,0x68e60035,0x29020375,0xe3ba0004}},	//   tési_, nakd, ngka_, _нбм_
  { {0xc0e70029,0x6576008c,0x94bb004f,0xc6fa004f}},	//   رفون_, miyh, _ממכת, ֤לֶך
  { {0x399900dc,0xa2d60015,0xb2d60015,0x90530033}},	//   rési_, _سيرت, _سيرغ, ывіц
  { {0x39990014,0x63830063,0x25e3005d,0xdb030125}},	//   sési_, _сгра, टीपी_, _ghné
  { {0x399900dc,0x1d340063,0x9cca0010,0xd00a176c}},	//   pési_, тния, чыка_, _небе_
  { {0xfbcf0086,0x9f86042b,0xfd660016,0x61fe4498}},	//   یتی_, _згад, _khuế, lupl
  { {0x7017000a,0x5a3429f7,0x1ee8002b,0x61fe1359}},	//   _אחמד_, внот, _آوای_, oupl
  { {0xb87b002d,0x6576008c,0x28f908f0,0x58d515d2}},	//   taío, kiyh, мень_, конт
  { {0xc27b000a,0x89b40033,0xc213000a,0x7c860883}},	//   לריי, лёўш, נהר_, _пуле
  { {0xb87b002f,0xdd8f0086,0x2bb2000b,0xd8380033}},	//   raío, _اون_, ीददा, нэр_
  { {0xb87b002d,0x61fe4499,0x99a0003d,0x290202f2}},	//   saío, kupl, āršu_, agka_
  { {0xdb030089,0x8f9b000a,0xb5a701f3,0xb87b0125}},	//   _jiný, פילי, ерай, paío
  { {0xba9b013a,0x65640035,0x1a9b0008,0x6a9b000a}},	//   _מסוי, ghih, _מיוע, _משונ
  { {0x24f80010,0x61fe0003,0x94770021,0x26d837bf}},	// [9bb0] энты_, eupl, ردرا, bbro_
  { {0xd6db005f,0x65640b63,0xa87c000a,0x04940015}},	//   _эти_, ahih, _מאחר, الْح
  { {0x52e1005d,0xa4d9034e,0x75d50015,0x0000006a}},	//   _फ़ीस, _одну_, _جيجا,
  { {0x60b500e6,0x24990015,0x40c80015,0x6564449a}},	//   نمائ, _يندد_, ّونَ_, chih
  { {0x212a002b,0x61fe007c,0xd1b80015,0x753d24ad}},	//   بينی_, aupl, راما_, _insz
  { {0x0eac005d,0xa3f6000a,0xc476000a,0x61fe0546}},	//   टइंड, _במשק_, _יתרו_, bupl
  { {0x6234006b,0xce180033,0x41770015,0x68e602f2}},	//   _йеру, ецыі_, _كارس, yakd
  { {0x69c70264,0xa63c000a,0xdc33006f,0xa2940033}},	//   íjem, לגור, súče, _сасі
  { {0x518401b0,0xdfd1002b,0x6c520054,0x59c60065}},	//   _сура, _ضيا_, икћу, _रूबर
  { {0x799d018b,0x999f0007,0xf412000a,0xeac5006b}},	//   elsw, kytų_, ספי_, ъбоп
  { {0x68e6025e,0xc3320008,0xb87b0125,0x78a40030}},	//   takd, בוי_, saíl, _sziv
  { {0x4ad1005d,0x999f0007,0x0cd5005e,0xdb030012}},	//   _द्रव, dytų_, _родю, _hinü
  { {0xf1b2103d,0x8b250210,0xfd56000a,0x6d88000a}},	//   יסט_, _адле, _ששני_, _אָסְ
  { {0x29050014,0xdcfb0091,0x5f09000b,0x6d5b008c}},	//   őlap_, inuč, _साफ्_, lkua
  { {0x66060063,0xa59605c4,0xa6e3005e,0x6576008c}},	//   ъпва, вращ, ржсл, tiyh
  { {0x6d5b00d9,0xf772002b,0x64dc000b,0xb5a90015}},	//   nkua, _چاد_, बरेश, فاقك_
  { {0xc953013a,0xb8f6000b,0x7ae3449b,0xe3ba06a6}},	// [9bc0] _כמה_, ाँ_, _kent, дба_
  { {0xd7fb01e4,0x57fb0053,0x7ae3449c,0x69c3449d}},	//   _קהיל, _קליו, _jent, _kune
  { {0x00e6005e,0xa75b000a,0x2cb10046,0x6d5b01be}},	//   вжен, _חדיר, ězdy_, kkua
  { {0xb2950001,0x61fe449e,0x7ae3449f,0x69c30072}},	//   ујућ, rupl, _lent, _mune
  { {0xdb0b0064,0x68e41d84,0x91030004,0x69c70046}},	//   _bugü, _meid, рпче, íjej
  { {0x399900dc,0xe3b200e5,0xa857000a,0x68e41efd}},	//   lést_, _خرج_, כינה_, _leid
  { {0x91e3021a,0x35a7000b,0x69c344a0,0x0000006a}},	//   _восе, _कीड़, _nune,
  { {0xdb19005c,0xdce90064,0x68e40313,0x39992024}},	//   _otwó, rneğ, _neid, nést_
  { {0x316600dc,0x8ca7000b,0x7b66005e,0x7ae3015a}},	//   mhoz_, _चरणो, втне, _bent
  { {0xdb1800dc,0x316600dc,0xa2d8000b,0xda7a034e}},	//   _kivé, lhoz_, यरट्, дям_
  { {0x02fb0008,0x7ae308aa,0x63bc16ed,0x27e002f2}},	//   ולימ, _dent, _mirn, _awin_
  { {0x5e790053,0x68e40026,0x58870033,0x99810091}},	//   _אָנד, _ceid, выга, _čių_
  { {0x399900dc,0x7ae344a1,0x58870033,0xad650015}},	//   dést_, _fent, тына, _حاله
  { {0x999f0007,0xba760015,0x644b007c,0xdca30054}},	//   tytų_, _لاعت, ägim, _тачи
  { {0x68e4002f,0x31660014,0x37740010,0xf6740010}},	//   _feid, khoz_, рыўс, агрэ
  { {0x2bb2005d,0x8ab70008,0x7ae300b8,0xd9440001}},	//   ीदवा, _בלוג_, _zent, _већи
  { {0xe454008f,0x69c300b8,0xd4070080,0x629c0035}},	// [9bd0] акты, _zune, ъяви, _ayro
  { {0x7ae8005c,0x68e40079,0xe8890030,0x629c44a2}},	//   nadt, _zeid, _égőá, _byro
  { {0xa6e3001a,0x44322f77,0x76840033,0xf2c40a31}},	//   íður, avy_, _выяж, рсун
  { {0xb65a0008,0xa4d50036,0x865a00a3,0xfe43002b}},	//   _נדרש, _щомі, _נדרי, یکای
  { {0xe0d80036,0xb4fa039e,0x80240015,0x64b60046}},	//   тві_, _אפרי, لروم, třiž
  { {0x6360002e,0x8fa50015,0xaf04005e,0xdb180030}},	//   _hönn, دمته, ипіл, _fivé
  { {0x6360018b,0x60c400f0,0x7ae344a3,0x6d5b01c2}},	//   _könn, žima, _rent, tkua
  { {0x6e160015,0x1d250054,0x63600030,0x290908d2}},	//   اييس_, умим, _jönn, _ncaa_
  { {0x7ae344a4,0xcc350029,0x6d5b08c0,0x6e9f000b}},	//   _pent, اربع, rkua, _ओरकु
  { {0x7ae80014,0x69c30011,0x399900dc,0x69c4002c}},	//   gadt, _pune, zést_, _čier
  { {0xc33200b2,0x52e1014e,0x7dc70064,0xe9e9002c}},	//   זוי_, _फ़ैस, _kısm, knúť_
  { {0x5e440015,0x290944a5,0x443244a6,0x7ae344a7}},	//   _خَمْ, _ccaa_, yvy_, _went
  { {0x68e403eb,0x39990089,0xe9e9002c,0xada4005e}},	//   _veid, vést_, dnúť_, _таїл
  { {0xa8750080,0x7ae30077,0x34dc000b,0xd62a0054}},	//   рующ, _uent, बर्द, ноге_
  { {0x39990014,0x68e4002f,0x2bdf005d,0xc9f50015}},	//   tést_, _teid, पीरा, _إستع
  { {0x27e044a8,0x96d4000b,0xb4c0000b,0x443244a9}},	//   _twin_, _ब्रॉ, ुडे_, tvy_
  { {0xdb19005c,0x15b90010,0x399900dc,0x39403719}},	// [9be0] _utwó, тыры_, rést_, _inis_
  { {0x87260080,0x399900dc,0x443201b2,0xbf1d000b}},	//   _смож, sést_, rvy_, फ़ोन_
  { {0x316600dc,0x399900dc,0xf5060033,0x44320123}},	//   thoz_, pést_, _йзно, svy_
  { {0xf2c90053,0x629c0107,0x867b000a,0xb7d7002b}},	//   לע_, _vyro, _טריו, _جویا_
  { {0xdfcf0029,0x629c005c,0x297b0053,0x316600dc}},	//   كين_, _wyro, עטנא, rhoz_
  { {0x31660014,0x07360053,0x25a00020,0x2ee50026}},	//   shoz_, ראַם_, llil_, _celf_
  { {0x2dd70015,0x31660030,0xdd9000c3,0x539b000a}},	//   هبية_, phoz_, يوت_, _נילו
  { {0x5d540254,0x2567007c,0x9bf40a86,0xe3c20061}},	//   ркит, _võlg_, азич, arış_
  { {0x54770053,0x90290015,0x71530040,0x21670e91}},	//   ָגיע_, _لألف_, _انقض, _сити_
  { {0x9b58000d,0xfbcf0029,0x96d4021e,0x6c170015}},	//   тиот_, أتي_, _ब्लॉ, اتيح_
  { {0xdb03002d,0x395244aa,0xc333000a,0x6fb30067}},	//   _ghní, _boys_, מוז_, _املا
  { {0x2ee50111,0x02b70053,0x19950010,0xd2b7000a}},	//   _zelf_, טליך_, рамя, טלית_
  { {0x8d93003b,0x9c570074,0x4c560015,0x7d7b000a}},	//   _النش, _مجوز_, _حضار, _אראג
  { {0x6360001a,0x862704d5,0x0000006a,0x0000006a}},	//   _sönn, льбе,   ,
  { {0x58d5010f,0xe9e9002c,0xda660087,0x8b9b000a}},	//   _койт, tnúť_, _حاشي, _רבות
  { {0x3940003e,0xb4d509ef,0x583900a4,0xe5c4004a}},	//   _gnis_, ржащ, _азия_, ссро
  { {0xa9bc0008,0xe8d8000a,0x3375223b,0xdd000046}},	// [9bf0] _אזהר, _עוזר_, агар, _štěc
  { {0xe9e9006f,0x6cab004f,0x0000006a,0x0000006a}},	//   snúť_, תֹלְ,   ,
  { {0xe9e9002c,0x77ba0008,0xc0d50029,0x9b17000a}},	//   pnúť_, _שמתח, لياب, רחבה_
  { {0xda7b00b2,0x2ee5014c,0xb0350004,0x27ed0085}},	//   ענאר, _self_, инеш, šenu_
  { {0xb0af005d,0x09b80053,0x504507be,0xffb50033}},	//   जेंग, אפאט_, релб, айдэ
  { {0x7ff40015,0xb364006b,0xb0d5000b,0x443944ab}},	//   إسنا, _лъск, _ड्रग, _irs_
  { {0x4229000a,0x752f44ac,0x6b5f00aa,0xf1a70588}},	//   _בֵּ֣, _kacz, _sêgo, _бран
  { {0x52840029,0x2d990003,0xc105002b,0x39990030}},	//   _الفك, ôse_, _خوري, zésr_
  { {0x506744ad,0x69ce0046,0xaffc005e,0xd1080015}},	//   _ства, íben, _потi, _حققه_
  { {0xd7a4005d,0x44390495,0xce6b05b1,0x752f002a}},	//   _खींच, _mrs_, _пред_, _lacz
  { {0xc3320008,0xed4e002b,0xd9460004,0xb33100fd}},	//   קוט_, سپی_, аени, спiл
  { {0x752f005c,0xc7a900a3,0x39920030,0x443944ae}},	//   _nacz, _חב_, lász_, _ors_
  { {0x7db403c4,0x8d5a000a,0xebe5011d,0xbb45029b}},	//   _اصلا, _שכני, _толп, _велк
  { {0xcb08002b,0x7c2b0034,0xeb080015,0x0000006a}},	//   _ميهن_, _isgr, _مقهى_,
  { {0x4b7a1282,0x39520f21,0x752f002a,0x7bca003d}},	//   _שאצו, _toys_, _bacz, ēmuš
  { {0x39400152,0x442b44af,0xc56302ed,0x399201d3}},	//   _unis_, _bsc_, окск, hász_

  { {0x33b60015,0x23b60015,0xd2d60015,0xa99b000a}},	// [9c00] لمرأ, لمرس, لغاب, _בבקר
  { {0x2bb6002a,0x443944b0,0xa857000a,0x25a044b1}},	//   _płci_, _drs_, _כיפה_, slil_
  { {0x443944b2,0xb87b0089,0xe5a609ac,0x2327005e}},	//   _ers_, abíd, _вини, рохи_
  { {0x5a16004c,0x6a3a004c,0xe2970822,0xd0120058}},	//   יקען_, כגעפ, шах_, قلص_
  { {0x33d5078f,0x63600064,0xdfd00015,0x3034004a}},	//   _гіст, _yönl, أيت_, селё
  { {0x752f0050,0x92e90015,0x7f73005e,0xa0670054}},	//   _zacz, _مرفق_, огіє, раља_
  { {0x224708e9,0x7e2a005e,0x5e430015,0xf536000a}},	//   änkt_, тіла_, قَوْ, ֹנִי_
  { {0x2372005c,0x68f60091,0x443944b3,0x0000006a}},	//   żają_, _ndyd, _yrs_,
  { {0x8c43023e,0x4d730015,0x70fb000a,0x5f46002b}},	//   жење, تطور, _שהמח, _پنال
  { {0x61fe00dd,0xf413000a,0x600b000a,0x661e00cb}},	//   orpl, קפת_, _יִבְ, _oppk
  { {0xd3370008,0x1959054f,0xeb970004,0x99590046}},	//   בריה_, ганы_, риќ_, réž_
  { {0x1eea002b,0x61fe01f9,0x0000006a,0x0000006a}},	//   _سوچی_, irpl,   ,
  { {0x68f60176,0xb8cf005d,0x752f005c,0x61fe0012}},	//   _ddyd, _कर_, _racz, hrpl
  { {0x0b930115,0x8c1b000a,0xdb180030,0x98a20535}},	//   _وجود, _סווי, _kiví, ndkę_
  { {0x9942005c,0x5678004a,0x45d5024f,0x752f002a}},	//   _dół_, абря_, собс, _pacz
  { {0x7c2b0176,0x99d30074,0xcdf70008,0x63600064}},	//   _ysgr, _بتوا, ימלי_, _dönm
  { {0x3958000a,0x61fe44b4,0x69da44b5,0xf2c70459}},	// [9c10] _כשהם_, erpl, lpte, асен
  { {0x34a7005d,0x889c0008,0xd25b0010,0xdb0a002d}},	//   _खरीद, _בבחי, кце_, _bhfé
  { {0x32790015,0x6d420045,0x7648008c,0x752f002a}},	//   دماج_, _onoa, ädyt, _tacz
  { {0xdd860074,0x91ac0092,0x7afd0007,0xc1980036}},	//   _رو_, _đọc_, ėsti, атії_
  { {0xf7700074,0x442b1d9d,0x351a000a,0x3cfc000b}},	//   _رای_, _usc_, _גורנ, ोलने_
  { {0x4429000c,0xf1c90029,0xf8bf00dc,0xf456000a}},	//   mwa_, _موسى_, ldés_, _הישר_
  { {0xdf480029,0x442944b6,0x3e320015,0x2eb4006b}},	//   شؤون_, lwa_, كفور, осъс
  { {0x4429005c,0xcd290080,0x31850015,0x98a5002a}},	//   owa_, ужие_, _الرِ, ślę_
  { {0xdd2f0089,0x1c4204ab,0xbc390015,0xeb991eb8}},	//   _těžk, зным, اسبا_, лии_
  { {0xe452000a,0xcb69002b,0x442902e3,0x0000006a}},	//   לֶת_, امده_, iwa_,
  { {0x442944b7,0x0000006a,0x0000006a,0x0000006a}},	//   hwa_,   ,   ,
  { {0x44290553,0xce6805aa,0x0000006a,0x0000006a}},	//   kwa_, _труд_,   ,
  { {0x4429000c,0x9942005c,0xdc74004a,0x7d0944b8}},	//   jwa_, _pół_, _мышь, mges
  { {0x59cf014e,0x44291865,0x7c292080,0x7d0944b9}},	//   _संपर, dwa_, mwer, lges
  { {0xdb03002d,0x4429002a,0x7bdb008c,0x7c2944ba}},	//   _ghná, ewa_, lpuu, lwer
  { {0x16a8000b,0x7c2944bb,0x7d09352a,0x99420535}},	//   _गरीब, ower, nges, _wół_
  { {0x75240048,0x4429003f,0xf9930135,0x7c2944bc}},	// [9c20] reiz, gwa_, _מרה_, nwer
  { {0x7d0900b8,0xdc880008,0x61fe0844,0x2837000a}},	//   hges, בְעָ, trpl, _פניך_
  { {0x7c29018b,0xb9c10064,0xe1fa12c9,0x7d091786}},	//   hwer, _üçün, уге_, kges
  { {0x4429000c,0x4fc60010,0xf53f002c,0x7d090111}},	//   bwa_, бска, áťte_, jges
  { {0x7c290111,0x674500dc,0x3849000a,0xd12f0015}},	//   jwer, _útjá, ֹאוּ_, عمه_
  { {0x7d090313,0xadd801f3,0x0ce0000b,0x88bb000a}},	//   eges, амку_, नर्म, אזני
  { {0xdef9008f,0x11d50010,0x7c290186,0x4769000a}},	//   рыі_, _мітр, ewer, שׁוּ_
  { {0xa5db0053,0x3f870026,0xbebc0024,0xdd900002}},	//   אַזי, annu_, _saīs, بوب_
  { {0xb87b002d,0xdb030125,0x69c2000b,0x8066023c}},	//   naít, _shná, _रंजी, _уваж
  { {0x2619014e,0x6e3c02c1,0xf8bf0030,0x1f633cde}},	//   _पहली_, _árbo, zdés_, _екум
  { {0xdc550086,0x442944bd,0x7f3b0008,0x6e960029}},	//   مریک, zwa_, _תעבו, _الضا
  { {0x7c29020a,0xd90f0074,0x4429005c,0x3da50036}},	//   bwer, ریخ_, ywa_, _дріб
  { {0x87e40033,0x0000006a,0x0000006a,0x0000006a}},	//   зюсе,   ,   ,
  { {0xd7f80080,0xb87b002d,0x600b000a,0x69da44be}},	//   щую_, daít, נִכְ, ppte
  { {0x4b7b0135,0x9df8000a,0x7aea0045,0x6df8000a}},	//   _תאוו, יִּז, _ieft, יִּצ
  { {0x46d9000b,0x442944bf,0xf4d90323,0x7aea1529}},	//   _ब्रह, twa_, рмаш_, _heft
  { {0x4429000c,0x3f870026,0x69cd0024,0xf8bf01c4}},	// [9c30] uwa_, ynnu_, ēneš, rdés_
  { {0xe2f90036,0x7aea0cb8,0x442944c0,0xf2c70888}},	//   режі_, _jeft, rwa_, ссан
  { {0x7d0900dd,0x201f0045,0x442918bb,0x7c2916a4}},	//   yges, _spui_, swa_, zwer
  { {0x80e3005d,0x44290358,0xc1040015,0xe705002b}},	//   खरेख_, pwa_, كومي, _اسکی
  { {0xf194005e,0x19bc004c,0x9ee90015,0x7af8006f}},	//   чиць, אמאב, لفشل_, _odvt
  { {0x9e090015,0xef18005e,0x0000006a,0x0000006a}},	//   ليتك_, ймі_,   ,
  { {0xc33200f3,0x7d09299f,0xa75c004c,0x7c290079}},	//   _קול_, tges, רדור, wwer
  { {0x7c293617,0xa282002b,0x7f9f0003,0xc537000a}},	//   twer, _تیمو, vêqu, מָ֖ה_
  { {0x69ca00b8,0x69d802fd,0x7c290f55,0x93c60045}},	//   _aufe, _atve, uwer, prăş
  { {0xdce00007,0x2d8300dc,0x7d0911a6,0x7c2944c1}},	//   kimė, ője_, sges, rwer
  { {0x7aea0064,0xdd9901c9,0x3ced007c,0x3724004c}},	//   _deft, poň_, paev_, אַמיר_
  { {0x7bdb00f2,0x98a60063,0xdb0144c2,0xdc55002b}},	//   ppuu, жиме, illé, _ورشک
  { {0x6ca7002b,0x9b750015,0xb87b0e51,0x7ce8004f}},	//   _اصال, _واتص, daís, _הַצֶ
  { {0xe73a0124,0xd6da002b,0xacb6004f,0x0000006a}},	//   шег_, شورش_, _והנח_,
  { {0x857a0004,0x159a0015,0xd62a1528,0x7bcb027b}},	//   асат_, لنسخ_, шове_, _hugu
  { {0x656d025c,0x7bcb003f,0xe9730031,0xf9920018}},	//   ghah, _kugu, _يهود, _تبت_
  { {0x64a317b7,0xe7320087,0x7bc344c3,0x42ea0054}},	// [9c40] дата, _قصد_, _kinu, имао_
  { {0xdb180014,0x6360018b,0xaac9005d,0xb87b002d}},	//   _kivá, _köni, रशिक, raít
  { {0x7bcb2607,0x24960091,0x778300e2,0x7bc344c4}},	//   _lugu, _žemę_, _ілюз, _minu
  { {0x5a0c00b2,0x02aa000b,0x6716000b,0xdce244c5}},	//   רלאַ, _करीन, द्रक_, _ploč
  { {0x644b0020,0x79b7000a,0xdb010003,0x2eee24a7}},	//   ägit, קלנד_, allé, taff_
  { {0xb0330127,0x883b000a,0x8e3a0015,0x442201c2}},	//   ьніш, יתנו, لسعر_, _ipk_
  { {0xdbd1001c,0x2eee2460,0x7bcb44c6,0x2e4a024f}},	//   qüên, raff_, _augu, ряло_
  { {0x7bc3267f,0x442200e8,0xdd900029,0x98ab0011}},	//   _ainu, _kpk_, عوة_, ndcă_
  { {0xdca30124,0x7bc30035,0x69ca0011,0xa2be000b}},	//   маћи, _binu, _sufe, _वृत्
  { {0xb4db0251,0x442244c7,0xbf660067,0x7bcb44c8}},	//   _anàl, _mpk_, _بدرو, _dugu
  { {0xf2d30008,0x78ad00dc,0x7aea001a,0x6aa30034}},	//   ועת_, _szav, _veft, _cynf
  { {0x7bc30084,0xdb03001c,0xfc66006b,0xbe850015}},	//   _einu, _sinô, _мълн, _عجلو
  { {0xf8b00029,0x7536002a,0x2c92002b,0xdb10001a}},	//   َةُ_, ddyz, _زیدآ, ófón
  { {0x6021002e,0xe667006b,0xba760015,0x7bc344c9}},	//   _hámö, отбо, _واغت, _ginu
  { {0x69d844ca,0x163403fc,0x7bcb0012,0x8afb000a}},	//   _utve, меря, _zugu, _כהגי
  { {0xb87b0467,0x3f9c016f,0x798d005c,0x32010057}},	//   abía, hovu_, _ujaw, vrhy_
  { {0x78ad0107,0x85880033,0x44220085,0xdce00091}},	// [9c50] _uzav, цёра_, _cpk_, simė
  { {0x4374005e,0xa2950033,0x68ed44cb,0x02a70555}},	//   муєт, пазі, _head, орем
  { {0x68ed08c0,0x6440002e,0xa2be005d,0xc7940015}},	//   _kead, _ámin, _वृद्, _تشيب
  { {0x41740086,0x81c8005e,0xe1d8005e,0x715a0054}},	//   وانس, ігів_, ідчі_, èрес_
  { {0xb97c0053,0x68ed3bc0,0xb367006b,0xa1160015}},	//   סנדי, _mead, _дъвк, سقوط_
  { {0xdfce04c9,0x3f9c016f,0x799d0026,0x68ed1027}},	//   ديو_, govu_, hosw, _lead
  { {0xa6fc0008,0x7bcb22a4,0xed59005e,0x7bc30a2d}},	//   שִׂי, _sugu, йок_, _rinu
  { {0x7bcb08e0,0x7bc344cc,0x7c220125,0x68ed44cd}},	//   _pugu, _sinu, _bpor, _nead
  { {0x9c220080,0x7bc30035,0xdfd8006b,0xec790004}},	//   едыд, _pinu, _дъх_, спп_
  { {0x3b090124,0x59cf005d,0x7c22006f,0xdcfb0085}},	//   љено_, _संदर, _dpor, knuć
  { {0x4a740033,0xdcfb0091,0x7bc344ce,0x27e91d46}},	//   дыят, liuč, _vinu, _awan_
  { {0xbea80086,0x68ed002d,0x50cb000b,0x799d0034}},	//   _بهمن_, _cead, िशिष, gosw
  { {0x69c40020,0xa3ab005d,0x7bc30035,0x8d740086}},	//   _viie, खता_, _tinu, _تالا
  { {0xcc560008,0xdc3a004c,0xff47002b,0x7bc3007c}},	//   _מבני_, _לענר, رخ_, _uinu
  { {0xb5aa0029,0x68ed002d,0xd6cf0029,0x0b780015}},	//   مارك_, _fead, اقف_, _بصنع_
  { {0xf9fa000a,0x05aa0033,0x3f9c00b3,0x68ed15b9}},	//   _ההקמ, ёвай_, zovu_, _gead
  { {0xa2be000b,0x07fa0015,0x27e90039,0x48590033}},	// [9c60] वेन्, _اربع_, _gwan_, _дрэў_
  { {0x083b013a,0xc2b60054,0x6b810061,0xa87b000a}},	//   _פעיל, пљењ, nilg, _לאפר
  { {0xb6a30152,0xa2ce005d,0xa75b0008,0x35a61c64}},	//   éâtr, तशब्, _הדיר, _наог
  { {0x4fc644cf,0x69fa0053,0x7c3b02de,0xdb0a001a}},	//   пска, מלעק, kvur, _lifð
  { {0xdbd10251,0x6b81002e,0x55bb000a,0xe046004a}},	//   qüèn, kilg, _למטו, янди
  { {0x33b5004a,0x60c944d0,0x7d1b44d1,0x0000006a}},	//   _жёст, _egem, efus,
  { {0x7d1b44d2,0x60cd003d,0x7c2244d3,0xc0e6067a}},	//   ffus, žama, _spor, _новк
  { {0x7d780029,0x6b81002d,0x3f9c06cf,0x6d5900da}},	//   تمبر_, eilg, sovu_, _cowa
  { {0x2055000d,0x69d50089,0x68ed36d8,0x3cf70015}},	//   _отфр, ízen, _read, سعيد_
  { {0x68ed1c23,0x4477013a,0x27e90026,0x3ea500cb}},	//   _sead, פעיל_, _rwan_, _fylt_
  { {0xd5be005d,0x7edb0008,0x68ed3f83,0x27e944d4}},	//   ्दाज, _הקבצ, _pead, _swan_
  { {0x523b0053,0xe9810033,0x39990030,0x4d76006e}},	//   צײכנ, тамi_, lész_, _عطار
  { {0x7c220e6d,0xccf3000a,0xf9900015,0x6b8144d5}},	//   _upor, _נכס_, ابٍ_, bilg
  { {0xc7c40731,0x1cbb0008,0xb904000b,0x8cbb000a}},	//   есси, _המדע, _प्_, _הצדק
  { {0x68ed0005,0x66b40001,0xd9550015,0xf7940033}},	//   _tead, ебру, _ينتخ, харэ
  { {0xa6340010,0xe5090015,0x4ddb000a,0xd49b0004}},	//   энсі, تيرو_, מחלו, брз_
  { {0x78fc000a,0x2418005e,0x39990030,0xdcfb0085}},	// [9c70] _הפחו, зією_, kész_, snuć
  { {0x6e2d002a,0x8afc002a,0x98140015,0x60c90034}},	//   łabi, chęt, _أبيا, _sgem
  { {0x39990030,0x0667002b,0x35b510b7,0x81d40138}},	//   dész_, _رادپ, _обор, еціц
  { {0x92b40015,0x2509002b,0x0000006a,0x0000006a}},	//   رحلا, _بردی_,   ,
  { {0x853a000a,0xf99f02b9,0x50b9002b,0xdb18008c}},	//   _וגרי, ioè_, زگرد_, _kivä
  { {0x6d5900dd,0xbea50ea6,0x25a944d6,0xf838000a}},	//   _sowa, малк, llal_, פנות_
  { {0x6d59005c,0x2617001c,0x3949002d,0xf204004a}},	//   _powa, nço_, _onas_, _пято
  { {0xc2120008,0x61fa002e,0xae02005d,0x41550010}},	//   _שהן_, _ætla, रंजन_, _ўвас
  { {0x6b8144d7,0x104b005e,0x9f05006e,0xb035009b}},	//   tilg, _уяви_, _يورو, _юнаш
  { {0x25a90061,0x80a40015,0xb0340323,0x7c3b44d8}},	//   hlal_, _أمكن, _януш, rvur
  { {0xda780010,0xce6b0010,0x6d5907e9,0x6e67004a}},	//   зяў_, _урад_, _towa, _этаж
  { {0x5e9a000a,0xf769000a,0xfe9a000a,0xb87b013f}},	//   _ובעק, _דק_, _ויעמ, rbín
  { {0x02aa005d,0x59cf000b,0x071f000b,0x52aa000b}},	//   _कर्न, _संवर, म्भव_, _कर्स
  { {0xae21005d,0x3ea00011,0x4cba000a,0xb4b1000b}},	//   _महान_, şite_, _ומנג, टेज़_
  { {0xcb12000a,0x46a312ae,0x637202de,0xe5a61cd9}},	//   _סלה_, варв, _hæng, диви
  { {0xdb18022d,0x69950010,0x05aa0010,0x660135b3}},	//   _eivä, _прых, івай_, álka
  { {0xfc4a001a,0xe5a33e28,0x2d8d01f9,0xe73a44d9}},	// [9c80] mtíð_, тити, inee_, _деп_
  { {0x74130086,0x63720134,0x91e603ad,0x2d8d04ef}},	//   ئولا, _mæng, доже, hnee_
  { {0x637200fb,0x39990030,0x21761884,0xa2b30065}},	//   _læng, vész_, мудр, _अरण्
  { {0x290f0123,0x6e3c0e51,0x26d844da,0x91e344db}},	//   _ögat_, _árbi, lcro_, тоце
  { {0xdfcf0806,0xe571000a,0x39990030,0x2d9f0003}},	//   لين_, _גַם_, tész_, doue_
  { {0x9e14005e,0x6d5d0b1f,0xcdda0054,0x2d8d008c}},	//   едкі, ösan, оњи_, enee_
  { {0x636000dc,0xde930054,0x39990030,0x216a0477}},	//   _dönt, кашњ, rész_, _диви_
  { {0x60260001,0x71260015,0x8c66005e,0x427b000a}},	//   _одба, _ترسل, дтод, _ואלג
  { {0xc0d30015,0x394901f9,0x0000006a,0x0000006a}},	//   _شيلب, _rnas_,   ,
  { {0x25a0002d,0x6eb60015,0xdb0a0125,0x9a8601f3}},	//   hoil_, _قصائ, _bhfá, думл
  { {0xc333011f,0xdb180cbf,0x6f770015,0x2d9f00aa}},	//   דות_, _nivå, _تملأ_, boue_
  { {0x63721946,0x63600123,0x59ac000b,0x2d9f01f6}},	//   _hænd, _köns, _टीआर, coue_
  { {0x636044dc,0xa3c0005d,0xa2be005d,0x69ca000b}},	//   _yönt, ुदा_, वेत्, _संकी
  { {0x0a94008f,0x2d8444dd,0x636000c0,0x29050064}},	//   _палю, lime_, _möns, şla_
  { {0x3f7b004c,0x63600123,0x2d84007c,0x637202de}},	//   קאלס, _löns, oime_, _mænd
  { {0x2617001c,0x394902c1,0x636000c0,0x69fb000a}},	//   rço_, _unas_, _oöns, _ולהק
  { {0x93b50001,0x42550086,0x9f9f0030,0x2d84008c}},	// [9c90] ебац, کنار, téül_, iime_
  { {0x339b0015,0x20060034,0x326b0015,0xdb0a0012}},	//   آخرة_, droi_, يحاً_, _eifö
  { {0x15e8014e,0xeab401d8,0x2d8444de,0x466b005e}},	//   टीआर_, תִּי_, kime_, _єром_
  { {0x02df014e,0x25a00541,0xeab1000a,0xc4c70015}},	//   _प्रभ, coil_, אֹד_, _يتحو
  { {0x6360002e,0x752d332f,0x83870033,0x60cd003d}},	//   _pönt, meaz, _жыве, žamo
  { {0x752d0011,0x6360001a,0x2d8d44df,0xb4bd0065}},	//   leaz, _döns, wnee_, ेखी_
  { {0x69ca005d,0x62340080,0x11d40029,0x1758000a}},	//   _संगी, _иеру, _لتقد, וסגר_
  { {0x636001d1,0x752d0011,0xf5320008,0x212b0125}},	//   _föns, neaz, ָ֥ה_, _úch_
  { {0x7e990074,0x7f950010,0x2d9f00aa,0xa2d6000b}},	//   _کنار_, _заах, roue_, मुक्
  { {0x752d0045,0x5e270015,0xe452000a,0x8cbb000b}},	//   heaz, _يعاق, רֶה_, शेषो
  { {0xd9100086,0x9e140033,0x2d840091,0x60c40091}},	//   لیغ_, _адхі, bime_, žimt
  { {0x752d0011,0x6e3a000a,0xc7a9000a,0x2d8444e0}},	//   jeaz, _מתעד, _הב_, cime_
  { {0xc7960080,0x60db003f,0x26cc002c,0x752d0045}},	//   ервы, _mfum, ždom_, deaz
  { {0x907a0135,0x3f79004c,0x656f44e1,0x207a004f}},	//   לטרי, לאָס, _alch, לארא
  { {0xf5b60033,0x25a00072,0xa96a44e2,0x0000006a}},	//   есаю, toil_, _ника_,
  { {0xc6c30010,0x7dc700dc,0xe5a61adc,0x0000006a}},	//   уйск, _műso, хиби,
  { {0x09030010,0x09b7000a,0x0000006a,0x0000006a}},	// [9ca0] _спын, _אפקט_,   ,
  { {0x138a0029,0x88770008,0x27e00007,0x798644e3}},	//   أخرى_, _נתיב_, _itin_, likw
  { {0x2bb2005d,0x32170029,0x42560015,0xa93a000a}},	//   ुगता, فيلد_, عنصر, ּתְפ
  { {0x2d8444e4,0x79860297,0x6d4b00cb,0x59b20065}},	//   xime_, nikw, _nnga, ीगिर
  { {0x40340403,0xa0670001,0xf993000a,0xa75a000a}},	//   телс, наца_, נרד_, ּדֶר
  { {0x6d4b44e5,0xa2d60065,0x03a600af,0x200601f6}},	//   _anga, मुख्, _чиго, rroi_
  { {0x8e3700c3,0xa3c9000b,0x44320542,0x9e660015}},	//   فسير_, _लूट_, lwy_, عاتن
  { {0xf6530008,0x4432005c,0x6da300d7,0x621b000a}},	//   רצה_, owy_, лија, _מולק
  { {0x7986000c,0x44320026,0x63720134,0xcfea002b}},	//   dikw, nwy_, _tænd, _رفاه_
  { {0x752d04f9,0x543b0053,0x2d8444e6,0x6ffb000a}},	//   zeaz, לעפא, sime_, _מהמפ
  { {0x2a6a0014,0x672e0134,0x33770008,0x7e9a0115}},	//   ább_, debj, געים_, _عنصر_
  { {0x752d0045,0x67d544e7,0x092b0058,0x0000006a}},	//   xeaz, кому, أسدي_,
  { {0x752d0011,0x38c9002b,0x48ab0121,0x96eb09b1}},	//   veaz, بادی_, ятом_, зьба_
  { {0x44320176,0x66012497,0xdb4f0033,0xec37000a}},	//   dwy_, álko, _ёю_, _נאור_
  { {0x752d04f9,0x79a72b7a,0x27e00061,0x6d4b0034}},	//   teaz, _прие, _etin_, _ynga
  { {0x55580063,0xe5340323,0x0000006a,0x0000006a}},	//   нася_, лесь,   ,
  { {0x7bca000c,0x752d04f9,0x6aaa0026,0xd6db005e}},	// [9cb0] _kifu, reaz, _hyff, _нтн_
  { {0x752d0011,0x7bca003f,0xe6950015,0x94040015}},	//   seaz, _jifu, _للخد, اوله
  { {0x61ee0026,0x7bca003f,0x51870180,0xa1590054}},	//   _cwbl, _mifu, нуда, мажу_
  { {0x7ff54257,0x92b40029,0xe0d00067,0x30350015}},	//   نستا, احكا, مزه_, َّار
  { {0xfbe70092,0x78fc004c,0xd5640033,0xc428070c}},	//   _chế_, לפאו, _стэп, _пюре_
  { {0x083c0008,0x257e0046,0xb68b004f,0x0000006a}},	//   פעול, vůli_, ּרֵ֥,
  { {0x61ee0026,0x6aaa0026,0xed590139,0xde350033}},	//   _gwbl, _nyff, дой_, тэль
  { {0x27ed0089,0x361c000a,0x60db00aa,0x61e5343d}},	//   šeny_, פוחד, _ufum, mphl
  { {0x69cb000b,0x1004006b,0xdfd5055f,0xc05b0015}},	//   _संजी, _бяхм, _розы, _عشرا_
  { {0x0b420558,0x4a450c71,0x200f1a5e,0xfaf10015}},	//   аньн, внов, mugi_, جثة_
  { {0x6aaa0176,0x4432005c,0xf2d20008,0x48e6119f}},	//   _cyff, zwy_, יעי_, конв
  { {0x6aaa0026,0x69dc002d,0x1e56000a,0x3f8744e8}},	//   _dyff, írea, _בשער_, linu_
  { {0x8d7400e6,0x5d7a004c,0x3156004c,0xe14f005e}},	//   _حالا, _קאנק, דירן_, рсiв_
  { {0x3f8744e8,0xba750015,0x798602ad,0x660e0072}},	//   ninu_, _لابت, sikw, tubk
  { {0x6aaa0026,0xf8c700dc,0x200f007c,0x2d580003}},	//   _gyff, éért_, hugi_, _réez_
  { {0x1614014e,0x4432005c,0x7bca003f,0x91a30065}},	//   तंबर_, twy_, _zifu, _ज़ीलै
  { {0xf7730074,0x3f870084,0xccf20632,0x8cc4005d}},	// [9cc0] _چاپ_, kinu_, יכן_, ाइयो
  { {0x200f0020,0xc88700b8,0x44321817,0x3f870910}},	//   dugi_, ößer_, rwy_, jinu_
  { {0x7ae50020,0xf506047d,0x3f870c88,0x0000006a}},	//   _õhtu, _изно, dinu_,
  { {0x4a5a01c8,0xafe6008f,0x61430080,0xb816000b}},	//   ודעו, водл, иеха, _तमाम_
  { {0x3f87002e,0x200f0020,0xc6fa000a,0x69cb000b}},	//   finu_, gugi_, ֥לֶך, _संघी
  { {0xa0670001,0x3f8744e9,0x9207003d,0x64460091}},	//   ђаја_, ginu_, _stāš, _irki
  { {0x7bca02b9,0x61e50125,0xdb0100aa,0xf773000a}},	//   _rifu, cphl, polê, שקו_
  { {0xfbe70023,0xc5f30008,0xc693039e,0xcff4002b}},	//   _thế_, בדה_, יאו_, _ميرک
  { {0x711b000a,0x9bf30033,0xbfc632b0,0x3f873b9c}},	//   _קומפ, азыч, _абак, binu_
  { {0x3ce2000b,0x1eaa0015,0x81c7003d,0x3f8744ea}},	//   _ट्रे_, _قاضي_, amēģ, cinu_
  { {0x7bca000c,0xe9f80010,0x6a6b001a,0x8f7500ce}},	//   _vifu, энні_, vöfö, _суті
  { {0x79a4004a,0x644644eb,0xfce62ae4,0x0000006a}},	//   иряе, _orki, _родо,
  { {0x7d02016e,0x38340238,0x6d8b004f,0x6da300af}},	//   _idos, аняр, _קָבְ, _тица
  { {0x2575079b,0x248d0091,0xe7870b1e,0x2c84003d}},	//   _måle_, _žemo_, тумо, rīdī_
  { {0xfbb7013a,0x0bb704dc,0xdb6b000a,0xba550016}},	//   _שפות_, _שלום_, _קֳדָ, _vắcx
  { {0x69cb005d,0x3f8744ec,0xa87b0015,0xbe3b000a}},	//   _सूची, zinu_, _يحظر_, ועלת
  { {0x4993002b,0x64c40015,0x1614000b,0xf8bf0003}},	// [9cd0] _میگر, ليفل, तूबर_, ffée_
  { {0x41e7017f,0x81c70024,0x38640123,0xcc77000a}},	//   віда, zmēģ, ämre_, דגמת_
  { {0x7d02032c,0x3f87128d,0xa2be000b,0x70cb000b}},	//   _odos, vinu_, वेल्, िश्ल
  { {0xe4e40036,0x200f007c,0xe1f00015,0xc1040021}},	//   _вірн, tugi_, تسك_, لومي
  { {0x3f8713e7,0x2bce021e,0xb97c000a,0x80040004}},	//   tinu_, _हंगा, ונאי, ачје
  { {0x753d03c0,0x61e5001a,0x69c80046,0xa2be000b}},	//   _hasz, pphl, íjez, _वृक्
  { {0x753d0eba,0x3f8744ed,0x443937db,0x81c7003d}},	//   _kasz, rinu_, _hss_, tmēģ
  { {0x22940191,0x442b00e8,0xa0c50015,0x63a50012}},	//   _тися, _kpc_, _ميزو, lohn
  { {0x69dc032c,0x7d020026,0x753d0fce,0xcdc80015}},	//   íren, _ddos, _masz, خذون_
  { {0x442b44ee,0x765a008c,0x9a9d005e,0x443901f9}},	//   _mpc_, ätyk, зумi, _mss_
  { {0x656d3c28,0x198a0719,0x6a94005e,0x6a85009b}},	//   kkah, ебни_, ирює, улна
  { {0x753d0050,0x19f60015,0xe71a002b,0x4439146d}},	//   _nasz, دَّد_, کيست_, _oss_
  { {0x291e005c,0x8884002b,0xe8f701b0,0x69cd0696}},	//   ęta_, شیدن, ыля_, _diae
  { {0x8c28000a,0xf7460054,0x7d02006f,0xf092004f}},	//   _יֵצֵ, ћево, _zdos, מנכ_
  { {0x7bc1018b,0x1b9a0053,0xdb2200dc,0x75d600e6}},	//   mmlu, _אױסמ, _óráb, ايرا
  { {0x656d0035,0x6d5b064e,0x798402f2,0xa9280046}},	//   gkah, njua, _umiw, _drží
  { {0x9f4f002e,0xe3ba16e7,0x753d002a,0x442b44ef}},	// [9ce0] yrgð_, еба_, _dasz, _cpc_
  { {0x74130029,0x656d02f2,0x11d6005e,0x443944f0}},	//   صوما, akah, гідр, _dss_
  { {0xe216003b,0x471b0135,0x171b004c,0xccf9002a}},	//   طباع, _אויג, _אויע, kaś_
  { {0x7c2b44f1,0x32070030,0xf1a5005e,0xdb010003}},	//   _opgr, ánya_, арін, solè
  { {0x68f60064,0x673e00dc,0xd12f0029,0xd0d7005e}},	//   _meyd, _kapj, ثمن_, удії_
  { {0x27f20176,0x753d005c,0x8fa30809,0xe5e7002b}},	//   _mwyn_, _zasz, баче, _جزیی
  { {0x7bdd0084,0x09cf005d,0x5e260029,0x7c2b231a}},	//   ísun, _संगठ, اعتق, _apgr
  { {0x442000df,0x673e00dc,0x22930029,0x9f960020}},	//   oti_, _lapj, _الفس, lüüs_
  { {0x752400dc,0x442044f2,0xbb740099,0x0b8a0719}},	//   ifiz, nti_, игиј, есни_
  { {0xf0630124,0x673e0f49,0x69d8000b,0x409503ae}},	//   _укуп, _napj, _नंदी, _трст
  { {0x28c7005d,0x442009e7,0x6b884244,0x2bb70015}},	//   रेनि, hti_, ridg, داية_
  { {0x7d02005c,0x442044f3,0xbd290015,0x6444007c}},	//   _udos, kti_, _لأهل_, kvii
  { {0x442022b3,0xcebf0046,0x0137000a,0x27f20034}},	//   jti_, ěřen_, ארכת_, _cwyn_
  { {0x752400dc,0x27f20026,0xdceb0024,0xdc3b000a}},	//   efiz, _dwyn_, _ilgā, _נעור
  { {0x7afa022d,0xaadb0008,0x752400b8,0x28a5000b}},	//   matt, _אחור, ffiz, _गुरि
  { {0x63a500b8,0x6d401133,0x61fe220e,0x7afa44f4}},	//   wohn, ndma, dspl, latt
  { {0x27f20026,0xdb03002d,0x656d36f0,0x44200f28}},	// [9cf0] _gwyn_, _ghnó, rkah, gti_
  { {0x2d810014,0x753d005c,0x656d014b,0x7bdf0003}},	//   éhez_, _wasz, skah, _éque
  { {0x7afa02b9,0x6440003d,0x4420309b,0x6444008c}},	//   iatt, _šmit, ati_, avii
  { {0x7afa44f5,0x42040015,0x442044f6,0x865a004f}},	//   hatt, إِنْ, bti_, _סדרי
  { {0xb97c00b2,0xe4fa0008,0xb4fa0008,0x29040030}},	//   ענדי, _בפרש, _בפרי, ómai_
  { {0x6d470048,0x7afa00f2,0xdb0130fd,0x2567007c}},	//   ējam, jatt, polé, _võlu_
  { {0x7afa0ddf,0x539a0008,0x6d400079,0xe39a000a}},	//   datt, _יישו, fdma, _יששכ
  { {0xdb0100c0,0x63bc006f,0x3d01000b,0x7afa44f7}},	//   illå, _zhrn, ोलें_, eatt
  { {0x6d5b08c0,0x28c7000b,0x7afa44f8,0xeb990e4d}},	//   rjua, रेमि, fatt, кии_
  { {0xba750015,0x3a250418,0x8b690004,0x7afa44f9}},	//   لاجت, амог, тиов_, gatt
  { {0x442000dc,0xc332000a,0x5fba004c,0xd5b5000b}},	//   zti_, חוי_, _סצענ, ंताज
  { {0x64430048,0x442026f3,0x7afa00f2,0x213f064e}},	//   ānij, yti_, aatt, _jauh_
  { {0x442044fa,0x7c2b25bd,0x290c0061,0x7afa44fb}},	//   xti_, _upgr, ğda_, batt
  { {0xcf9200b2,0x1ae5000d,0xcb6644fc,0x6c7a000a}},	//   ַטן_, _токм, _ваше_, _ברנד
  { {0xcb12000a,0x96630a6c,0x24f61797,0xfb1a000a}},	//   _ולו_, окре, ичар, _יוסמ
  { {0x1a9a00f3,0x442044fd,0x4a9a000a,0x53e60015}},	//   _שיקע, tti_, _שיקג, لأطف
  { {0x31bc0089,0xd467017a,0x63860004,0x442044fe}},	// [9d00] níze_, аите_, агаа, uti_
  { {0x261e0026,0xb7fb000a,0xc6960015,0x44203b72}},	//   pïo_, _שפית, _نشجع, rti_
  { {0x201f03af,0x64440607,0xb2d30015,0xd24f0015}},	//   _aqui_, svii, زينغ, ونك_
  { {0x442044ff,0x7afa00dc,0x39401221,0xf1a9002b}},	//   pti_, zatt, _jais_, هانه_
  { {0x61e910d5,0x3940082d,0x7afa0061,0xd12f0015}},	//   _čele, _mais_, yatt, ظمه_
  { {0x42e70083,0x26cc01b2,0x39400034,0xd47b000a}},	//   _вмро_, ždou_, _lais_, _יאכל
  { {0x539b000a,0x7afa4500,0xdd9a098b,0x9757004f}},	//   _סילו, vatt, кши_, ייסו_
  { {0x28c7014e,0x394000b6,0x5d54066c,0x6443005c}},	//   रेडि, _nais_, скит, łnie
  { {0x1be70054,0xc0aa0040,0x6d404501,0x7afa4502}},	//   адњи_, _شارل_, rdma, tatt
  { {0x395208e0,0xeb4a3736,0x7ac605f8,0x4f960054}},	//   _anys_, тчик_, исне, _трбу
  { {0x9f7b0008,0xfe720029,0x83b70008,0x28f90286}},	//   _שנבח, _بدء_, שפיע_, лень_
  { {0x39400176,0x64490007,0xcc870086,0xc237000a}},	//   _cais_, _šeim, انیه_, ברטו_
  { {0xb87b0089,0x7d7b0447,0xc86415fd,0x7afa4503}},	//   dcíc, _בנאו, отри, patt
  { {0x3ea904f9,0xd7f8054f,0x3c7b000a,0x98c40033}},	//   şate_, шую_, _שָׁב, ўсюл
  { {0x3bbb0008,0xf1bf002c,0x39400152,0x31ae01c0}},	//   _שמוד, žšia_, _fais_, lýzu_
  { {0xda5b013a,0x39402296,0xccf1000a,0x224d0b28}},	//   _יכול, _gais_, ּ֛ן_, _ček_
  { {0xa99c0008,0x54b9054f,0xe4500015,0x7ceb004f}},	// [9d10] _שבחר, угая_, وضك_, דַבֶ
  { {0x28c7005d,0xc2cb0086,0xddce002c,0xb3540a82}},	//   रेणि, نبال_, ždňo, окуш
  { {0x39520026,0xcb37000a,0x213f0c48,0xeb91000a}},	//   _ynys_, שאבי_, _pauh_, הָא_
  { {0xd1090086,0xb87b00dc,0x29190d25,0xe2980036}},	//   اقشه_, bbít, ngsa_, шає_
  { {0x59d0005d,0x5045000d,0x90450015,0x55ba000a}},	//   _संघर, селб, إنته, _תמרו
  { {0x69d80152,0x543a0053,0x6fd40036,0x7838000a}},	//   _ouve, _געשא, іціє, שָׁב_
  { {0xc2930086,0x41e40033,0x925808fc,0xc332000a}},	//   _بیاب, _міта, _карт_, _מום_
  { {0x0698000a,0x59dd000b,0xbda40015,0x68fd003d}},	//   ידום_, _नंबर, يحيو, jasd
  { {0x39400d89,0x4d460033,0x69d824ee,0xff530058}},	//   _rais_, спын_, _auve, _وخط_
  { {0x39404504,0xa2be000b,0x4ea7032d,0x94b6000a}},	//   _sais_, वेक्, _креа, מִיד_
  { {0x8b640029,0xd9462354,0xb87b0046,0xa96a0e91}},	//   تايم, бени, ycíc, гина_
  { {0xf769000a,0xdd8f002b,0x59831092,0x69d84505}},	//   _אק_, _کوچ_, злюб, _duve
  { {0x9cda0053,0xc19a0053,0xb900000b,0x6be50015}},	//   _עקספ, רשרי, _तल_, _اكتم
  { {0x6a25002b,0xdb18016e,0xbbd6000a,0x66080d46}},	//   _هفتم, _divó, _פוצץ_, ádko
  { {0x2618005d,0x69d84506,0xb87b0046,0x39404507}},	//   बंधी_, _guve, tcíc, _tais_
  { {0xdb1a001a,0xb87b0046,0x3940016e,0x0000006a}},	//   mmtá, ucíc, _uais_,
  { {0x69d800b8,0xb87b4508,0xd776002b,0x3164007c}},	// [9d20] _zuve, rcíc, _هادع, _romz_
  { {0x2618005d,0x6735005c,0x0b15000a,0xb87b4509}},	//   बंदी_, cezj, מַ֣ר_, scíc
  { {0x86c6002b,0x200f140d,0xe5a6012e,0xb87b450a}},	//   _ديدن, ergi_, _гини, sbít
  { {0xa1130015,0xd0e8002b,0x0000006a,0x0000006a}},	//   كومت, شکرم_,   ,
  { {0x30140036,0xb87b00dc,0x7f4101c2,0xf1a90015}},	//   ідкр, lbír, _balq, جاله_
  { {0xb7db0053,0xb87b0077,0x69dc0030,0xd367004f}},	//   אקסי, ncía, írek, _ִ֙ם֙_
  { {0x41b60086,0x7e2a0033,0xcf250021,0xe733000a}},	//   _همسر, уіла_, ترني, לֵק_
  { {0x8cc4005d,0xf653000a,0x2d8d00aa,0x248d0091}},	//   ाइलो, לצו_, giee_, _žemi_
  { {0x205600d7,0x69d8450b,0x2618000b,0x0caa004a}},	//   _утвр, _suve, बूती_, ытки_
  { {0x4f650029,0xc43b0008,0x220a000a,0x68e40799}},	//   _والف, נתיי, ְפָּ, _afid
  { {0x99990083,0x69350256,0xeb970004,0x25a901d7}},	//   икот_, онну, сиќ_, yoal_
  { {0xd2b70008,0x3f8e003f,0x721b0008,0xe29b004c}},	//   מלית_, lifu_, נוכח, רשטר
  { {0xbda50029,0x27480030,0x98ab0045,0x91bb004f}},	//   _بحلو, zínű_, decă_, טמטי
  { {0x3f8e003f,0x7bdf0152,0x8c1b015b,0x69c6001a}},	//   nifu_, _équa, _עווי, amke
  { {0xa5f90001,0x8f8b000a,0xde78000a,0x68e40034}},	//   ребу_, רְכֵ, בְּך, _ffid
  { {0x3d06000b,0x56940a13,0xb87b039f,0x0000006a}},	//   _षयों_, част, acía,
  { {0x98170087,0xf994000a,0xf8ab0015,0x2419055f}},	// [9d30] _ابعا, _מרק_, _حدثه_, розы_
  { {0x6d470024,0x25a9450c,0x63600030,0xc7f8000a}},	//   ējai, soal_, _köny, _הזזת_
  { {0xd2510029,0xa4d505d1,0x42990015,0x765a008c}},	//   بنا_, _моні, جناح_, ätyt
  { {0xdb01450d,0xc2c40015,0x2127002b,0x3cf2000b}},	//   volí, سيني, صيتی_, घरों_
  { {0x1ee7002b,0x351a000a,0xdcee0046,0x251a004f}},	//   موشی_, _דורנ, žděl, _דורא
  { {0x21270086,0x2d9a00dc,0xdb010264,0xa6fb000a}},	//   _گيری_, épen_, tolí, אִ֗י
  { {0x171c0aef,0xdb180057,0x01e9000a,0x0000006a}},	//   אווע, _chví, _כַּֽ,
  { {0xcfe90086,0x637b0003,0x27e9450e,0xdb01450f}},	//   _نفره_, _dîne, _otan_, rolí
  { {0x3ea9005c,0x3f8e003f,0x1c4204ab,0xbbe8002b}},	//   łat_, bifu_, дным, یریم_
  { {0x3b090001,0x1a050c71,0x68e40824,0x6488004f}},	//   јено_, опом, _sfid, מְתְ
  { {0xeab1003b,0xfa53002b,0x2d8d00aa,0x27e9151e}},	//   بعة_, سردگ, piee_, _atan_
  { {0x3a980080,0xdc7508f0,0xd826011e,0x0dcb0597}},	//   стью_, _мыль, одми, _сузи_
  { {0xa13a0053,0x913a004c,0xd78a0015,0x66e600ce}},	//   בערח, בערק, لنحو_, жога
  { {0x7d1b0020,0x257c4510,0x5bc50015,0xdb1f008c}},	//   lgus, _míle_, _بقتل, äväp
  { {0x212d1f8b,0x7d1b1a5e,0x98ab0045,0x9e09000a}},	//   _obeh_, ogus, tecă_, יִּ֖
  { {0x057a0015,0x7d1b0521,0x7c2400d4,0x0000006a}},	//   جمرة_, ngus, _ţiri,
  { {0x7d1b0020,0x336602e1,0xf6d6005e,0xb87b0046}},	// [9d40] igus, оваг, _міня, sbír
  { {0x257500c0,0x656600dd,0xe2920015,0xb7d7002b}},	//   _håll_, _wokh, وذا_, _گویا_
  { {0x021a005e,0xe0da4511,0xc0ea006e,0xc916000a}},	//   різь_, аве_, لفان_, ַחַת_
  { {0x6443005c,0x27e90123,0xc1780091,0x8afc002a}},	//   łnia, _ytan_, _įės_, ojęc
  { {0x3f8e003f,0x257c0089,0xa2aa000b,0xaff70015}},	//   tifu_, _cíle_, _जुर्, قفنا_
  { {0xe45101e4,0xdce20064,0x7d1b14d3,0x70530015}},	//   _אֶל_, _bloğ, egus, بنها
  { {0x3f8e000c,0x6e93002b,0xa1160015,0x7d1b0012}},	//   rifu_, ولها, _ووست, fgus
  { {0x71760018,0x7d1b2c7e,0x42530058,0xdb0801f6}},	//   _بهرا, ggus, _تنفر, modé
  { {0xe8160065,0x0000006a,0x0000006a,0x0000006a}},	//   _तमगा_,   ,   ,
  { {0xe45700b2,0x8afc005c,0x7d1b0035,0xb603006f}},	//   קייט_, djęc, agus, žšie
  { {0x27e94512,0xd337000a,0xd006002b,0x418a004f}},	//   _stan_, חריה_, کل_, ֹנָ֑
  { {0x49740033,0xf8bf0030,0x0000006a,0x0000006a}},	//   длюс, bfél_,   ,
  { {0x7dd500df,0xd7fb0001,0x23aa000b,0x798f0034}},	//   _išsa, јум_, कवाद, ricw
  { {0x28c7005d,0x7d004513,0x290405a4,0xd8380033}},	//   रेषि, lams, ómar_, цэю_
  { {0x55590063,0x86240080,0x4b7b000a,0xaa570015}},	//   бавя_, мьте, _דאגו, _ولها_
  { {0x6602002a,0x55070033,0xdb010030,0x4a7b000a}},	//   _łokc, ўчва, molá, _כרוב
  { {0xd3750001,0x27e94514,0x43070015,0xc2eb0015}},	// [9d50] плаћ, _utan_, قذاف, لعام_
  { {0x27e90024,0xbbd7000a,0x6b9a0012,0xdbd6008c}},	//   ķinā_, קובץ_, nntg, mään
  { {0x35f40010,0x28c7005d,0xf772000a,0x7d1b0061}},	//   _опэр, रेरि, _נקט_, ygus
  { {0xe9380053,0xf5590029,0x36340086,0x05590015}},	//   ַנוץ_, _الحب_, _کریس, _الحظ_
  { {0xe3170015,0xf55a000a,0xdbd6008c,0xdee52372}},	//   _وبسب, _הדרמ, nään, поли
  { {0xa3f60008,0xa5d80086,0x3fab0054,0x92a6002a}},	//   _ממשק_, _دبیر_, шњем_, wiłł
  { {0x7d000026,0xfe710021,0x798d002a,0x91560046}},	//   fams, عدت_, _omaw, áříc
  { {0xdb0100dc,0xf2d200f3,0x7d1b4515,0x7c3b0303}},	//   dolá, _טעם_, ugus, twur
  { {0xdbd60e95,0x1c45005e,0x7d1b4516,0xd0110058}},	//   jään, їном, rgus, _سلا_
  { {0x547c0008,0x3f140001,0x3b82223b,0x7c3b0012}},	//   יטחו, _одус, ельг, rwur
  { {0x8d770029,0x63720134,0xd9460c5b,0x89f40033}},	//   _واصا, _sænk, пени, мяяц
  { {0xac190802,0x7d250086,0xdb0a002d,0x89360015}},	//   _году_, _رفتن, _bhfó, أعدا
  { {0xb87b002d,0x28c7000b,0x48b6006b,0x52b8000b}},	//   scín, रेलि, ящот, _अर्स
  { {0xb87b002d,0x2b18000b,0x89d6002b,0x61e9055c}},	//   pcín, _दाएँ_, _کوير_, _čeln
  { {0x644b002e,0x2d7f002a,0xdb010533,0x07a30195}},	//   ægin, ałeś_, colá, харн
  { {0xceb20008,0x7ae60089,0x63720134,0x18a6042b}},	//   גיל_, ěkte, _tænk, _найм
  { {0x130a0010,0xd5af0806,0xf3f10016,0x38c8002b}},	// [9d60] йнай_, افق_, _ặc_, _باغی_
  { {0x29023a62,0x6e2d002a,0x69d60061,0xdb080324}},	//   laka_, łaby, _hiye, todé
  { {0x11d60074,0xd6db0008,0x7dc50077,0xdce200bc}},	//   ستاد, _לחיל, mósf, _sooč
  { {0x6a9a0053,0xe5a603ad,0x1876000a,0x29024517}},	//   זשענ, _хими, ּעַר_, naka_
  { {0x69d600b6,0xdb0100dc,0x65620020,0xb87b0046}},	//   _miye, zolá, öohu, jcíl
  { {0x94bb000a,0x7f1a00fd,0x90530033,0x78b6008c}},	//   _למכת, сіду_, эвіц, _myyv
  { {0x29020035,0x7ee30029,0x7fd5005e,0x0f290015}},	//   kaka_, ركين, фіці, تثنى_
  { {0xd29b0008,0x69d60064,0xfd1200a2,0x6143018f}},	//   _השלט, _niye, رجع_, _песа
  { {0x7d004518,0x29024519,0xec32002b,0xe571000a}},	//   rams, daka_, رودگ, דַי_
  { {0x807b0008,0x307b0008,0xdb0100dc,0xfc2f00e6}},	//   _הנמצ, _האמנ, tolá, احي_
  { {0xcf250029,0x69d602f2,0xb87b0046,0xe981005e}},	//   _ترقي, _biye, acíl, ванi_
  { {0xdc2a0074,0xdb0100dc,0x644a0024,0xdbd600f2}},	//   _هسته_, rolá, āfij, tään
  { {0xdb010014,0x6c340086,0x98740127,0x69d60064}},	//   solá, _آفتا, еляц, _diye
  { {0x8bd7000a,0x321a1b3f,0xdb01451a,0x2902005b}},	//   _זוגו_, kupy_, polá, aaka_
  { {0x2902451b,0x8b8b0008,0x3bbb0008,0x8f9b000a}},	//   baka_, _לָהֶ, _המגד, צילי
  { {0x2006022d,0xdbd6022d,0x79a40010,0x6a9b000f}},	//   ksoi_, sään, _прые, _לשונ
  { {0x24f80010,0x2458004a,0x03d500e2,0x98a400af}},	// [9d70] янты_, пать_, джаю, _пиће
  { {0xa87c013a,0xd25b008f,0x6443005c,0xf2c7000d}},	//   _לאחר, йце_, łnio, псен
  { {0xe3b00029,0x69d60061,0x799d0012,0x62080015}},	//   ارق_, _yiye, onsw, كْلِ_
  { {0x637301e2,0x4095012c,0x0000006a,0x0000006a}},	//   _sını, ولار,   ,
  { {0xb4d9000b,0x6443003d,0xc0e20054,0x3f69226f}},	//   ाशी_, ānis, њошк, жило_
  { {0x4429451c,0x2902451d,0x0000006a,0x0000006a}},	//   mta_, zaka_,   ,
  { {0xee390191,0xc3320053,0xce190010,0x321a00da}},	//   іни_, _שול_, іцкі_, cupy_
  { {0xd6580008,0xc2c40015,0x4429451e,0xc537004f}},	//   ליות_, _سيقي, ota_, פָ֔ה_
  { {0x2d830007,0x69c40026,0x644d451f,0x29023b3a}},	//   ėje_, _rhie, nvai, vaka_
  { {0x69c426e3,0x62850057,0x44294520,0xb87b1756}},	//   _shie, ozho, ita_, gcím
  { {0x8e990029,0x29022b8b,0x527a0053,0x44294521}},	//   _بناء_, taka_, ַנשא, hta_
  { {0xdde90086,0x8c590015,0x44294522,0x6f03406e}},	//   _هرچه_, _ولاء_, kta_, lanc
  { {0x9a990024,0x8c4509ef,0x6d5907e9,0x29024523}},	//   _šādā, _целе, _inwa, raka_
  { {0x6d494524,0x29024525,0x44294526,0xdc88000a}},	//   ldea, saka_, dta_, _מְצָ
  { {0x45d6004a,0x69c40043,0x6443002a,0x29024527}},	//   дцат, _thie, łnil, paka_
  { {0x60d60007,0x79fa000a,0xf9fa000a,0x44294528}},	//   žymi, _ולקח, _והקמ, fta_
  { {0x6d49002d,0xf9c70086,0x6f030e59,0x44294529}},	// [9d80] idea, _تحوی, kanc, gta_
  { {0x257c0089,0x6d4900f2,0x6f030b88,0x321a01c0}},	//   _díla_, hdea, janc, tupy_
  { {0xa6ca0074,0x673c1344,0x2d9a00dc,0x6f0307fc}},	//   _گوگل_, merj, épek_, danc
  { {0x27e0022d,0x321a005c,0xc329000f,0x7c29452a}},	//   _kuin_, rupy_, יו_, kter
  { {0xc483008f,0x27e00152,0x2900001c,0xa0670054}},	//   _аляк, _juin_, _meia_, маца_
  { {0x6d5922cc,0x673c452b,0x25ad0796,0x2900452c}},	//   _anwa, nerj, čele_, _leia_
  { {0x9e66002b,0xda09000b,0x658c0061,0x661c452d}},	//   باشن, _विगत_, eşhi, nurk
  { {0x27ed0011,0x7c29452e,0xa1130015,0x6da302d9}},	//   ţeni_, fter, _لوفت, кија
  { {0x4f260124,0x6f0343fc,0x673c013c,0x84a9000a}},	//   _одаб, banc, kerj, ּיתִ
  { {0x661c0007,0x6d590026,0x2d9800dc,0x799d0034}},	//   kurk, _enwa, őre_, wnsw
  { {0x644d0024,0x442906e7,0xfaa6004a,0xdb230030}},	//   zvai, zta_, ьшин, úság
  { {0x298b0036,0x442907a0,0xed630091,0x7c29240d}},	//   існо_, yta_, gužė_, bter
  { {0xdb080077,0x29000144,0xd0f7000a,0x4429452f}},	//   lodí, _deia_, ומכת_, xta_
  { {0x1cbb000a,0x8c430054,0x7dea0091,0x69dc0030}},	//   _ומדע, _реље, _tęsd, íres
  { {0x67d40080,0x5a460010,0x057700e6,0x29003d96}},	//   тору, _цэла, وارد, _feia_
  { {0x628500bd,0x9e4b000a,0xf9880015,0x2cfb004c}},	//   vzho, חֲמִ, _ينوي_, ַלבא
  { {0x8cc4005d,0x644d1e14,0x44294530,0xc8fa000a}},	// [9d90] ाइटो, uvai, uta_, _מִיכ
  { {0x752d4531,0x61fc0034,0x644d4532,0x257c3e08}},	//   sfaz, _bwrl, rvai, _víla_
  { {0xa1150029,0xb1150001,0x41e40010,0x6f034533}},	//   فوات, емеш, віча, vanc
  { {0xf9d900b2,0x6f030a3d,0x7c294534,0x44294535}},	//   פֿעל, wanc, yter, pta_
  { {0xd47900b2,0xe4a7009c,0x06f3000b,0x7fe8002b}},	//   _זאָל, _црно, _अभाव_, وروف_
  { {0x394900dd,0xa2950210,0x9f050029,0x33fa000a}},	//   _laas_, _загі, روبو, _מהשנ
  { {0x6d490011,0x2b470034,0x6f034536,0xad650058}},	//   tdea, _ranc_, ranc, فاظه
  { {0x6f031f10,0x394900dd,0x7c294537,0x2d940033}},	//   sanc, _naas_, tter, крыс
  { {0xfc480023,0x7c294538,0xcfe90015,0x7dc5001a}},	//   _cử_, uter, _رفضه_, jóse
  { {0xfaf10029,0x6d490125,0x27e04539,0x2900453a}},	//   دثة_, sdea, _ruin_, _seia_
  { {0xc3320053,0x673c453b,0x7bd8453c,0x3a99004a}},	//   נוט_, verj, _divu, ятию_
  { {0xf2d20008,0x127a0053,0x6d59453d,0xbd450015}},	//   טעי_, פארע, _unwa, _سنتي
  { {0x27e00251,0x673c453e,0xa3db000b,0xdb01008c}},	//   _quin_, terj, _ढंग_, tolä
  { {0xfaa51bc8,0xa875004a,0xfbc50b9b,0x5c9a000a}},	//   _пало, тующ, _ябло, _צֹאנ
  { {0xcb120008,0x8f9a0008,0xdb010123,0x46a30033}},	//   _עלה_, לישי, rolä, гарв
  { {0x2d9f0152,0x661c0064,0xf484002b,0x39491703}},	//   nnue_, rurk, پاری, _gaas_
  { {0xfc480023,0xa99b0008,0x66e6107c,0x399b000a}},	// [9da0] _xử_, _מבקר, _попа, _מיקד
  { {0x74130029,0xe3b70221,0x03230174,0xf746011e}},	//   اولا, ебу_, лдун, _џено
  { {0xf6260033,0x8afc002a,0x0676009b,0xd26001ec}},	//   _ядно, djęl, _чупя, āņos_
  { {0xa87a0135,0xf653000a,0xc0e615fb,0xdb080069}},	//   ּאַר, _עצר_, ходк, vodí
  { {0x26c70046,0xdd90002b,0x25a000bc,0x6f01453f}},	//   _únor_, یوت_, mnil_, _belc
  { {0xdfcf04c9,0x3dc64540,0xa8a9000a,0x8f3407bd}},	//   مين_, _show_, וֹצִ, текц
  { {0xfc4800a7,0xf773000a,0x25a0104b,0x32070030}},	//   _sử_, רקו_, onil_, ányt_
  { {0x7bd80945,0xc106002b,0x5d540608,0xc693000a}},	//   _sivu, _سوئي, ткит, טאו_
  { {0xdca30054,0x10a306c3,0x6f014541,0x25a00072}},	//   лаћи, _битн, _felc, inil_
  { {0xf8bf0152,0x25a000bc,0xf413004f,0x9b58009b}},	//   ngée_, hnil_, נפת_, фиот_
  { {0xc333011f,0x25a000bc,0xa93d01f3,0x2e160058}},	//   אות_, knil_, однi, _سباح
  { {0xbfa50023,0xfc480023,0x4c8603fa,0x929b000a}},	//   hiệ, _tử_, _плев, ליית
  { {0xb909005d,0x99840015,0xdbd6008c,0xdb08016e}},	//   _बल_, الُو, _pääj, godã
  { {0xcb670342,0x7dc5001a,0x9cd7000a,0x6c470058}},	//   _паче_, róse, _נוגה_, _ألوف_
  { {0x64463e62,0x4e34000a,0x6a860003,0x39494542}},	//   _aski, כָּן_, _défé, _taas_
  { {0x257c0089,0x7abb00f3,0x3abb000a,0xd5b81017}},	//   _dílo_, _מצוו, _ממונ, есу_
  { {0x68ed0064,0x7dc50125,0x28c7000b,0xe4350058}},	// [9db0] _ifad, lósc, रेखि, ضفاد
  { {0x889c0008,0x339b0015,0x25a0007c,0x3339009a}},	//   _מבחי, أخرة_, anil_, بزرگ_
  { {0x22590029,0x64464543,0x998701ec,0x0000006a}},	//   بلاد_, _eski, ļiņa_,
  { {0xc0d50015,0xd1780033,0xeab1000a,0x7d023ef4}},	//   نياب, нсіі_, בֹד_, _neos
  { {0xb0cb000b,0x00e4005e,0x05b6002b,0xb87b0046}},	//   ़ेंग, ужін, _شگفت_, ucíh
  { {0x7bdf038d,0x656f018b,0x7ff4006e,0xe0d00015}},	//   _équi, _hoch, اسنا, حزم_
  { {0xb87b00dc,0x6372002e,0x656f4544,0x443901d7}},	//   gbíz, _vænt, _koch, _hps_
  { {0x7dd500df,0x11d40029,0x6f010334,0xb604006f}},	//   _išsk, _متقد, _welc, ýšit
  { {0x7d020011,0xb87b0046,0x656f4545,0x7538000a}},	//   _deos, abíz, _moch, תאחד_
  { {0x656f1c1b,0x20c80015,0x24890085,0x44394546}},	//   _loch, _أبِي_, izam_, _mps_
  { {0x6a86038d,0xcf56000a,0xdc28002b,0x8ad40033}},	//   _réfé, _שבעת_, وسیه_, лююц
  { {0xc7a9000f,0xdc53002b,0x656f4547,0x44394548}},	//   _וב_, _مرتک, _noch, _ops_
  { {0x8ccd005d,0x35db005d,0x5d780036,0x25a0013f}},	//   देशो, _मंज़, _яйця_, vnil_
  { {0x24894549,0xaba90015,0xfc460046,0xf53f0123}},	//   dzam_, _تهتم_, řích_, _skåp_
  { {0x6d4b00b6,0xd6270731,0xd639005e,0x6b96000a}},	//   _kaga, коре_, няті_, _בכסף_
  { {0xceb20008,0x6d4b3591,0x4439454a,0x656f454b}},	//   ׁים_, _jaga, _bps_, _coch
  { {0xf9b7000a,0x6d4b454c,0x75d30015,0x27f5006f}},	// [9dc0] _שהפך_, _maga, شيكا, čaný_
  { {0x656f002d,0x25ad01a3,0x6d4b3029,0xebd5000a}},	//   _eoch, čela_, _laga, דֵ֣י_
  { {0xf8bf0152,0xa77b000a,0xdb080046,0x6372001a}},	//   rgée_, _חריפ, nodá, _sæns
  { {0xa1130031,0x6d4b454d,0xd1300015,0xa3ea0004}},	//   لومت, _naga, صمت_, _одма_
  { {0x60f70010,0xc953000a,0x6023004a,0x7d0201bc}},	//   тнія_, ימא_, идца, _reos
  { {0x28c7005d,0xe0010010,0x7d02128b,0x38bd002d}},	//   रेटि, сьцi_, _seos, lárú_
  { {0x9e030010,0x4420454e,0xf1aa0086,0x1ee90086}},	//   ачыл, lui_, _قاره_, رويی_
  { {0x7524454f,0x3ea00045,0x90e50015,0xdb08006f}},	//   ngiz, ăit_, _مسكن, dodá
  { {0x98be0089,0xafe60036,0xdb1a002d,0xddca00dc}},	//   ětě_, _розл, llté, ínűs
  { {0x6d4b002f,0x2bba0029,0x8e3a0015,0xda660015}},	//   _eaga, باعة_, _يسار_, ناجي
  { {0xeb97000d,0x33770008,0x7d0209e7,0x4420064e}},	//   тиќ_, דעים_, _teos, hui_
  { {0x6d4b30e7,0x7c47008c,0xfe090015,0xfaa30004}},	//   _gaga, ärrä, _أغلى_, раџо
  { {0x96eb004a,0x6d404550,0x44204551,0x656f4552}},	//   дьба_, mema, jui_, _roch
  { {0xdc37004c,0x9b6a01f3,0x6d4b40e0,0x656f4553}},	//   _סאוט_, _ішла_, _zaga, _soch
  { {0x35e40191,0xda6f010f,0x9a870015,0xe4e700fd}},	//   ицтв, _тя_, _لَوْ_, візн
  { {0x6d400100,0x88c80046,0xa9270015,0x7c2d0045}},	//   nema, _stěž, _شعبه, _ţari
  { {0x5455044e,0x442009a3,0xc7ab0029,0xdb1a00dc}},	// [9dd0] ыват, gui_, _يدخل_, elté
  { {0x656f00b8,0x6d404554,0xbebc003d,0x9f9a019a}},	//   _woch, hema, _acīm, _jään_
  { {0x52150511,0x44394555,0x31ae0107,0x656f4556}},	//   удет, _wps_, lýzy_, _toch
  { {0x4420315e,0x1a9b0053,0xf67a0053,0x7ff50086}},	//   bui_, ויבע, _נארמ, هستا
  { {0x44201f5f,0x351a000a,0x6d40437f,0x7dc5001a}},	//   cui_, _אורנ, dema, jósa
  { {0x7dd500df,0x6d4b4557,0xff25005e,0x6d40007c}},	//   _išsi, _saga, умко, eema
  { {0x3e320015,0x6d4b4558,0x43940dfc,0x0000006a}},	//   مفور, _paga, _тарс,
  { {0x26dc0135,0xc5f4000a,0xed450004,0x8e740937}},	//   וקומ, בדק_, унип, рушч
  { {0x7bca017e,0xdb01002e,0xff25002b,0x0d820033}},	//   _bhfu, illö, _مبای, ёльн
  { {0x9ee90029,0xc0c80063,0x20090cd4,0xdfd5004a}},	//   _أفضل_, _русе_, šais_, _созы
  { {0x7dc700dc,0xadf503fc,0x6d404559,0x6d4b455a}},	//   _műsz, _спеш, bema, _taga
  { {0x2d9a0030,0x8dfa000a,0x2904455b,0x9f4e0030}},	//   épet_, _נהנת, úma_, önös_
  { {0x30790053,0xdb23002b,0xdb080030,0x3ced00bc}},	//   גאָנ, _نوشی, sodá, mcev_
  { {0x3ced018c,0xdb081754,0x4420455c,0x0000006a}},	//   lcev_, podá, vui_,
  { {0x98a40064,0xdbd10020,0x2a150010,0xba390053}},	//   ımı_, _müüj, _сьлё, _טײַט
  { {0x3ced00bd,0x7d09016f,0x7524003f,0x4420455d}},	//   ncev_, naes, ugiz, tui_
  { {0x7984003f,0x75d30015,0x031a0015,0x3942007c}},	// [9de0] _iliw, إيقا, فتات_, meks_
  { {0x3942455e,0xf773002b,0x4420455f,0x6d404560}},	//   leks_, _هاپ_, rui_, zema
  { {0xeb9600b2,0x6b7a00b2,0xdb960053,0x877b0053}},	//   נדער_, ערענ, נדעט_, _נאטי
  { {0x11d70029,0x39420020,0x673b016f,0xd46a06da}},	//   هولة_, neks_, đuje, _зиме_
  { {0x644a0024,0x79b7000a,0x26c5006f,0x7dc70030}},	//   āfis, נלנד_, ýlov_, _fűsz
  { {0x39420020,0xd8d70053,0x79840026,0xa2e324bf}},	//   heks_, אונט_, _lliw, _горд
  { {0x63ab00dc,0xdef90010,0x63830001,0x8cd6000b}},	//   égne, тыі_, _угра, मेनो
  { {0x644d0020,0xc0d60086,0xd1320015,0x765a008c}},	//   _üliõ, _ميزب, _دمر_, ätyy
  { {0xd1b30074,0x6d404561,0x9f9a008c,0x39424562}},	//   _اینک, rema, _pään_, deks_
  { {0x6d870467,0xbc370029,0x79840b63,0x6d404563}},	//   _añad, اسيا_, _aliw, sema
  { {0xee290029,0x2d9a00dc,0x4e1a0087,0x6d400020}},	//   _لأنه_, épes_, _ستاد_, pema
  { {0x984b0010,0x39420020,0xc9870015,0x3cfa0015}},	//   няга_, geks_, اشدي, _أعاد_
  { {0x0c760018,0x0c77002b,0xa3d7000b,0xa3e40065}},	//   _حداد, _مصوب_, ागम_, _पूल_
  { {0xba0a0029,0xead43839,0x60dd016d,0x0000006a}},	//   _كتبك_, _коль, _úsme,
  { {0x5b7b0053,0x6b7b0008,0x9bbb000a,0x6b9a0012}},	//   _ארגא, _ארגנ, _רצופ, mitg
  { {0x25ad01a3,0xc615000b,0x79843738,0x6b9a0773}},	//   čelo_, _तटीय_, _gliw, litg
  { {0x33f40015,0x3ebe00cb,0xd91c000a,0x64150015}},	// [9df0] مسلس, _lytt_, _נוזל, شواط
  { {0x98b90024,0x290b4564,0xf3150033,0xf8bf0144}},	//   cesā_, laca_, рджэ, sfés_
  { {0x3ebe069c,0xd6db0036,0xdb08001a,0x69df0030}},	//   _nytt_, _яти_, lldó, _épes
  { {0x31350036,0xe4e40036,0x290b2be9,0xc5fa000a}},	//   редр, _гірн, naca_, _שפרט
  { {0x3ced00bd,0x9f05002b,0x7d09014b,0xf19400ce}},	//   vcev_, لوشو, vaes, щиць
  { {0x9e090029,0x3ebe02d2,0x6602002a,0xdde8002b}},	//   نيتك_, _bytt_, _łoki, گروه_
  { {0x27780008,0x7d0900f2,0x6b9a4565,0x7aed007f}},	//   רגון_, taes, ditg, _şato
  { {0x463c004c,0x6e920015,0x290b4566,0x6b9a4567}},	//   געהע, غليا, jaca_, eitg
  { {0x3ebe0084,0x0d8206b4,0xe7e1000b,0x3ced00bc}},	//   _eytt_, ільн, _गंगा_, rcev_
  { {0x30840029,0x15e5000b,0x0000006a,0x0000006a}},	//   _الكف, कदार_,   ,
  { {0x39420005,0x3ced00bd,0xdd15002b,0xc869000a}},	//   teks_, pcev_, _نواخ, _קן_
  { {0xac960074,0x69cd0026,0xd2b6000a,0x4996005e}},	//   انیا_, _chae, ילתת_, ршот
  { {0x39420020,0x6b65034e,0x6d7a000a,0x97c6005e}},	//   reks_, _вкла, _שאנח, ийме
  { {0x39421c23,0x8c1a00f3,0x3c8a000a,0xcb690054}},	//   seks_, _יוני, _שָׁ֑, _јаке_
  { {0x290b013c,0x85960033,0x3942007c,0x63b701c0}},	//   baca_, ашац, peks_, doxn
  { {0x60c900bd,0x69cd002d,0x9990005c,0x64a60010}},	//   _ozem, _ghae, żała_, ааба
  { {0x19bb0008,0x49bb000a,0x3f85001a,0x07a60262}},	// [9e00] _במקב, _במקס, _ollu_, _вапн
  { {0x7bc10176,0xddd80007,0x187b000a,0x987b000a}},	//   nllu, tyvū, _סטיב, _סריק
  { {0x171b0053,0x00e61310,0x7bc14568,0x7dc51ad6}},	//   _בויע, ажен, illu, jóso
  { {0x3f850026,0x7dc50030,0x0000006a,0x0000006a}},	//   _allu_, dóso,   ,
  { {0x33d60036,0x60c9005c,0x70540029,0xf1a90021}},	//   _вівт, _czem, إنتا, داله_
  { {0xa8570008,0x57fb000a,0x60c9003d,0xcfaa002b}},	//   יינה_, דלסו, _dzem, خاصم_
  { {0x44324569,0xe8e00016,0xd252002b,0x433b004f}},	//   lty_, _muối_, _بنز_, _שעלב
  { {0x3f850020,0x44321212,0xc5f3000a,0xad660021}},	//   _ellu_, oty_, חדה_, شابه
  { {0x290b456a,0x443205a1,0x257c0046,0x69cd456b}},	//   vaca_, nty_, _cíli_, _rhae
  { {0xda7a006b,0x0437004c,0x4432456c,0x61e0456d}},	//   вям_, סטיש_, ity_, _himl
  { {0x61e001e2,0xac730086,0x44320a8e,0xa3d7000b}},	//   _kiml, مایش, hty_, ागत_
  { {0x60c000f2,0x6b9a0251,0x4432456e,0x61e001d7}},	//   _kymm, sitg, kty_, _jiml
  { {0xdbdc0089,0xcce5006e,0x290b456f,0x4432220c}},	//   lšíh, _اسمي, raca_, jty_
  { {0xe8e00023,0x7a34002b,0xda66006e,0xbb430663}},	//   _cuối_, _هفتص, _نابي, _мечк
  { {0xada5002c,0x603a0024,0x290b3913,0x44324570}},	//   skúš, lāmā, paca_, ety_
  { {0x4432003e,0xaadb00a3,0xa9940015,0x63f70015}},	//   fty_, _בחור, _وشيت, لأطر
  { {0x799d003f,0x02af000b,0xdce00091,0xe3c50015}},	// [9e10] misw, _जुड़न, rkmė, مْرَ
  { {0x8c1b0008,0x9cd70008,0x3f9c32ed,0x88bc000a}},	//   כומי, שומה_, jivu_, _במחז
  { {0xd251003b,0xd8b80074,0x60c90014,0xdbdc0089}},	//   ثنا_, _مدیا_, _szem, jšíh
  { {0x10150029,0x8ad90053,0x41740058,0xd25800af}},	//   مبتد, אַנפ, يانس, шцу_
  { {0x3e4700dc,0x27e94571,0x7f430012,0xdceb003d}},	//   _sőt_, _juan_, tenq, _nogā
  { {0xe7fa000b,0x43850015,0x60c900bc,0x603a003d}},	//   ्ठता_, _السق, _vzem, dāmā
  { {0x6fcd002c,0xe7180008,0x13aa002b,0xaf34002b}},	//   júce, בחור_, _صنفی_, ترنت
  { {0xee360010,0x4d6505ab,0x6fcd0695,0x518700ce}},	//   ёны_, скив, dúce, _туга
  { {0xec790080,0x799d0034,0xbc620033,0x303a002b}},	//   упп_, disw, звык, _متلک_
  { {0x5f740029,0x68e40034,0x3b85076f,0x7bc14572}},	//   _والر, _sgid, слог, ullu
  { {0xe9da010f,0xc3320008,0x4432002a,0xdce900bc}},	//   лко_, הוי_, zty_, lječ
  { {0xe9a60036,0xe8e00016,0x27e90034,0x186a19b2}},	//   самп, _suối_, _buan_, гами_
  { {0xf71a0010,0x7db40015,0xca74002b,0x44324573}},	//   лівы_, _بصلا, منیک, xty_
  { {0xdce9010b,0xcc560008,0x291e4574,0xd62a0164}},	//   iječ, _לבני_, şta_, логе_
  { {0xc9f50070,0xfaa24575,0xceb2000a,0x0000006a}},	//   _استع, _нашо, ֤ין_,
  { {0x27e90026,0x44320ae5,0xceb2000f,0x3f9c044c}},	//   _fuan_, tty_, פין_, zivu_
  { {0x98b904f9,0x1ddf005d,0x44324576,0xe45a0033}},	// [9e20] resă_, _पूछत, uty_, ыжа_
  { {0x212d0273,0x60c00123,0x44324577,0xdb014578}},	//   _aceh_, _rymm, rty_, moló
  { {0xdb9a0053,0xd36f0029,0x02060080,0x44321ac1}},	//   נסער, عهم_, ёздн, sty_
  { {0x3aba0053,0x32170015,0x443205b2,0x395200da}},	//   אמענ, إيند_, pty_, _jays_
  { {0xc0130036,0xb87b4579,0x3a250150,0xc4d6002b}},	//   зміщ, ncíp, hulp_, _دغدغ
  { {0xe820005d,0x2fd700e6,0xa0070015,0xef0e006b}},	//   _बिना_, موند_, حقول_, амa_
  { {0x52860029,0xb7db039e,0x442013e5,0xa248002b}},	//   _الأك, נקצי, lri_, _خیال_
  { {0x3f9c022d,0x9bf4005e,0xdbdc0046,0xdceb003d}},	//   sivu_, озич, ršíh, _pogā
  { {0x40960029,0x9dad000b,0x4420457a,0x351b000a}},	//   _الذر, ँकड़ो, nri_, אופנ
  { {0x799d0176,0x4420457b,0x7a38005e,0x3ea60004}},	//   wisw, iri_, апор_, _лизг
  { {0xed060086,0xc333000a,0x395200da,0x8afc002a}},	//   _هواپ, לוז_, _bays_, djęt
  { {0x8afc005c,0x27e928f8,0x9e650015,0xf96b004a}},	//   ejęt, _puan_, _باكن, урой_
  { {0x27e9457c,0x3952003e,0xd0060115,0xdd3b000a}},	//   _quan_, _days_, بل_, _תעדכ
  { {0x799d064e,0x9cd7000a,0xf093000a,0x0bb5002b}},	//   sisw, _הודה_, לנר_, _وجوگ
  { {0x4b37000a,0xf5e40033,0x7d25001a,0xb6bd005e}},	//   _לרגל_, зіум, _útsý, тивi
  { {0x7df10024,0x27e90375,0xe9a400d7,0xa5350033}},	//   _jāsa, _tuan_, _најп, ўнач
  { {0x44201a26,0x539904ab,0x97c50015,0xdb011a2a}},	// [9e30] gri_, авая_, _وقعو, coló
  { {0xdce90085,0xdceb0045,0xdce0003d,0x93970058}},	//   vječ, _kogă, ekmī, حجرا
  { {0x26c7002c,0xd25b0033,0x0736000a,0xd1750033}},	//   _áno_, ыца_, _ואתם_, жылы
  { {0x4420457d,0x59c9000b,0x969a000a,0xdce90085}},	//   bri_, रतिर, _כשתה, tječ
  { {0x602500fd,0xa3d50c96,0xb8820030,0x67480030}},	//   ідка, _момч, őíve, _érjü
  { {0xfe700086,0x98b90007,0x66fb000b,0xdce90085}},	//   کده_, cesą_, ्रिक_, rječ
  { {0xdce9016f,0x877c0053,0xdb01080d,0x69330046}},	//   sječ, ראוי, rolü, _křeč
  { {0x4c850191,0xee36008f,0x31340180,0xa69c004c}},	//   жлив, іны_, _неср, טשופ
  { {0x395200da,0x506701b0,0x8afc002a,0xdb010552}},	//   _rays_, _утва, yjęt, polü
  { {0x3952003e,0xeb990684,0x80a40015,0xdb79006b}},	//   _says_, рио_, _عملن, рсиш_
  { {0x89aa005f,0x3952038d,0x539a0008,0x753d005c}},	//   иков_, _pays_, שיתו, _obsz
  { {0x4420457e,0xf769000a,0xdb1a00aa,0xdb01457f}},	//   yri_, _בק_, notê, toló
  { {0xfd100029,0xe8e00016,0x25a9013f,0x0136000a}},	//   _سجن_, _ruồi_, dnal_, חררת_
  { {0x3952003e,0x50da0053,0xbae50015,0xbb420004}},	//   _ways_, יקרא, _بكثي, _жешк
  { {0xdb014580,0xb9c60015,0x645d4581,0x44200034}},	//   soló, _وتعه, _arsi, wri_
  { {0x44204582,0x25a90043,0xdb014583,0x26c4003d}},	//   tri_, gnal_, colò, āmo_
  { {0x7d0b0014,0x842a005e,0xa7d60015,0xdb1a0030}},	// [9e40] _megs, ржзв_, _وتخص, lltá
  { {0x2bcf005d,0x44204584,0x14170015,0x7d0b2ed5}},	//   _सीमा, rri_, زيمة_, _legs
  { {0x98b900df,0x43750036,0x6140002e,0xdce9002c}},	//   resą_, чутт, _nálæ, dieľ
  { {0x44204585,0x41030033,0xdb1a0030,0x0000006a}},	//   pri_, дзцв, iltá,
  { {0x69c600c0,0xf993039e,0x98a20091,0xdfcf002b}},	//   ilke, ורא_, iekį_, چين_
  { {0xdfcf0070,0x7d0b007c,0x90530033,0xd03700ce}},	//   نين_, _aegs, ьвіц, юзії_
  { {0xa3d7000b,0x0000006a,0x0000006a,0x0000006a}},	//   ागर_,   ,   ,
  { {0x867b004c,0x71660015,0x5c741831,0x0000006a}},	//   ירצו, _باسك, злит,
  { {0x8c43000d,0xb143017f,0xfbaa004a,0xdddc0030}},	//   дење, _інфл, итой_, ézőj
  { {0xc43b0008,0x25ad0198,0x61fe02d2,0x24800061}},	//   סתיי, čeli_, oppl, iyim_
  { {0x5ea60015,0xdb010144,0xd35b000a,0x7fd500ce}},	//   _بمال, tolò, בדיל, _хіті
  { {0x9c660015,0xdebb000a,0x6fc40144,0x2d8d1859}},	//   _وهاو, _דמבל, dòci, chee_
  { {0x7dd50007,0xdb010144,0x7df1003d,0xb8f30157}},	//   _išsp, rolò, _jāsn, _वर_
  { {0x35c3000b,0x5bc60015,0x68f60034,0xc7bb004a}},	//   _वीज़, _بتصف, _efyd, рём_
  { {0x69330089,0x68f60026,0x9df80008,0x25a00020}},	//   _přeč, _ffyd, מִּז, fiil_
  { {0xf568017f,0x0595002b,0x481509dd,0x74a70054}},	//   ошук_, سازگ, _емис, ојзе
  { {0xe8e00092,0x99d40029,0xc6e70127,0x25a90aff}},	// [9e50] _buổi_, _تتوا, _мінп, rnal_
  { {0xd25b1174,0x03d40036,0xdb1a001a,0xed5910af}},	//   ице_, джую, amtö, može_
  { {0x25a00020,0x6fc40144,0xb8820030,0x52550058}},	//   biil_, còci, őíte, ثناء
  { {0x51840033,0x7dea002a,0xb5a71ab1,0x85a7116f}},	//   муча, _gęsi, _фрой, _фјод
  { {0x644f04ed,0x7d0b00dd,0x2492005c,0xdca60015}},	//   _usci, _regs, czym_, _أى_
  { {0x644d0026,0x4429013c,0xd343002b,0xdceb002a}},	//   mwai, mua_, _تفسی, _mogą
  { {0x44294586,0xcf240015,0x171c004c,0x7dc50030}},	//   lua_, ذروي, בווע, lósi
  { {0x752d000c,0x3cf7014e,0x44290045,0x66150030}},	//   ngaz, ीरें_, oua_, iszk
  { {0x644d0026,0x752d0030,0xdb1a001a,0x1c4201b0}},	//   nwai, igaz, iltæ, еным
  { {0xcf780029,0x5f95002b,0x44290045,0xab290054}},	//   _وإلا_, _علائ, iua_, љона_
  { {0xb6030046,0x644d0702,0x9f34005e,0x752d0030}},	//   ýšle, hwai, _цехі, kgaz
  { {0x44293da1,0xed58005e,0x69c6008c,0x6615002a}},	//   kua_, _моє_, ulke, dszk
  { {0x4429003f,0x38550063,0x25a0007c,0x66151506}},	//   jua_, мърс, viil_, eszk
  { {0xddc10089,0x644d0026,0x4429013c,0xcc76000a}},	//   _splň, dwai, dua_, _מענה_
  { {0x6abc0012,0xfb52002b,0x7c294587,0x96630c02}},	//   ürft, _سپيد, luer, нкре
  { {0x25080086,0x291e0007,0xceb2000a,0x2bcf000b}},	//   ترسی_, ėtas_, ׂים_, _सीता
  { {0x44294588,0x25a001d7,0xd4672124,0x98a60785}},	// [9e60] gua_, riil_, пите_, _хипе
  { {0x9837000a,0x2492002a,0x752d4589,0xf74a0058}},	//   _צריף_, rzym_, agaz, _الدي_
  { {0x61fe0084,0x24920050,0xb77b013a,0x877b0008}},	//   uppl, szym_, _האיש, _האיי
  { {0x3cf7005d,0x673c002e,0x4429458a,0x752d0030}},	//   ीरों_, lfrj, bua_, cgaz
  { {0xe8e00023,0xf993004c,0x93c60045,0x50ba0015}},	//   _tuổi_, ערד_, epăş, حداد_
  { {0xfbc70031,0xd3b9005e,0x6fe9005e,0xb4d80065}},	//   _ست_, _дусі_, іфів_, ाधी_
  { {0x7c290012,0xdb0e0046,0x324314b5,0x8e370058}},	//   euer, ádím, _перг, كسير_
  { {0x7c2902c1,0x63be016f,0xa2d30058,0x8e830058}},	//   fuer, lopn, _سيقت, عليه
  { {0xac310053,0x8e20005e,0xbd870015,0x66150030}},	//   _לאָזן_, рiв_, ثنين_, zszk
  { {0x53be005d,0x7017000a,0x6615002a,0xe47b000a}},	//   ्तिश, _מחמד_, yszk, צריכ
  { {0xa3e4000b,0xfbcf0015,0x7c290012,0x7df1003d}},	//   _पूछ_, دتي_, auer, _jāsl
  { {0xed590156,0x644d0026,0x63be0107,0x9f440144}},	//   tože_, ywai, hopn, _humà_
  { {0x7c2902c1,0xf1bf006f,0x38c9002b,0x61ee458b}},	//   cuer, ýšia_, تادی_, _lubl
  { {0x4429022d,0x61ee0152,0x07090015,0x36d51236}},	//   vua_, _oubl, تيسي_, догр
  { {0x8b3b0008,0xc6680001,0x7bda002e,0xeb3b000a}},	//   _התוצ, пште_, mmtu, _העוש
  { {0x442911ec,0x4dfb004c,0x66150030,0x7a530015}},	//   tua_, מפלא, rszk, _أضوا
  { {0x3f8c0064,0x6fcd002c,0x752d00dc,0xd91c0008}},	// [9e70] _oldu_, dúcn, rgaz, _הוחל
  { {0x4429000c,0x026b004a,0x644d00a9,0x61ee013f}},	//   rua_, йшей_, rwai, _bubl
  { {0x7bda0084,0x798d1316,0x442908b1,0xf2040033}},	//   imtu, _klaw, sua_, еячо
  { {0xc5f80048,0x6d970011,0x7dc5047e,0x44292e51}},	//   ģēt_, nţat, pósi, pua_
  { {0xcee90010,0x4429458c,0xe796002b,0x7f750033}},	//   одле_, qua_, _رایک, дуйц
  { {0x798d0176,0x394b0003,0x5f94004a,0x25ad0b28}},	//   _llaw, hecs_, ничт, čelu_
  { {0xdce90024,0x6e950015,0x64420003,0x61ee0085}},	//   pieļ, بلغا, çoiv, _gubl
  { {0xc537000a,0x3f8c001a,0xdb1a0012,0x7c29458d}},	//   לָ֖ה_, _eldu_, hltä, tuer
  { {0x6d490939,0xed5900bc,0x394000da,0x394b3be3}},	//   reea, tožb_, _rbis_, decs_
  { {0x161e000b,0x7c29458e,0x6d4901f9,0x798d458f}},	//   _बटलर_, ruer, seea, _alaw
  { {0xcda80086,0xdcf70015,0xddc80030,0x394a118f}},	//   _کهنه_, _فأشب, _erdő, озно_
  { {0xa96a0124,0x499a0191,0x7c2902c1,0xdeba0008}},	//   цима_, ітня_, puer, _ומעל
  { {0x7c294590,0x798d0034,0xd116000a,0x673c0052}},	//   quer, _dlaw, וקרה_, tfrj
  { {0xa088000a,0x8c4200c9,0x61fb0160,0x0000006a}},	//   פְרִ, _реше, _čuln,
  { {0xaa92003b,0xe7370080,0x8afa000a,0x798d0a5d}},	//   _للوث, ьер_, _והצי, _flaw
  { {0xceb20008,0x99520007,0x19b60015,0x798d233f}},	//   דיל_, ršų_, _تحتج, _glaw
  { {0x6fcd002c,0x64a30c53,0x61ee0490,0x63be4591}},	// [9e80] júco, вата, _subl, topn
  { {0x387f00b8,0xaad1000b,0x6fcd006f,0x7dea0091}},	//   äure_, _हराक, dúco, _kęst
  { {0x7dc50030,0x72030015,0x8266006e,0x6d970045}},	//   lósu, َوْم, بهان, nţas
  { {0xdce902d5,0x2f0a005c,0x62650015,0x7dea002a}},	//   ěněn, _mógł_, عالق, _męst
  { {0x7bc8002e,0x7bc301d7,0x4424339a,0x0000006a}},	//   yldu, _oknu, _ím_,
  { {0x61ee0020,0xdfd00018,0xde580033,0xdf770033}},	//   _tubl, ديت_, закі_, мбіі_
  { {0x69c425b5,0x114a0015,0xf536000a,0x02060138}},	//   _okie, _وجرى_, ֥נִי_, _ізан
  { {0x2dd7003b,0x99860089,0x1d34006b,0x7afc0061}},	//   وبية_, dulů_, хния, ırtm
  { {0x7e870007,0x447b004c,0xdb1800bf,0x21a31208}},	//   _įspū, ַנטע, _akvá, _ритм
  { {0x798d11a8,0x807b000a,0x307b000a,0x7bc80061}},	//   _slaw, _ונמצ, _ואמנ, uldu
  { {0xe9f80127,0xfe46005e,0x798d01d7,0x394b33d0}},	//   янні_, _індо, _plaw, tecs_
  { {0x1ea900c3,0x7c470123,0xded30058,0x26180065}},	//   _عالي_, örrå, _شينخ, _फिजी_
  { {0x6d970045,0x394b1e83,0xa16c0033,0xdb1800bf}},	//   rţat, recs_, рцiн, _ekvá
  { {0xbc6700c3,0x27c40058,0x0000006a,0x0000006a}},	//   _آمون_, َيَّ,   ,
  { {0x7dea005c,0x3bbb000a,0x386d0045,0x64460091}},	//   _gęst, _ומגד, ţer_, _apki
  { {0x9999005c,0x58d5004a,0x03f901ca,0xf3f900af}},	//   żyła_, _пойт, знај_, знаш_
  { {0xdb0120bf,0x54990033,0x69dd4592,0x44990138}},	// [9e90] rolö, чваў_, mmse, чваю_
  { {0x6d970011,0x58d80010,0x4374005e,0x39a80030}},	//   nţar, _ідэя_, куєт, rőse_
  { {0x98ac005c,0xdcee0046,0xe7e8000b,0xc50b0015}},	//   ędą_, ýděl, _टूटा_, _وتحل_
  { {0xe5070002,0x65950010,0x8aab000a,0xe72b002b}},	//   _تبدي, _чаму, חֹדֶ, _اسکو_
  { {0x50670029,0xb4fa0008,0x04c900a2,0x60080484}},	//   بطاق, _מפרי, _روسي_, днім_
  { {0x6d42003e,0xd00e0015,0x7e5504bb,0x657d4593}},	//   _aboa, حلو_, етиц, _hosh
  { {0xee39129a,0x23be005d,0xa1950784,0xdb08002a}},	//   їни_, ्तरद, _завч, hodó
  { {0x5067006b,0x8db50033,0x63a501d7,0x657d4594}},	//   _отза, эслі, lihn, _josh
  { {0xed591c1e,0xdb011d2c,0x6fc40144,0x657d4595}},	//   rdž_, lilé, tòct, _mosh
  { {0xa3bf005d,0x69c41514,0x99860046,0x69dd4596}},	//   ँकि_, _skie, tulů_, emse
  { {0x61e91805,0xf98a0015,0xdb0e0046,0x4b33002b}},	//   _kiel, كندي_, ádám, _یکدس
  { {0xf9920002,0x99d60015,0x4c950923,0xb9c50015}},	//   ابد_, عتدا, _пиес, َتَه
  { {0x7a3501e2,0x9c870015,0xdb080077,0x6fc40144}},	//   _bütç, _تشاه, godó, mòcr
  { {0x61e90048,0x7dea00df,0x5c7a0053,0xa09a0053}},	//   _liel, _tęst, _מאנה, לירט
  { {0x0b780029,0xcb660080,0xdb010003,0x6d591b8c}},	//   _تصنع_, _чаще_, vilè, _kawa
  { {0x6d5b4597,0x69c412d1,0x6d594598,0x61e94599}},	//   ndua, _ukie, _jawa, _niel
  { {0x6d5921a0,0x809f005d,0xeb390008,0x7c3b248e}},	// [9ea0] _mawa, _खेले, ּעֲש, ntur
  { {0x68ed005c,0x6d590375,0xe45f008c,0x7bc1459a}},	//   _zgad, _lawa, _työn_, nolu
  { {0xc4c90008,0xe733000a,0x2d8f007c,0x62850034}},	//   צג_, _עֵץ_, _olge_, gyho
  { {0xc05a01f3,0x61e9459b,0x7bc10012,0x6d59459c}},	//   зік_, _ciel, holu, _nawa
  { {0x9f3402e1,0x4fc6459d,0x61e9459e,0xc4830033}},	//   велі, нска, _diel, _бляк
  { {0xa49b0144,0x7c3b459f,0x2d8f45a0,0x25bf0160}},	//   _teòr, dtur, _alge_, čule_
  { {0x61e91633,0x6d5945a1,0xade604b4,0x7bc10a57}},	//   _fiel, _bawa, нцик, dolu
  { {0xdd970080,0x6d590375,0xfe6f0015,0x7c3b45a2}},	//   ешь_, _cawa, صدى_, ftur
  { {0xacea0086,0x7c3b0035,0x6d5945a3,0x4c9406da}},	//   يرکل_, gtur, _dawa, типс
  { {0x09c9014e,0x7bc10030,0xe451000a,0x61e931bd}},	//   रत्य, golu, בֶט_, _ziel
  { {0x200d018b,0x61e9003e,0xdb08005c,0x0c73002b}},	//   _zwei_, _yiel, wodó, ندید
  { {0x6d5911ac,0xdb01008c,0x7c3b003d,0xa28b004f}},	//   _gawa, enlä, btur, לְכ֖
  { {0x802a000a,0x7c3b0b8b,0xc19b000a,0xcb6a07f7}},	//   הוָ֥, ctur, לשטי, _наде_
  { {0x7bc104f9,0x6d593dad,0xd90f0086,0xef0e0010}},	//   colu, _zawa, جیک_, амi_
  { {0x7dc50084,0x39820084,0x862403e7,0x46e8004a}},	//   póst, _póst_, льте, едён_
  { {0xb8950015,0xdb080030,0x68ed0125,0x9e4b000a}},	//   _للبع, indí, _ugad, הֲמִ
  { {0x93270086,0xf99400a3,0x8335006b,0x34940054}},	// [9eb0] فران, _תרפ_, кнах, гатр
  { {0x61e945a4,0xe9df0030,0x8c1b000a,0xb5f502ed}},	//   _siel, lmú_, פובי, _изощ
  { {0x61e945a5,0xe1390010,0x53440010,0x657d45a6}},	//   _piel, дзеі_, ыхта, _tosh
  { {0x361a00a3,0x62850107,0xc2c400c3,0x63a507c8}},	//   _קורד, ryho, ديمي, sihn
  { {0x29d9002f,0x61e945a7,0x6d590375,0x7c3b45a8}},	//   méad_, _viel, _rawa, xtur
  { {0x61e90050,0x44290014,0x50b80086,0xdce9016f}},	//   _wiel, mra_, ردند_, ljeć
  { {0xc2c50087,0x442945a9,0x60c9002a,0x6d4045aa}},	//   _شيري, lra_, _wyem, ffma
  { {0x7c3b45ab,0x1c4509a7,0x29d9002d,0x8d6503ad}},	//   ttur, вним, néad_, твие
  { {0x442945ac,0xfc160015,0xdce90085,0xddc90030}},	//   nra_, نقيب_, ijeć, ínűb
  { {0xdb230086,0x442945ad,0x6d5945ae,0x7c3b0490}},	//   دودی, ira_, _wawa, rtur
  { {0xa2a7005d,0xda780010,0xe80f000b,0x7c3b2482}},	//   _टेम्, еяў_, ़ीसा_, stur
  { {0x442945af,0x7c3b00d1,0x6ad1000b,0x7bc10bbc}},	//   kra_, ptur, _हरीर, solu
  { {0x29120482,0x442900dc,0x9f9b0020,0xdce90085}},	//   _veya_, jra_, pääs_, djeć
  { {0x7aa50029,0x442945b0,0x321a002a,0x7c2907a3}},	//   _لإعل, dra_, yspy_, mrer
  { {0xd4f6004a,0x99860015,0x395b45b1,0xdb010400}},	//   вязы, _للثو, _faqs_, rnlä
  { {0x29d90125,0xf8661797,0x9ae8000a,0xb8b60015}},	//   géad_, _авио, _אַפִ, _لإخت
  { {0xd706010f,0x28de005d,0xb957000a,0xdce9003d}},	// [9ec0] _изпи, नेशि, _ייקח_, rieķ
  { {0x78ad0089,0x2ba4000b,0xf7ea0015,0x7c2945b2}},	//   šová, गोपा, _ترعى_, irer
  { {0x7c29018b,0x7d0900dd,0xd24f0015,0xdce90085}},	//   hrer, kbes, ينك_, bjeć
  { {0x42550010,0x104a005e,0x6fcd0125,0x7c292215}},	//   ытут, дяки_, lúch, krer
  { {0xa8ad0008,0x442945b3,0x7d092c2d,0x0000006a}},	//   ּבוֹ, cra_, dbes,
  { {0x889b0008,0x7dd50091,0x6fcd0125,0x389b000a}},	//   ובני, _išsy, núch, ויננ
  { {0x7c2945b4,0x5725004c,0x1e96006b,0x98ac002a}},	//   erer, אַפּ_, ърдр, ędę_
  { {0xed870036,0x6ce6022a,0x7d092db9,0x8c66005e}},	//   вськ_, кіпе, gbes, втод
  { {0xc045012c,0xc0e306da,0x7c293e55,0x0000006a}},	//   _مخلو, _вотк, grer,
  { {0xf413013a,0x4a54030c,0x9b940015,0xa037004f}},	//   ספת_, гкос, الدت, _באמה_
  { {0xc33304dc,0x7d0945b5,0x29040061,0x442945b6}},	//   בות_, bbes, ıman_, zra_
  { {0x6f1800bd,0x8d1a0086,0x44293a47,0x7c2945b7}},	//   lavc, _آزار_, yra_, brer
  { {0x9c9a0015,0x6d630247,0x7c2901f6,0xe9a40138}},	//   _تنشط_, ávaž, crer, раўп
  { {0x6018002d,0xe9df002c,0x442945b8,0x9cd7000a}},	//   _zúmá, smú_, vra_, _סוגה_
  { {0xcb8b000a,0xdb1a016e,0x96f8029b,0xb8ca0065}},	//   _קְדֹ, potâ, тест_, _गे_
  { {0x7793002b,0x7afd0046,0xa9c4005e,0x442945b9}},	//   ایگا, ěste, _вськ, tra_
  { {0xb4d50080,0xf8bf0152,0x291945ba,0x97c70015}},	// [9ed0] ужащ, rgés_, masa_, _لتدم
  { {0x17550063,0xf2070010,0x7d0900dc,0xdce9016f}},	//   _своя, вядо, zbes, sjeć
  { {0x29d9002f,0x44291e69,0xc2c40015,0xe80f000b}},	//   péad_, sra_, ليكي, ़ीरा_
  { {0x32641a11,0x442945bb,0x7d090079,0x673b0085}},	//   штув, pra_, xbes, đuju
  { {0x90450115,0x656f0ec3,0x6fcd45bc,0x25a91993}},	//   انته, _inch, lúci, mial_
  { {0x29190849,0x649a0053,0x2d820123,0xee39394e}},	//   hasa_, _טירה, öken_, енк_
  { {0xf77400f3,0xa29500e2,0xada50a31,0x291945bd}},	//   יקס_, _саві, лакл, kasa_
  { {0x7c2945be,0x29191fb0,0x25a945bf,0xa282009a}},	//   trer, jasa_, nial_, _دیمو
  { {0x1be9004a,0x6d950030,0xdd1c0046,0x2489287a}},	//   ндии_, _ráad, nářk, nyam_
  { {0x7d0945c0,0x7d060061,0x7c292e2f,0x6f18006f}},	//   sbes, ıksa, rrer, cavc
  { {0x6fcd032c,0xdd8e0086,0x7d0945c1,0xc9aa0a3e}},	//   júci, زوی_, pbes, евне_
  { {0x6fcd002c,0x2d94005e,0xf2d2000a,0x7c2945c2}},	//   dúci, _кріс, מעי_, prer
  { {0x9b45003b,0x31560053,0x0c24005e,0x67280030}},	//   _منشو, נישן_, _вмін, ódjo
  { {0xa1420048,0x2d8d00f2,0x656f052a,0x2919007c}},	//   ēķin, lkee_, _anch, aasa_
  { {0x291900b6,0xfe670029,0xfbd20008,0x6fcd002d}},	//   basa_, حد_, _התג_, rúch
  { {0xd5e60ffe,0x2d8d45c3,0x291945c4,0x25a945c5}},	//   ужби, nkee_, casa_, gial_
  { {0x2bf600b2,0x69c60007,0xb4660174,0xdb1a16ce}},	// [9ee0] ָמען_, moke, ыкал, lotá
  { {0x6fcd163c,0x656f1447,0x389b015b,0x61f5068c}},	//   búci, _ench, _ניינ, _buzl
  { {0xb2260010,0x201f0251,0x57570008,0x35a62c2a}},	//   умел, _avui_, _גביע_, _банг
  { {0x25a908aa,0xf67b004c,0x9942002a,0x05560734}},	//   cial_, _נאכמ, _nóż_, _стоя
  { {0xdefa005f,0xa0670c53,0xf1a90021,0xb113005e}},	//   ный_, лаца_, خاله_, сміш
  { {0xa8570008,0xdb1a00dc,0x3e340015,0x7e7e0123}},	//   טינה_, kotá, لفتر, äppo
  { {0x69c600f2,0x291945c6,0x9757000a,0x44320003}},	//   koke, yasa_, ריצו_, luy_
  { {0x9942005c,0x010a0015,0x8e470015,0xbdf70015}},	//   _cóż_, _سترو_, اليك_, دروا_
  { {0x69c6000c,0x41270063,0xaf360087,0xbf36002b}},	//   doke, _щото_, _مرات, _مراغ
  { {0x4093003b,0x30830015,0xaf0a0015,0x25a945c7}},	//   _الكر, _الْف, _أقام_, zial_
  { {0xc3330008,0x7377000a,0x69c6007c,0xdb010077}},	//   זות_, אגיד_, foke, cilí
  { {0x29190375,0xdb01016e,0x61e243ba,0x1e57004f}},	//   uasa_, gilâ, nmol, _תשאר_
  { {0x7d1d002e,0x29190553,0xdca3198b,0x7c83006b}},	//   ðsse, rasa_, _лаци, _гуще
  { {0x2919003f,0x4c9b000a,0x6fcd151b,0x61e245c8}},	//   sasa_, _אבדו, túci, hmol
  { {0x25a90493,0x4993002b,0x69c645c9,0x291945ca}},	//   tial_, _هیدر, boke, pasa_
  { {0x555802e5,0x5694106d,0xdd1c005a,0x0000006a}},	//   лася_, щаст, tářk,
  { {0x998600dc,0xe315049d,0xdb08016e,0x394900ac}},	// [9ef0] cslő_, имањ, vidê, _ibas_
  { {0x9cd70008,0x25a945cb,0x4cbb000a,0x248945cc}},	//   רומה_, sial_, תזמו, ryam_
  { {0xd2510029,0x7ceb0a55,0x325545cd,0x32670033}},	//   تنا_, _körü, рвер, ытав
  { {0x3d0e005d,0x2127002b,0x656f45ce,0xbeff000b}},	//   सरों_, ايشی_, _unch, ॉर्न_
  { {0x653600b2,0xf3ff001c,0x351a0135,0xf48701c5}},	//   _דארף_, _irão_, _שושנ, _сунн
  { {0xdb08001c,0x8e850180,0x9fc9006b,0x3818004c}},	//   sidê, игле, ъгла_, נקום_
  { {0xed591292,0xd738000a,0xb3ba000a,0x2d951adc}},	//   вой_, אטות_, _ימשכ, ирис
  { {0x38690011,0xf532000a,0x2d8d45cf,0x0d852b2c}},	//   _orar_, ַ֥ח_, ukee_, рлин
  { {0xff250086,0x69c6026f,0x0c360015,0x31840015}},	//   _نبای, voke, لكية_, _القِ
  { {0x8b25000d,0x2d8d1024,0x4a4545d0,0x0b420033}},	//   јдне, skee_, анов, оньн
  { {0x69c60f4d,0xa2cb000b,0xeab10015,0x1a29006b}},	//   toke, _तुम्, تعة_, ъжни_
  { {0x2fc7043a,0x88e60a61,0xf8660342,0xb9b30015}},	//   long_, ижне, авмо, ْمَع
  { {0xa2a7005d,0x69c645d1,0x7d1b45d2,0x2fc702f2}},	//   _टेस्, roke, maus, oong_
  { {0x2fc700b6,0xdc9a01d8,0xdb1a00dc,0x8c1a0008}},	//   nong_, _בינל, potá, _סוצי
  { {0x69c6000c,0x66e645d3,0x9f450144,0xb7e30033}},	//   poke, рова, _milà_, іжск
  { {0x7ceb0482,0x2fc7025e,0x7d1b45d4,0x8b03002a}},	//   _görü, hong_, naus, łędz
  { {0xd6d9005c,0x2fc71636,0xdb080003,0x6b8345d5}},	// [9f00] ęła_, kong_, fidè, _kong
  { {0x44320092,0x7d1b2414,0xb4e6000b,0x6b8345d6}},	//   ruy_, haus, _पणी_, _jong
  { {0x2fc700b6,0xf3c90086,0x7d1b45d7,0x877b000a}},	//   dong_, ابقه_, kaus, _סאטי
  { {0x7d1b45d8,0x614645d9,0xf3ff016e,0x6b830aff}},	//   jaus, реда, _grão_, _long
  { {0x79b7000a,0xb033005e,0xaff70015,0x7d1b45da}},	//   סלנד_, жніш, لفنا_, daus
  { {0x2fc700b6,0x79960176,0x10150010,0x5f93023e}},	//   gong_, _llyw, сьця, жишт
  { {0x91e6000d,0x257c0089,0x6e93002b,0x8e370015}},	//   _вове, _síly_, يلها, لسير_
  { {0x30060036,0x7d1b0007,0x6b83003f,0x442045db}},	//   _взаг, gaus, _aong, osi_
  { {0x2fc700b6,0x9f4c0089,0x9b440015,0x44201450}},	//   bong_, _lidé_, منظو, nsi_
  { {0x23c6005d,0xdb6a006b,0x9b940054,0xdb010144}},	//   वविद, трил_, сиоц, gilà
  { {0xa2f7000a,0x44200061,0x8f9b000a,0x3e330015}},	//   ימיה_, hsi_, _שיבי, _وفكر
  { {0x7d1b0041,0x79960026,0xc27b0008,0x44201399}},	//   caus, _clyw, דרטי, ksi_
  { {0xd0060115,0x23c6000b,0xe0fb000a,0x9f4c0003}},	//   ثل_, ववाद, כלכל, _aidé_
  { {0x395f0cd4,0x8c1b05bd,0x7793002b,0x442045dc}},	//   žus_, _יודי, زیجا, dsi_
  { {0x614103c0,0x4420191a,0xe5730029,0x7c221f70}},	//   náló, esi_, يطر_, _hvor
  { {0x4420000c,0x79960026,0xb594004a,0x96080033}},	//   fsi_, _glyw, оисш, рэра_
  { {0x2fc7025c,0xe4e70191,0x7bc80020,0x98b90024}},	// [9f10] yong_, рівн, oodu, resē_
  { {0x0eb6000b,0xc398005e,0x47352cc9,0x61410030}},	//   _अखंड, акує_, _унос, káló
  { {0x17560008,0x59bb000b,0x442045dd,0x4422007c}},	//   _הסתר_, _उदार, asi_, _evk_
  { {0xdb080251,0x2fc700d9,0xdb1a3bfa,0x7bc80069}},	//   sidè, wong_, eltü, hodu
  { {0x7d1b00f2,0x55760053,0x2fc73df2,0xdfce002b}},	//   vaus, _הערן_, tong_, کيو_
  { {0x2fc70035,0xdb010030,0x8237002b,0x0000006a}},	//   uong_, kilá, _پرسا,
  { {0x2295003b,0xce18008f,0x1ec9005f,0xed590582}},	//   _الأس, ацыі_, ылки_, loži_
  { {0xc6b80008,0xa2a0000b,0x56b8000a,0xa3cf000b}},	//   יהוי_, _गेट्, יפון_, शतक_
  { {0x2fc745de,0x7d1b45df,0x6b8345e0,0x7bc80034}},	//   pong_, raus, _pong, fodu
  { {0x7d1b0435,0xb4f4000b,0xb35f005e,0x7c220c1a}},	//   saus, _अल्प_, змiщ, _dvor
  { {0xdb0600dc,0x7d1b45e1,0x4ea70004,0x44200030}},	//   émák, paus, _траа, zsi_
  { {0x645d3b29,0x442045e2,0x644f45e3,0x199600af}},	//   _ossi, ysi_, _opci, сјор
  { {0x8d5a0008,0x8884002b,0x3156004c,0x6b8315fc}},	//   _תכני, زیدن, זירן_, _tong
  { {0xa7da0029,0x6b83003f,0x5bc40015,0x6b9a237b}},	//   اوسط_, _uong, _وتوف, chtg
  { {0x645d0d2d,0xb7b90033,0x644f003d,0xdb1a0125}},	//   _assi, рыях_, _apci, altó
  { {0x44200044,0xe5a30684,0xf6e50033,0xdb0845e4}},	//   tsi_, писи, іцён, vidé
  { {0x7b060014,0x614100dc,0x03261070,0x8c190643}},	// [9f20] _érté, záló, йдан, טוּי
  { {0x442045e5,0x74130015,0x04b5005e,0x8726002b}},	//   rsi_, سوما, істя, _اعظم
  { {0x442045e6,0xcb12000a,0x8bd6000a,0x216a012b}},	//   ssi_, פלא_, צועו_, лижи_
  { {0xf1a50191,0x614100dc,0x44220020,0x7d1917cb}},	//   орін, váló, _tvk_, _news
  { {0x629e06e7,0x493b000a,0xe1650015,0xdb010030}},	//   szpo, רגנו, تدلي, zilá
  { {0xd8d70053,0x90530010,0x6d4b00b8,0xc8db004c}},	//   זונט_, явіц, _abga, נקסט
  { {0x3f8545e7,0x644400f2,0x031d000b,0xbe4a002b}},	//   _dolu_, ltii, _फ़तह_, اشتم_
  { {0x7bc8005c,0xdd970010,0x5bd0000b,0x656445e8}},	//   wodu, йшы_, हत्व, ndih
  { {0x64440044,0x7c960015,0x5577004c,0x7afd0046}},	//   ntii, إشعا, מעקן_, ěstn
  { {0xa3d8000b,0x6444008c,0x29d90125,0x5fdf000b}},	//   ाति_, itii, géan_, _पीपल
  { {0x64d5014e,0x644400f2,0xd37b0053,0x2bc7000b}},	//   _दर्श, htii, אריט, रक़ा
  { {0x6444041c,0x7c221744,0xb2bb000a,0xad650021}},	//   ktii, _tvor, רמטר, _وانه
  { {0xa3d8014e,0x3f850064,0x65640026,0x6f1a0326}},	//   ाता_, _yolu_, ddih, _ketc
  { {0x0a94022a,0x07090015,0xaa940190,0x7d19002a}},	//   _малю, شيري_, _милч, _zews
  { {0xa1430048,0xd6d9005c,0x569445e9,0x8b03002a}},	//   šķir, ęło_, парт, łęcz
  { {0x7df1003d,0x6f1a45ea,0x0000006a,0x0000006a}},	//   _jāsp, _letc,   ,
  { {0x49b80115,0x5fba000b,0x644402f2,0xf3ff00a1}},	// [9f30] _داود_, ेवाल, gtii, _trãm_
  { {0xdb1a0123,0x6d9c0125,0xed5900bc,0x6f1a2ba7}},	//   botå, _héad, roži_, _netc
  { {0xd6d90086,0xa5f90001,0x92590080,0x72b90029}},	//   _خودش_, _њему_, рает_, جهاز_
  { {0x40950015,0x6444007c,0x212a002b,0x3f8545eb}},	//   يلار, btii, ليمی_, _solu_
  { {0x4acf005d,0x6d9c002d,0x3f8512e1,0xaacf000b}},	//   _सुनव, _méad, _polu_, _सुनक
  { {0x6d9c0125,0x3f6915df,0x8e750058,0x28de0065}},	//   _léad, рико_, قابض, नेटि
  { {0xfebb0086,0xfd110029,0x6234017f,0x290245ec}},	//   داشت_, وجة_, _неру, ycka_
  { {0x7dc500dc,0x236345ed,0x7ed40058,0x0000006a}},	//   lósz, _hajj_, أزها,
  { {0xa2b9005d,0x6d95002e,0x29d9002d,0xf1b2000a}},	//   ्थव्, _fáan, téan_, _חסן_
  { {0x0a49004a,0xba251977,0xe4a8000a,0x3a2519db}},	//   азой_, одок, מֹתָ, омог
  { {0xdcfb065d,0xf98a0029,0xc33200a3,0x9f04002b}},	//   ljuč, لندي_, ווי_, _رونو
  { {0x6d9c0c1b,0x41c9005d,0x6444008c,0x5c750054}},	//   _céad, िकिस, ytii, _млет
  { {0xe45f022d,0x29020535,0x6564013b,0x0000006a}},	//   _myös_, rcka_, vdih,
  { {0xe73a07c1,0x6d9c0003,0x6d4901f1,0xdc88004f}},	//   јев_, _péag, lfea, _לְצָ
  { {0xba770074,0x6d9c002d,0xceb2000a,0x41c9000b}},	//   _داشت, _féad, ֥ין_, िकास
  { {0x6444022d,0x799d26af,0x29d90125,0x6d4901b3}},	//   ttii, chsw, néal_, nfea
  { {0x6d49002d,0xd467066c,0x47d60015,0x97c60015}},	// [9f40] ifea, оите_, _ويعر, _وقبو
  { {0x03260036,0x64440e95,0x6d49002d,0x29d90125}},	//   іден, rtii, hfea, héal_
  { {0xc3050029,0x644445ee,0x27ed00aa,0xd10a0015}},	//   سبلو, stii, ïene_, لقاه_
  { {0x94060015,0xb2d30015,0x11e90015,0x7aba000a}},	//   _ووجه, ذينغ, معني_, בצעו
  { {0xe05604c9,0x6d49002d,0x11d70015,0x29d90125}},	//   تخاب, dfea, آونة_, déal_
  { {0x443245ef,0x6029005e,0x9e0601eb,0x96fa004f}},	//   mry_, сіїв_, очил, ׁלְת
  { {0x4432003e,0x9e66002b,0xdd9a00d8,0x6d49040a}},	//   lry_, تاشن, иши_, ffea
  { {0x44320dde,0x127b004c,0xe45f008c,0xdb01008c}},	//   ory_, _דאלע, _työt_, hilä
  { {0xdb0100f2,0x6d9c002d,0x443225c3,0x61fc351a}},	//   kilä, _réad, nry_, _hurl
  { {0x443200d9,0x0b8a05c4,0x6fb60015,0x1be70054}},	//   iry_, рсии_, _بمطا, одњи_
  { {0x9d460404,0x8aa30142,0xaa580248,0xbec7003d}},	//   _межд, дряд, щину_, tzīš
  { {0x6d49002d,0x44320b6b,0x61fc00e7,0x29d90125}},	//   cfea, kry_, _murl, céal_
  { {0x9f4c0089,0xbec7003d,0x58870033,0xdce90085}},	//   _lidí_, rzīš, цына, bjeđ
  { {0xdceb003d,0x44320188,0xdb01007c,0x7c3001ec}},	//   _ungā, dry_, gilä, īdrā
  { {0x99d7003b,0x44320dde,0x9577002b,0x8aa3006b}},	//   _وتعا, ery_, يدرض, _оръд
  { {0x628300b8,0x1a9b000a,0x3915004a,0x44320bba}},	//   änom, _כיוע, _эмир, fry_
  { {0xb9c40029,0x6fca000b,0x8d5b000a,0x443245f0}},	// [9f50] _تقيي, ाकां, סכמי, gry_
  { {0x67e000f2,0xef1f005c,0x39590705,0x9378005e}},	//   töje, ążka_, less_, обут_
  { {0x443245f1,0x61fc45f2,0xd1310015,0x47340033}},	//   ary_, _curl, فما_, _юнэс
  { {0x7dc50014,0x39592ce3,0xe1f80010,0x443245f3}},	//   sósz, ness_, ігі_, bry_
  { {0xa2cb005d,0xf9940008,0xd4790053,0xd0ab000d}},	//   _तुर्, ורף_, _האָל, јтед_
  { {0x23fa0008,0xf8380008,0x80640033,0x3864001a}},	//   _להשא, קנות_, ьвіж, æmri_
  { {0xa3d8005d,0xc7b4000a,0x8db500ce,0x522404b5}},	//   ातर_, ובס_, зспі, _офта
  { {0xb6bc000a,0x6de40015,0x2024001a,0x2d990077}},	//   יצוי, وثيق, örið_, óse_
  { {0x6d49002d,0xfc310015,0x29d945f4,0x11440015}},	//   rfea, رحة_, réal_, _تَقُ
  { {0xeb9945f5,0x94b6004f,0x0b4500af,0x0000006a}},	//   сио_, לִיד_, чнон,
  { {0x8a0504ab,0xc332000a,0x395900c7,0xa96a18fc}},	//   язне, עוט_, fess_, бина_
  { {0xc7a9000a,0x499a024f,0xed59003d,0x598304e5}},	//   _גב_, стоя_, tožu_, елюб
  { {0x515a000a,0x1a65002b,0xdb01008c,0xef18003d}},	//   זכרו, زیکی_, tilä, _soļi_
  { {0xfaa52077,0xcb680015,0x6bd70015,0x96f90033}},	//   _нало, _ومنه_, _بتصر, жэту_
  { {0xa5960063,0x4b7a000a,0x70b8000b,0x6d950125}},	//   пращ, _לאסו, _अश्ल, _láam
  { {0x395945f6,0x39400045,0xf99f02b9,0x443205a1}},	//   cess_, _ucis_, chè_, try_
  { {0xed59002c,0xa98b000a,0xa99b000a,0x442645f7}},	// [9f60] iež_, _הָיִ, _לבקר, éo_
  { {0x443245f8,0x3363005e,0x0000006a,0x0000006a}},	//   rry_, нвуг,   ,
  { {0xe7170008,0xd6fb0008,0x02d70015,0xf8a9002b}},	//   _מחיר_, _לפיכ, كوكب_, _هدیه_
  { {0xc69300b2,0x9f4c01b2,0xc1ba0015,0x0f14000b}},	//   _נאר_, _vidí_, حائط_, डर्स_
  { {0x44240092,0xed590844,0x31660030,0x3fc8002b}},	//   _ìm_, dež_, rdoz_, يدتی_
  { {0xae00005d,0xa2a7005d,0x395900b8,0xdfcf00e5}},	//   _लंदन_, _टेक्, zess_, هين_
  { {0x539b0008,0x6d9c002d,0xf773000a,0xe3b3004c}},	//   _פילו, _réab, תקו_, _טױש_
  { {0x5c98006b,0x7a01003d,0x66e70030,0x5c74013e}},	//   жкия_, _pētn, léké, длит
  { {0x6c470015,0x8c430004,0xdb080077,0x656645f9}},	//   كليف_, еење, sidí, _makh
  { {0x395900da,0xddd80091,0x7ac60c31,0xbf650015}},	//   wess_, tyvų, зсме, _يدلو
  { {0x3959307c,0xa93500e2,0x0000006a,0x0000006a}},	//   tess_, менш,   ,
  { {0x02b70008,0xd2b70008,0x5eeb000a,0x5dfb000a}},	//   להים_, ללית_, _הַדְ, _הפאנ
  { {0x395945fa,0x5d83002b,0x6d420045,0xf3ff0016}},	//   ress_, _سلول, _icoa, _trãi_
  { {0x6d9c002f,0xdb1a00dc,0xcb67005e,0x7fc7000a}},	//   _féac, eltö, _наче_, ּ֔ךְ_
  { {0xf6740010,0x86c5002b,0x66e70030,0x45d545fb}},	//   нгрэ, ذيرن, déké, довс
  { {0x98b90024,0xcad70008,0x25a0002d,0x7abb000a}},	//   nesī_, _מוות_, ghil_, _לצוו
  { {0x7a080046,0x58040015,0x69cf0247,0x5fdc0065}},	// [9f70] _děte, _كويك, moce, यताल
  { {0x889c0008,0xb89c0008,0x25a01d6c,0x64a40054}},	//   _לבחי, _לשחז, ahil_, хађа
  { {0x8e2001f3,0x24800045,0x62750015,0x4224005e}},	//   сiм_, axim_, بهائ, едєв
  { {0x25a00111,0x69cf0c5c,0xc2c400c3,0x29d2001a}},	//   chil_, noce, ريني, láar_
  { {0xf211000b,0xe0ce01b0,0x0000006a,0x0000006a}},	//   डीज़_, тв_,   ,
  { {0xc3480033,0xd00e00c3,0xd47a004f,0xa3d80065}},	//   _нясе_, جلو_, _ואשל, ातः_
  { {0x9e640015,0x656600aa,0x1287002b,0xed5900b3}},	//   فاين, _yakh, _عمری_, tež_
  { {0x96270048,0x6d9c0152,0xb147002b,0x7c9503ea}},	//   _ieņē, _réac, _ریتم_, дроц
  { {0xcc890086,0x1c420080,0x0b5901b0,0x40340aed}},	//   زنده_, вным, орны_, _петс
  { {0xcb690086,0x7d030030,0xdb08016e,0xdfb40054}},	//   آمده_, _bíró, vidã, _збуњ
  { {0x52db005d,0x9f34005e,0x7e7e0123,0x5e95002b}},	//   _भरोस, _чехі, äppt, _تلاط
  { {0x2d820db2,0xdb08016e,0x3eba006f,0x7ed40015}},	//   öket_, tidã, úpte_, _أزكا
  { {0xa3bf000b,0x656645fc,0xbb45011e,0x29d20052}},	//   ुका_, _rakh, _желк, fáar_
  { {0x6d9c002f,0xe8f70010,0x7c3b07b9,0xabfa000a}},	//   _téac, ьля_, muur, _והסר
  { {0xd5b20029,0x7c3b007c,0xba190015,0x0000006a}},	//   نفس_, luur, _بيعا_,
  { {0xdb1a0152,0xaa560015,0x69cf2ec8,0x6d5b01e0}},	//   entè, _آليا_, coce, neua
  { {0xb9b30029,0x66e700dc,0xa494002b,0x98a60054}},	// [9f80] _جميع, téké, ریست, _ципе
  { {0x61b8005d,0x6d5b0026,0x39b60024,0x42da006b}},	//   ेक्ष, heua, rāsu_, офея_
  { {0x1a9a0053,0xb77b000a,0x656645fd,0x23090015}},	//   ֿינע, _ואיש, _takh, ستلي_
  { {0xe0da45fe,0x6463008c,0x7c3b0bb5,0xc8b5009a}},	//   ове_, äviä, kuur, _آلیک
  { {0x9fca0080,0x7c3b0e95,0x03330046,0x9fe6002b}},	//   огда_, juur, _říši_, وسته
  { {0x09bb005d,0x6d420011,0x7c3b0171,0x2bdd000b}},	//   _उद्य, _scoa, duur, _नीला
  { {0x7e2a0010,0x1eaa002b,0xa11600c3,0xdb20005a}},	//   ціла_, غاتي_, _يوست, átím
  { {0x71760074,0x661a006f,0xdb08013f,0x0000006a}},	//   _تهرا, átky, didá,
  { {0x8e20005e,0xdb1a0030,0xef18003d,0x9bf40b1e}},	//   сiв_, lnté, _soļu_, нзич
  { {0x547b01ac,0xef18003d,0x395208d0,0xdb1a134b}},	//   קטיו, _poļu_, _abys_, onté
  { {0xd337013a,0x3f9b0152,0x5337000a,0xa3e6000b}},	//   וריה_, êque_, ונין_, _पठन_
  { {0x49740248,0x38720804,0x7c3b0547,0xd7fb011e}},	//   влюс, _bryr_, buur, жув_
  { {0xad250086,0xd7770029,0xbd43002b,0x3f8c45ff}},	//   _سرنو, واسع, _شنوي, _kodu_
  { {0xac970074,0xeaaf0074,0xd90f0086,0x9b440015}},	//   _تنها_, اعی_, دیک_, _أنغو
  { {0x5b57011f,0x8b3b000a,0xeb3b000a,0x6d400079}},	//   _חיוב_, _ותוצ, _ועוש, ogma
  { {0x69360089,0x7bda0b10,0x3f8c002a,0x67e00123}},	//   _přež, lltu, _lodu_, röja
  { {0xdb1a01c4,0x3f9e1af8,0x33752c2a,0x8c49000a}},	// [9f90] enté, _oltu_, нгар, ּׂעִ
  { {0xc7c70036,0x68e00061,0x8bd8000a,0xdce200b3}},	//   _іспи, ümde, פַּח, _naoč
  { {0x27f8006f,0x51553f64,0x65952fa0,0x76d50058}},	//   ženú_, етлу, _зану, _سيحض
  { {0x59f900b4,0x2519000a,0xc1050015,0x3f9e02d8}},	//   פּעד, _מוֹא, روتي, _altu_
  { {0xf536000a,0xdb010123,0x7fd5005e,0x3f8c013f}},	//   _אנרי_, mnlö, нікі, _bodu_
  { {0x141a0008,0x63b10089,0x6f64008b,0x6d404600}},	//   _מושב, édně, квіз, egma
  { {0x53340001,0xbdf50054,0x44294601,0xe732004f}},	//   _јест, нчић, lsa_, רֵד_
  { {0x217b003b,0xbc650a61,0xbbc7000b,0x1d090004}},	//   _بحسب_, евик, रक्क, џепи_
  { {0x44294602,0x7de30030,0x50190015,0x4bd90033}},	//   nsa_, _kősz, _رياح_, зьня_
  { {0x2d8200c0,0x44294603,0x6d400035,0x2bb90015}},	//   öker_, isa_, agma, ثابة_
  { {0x752f005c,0xd94605ae,0x7c3b1928,0x0b420033}},	//   _odcz, нени, suur, ынэн
  { {0xa96a0001,0x3f870085,0x7bda1f26,0x98a6011a}},	//   чима_, ljnu_, altu, еиме
  { {0xaacf014e,0x752400df,0xb908005d,0x9d1a0053}},	//   _सुरक, vaiz, _भर_, _זונט
  { {0xbb850029,0x44294604,0x7c294605,0xec36000a}},	//   _سلبي, dsa_, mser, _נאצר_
  { {0xdce20024,0x7c260227,0x44294606,0x70dc000b}},	//   _bloķ, škrt, esa_, _बर्ल
  { {0x6d9c0c1b,0xceb2000a,0x7d09050d,0x44294607}},	//   _léan, איל_, nces, fsa_
  { {0x2806005c,0x7c294608,0x64a322d7,0x75d30015}},	// [9fa0] ówną_, nser, гата, ايقا
  { {0x6d9c0152,0x7d09005c,0x37c60015,0xb4630033}},	//   _néan, hces, _سيجف, ыкул
  { {0x7d09005c,0x44294609,0xeb96004c,0xa2e60195}},	//   kces, asa_, עדער_, хожд
  { {0xc3290008,0xd1320087,0xf1a90002,0x7c29460a}},	//   מו_, امش_, وانه_, kser
  { {0xfaf80024,0x442900dc,0x50650015,0xc448002b}},	//   ldīt_, csa_, َاهِ, _زیان_
  { {0x6d9c002d,0x7c29460b,0x7d09460c,0xa2cb0065}},	//   _céan, dser, eces, _तुक्
  { {0x6d9c002f,0xa3b5005d,0x7c2b146d,0xa2e30763}},	//   _déan, _जगत_, _avgr, _борд
  { {0xcfaa002b,0xfaf8003d,0x65bb008c,0x6d400085}},	//   _کارم_, idīt_, mähä, ugma
  { {0xdb030123,0xa4ba000a,0x6fb60015,0x2fda012c}},	//   _omnä, לֶ֙י, _كمرا, _فورد_
  { {0x8c530115,0x6d9c0003,0xdd000061,0x9b940054}},	//   ائيا, _géan, ıtıl, тиоц
  { {0x533700b2,0x44290399,0xed5a1d8a,0x7c290d3d}},	//   ענטן_, zsa_, _нож_, aser
  { {0xbae30010,0x23a400c0,0x7d091350,0x4429460d}},	//   ыцый, _höjd_, cces, ysa_
  { {0xc173013a,0x67e000c0,0x7c290694,0x7c930015}},	//   אחר_, röjn, cser, _مشوا
  { {0x5c97008f,0x69c4003d,0xbc670015,0xcb34006b}},	//   _якія_, _ejie, _أمون_, _рекъ
  { {0x6be3003b,0x68e400dc,0x36d5049d,0xa31d000b}},	//   _حكوم, _ezid, товр, _फ़ौज_
  { {0x4429460e,0xfa770c44,0xaadb004f,0xe945009a}},	//   tsa_, _טעות_, _מחור, _شربی
  { {0x24580080,0xf3f9000d,0x98b90007,0xf4340010}},	// [9fb0] нать_, днаш_, mesį_, летэ
  { {0x61c9005d,0x23a400c0,0x73d80342,0xb7d90015}},	//   िक्ष, _nöjd_, едур_, _زوجا_
  { {0xa2d4005d,0x98be005c,0x4429460f,0xdb1a4610}},	//   _बुद्, ętą_, ssa_, lotó
  { {0x6d9c4611,0x98b90007,0xc1980036,0x7f940144}},	//   _séan, nesį_, нтії_, _màqu
  { {0xa134002b,0x34940033,0x3f69405a,0x4104005e}},	//   طرنش, _баяр, дило_, узів
  { {0x5f770015,0x2607007c,0x1014002b,0x69dd0012}},	//   عاشر, _kõo_, ابند, hlse
  { {0x8fa20080,0x69c70089,0x644d4612,0xee39005e}},	//   раще, čkej, ltai, єни_
  { {0xf67c0008,0xdd8e0029,0xdb01002d,0x644d4613}},	//   לאומ, قوى_, mhlé, otai
  { {0xdd8e003b,0x6d9c002d,0x644d4614,0xdca50004}},	//   توي_, _téan, ntai, тапи
  { {0x7d094615,0x69dd4616,0x7ff70015,0x09ca000b}},	//   sces, else, _أسرا, रव्य
  { {0x644d4617,0x7a080046,0x7c294618,0x61fb0573}},	//   htai, _pěta, sser, _kiul
  { {0x6996008f,0xdb0800f2,0x644d2233,0x8ed80015}},	//   трох, eidä, ktai, _أذكر_
  { {0x0db800e6,0x5dc8000a,0x8c45159d,0x61e90034}},	//   _ثالث_, _אֶסְ, _реле, _mhel
  { {0x69dd0005,0x2d8f0111,0x8c1a000a,0x9bc80015}},	//   alse, _hoge_, _חוסי, _كونك_
  { {0xfaf80024,0xecc30024,0x9f45002d,0xfe670015}},	//   udīt_, šķās_, _chlé_, جد_
  { {0xdb1a005c,0x61fb003f,0x644d4619,0xfaf801ec}},	//   botó, _niul, ftai, adīs_
  { {0x60db000c,0x23bf000b,0xc5e9000a,0x644d461a}},	// [9fc0] _nyum, ्वंद, ַד_, gtai
  { {0x61e90020,0x656d01d7,0x22ba0015,0x657d00da}},	//   _ahel, adah, وداع_, _ensh
  { {0x179b0008,0xe2860063,0x65c60010,0xb7370053}},	//   _חייב, ължи, _абна, _בריװ_
  { {0x61e9461b,0x644d0a5d,0x2d8f0b28,0xc0a9009a}},	//   _chel, btai, _noge_, کامل_
  { {0xd007010f,0x70540031,0x644d461c,0x2126461d}},	//   вече_, انتا, ctai, raoh_
  { {0x8cc5005d,0xdefa0080,0x4fd30036,0x61e90012}},	//   ापनो, мый_, ажіт, _ehel
  { {0xdeef0010,0xdb010046,0xbe630015,0x61fb0045}},	//   ры_, chlé, لهوي, _fiul
  { {0xc6930008,0x61fb4286,0xf1bf006f,0x91e6257f}},	//   שאה_, _giul, úšta_, _робе
  { {0x9f4c00f2,0x98b90091,0xe0d70a1f,0x2d8f2908}},	//   _pidä_, vesį_, _авт_, _doge_
  { {0xdc55002b,0x5b140138,0x0000006a,0x0000006a}},	//   اريک, ымот,   ,
  { {0xdd92002b,0x8f1b000a,0xac73002b,0x2d8f016e}},	//   _پوش_, _חובת, هایش, _foge_
  { {0x2004003f,0xf2d301d8,0x4ea50054,0x9f45013f}},	//   _kumi_, יעת_, _срђа, _milý_
  { {0x1d070124,0x8c4338a1,0xe8240974,0x7e6817cd}},	//   _речи_, _вече, ифро, _hsdp
  { {0xc7c40080,0x9f45002d,0xfbcf002b,0xfce3005e}},	//   асси, _phlé_, _وتو_, _точо
  { {0x6d9c002f,0xdb1a0125,0x66b4045c,0x2004461e}},	//   _léam, nntí, абру, _lumi_
  { {0xa3b5005d,0xa2b8005d,0x644d39d2,0x1af7000a}},	//   _जगह_, ्पन्, ttai, _במול_
  { {0x6d9c3ed1,0x656d163a,0xe4150033,0x3949016e}},	// [9fd0] _réal, rdah, удзь, _icas_
  { {0xe8d80008,0x386900c0,0x61e921e0,0x644d0c16}},	//   _בוחר_, _isar_, _shel, rtai
  { {0x644d3d8d,0x60db01c2,0x61e922eb,0x569501e1}},	//   stai, _syum, _phel, _сант
  { {0x81d40010,0xc1750086,0x644d461f,0x20040049}},	//   аціц, دگست, ptai, _bumi_
  { {0x7fb50033,0x443f0016,0x29d9176a,0x61fb008c}},	//   лёкі, _êu_, léas_, _viul
  { {0x289c0008,0x889c0008,0x53a7000b,0x720500c3}},	//   וידא, ובדי, _गतिश, _موسم
  { {0x6d9c002d,0xc695004c,0x28da000b,0x61e94620}},	//   _téal, טאַ_, _युनि, _thel
  { {0x96fc000a,0x5e560015,0x799d0079,0xdcfb0085}},	//   ולות, اليس_, jksw, njuć
  { {0x60db0064,0xb0b7000b,0x2bb90015,0x0000006a}},	//   _uyum, _अधिग, فادة_,
  { {0x3b85005e,0xe9df006f,0xdd1c0046,0xceeb0067}},	//   улог, elú_, háňk, _قران_
  { {0x386900d9,0x6605007c,0xd356000a,0x2004002a}},	//   _asar_, _nuhk, איתי_, _zumi_
  { {0x98b20064,0xcd2b0086,0xf769000a,0xa3b30065}},	//   _sayı_, _آسان_, _מק_, जोत_
  { {0x98b20061,0xe8f7008b,0xc8b6056d,0x7d1b3b33}},	//   _payı_, ллю_, усны, mbus
  { {0x366a008f,0xe9df002d,0xdc3a000a,0x7afd0046}},	//   наго_, alú_, _נעצר, ěsts
  { {0x46a300fd,0xfb160058,0x0000006a,0x0000006a}},	//   барв, _صقيع_,   ,
  { {0xceb200a3,0x09e6005e,0xd5b20015,0xca36004f}},	//   צין_, _щойн, حفر_, _ענפה_
  { {0x5fc3005d,0x69db0053,0xb4250015,0x29d90003}},	// [9fe0] वचाल, _אַזו, لعلو, réat_
  { {0x6d9c002f,0x1c1b000b,0x2004050b,0xf8b20065}},	//   _réam, पीएल_, _rumi_, ीपीप
  { {0xdb9a00b2,0x95c60086,0x77f7000f,0x06760010}},	//   עסער, _ميده, _תמיד_, _супя
  { {0x32170086,0x10a60457,0xe1da0015,0x7d1b0d64}},	//   ايند_, лиен, رباص_, jbus
  { {0x25d7013a,0xdfda0063,0xa2d4000b,0x6283008c}},	//   _תוכן_, нък_, _बुर्, änor
  { {0x7d1b0020,0xa857000a,0x9e14008b,0xce94009b}},	//   ebus, ריסה_, адкі, иалъ
  { {0xb7db0053,0x7c3b3bbc,0x7dde0073,0x0000006a}},	//   עקצי, erur, lësi,
  { {0xc0460015,0xdc8a0004,0x6d9c0125,0xc27b000a}},	//   _مخطو, есол_, _téam, _ארלי
  { {0x5b26044e,0x51930029,0x0000006a,0x0000006a}},	//   льна, _القذ,   ,
  { {0x7fd60033,0x7d1b02f2,0x1bb40033,0x7e6d002a}},	//   _сібі, abus, рбоў, łapa
  { {0xfc2f0086,0xd35701ac,0xe919005e,0xb3bb000a}},	//   يحی_, ניטי_, коні_, תמיכ
  { {0x7d1d002e,0x3ec20091,0xd12600c3,0xe9810033}},	//   ðsst, įstą_, غم_, цамi_
  { {0x7c3b0011,0xe9df002d,0xd0060002,0xe7b50015}},	//   crur, rlú_, تل_, لمحد
  { {0x66050005,0x2fc0002d,0xa49b0016,0xe9df006f}},	//   _puhk, éigh_, _ngòa, slú_
  { {0xa2d4000b,0x6757002b,0x7bdb004f,0x2b92009a}},	//   _बुल्, نیکس_, _רקוו, _نیکس
  { {0x39490034,0x386939f0,0x9aeb004f,0x96f8009b}},	//   _ucas_, _tsar_, _אַחִ, уест_
  { {0x442f00dc,0x29d9002d,0x38692cb1,0x73d9006b}},	// [9ff0] ég_, séas_, _usar_, вдар_
  { {0xe3b30015,0x1755006b,0x3717000a,0x66050bb5}},	//   حرر_, _твоя, _עַ֖ל_, _tuhk
  { {0x7d0200bd,0xd3d80015,0x76b8004a,0xc2c40015}},	//   _ogos, ابقا_, _блэр_, ميكي
  { {0xd5670317,0x7127012c,0x7d021349,0xa69a004f}},	//   _стоп, ارال, _ngos, _ישתפ
  { {0x656f1f22,0x5ff50054,0x998d0046,0xa069100f}},	//   _iach, азду, kudž_, тала_
  { {0xdfd40010,0xad9c002c,0x244f0061,0x9f040015}},	//   бочы, _stĺp, müm_, موهو
  { {0x244f0064,0x7c220092,0x9f9600d0,0xa77c000a}},	//   lüm_, _awor, рвју_, תרופ
  { {0x3015005e,0xdb01007c,0x71f80021,0x317f0061}},	//   _вдар, silü, _مرقس_, _unuz_
  { {0x244f0064,0x23a40123,0x7a080046,0x656f2bb8}},	//   nüm_, _höja_, _dětm, _mach
  { {0xeb990001,0x543c0053,0xdb1a00dd,0x0ffb0015}},	//   тио_, געזא, litê, _أعرب_
  { {0xdd8e0086,0x93b6000a,0x99b60015,0x6fdf0003}},	//   سوی_, שלתו_, لإحص, vêch
  { {0xa2b8005d,0xdb01002d,0x656f4621,0x645d4622}},	//   ्पत्, mhlí, _nach, _opsi
  { {0xc7960010,0x25a901d7,0x29d90125,0x0000006a}},	//   арвы, dhal_, téar_,
  { {0xf7460054,0x9c820046,0xcc56000a,0x656f4623}},	//   јево, účel, _כבני_, _aach
  { {0x645d00df,0xb8fd000b,0xa9a6005e,0x75d60015}},	//   _apsi, _तु_, _вийд, ليسا
  { {0x3eaa0012,0x0566012e,0x656f4624,0x25a94625}},	//   _übte_, јван, _cach, ghal_

  { {0x04464626,0x6fdf0152,0x29d9002d,0x03260e77}},	// [a000] резн, pêch, péar_, идан
  { {0x656f002d,0xdb1a002d,0xd7640086,0x389b000a}},	//   _each, ontá, _اندی, _סיינ
  { {0xadf7000b,0x55e60004,0x2d9f008c,0xc16f005e}},	//   ुदान_, _вонб, kkue_, ої_
  { {0xd2e6005d,0x244f0064,0x9f45002d,0x2a560053}},	//   _करीब_, büm_, _dhlí_, יבען_
  { {0x69c61f09,0x6564008c,0x351b000a,0xd0100015}},	//   inke, meih, _בוכנ, ألت_
  { {0x08770053,0x656f1f58,0x3e340015,0x6d590012}},	//   יענט_, _zach, مفتر, _abwa
  { {0x7c22003e,0xcfa9002b,0x656f26d0,0xfda60054}},	//   _swor, دانم_, _yach, ијим
  { {0xac540029,0xb0160029,0xdceb0064,0x65a3007c}},	//   منبث, _نورث, _algı, _lõhn
  { {0x9da70063,0x644402f2,0x7f86002b,0x7db3002b}},	//   ръща_, nuii, _پلان, تصوا
  { {0x2912003f,0x5457000a,0xe457015b,0x6d9c0125}},	//   _afya_, סביב_, סייט_, _méai
  { {0x237900b2,0xc333011f,0xa4e3005d,0x3377000a}},	//   אָרמ, חות_, _खर्च_, בעים_
  { {0x7c220050,0xbd490015,0x7d020085,0xfe9b000a}},	//   _twor, _مؤهل_, _ugos, _שיאמ
  { {0x99990030,0x7db30015,0x97c70015,0xdd8f006e}},	//   érő_, _بمنص, لتآم, _تون_
  { {0xfc5b000a,0xaab7002b,0xc7bb004a,0x656f4627}},	//   _סכומ, ادیر_, тём_, _sach
  { {0x8b650087,0xc7c80033,0xee31000a,0x656f4628}},	//   _دانم, рыяе_, ּֽל_, _pach
  { {0xf9900015,0xf53f0123,0x99b40058,0x6564005b}},	//   _يبي_, _blåa_, _وإيص, geih
  { {0x19b80029,0x25a930e9,0x656f4629,0xd7e702a3}},	// [a010] _خطوة_, rhal_, _vach, _віно
  { {0x244f0064,0x656f462a,0x82370015,0xddda0046}},	//   rüm_, _wach, لرصا, _vstř
  { {0xed5902d5,0x656f462b,0x8bd7000a,0xa2d50015}},	//   liže_, _tach, סובו_, حيات
  { {0x656f002d,0x998d005c,0xcfe9002b,0x6564008c}},	//   _uach, erdź_, گفته_, ceih
  { {0x85fa0053,0x20670001,0x321a00da,0x645d039d}},	//   _תּיק, рђев, appy_, _upsi
  { {0x94f6000a,0x0217002b,0x28c80065,0xf0a800ce}},	//   _לצרף_, _نظرد, रपति, шкіл_
  { {0x61e20064,0xed590256,0x9f450046,0x316b0054}},	//   blol, гой_, _uhlí_, _ишао_
  { {0xf1a7000d,0x8d750015,0xa3b3000b,0x0d851e91}},	//   _тргн, صابا, जोर_, слин
  { {0xdf58002b,0xa3db0065,0x3b09009b,0x2d8d462c}},	//   _چشمش_, डकप_, лепо_, rjee_
  { {0x2cad005c,0xb47a0053,0x4a45009f,0xed590085}},	//   rzed_, אָטי, бнов, diže_
  { {0x733a0053,0xc869000a,0x5f74006e,0x2cad0030}},	//   װערס, _רן_, _باقر, szed_
  { {0xfe70002b,0x1e56000a,0x7d740015,0x8d74006e}},	//   _زدم_, _לשער_, _وانط, _وانا
  { {0xdb08007c,0xb886006f,0xfc3f0125,0xf1b20643}},	//   endõ, _opíš, áíd_, לסט_
  { {0x656400b8,0xfb35004c,0x999f0046,0x0000006a}},	//   weih, _האַש_, butů_,
  { {0x644b0251,0xeb900029,0x6b833d8f,0x656401a0}},	//   àgin, _تظن_, _inng, teih
  { {0xa2b8005d,0x6d49462d,0x0000006a,0x0000006a}},	//   ्पस्, ngea,   ,
  { {0x6d49002d,0x79840035,0xf74607c1,0x1604000b}},	// [a020] igea, _iniw, _лепо, _शंकर_
  { {0x25b9007c,0x1877004c,0x25a0462e,0x656406d2}},	//   _emsl_, _פעיר_, skil_, seih
  { {0x86750010,0xa564002b,0x9bba004c,0x6564008c}},	//   _дыяц, _وگرن, נצעפ, peih
  { {0xd7640086,0x614637c7,0xe875002b,0xe2970054}},	//   _انگی, седа, _انیگ, љац_
  { {0xb0330036,0xdb0300dc,0x55f7000a,0x89db000a}},	//   зніш, _elné, _למטב_, נחני
  { {0xa8570008,0x33d50036,0xccf9005c,0xe0850015}},	//   מינה_, _діст, reśl_, تجمي
  { {0x62650029,0x91e6016a,0x4432462f,0xedd40058}},	//   _وافق, _гове, lsy_, ييتد
  { {0xddea0015,0x6c144630,0xdb1a0936,0x929b000a}},	//   درته_, одиф, mité, _גילת
  { {0xdb1a038d,0x6ab2005d,0x02b8005d,0x44323905}},	//   lité, ुप्र, _आधुन, nsy_
  { {0xdb0a0123,0x443201f6,0x5a340b45,0x320a4631}},	//   _omfå, isy_, онот, _kuby_
  { {0xa3d9000b,0x5f17000a,0xdb1a1112,0x15f8000b}},	//   ावत_, _החבא_, nité, ंगार_
  { {0x394d08e0,0xc27b0053,0x527b01ac,0x44324632}},	//   ües_, ארטי, אנטא, ksy_
  { {0xac940063,0xcb34006b,0x4432002a,0x984b0138}},	//   _фалш, _делъ, jsy_, ыяна_
  { {0x44320f75,0x7a130045,0xdca30054,0xbce50015}},	//   dsy_, _săte, _хаљи, _بأمو
  { {0x9f5e0152,0xfa330115,0xb9b50015,0x7a02003d}},	//   _cité_, _فريد, _ومتع, _vētr
  { {0xb8860089,0xe654005e,0xdb1a0003,0x96080033}},	//   _spíš, явсь, dité, сэра_
  { {0xe4500029,0xe4e7005e,0xc307002b,0x7bc84633}},	// [a030] فضل_, сівн, مباو, ondu
  { {0xa3b3005d,0x7bc84634,0xdb03013f,0x68ed035e}},	//   जों_, nndu, _plné, _izad
  { {0xb886032c,0xdb08002d,0xa2b8000b,0x9756000a}},	//   _vpíš, ghdé, ्पष्, _ושתף_
  { {0x7bda00f2,0xda7b000a,0x85080033,0xf1ab0015}},	//   hotu, טנבר, _гэрб_, دائه_
  { {0x7bda022d,0x1958004c,0x0576000a,0xdb0104b2}},	//   kotu, מבאל_, _וגרם_, ihlá
  { {0x8cdc014e,0xa2d4000b,0xdb1a4635,0xe0d0006e}},	//   _पड़ो, _बुक्, bité, رزن_
  { {0x7bda26f9,0x35f80086,0xdb1a4636,0xde350033}},	//   dotu, _خرید_, cité, цэль
  { {0x8db5008f,0xa2b8014e,0xd0d50063,0x7bda0020}},	//   ўскі, ्पर्, _добъ, eotu
  { {0x7bda007c,0x5ba90432,0x7bc8001a,0x6d494637}},	//   fotu, иким_, fndu, rgea
  { {0xdfdb006b,0x6d490012,0x7e2b005e,0x98a9002a}},	//   _съб_, sgea, _біда_, _zdać_
  { {0x99d60015,0x49ba00c3,0x8a050138,0x68ed4638}},	//   قتحا, لاحد_, юзне, _azad
  { {0xdb0100f2,0x82760053,0xdb1a00f2,0x7bda007c}},	//   kilö, קערע_, entä, aotu
  { {0x629e005c,0xa1560008,0xa3d9021e,0x8884002b}},	//   zypo, חברה_, ावा_, سیدن
  { {0x6b83003c,0x97da004a,0xdb0100bf,0xfaa50924}},	//   _unng, рьму_, ahlá, _мало
  { {0x99d60015,0x0bb6002b,0x672e0030,0xa50a0579}},	//   _وتبا, _بجنگ, rabj, иева_
  { {0xdb01002f,0x7984005c,0xdb1a3869,0x14260063}},	//   chlá, _uniw, vité, ждам
  { {0x29050089,0x7cf60053,0xf7720015,0xe73a005e}},	// [a040] ělat_, ַזעס_, _قاد_, _кеп_
  { {0x16663546,0x2122000b,0x8387005e,0x44324639}},	//   _двом, मर्श_, обув_, rsy_
  { {0x7a080046,0x63be00bc,0x4432463a,0xe81e0065}},	//   _pěti, ripn, ssy_, _बढ़ता_
  { {0xf3e9013a,0x7bda003f,0x80a60002,0xa1830033}},	//   דף_, zotu, يمان, дышл
  { {0x7bc8002e,0x7bda003f,0xdb1a463b,0x10130015}},	//   yndu, yotu, sité, وبود
  { {0x27170089,0x2d9911e2,0xdb01007c,0x987b000a}},	//   mění_, ösen_, lilõ, יאנט
  { {0x59ca005d,0x5e440015,0xf8bf0003,0x6d470091}},	//   ाचार, أَعْ, mbée_, ėjan
  { {0x2dd70029,0x1d340063,0x6ebe000b,0x98a9002a}},	//   يبية_, чния, _वेणु, _udać_
  { {0xc5f304dc,0x27170089,0xdb1a00f2,0x6eda005d}},	//   ודה_, nění_, yntä, _पुरु
  { {0xa3ea005d,0x68ed005c,0xdfa60115,0x7bda0620}},	//   मति_, _rzad, _بحري, uotu
  { {0x7ae30176,0x43770053,0xcf930008,0xd37b0008}},	//   _cynt, קײטן_, _קטע_, בריט
  { {0x6d460030,0x7bda008c,0x6c860058,0x4c8600af}},	//   ókad, sotu, _ولام, _млев
  { {0xa3ea000b,0xdc55002b,0x7bda463c,0xcdf7004f}},	//   मता_, _فروک, potu, _ומאי_
  { {0x27170089,0xbb570010,0x6c83002b,0xa6170015}},	//   dění_, _маіх_, _آلوم, قبرص
  { {0x7ae30176,0xc5fb0015,0xb5c90015,0xe695004a}},	//   _gynt, لعرض_, موسم_, чивы
  { {0xdb01463d,0xbdf40008,0xa3b3000b,0x84150ef5}},	//   gilõ, לֶּה_, जोई_, змах
  { {0xcd970008,0x6d9c002d,0xb604006f,0x5fbc000b}},	// [a050] קדמת_, _héas, úšat, ्चाल
  { {0xd3710029,0x8c1b000a,0xdc8b000a,0x69dd463e}},	//   عها_, יומי, יְבָ, lose
  { {0xdb010604,0xf8040010,0x17f80015,0x65a3007c}},	//   silö, _ўчын, _برية_, _jõhk
  { {0xe0d30074,0xc6920053,0x6b9801f0,0x212a002b}},	//   وزش_, _נאכ_, _lovg, ميمی_
  { {0x95160008,0x65a30020,0x397c0643,0x7a130045}},	//   _מקרא_, _lõhk, יטאנ, _măta
  { {0xb4fa0008,0xe4fa000a,0x62350bb1,0xd678002b}},	//   _לפרי, _לפרש, _негу, _احیا_
  { {0x69dd1437,0x6e92002b,0xdf360015,0xfe790033}},	//   kose, فلوا, سكيت_, сёлы_
  { {0x32280036,0xf1bf0030,0xf2d2015b,0x9f470125}},	//   _фірм_, _öá_, _נען_, nmnú_
  { {0x65a30005,0xcc350029,0x7ae308af,0xdd8f002b}},	//   _põhj, أربع, _synt, فوژ_
  { {0x5ba9463f,0x7ae3377a,0x69dd4640,0x32042402}},	//   ском_, _pynt, eose, _zimy_
  { {0x0dcb0036,0xa3b3000b,0x539c004c,0x20050061}},	//   _куди_, जोए_, ייזו, _iili_
  { {0x2005000c,0x186a03e7,0x6456008c,0x9df90054}},	//   _hili_, бами_, ytyi, _унет_
  { {0xda0b000b,0x6d5b0573,0x7ae3108d,0x65aa0052}},	//   _सूरत_, mfua, _wynt, _nýha
  { {0x8c1a000f,0xbca400c3,0xf092000a,0x27170046}},	//   _הוסי, _تمهي, תנך_, vění_
  { {0xcb12013a,0xcf9200b2,0x6d5b003f,0x8f88000a}},	//   _אלו_, ײטן_, ofua, קְשֵ
  { {0x27170089,0x645600f2,0x2cb00064,0x7bc100f2}},	//   tění_, ttyi, _öldü_, lilu
  { {0xddc10024,0x0000006a,0x0000006a,0x0000006a}},	// [a060] _aplū,   ,   ,
  { {0x287b0008,0x7bc14641,0xa87b000a,0x7a080046}},	//   _פנימ, nilu, _פריח, _větv
  { {0x479b00b2,0xa79b0008,0x6d9c002d,0x179b01ac}},	//   _הייס, _השיח, _méar, _הייב
  { {0x6d9c002d,0x6a3a0053,0xa1580036,0xb2d30015}},	//   _léar, מגעפ, іалу_, رينغ
  { {0xd12f04b6,0x60230010,0x40c50086,0x20054642}},	//   امه_, едча, وزهف, _bili_
  { {0xb6020089,0x44204643,0x6d9c0125,0x9837004f}},	//   žáda, mpi_, _néar, לטנו_
  { {0x20050064,0x9757000a,0xa3d9000b,0x44204644}},	//   _dili_, פיקו_, ावर_, lpi_
  { {0xdceb0024,0x91e3005e,0xad260015,0xd257000a}},	//   _sagā, _зосе, أرثو, _משלה_
  { {0x6d9c002d,0xdceb0024,0x7bc14645,0xcf5a004a}},	//   _béar, _pagā, filu, _греч_
  { {0x0b8a005f,0x6d9c002d,0x6d5b003f,0xa08b000a}},	//   ссии_, _céar, afua, _לְבִ
  { {0xde170029,0x0ac6004a,0x9e660033,0x6d9c0125}},	//   _فقلت_, ящим, _хвед, _déar
  { {0x6d9c02c1,0xc27b000a,0x6444019a,0x7bc14646}},	//   _véas, צרכי, krii, ailu
  { {0x5887008f,0x387f001a,0x7bc14647,0xdb1a4648}},	//   чына, íur_, bilu, lití
  { {0x6d9c0b78,0x660626a6,0x64444649,0x9c17004f}},	//   _téas, _aikk, drii, _צחוק_
  { {0x6a130029,0xe5ab0001,0x7d04002d,0x69dd0287}},	//   _كبير, бњак_, _úisb, pose
  { {0x660600dc,0x21e7007c,0x75240030,0x1c110065}},	//   _cikk, rõhk_, gbiz, _डूडल_
  { {0x93270029,0x6606464a,0x5399054f,0xdb1a0045}},	// [a070] كران, _dikk, овая_, mitâ
  { {0xe4e40010,0x8c1b000a,0x33741d9f,0xdb1a059d}},	//   хісн, צובי, нгур, litâ
  { {0xdb0100b8,0x6444464b,0x81c8003d,0x4420464c}},	//   chlä, arii, _orēķ, api_
  { {0x75350053,0x64440020,0x2005464d,0xe4a70d1f}},	//   _קאָד_, brii, _sili_, _ерго
  { {0x7ff50086,0x200d04ed,0x2005464e,0x644400d4}},	//   وستا, _quei_, _pili_, crii
  { {0xedf7005d,0xdceb0045,0x6d470091,0x442b0fc1}},	//   ुद्ध_, _lagă, ėjam, _iwc_
  { {0x7bc102b9,0xce180033,0xdce90085,0xe6c8000a}},	//   vilu, пцыі_, odeć, ּ֔וֹ_
  { {0x7db40010,0x6d5b003f,0x6d9c0125,0x31c4005e}},	//   есьц, ufua, _séar, _зсув
  { {0x2005022d,0xd6d9005c,0x752f005c,0x2bb90029}},	//   _tili_, ęły_, _mecz, قادة_
  { {0x2bb90029,0x752f005c,0x1bb90029,0x75240030}},	//   تابة_, _lecz, تابع_, zbiz
  { {0xc3320008,0xd9464068,0x753d002a,0x442b0034}},	//   כוי_, мени, _odsz, _lwc_
  { {0x5dd80036,0x1eea0086,0xc7a90008,0x3179004c}},	//   _ефір_, _بومی_, _דב_, קאָד
  { {0x6d9c002f,0x66060458,0x0136000a,0xdd31002a}},	//   _téar, _rikk, וררת_, iężk
  { {0xeab10029,0x660602e9,0xcb080015,0x07fa0015}},	//   _لعب_, _sikk, _فيهن_, ترجع_
  { {0x7a080089,0x66060607,0xb9c60015,0xe57a005e}},	//   _děts, _pikk, _يتعه, озв_
  { {0x85ea005e,0x7aee0012,0x6444019a,0xdb1a13e3}},	//   ідав_, übte, trii, citâ
  { {0x3cfa0053,0xdb1a464f,0xabf9000a,0x6444019a}},	// [a080] ַלענ, zití, ַהֲר, urii
  { {0x44390440,0xf74a0015,0x994a002b,0xf7720067}},	//   _dvs_, _بلدي_, _الکل_, _شاخ_
  { {0x64440005,0x4439007c,0xa3bd000b,0x3f9a001a}},	//   srii, _evs_, इफ़_, öpum_
  { {0x64444650,0x44204651,0x0000006a,0x0000006a}},	//   prii, ppi_,   ,
  { {0xd43600c3,0x2f180fa5,0x0000006a,0x0000006a}},	//   _تعجب, поль_,   ,
  { {0xdb1a30e5,0xf8b7000a,0x5e86033d,0x437534d4}},	//   zitâ, ופני_, дуиз, _пуст
  { {0x7c2b0176,0x63a34652,0xa3db000b,0xfc3f0125}},	//   _awgr, önne, डकर_, áín_
  { {0x65a30005,0xbdf700e6,0xdd900029,0x5c741a56}},	//   _põhi, وريا_, اوة_, елит
  { {0xe10b0008,0xe04600ce,0x9b6a2be2,0xfc3f0417}},	//   _וּבָ, _інжи, ошна_, šín_
  { {0x409b000a,0x65a3007c,0x109b004f,0x7ac62d88}},	//   _ובמס, _võhi, _ובמב, дсме
  { {0x3ddf0111,0xdc55002b,0xed5a00ce,0x0000006a}},	//   bouw_, وریک, _мож_,
  { {0xc237000a,0xdcff01ec,0x0000006a,0x0000006a}},	//   ורטו_, švār,   ,
  { {0x8dfb000a,0xdb1a016e,0x3dfb000a,0xc8c90058}},	//   _והאת, ritâ, _ולאד, سوسن_
  { {0x2cb00064,0xead4154c,0x65a3007c,0x5bc60015}},	//   ıldı_, _поль, _jõhv, _تتصف
  { {0xf8ae0086,0xbd050152,0xef67000a,0x26070033}},	//   لکی_, _théâ, וֹן֙_, дчаг
  { {0xfaa70086,0xa021001a,0xdb1a0714,0xa9c400ce}},	//   _تجهی, _þögg, lità, _аськ
  { {0x94ab02e5,0xd37b0036,0x24580080,0xdce90085}},	// [a090] цтва_, жче_, мать_, rdeć
  { {0x08f800e6,0x47d50015,0xdb1a0714,0x7c2d0061}},	//   _غريب_, _سيجر, nità, _çare
  { {0xc2c40015,0x69cf4653,0xe5351111,0xe3c40058}},	//   نيكي, once, _пень, خْلَ
  { {0x77b000c0,0x3264006b,0xd1b800c3,0x64580045}},	//   _växe, ътув, وانا_, ăvir
  { {0xb06b0029,0xe0ce0036,0x251a000a,0x6d9c0003}},	//   تصال_, ув_, _מורא, _réap
  { {0xf41f00f2,0xf456000a,0x9f470046,0x24b6004f}},	//   _itä_, _אישר_, olné_, _טהרן_
  { {0x52140010,0x644d4654,0x9ea902c8,0xdee210ff}},	//   _адст, luai, явка_, лоши
  { {0xe1f00015,0x4ea4006b,0x7c950004,0xf41f0123}},	//   _نسق_, ърча, ероц, _träd_
  { {0xcc89002b,0x3ddf0079,0xa017002b,0x6735002a}},	//   سنده_, rouw_, _آذرش, kazj
  { {0x69cf263b,0xeb910015,0x3496004f,0x61eb10c6}},	//   ence, اظة_, ׂ֣ים_, llgl
  { {0x25a90014,0x644d002d,0x5e450015,0xf8c8000b}},	//   kkal_, huai, _أَصْ, रप्प
  { {0x5d840029,0xf2d2004c,0x65a3007c,0x644d008c}},	//   _للمل, רעט_, _kõhu, kuai
  { {0x7bf90054,0x29040fd8,0x0c2400fd,0x7bcc001a}},	//   _ендр_, äma_, _амін, ðluð
  { {0xdb1a1732,0x644d4655,0x69cf4656,0xd7f20015}},	//   cità, duai, ance, اكس_
  { {0xa6a900e6,0xfe6700e6,0x7a090046,0x65a3007c}},	//   وافق_, دد_, _větr, _lõhu
  { {0x644d002d,0xdb1a4657,0x65aa0227,0x2aba000a}},	//   fuai, pitã, _výho, _ממצא
  { {0xd46728ae,0xb906005e,0x04430b27,0xdb1a4658}},	// [a0a0] ните_, _язик, летн, litá
  { {0x32d61e92,0x9325002b,0x2d9d4659,0x69c6465a}},	//   нцес, نرمن, _lowe_, like
  { {0x69c600f2,0xcb120053,0xdb1a465b,0xc70b000a}},	//   oike, אלב_, nitá, _מִכֹ
  { {0x2d9d0050,0x69c6465c,0x644d0003,0x25a90977}},	//   _nowe_, nike, buai, ckal_
  { {0x69c600f2,0xf5370008,0xc5f3000a,0x644d01c2}},	//   iike, _אנכי_, _תדר_, cuai
  { {0x69c60020,0x7bcf1d2c,0x61eb0012,0x0000006a}},	//   hike, écul, algl,
  { {0xda0b005d,0x61460001,0x5757000a,0x69c6465d}},	//   _संगत_, _пева, תבצע_, kike
  { {0xc693013a,0x2247032c,0x2c260036,0x765c005c}},	//   ראה_, ánke_, ньог, itry
  { {0xd577000a,0x2d9d00aa,0x01d70015,0x69c6220e}},	//   תתפה_, _dowe_, _أوقع_, dike
  { {0x765c005c,0x10090029,0x61e20020,0xceea0010}},	//   ktry, _قتلى_, lool, _едзе_
  { {0x6fb30225,0xdb1a465e,0xda6600e6,0x69c6465f}},	//   _حملا, rità, رادي, fike
  { {0x765c1639,0x24801e77,0xc237000a,0x6735002a}},	//   dtry, kvim_, ערכו_, wazj
  { {0xfbcf0086,0x0c940086,0x644d016e,0x65aa0046}},	//   شتی_, _جداگ, xuai, _výhl
  { {0x8c1b00b2,0x61e24660,0x36d509ac,0xeb97006b}},	//   _צווי, hool, вогр, _пич_
  { {0x61e20005,0xc9870036,0xf41f00f2,0x3f9e0a72}},	//   kool, _зупи, _stä_, _motu_
  { {0x69c63f00,0x644d1649,0xf0a60016,0x2a57000a}},	//   cike, tuai, _đành_, _נבחן_
  { {0x798d000c,0x59640063,0x2611005d,0x25a94661}},	// [a0b0] _inaw, _съща, _दूरी_, rkal_
  { {0x65a30020,0x644d002d,0x3f9e0064,0x38690030}},	//   _rõhu, ruai, _notu_, _ipar_
  { {0x3255087a,0x32670033,0x644d4662,0x02bd0065}},	//   твер, этав, suai, ्पेन
  { {0x65a3007c,0xaadb004f,0x11f6009a,0x0000006a}},	//   _põhu, החבר, نتنگ,
  { {0x75360053,0x644d0493,0xef0e366a,0x7aea0a88}},	//   _בארד_, quai, им_, _lyft
  { {0x10a207c1,0xdb1a2835,0x6096002b,0x69c6005a}},	//   ришн, litæ, ئنوس_, zike
  { {0x61150010,0x3f9e003d,0xb1aa001a,0xa6fb000a}},	//   _адбу, _dotu_, þýðu, הִ֗י
  { {0x65a30020,0xfc3f0f1b,0x68fb0091,0xdb1a4663}},	//   _tõhu, ším_, žudy, vitá
  { {0x69c64664,0x0c360058,0x0000006a,0x0000006a}},	//   vike, نكية_,   ,
  { {0x798d077c,0xdb1a0307,0xb4fc000a,0x765c4665}},	//   _anaw, titá, הפחי, ytry
  { {0x38690011,0x2fc7043a,0x69c64666,0x3376000a}},	//   _apar_, ming_, tike, דעתם_
  { {0x7c95002b,0x798d0034,0x2fc74667,0x765c06c7}},	//   _لشتا, _cnaw, ling_, vtry
  { {0x39430010,0xbca5002b,0x2fc700da,0x69c62838}},	//   шняг, _جمشي, oing_, rike
  { {0xf7720029,0x69c64668,0xdb1a4669,0x765c0bfd}},	//   جاح_, sike, pitá, ttry
  { {0x49ba0086,0xcf920053,0x3ea70026,0x25aa0015}},	//   _يابد_, סטל_, nynt_, ودري_
  { {0xceb2013a,0x7d1b2501,0x2fc7466a,0x765c3a91}},	//   ביל_, ncus, hing_, rtry
  { {0xe8fa0063,0x69c4005c,0x61e20020,0x2fc7466b}},	// [a0c0] _юли_, _imie, vool, king_
  { {0xf8370008,0x236a0015,0xa837000a,0x9c82006f}},	//   _שנית_, بحري_, _שריד_, účil
  { {0x2480016f,0x2fc7466c,0x28b2000b,0x3f9e008c}},	//   svim_, ding_, ुछवि, _rotu_
  { {0x3ea70026,0x2fc7003e,0xba9a000a,0xe2450015}},	//   dynt_, eing_, וסעי, اخلي
  { {0x61e20020,0x6e930086,0xdfda0063,0xc953000a}},	//   rool, یلها, мък_, שמד_
  { {0x66f6005d,0x2fc7068d,0x6e8a0054,0x88bb000a}},	//   _इराक_, ging_, дљив_, וזני
  { {0x61e20005,0x8fa30001,0xc7b30008,0x3ea7003c}},	//   pool, раје, שבו_, gynt_
  { {0x2fc702f2,0x71590033,0xfe45009a,0x0000006a}},	//   aing_, _прус_, اکلی,
  { {0x7aea00c0,0x7c3b0035,0x2f560805,0x2fc7466d}},	//   _syft, gsur, _атес, bing_
  { {0xef830180,0x2fc70fda,0xe945002b,0xfbcf0015}},	//   _клуп, cing_, گردی, ْتَ_
  { {0x7c3b003e,0x195902bf,0xcfb7000a,0x798d0034}},	//   asur, наны_, _שלבי_, _pnaw
  { {0xceb30053,0x200c02f2,0x7aea042f,0x79a710b7}},	//   _דיע_, _hidi_, _vyft, трое
  { {0xc1730008,0x987402e1,0xbb860015,0xdd050045}},	//   בחר_, аляц, _للإي, ăpăt
  { {0x5c3700f3,0x798d0034,0x4993002b,0x6566466e}},	//   _ירדן_, _wnaw, ایکر, _abkh
  { {0xf8bf03af,0xda7a0063,0xab290015,0x200c3d98}},	//   mbém_, _цял_, _أسهل_, _midi_
  { {0x798d000c,0x7c22002c,0x200c0089,0x2fc72655}},	//   _unaw, _ktor, _lidi_, zing_
  { {0x2fc7466f,0x8514005e,0xe4e7005e,0xd407004a}},	// [a0d0] ying_, рмує, тівн, вяжи
  { {0x02a70191,0x98be0011,0x2fc70b77,0x69c4066f}},	//   крем, ştă_, xing_, _zmie
  { {0x9f5e022d,0x2fc74670,0x75d50002,0xd25b0afa}},	//   _mitä_, ving_, _ميدا, ьца_
  { {0xc69200b4,0xdb1a195d,0xd0590010,0x7bc80849}},	//   _האט_, litä, еркі_, hidu
  { {0x3ea70026,0x2fc72345,0xb9bc000a,0x6aa80034}},	//   wynt_, ting_, וצאת, hydf
  { {0xdb1a0b0f,0x3fe4005e,0xa836004c,0x657d4671}},	//   nitä, ажів, אָקס_, _hash
  { {0x92940010,0xe1db0029,0x6e950002,0xc2c50015}},	//   _карц, _قبرص_, العا, _إيزي
  { {0xf2d20008,0x7c3b4672,0x7bc8144e,0xdd8e0015}},	//   _העל_, tsur, eidu, كوى_
  { {0x657d000c,0xd0110086,0xdb010046,0x7c940033}},	//   _mash, _طلا_, dklá, арэц
  { {0x7c22002f,0xdb013fa2,0xa3d9000b,0x7d1b164a}},	//   _dtor, eklá, ावट_, scus
  { {0xdb1a4673,0x68f6002a,0x7c3b4674,0xeab10015}},	//   entó, _szyd, ssur, صعد_
  { {0x1996012e,0x657d4675,0x3e7c0046,0x7c3b00d4}},	//   ујор, _nash, sátá_, psur
  { {0x35c6005d,0xdb08008c,0x7bc8265b,0x8c4501cf}},	//   रोफ़, ehdä, bidu, _селе
  { {0x7bc84676,0xdb01005a,0x96760138,0x628701d3}},	//   cidu, aklá, лыбі, _orjo
  { {0x7bda000a,0xf9920015,0xdb1a25d8,0x657d4677}},	//   _אקסו, _هبة_, antó, _bash
  { {0xceb20008,0x69c44678,0x39360033,0x657d4679}},	//   זיל_, _umie, _сэкс, _cash
  { {0x657d467a,0x0000006a,0x0000006a,0x0000006a}},	// [a0e0] _dash,   ,   ,
  { {0x5503467b,0x2897000a,0xe001005e,0xdb1a02ad}},	//   спуб, _עדין_, _крiм_, citä
  { {0xdb1a0064,0xa75b000a,0x82f60033,0x657d467c}},	//   sitç, _אדיר, учац, _fash
  { {0x2246002c,0x22470227,0x61fb467d,0x3239002b}},	//   čok_, ánka_, _chul, ئينگ_
  { {0x200c0020,0x61fb003f,0x4fc605b3,0x8fa61f67}},	//   _pidi_, _dhul, лска, ладе
  { {0x2d8f01d1,0x0877004c,0xdb010046,0x7bc8108c}},	//   _ange_, טענט_, zklá, xidu
  { {0x200c052c,0xa278000a,0x72780c44,0x1eaa012c}},	//   _vidi_, _בְּז, _בְּצ, عاتي_
  { {0x9f5e022d,0x7bc8005c,0xdb1a00b8,0x91e603c5}},	//   _sitä_, widu, zitä, _собе
  { {0x7c960015,0xe571000a,0xdb010046,0x7bc8467e}},	//   اشعا, חַי_, vklá, tidu
  { {0x99860007,0xdb1a0012,0x7bc8007c,0x2d8f0a2a}},	//   kslų_, xitä, uidu, _enge_
  { {0x7bc80005,0xdb1a0437,0x7c22002a,0x99990046}},	//   ridu, vitä, _wtor, érů_
  { {0x2eb0014e,0x7bc8467f,0x6aa80416,0x0000006a}},	//   जनीत, sidu, rydf,
  { {0xab94005e,0x657d0c81,0xcdf7000a,0xdb1a15c3}},	//   _вилі, _rash, _עמדי_, titä
  { {0xcc57000a,0x657d4680,0x0000006a,0x0000006a}},	//   _עסוק_, _sash,   ,
  { {0x8b650086,0x9f8b0020,0x1635006b,0xdb1a3756}},	//   _خانم, _töös_, ребя, ritä
  { {0xca470029,0xb5a402e1,0xfe37000a,0xa9680054}},	//   _إليه_, бруй, טרלי_, _бића_
  { {0xdb1a4681,0x2418005e,0x3387006b,0xf41f008c}},	// [a0f0] pitä, гією_, лужв, _erän_
  { {0x61e90472,0x657d2082,0x61fb4682,0x7e7a0dca}},	//   _skel, _wash, _shul, _ostp
  { {0x92590080,0x7bdb0008,0x20f40092,0xa3c4000b}},	//   тает_, עקבו, _ài_, एफ़_
  { {0x8ab500b2,0x2a570053,0x62080015,0x41e40138}},	//   סלײג_, רבאן_, هْلِ_, біча
  { {0x752d22cc,0x31580015,0x3d0e000b,0x853a004f}},	//   mbaz, اجمة_, ाखों_, _בגרי
  { {0xf838000a,0x644d0125,0x660f4683,0x9f4701c0}},	//   ננות_, mrai, _hick, plní_
  { {0xfd110029,0xa77c0135,0x44294684,0x660f4685}},	//   يجة_, גרופ, lpa_, _kick
  { {0xada50080,0x067c000a,0x2016006f,0x644d4686}},	//   раил, תנהל, údií_, orai
  { {0xdb1800c0,0x644d1f22,0x4429013c,0x65a8000a}},	//   _omvä, nrai, npa_, ר֣וּ_
  { {0x7ff7003b,0xec680015,0x660f35b5,0x5ba903b1}},	//   _إسرا, اصيو_, _lick, тком_
  { {0x644d4687,0xaa490063,0x35c60065,0x2d9902ad}},	//   hrai, ъпна_, रोड़, öses_
  { {0x41b5000b,0x660f27c4,0x7dc50091,0x7e9a000a}},	//   ंसिस, _nick, iųsk, _בסעו
  { {0x644d0030,0x0000006a,0x0000006a,0x0000006a}},	//   jrai,   ,   ,
  { {0xd0f60008,0x1cba000a,0x261a000b,0x7c290faa}},	//   שמשת_, _שמסע, _मंदी_, mper
  { {0x96060015,0x660f31aa,0x62850069,0xda64012c}},	//   لبرم, _bick, jvho, _هايي
  { {0xceb20008,0x644d4688,0x5ee8000a,0x45350033}},	//   קין_, frai, רַשְ, йхут
  { {0xb425003b,0x6fd60231,0x3d08000b,0x644d4067}},	// [a100] معلو, _बदलू, ाइये_, grai
  { {0xcb12004c,0x7c294689,0xdb010723,0xe3b73758}},	//   ַלד_, iper, rklæ, абу_
  { {0x644d1a28,0x4429468a,0xd5b10016,0x6d460030}},	//   arai, apa_, ếc_, ókak
  { {0x673c00bd,0xc0ca070e,0x2813002b,0x463b004c}},	//   larj, куле_, _دویس, _בעטע
  { {0xdcee0048,0x644d002f,0x66040607,0xd91b000a}},	//   ādīj, crai, mmik, דונל
  { {0x673c00bd,0x66040044,0x7c29468b,0xa3ca000b}},	//   narj, lmik, dper, _ऋषि_
  { {0x2eb0000b,0xe297468c,0x7c291ccf,0x6604013b}},	//   जनेत, _кар_, eper, omik
  { {0xef180024,0xc27b0008,0xbbae000b,0x91e30b97}},	//   _daļa_, _ברלי, टस्क, _досе
  { {0x6da30015,0xdce90061,0x9f450125,0x7a130045}},	//   تميم, rdeğ, _chló_, _mătu
  { {0x6be3003b,0x2d9903c1,0x6bd30015,0x0ba62e06}},	//   يكيم, öser_, ْتَر, ршим
  { {0xdb0100b8,0x673c00bd,0x77b000c0,0x32182889}},	//   chlü, darj, _växl, _jury_
  { {0x644d468d,0x3218002a,0x6e2a1631,0x6604002a}},	//   yrai, _mury_, mpfb, jmik
  { {0x764e0026,0xf7730115,0x0c76002b,0x57a70239}},	//   erby, ياس_, _خداد, ашва
  { {0x644d0152,0xdb0100b8,0x660f1bd0,0x2cbb0c44}},	//   vrai, fklä, _sick, _שֶׁב
  { {0x6595000d,0x644d0026,0x660f0220,0xabfb000a}},	//   баву, wrai, _pick, _שהור
  { {0x644d468e,0xd5b8468f,0x7a130045,0x48ab09d9}},	//   trai, асу_, _cătu, _атом_
  { {0xdb01002d,0x69fc000a,0x752d4690,0x9327002b}},	// [a110] bhló, _בלהק, rbaz, لران
  { {0x644d3ed1,0xe4e40010,0x660f0334,0xa3b3000b}},	//   rrai, цісн, _wick, ड़ों_
  { {0xd1310015,0x660f4691,0x326b0015,0xdb010dca}},	//   كما_, _tick, ضحاً_, cklä
  { {0xf5950029,0x2eb0000b,0x82340015,0xa4d5005e}},	//   _الحج, जनैत, تركا, _гомі
  { {0xe0d00087,0xe31b002b,0xa1580432,0xb4440033}},	//   وزه_, _لغزش_, рачу_, _мэрк
  { {0x1878000a,0x6e450015,0x889c000a,0x32180878}},	//   יעדר_, منتم, כבדי, _fury_
  { {0x98ab005c,0x87b801ac,0x0000006a,0x0000006a}},	//   racę_, שלוס_,   ,
  { {0x673c00bc,0x7c294692,0x261a0065,0x0000006a}},	//   zarj, tper, _मंसी_,
  { {0xb4f5005d,0x60d5039e,0x7c294693,0x42040058}},	//   _आरोप_, _הוּא_, uper, _ذِكْ
  { {0x5f440029,0xe4fa000b,0xbed50004,0x7c290476}},	//   _ونقل, ्धति_, _лозј, rper
  { {0x673c4694,0x7c294674,0x2fe40015,0xdb1e0046}},	//   varj, sper, _بكلف, ýván
  { {0x261c02c1,0xc7a900f3,0x7c290f99,0xf2d2000a}},	//   _río_, _אב_, pper, לעי_
  { {0x3e6100dc,0x7d7a000a,0x7c940015,0x673c4695}},	//   lót_, _תרנג, _وشها, tarj
  { {0x261c0077,0x7a130045,0xdca20302,0xab261411}},	//   _pío_, _sătu, _хаши, _лоша_
  { {0x4b36000a,0x4df9004c,0x69dd0046,0x7a130045}},	//   _הרצל_, ָפּא, érec, _pătu
  { {0x96630010,0xdb0108e9,0x09e3006b,0x673c4696}},	//   яксе, rklä, _нощн, sarj
  { {0xc9b70008,0x35e50010,0x66044697,0xe3160031}},	// [a120] _להקת_, ццёв, rmik, مباب
  { {0x389b000a,0x261c0077,0x7794002b,0x7ccb003d}},	//   _עיינ, _tío_, _بیسا, mērī
  { {0x9f4c0023,0x5b3a004c,0xa77b000a,0x06860015}},	//   _đoàn_, רגעק, _גריפ, _الجُ
  { {0x31c5005e,0x3e611ad6,0xdcff005a,0x0000006a}},	//   осів, dót_, ávěr,
  { {0x0f14005e,0x11d70015,0x0000006a,0x0000006a}},	//   омлю, حونة_,   ,
  { {0xc0590191,0xa073008f,0xdefa0080,0x25a000bc}},	//   рії_, ягіч, лый_, ljil_
  { {0xf7730008,0x877b0053,0xf8bf00dc,0xee86004a}},	//   פקה_, ראצי, zzé_, сыло
  { {0xc693000a,0x3dcd002a,0x25a0088a,0xbca40058}},	//   לאו_, giew_, njil_, قمعي
  { {0xe0da0001,0x5bb803ad,0x711b000a,0x25a001c2}},	//   _сва_, илия_, _תומפ, ijil_
  { {0x547b0008,0xf8bf3869,0x4f6600e5,0xf24a000a}},	//   נטיו, ncée_, _دارف, ְגָּ
  { {0xc3330008,0x6dbb005c,0x6576008c,0xd9d9005e}},	//   הות_, właś, keyh, имої_
  { {0x64560035,0x9d1a0015,0xbc67002b,0x6da3006b}},	//   kuyi, _إزاء_, جمین_, _ниха
  { {0xacf60067,0x98a2002a,0x5c0600e2,0x0000006a}},	//   _اسات, ybką_, _ляка,
  { {0x7bcf0152,0x9cd7000a,0xf8bf01ce,0x9b940993}},	//   écut, _פוגה_, rzé_, _фикц
  { {0x2bf7000a,0x15f70015,0x5bc50015,0xcbc5002b}},	//   _המגן_, مسرح, _بتنف, _بزني
  { {0xf9930115,0xe4e700fd,0x58d5006b,0xeaaf0015}},	//   _ربع_, бізн, _мойт, _سعى_
  { {0x3e6100dc,0x64a4000d,0xf9900015,0x34941bc8}},	// [a130] zót_, паѓа, _أبى_, патр
  { {0x3cfb0008,0x8c1b000a,0x261a000b,0xd3710015}},	//   רלמנ, טומי, _मूवी_, ظها_
  { {0xdb030251,0x02d90029,0xd019002a,0x627500c3}},	//   _conè, جواب_, _suń_, تهائ
  { {0x9f4c0092,0x92b40029,0xeab10008,0x69cf4698}},	//   _đoán_, أحكا, וֹד_, nice
  { {0x8fa509ef,0x3dcd4699,0x897c004c,0x0000006a}},	//   жале, view_, טראצ,
  { {0xa8580008,0x3e6100dc,0xc2c40086,0x523b0015}},	//   מידה_, tót_, _کيفي, _مسرح_
  { {0x9989005c,0x8e55005e,0x6e920054,0x394916ee}},	//   _miał_, іткі, дију, _odas_
  { {0x3e610eba,0x0c2500a5,0x8c490850,0xec492925}},	//   rót_, омин, апив_, азил_
  { {0x61eb320e,0x69cf469a,0x403400af,0x2d9f013b}},	//   mogl, dice, _нетс, rjue_
  { {0xfbc50036,0x9f04002b,0x2d84007c,0x4a451bef}},	//   ібно, _کومو, adme_, онов
  { {0xdb1a00f2,0xe9da3529,0x69cf2490,0xc213000a}},	//   yntö, ико_, fice, ּה֩_
  { {0x3e450024,0x7a130011,0x6c850015,0x6725469b}},	//   mēt_, _bătr, _ولضم, _afhj
  { {0x7a1304f9,0x3e450048,0x30790053,0xdb030003}},	//   _cătr, lēt_, באָנ, _moné
  { {0xd5b10023,0x9989002a,0xe8f7033d,0xd7ef0015}},	//   ến_, _ciał_, юля_, َكَ_
  { {0x3e450024,0x24890064,0x644b047e,0xb9c60021}},	//   nēt_, evam_, ágin, _وقتي
  { {0x28c5005d,0x05660010,0x6b8340fd,0x6d5b2d18}},	//   _लेकि, ўван, _hang, ngua
  { {0x61eb3604,0x63a702c6,0x6d5b02b9,0x999f0091}},	// [a140] dogl, _bojn, igua, autų_
  { {0x7c24002d,0x6b83013c,0x79840553,0x7bd9000a}},	//   _éire, _jang, _haiw, ׁקּו
  { {0xd36f0029,0x61eb3302,0xf8bf0003,0x2489469c}},	//   ئهم_, fogl, rcée_, avam_
  { {0x3e450048,0x902a0033,0xdfd0002b,0xdb03469d}},	//   dēt_, ацка_, کيت_, _coné
  { {0x79840035,0xb0330036,0x9fe60067,0x798600aa}},	//   _maiw, дніш, يسته, idkw
  { {0x6b833a2a,0x5f93009c,0x8fa30054,0x69cf469e}},	//   _nang, дишт, даље, zice
  { {0x70560086,0x171b000a,0xfae7002b,0x6263004a}},	//   _ژنرا, בוצע, _آث_, _овра
  { {0x6b8300f6,0xc0e6005e,0x61eb02b9,0x3ea00085}},	//   _aang, _добк, cogl, ćit_
  { {0x2d82002c,0x6b83469f,0x69cf12fe,0x644446a0}},	//   ľke_, _bang, vice, nsii
  { {0x644400f2,0x7996003e,0x70530086,0x4e960015}},	//   isii, _anyw, _آنلا, _وشار
  { {0xe9190036,0x03770008,0x3e450024,0x0ac60080}},	//   йоні_, חתית_, cēt_, ющим
  { {0x6444022d,0x6b831f22,0xd1260021,0x7bcf0003}},	//   ksii, _eang, عم_, écur
  { {0x6d4022ce,0x395f0024,0x7a140011,0xdd8f00e6}},	//   mama, ļus_, _pătr, _جون_
  { {0xcb670001,0x6d4046a1,0x39140033,0x48a8005e}},	//   _даље_, lama, ьмяр, ітям_
  { {0x09f70015,0x8f9b000a,0xb5a707d0,0x85a703ae}},	//   _وأعد, סילי, орай, ојад
  { {0x248900bd,0xb5980015,0x6d4046a2,0x65942044}},	//   tvam_, يَّا_, nama, масу
  { {0xb4b5014e,0x3e450048,0x6b8343bf,0x54550063}},	// [a150] जने_, zēt_, _yang, яват
  { {0x7bda002e,0xc398005e,0x6d401a07,0x2489016e}},	//   nntu, окує_, hama, rvam_
  { {0x877a0008,0x6d401636,0x65aa0107,0x6746006f}},	//   _האתי, kama, _výhr, šujú
  { {0xf67a00b2,0x63a70050,0x1a9b0053,0x3e450024}},	//   _פארמ, _wojn, ייבע, vēt_
  { {0x7dc50007,0x859a0008,0x759a000a,0x659a000a}},	//   iųst, _השרו, _הסרג, _הירק
  { {0xf87c0008,0x8e490029,0x3e450024,0x6d40050b}},	//   שְׁל, ملتك_, tēt_, eama
  { {0x5f7400e6,0x69cd0fb2,0x31350a2b,0xce180033}},	//   ظاهر, _omae, _невр, оцыі_
  { {0x753d0050,0x3e450048,0x26dc0008,0x6b83469f}},	//   _jesz, rēt_, יקומ, _sang
  { {0x7bda0026,0x3e450024,0x6b831640,0xfbd1002b}},	//   fntu, sēt_, _pang, فتد_
  { {0x69dd038d,0x3e450024,0x753d46a3,0x3fb70029}},	//   éren, pēt_, _lesz, _بإرس
  { {0x9ee90029,0x2bca005d,0xddc80024,0x6d40183c}},	//   _افضل_, ाफ़ा, žoša, bama
  { {0x6d40215e,0x929a000a,0x7bda46a4,0xa91b001a}},	//   cama, צירת, antu, ldþj
  { {0x60d5000a,0xdb1a006f,0x3dfa000a,0xec6e1092}},	//   לוֹא_, litý, _פלנד, _яп_
  { {0x78a90020,0x6b83363d,0xa088000a,0x5bc40015}},	//   äeva, _uang, קְרִ, _يتوف
  { {0x753d0014,0xcf920053,0xbb3a000a,0x7aee0107}},	//   _besz, עטל_, _העצי, čité
  { {0x64440005,0x44390026,0x3f85013c,0x7afc0359}},	//   tsii, _bws_, _lalu_, ürte
  { {0x39420005,0x4376005f,0x752446a5,0x49bb000a}},	// [a160] maks_, зует, rciz, _למקס
  { {0xb903005f,0x394222a4,0x644446a6,0xb4630033}},	//   _язык, laks_, rsii, экул
  { {0xae0e005d,0x68120089,0x741300e6,0x753d00dc}},	//   ागमन_, _vědě, روما, _fesz
  { {0xf1a90087,0x39420020,0xf3e9000a,0x246e003d}},	//   يانه_, naks_, אף_, tēmā_
  { {0x6d4046a7,0x1047006b,0xdb010012,0x0000006a}},	//   vama, пящи_, chlö,
  { {0x6d4b00fb,0xa8570008,0x39420020,0x68f600f2}},	//   _adga, פיצה_, haks_, _myyd
  { {0x7c2b0048,0x3f850026,0x39420020,0x6d4046a8}},	//   _atgr, _dalu_, kaks_, tama
  { {0xdef9008f,0x39420005,0x8d760015,0x9e030033}},	//   цыі_, jaks_, ساعا, нчыл
  { {0x39420020,0x3f85262d,0x6d40292a,0xdfd20015}},	//   daks_, _falu_, rama, _كير_
  { {0x39422d25,0x6d4046a9,0x6d4b1a84,0x3f8518df}},	//   eaks_, sama, _edga, _galu_
  { {0x21fc02d5,0x8af70033,0x8f8b000a,0x6d4046aa}},	//   ního_, знэс_, _לְאֵ, pama
  { {0x4efb004c,0x3942007c,0x7e9b000a,0x58d5005e}},	//   _פלאג, gaks_, _לסבו, домт
  { {0xd5b10023,0xed570036,0x753d0eba,0x6c060033}},	//   ếm_, _хоч_, _resz, _ездз
  { {0xba760015,0xd7f10016,0xf8b00015,0x3942007c}},	//   _فاعت, ỗ_, اةَ_, aaks_
  { {0x21fc0089,0xc5fb0021,0x3942060a,0xf1bf006f}},	//   jího_, معرض_, baks_, úška_
  { {0xfaf70008,0xe4e7005e,0x1af7000a,0x3ea101be}},	//   _מצוי_, пізн, _ממול_, ähti_
  { {0x753d00dc,0x9735002b,0x69dd2494,0xdb1a006f}},	// [a170] _vesz, _يکسا, mnse, zitý
  { {0x753d005c,0x58bc000a,0x88bc000a,0xeb92000a}},	//   _wesz, _למחצ, _למחז, ךָ֣_
  { {0x753d0014,0x22950029,0x224700dc,0x27e4006f}},	//   _tesz, بلاس, énk_, émne_
  { {0x69dd46ab,0x313508f7,0xdb1a01c0,0x3f8546ac}},	//   nnse, федр, vitý, _salu_
  { {0xc5fb005d,0xdce00024,0xdb1800dc,0xd8d80053}},	//   ्षीय_, iemē, _elvé, ּווט_
  { {0x7655005c,0xdfd10015,0xa4b6000a,0x1e9519a5}},	//   orzy, ضيع_, _חלשה_, дрир
  { {0x21fc02d5,0x63a3002e,0xdb090064,0x7ff4002b}},	//   cího_, önnu, ünün, رسها
  { {0x69dd3c66,0xa4c00064,0xe1f30015,0x656d0012}},	//   érel, nüşü_, _أسس_, nfah
  { {0x39420005,0x656d19f4,0x01640015,0xf09f0003}},	//   vaks_, ifah, _سُلَ, _çà_
  { {0x7655005c,0xa3b0000b,0x394239a7,0x656d0012}},	//   krzy, टॉप_, waks_, hfah
  { {0x8eb50086,0x39420020,0x7655005c,0x7afd005c}},	//   _تماش, taks_, jrzy, ęsto
  { {0x68f6022d,0x6d4b0134,0xbcb503ad,0xceb2000a}},	//   _pyyd, _udga, _обещ, _שיא_
  { {0xe87c01e2,0x7655005c,0x21fc0089,0x656d0012}},	//   _düşü, erzy, zího_, dfah
  { {0x39420005,0xa84d0046,0x6f040046,0x628b003d}},	//   saks_, énář_, řice, āgoj
  { {0xe9d2003b,0x7a420046,0x7bc10125,0x656d0012}},	//   _لغة_, _vítá, mhlu, ffah
  { {0xcb12000a,0x7bc1001a,0x68f6008c,0xee5c001a}},	//   _בלו_, lhlu, _tyyd, óðið_
  { {0x60040251,0xd4673b54,0xd4d50033,0xf993000a}},	// [a180] lòme, мите_, ніфэ, _ירה_
  { {0x7655005c,0x21fc0089,0x6722000b,0x22ba0015}},	//   brzy, tího_, _मलिक_, يداع_
  { {0x38cb0074,0xa79b000a,0xf79b000a,0x60040144}},	//   _هایی_, _ושיח, _ובימ, nòme
  { {0x200508c0,0x02de000b,0xbbaa000b,0xd24f002b}},	//   _ahli_, _मशीन, _चक्क, شنه_
  { {0x765c00f2,0x7bc10049,0x98b90045,0x1f740b9b}},	//   lury, khlu, masă_, елля
  { {0x3940017e,0x7bdd0152,0x63a30012,0x4432097c}},	//   _leis_, ésul, önnt, mpy_
  { {0x2e4a0063,0xf773000a,0x98b90045,0xe36303ae}},	//   цяло_, דקו_, oasă_, _шкри
  { {0xdb0a0134,0x394046ad,0x6b880034,0xee070004}},	//   _ilfø, _neis_, wddg, мејл_
  { {0x9be60036,0xdbc6007c,0x69dd0140,0x9f640125}},	//   дінк, _möön, érem, ótón_
  { {0x4bda0029,0x7bc1002d,0x5a340c55,0x5f46002b}},	//   تبعد_, ghlu, ннот, _آنال
  { {0x8aa30036,0x59f90010,0x4f650015,0x6fb30067}},	//   вряд, зеня_, _سالف, _جملا
  { {0x8d930029,0x7d930015,0x69dd24f5,0x765c46ae}},	//   _للمش, _للمؤ, unse, dury
  { {0x3940002d,0x7655002a,0x69dd46af,0x0137000a}},	//   _deis_, wrzy, rnse, ורכת_
  { {0x76550050,0x7bc126af,0x7d020b6c,0xdb1a46b0}},	//   trzy, chlu, _izos, ritó
  { {0x99d70029,0xef11000a,0x656d0012,0x443246b1}},	//   _يتعا, ָּם_, tfah, epy_
  { {0x69d600dc,0x8a040054,0x181a009a,0x29d20160}},	//   ézet, _изје, _کريک_, nšal_
  { {0xe9df032c,0x656d018b,0xf7950033,0xa4c00061}},	// [a190] mnú_, rfah, _запэ, rüşü_
  { {0x7655005c,0xe9df002c,0x66060020,0x8c1b000a}},	//   przy, lnú_, _ehkk, קובי
  { {0x77b000c0,0x33f40123,0x656d0012,0x4155131f}},	//   _växt, växt_, pfah, евес
  { {0xe9df46b2,0x397c004c,0xd2580088,0x29d200bc}},	//   nnú_, ַטונ, ьцу_, jšal_
  { {0xe4e70036,0x53470080,0x660d0201,0xd46b0015}},	//   _цінн, _охва, mmak, _بحجم_
  { {0xe9df1421,0x409200c3,0x660d2531,0x9fc9005e}},	//   hnú_, الور, lmak, ягла_
  { {0xf3140010,0xe9df002c,0xfe710031,0x660d46b3}},	//   _адрэ, knú_, ادت_, omak
  { {0x660d46b4,0x22470107,0xe9df006f,0xcc880016}},	//   nmak, ánku_, jnú_, _bớ_
  { {0xe9df002c,0xe572000a,0xcc880016,0x7bc1001a}},	//   dnú_, אַת_, _cớ_, thlu
  { {0xdd1d0045,0x660d0158,0x30180015,0x539a000a}},	//   _fâşi, hmak, _قتلة_, ִירו
  { {0xdd950033,0x7bc1001a,0x660d46b5,0xba750015}},	//   _пажы, rhlu, kmak, رادت
  { {0x3ce0044c,0x8d740015,0x6fcd002a,0x4d740015}},	//   _žive_, _لاها, dźci, _لطهر
  { {0x7cc4006e,0x660d46b6,0x415a004f,0xdd1c005a}},	//   _لزوم, dmak, הדרג, ušťk
  { {0x765c1e7f,0xdbc6007c,0x660d04f1,0x394046b7}},	//   tury, _söön, emak, _weis_
  { {0xe9df002c,0xf6d5005e,0x3940007c,0xb7d70015}},	//   bnú_, вітя, _teis_, روفا_
  { {0xe9a90015,0xe617006b,0xca740033,0xe9df006f}},	//   _يدين_, едс_, _рушы, cnú_
  { {0xe3ba006b,0x999f0091,0xe40600eb,0xaa090015}},	// [a1a0] пба_, artų_, езап, _تزول_
  { {0x43860029,0x6456003e,0x26cc001c,0x42260033}},	//   علاق, rryi, údos_, еджв
  { {0x44320305,0x14170015,0xdbc6007c,0xdb0100bf}},	//   spy_, ريمة_, _töön, yklý
  { {0x4432014c,0x7aba000a,0x41aa006b,0xda02000b}},	//   ppy_, הצעו, явен_, ोषित_
  { {0x351b0008,0xf1a90067,0x44241171,0x0000006a}},	//   _מוכנ, باله_, _îm_,
  { {0xd0100015,0xf1aa002b,0xf41f008c,0x7f580674}},	//   جلت_, _کاسه_, _eräs_, факс_
  { {0x539b0008,0xf67a0053,0xc7b30008,0x7d02002a}},	//   _צילו, לאַמ, רבו_, _szos
  { {0xf41f0123,0xde930015,0xf653004f,0x3e6801f6}},	//   _gräs_, اجوب, אצה_, rût_
  { {0xe9df002c,0xfc2f0086,0x442208ce,0xdb01001a}},	//   vnú_, یحی_, _juk_, rklý
  { {0x660d46b8,0xda7a006b,0xcc880016,0x7ac6121e}},	//   zmak, пям_, _vớ_, есме
  { {0x43570053,0xe9df002c,0x2ec60029,0x442246b9}},	//   עסטל_, tnú_, _ثقاف, _luk_
  { {0x32db000a,0x3e4c0046,0x6ebb000a,0xcc880016}},	//   לחינ, mět_, _מזבח, _tớ_
  { {0x98b80063,0xe9df002c,0xdb180052,0x0000006a}},	//   елят_, rnú_, _ilví,
  { {0xc5fb005d,0xe9df0f45,0x8c1b000a,0x660d00da}},	//   ्ष्य_, snú_, _זוגי, wmak
  { {0x7c22003f,0x4422199c,0x2bf7000a,0xd5bb46ba}},	//   _huor, _auk_, _רמון_, пса_
  { {0xc5f8000d,0x660d0035,0x7c220df8,0xdcfb0085}},	//   еѓу_, umak, _kuor, uduć
  { {0x660d46bb,0xd7fb005e,0x63ae00bc,0xf3f10016}},	// [a1b0] rmak, _нуо_, _bobn, _ự_
  { {0xa2950036,0xd3710029,0x7c2202b9,0x660d46bc}},	//   казі, ؤها_, _muor, smak
  { {0x660d189d,0xd1310115,0xdb03013f,0xeb91000a}},	//   pmak, لما_, _koná, יָא_
  { {0x3e4c0089,0x3a370053,0x2127002b,0x3035004a}},	//   dět_, גראם_, ريتی_, ведё
  { {0x7c221203,0xf8b3005d,0x690c000a,0x74150021}},	//   _nuor, ुनिय, ִּדְ, _لوحا
  { {0x25a92984,0x6e214311,0xdcf90535,0x7dde01ec}},	//   ljal_, _pulb, _gawę, bīsk
  { {0xbea50238,0xdfce012c,0x9e090015,0x0000006a}},	//   тайк, تيو_, ويتك_,
  { {0xc69400f3,0xbbb9000b,0xdcf9002a,0x442201d7}},	//   ראק_, इस्क, _zawę, _yuk_
  { {0x6d4204f9,0x116a0086,0x1c420010,0x7c2204ed}},	//   _deoa, _تلقی_, аным, _cuor
  { {0x25a90020,0x3e4c0046,0x6e2146bd,0x8b9538b6}},	//   hjal_, bět_, _tulb, трич
  { {0x2b58002a,0xed51002b,0x25a93c58,0xaceb009a}},	//   órca_, _نپا_, kjal_, _کرال_
  { {0x7c2204ed,0x3eba00cb,0x25a90030,0x6d4246be}},	//   _fuor, øpte_, jjal_, _geoa
  { {0xef180024,0x9b950029,0xbb850015,0x25a9007c}},	//   _daļu_, _للإت, _للشي, djal_
  { {0xcd04005e,0x25a900bc,0xd75a0015,0x442246bf}},	//   _спій, ejal_, بلست_, _ruk_
  { {0x7c2200b8,0xb9c60015,0x461a0033,0x63ae06f2}},	//   _zuor, _لتظه, дцаў_, _robn
  { {0x442246c0,0x2d8d46c1,0x63ae3e60,0x0000006a}},	//   _puk_, ndee_, _sobn,
  { {0xf484002b,0x62950077,0x2d8d007c,0x63ae0034}},	// [a1c0] دازی, _arzo, idee_, _pobn
  { {0x35c6000b,0x25a9007c,0x442242f6,0xf2da0015}},	//   रोज़, ajal_, _vuk_, وظات_
  { {0xdb0300dc,0x69c60020,0x20020007,0x599a000a}},	//   _elnö, ohke, _ūkio_, ֽשְׁ
  { {0x3e4c0089,0xf41f008c,0x442246c2,0x0000006a}},	//   vět_, _isän_, _tuk_,
  { {0x4153042b,0xf99300f3,0x64430085,0xe165006e}},	//   рвіс, ירא_, ćnic, ادمي
  { {0x3e4c0089,0xdb1a007c,0x9f8a007c,0x65641ca2}},	//   tět_, mitö, _lööb_, lgih
  { {0x7c22022d,0x5ea40086,0x22160010,0xb7db000a}},	//   _suor, امعل, _афар, וקסי
  { {0xd6570008,0x6d0d000b,0x656446c3,0x0000006a}},	//   דיקת_, ाइंग_, ngih,
  { {0x7dde0024,0xc157000a,0x11d70015,0x6d42007c}},	//   nīsi, _ששמו_, _شوكة_, _veoa
  { {0x7c2200f2,0x3e4c0089,0xdb031730,0x0000006a}},	//   _vuor, pět_, _soná,
  { {0xdea30086,0xdb1a007c,0x0ba30033,0x735b000a}},	//   _نیوی, hitö, ршым, וכיח
  { {0x7c2200f2,0x3ed90053,0xad65002b,0x61e246c4}},	//   _tuor, _אַנא, _ماهه, nnol
  { {0x7c2d0064,0x6c54000d,0xfbcf0086,0xdb030030}},	//   _çarp, _склу, صتی_, _voná
  { {0x7dde0048,0xe7300029,0x6b8a02de,0x69c6080d}},	//   dīsi, قصف_, _uafg, ahke
  { {0x8c1b103d,0x25a90020,0xf1b900bc,0x2ef8000a}},	//   _קווי, tjal_, _hiše_, גִּב
  { {0x69c6018b,0xdb1a1421,0x65640035,0xf1b900b3}},	//   chke, chtá, ggih, _kiše_
  { {0x3375001e,0xa5f8385e,0x61e246c5,0x25a946c6}},	// [a1d0] лгар, тету_, dnol, rjal_
  { {0x389a0008,0x6295005c,0xd498006b,0x25a9007c}},	//   _ניתנ, _przo, ърс_, sjal_
  { {0x387e0011,0xf60b0015,0x3f8e0034,0x798d02f2}},	//   ătre_, _يتجه_, ddfu_, _kaaw
  { {0xfb150053,0x3ab90053,0x61e246c7,0xdb1a1ca8}},	//   אַנט_, עמײנ, gnol, bitö
  { {0xd5b10023,0x80cd005d,0x7fd502e1,0x853a000a}},	//   ếu_, _देखे, лікі, _רגשי
  { {0x61e20026,0x6f64005e,0xc4d2000a,0x6295002a}},	//   anol, ивіз, _פגם_, _trzo
  { {0x2f540036,0x9e6400c3,0x661d46c8,0xa3d401c5}},	//   ртіс, لاين, _kisk, _торч
  { {0x2c6b0293,0x8e760015,0xf1b90085,0x644d008c}},	//   tød_, اميذ_, _biše_, osai
  { {0x40590002,0x53b7000b,0x442900aa,0x2d910046}},	//   _سلاح_, _आकाश, nqa_, ěze_
  { {0x3f8c0024,0x2d8b01b2,0x5f74002b,0x9f8a007c}},	//   _gadu_, žce_, _نامر, _sööb_
  { {0xd3a8000a,0xd9460df0,0x7dde003d,0x5d75006b}},	//   דֹרֹ, лени, zīsi, _булф
  { {0x82760053,0x9b45002b,0x7c950067,0x661d46c9}},	//   נערע_, خنگو, _مشتا, _nisk
  { {0x256d0030,0xdb1a007c,0x644d003d,0x4c99000a}},	//   zóló_, ditõ, jsai, _רֹ֣א
  { {0x6c520124,0x8b940063,0x644d007c,0x661d46ca}},	//   _укљу, _връч, dsai, _aisk
  { {0xed590107,0x661d46cb,0xd6da002b,0xe9da029f}},	//   akže_, _bisk, رورش_, _пкк_
  { {0x7dde0048,0x88861c86,0xdb1a007c,0x6d4900da}},	//   tīsi, _ближ, titö, naea
  { {0xb0d2005d,0xb97b000a,0x69c446cc,0x9f5e0016}},	// [a1e0] _देंग, _טנקי, _ilie, _kitô_
  { {0xdd0300df,0x798d005c,0xdb030152,0xdb1a0fb2}},	//   ūrėk, _zaaw, _conç, ritö
  { {0x50d60074,0x7afd005c,0xd7bb000a,0x69c446cd}},	//   گزار, ęstw, _נצטר, _klie
  { {0xd5b10023,0xc3290008,0xf1fa0015,0x249f0085}},	//   ết_, לו_, رعات_, _šume_
  { {0x7bc30005,0x935a0001,0x3f8c46ce,0x69c4006f}},	//   _olnu, _прву_, _padu_, _mlie
  { {0x661d0227,0x0877004c,0xdb030527,0x78a9007c}},	//   _zisk, רעסט_, _gonç, äevi
  { {0x63aa002e,0x03d7039e,0xc616000a,0x91e60054}},	//   öfnu, _עולם_, ְחִי_, _бове
  { {0xbdb4009c,0xf1b901a3,0x3f8c0034,0x7afc007f}},	//   рбиј, _piše_, _wadu_, ürtm
  { {0x9b6a006b,0x6b810028,0x7bc613b3,0x7cd7009b}},	//   ншна_, felg, ūkum, лмър_
  { {0xf1b9010b,0xef910086,0xe0d70054,0x69c446cf}},	//   _više_, _ویند, _сву_, _alie
  { {0x69c400b8,0x8cd4000b,0xdd8f0004,0xb9b50015}},	//   _blie, _बेरो, _лш_, لمدع
  { {0xf2d3000a,0xd915004a,0xf1b90de8,0x8c461adc}},	//   מעת_, идны, _tiše_, _беде
  { {0x201e46d0,0x6fb8000b,0x91bb000a,0x05b8000b}},	//   _kiti_, _अवां, תמכי, _इक़ब
  { {0xdb1800dc,0xc7c7006b,0xa635005e,0x69c446d1}},	//   _elvá, усми, ингі, _elie
  { {0x8f9b0008,0x7bda26a2,0xe5b50033,0x69c40b20}},	//   עילי, mitu, айвы, _flie
  { {0x69c4285f,0xa3d7000b,0x7bda074e,0x201e46d2}},	//   _glie, ़ोन_, litu, _liti_
  { {0x24580080,0x24550086,0x03d50839,0x661d46d3}},	// [a1f0] лать_, شناس, ажаю, _visk
  { {0x36d50860,0x201e01a3,0x661d0150,0xa5bb002a}},	//   _воор, _niti_, _wisk, _siód
  { {0x644d46d4,0x7bda0020,0x7afd0089,0xd404034e}},	//   ssai, iitu, řstv, сяти
  { {0x7bda0523,0x6b810399,0xa1190015,0x50b53878}},	//   hitu, zelg, نقاط_, ислу
  { {0x201e060b,0x7bda46d5,0xa0a50515,0x10a50aed}},	//   _biti_, kitu, ралд, рилн
  { {0x90280010,0x201e46d6,0x7e5515be,0x200c0416}},	//   уцца_, _citi_, атиц, _chdi_
  { {0x74d9005d,0x7de10024,0x6b8146d7,0x7bda46d8}},	//   _नेतृ, lēsi, velg, ditu
  { {0xf2d20008,0x201e0007,0xc537000a,0xd62c000a}},	//   _ועל_, _eiti_, נָ֔ה_, ע֥וֹ
  { {0x7bda3d66,0x212a002b,0x8bb50015,0xbf67012c}},	//   fitu, _شيلی_, لإدا, _مداو
  { {0xdab90010,0x764e0026,0x61e913e1,0x765c0034}},	//   вымі_, ysby, _hjel, yrry
  { {0xbf9a000a,0x7e9c0045,0x99d60015,0x8f9a000a}},	//   _שיעש, _căpă, لتحا, _שיעי
  { {0x7cd90004,0x6b8146d9,0x6e3a004f,0x0000006a}},	//   _имер_, selg, _יתעד,
  { {0x91f60008,0x69c4016b,0xdb1a008c,0x7bda0f4b}},	//   שמרו_, _vlie, ehtä, bitu
  { {0xd5eb0092,0x7d060064,0x7bda0a28,0x7de10024}},	//   _đíc, ükse, citu, dēsi
  { {0x8f880008,0x61fb2442,0xe6b2000b,0xa2d5000b}},	//   נְשֵ, _okul, ीनेज, _येल्
  { {0xceb20008,0x39360010,0x96630063,0x69dd3959}},	//   חיל_, _тэкс, юксе, éret
  { {0x9f5e00f2,0xf9fb000a,0x741600c3,0x79fb000a}},	// [a200] _yhtä_, _בהקמ, لورا, _שלפח
  { {0x80a6002b,0xbb48004c,0xb2960054,0x2d8f46da}},	//   یمان, ָנאַ_, ијећ, _lage_
  { {0xa75b000a,0x61e946db,0x201e46dc,0x16070065}},	//   _בדיר, _bjel, _riti_, _वीवर_
  { {0xea7600b2,0x61e9016f,0xc05a042b,0x7bda46cc}},	//   יגער_, _cjel, вік_, zitu
  { {0x61e9010b,0xe523005e,0x7de1003d,0x201e46dd}},	//   _djel, _єдрп, cēsi, _piti_
  { {0x7c24002f,0xdfcf00e5,0x3ce020a3,0x7e540015}},	//   _éiri, وين_, _živo_, منتص
  { {0x61e90af5,0x7bda46de,0xeea7006b,0x7e98002b}},	//   _fjel, vitu, итък_, انبر_
  { {0x61e906f5,0x420a005e,0x6e97006b,0x1d34006b}},	//   _gjel, _рнбо_, рвър_, щния
  { {0x2d8f00fb,0xbc6706e4,0x6c830015,0xe571000a}},	//   _dage_, لمين_, قليم, הַי_
  { {0x90e50086,0xc5e3000b,0xdb1a005b,0x0000006a}},	//   _اسفن, _गद्य_, yhtä,
  { {0xbeaa04b6,0x7de10024,0x8ae60036,0xfba70033}},	//   _جهان_, zēsi, ріпл, ртый_
  { {0xdebb000a,0x7bda46df,0x7edb000a,0xf1b90085}},	//   _שמאל, situ, _בקבצ, _kiša_
  { {0x6c340086,0xedf50086,0x6e280107,0x48e40033}},	//   _افتا, _اينگ, _hudb, жоўв
  { {0xdcfb01e2,0x2d8422d2,0xc7c40080,0x1cbb000a}},	//   lduğ, leme_, осси, _במדע
  { {0xba540015,0x66b40004,0x394b01c2,0x5559006b}},	//   _انبع, обру, pacs_, лавя_
  { {0xdcfb01e2,0x59d40029,0xf99f0251,0x1da9000b}},	//   nduğ, _وغير, rmès_, कायत
  { {0x54990010,0x69dd074e,0x600d0077,0x64a40004}},	// [a210] ываў_, mise, lúme, оаѓа
  { {0x7de10048,0x61e913e1,0x69dd46e0,0x2d8446e1}},	//   rēsi, _sjel, lise, heme_
  { {0xe695003b,0x600d0084,0xa3d6000b,0x98140015}},	//   _الجد, núme, िफ़_, _ببيا
  { {0x2d843523,0x212a002b,0xa5bb0077,0x7de1003d}},	//   jeme_, هيمی_, _dióc, pēsi
  { {0x3949002d,0x60f8005e,0x2d8446e2,0xe4a70099}},	//   _meas_, анця_, deme_, _трно
  { {0x69dd2ba4,0x7dde0024,0x3949002d,0x70520015}},	//   hise, zīst, _leas_, أنوا
  { {0x320d03c2,0x4e950029,0x3dc6003e,0xee390001}},	//   _they_, إشتر, _blow_, ћни_
  { {0x63b500dc,0xd5b2000a,0x1c45005e,0x3dc646e3}},	//   _hozn, ִׁי_, бним, _clow_
  { {0x69dd0005,0x61f9002a,0xab291293,0x2d8f026c}},	//   dise, mowl, лопа_, _vage_
  { {0x78bd022d,0x6e28016f,0x2d8f00c7,0x69dd46e4}},	//   dysv, _fudb, _wage_, eise
  { {0x7dde0024,0x69dd46e5,0x2d8f46e6,0x3dc608b8}},	//   tīst, fise, _tage_, _flow_
  { {0xc9760029,0x39490011,0x2d840227,0x61f9055e}},	//   حادث, _ceas_, ceme_, nowl
  { {0x27f83c2c,0x31fa000a,0xec35004c,0x39490125}},	//   torn_, רִיע, _פאַר_, _deas_
  { {0x30da0053,0x40da0053,0x69dd46e7,0x2bc800e2}},	//   אַלע, אַלײ, aise, _кліп_
  { {0x96060015,0x857a2044,0x7afd002a,0xfa350040}},	//   مبرم, лсат_, ęsts, _ارتد
  { {0xd5b10023,0x249f0085,0x69dd1103,0x4a56000a}},	//   ếp_, _šuma_, cise, _השקל_
  { {0x64a30010,0x7bc10024,0x61f90305,0x7986003f}},	// [a220] пата, oklu, dowl, mekw
  { {0xd8d70053,0x79861865,0xf7860015,0xd764002b}},	//   _לופט_, lekw, _الدَ, _بندی
  { {0x79860111,0xdceb0024,0xce950024,0xdcfb0064}},	//   oekw, _angļ, šējā_, yduğ
  { {0x987a0053,0x6e2846e8,0x6f040046,0x629a026a}},	//   ָאַט, _rudb, řick, _átom
  { {0x9053008f,0xdfda0063,0x6e2846e9,0xc953000a}},	//   звіц, лък_, _sudb, למא_
  { {0x087700b2,0x3dc6003e,0xdfd00196,0x660446ea}},	//   מענט_, _slow_, بيت_, llik
  { {0x6f010026,0x69dd00f2,0x29d218df,0x2d8446eb}},	//   _cylc, yise, nšas_, teme_
  { {0x63b5002c,0x629c46ec,0x660446ed,0x0000006a}},	//   _zozn, _irro, nlik,
  { {0xdcfb0064,0x91bb000a,0x69dd46ee,0x660446ef}},	//   rduğ, _עממי, vise, ilik
  { {0xdee60431,0x66040064,0x2d840020,0x672102c6}},	//   _лози, hlik, seme_, žlji
  { {0x6f010026,0x29040064,0x7c3b0026,0x5f370008}},	//   _gylc, üman_, apur, _הטבע_
  { {0x59f90080,0x78bd00f2,0x7bc100d9,0x2489002a}},	//   ремя_, tysv, aklu, ywam_
  { {0x660446f0,0x7d23002b,0x98740033,0x600d0077}},	//   dlik, _عفون, пляц, súme
  { {0x7bc1018b,0xcc5700f3,0x69dd46f1,0x6d4004d2}},	//   cklu, _פסוק_, sise, lbma
  { {0x98a501e2,0x37740010,0x7bdb000f,0xdb0a0030}},	//   ğlı_, чыўс, _תקוו, _alfö
  { {0xaae50029,0x98a50064,0x55750033,0x660446f2}},	//   _بسهو, şlı_, ўгат, glik
  { {0x54550191,0xb4b5005d,0xf92a0053,0xe9df002d}},	// [a230] юват, ड़ने_, _דופּ, miú_
  { {0xe4d4003b,0xe9df002d,0x6e220125,0x660446f3}},	//   ستقب, liú_, _liob, alik
  { {0xe2350004,0x69c00030,0x63b5438b,0x660446f4}},	//   цнењ, ömeg, _vozn, blik
  { {0xe9df002f,0xdb03002c,0x225c0107,0xd14b002b}},	//   niú_, _ponú, ávka_, اشان_
  { {0x628e46f5,0x629c050d,0x6ff50015,0x7ff50040}},	//   _esbo, _erro, يستط, يستا
  { {0x443903c2,0x4fe80036,0xb4fa000a,0x7986002a}},	//   _its_, бмін_, _כפרי, zekw
  { {0xdfcf0074,0x2fd60015,0x7ff40015,0x1e85005e}},	//   ويچ_, توود_, أسنا, ілим
  { {0x44230298,0xf8bf46f6,0x6e220045,0x11d40058}},	//   _hij_, ncés_, _ciob, _فتقد
  { {0xe9df002f,0xdb1a002d,0xa3b0000b,0xf1b900bc}},	//   diú_, chtú, टॉक_, _hišo_
  { {0x69dd0152,0x7986003f,0x442b002d,0x442317d9}},	//   èren, wekw, _muc_, _jij_
  { {0xdd8e0074,0x656f04ed,0x44230111,0x661600f2}},	//   روی_, _occh, _mij_, ymyk
  { {0x7c3b46f7,0x7bc146f8,0xdef6000a,0x64430085}},	//   ppur, sklu, _ומעט_, ćnij
  { {0xa17a0053,0x6bd50015,0x6d4b003d,0xf98a002b}},	//   סטשט, _وتتر, _iega, هنگي_
  { {0x61b6014e,0x657d00e8,0xaa450189,0x656f01e0}},	//   _अक्ष, _absh, _декл, _acch
  { {0x3f870cd4,0x6d4b0509,0x660446f9,0xc9f60015}},	//   ienu_, _kega, tlik, _وسبع
  { {0xa3d7014e,0xcb120008,0x7c231a15,0xe5a307d5}},	//   ़ोस_, _קלה_, _hinr, миси
  { {0x44230a9c,0x6d4b46fa,0x3f8712ef,0x660446fb}},	// [a240] _bij_, _mega, kenu_, rlik
  { {0x660443ac,0x3f87016f,0xe73a0001,0x6d4b46fc}},	//   slik, jenu_, _њен_, _lega
  { {0x443946fd,0x4256006b,0x6d59002a,0xe29702ec}},	//   _ets_, ютат, _odwa, жах_
  { {0xf6530008,0xda7a0053,0xf8bf0144,0x64a6176c}},	//   _קצר_, ינער, ccés_, _дама
  { {0x10470063,0xbfaa007e,0x7c2b46fe,0xb623002b}},	//   оящи_, итке_, _nugr, _ﺩﺭ_
  { {0xc0590191,0x44230111,0x7de10024,0x6d4b0020}},	//   сії_, _gij_, zēst, _aega
  { {0x60040251,0x6d4b0334,0x8790002b,0x51860015}},	//   nòmi, _bega, ﻟﮑﻴﺖ_, _وشرق
  { {0x44230298,0x5d5413ab,0x463b0053,0xbdf70015}},	//   _zij_, чкит, בעקע, يريا_
  { {0xab5c0024,0x4f5a0029,0xd12f0015,0x7de1003d}},	//   ekļa, _نجاد_, _شمل_, vēst
  { {0x547b000a,0x6d5946ff,0x3f8704c1,0x3206069f}},	//   סטיו, _edwa, cenu_, lloy_
  { {0xba0b0063,0xe9df002d,0xc33304dc,0xce35002b}},	//   ихме_, tiú_, וות_, _فولک
  { {0x7c2300b8,0x9e65002b,0xbca60015,0xdd90002b}},	//   _einr, _رامن, _وماي, _سوت_
  { {0xe9df002f,0xec77000d,0xd90f002b,0x1d070054}},	//   riú_, _мпц_, کیک_, _деци_
  { {0x29050048,0xe9df002d,0xf8ae0086,0x6d4b005c}},	//   āla_, siú_, چکی_, _zega
  { {0x163b003b,0x7c2b00b8,0x454b0063,0xf8ae0086}},	//   ؤسسة_, _zugr, ичам_, نکی_
  { {0x442b08e0,0xa4d50036,0xca830029,0x2a57000a}},	//   _puc_, побі, _آليً, _ובהן_
  { {0x69c00020,0xf8bf0140,0x44230e2a,0x26c54056}},	// [a250] ömee, rcés_, _pij_, šlo_
  { {0x2915005c,0x33d4005e,0xad1b000a,0xb8e10157}},	//   ądać_, мієт, שומר, ून_
  { {0x3f874700,0xaaca000b,0x4bfb004f,0xe53500ce}},	//   venu_, ानिक, סלבס, _нень
  { {0x44230111,0xd1b80115,0xe2900015,0x3264005e}},	//   _wij_, يانا_, خذك_, ьтув
  { {0x3f870152,0x8fa502e5,0xc0c80001,0x7655005c}},	//   tenu_, зале, жује_, lszy
  { {0x94ba013a,0x9f474701,0x351a000a,0x7655002a}},	//   _המשת, onné_, _לורנ, oszy
  { {0x7c2b0007,0xed590802,0x9758000a,0x6d4b4702}},	//   _sugr, бой_, קיהו_, _pega
  { {0x656d4703,0x8d750029,0xc05b0015,0x01340015}},	//   ngah, سابا, _نشطا_, _يعقد
  { {0xdb03002f,0x20540080,0x6d4b2456,0x4c82004a}},	//   _inné, _октя, _vega, елыв
  { {0xcb690001,0x7c2d0125,0x7655002a,0xce95006b}},	//   љане_, _éarm, kszy, _назъ
  { {0x7655005c,0xc8690008,0x7c950086,0x3dcd00da}},	//   jszy, _תן_, زشکا, phew_
  { {0xf1b9010b,0x22470264,0x7655002a,0x61eb0012}},	//   _još_, ánky_, dszy, nngl
  { {0xbc190010,0x2904002e,0xa3ae005d,0x7655002a}},	//   _лікі_, æma_, काम_, eszy
  { {0x4c9a000f,0x9d1a000a,0xf1b90085,0x8cd4000b}},	//   _לבנו, _פוסט, _loš_, _बेटो
  { {0xbb3a004c,0x4bd8002b,0xab760015,0xfaf70058}},	//   _פעקי, _ببند_, _رميا_, _بأشخ
  { {0x09fa0029,0x25a607dd,0x3ce00263,0x060a0033}},	//   _دفعة_, ñol_, _živi_, ёнак_
  { {0x2ea8005d,0x7655005c,0xe5060015,0xbb75000a}},	// [a260] _कप्त, aszy, سبري, ּעֲו_
  { {0xdb03038d,0x18770008,0x317f0011,0x389b00a3}},	//   _anné, _צעיר_, _abuz_, _פיינ
  { {0x67bb0008,0xd36f0806,0x91e6023e,0xf1b900bd}},	//   _המיק, اهم_, поже, _boš_
  { {0x69c63ff5,0x59af000b,0x216a09d9,0x20074704}},	//   nkke, टायर, сиди_, elni_
  { {0x859b0008,0xd00a1179,0xb033005e,0xa0670a9d}},	//   _השכו, беде_, еніш, зача_
  { {0xdb0300dc,0x987b004c,0xa857000a,0x61eb4705}},	//   _enné, מאנט, לינה_, angl
  { {0x3206003e,0x20020091,0x61462124,0x6b8801de}},	//   ploy_, _ūkis_, _нева, vedg
  { {0x200710a4,0x0000006a,0x0000006a,0x0000006a}},	//   alni_,   ,   ,
  { {0x69dd0152,0x5c060010,0xc3340008,0x4df1000b}},	//   èrem, зяна, ֽוֹ_, ँकड़े_
  { {0x6f66000d,0xfbaa0142,0x7655002a,0x656d0061}},	//   _ѕвез, стий_, yszy, zgah
  { {0x7f3b000a,0x765a0007,0x28cf000b,0xeb970004}},	//   _העבו, štyj, सैनि, чиќ_
  { {0x61e24706,0x394d0077,0xdd8f002b,0x6456005b}},	//   niol, úes_, _موم_, ksyi
  { {0x3d2b0074,0x7655005c,0x1da9000b,0x60c20030}},	//   _اتمی_, wszy, कारत, nyom
  { {0xfbcf0029,0x61e20026,0xcce50029,0x645600dd}},	//   _متى_, hiol, _تسمي, dsyi
  { {0xdb7b013a,0x4b7b20c1,0x1b7b000a,0x5b7b000a}},	//   _הנוכ, _האוו, _הטוע, _הרוא
  { {0x7655005c,0x69c600b8,0x644a002a,0x9f47006f}},	//   rszy, ckke, ćfin, rnné_
  { {0x99f80008,0x39780029,0x57f53c2f,0xf9050086}},	// [a270] _מזהה_, _رصيد_, _опит, _تأثی
  { {0xa3d7014e,0x7655005c,0x274b0054,0x47350121}},	//   ़ों_, pszy, _учио_, _юнос
  { {0xd6280004,0x69cd042f,0x645601c2,0x61e22e87}},	//   _ноќе_, _klae, asyi, fiol
  { {0x68e20007,0x27e30111,0xe1340033,0xe664005e}},	//   _žodi, lijn_, енцы, _ятьо
  { {0x69cd0026,0x9475002b,0x759a000a,0x859a000a}},	//   _mlae, _تگزا, _וסרג, _ושרו
  { {0x69cd0026,0x8b070089,0xd24e002b,0xdfd40033}},	//   _llae, _jiří, _چچن_, ночы
  { {0xc33205af,0x69c64707,0x1da9000b,0x629a0085}},	//   _יום_, ykke, कालत, _štov
  { {0xf19405cb,0x27e30079,0x61e24708,0x3e5700d4}},	//   _пись, hijn_, ciol, răt_
  { {0xcf270067,0xd0e9002b,0x0000006a,0x0000006a}},	//   _فراي, _بکام_,   ,
  { {0x0ae90080,0x69cd0020,0x3e570011,0x999f0091}},	//   ждой_, _alae, păt_, kstų_
  { {0x69cd0176,0xa3ae021e,0x5336000a,0x6ff40015}},	//   _blae, कात_, ונתן_, _أسقط
  { {0x4efa000a,0x88e60839,0x929a000a,0x69c64709}},	//   _והעו, джме, קירת, ukke
  { {0x69c6022d,0x31560053,0xc156000a,0xca74002b}},	//   rkke, וירן_, ושרו_, ونیک
  { {0x38330033,0x8b030046,0x61e22323,0xd62a009b}},	//   тнёр, ářsk, ziol, жове_
  { {0x2bda0086,0xf7720086,0x69cd0026,0x99d60015}},	//   _بانک_, _یاد_, _flae, _يتبا
  { {0xc9f60029,0x060a0033,0xe57a0033,0x1c380016}},	//   _تستع, інак_, ўза_, _hỗịc_
  { {0x14260146,0xe5e50015,0x4376004a,0x8cc3000b}},	// [a280] ддам, رثفي, дует, ाईटो
  { {0x836a0015,0x4cc8000a,0x645601c2,0x61e2028a}},	//   تصرف_, הֶעֱ, rsyi, wiol
  { {0x754900dc,0x6456008c,0xd25901c6,0x61e2470a}},	//   észü, ssyi, зці_, tiol
  { {0x9f5c0107,0x9ae8000a,0x55e600af,0x0000006a}},	//   mové_, הַנִ, _цомб,
  { {0x9f5c0f1b,0x61e239f0,0xf1a90058,0x20560993}},	//   lové_, riol, ثاله_, фтер
  { {0x2f140010,0xd0100015,0xdb03002a,0x4ea63de5}},	//   ндлё, دلت_, _jonó, дриа
  { {0x6e930036,0x9f5c0107,0xc246042b,0xfe6f0015}},	//   вищу, nové_, _інак, لدي_
  { {0x9186002b,0x27e30079,0x68f610ee,0x63bc470b}},	//   _تجسم, zijn_, _oxyd, _horn
  { {0x9f5c0057,0xbdf700c3,0xf41f0123,0x1b4a0015}},	//   hové_, بروا_, _isär_, يؤدي_
  { {0xdfa60070,0x9f5c0107,0x63bc470c,0x3fa60021}},	//   _تحري, kové_, _jorn, _تصرف
  { {0x2fd70002,0x9f5c0057,0x539b004c,0x63bc05ee}},	//   _تولد_, jové_, קסטא, _morn
  { {0xb2570008,0xceb301ac,0x9f5c0107,0x7afd0012}},	//   ובטח_, _שיף_, dové_, ßsta
  { {0x27e30111,0xae1b0053,0xeb9a004a,0x63bc00aa}},	//   tijn_, _וואכ, _мид_, _oorn
  { {0x9f5c0046,0xe784023b,0x4cb7004e,0x0000006a}},	//   fové_, кусо, _юлію_,
  { {0xabfb000a,0x9f5c0057,0xd5bb4014,0x1bfb000a}},	//   _והגר, gové_, оса_, _ולגב
  { {0xca2900b2,0xdb180107,0x8e97000a,0x1e97000a}},	//   _צופֿ, _nové, ודלו_, וכלל_
  { {0x84150063,0x27e30079,0x6b9806d1,0x63bc0252}},	// [a290] емах, pijn_, _kavg, _born
  { {0xcc770008,0x9f5c0f1b,0x6b9a02de,0xdb1a001a}},	//   וגמת_, bové_, ndtg, rktæ
  { {0xddc30011,0x2a6c00bd,0xf1b900bc,0x9f5c013f}},	//   nunţ, nudb_, _hiši_, cové_
  { {0x28c6014e,0x471a000a,0xf1b9005a,0x0000006a}},	//   रैकि, _מותג, _kiši_,
  { {0xb53a000a,0x653a004c,0x63bc470d,0x808b0015}},	//   _מגרש, _מערד, _forn, تضاف_
  { {0xdfd10029,0x63bc470e,0x1e950c5b,0xdb030144}},	//   طيع_, _gorn, ерир, _monò
  { {0xed590892,0x82340058,0xa282009a,0x0000006a}},	//   пой_, _لرقا, _میلو,
  { {0xbbb9000b,0x66ee0030,0xe1ff001a,0x63bc470f}},	//   ेस्क, lőké, _ðó_, _zorn
  { {0x9f5c0107,0x0cc9000b,0x9c2520b9,0xbbca0065}},	//   zové_, िनेम, ндид, िसूक
  { {0x7e2b005e,0xbe870015,0x4a4507d0,0x2fd90021}},	//   _діда_, _يجاو, ннов, _عواد_
  { {0x8b940010,0xdb1a0012,0x63b80123,0x2b14005e}},	//   трыч, chtü, övni, кьюр
  { {0x7e9a013a,0x9f47002d,0x82da004c,0x49ba0015}},	//   _מסעו, inní_, פֿיק, ساجد_
  { {0xdb03005c,0xa3c4000b,0x7cc70015,0x1c4401c6}},	//   _ponó, ौसम_, _تزام, _анім
  { {0x4cba013a,0xa5bb0014,0xe0d20053,0x9f5c0057}},	//   _מזנו, _fiók, רײך_, tové_
  { {0xb907014e,0xa3ae005d,0x28e0005d,0x8b76000a}},	//   _ये_, कास_, _पेरि, _נתקע_
  { {0xceb20008,0x9f5c0057,0x057a0015,0xbada000a}},	//   נין_, rové_, ثمرة_, _מקצת
  { {0x91690023,0x62870048,0x7de80089,0x9f5c0057}},	// [a2a0] _gửi_, _apjo, měst, sové_
  { {0xdb1a002d,0xa87b000a,0xdb18001a,0xdcea0085}},	//   chtó, _צריח, _sové, šiće
  { {0x599a01e4,0xa99a0008,0x3952003e,0x63bc4710}},	//   ּשְׁ, ּבְר, _keys_, _vorn
  { {0xfb1600b2,0x463b0053,0x78a40735,0x0000006a}},	//   ײַבט_, _מעטע, _kriv,
  { {0x63bc4711,0xd037005e,0xf993000a,0x67310046}},	//   _torn, езії_, טרא_, řejň
  { {0x7416006e,0x64444712,0x80a300c3,0x0000006a}},	//   _سوزا, mpii, امون,
  { {0x8e2605c4,0xaade000b,0xf773000a,0x6e18002b}},	//   нфид, _फेंक, אקו_, ويتس_
  { {0xa3ae005d,0x2492005c,0x20050061,0x249f0085}},	//   काव_, owym_, _ekli_, _šumi_
  { {0xd1750033,0x6444008c,0x3157000a,0xc157004f}},	//   _шыры, npii, _רימן_, _רשמו_
  { {0x9d130010,0x3a290049,0x5477004c,0x539b000a}},	//   ыдыч, _siap_, עגיע_, ִיכו
  { {0xdd8f002b,0x5ffb004f,0xf44d00af,0x442a4713}},	//   _گون_, _צהבה, циjу_, _mib_
  { {0x7df30045,0x66ee0030,0x3f8e001a,0xddc30045}},	//   păsa, zőké, lefu_, runţ
  { {0xdd8f003b,0x8c430054,0xc02e0016,0x7dbb000a}},	//   _دون_, _бече, _điểu_, _מצאצ
  { {0x7aeb00dc,0x78a44714,0xf1b90085,0x38640030}},	//   áltá, _driv, _viši_, ámra_
  { {0xdb9b0008,0xeb97000d,0x78a40e95,0x3a29013c}},	//   _מסגר, _чиј_, _eriv, _tiap_
  { {0x4a53006b,0x4974006b,0x442a31c0,0x65942921}},	//   _скъс, _блъс, _aib_, ласу
  { {0x7c2a003f,0x24f80256,0xa4d4005e,0x69fc000a}},	// [a2b0] _kifr, енты_, готі, _מלהק
  { {0x6672002b,0x799d4715,0x0000006a,0x0000006a}},	//   دگیر, ldsw,   ,
  { {0x0736000a,0xa195005e,0xe3b00015,0xe3300016}},	//   _באתם_, кажч, حرق_, _đuổ
  { {0x7dde121a,0x66ee0030,0xd0410033,0xe4e700ce}},	//   būsi, sőké, аўкi_, _зігн
  { {0xa3ae000b,0x660d4716,0x799d0079,0x0000006a}},	//   काश_, mlak, idsw,
  { {0xdee5209b,0xf8380008,0x660d4717,0x442a01f1}},	//   коли, ענות_, llak, _gib_
  { {0xa3ae014e,0x1798000a,0x6e920015,0x660d0535}},	//   कार_, גדול_, للوا, olak
  { {0x4c850080,0xce180010,0xcee80015,0x660d0312}},	//   влив, нцыі_, عرون_, nlak
  { {0x660d0049,0xc8e0000b,0xe572000a,0x7de80046}},	//   ilak, _पेंट, בַת_, věst
  { {0x30180015,0x7c2a4718,0x660d140c,0x98b90073}},	//   _كتلة_, _cifr, hlak, lasė_
  { {0xa96a0c5b,0x7de80046,0x7c2a4719,0xda65006b}},	//   мина_, těst, _difr, ъвни
  { {0x6016001c,0x5ee8000a,0x8d740067,0x59830033}},	//   râme, _אַנְ, _ماها, алюб
  { {0x1a65002b,0x6d49471a,0x515a000a,0x660d471b}},	//   ریکی_, mbea, וכרו, dlak
  { {0x290c0024,0x9cd6000a,0x660d471c,0x9056000a}},	//   āda_, _בונה_, elak, כבשו_
  { {0x07a30180,0xa3b5000b,0x645d471d,0x442a471e}},	//   јасн, झान_, _avsi, _rib_
  { {0x660d0035,0x78a41fb7,0x644f0034,0xc563033d}},	//   glak, _triv, _bwci, икск
  { {0xa3ae005d,0x644f0026,0xbeee000b,0x70bd000b}},	// [a2c0] काल_, _cwci, _जश्न_, ्नोल
  { {0xa3dc014e,0x7c2a0251,0x6e2b00aa,0x660d471f}},	//   तों_, _xifr, _ligb, alak
  { {0x660d00dc,0x64440209,0xd54a0054,0xd12f171b}},	//   blak, spii, _опне_, их_
  { {0x3aba00b2,0x504605e6,0x442a4720,0x7aba000a}},	//   ומענ, ведб, _wib_, וצעו
  { {0x644f0034,0x7afd002a,0x6d491a0f,0xf1b90160}},	//   _gwci, ęsty, dbea, _nišu_
  { {0x14d70008,0xe1230054,0x73370033,0x6604008c}},	//   _יוכל_, јмљи, _азёр_, loik
  { {0x539b0008,0x3f8e26cc,0x55bc004f,0x7c2a01e0}},	//   _קילו, refu_, ּמ֖ו, _rifr
  { {0x660400f2,0x2bca005d,0x3f8e003f,0xbbca000b}},	//   noik, िस्थ, sefu_, िस्क
  { {0xdb0a0152,0x8c430004,0x6e2b12a8,0x60160045}},	//   _infé, аење, _digb, râmb
  { {0xc332000a,0x660d002a,0x6489004f,0x5ba64721}},	//   יו֙_, zlak, תְקְ, триз
  { {0x9e650074,0x6d49031c,0xcf260015,0x5d860015}},	//   _مانن, bbea, _شرطي, _للال
  { {0x799d0079,0x7a3e003d,0x9e77000a,0x245d0046}},	//   udsw, _rītd, _יגבה_, námý_
  { {0x09e40010,0xc867006b,0x98b8005e,0x984b09b1}},	//   роўн, ътни, влят_, ьяна_
  { {0x5ba3010f,0x95c5002b,0x9f5c0046,0x0000006a}},	//   _връз, گيره, koví_,
  { {0x660d0014,0x27ed010b,0x45d50419,0x6d5d001a}},	//   tlak, đen_, говс, ðsag
  { {0x27ed00dc,0x59670063,0x95c50015,0x8ab7000a}},	//   ően_, _ръка, ديره, _יהוו_
  { {0x08fb0029,0x24580080,0x660d0375,0xdb180077}},	// [a2d0] _ترغب_, кать_, rlak, _moví
  { {0x93270086,0x9cd70008,0x92eb0015,0x03d4005e}},	//   نران, דומה_, وراق_, ажую
  { {0x6d4900da,0x660d4722,0xdb18004f,0xd1310058}},	//   ybea, plak, תֵּך, مما_
  { {0xa1150029,0xa3d7000b,0xcad7000a,0xdb18006f}},	//   هوات, ़ोज_, כובת_, _noví
  { {0x07f80086,0xe0d00018,0x30850015,0xa06909d3}},	//   _سریع_, يزه_, التف, хала_
  { {0x6e2b00dd,0xe816000b,0x828b005e,0x9f5c00bf}},	//   _sigb, णतया_, _осбб_, boví_
  { {0x2eb40063,0xc2930086,0x82d5005e,0xdb1a006f}},	//   исъс, _خیاب, _совє, aktú
  { {0xf1a4009c,0xd2290015,0x2ca64723,0xf1b90085}},	//   _крун, _أكره_, _brod_, _pišu_
  { {0xcc890086,0x4421002d,0x39593b3b,0xcd28002b}},	//   رنده_, omh_, dass_, پسين_
  { {0xd9cc005d,0x60c400f2,0xf1b90085,0xdb034724}},	//   ास्ट, äime, _višu_, _anná
  { {0x4421002d,0x03d6000a,0x39ea05b1,0xcc080015}},	//   imh_, רותם_, едно_, خزين_
  { {0x186a087a,0x3959180d,0x64400003,0xceb20643}},	//   нами_, gass_, _émig, _ליב_
  { {0x8d5a000a,0xcb6904ab,0x0cd4005e,0x765c0034}},	//   _נכסי, _зале_, _коцю, wsry
  { {0xaae4002b,0x2d9d086c,0xed590085,0x66e61534}},	//   اسیو, _hawe_, laž_, гога
  { {0xf7430063,0xcb560008,0xf7530015,0xa7a70033}},	//   сесо, _עסקה_, إنفج, ыкра_
  { {0x29560063,0x2d9f4725,0xfaf00058,0x69dd01f6}},	//   _съкр, ndue_, _بثه_, èret
  { {0x2d9d003f,0xd46720f1,0xe5a306b9,0x66044726}},	// [a2e0] _mawe_, лите_, щити, roik
  { {0x660400f2,0x600d001a,0x9f5c00bf,0xc8db004f}},	//   soik, búmi, toví_, _נקיט
  { {0x8b5600b2,0x6604008c,0x7413006e,0xed590046}},	//   ריעס_, poik, حولا, kaž_
  { {0xc69300b4,0x72290036,0x4421002d,0x2e380152}},	//   _פאר_, вців_, amh_, _réf_
  { {0x11d70015,0xe1370033,0xc977000a,0x6098002b}},	//   دونة_, узіі_, רגני_, ئنتس_
  { {0xc0590036,0x25a00020,0x9f5c0046,0x2d830030}},	//   тії_, ldil_, poví_, őjel_
  { {0x25a0242b,0xdb180089,0xe357000a,0x7413002b}},	//   odil_, _poví, _תשלח_, _طوفا
  { {0x25a00020,0xd5b30008,0x1d340063,0xdcba0758}},	//   ndil_, ֶׁת_, шния, ещо_
  { {0x24804727,0xa3ae000b,0x7f46123e,0x621b004f}},	//   ntim_, काऊ_, _безж, _טולק
  { {0xe47b0008,0xdfa9002b,0x747b004c,0x547b004c}},	//   עריכ, _لطمه_, עניג, עטיו
  { {0x83b7004c,0x1604000b,0x2d9f00da,0x39590030}},	//   אפיע_, लवार_, bdue_, tass_
  { {0x2e160029,0x7dde0024,0x9e650015,0x2d9d01d7}},	//   _صباح, gūst, _ضامن, _gawe_
  { {0x8d93002b,0xa5bb0030,0x25a000e7,0x39590bbc}},	//   _دلنش, _miót, ddil_, rass_
  { {0x7d060020,0x3959047f,0xcec30535,0x25a0013b}},	//   üksu, sass_, _więź_, edil_
  { {0xa3ae000b,0x8b57000a,0x39594728,0x07e400e2}},	//   काई_, _גיוס_, pass_, сцям
  { {0x4a7b0008,0xf9930040,0x9a670015,0x3ce90091}},	//   _נרחב, _طبع_, _إميل_, _žavi_
  { {0xdce9006f,0xddab000a,0x95540015,0xc35503ae}},	// [a2f0] zdeľ, עֱלָ, إخفا, икај
  { {0x25a024ec,0x44980138,0x657601d3,0x0000006a}},	//   adil_, ывую_, agyh,
  { {0x92950010,0x17f80029,0x93880010,0x82a70080}},	//   раец, _حرية_, ыста_, ышае
  { {0xe45f002e,0x9f470152,0x69cf0046,0xe1ee005e}},	//   _tvö_, miné_, nkce, іг_
  { {0xe4c7008f,0x2480003e,0x3f9e08c0,0x25f4000b}},	//   _сённ, ctim_, _batu_, ्करी_
  { {0xa85800a3,0x3f9e01d7,0x8fa54729,0xfe45153d}},	//   ריגה_, _catu_, раке, анко
  { {0x9e640086,0x3f9e472a,0x2778000a,0xe7f8000b}},	//   ماين, _datu_, אגון_, ूकता_
  { {0x2d94004a,0x3d19000b,0x601600d4,0x0000006a}},	//   брьс, _परदे_, râma,
  { {0x61eb02d7,0x25d8004c,0xed5900b3,0xe588000a}},	//   migl, טוהן_, raž_, אָתָ
  { {0xa5bb002d,0xa2f5000a,0x5f740015,0xa3ae000b}},	//   _fhóg, ֹמֹה_, _هامر, काए_
  { {0xb6040007,0x2d9d0034,0x7dd53b06,0x3b090054}},	//   ūšiu, _tawe_, _cásc, ђемо_
  { {0x82760053,0x61eb285f,0xdeba000a,0x2007472b}},	//   סערע_, nigl, _במעל, loni_
  { {0x20070005,0x9f5c099c,0x7645002e,0x6d5b01d7}},	//   ooni_, lová_, _athy, maua
  { {0xfaa5327e,0x2007472c,0x61eb02b9,0x37760033}},	//   _вако, noni_, higl, шымс
  { {0x9f5c0057,0xca73002b,0x65c6006b,0x9f470140}},	//   nová_, _انعک, абва, giné_
  { {0x7bc30084,0x75d60029,0x8afa000a,0x3703005e}},	//   _honu, جيرا, _שהקי, цпсг
  { {0xd5b70023,0x7bc3472d,0xe8fa004a,0xd910002b}},	// [a300] ớng_, _konu, _шли_, _ریس_
  { {0xf7460001,0x9f5c0107,0x27ed0003,0x74130015}},	//   _њено, ková_, éent_, قوقا
  { {0xd252002b,0x3f9e3a53,0x9fe6002b,0x7bc316c8}},	//   زنش_, _ratu_, یسته, _monu
  { {0x3f9e013c,0x9f5c0107,0xad9d002a,0xd9f8000b}},	//   _satu_, dová_, woźn, ीवित_
  { {0x2007472e,0xa0970015,0x60262797,0x00da0058}},	//   foni_, لضوء_, адда, خبات_
  { {0x33d5008f,0xc6fa000a,0x261700e9,0xc6b6000a}},	//   _ліст, ֣לֶך, nçon_, ֹהֵי_
  { {0xd1760080,0xfe770015,0x61eb472f,0x2ba60065}},	//   _вызы, لصيغ_, bigl, _कोषा
  { {0x3f9e000c,0x2007003f,0x69c44730,0xd29b000a}},	//   _watu_, aoni_, _noie, _בשלט
  { {0x3f9e003f,0xdb0a0012,0x20074731,0x7bc34732}},	//   _tatu_, _wofü, boni_, _bonu
  { {0xa5bb002d,0x9f5c0057,0x307b000a,0x8e20005e}},	//   _thóg, bová_, _באמנ, хiв_
  { {0x1fb50229,0x69c40011,0xd337000a,0x19590174}},	//   _устр, _boie, יריה_, ланы_
  { {0x09f90029,0x69cf002a,0xbf130015,0xbae30033}},	//   افحة_, ukce, _بومب, іцэй
  { {0xa3e7005d,0xdb030012,0x58870033,0xcdf7015b}},	//   _बगल_, _annä, шына, _דמאי_
  { {0xad1b000a,0xa08b000a,0x628e2b99,0x9f470003}},	//   _סוגר, כְלִ, _opbo, tiné_
  { {0x35e7008f,0x8c1b00f3,0xdb18001a,0xd7f8033d}},	//   ацав, _שווי, _alvö, руя_
  { {0xd6d9005c,0x26170003,0xaabb000a,0x69d600aa}},	//   ął_, açon_, _יזוכ, _glye
  { {0xf94a00b2,0x61eb04ed,0x7bda0209,0x9f5c0107}},	// [a310] _געפֿ, vigl, ohtu, zová_
  { {0xd795003b,0xa3470033,0x92a70054,0xdb0a196b}},	//   _الدخ, рэал, ијел, _infâ
  { {0x644601e2,0x2007003f,0x61eb4733,0xa3bb002b}},	//   _etki, voni_, tigl, _یاسر_
  { {0xd167006b,0x9f5c01c0,0x2007002a,0x201e05ff}},	//   ръжи, vová_, woni_, _ahti_
  { {0x9f4700f2,0xa98c000a,0xf99f0781,0x10a50076}},	//   ynnä_, דָוִ, llès_, силн
  { {0x6aaa0026,0x9f5c0264,0x2ba6000b,0xfba6000b}},	//   _orff, tová_, _कोला, _कोलम
  { {0xe61f0016,0x24950061,0x61eb4734,0x44390caf}},	//   _khô_, şamı_, pigl, _hus_
  { {0x7bc301e2,0x44390005,0xa3b5005d,0x9f5c0107}},	//   _sonu, _kus_, झाव_, rová_
  { {0x44390c80,0x7bc34735,0x61e94736,0x9f5c0057}},	//   _jus_, _ponu, _imel, sová_
  { {0x69c40152,0x9f34005e,0x20d40015,0x44394737}},	//   _soie, _дефі, _بتفج, _mus_
  { {0x15f9014e,0x7bc3234c,0x7d770015,0xdb180247}},	//   ्कार_, _vonu, _ناشط, _pová
  { {0x44390291,0xf9920015,0x44311d95,0x7dc40058}},	//   _ous_, أبد_, _liz_, _وقلن
  { {0x69c432a0,0x7bda0125,0x44394738,0x7bc34739}},	//   _voie, bhtu, _nus_, _tonu
  { {0x7bda018b,0x6d5900e8,0xf7430888,0x4431473a}},	//   chtu, _hewa, зеро, _niz_
  { {0x44390bcf,0xdb180014,0x1ddb005d,0xf99f0251}},	//   _aus_, _tová, _बतात, glès_
  { {0x4439473b,0xf5b50036,0x44310024,0x320d0125}},	//   _bus_, осую, _aiz_, _nkey_
  { {0x74160086,0x4431473c,0x6d590509,0xa5bb002a}},	// [a320] مورا, _biz_, _mewa, _piór
  { {0xf1a90086,0x6d59013c,0xa8030061,0xb4630033}},	//   یانه_, _lewa, _çıpl, якул
  { {0x443103af,0x63060029,0x857c004a,0xc4c9004c}},	//   _diz_, حوال, _а́ет_, עג_
  { {0x12190010,0x11760015,0xda7a004c,0x6d59473d}},	//   аючы_, إطاح, טנער, _newa
  { {0x4fc6473e,0x4431016e,0xa91b001a,0x4439473f}},	//   йска, _fiz_, efþj, _gus_
  { {0x161c005d,0xd3ba0036,0x7dd53d49,0x61e94740}},	//   _भीतर_, _сумі_, _rása, _emel
  { {0x10150010,0x2fc500bd,0xb87b0ce7,0x44391892}},	//   цьця, _dolg_, ozíc, _zus_
  { {0x82f7000a,0x5e430015,0x2dda0015,0xa2f7000a}},	//   _הצלב_, أَيْ, طبعة_, _המלה_
  { {0x6d590375,0x7bda00da,0x6d401fc3,0xebd8009b}},	//   _dewa, thtu, rcma, идиш_
  { {0x9b580083,0xcf890015,0x7bda007c,0xf3f3004f}},	//   шиот_, _نضمن_, uhtu, ּ֣ץ_
  { {0xfba7004a,0x5e4a0004,0x5d6a006b,0xdfa50015}},	//   стый_, _спем_, _бием_, _بحقي
  { {0xf2d30053,0x2e37000a,0xc27b000a,0x6d592735}},	//   פער_, _הראש_, נרכי, _gewa
  { {0xae1b0008,0x48e40033,0xb87b006f,0x718b004f}},	//   _עודכ, зоўв, dzíc, נְטַ
  { {0xa3a8005d,0x44394741,0x6e3a43fd,0xead40b9b}},	//   _खोल_, _rus_, _kutb, _моль
  { {0x44394742,0x8a460029,0xe61f0016,0x7dd50030}},	//   _sus_, _ائتم, _phô_, _másn
  { {0x443101e2,0x06150036,0xca470029,0x44394743}},	//   _siz_, ідаю, _اليه_, _pus_
  { {0x68200123,0xadd7000a,0x9f4702b9,0x0000006a}},	// [a330] född, צומח_, finì_,
  { {0x6e3a003e,0x7df30011,0x61e90ab5,0x44390003}},	//   _outb, răsi, _smel, _vus_
  { {0xe5350256,0x8c1b000a,0x2b58002a,0xe61f0016}},	//   _мень, נובי, órcy_, _thô_
  { {0x443902c1,0x32640036,0xca7b004c,0xc1150054}},	//   _tus_, ятув, רנאט, омеј
  { {0x44390005,0x01340015,0x6d594744,0x7dd50107}},	//   _uus_, أعمد, _rewa, _básn
  { {0x185c0053,0xdb1a0eba,0x644d4745,0xae990015}},	//   רכגע, nktó, mpai, لضبط_
  { {0x644d00f2,0x2fc51786,0x798d005c,0x39420123}},	//   lpai, _volg_, _obaw, ycks_
  { {0x2d8a00dc,0x307b0029,0x61e91298,0xd5b2000a}},	//   őben_, _محطة_, _umel, ֵׁי_
  { {0x644d0696,0x62851683,0x68200123,0xf5cc004f}},	//   npai, ltho, löde, ר֖וּ
  { {0x7ff70225,0x3a20003e,0x6d5901d7,0xcb690099}},	//   _اسرا, _ship_, _wewa, јане_
  { {0xf8a90008,0x6d590509,0x8ae40033,0x5e440015}},	//   _שש_, _tewa, зіўл, _فَلْ
  { {0xee2e0127,0x8ed80015,0x62852860,0x2e17002b}},	//   _ін_, _اذكر_, itho, _ابطح
  { {0x78ad1a06,0xf7461092,0x7bf9013e,0x39424746}},	//   _crav, жего, _кндр_, rcks_
  { {0x3a2000da,0xaca8002b,0x2c7701c0,0xab294747}},	//   _whip_, _دههٔ_, aždá_, _кола_
  { {0xae1d000b,0x96b90342,0x69dd0125,0x644d0351}},	//   _पठान_, буту_, bhse, epai
  { {0x7dd50014,0x69dd018b,0x78ad0bfa,0xd4f6004a}},	//   _máso, chse, _frav, оязы
  { {0x62850176,0x13ea0010,0x4466005e,0x8e20005e}},	// [a340] etho, амай_, ював, цiй_
  { {0xa5bb002d,0x14170029,0x798d002a,0xe3b71c8c}},	//   _phóc, قيقة_, _zbaw, обу_
  { {0x78ad00bd,0xe29a36bb,0x7dd50107,0x644d008c}},	//   _zrav, рае_, _náso, apai
  { {0x7ddc0030,0xe733004f,0x0000006a,0x0000006a}},	//   _kése, _קֵץ_,   ,
  { {0xa3da000b,0xc0960015,0x3217002b,0x62854748}},	//   ़सद_, تجات, آيند_, atho
  { {0x66164749,0x68200012,0x1fb630db,0x3e6a0047}},	//   llyk, böde, юсер, ашин_
  { {0x6e430087,0xce470004,0xcdda0099,0x0000006a}},	//   ونوم, озје_, ињи_,
  { {0x85480007,0x9daa006b,0x8c662341,0xdc8a0138}},	//   brėž, ръка_, отод, асол_
  { {0x60970015,0x9c370138,0x0000006a,0x0000006a}},	//   _ونفس_, опыт_,   ,
  { {0xc3340008,0x34b7000a,0x3a740054,0x8bd80974}},	//   ּוֹ_, קפים_, плор, смос_
  { {0x8ae3005e,0x29050061,0xdfcf00c3,0x1fb508f0}},	//   діял, ğlam_, _جيل_, _эстр
  { {0x8b66002b,0x78ad09cb,0x0000006a,0x0000006a}},	//   حاکم, _prav,   ,
  { {0x7dd501c9,0x0907005e,0x3eb2002a,0x57a70033}},	//   _záso, ючом, łatę_, ошва
  { {0x7ddc0152,0x661600aa,0x78ad006f,0x6285474a}},	//   _dése, elyk, _vrav, ytho
  { {0x66160804,0xe81f0065,0x0000006a,0x0000006a}},	//   flyk, _मीणा_,   ,
  { {0x7dd528cc,0x78ad16c8,0xd5b81c86,0x6abc0012}},	//   _násl, _trav, осу_, ärfu
  { {0x04590029,0x6e220034,0x78ad036d,0x628526d0}},	// [a350] صلاة_, _mhob, _urav, wtho
  { {0xa3e5005d,0x57f40080,0x8bf8000a,0x68200123}},	//   बों_, _опыт, צִּפ, töde
  { {0xe2980036,0xf1a90086,0x979a000a,0x61550015}},	//   жає_, یاچه_, _השתק, كنائ
  { {0x7df30011,0x6285474b,0x644d474c,0x7ddc00e1}},	//   năst, rtho, ppai, _lésb
  { {0x55ba013a,0xadc30016,0x6285474d,0x296c004f}},	//   _המרו, hoản, stho, ב֣וּ
  { {0x94050074,0x1da3000b,0x26170061,0xd378004a}},	//   _روزه, _खोजत, kçok_, _мчс_
  { {0xf412000a,0x1758000a,0x9758004f,0xd346009a}},	//   _נפל_, חסור_, חשוף_, _رینه_
  { {0xbca50029,0xb222002e,0x96fc0008,0xc332000a}},	//   كمبي, áætl, ילות, _טום_
  { {0x2bb90029,0x96270024,0xcd35002b,0x0000006a}},	//   مادة_, _izņē, يرکب,
  { {0x7ddc038d,0x9c220010,0x95f9000b,0x5f440015}},	//   _rése, ндыд, ्कुट_, _ينقل
  { {0xe8e10023,0x2fe40029,0x7dc70015,0xdd950033}},	//   _đều_, _تكلف, _وتؤك, _нажы
  { {0xf2d2004c,0x8f1a000a,0x6ec80065,0x0000006a}},	//   געט_, _הועת, ़हरु,
  { {0x5d3a0008,0x2d8f016e,0x7d56004c,0xdd99006f}},	//   _התנא, _ibge_, _זינד_, meň_
  { {0x2bbb003b,0xc604000b,0xdca227a1,0xddc30073}},	//   _خاصة_, लव्य_, _чаши, ksnū
  { {0xa3b5005d,0x6abc0012,0x290c002a,0xe9df0125}},	//   झाई_, ärft, łda_, bhú_
  { {0x4df9004c,0xe9df006f,0xa4460ef5,0x39c50058}},	//   צפּא, chú_, знад, _يغيّ
  { {0x75d30029,0x99920007,0xe97b000a,0x89db000a}},	// [a360] ريكا, ūzų_, _הנפש, _לחקי
  { {0x6616079b,0x04570015,0x6e290012,0x764e474e}},	//   slyk, سلمة_, hmeb, ppby
  { {0x8c1a0008,0x1757000a,0x5757000a,0x021a005e}},	//   צועי, _מסיר_, _מביע_, бідь_
  { {0x68e20007,0x76bb000a,0xb6bb000a,0xf41f0012}},	//   _žody, _המטפ, _הצטי, _spät_
  { {0xf537013a,0x6e290020,0x6016001c,0xdd990107}},	//   _מרכז_, dmeb, lâmi, deň_
  { {0x9f5c002c,0xd0100029,0x58f7004f,0x9f4703a0}},	//   lovú_, خلت_, המנע_, ginà_
  { {0xcf260029,0xc7b30008,0x6016001c,0x6e22474f}},	//   أرشي, תבו_, nâmi, _phob
  { {0xade30191,0x9f5c006f,0x21a311bd,0xc693004f}},	//   ецьк, novú_, _писм, גאה_
  { {0xaf360018,0x4cb8005e,0xbf360040,0xe0da1de1}},	//   _فرات, ілою_, _فراغ, _ува_
  { {0x9f5c002c,0xa3b5000b,0x09d5000b,0xf3c7000a}},	//   hovú_, झाए_, दस्य, ִּי֙_
  { {0xe9df002f,0xbeaa002b,0x9f5c006f,0x03d7004f}},	//   thú_, _دهان_, kovú_, פוטם_
  { {0x26170064,0xdb030003,0x3ddf0079,0x9f47016e}},	//   rçok_, _manè, chuw_, miná_
  { {0x7de50015,0x9d1a00c3,0x9f5c006f,0xad8b004f}},	//   _تسلم, _ازاء_, dovú_, _לְגֻ
  { {0x4c9b0008,0xdc370053,0x7d1d1341,0xa5bb4750}},	//   _לבדו, _זאגט_, üsse, _chón
  { {0x87040080,0xd61b0015,0xbc1b000a,0xeaaf0015}},	//   еяте, مترا_, _הוגש, _معي_
  { {0xda7b000a,0xa63400fd,0xbafb000a,0xa5bb0030}},	//   _הנהר, енсі, _להוש, _ehón
  { {0x64404751,0x349401cf,0x64a40004,0x660d072f}},	// [a370] _émil, натр, наѓа, roak
  { {0xd371003b,0xdd99013f,0xc6a70350,0x38694752}},	//   ئها_, zeň_, _ерми, _ivar_
  { {0x3869002e,0x9f5c002c,0x754800dc,0xe3c40015}},	//   _hvar_, bovú_, észí, عْمَ
  { {0x41e4008f,0xd1310070,0x7dd50107,0x386902ce}},	//   ніча, نما_, _pásm, _kvar_
  { {0xc0c80001,0xdd990057,0x6d5d001a,0xb457002b}},	//   зује_, veň_, ðsam, _ریاض_
  { {0x25a900dc,0x94ba0008,0xfeb9002b,0xf78a004c}},	//   ldal_, _ומשת, قابت_, ַנפֿ
  { {0xe1f30015,0xe3b2004c,0x24894753,0x92940a0b}},	//   _كسر_, _בױם_, ltam_, _парц
  { {0x96270048,0x56b80008,0x26dc0008,0x8c49005e}},	//   _uzņē, לפון_, מקומ, опив_
  { {0xea000092,0x24894754,0x7dd5002e,0xdd99002c}},	//   _ngại_, ntam_, _hásk, reň_
  { {0x320f2d92,0xff25002b,0x9f5c006f,0x25a90034}},	//   logy_, _قبای, zovú_, hdal_
  { {0x3ed5003b,0xfe700029,0x9ee90015,0xdd990264}},	//   _تقار, _مدن_, _بفضل_, peň_
  { {0x7dd500dc,0x5e440015,0x24894755,0x3cd500eb}},	//   _másk, _أَنْ, ktam_, _ожес
  { {0xa5bb0023,0xb87b00dc,0xdb0a00b8,0x25a924b5}},	//   _phón, szín, _anfä, ddal_
  { {0x0c240191,0xac270010,0x62950079,0x24890030}},	//   _змін, _эфек, _opzo, dtam_
  { {0x2cad0041,0x16a70403,0x9f5c006f,0x6b9c007c}},	//   lved_, мври_, tovú_, õrge
  { {0xcb12013a,0xe45a0010,0x057a0029,0x7b030011}},	//   _שלה_, жжа_, تمرة_, ăută
  { {0x63a70030,0x9f5c006f,0xb3ca0054,0x53a60033}},	// [a380] _bajn, rovú_, олаз_, мааб
  { {0x2cad003e,0x18770053,0x660906e6,0x9f5c006f}},	//   ived_, _קעיר_, čeka, sovú_
  { {0x67bb0008,0xd7bb000a,0xea010016,0xe72a0585}},	//   _ומיק, _וציר, _quầy_, _фонд_
  { {0xe61a005e,0xa1ba0021,0x6b9a1b8e,0x95560058}},	//   _фдм_, غطاء_, zetg, _تخدا
  { {0xd59b000a,0xdb0338f0,0x69c60079,0x859b000a}},	//   _ובכל, _dané, ijke, _ושכו
  { {0xb0330191,0xdfd00015,0x65640030,0xc0e70015}},	//   вніш, طيب_, laih, ظفون_
  { {0x2cad2316,0x52750054,0x2d8d4756,0x44384757}},	//   eved_, _путу, ffee_, _iir_
  { {0x656400f2,0x44380304,0xdb080003,0x6b9a0079}},	//   naih, _hir_, _élép, wetg
  { {0xc0460029,0x2383002e,0xff760015,0xe0860067}},	//   _آخرو, _þrjá_, _يُرج, _تجزي
  { {0x7ddc0152,0x6f0d0064,0x4e960029,0x5f760067}},	//   _désa, şaca, _يشار, _زائر
  { {0x33770e22,0x03770008,0xdb03002e,0x44384758}},	//   ועים_, ותית_, _ennþ, _mir_
  { {0x2b5101e2,0xc33305af,0x61e20af5,0x6a140015}},	//   ızca_, כות_, nhol, َبَر
  { {0xdd8f0086,0xa09b0053,0xadd70033,0x44383b06}},	//   _خون_, ֿילט, _імшу_, _oir_
  { {0xc7bb0010,0xbb840015,0x61e21b03,0xad1b004f}},	//   цём_, _ألغي, hhol, _וודר
  { {0xe613003b,0xb5950c94,0x5b7b000a,0x6b7b000a}},	//   نشر_, нивш, _ורוא, _ורונ
  { {0x63a70014,0x248900dc,0xe5730015,0x44384759}},	//   _sajn, ttam_, ضطر_, _air_
  { {0x44380482,0x61e200fb,0xb4d9005d,0xd7e70036}},	// [a390] _bir_, dhol, ़ने_, _жіно
  { {0x6fd40251,0x2c34000a,0x3f9c18ca,0x44381859}},	//   _fàci, תָֽם_, jevu_, _cir_
  { {0x2cad0024,0x1756039e,0x9756000a,0xdb0a0012}},	//   zved_, _אסתר_, _איתו_, _unfä
  { {0xc6920053,0x62080015,0x7c38475a,0x261e0034}},	//   _גאט_, وْلِ_, _livr, nïol_
  { {0x2444203a,0x4438124e,0x63a72583,0x320f00bf}},	//   _göm_, _fir_, _tajn, rogy_
  { {0x4438003c,0x187c0008,0x80a8005e,0x268b000a}},	//   _gir_, קטוב, ьвів_, ַנִּ
  { {0x682000dc,0x9d45070c,0x11770058,0x799d01f9}},	//   ködn, нейд, _يطرح, kesw
  { {0xd7380008,0x6fdd0251,0xcee80015,0x92940033}},	//   וטות_, _dèca, ظرون_, _шасц
  { {0x61140033,0x98ab0061,0x7dd5013f,0xac960058}},	//   _адту, kacı_, _jási, ّنًا_
  { {0x7dd500dc,0x2cad475b,0xddc8003d,0x8f550015}},	//   _mási, rved_, ļoša, _أناش
  { {0xf4120008,0x656f0d57,0x291e002a,0x6f48000a}},	//   רפי_, _odch, ętam_, _חֲנַ
  { {0xc3320008,0x6fd40144,0x8e56000a,0x799d0034}},	//   טוי_, _ràci, _נינג_, gesw
  { {0x6c840029,0x2617001c,0x656401a0,0x1bd50268}},	//   _للنم, nçou_, vaih, _подя
  { {0xa7da003b,0xd0f60008,0x60c40604,0x00f6000a}},	//   أوسط_, תמשת_, äimi, תמשך_
  { {0x66e6475c,0x6606006b,0x4438475d,0x9b840015}},	//   хова, епва, _rir_, _شؤون
  { {0xa3a8005d,0x78a40020,0xc6c30010,0x44380495}},	//   _खोज_, _tsiv, ыйск, _sir_
  { {0x6d49002d,0x66350033,0x142615ce,0x67e2006f}},	// [a3a0] icea, тэрф, едам, _pôjd
  { {0x0857013a,0x6564475e,0x645d0034,0x9f47008c}},	//   _רבים_, saih, _dwsi, ninä_
  { {0x44380f75,0xe7320015,0xd259005e,0x61e2475f}},	//   _vir_, _حصة_, дці_, thol
  { {0x2a6a0014,0x44380940,0x3f9c003f,0xe2160015}},	//   ábbi_, _wir_, wevu_, رباع
  { {0x9f47008c,0x44384760,0x61e22b0e,0x3f9c006f}},	//   kinä_, _tir_, rhol, tevu_
  { {0x443820d9,0x4ea603ad,0x74160015,0x64160015}},	//   _uir_, ериа, _أوسا, _أوسط
  { {0xfe6f00a2,0x877b000a,0xdd900015,0x2617016e}},	//   مدي_, לאסי, لوث_, açou_
  { {0x291e005c,0xbef70029,0x8d760015,0x7c3845b2}},	//   ętaj_, عروض_, راعا, _sivr
  { {0xe58b0008,0x98ab0064,0xe53b000a,0xdb18134b}},	//   הָיָ, yacı_, התפר, _invé
  { {0x3ea9005c,0x70530015,0x7c930021,0xdb572b9f}},	//   łata_, _إنلا, اشيا, нюю_
  { {0x7c38353c,0xa3e5000b,0xbe850015,0x2a6a0030}},	//   _vivr, बोट_, _لجنو, ébb_
  { {0x225c0057,0x61360061,0xd9440b1e,0x7edb004f}},	//   ávky_, _gülü, леџи, _מקבצ
  { {0xf1b3000a,0x6aa12004,0x68200030,0x799d0bd8}},	//   אסר_, awlf, rödn, resw
  { {0xb8c9005d,0x2ca60026,0x7dd5002e,0x645d0026}},	//   _गई_, _isod_, _rási, _rwsi
  { {0xab270001,0x7a3e0007,0x9c17000a,0x501b000a}},	//   _поља_, _būte, _רחוק_, פולו
  { {0x34950256,0xa8a70033,0x7ddc2522,0x89d70015}},	//   кабр, _зрок, _méso, _ستعط
  { {0xe4e7005e,0xf51b002b,0x7bda0061,0xdb08016d}},	// [a3b0] хівн, سترش_, oktu, ajdô
  { {0xdd0c002a,0xdce00b28,0x7bda4761,0x93070004}},	//   _kółk, jamč, nktu, нџел
  { {0xf836000a,0xc87f0012,0x7bda0091,0x43840015}},	//   _שנתת_, luß_, iktu, المق
  { {0xcb130053,0x7ae50020,0x2ca60026,0xd6560008}},	//   אלע_, _ühte, _osod_, _שירת_
  { {0xf9940008,0x7bda002e,0x35a40033,0x9f47008c}},	//   טרף_, kktu, _саўг, yinä_
  { {0x2617016e,0x7d190034,0x7e6d01ec,0x1e954762}},	//   rçou_, _ryws, ņapm, врир
  { {0x5f050063,0x97ac000f,0x9f47008c,0x628b0045}},	//   ъзка, לֹהֵ, vinä_, ăgos
  { {0x7ddc0152,0x9f5c0069,0x7bda0061,0x0000006a}},	//   _déso, mový_, ektu,
  { {0xf204008f,0x9f5c0057,0xc0940015,0x9f47008c}},	//   _сяро, lový_, _مجلت, tinä_
  { {0x1a650086,0x6d490c1b,0x66dc008c,0x0000006a}},	//   نیتی_, scea, näkö,
  { {0x6d460064,0x7ddc00dc,0x8d950029,0x7ff40015}},	//   ıkar, _késl, _للاش, _إسقا
  { {0x9f4700f2,0xc87f0012,0x186a0361,0x3a294763}},	//   sinä_, fuß_, мами_, _chap_
  { {0x88c7005e,0x75fa0046,0xfce90015,0x9f5c01c0}},	//   вляв_, hůzc, _تفشي_, hový_
  { {0x9f5c0107,0xbc07004a,0xcc76000a,0xeb9912fd}},	//   kový_, _ячей, _יענה_, _цик_
  { {0xfaa51328,0xcf92004c,0x9f5c0264,0x9663158e}},	//   _райо, ױטן_, jový_, икре
  { {0x98be0064,0xceb20008,0x9f5c01c0,0xdb03006f}},	//   ştı_, סין_, dový_, _janí
  { {0xd467066c,0xf3da0029,0xb3860484,0x7416006e}},	// [a3c0] ките_, وورث_, клал, نورا
  { {0x987b000a,0xd78a002b,0x2d9f086c,0x2c35000a}},	//   _קריק, _کنگو_, heue_, דָ֣ם_
  { {0x27770008,0x29050064,0x74130015,0x66e60419}},	//   _בגין_, şlat_, جولا, _рона
  { {0x7ddc0152,0xdb180057,0xd24f006e,0x7d0e002a}},	//   _réso, _nový, زنه_, ębsz
  { {0x40940021,0x50ba0058,0x11d70058,0x0000006a}},	//   التر, بداد_, خونة_,
  { {0xdfcf0070,0xb4de005d,0x25a00152,0x60230033}},	//   يين_, तनी_, leil_, адча
  { {0x93160086,0x6fdd0251,0x7996005c,0x8eb40015}},	//   _شورش, _tècn, _obyw, امبش
  { {0x27f80012,0xddea0015,0x2327261d,0x25a001f9}},	//   hirn_, برته_, _роси_, neil_
  { {0xc5f3013a,0xdb010134,0xa177000a,0xdb030046}},	//   ידה_, ndlæ, _שעמד_, _daní
  { {0x6e960029,0xdfa50015,0xdd0c002a,0x25a002f7}},	//   _للطا, _محمي, _półk, heil_
  { {0xe9f906b4,0x0d861186,0x7bda4764,0x5a3525e0}},	//   енні_, _ален, rktu, лнот
  { {0xadb70029,0xdef7000a,0x0e690015,0xddea0058}},	//   _لهما_, _במבט_, _أصلي_, _غرضه_
  { {0x386d038d,0x5c73005e,0x79540015,0x7a0b002a}},	//   éer_, _вліт, شَّا, jęte
  { {0xd7c90086,0x24801cb6,0x9cd7004f,0x6eb80065}},	//   روزه_, duim_, _בודה_, ्मपु
  { {0x25a04765,0x6b9b000a,0x9f5c04b2,0x66f4008b}},	//   feil_, _חשוד, xový_, апру
  { {0x1dc5000b,0xa907002b,0xdb37000a,0x644b016e}},	//   वायत, _لبخن, _בנוח_, ígio
  { {0x80be014e,0x38600026,0x99990007,0xf367033f}},	// [a3d0] ्हों, _gwir_, ūrų_, втен
  { {0xc3540001,0x7dd5002e,0x9f5c0227,0x6fdd0144}},	//   икуј, _hást, tový_, _rèco
  { {0x7dd50089,0xeb91000a,0x9388006b,0x68200030}},	//   _zásu, מָא_, ъста_, ködj
  { {0x261711dd,0x9f5c0227,0x27ef002a,0x66dc008c}},	//   rços_, rový_, żoną_, säkö
  { {0xdfd50256,0x9f5c0057,0x999f0091,0x7dd50077}},	//   лоды, sový_, lptų_, _mást
  { {0x9f5c01c9,0x9f84005e,0x7dd50533,0x3f6909c3}},	//   pový_, игід, _lást, хико_
  { {0x4e950029,0xdb1801b2,0xcf58005e,0xbf58005e}},	//   اشتر, _pový, тріч_, трії_
  { {0x7db4008f,0x7dd504af,0xa2a8000b,0x7e960015}},	//   асьц, _nást, _घनत्, انير_
  { {0xa5bb002f,0x7c2a002f,0xbfab0036,0xbb450010}},	//   _chói, _bhfr, _отже_, лепк
  { {0x7dd5001a,0xa5bb0125,0x5fbb0015,0x7aa504b9}},	//   _rásu, _dhói, _تدرج_, гиоз
  { {0x1603005d,0xdb0300dc,0x3ed5009a,0x0000006a}},	//   रचार_, _taní, _حقار,
  { {0xc7a9000a,0x8d74002b,0x6016016e,0xdb180144}},	//   _מב_, _ناها, lâmp, _envï
  { {0xfd44008f,0x6d5b013c,0x6fd40144,0x6d5d001a}},	//   _тэхн, mbua, _tàct, ðsau
  { {0x69dd022d,0x291e0024,0xaae50031,0x75d6002b}},	//   akse, āta_, _مسعو, گيرا
  { {0x25a000b8,0x65ba0001,0x7dd5002d,0x26de01c9}},	//   teil_, нуар_, _fást, áto_
  { {0x290501e2,0x75d600e6,0xdce00024,0x69dd0334}},	//   ğlar_, ديرا, lamā, ckse
  { {0x290501e2,0xb4de005d,0x25a00152,0x037a00e5}},	// [a3e0] şlar_, तने_, reil_, فحات_
  { {0x7dd50107,0x07a60054,0x5436004a,0x7a0b002a}},	//   _zást, _саон, ухбу, ręte
  { {0x1bf60053,0x232a004a,0xdb0a0144,0x0000006a}},	//   נצער_, хожи_, _cafè,
  { {0x067b01ac,0x00e60579,0x7a3e003d,0x224703ae}},	//   _אנטל, лжен, _jūta, упци_
  { {0x8a170008,0x463b0053,0x24800341,0xf993000a}},	//   נחנו_, _רעכע, quim_, מרא_
  { {0xc4d30008,0xdce00024,0x660411aa,0x33d5005e}},	//   _הגש_, jamā, lnik, _кіст
  { {0x69dd022d,0x61f90026,0x656600e8,0x877b0053}},	//   ykse, biwl, _kekh, גאצי
  { {0xa5bb002d,0x64464766,0x6ca624b7,0x2d840085}},	//   _phói, _kuki, грож, ugme_
  { {0x71d70008,0xa3e8005d,0x1d070054,0x600a06a6}},	//   _עומד_, _बता_, лећи_, _знам_
  { {0xda7a13ae,0x7dd5002d,0xb09b000a,0x66041be7}},	//   ням_, _sást, _אימר, hnik
  { {0xd00f00e5,0x5d86002b,0x6446118c,0xdb030144}},	//   _علم_, _ملال, _luki, _canà
  { {0x69dd022d,0xa5bb002d,0xd3370008,0x5eeb000a}},	//   ukse, _thói, טריה_, _אַדְ
  { {0x98b8006b,0x09e40033,0x64464767,0x3dfb000a}},	//   глят_, соўн, _nuki, _אלאד
  { {0xdce00024,0x6fc7000b,0x69dd007c,0x8aa602da}},	//   camā, लायं, skse, _брид
  { {0x64463ce0,0xaab700e5,0x7dd5002d,0x99d70015}},	//   _auki, _مدير_, _tást, _متظا
  { {0x7ae5007c,0x64464768,0x66041a5e,0x3abb004f}},	//   _ühta, _buki, gnik, _טמונ
  { {0x55070617,0x5f16000b,0xc4540015,0xf9900015}},	// [a3f0] учва, _पुस्_, مضلع, _ربي_
  { {0x430b0004,0x9cd7000a,0x629c0125,0x93270067}},	//   нхем_, אומה_, _bpro, هران
  { {0x6604018c,0xdb0304af,0x23740029,0x7ff5002b}},	//   bnik, _kaná, صالح, یستا
  { {0x6d420092,0x8afb0053,0x81ab002b,0x6604002a}},	//   _ngoa, עלאז, عطاف_, cnik
  { {0x601604f9,0x601f001c,0xdca60015,0x90c5033d}},	//   tâmp, lêmi, _بى_, рбле
  { {0xd47a0053,0x3d18005d,0xe0d80033,0x225f002a}},	//   _באשל, _पड़े_, ыві_, _łuku_
  { {0xcee60036,0x9758000a,0xd00e006e,0xd7bc000a}},	//   идше_, ניהו_, بلو_, תצור
  { {0xbca50029,0x8db50010,0x9cb50015,0x3e320021}},	//   لمبي, рскі, لمعت, يفور
  { {0xe5720008,0xcd290063,0x629c0089,0x6d5b0375}},	//   חַת_, ъжие_, _zpro, rbua
  { {0xdb180467,0xbab50010,0xabd50180,0x09de000b}},	//   _enví, аёмы, рциј, मस्य
  { {0x6604005c,0x2cb80024,0x09f60029,0x1a0600a4}},	//   ynik, ārda_, لأحد, ипом
  { {0x601f001c,0x1d19004a,0x68200012,0x2a780030}},	//   dêmi, _июль_, mödi, árba_
  { {0x6604060b,0x68200123,0x0000006a,0x0000006a}},	//   vnik, lödi,   ,
  { {0x66040050,0xdb03002d,0xcf92004c,0x3dcd002a}},	//   wnik, _eaná, ֿטן_, ljew_
  { {0x09e62dd8,0x9bfa000a,0x57250015,0x64464769}},	//   _войн, _שהצט, مرفق, _suki
  { {0xe9df002c,0x395f001a,0x4a9a000a,0xf5060890}},	//   ckú_, ðust_, _ייצג, азбо

  { {0xa3560029,0x629c476a,0x64b2000b,0x7ddc0003}},	// [a400] لخاص, _spro, ीमेश, _désh
  { {0x6604052c,0xd8db0008,0x682000dc,0x78a90061}},	//   snik, _סקיר, ködi, çeve
  { {0x463a0029,0x877b000a,0xb77b000a,0x9343005e}},	//   _لأحد_, _באיי, _באיש, інце
  { {0xfc480092,0xe0da239c,0x64460df8,0x5f16000b}},	//   _lửa_, кве_, _tuki, _पुष्_
  { {0x629c0050,0x2087006b,0x3d0f000b,0x4fc6249a}},	//   _wpro, ийци_, ाथों_, иска
  { {0xfc480092,0x2492002a,0x5ff300e2,0x0000006a}},	//   _nửa_, mtym_, озіу,
  { {0x539b0008,0x7ddc0152,0x7f830015,0x68200012}},	//   _שילו, _hési, زلين, gödi
  { {0x9fa30084,0xf657000a,0xf653000a,0x7ddc0030}},	//   síðu_, בסקי_, חצה_, _kési
  { {0x64400152,0x717b000a,0xa2250067,0x224d476b}},	//   _émis, _שנמס, _طرفه, _čeki_
  { {0xfc480023,0x60e80064,0x6609016f,0x23c9000b}},	//   _cửa_, ırmı, čeki, रायद
  { {0xb4db0092,0xdd8a0033,0x7ddc0003,0xc3b7004f}},	//   _ngàn, _абед_, _lési, בליץ_
  { {0xedd30015,0xbae30033,0x99670e7c,0xdd90006e}},	//   _ويلد, юцый, штол, _روت_
  { {0xfbcf0074,0x7ae5007c,0x9bea0054,0x98170058}},	//   ستی_, _ühtn, _имдб_, لبسا
  { {0xd7fb009c,0x9b940015,0xe9df006f,0x0000006a}},	//   тум_, _طلبت, skú_,
  { {0xdb0300dc,0x39520034,0xd61b0369,0x75fa005a}},	//   _taná, _ffys_, نترا_, různ
  { {0x8b3b0008,0xdb180251,0xc9f4012c,0x09f40015}},	//   _בתוצ, _invà, _وسيع, _وأيد
  { {0xb87b00dc,0x22a80061,0x061400fd,0xdb210030}},	// [a410] gzít, _aşk_, ідую, ötöz
  { {0x7ddc038d,0xd1b8002b,0x6b880123,0x8bd8000a}},	//   _dési, یانا_, ngdg, נַּח
  { {0xdb0a19fe,0x7a3f003d,0x85470138,0x0000006a}},	//   _infó, _jūto, _вэге,
  { {0x6d470089,0xc2440484,0x31580015,0x25d5004f}},	//   ějak, інік, لجهة_, _הוֹן_
  { {0xc1040029,0x7f750010,0xdb0a00b8,0xc0a80015}},	//   يومي, буйц, _anfü, لاول_
  { {0xdce00045,0x656d01d7,0x8fa50033,0x0000006a}},	//   zamă, laah, саке,
  { {0x21270086,0xd00e0029,0x2129006f,0xfc480016}},	//   _چيزی_, على_, ťah_, _rửa_
  { {0xfc480023,0x90450086,0x69dd00dd,0x78ad0607}},	//   _sửa_, _هنره, êrel, _osav
  { {0xdb0100dc,0x1fa70036,0x8eb5002b,0xe5f8000a}},	//   melé, _врег, _گماش, יזהר_
  { {0xa0c40015,0x63a500bc,0xdb010030,0xc279000a}},	//   _بيكو, nehn, lelé, ְרָי
  { {0xae780191,0xf8a9000f,0xdb23002b,0xa96a04bb}},	//   _всіх_, _רש_, تودی, лина_
  { {0xdb03386a,0x7c950086,0x7db40015,0x6fdd0003}},	//   _lanç, _هشتا, _وصنا, _sèch
  { {0x99160010,0x91ba0008,0xeb990549,0x78ad0030}},	//   сьні, אמרי, _бил_, _csav
  { {0x7ddc0152,0xd116000a,0x6285007c,0xdb010030}},	//   _rési, מקרה_, kuho, helé
  { {0x67290089,0xdb0100dc,0x2007199c,0xcb56000a}},	//   řejn, kelé, inni_, _פסקה_
  { {0xbb3a0053,0x9a76000a,0x7ddc039f,0x62853afc}},	//   _געצי, _התקף_, _pési, duho
  { {0xdb18476c,0xd627004a,0x452a0054,0xf993000a}},	// [a420] _invá, соте_, ужан_, _זרח_
  { {0x77860001,0xdb030ade,0x2492002a,0x661d476d}},	//   _улоз, _canç, rtym_, _eksk
  { {0xb87b0014,0x9bfa0053,0xdb03001c,0x2492476e}},	//   szít, נהעט, _danç, stym_
  { {0xdb010030,0x20090125,0x69d60a8b,0x7a0b002a}},	//   gelé, éain_, _joye, hętn
  { {0x69d6038d,0x69c40050,0x6b9c007c,0x40960054}},	//   _moye, _mnie, õrgk, срет
  { {0xf8b30008,0x7a0b002a,0xdb030012,0xdce00091}},	//   פשו_, jętn, _kanä, namą
  { {0x69c4002a,0xf1c30046,0x0000006a,0x0000006a}},	//   _onie, áší_,   ,
  { {0x7bc3476f,0xd657000a,0x14b6000a,0x69d610eb}},	//   _annu, זיקת_, ֶּ֥ר_, _noye
  { {0x8afc005c,0xf1c30107,0x81bd0003,0xa4fb004c}},	//   zbęd, šší_, _chœu, ָליט
  { {0x2480002d,0xfbaa0342,0x69c427a8,0x8bc6004a}},	//   irim_, утий_, _anie, ссид
  { {0x539b0053,0x441b0053,0x7ae50020,0xfd120086}},	//   נסטא, רויס, _ühtl, _کجا_
  { {0xa3b1005d,0x14c8005d,0x63a500b8,0xf2d3000a}},	//   _फ़ोन_, रमाण, zehn, לעת_
  { {0x69d60618,0x69c44770,0xdca305a7,0x62850012}},	//   _doye, _dnie, _наци, zuho
  { {0xdb010014,0xb8d1000b,0xad25012c,0x2ac60054}},	//   zelé, _ऐन_, _برمو, _гљив
  { {0x7bfb0008,0x5e78000a,0x5b7b004c,0x69d619ad}},	//   _תפוצ, יָּד, _ערהא, _foye
  { {0x91ad0023,0x69c4005c,0x9f470107,0xdb030527}},	//   _thẻ_, _gnie, diný_, _sanç
  { {0xdb010014,0xf94a0053,0xe3c50015,0x63a54771}},	// [a430] velé, _דעפֿ, يْرَ, tehn
  { {0x290c0064,0x7d1d00b8,0xa5bb4772,0x69c40d55}},	//   ğdat_, üssi, _chór, _znie
  { {0x32550010,0xdb0100dc,0xa6ab0002,0x92670015}},	//   цвер, telé, _صادق_, صدام
  { {0xd0590010,0x201e2c50,0x200c00bc,0x63a50012}},	//   аркі_, _akti_, _ajdi_, sehn
  { {0x7ddc0152,0xfe090092,0x224d0340,0x0085005e}},	//   _jésu, hắc_, _čeku_, ілко
  { {0x988c0008,0x6f870127,0xd0090054,0x7e5525e0}},	//   רָאֵ, судж, јеке_, отиц
  { {0xb7dc00b2,0xdcfb016f,0xdb011f05,0x7a0b002a}},	//   רקוי, oguć, pelé, jęto
  { {0xa1940080,0xec790561,0x91f40015,0xec990054}},	//   _насч, апи_, _فأقا, атој_
  { {0x7a120024,0x1d0907be,0x1be9024f,0x61fb02f2}},	//   nāte, репи_, идии_, _imul
  { {0x69c40048,0x69d60152,0x9f35005e,0x6c320015}},	//   _snie, _soye, _дезі, وفيا
  { {0x93fa000a,0xa9a605ab,0x9f040015,0x8d77002b}},	//   שלתי, оинд, _فوكو, _هاشا
  { {0x99f60033,0x27fa01d7,0xfe700015,0x7ae5007c}},	//   іяні, _smpn_, _أدل_, _ühtm
  { {0xfba9005d,0x69d60152,0x9f450003,0xbfba0046}},	//   क़दम, _voye, _allé_, říšt
  { {0x248001e2,0x7c56002b,0x61e24773,0x9f470533}},	//   vrim_, _بلور_, zkol, minó_
  { {0x4ded005d,0x61fb0011,0xfe6700a2,0x61e24774}},	//   _जताई_, _omul, بد_, ykol
  { {0xceb200a3,0xa5bb0125,0x4466005e,0x69c44775}},	//   ויל_, _shór, жвав, _unie
  { {0xe617017f,0x7d1600cb,0xb87b0030,0x70d30065}},	// [a440] іду_, _øyst, szír, थहोल
  { {0x2009002d,0x53c70004,0xf35a0054,0x61e94776}},	//   éail_, огум_, ршај_, _alel
  { {0x479b000a,0x75ea0069,0x61e24777,0x316a116f}},	//   _דייס, _výzb, tkol, ашло_
  { {0xea8c0053,0x61e20046,0x248000d4,0xc05a0138}},	//   רנאָ, ukol, prim_, аік_
  { {0x75fa0089,0x61e24778,0xdb0a0046,0x9f5c01c0}},	//   hůzk, rkol, _rafí, livé_
  { {0x88bb000a,0xd372006e,0xb8bb000a,0x61fb1882}},	//   יזני, _زهر_, יזנש, _emul
  { {0x65360086,0xfe6f00e6,0x1dc5000b,0xc307005e}},	//   _درگذ, ندي_, वांत, _держ_
  { {0x93430191,0x1e170015,0xdd900021,0x2cbd0034}},	//   _інте, يغية_, روخ_, _brwd_
  { {0x9f470077,0xdca30054,0xbdf70058,0xa1c30138}},	//   ginó_, дањи, تروا_, _ўбуд
  { {0x7ddc038d,0x93fa000a,0x201e0091,0x3a200061}},	//   _résu, ילִי, _ukti_, _akip_
  { {0x3eb800dc,0x93b7000a,0x61e9008c,0x201c4779}},	//   _ért_, קלטו_, _ylel, movi_
  { {0xfcaa0074,0x201c07d4,0x7a0b002a,0x2cbd0034}},	//   _ناتو_, lovi_, ręto, _frwd_
  { {0xc173013a,0x2e37000a,0x9f4702b9,0x48e40033}},	//   וחר_, _וראש_, minò_, доўв
  { {0xbebc0024,0x67290046,0xc7470015,0x201c04a6}},	//   _dzīv, řejm, تضحي, novi_
  { {0x3dc60041,0xc5fb000d,0x67e2002c,0x23c9000b}},	//   _know_, аѓа_, _môjh, रासद
  { {0x7a120048,0xe607005e,0xdb09001a,0x8cb1000b}},	//   tāte, іївн, _ónák, _अनमो
  { {0x94ab209b,0x34940c9c,0x39490020,0x96080010}},	// [a450] штва_, матр, _igas_, цэра_
  { {0xa858000a,0x61fb477a,0x250800e2,0x9f5c00bf}},	//   _ויזה_, _smul, іхто_, bivé_
  { {0x7afc002d,0x28380015,0x201c18ca,0x8c1b000a}},	//   úrth, _بأية_, dovi_, סובי
  { {0x41e4005e,0xdb180123,0xa787002b,0xc1780015}},	//   міча, _invä, _اشکو, قصها_
  { {0xf7f40086,0xa6e2002e,0xf8cb000b,0x9f4702b9}},	//   _رسید, öðva, ामिय, dinò_
  { {0x201c01a3,0xa2a6000b,0x1ea90015,0xc058002b}},	//   govi_, _टैक्, ماعي_, زشها_
  { {0x2ba9005d,0x1ea8002b,0x0000006a,0x0000006a}},	//   क़सा, قايي_,   ,
  { {0xee390001,0xc2c40015,0x61fb477b,0xdd8e0015}},	//   љни_, _تيفي, _umul, هوى_
  { {0x321d005c,0x2489001c,0x63b5477c,0x683202de}},	//   mowy_, nuam_, _kazn, læde
  { {0x321d0050,0x80a40029,0x7ae5007c,0x25a904f6}},	//   lowy_, _تمكن, _ühtk, heal_
  { {0x7bd802d7,0x4b25005e,0xda780033,0x63b501c2}},	//   _dovu, ямов, ояў_, _mazn
  { {0x321d005c,0xdd950033,0x75fa0046,0x99d60015}},	//   nowy_, _хады, růzk, ستجا
  { {0xdb1827a9,0x25a9002f,0xdb03002e,0xdb010046}},	//   _anvä, deal_, _janú, melí
  { {0x9cd60008,0x9f5c3869,0x711a000a,0x7aa50015}},	//   _מונה_, tivé_, מורפ, _فإعل
  { {0xfaa2010f,0x321d005c,0xb7b90010,0x66d60061}},	//   _защо, kowy_, цыях_, dükç
  { {0xda7a0008,0x2d8d003f,0x321d005c,0xceb2000f}},	//   _הנקר, ngee_, jowy_, עין_
  { {0x321d005c,0x248900d9,0x64a3477d,0x9446002b}},	// [a460] dowy_, guam_, ната, سپان
  { {0xd764002b,0x61350030,0x59c4000b,0x141a0015}},	//   _تندی, zülé, षाकर, حيطة_
  { {0xe7db013a,0xb7db0008,0x386900b8,0xe29a0239}},	//   _הקיש, _הקיי, _zwar_, сае_
  { {0x04460892,0x321d002a,0xc9b7000a,0xa3e8000b}},	//   _немн, gowy_, ּ֔את_, _बतक_
  { {0x25d700b4,0x55bb0008,0xdb1800c0,0xdb03002d}},	//   _זוכן_, _המכו, _invå, _canú
  { {0x74160086,0xdb0a00c0,0x3dc6477e,0x3ff40015}},	//   _روزا, _infö, _snow_, بكتر
  { {0x2cad00da,0x321d002a,0x9f470046,0x201c477f}},	//   ewed_, bowy_, chní_, rovi_
  { {0x12eb000a,0x9daa006b,0x321d002a,0xdb03006f}},	//   _הַמּ, съка_, cowy_, _fanú
  { {0x7bd8016f,0x613500dc,0x201c2064,0xeaf6000b}},	//   _povu, rülé, povi_, ुप्त_
  { {0x50b50010,0x7b70004c,0x7ae100cb,0x61350030}},	//   _ўсту, _אַרטי, fylt, sülé
  { {0x613500dc,0x443a0011,0xc4c8000b,0xe45f001a}},	//   pülé, imp_, रमुख, _gröf_
  { {0x80b3005d,0xa8990004,0xee3a0054,0x39eb02ed}},	//   _इनमे, окму_, _уне_, сьон_
  { {0x7bd8000c,0x25a9003e,0x7a3f003d,0x7dbb000a}},	//   _tovu, veal_, _jūti, _לצאצ
  { {0xca470086,0xdd3b0008,0x321d005c,0x6c7b000a}},	//   _کليه_, _העדכ, zowy_, _פרוד
  { {0x752f0050,0xdb9b0008,0x319100dc,0x63b501a3}},	//   _szcz, _הסור, lőző_, _razn
  { {0x63b5010b,0xfe090016,0x443a23bc,0x2489016e}},	//   _sazn, hắn_, emp_, tuam_
  { {0xb97c0008,0xe97c000a,0x69fc000a,0x7c280144}},	// [a470] _הנחי, _הנחש, _ללהק, oldr
  { {0x672500f2,0x68ef0064,0x321d005c,0xdb0100dc}},	//   _tyhj, ındı, wowy_, zelí
  { {0x98b901e2,0x321d005c,0x9259004a,0x63b50085}},	//   ması_, towy_, цает_, _vazn
  { {0x68320134,0x2cad0026,0x7a3f0f28,0x98b90061}},	//   ræde, ywed_, _būti, lası_
  { {0x656f0176,0x7a120024,0x321d005c,0x55ba000a}},	//   _iech, nāta, rowy_, _ומרו
  { {0x656f4780,0x321d005c,0x389c000f,0xdb460015}},	//   _hech, sowy_, ציונ, _لَ_
  { {0xd5e1005d,0x321d002a,0xdb010046,0xb284004a}},	//   _नवाज, powy_, telí, _пытк
  { {0xdb0300dc,0x660d4781,0x7bdc05f7,0x656f4782}},	//   _tanú, nnak, örun, _jech
  { {0x660d200d,0x98b90064,0x6447003f,0xe45f002e}},	//   inak, kası_, _kiji, _drög_
  { {0x7a120024,0xd1080015,0x5ba905ab,0x0c360015}},	//   dāta, _عقله_, цком_, وكية_
  { {0xeeb9201e,0x98b90061,0x6447003d,0xc9aa4783}},	//   _флеш_, dası_, _miji, овне_
  { {0xf2d20053,0x645d09e7,0x656f0107,0xce380015}},	//   דעט_, _otsi, _nech, _فأنا_
  { {0x6d59003f,0x98b90064,0x660d4784,0xa176004c}},	//   _ifwa, fası_, dnak, וערד_
  { {0xa3ac005d,0x660d00f2,0x5d3a000a,0xbebc003d}},	//   कड़ा_, enak, _ותנא, _izīr
  { {0x645d0780,0xfbd2000a,0x291e002a,0x9c08000a}},	//   _atsi, _בתג_, łta_, _מִקִ
  { {0x7a120024,0x656f1212,0x6e290012,0x660d0e05}},	//   bāta, _cech, nleb, gnak
  { {0x656f0176,0x25fd005d,0x98b90064,0xa37a0015}},	// [a480] _dech, रोधी_, bası_, قصاء_
  { {0x7a3f0024,0x9f451967,0x98b90061,0x660d4785}},	//   _rūti, _allí_, cası_, anak
  { {0x645d022d,0x2cb80024,0x7a3f0024,0x656f4786}},	//   _etsi, ārdi_, _sūti, _fech
  { {0x8b080008,0x6d4b00e8,0xf1a300d7,0xc0aa0015}},	//   הִנֵ, _ngga, вршн, قاتل_
  { {0x6604008c,0x7c284787,0x6d5d0061,0x64474788}},	//   miik, yldr, ısal, _fiji
  { {0x66040607,0x6d59016b,0x88f7000a,0x8869000a}},	//   liik, _afwa, וזנו_, פֻנֶ
  { {0xbea30b1e,0xdb080144,0xf1aa009a,0x6e2902ad}},	//   вајк, cedè, _واره_, fleb
  { {0x98b90064,0x66040f7a,0x7dd50030,0x6ce6005e}},	//   zası_, niik, _zász, діое
  { {0x98b90061,0x6da30054,0x9f5c0046,0x2e230015}},	//   yası_, тиња, liví_, خفيف
  { {0x7a120024,0x8bc30121,0x8af807f7,0x6e29068c}},	//   vāta, всюд, знос_, aleb
  { {0x660d0064,0x98b90064,0xddcb06e6,0x920801ec}},	//   ynak, vası_, žišt, _trāķ
  { {0xdb080030,0x7a12003d,0x3e7a003d,0x7c660040}},	//   nedé, tāta, mīt_, _قاتل
  { {0x98b901e2,0x660d002c,0x3e7a0024,0x09e40010}},	//   tası_, vnak, līt_, тоўн
  { {0x656f00b8,0xdce00046,0x2ca627fc,0x5bb7005e}},	//   _sech, zamě, _ipod_, _олія_
  { {0x3e7a0048,0x98b901e2,0xa3d2005d,0xdb0800dc}},	//   nīt_, rası_, वान_, kedé
  { {0x98b90064,0x644700d9,0x62850227,0xa4d5005e}},	//   sası_, _siji, vrho, нобі
  { {0x656f4789,0xd7f10029,0x98b90061,0x25a201c2}},	// [a490] _vech, _مكة_, pası_, _dbkl_
  { {0x656f00b8,0x7a120024,0xd37100e5,0x68e00123}},	//   _wech, nātn, اها_, ämde
  { {0xe0d00086,0xc7b20008,0x6447003f,0xdb080030}},	//   یزه_, _גבי_, _viji, fedé
  { {0x3e7a0048,0xd131003b,0xdb0800dc,0xf8bf0057}},	//   dīt_, هما_, gedé, ové_
  { {0xe0010010,0xc0c80001,0x645d02df,0xf8bf0144}},	//   лькi_, дује_, _utsi, nvé_
  { {0x7a360046,0x13a7002b,0x7bdc001a,0xa2950138}},	//   máte, _تنسی_, örul, _пагі
  { {0xfc480023,0x2ca601cb,0xdce00046,0xaf080015}},	//   _gửi_, _apod_, pamě, وقهم_
  { {0x24860780,0x6e203302,0x7d750015,0x02450015}},	//   šome_, gomb, رابط, _أَرَ
  { {0x3015008f,0x91ad0092,0xdb01002c,0x1c450142}},	//   _здар, _ghé_, delá, нним
  { {0xeb990001,0x2e4b0063,0xc052000a,0xa3d2000b}},	//   чио_, _дядо_, _עזב_, वाय_
  { {0xdd000024,0xf99f02b9,0x3e7a003d,0x6e202d66}},	//   ātāj, ffè_, cīt_, bomb
  { {0x61f901e2,0x9d750053,0xce07002b,0xdeba000a}},	//   _çalı, _װײַס_, _غذاي, _ממעל
  { {0x0d760074,0x4421013c,0x39440123,0x660401be}},	//   _سخنگ, koh_, äms_, viik
  { {0x7a360046,0x1602000b,0xcc7605bd,0xdb080030}},	//   dáte, रोनर_, _טענה_, zedé
  { {0xe7940074,0x660400f2,0xf7530029,0xfe090016}},	//   _یادک, tiik, انفج, hắm_
  { {0xf1b9065d,0x7a3f0007,0x75ea006f,0x8afa000a}},	//   _naš_, _būtu, _výzo, _מהצי
  { {0x3e7a0024,0x66040fb2,0xe5060015,0x480a006b}},	// [a4a0] zīt_, riik, ربري, _неин_
  { {0x660400f2,0x2bd2000b,0x389b000a,0xf507004a}},	//   siik, ताया, _ציינ, хнул_
  { {0x7a120024,0x25fd005d,0x74130029,0xf1b9016f}},	//   nāto, रोही_, دولا, _baš_
  { {0xf8a4000b,0x0000006a,0x0000006a,0x0000006a}},	//   _ओहाय,   ,   ,
  { {0x71730086,0xf123034e,0x44210375,0x9f450144}},	//   اهها, льшо, boh_, _allà_
  { {0x3e7a0048,0xc0590036,0x987b0053,0xdb0800dc}},	//   tīt_, фії_, לאנט, sedé
  { {0x4438018b,0x03a3005e,0x7bdc001a,0x6e20478a}},	//   _ihr_, _щиро, örum, tomb
  { {0x3e7a0048,0xe2a6002e,0x71660029,0xf653000f}},	//   rīt_, öðum_, _سارك, נצח_
  { {0x3e7a0048,0x6e20478b,0x30860058,0x6d57009a}},	//   sīt_, romb, _سلاف, رجيح_
  { {0x6497000a,0x307b000a,0x44380028,0x3e7a003d}},	//   עדיף_, _מאמנ, _jhr_, pīt_
  { {0x6e2000bd,0xda770139,0xdfcf0015,0x5ba30033}},	//   pomb, няя_, _ديل_, урыз
  { {0xddea0002,0x7d260015,0xf1c60157,0xf8bf01c0}},	//   _عرضه_, _كفان, _रोमन, tvé_
  { {0xf8bf0152,0x291e0064,0xebe6478c,0x44380012}},	//   uvé_, ştan_, _подп, _ohr_
  { {0xecb70008,0xf8bf428a,0x7a12003d,0x8c18002b}},	//   _נפוץ_, rvé_, bāto, _تيتر_
  { {0x2cb80048,0x25a00026,0x5b570008,0xfbd3000a}},	//   ārdu_, ffil_, _איוב_, _תתצ_
  { {0x25a01639,0x3860001a,0x7a3631ab,0xd5b82a30}},	//   gfil_, _ftir_, táte, нсу_
  { {0x69cd003f,0x28f9004a,0x2bb7000b,0xe4530040}},	// [a4b0] _inae, _цепь_, _असमा, اضر_
  { {0xdc8b000a,0x94390015,0x67e2006f,0x4438478d}},	//   לְבָ, ذكاء_, _dôjs, _chr_
  { {0x8c1b0008,0x97560008,0x92950b75,0x1756000a}},	//   לומי, _ביתו_, таец, _בסתר_
  { {0x442100d9,0x225c0046,0xf67a000a,0x443813aa}},	//   soh_, ívka_, _קארמ, _ehr_
  { {0xf1b9060b,0x7c380020,0x442101c2,0x70390015}},	//   _vaš_, _ohvr, poh_, وستس_
  { {0x9f4502c1,0x8fa5243d,0x969b000a,0xa8cc000a}},	//   _allá_, таке, ִׁ֥י, ל֖וֹ
  { {0xa75c0008,0x91ad0016,0xf1a7478e,0x6fb2002b}},	//   הדור, _chẽ_, _пран, شميا
  { {0x2489478f,0x7a12003d,0xbba9000b,0xf2d2004f}},	//   oram_, vāto, क़्क, _דעל_
  { {0x44380012,0x00db0040,0xdb0301c0,0x0000006a}},	//   _yhr_, _عبرت_, _daný,
  { {0xa5bb002e,0xcf270015,0x68e60091,0x6ca40015}},	//   _skól, _كراي, vykd, اصيل
  { {0x05e1005d,0x7de70036,0x0dcb00d7,0xa3d20231}},	//   _नवंब, _підд, _нуди_, वात_
  { {0xdd1d0011,0xbed6000a,0x7a12003d,0x9cb50015}},	//   _câţi, _בועז_, rāto, _لمؤت
  { {0x48fc005d,0x7c2100e8,0x61d6000a,0x317a000a}},	//   _लेखो_, polr, דורף_, וארד
  { {0x9784002b,0x20074790,0x8b94006b,0xb8da0065}},	//   دیده, nini_, _бръч, _घन_
  { {0xcf92000a,0x2bda002b,0x2ad20015,0xd62a30ee}},	//   יטם_, _تانک_, _نيوآ, дове_
  { {0x2489002e,0x20074791,0x75d60021,0xc6430015}},	//   fram_, hini_, خيرا, لَّي
  { {0x696500e6,0x20070278,0xe021000b,0xd8b3002b}},	// [a4c0] _صديق, kini_, यवाद_, _نميخ
  { {0x7ae50020,0x93590054,0xdb01063b,0x741300c3}},	//   _ühts, ерцу_, relæ, لوقا
  { {0x877b0053,0xd2590484,0x93430937,0x8146002b}},	//   _קאטי, еці_, анфе, چنان
  { {0x463a005e,0xe2970054,0x24894792,0x9f5c013f}},	//   _ічня_, ђач_, bram_, divá_
  { {0x4096005f,0xa3d2005d,0xf9930008,0x70f60015}},	//   трет, वाद_, שרד_, خسائ
  { {0x443800b8,0xbea60080,0x20074793,0xe363005e}},	//   _uhr_, вший, gini_, _вкри
  { {0x59b2005d,0xe7a4000b,0xdd900021,0x63bc4794}},	//   ज़ार, ख्यप, موث_, _iarn
  { {0x6e390034,0x531b000a,0xbdb4012e,0x63bc0a17}},	//   _chwb, _חולצ, убиј, _harn
  { {0x61e0002f,0x63bc12ea,0x20074795,0xe10a0033}},	//   _ioml, _karn, bini_, _ўезд_
  { {0x2bd2000b,0xdb1a0030,0x61e00030,0xa0670923}},	//   ताधा, ldté, _homl, _рафа_
  { {0x291e0011,0x1a780010,0x7ec80152,0x229c0107}},	//   ştal_, эбны_, _dépô, ník_
  { {0xc27b013a,0x627b000a,0x1ea90015,0x2d9200cb}},	//   ורטי, ונטנ, _سامي_, _øye_
  { {0xcdf70008,0x2cb80024,0xbbbc000b,0x38c9002b}},	//   _במאי_, ārds_, ्फ़ॉक, راحی_
  { {0x69cd0176,0xc0530053,0x629e02df,0xaa580015}},	//   _wnae, יזש_, ktpo, _كلتا_
  { {0x5c37039e,0xdceb0024,0x07090015,0x37740033}},	//   _שרון_, _iegā, ريري_, шыўс
  { {0x2489469c,0x20074796,0x229c0069,0x7a360046}},	//   tram_, zini_, dík_, rátc
  { {0xdb03002a,0x20070061,0x0495006e,0x94740015}},	// [a4d0] _fanó, yini_, طلاح, لدلا
  { {0x7a36002e,0x44270b19,0x229c04b2,0xdc9b000a}},	//   máta, ôn_, fík_, וסמכ
  { {0x20074797,0x63bc215a,0xc3480033,0x61e00030}},	//   vini_, _darn, вяце_, _boml
  { {0xa1590010,0xf7550086,0x24860007,0xa5f90175}},	//   хаду_, _جنگج, šoma_, _чему_
  { {0x3c390152,0x20074798,0x80a50015,0x61e00046}},	//   lève_, tini_, امتن, _doml
  { {0xe0d000a2,0x27e14799,0x6024005e,0x3204479a}},	//   تزم_, _john_, адіа, _emmy_
  { {0x20070482,0xed59479b,0x3e890015,0x60c20091}},	//   rini_, ной_, رَةَ_, avom
  { {0x2007479c,0x27e10012,0xf99f0144,0x27120030}},	//   sini_, _lohn_, inès_, lőné_
  { {0x2007479d,0xdd110064,0xc172000a,0xfbd10015}},	//   pini_, _düşm, _לחן_, متد_
  { {0xdb180046,0x61400046,0x6d5b3ca1,0xe9df01c0}},	//   _zavé, _dílč, scua, hmúd_
  { {0x224d00df,0xba750086,0xaa4607f8,0x20050061}},	//   _kiek_, داخت, леол, _imli_
  { {0x75ea0089,0xc332000a,0xdb081279,0xe8fa1d90}},	//   _výzk, מוי_, cedí, елм_
  { {0x224702d5,0xf98a002b,0xdb010123,0xdb03479e}},	//   ínky_, ونگي_, delå, _panó
  { {0x224d00dd,0xdb01008c,0xdb1a0030,0x981600c3}},	//   _liek_, telä, zdté, ابحا
  { {0x98a50048,0xa3d2005d,0xd7570086,0x8c1a000a}},	//   ālā_, वास_, الفت_, _אוסי
  { {0x63bc0020,0x229c479f,0xdb010123,0xa3e6000b}},	//   _sarn, vík_, relä, यॉन_
  { {0x20ce002e,0xfbb7000b,0xd5751070,0x63bc25b6}},	// [a4e0] iðið_, _असाम, русь, _parn
  { {0x56640086,0xb3850015,0x61e00123,0x69a0000b}},	//   _نگرف, لجمه, _soml, ग्री
  { {0x179b0053,0x38720026,0xf79b000a,0xc7b3000a}},	//   _אייב, _hwyr_, _אבימ, _הבת_
  { {0xa3d2005d,0xbbe0005d,0xa1ba0015,0x63bc26c9}},	//   वाह_, _पक्क, عطاء_, _warn
  { {0xd0d4006b,0xdb1a0030,0x63bc47a0,0x229c013f}},	//   ролъ, rdté, _tarn, sík_
  { {0xb4c2005d,0xceba0001,0x7a0b005c,0xb4c0000b}},	//   ्मी_, ељи_, nętr, ंटी_
  { {0x7a12003d,0x290c0061,0x38720034,0x9757000a}},	//   gātk, ğday_, _lwyr_, ניקו_
  { {0x11da0029,0x5d540254,0xdb01007c,0x20ce001a}},	//   _ثورة_, шкит, ndlõ, gðið_
  { {0x7ddc0014,0x644e000c,0x25d70053,0x3157000f}},	//   _kész, _kibi, רופן_, _תימן_
  { {0x644e003f,0x34b7000a,0xd286000a,0x224d2123}},	//   _jibi, נפים_, ְךָ֙_, _ziek_
  { {0x38720026,0xc3fb01ac,0x600b000a,0x59f90033}},	//   _awyr_, גליש, _נִמְ, веня_
  { {0xf2d300b2,0x27e100b8,0xadb70029,0xc27b000a}},	//   צער_, _sohn_, _مهما_, ערכי
  { {0x79840176,0x7d7b0053,0x7afa0030,0x79540015}},	//   _ddiw, _טראג, sztt, صَّا
  { {0x7a3647a1,0x4ae60015,0xaae60021,0xf41f0123}},	//   ráta, _مثبّ, _مسبو, _iväg_
  { {0xd90f0086,0xe7f6005d,0x85a70004,0x7a360046}},	//   تیک_, ीफ़ा_, лјад, mátn
  { {0xb4c2005d,0x2bd2005d,0x35b50b1e,0xf99f0781}},	//   ्मू_, तावा, јбар, rnès_
  { {0x7b040007,0xa4d4005e,0xe4a70033,0x224d006f}},	// [a4f0] žutė, боті, ырво, _riek_
  { {0xdce00048,0x9f4500f2,0x386400dc,0x7a360247}},	//   lamē, _yllä_, ímre_, nátn
  { {0x41e70484,0xf776000a,0x644e47a2,0x96f9006b}},	//   ліда, _דעתי_, _dibi, _рент_
  { {0xd6d8005e,0xb15c005e,0x25b20061,0x26da004f}},	//   _сть_, енцi, ceyl_, _סקרמ
  { {0x25190008,0x7a360107,0x656d013c,0x3519000a}},	//   _יוֹא, kátn, mbah, _יוֹנ
  { {0xdceb04f9,0x224d28ef,0xd9b2000b,0x656d47a3}},	//   _legă, _wiek_, _जस्ट, lbah
  { {0xa3d2014e,0x224d1cdb,0x141a0008,0x7fb60015}},	//   वार_, _tiek_, _יושב, شهير_
  { {0x656d0ac0,0xfbb7000b,0xdceb0045,0x78ad0046}},	//   nbah, _असहम, _negă, _opav
  { {0x20ce0084,0x4bd50033,0xec760174,0x656d01d7}},	//   rðið_, аўну, апы_, ibah
  { {0x7a120048,0xa3ab005d,0x644e016e,0x764f002a}},	//   māti, _कॉम_, _xibi, _licy
  { {0x78ad47a4,0x63800046,0x99990030,0x656d068c}},	//   _apav, lání, első_, kbah
  { {0xdb2400dc,0xd946023b,0x59831cd9,0x60c947a5}},	//   ásáv, иени, олюб, _krem
  { {0x7a120048,0x63800046,0x656d0012,0xf936056d}},	//   nāti, nání, dbah, рхню
  { {0xacfa000a,0x656d01c2,0x18670a2b,0x7a36005a}},	//   _שהסכ, ebah, рари_, cátn
  { {0x7ddc0014,0xf74647a6,0x656d0012,0x2bd2000b}},	//   _rész, рево, fbah, तारा
  { {0x96550063,0x05660354,0x63800046,0xee46001a}},	//   сърч, рван, kání, _þýtt_
  { {0x9f47002f,0x7a120024,0x8cc8005d,0xa3d2005d}},	// [a500] ghnú_, jāti, ़ियो, वाल_
  { {0x187b00b2,0xdb0802d5,0x63800089,0x7bc147a7}},	//   _שטיב, ledá, dání, ndlu
  { {0xe29a01d9,0x7bc10020,0x35a60329,0x9f5c0b56}},	//   тае_, idlu, _канг, nivå_
  { {0x71a6008f,0x60c947a8,0x506647a9,0x867b000a}},	//   радз, _brem, атка, _ברטו
  { {0x9f4722a8,0x7ddc0030,0x7a12003d,0x10a30099}},	//   chnú_, _tész, gāti, жичн
  { {0x7a3d00dc,0x24800024,0x60f70010,0x76440717}},	//   méte, msim_, шнія_, lmiy
  { {0xd335008f,0xf7730008,0x7a360f49,0x7a3d1f0d}},	//   _гэты, חקו_, játo, léte
  { {0x80660191,0x76440064,0x60c947aa,0x444404dd}},	//   _вваж, nmiy, _frem, lm_
  { {0x2bd2005d,0xdceb0011,0x4444115b,0x7a12003d}},	//   ताला, _regă, om_, cāti
  { {0x4444002d,0x8c430004,0xed590085,0x3f78000a}},	//   nm_, оење, rdža_, _תָּע
  { {0xfeba0029,0xeb970004,0x444447ab,0x76440061}},	//   _جاءت_, шиќ_, im_, kmiy
  { {0x4444020d,0x248047ac,0x7d080024,0xa3d2000b}},	//   hm_, ksim_, tīrī, वाँ_
  { {0xfd12002b,0x98b801b7,0xb4c0000b,0xb4c2000b}},	//   _بجا_, алят_, ंटो_, ्मो_
  { {0xbec7003d,0x7a3d0003,0xdce0003d,0x7cfb000a}},	//   stīš, déte, samē, _שִׁק
  { {0x0cb6014e,0x89d90086,0x24800064,0x7c3b000a}},	//   _अनुम, _موثر_, esim_, _שתוס
  { {0xb9990001,0x9f47002d,0xdb180097,0xe55507c1}},	//   _свих_, thnú_, _javí, скањ
  { {0x290f0123,0x2480003d,0xa3d2000b,0x656d47ad}},	// [a510] _äga_, gsim_, वां_, rbah
  { {0x63800089,0x1da6005d,0x7a120024,0x9cd7000a}},	//   vání, क्तत, vāti, בומה_
  { {0x752f005c,0x7d1d0030,0x60c91129,0x71550015}},	//   _wycz, üssz, _srem, مناض
  { {0xdb1847ae,0x444400ed,0x752f002a,0xe298005e}},	//   _naví, am_, _tycz, раї_
  { {0x7a360264,0x7c280b7e,0x273c0046,0x44440454}},	//   záto, kodr, _tání_, bm_
  { {0x289a00b2,0xafe20080,0x60c947af,0x8e850015}},	//   ריװא, зошл, _vrem, ملته
  { {0xe7ff005d,0x75ea0227,0xbda50015,0x7a12003d}},	//   _उतना_, _výzv, محظو, sāti
  { {0xc332000a,0xd087004a,0xcd35002b,0x60c90aff}},	//   _זול_, _выжи, یرکب, _trem
  { {0xd0e90086,0x2d860026,0x02440015,0x2bb90015}},	//   _حکام_, _ddoe_, _ذَكَ, هادة_
  { {0x64450125,0x7a361dde,0x99820046,0xa1f8003d}},	//   nmhi, táto, toků_, _cīņā_
  { {0x7bc10020,0x7a3d0030,0x64450125,0x660d47b0}},	//   rdlu, zéte, imhi, kiak
  { {0x69d8005d,0x99820046,0x8de40015,0x7a362a76}},	//   याधी, roků_, _وكله, ráto
  { {0xfd56013a,0x4444005c,0x660d400e,0xdb08006f}},	//   _השני_, ym_, diak, redá
  { {0x7a3d0014,0xdb080046,0xdb180046,0xe9df006f}},	//   véte, sedá, _zaví, ajú_
  { {0xaa950029,0xcc3a004c,0x76440061,0xe45f0123}},	//   _العث, _געסט, tmiy, _dröm_
  { {0x6a640029,0x7a3d00dc,0x5bb7005d,0x444400e7}},	//   _بطول, téte, _असुव, wm_
  { {0x76440064,0x09f7000a,0xe4360015,0x141a0015}},	// [a520] rmiy, _למקם_, مفرد, هيرة_
  { {0x3ea9005c,0x32d60010,0x660d007c,0x73e30054}},	//   łaty_, йцес, aiak, поуз
  { {0x660d1bf1,0xd36f0015,0x4444297f,0x4b7a004c}},	//   biak, ءهم_, rm_, רטעג
  { {0x7229005e,0x44440b29,0x63550046,0xf772002b}},	//   аців_, sm_, třní, _باک_
  { {0x399b0053,0xe1650015,0x444447b1,0xdf7809a0}},	//   רינד, آدمي, pm_, аблі_
  { {0x93260086,0xf3e60036,0x7a120024,0x0eb4000b}},	//   _هرزن, _ужго, mātu, ंबलड
  { {0xf2d8000a,0xadd816cf,0x7a1201ec,0x0000006a}},	//   _דַּל, имку_, lātu,
  { {0x21a30001,0x7c280026,0x13170008,0x867b0053}},	//   _нисм, wodr, _החלל_, ארקו
  { {0xb87b00dc,0x9bc6004a,0x7a12003d,0x7a3d01f6}},	//   nyít, бёнк, nātu, hétc
  { {0xe0f7000a,0x8fe50015,0x7c280091,0xaae60058}},	//   _הצמח_, _وألم, uodr, مسجو
  { {0xfe720015,0x9a67002b,0x7c2847b2,0xfa1900af}},	//   _ردا_, یمیل_, rodr, ижој_
  { {0x7f3b00b2,0x1e570008,0x7a12003d,0x7a360030}},	//   _געבו, _השאר_, kātu, látj
  { {0x88170015,0x17fb0015,0x7bdc001a,0xcd360067}},	//   مبسط, هرسة_, örus, _اراب
  { {0x8cb7000b,0xf77000c3,0x660d002a,0xad1b004f}},	//   ्टरो, فاف_, wiak, _גודר
  { {0xa3d2005d,0x6b7b00a3,0xa3cc021e,0x4b7b0643}},	//   वाई_, _גרונ, _शोध_, _גאוו
  { {0x963500e2,0x78ac0123,0x9a6700c3,0x0000006a}},	//   інац, ålvä, _اميل_,
  { {0x045b0086,0x4c78000a,0x94770015,0x660d47b3}},	// [a530] اجرت_, שָֽׁ, إدرا, riak
  { {0x660d160f,0x1878000a,0x7a360030,0x443310eb}},	//   siak, _העזר_, játj, ulx_
  { {0xe1f0002b,0x386901c2,0x660d430c,0xd5c40065}},	//   کسل_, _htar_, piak, _लोकज
  { {0xd6e8000f,0xa4d50127,0xdb010293,0xd5bb011e}},	//   _הַשָ, _домі, relø, _ссо_
  { {0xdb0101f0,0x659a000a,0x661d0079,0x0000006a}},	//   selø, _דירק, _ijsk,
  { {0xa87c0053,0x187c000a,0x987c000a,0x7a040030}},	//   ראגר, נטוב, נאוט, lőtt
  { {0xa294005e,0x479c004c,0x25a90034,0xfe450121}},	//   _нарі, טיגס, ofal_, онко
  { {0xdb0a00b8,0x387e005c,0xee3900d7,0x36f8000a}},	//   _dafü, ątrz_, јни_, מצום_
  { {0xada80029,0x1fa700d8,0x386901d7,0x116a002b}},	//   صديق_, _грег, _ntar_, _خلقی_
  { {0x4aa90ea8,0xa3d2000b,0x10170021,0x7a36006f}},	//   акон_, वाए_, _ابرد, rátm
  { {0xbf15003b,0xa3ab000b,0x6f64002b,0x9f050021}},	//   _بواب, क्य_, _رهنم, _بوضو
  { {0x7a360089,0xf769000a,0xf1cf000b,0x753d002a}},	//   mátk, _יק_, _सोमन, _ozsz
  { {0x91bf0023,0xb9030010,0x893600e5,0xac191dd3}},	//   _chủ_, дзяк, تعدا, _коду_
  { {0xcb690036,0xfcfa0053,0x7a120024,0xf7720115}},	//   _таке_, _כּול, vātu, باح_
  { {0x7bc30011,0x26cc2a18,0x65c60063,0x4e89000a}},	//   _ianu, ído_, обва, יָּ֣
  { {0xbb3a004c,0x7bc347b4,0xf7431764,0x7a1201ec}},	//   _דעצי, _hanu, фесо, tātu
  { {0x69d60077,0x7bc347b5,0x9f640061,0x64a31356}},	// [a540] _inye, _kanu, _ütçe_, мата
  { {0x245f0026,0x2d8b002a,0x38a40118,0xdc88000a}},	//   _dîm_, ócej_, mör_, מְעָ
  { {0x05760196,0x69c60134,0xa5bb002e,0x7bc30faa}},	//   _واحد, odke, _bjód, _manu
  { {0xcb120008,0xdb1a00dc,0xd010002b,0x69c62f80}},	//   ולב_, ndtá, کلت_, ndke
  { {0x200e0061,0x7a3d1e37,0x38a4203a,0x22460030}},	//   tifi_, néta, nör_, rmok_
  { {0x69c410cc,0xbe8a03fc,0x03b60015,0xde580033}},	//   _laie, асие_, _بإحد, бакі_
  { {0x69d6000c,0x59ca005d,0x7a3600dc,0x38a404d4}},	//   _onye, ियार, rátj, hör_
  { {0x85f700b2,0x38a40d9c,0xdb1801b2,0xd657000a}},	//   ַציע_, kör_, _navá, חיקת_
  { {0x6fb60029,0x62830057,0x1da6000b,0x50650015}},	//   _ومرا, ánov, क्षत, _فطلق
  { {0xbd8a0086,0x7a3603d9,0x3f9e0046,0x69c6042f}},	//   _چنان_, láth, _uctu_, edke
  { {0x80c2005d,0xda350010,0xc43b000a,0x38690a41}},	//   लिके, зены, שתיי, _star_
  { {0x38a400c0,0x91bf0092,0x7a36002d,0x61e247b6}},	//   för_, _phủ_, náth, njol
  { {0x38a400c0,0x7a3d0152,0x99a500dc,0x987401f3}},	//   gör_, géta, ítők_, мляц
  { {0xf093000a,0x61e2008c,0x7bc316ad,0x4c9b000a}},	//   ונש_, hjol, _ganu, _כבדו
  { {0x98ac0024,0xe7300029,0x45d5201e,0xadee000b}},	//   ādā_, نصف_, повс, _जवान_
  { {0x91bf0092,0x2bd2000b,0x7a3d0003,0x7bc30bbd}},	//   _thủ_, ताका, béta, _zanu
  { {0x8ccd014e,0xe5340036,0x2902005c,0x24920026}},	// [a550] तियो, деть, czka_, grym_
  { {0x69a7014e,0xa3d2005d,0xd7f10029,0xd3a70010}},	//   ट्री, वाग_, _أكد_, ўрап
  { {0x77ba0008,0x67ba0008,0xd347002b,0xb8820046}},	//   _המתח, _המתק, زیره_, říte
  { {0x245f0176,0x2bb7005d,0x5bb7021e,0x2492002a}},	//   _tîm_, _अस्थ, _अस्व, brym_
  { {0x3cf4000b,0x40353f64,0xca38000a,0x3f6906bf}},	//   इनों_, педс, קנדה_, било_
  { {0x60080010,0xa2ad000b,0x2898000a,0x7205002b}},	//   онім_, ीबद्, קדון_, _کورم
  { {0xfd4c0023,0xf1c6005d,0x645d454f,0x38a400dc}},	//   _triể, _रोकन, _husi, zör_
  { {0x645d000c,0x657d003f,0x3d07005d,0x171c0135}},	//   _kusi, _jesh, िछले_, יווע
  { {0x4c350010,0x628547b7,0x645516d3,0xdb1a02de}},	//   зэнт, lsho, _kizi, ndtæ
  { {0x1c420892,0x7a3647b8,0x6ff70015,0xac090033}},	//   нным, máti, _بسرط, ённа_
  { {0x69c447b9,0xda650036,0xf4120008,0xbbe80015}},	//   _paie, явни, תפי_, تريم_
  { {0xa3ab0372,0xfe700086,0x7bc3003f,0x38a447ba}},	//   क्त_, _شدم_, _wanu, tör_
  { {0xc955008f,0x645d00df,0x8d5a0008,0x7bc347bb}},	//   дтры, _nusi, _הכני, _tanu
  { {0xa3ab005d,0x61e2002a,0x7a3d47bc,0x4b33002b}},	//   _कॉल_, zjol, réta, _يکدس
  { {0x61fb0005,0x38a40064,0x29020fce,0x4b7a000a}},	//   _olul, sör_, szka_, _האצו
  { {0xd90d0074,0x645d1027,0x7a3d32ab,0xc6c30033}},	//   ایی_, _busi, péta, эйск
  { {0xdb0a0084,0x65640064,0x64550064,0xf9fb0008}},	// [a560] _hafð, rcih, _bizi, _להקמ
  { {0x64550089,0xd40a0021,0x628547bd,0x61fb06d2}},	//   _cizi, حترم_, fsho, _alul
  { {0x645547be,0x1dbd000b,0xa75b000a,0x375b000a}},	//   _dizi, ्यात, _לדיר, _לכיד
  { {0x6d590026,0xa3cc000b,0xb0c7000b,0x11e6004a}},	//   _ngwa, _शोर_, लिंग, яжем
  { {0x61e90384,0xf0f8000b,0x61ed007c,0x61e247bf}},	//   _doel, ्छेद_, öala, rjol
  { {0x6d590035,0x61fb0020,0xdcff0046,0xdb010030}},	//   _agwa, _elul, ůvěr, felü
  { {0x27e500dc,0x6285002d,0xfe6f0015,0xe29715f1}},	//   ölni_, csho, هدي_, _нар_
  { {0x225c0046,0x531b000a,0xbda60015,0x61e947c0}},	//   ívku_, _הולצ, سحبو, _goel
  { {0xc0590036,0x6283003d,0xa3c2000b,0x7c960058}},	//   _діє_, šnot, ्यप_, أشعا
  { {0xcfaa0086,0x70fb000a,0xbf650015,0x3a2001d7}},	//   _دارم_, _ההמח, _قدمو, _ajip_
  { {0xdfa50031,0xdb01006f,0xb4e80065,0x0000006a}},	//   _تحقي, pelý, बहु_,
  { {0xbef7000a,0x6f4b000a,0xcefe0061,0x0dc90015}},	//   _מצבו_, _הֲדַ, ışın_, _وبنى_
  { {0xf9680033,0x6b812a2d,0x657d47c1,0xc8671cd9}},	//   ярэй_, balg, _resh, ятни
  { {0x1cbb000a,0xccf3000a,0x9cd70643,0x645d47c2}},	//   _למדע, _רכס_, _מודה_, _rusi
  { {0xa3e0005d,0x645d1a37,0x7bd80150,0x4c3b000a}},	//   थान_, _susi, _invu, _התגב
  { {0x645501e2,0xa4d50036,0xe6540036,0x38580086}},	//   _sizi, мобі, евсь, _کشيد_
  { {0x9f450003,0x99450015,0x5455006b,0xc8c4000b}},	// [a570] _volé_, _تَظه, дват, _लैपट
  { {0x78fc0008,0xa87c0008,0xc9540008,0x657d00b8}},	//   _לפחו, _האזר, _אמפ_, _wesh
  { {0x645547c3,0xf772000a,0xfbae000b,0xa2d500c3}},	//   _vizi, _שקט_, ज्यम, بيات
  { {0x2fc501f0,0x645d47c4,0xdb010030,0x7a36026a}},	//   _salg_, _tusi, velü, táti
  { {0xf4850074,0x645d022d,0xf3f30029,0xc9180053}},	//   _تاجی, _uusi, _كأس_, ּחות_
  { {0x6d590034,0x889c000a,0xd0110015,0x7a3647c5}},	//   _sgwa, מבדי, ضلع_, ráti
  { {0x3e7a0048,0x61e90234,0x2fc50293,0x7a3603bc}},	//   gūt_, _toel, _valg_, sáti
  { {0x7bc80026,0x201c0144,0xdce0003d,0x7a3647c6}},	//   eddu, anvi_, camī, látv
  { {0x1c45005e,0xf1b2000a,0xdb08006f,0xfd110015}},	//   мним, _בסן_, cedú, ضجة_
  { {0x3e7a0048,0x9f63022d,0xa3c2014e,0x798d0026}},	//   būt_, ävät_, ्यय_, _adaw
  { {0xfc460089,0x7a3d0f1b,0x321d0034,0xda0a002b}},	//   _říct_, rétn, onwy_, قيده_
  { {0x7a120024,0x7bd80077,0x8e3b0015,0x6b8147c7}},	//   gātp, _envu, _اسطر_, salg
  { {0xb4bc005d,0x7a3d00dc,0x850c005d,0x6b810020}},	//   _आने_, métl, _सेंट_, palg
  { {0x1c440036,0xfd1000e5,0xdce0003d,0xba3d0091}},	//   _знім, _حجم_, zamī, ntįj
  { {0xceb2000a,0xa3d1000b,0x46a3006b,0xe7ff000b}},	//   ֣ין_, वयन_, карв, _उतरा_
  { {0xa3ab005d,0xceb20008,0xda7a000a,0x2d9f0738}},	//   क्स_, כיל_, _ונקר, ngue_
  { {0x7a0b002a,0x13ea2ca0,0x2d9f039f,0x69c001f6}},	// [a580] jęty, омай_, igue_, ômeu
  { {0x798d005c,0x833a004a,0xc509006e,0xe3b707ec}},	//   _zdaw, очет_, ستقل_, мбу_
  { {0xb7db000a,0xe7db000a,0xc7f7000a,0x38600077}},	//   _וקיי, _וקיש, _חזית_, _huir_
  { {0x5679004f,0xf234009a,0x0000006a,0x0000006a}},	//   _מְשׂ, رباک,   ,
  { {0x987a0053,0x50d60086,0x7bc80d75,0x55bb000a}},	//   קאַט, بزار, yddu, _ומכו
  { {0x7a3647c8,0xbfaa005e,0xdce0003d,0x386026df}},	//   mátu, ітле_, samī, _muir_
  { {0x4ea60004,0x1dda000b,0x7a360b31,0x03a301eb}},	//   фрла, भालत, látu, _широ
  { {0xddea0015,0x386d0045,0xef18003d,0x25a047c9}},	//   ترته_, ţeri_, _ceļa_, ngil_
  { {0x80a60074,0x7a120024,0x7a360030,0x06370643}},	//   _زمان, vātp, nátu, ונקט_
  { {0x2d9f08d2,0x7bc80034,0x0000006a,0x0000006a}},	//   ague_, uddu,   ,
  { {0x7bc81745,0x78b60091,0xca15006b,0x7ec70030}},	//   rddu, _apyv, еднъ, répá
  { {0xdde30011,0x7a360030,0xe811000b,0xbf170058}},	//   ărţi, kátu, डोना_, _تقمص_
  { {0x3860017e,0xd90f0086,0xd1260002,0xfc2f002b}},	//   _cuir_, شید_, ام_, طحی_
  { {0xdc8b01d8,0x2d8447ca,0xdd3b000a,0x0cbc000b}},	//   _וְהָ, lame_, _ועדכ, ्टीम
  { {0x0bb700a3,0xa3bf000b,0xdcc80016,0xdb9b004f}},	//   _חלום_, ूएस_, _hỉ_, _וסור
  { {0x4d7b0053,0x7c3a18af,0xdcc80092,0x38600003}},	//   ַרבע, lltr, _kỉ_, _fuir_
  { {0xb9550036,0xd8470036,0x2d840007,0x54990010}},	// [a590] _явищ, _охоп, iame_, яваў_
  { {0xe8d60008,0xeddb000b,0x59dd000b,0xdcc80016}},	//   _נותר_, _मच्छ, यावर, _mỉ_
  { {0x8707008f,0x9259005f,0xa3ab005d,0xe2980036}},	//   _цяпе, чает_, क्ष_, дає_
  { {0x2d8400df,0x0b150053,0xe45f0123,0x7c3a0012}},	//   jame_, ײַער_, _bröt_, hltr
  { {0xb0680029,0x2d842e1c,0x3f69226f,0x7a360052}},	//   وصول_, dame_, пило_, mátt
  { {0x764d0064,0x7a360f3c,0xdb460015,0xdfd40033}},	//   lmay, látt, _مَ_, кочы
  { {0x24580080,0x9f450251,0x2d8447cb,0x7d16001a}},	//   _царь_, _allò_, fame_, _þysj
  { {0x764d3279,0xa3ab005d,0xdcc80016,0xada51952}},	//   nmay, क्र_, _bỉ_, хаил
  { {0xe1340010,0x248947cc,0xed590085,0x2d9f47cd}},	//   _анты, nsam_, ježe_, rgue_
  { {0x3ec4022d,0x5ba9017c,0x7a36002e,0xf538000a}},	//   ästä_, чком_, hátt, ונחי_
  { {0xe7e3005d,0x764d0064,0x20c7000b,0xa0080015}},	//   खाना_, kmay, लिकध, _تقلل_
  { {0x2d840041,0xc7a901e4,0x600d002a,0xd9ca000b}},	//   came_, _לב_, dźmi, ियेट
  { {0x7e610384,0x39350033,0x6119000a,0xe8f747ce}},	//   _hulp, вэрс, לוֹה, еля_
  { {0x291e0011,0x6e3b001a,0x2489007c,0xd116000a}},	//   ăta_, llub, dsam_, תקשה_
  { {0x45d6029f,0x1da6000b,0xabfa000a,0xf62607c3}},	//   нцат, क्कत, _מהסר, едво
  { {0xa2c3005d,0x6e3b02f2,0x18a600eb,0x99e90015}},	//   रबन्, nlub, _заим, _يعيق_
  { {0xdcc80016,0xf50a0190,0x24890dca,0x798647cf}},	// [a5a0] _xỉ_, чнал_, gsam_, makw
  { {0x36c605e6,0x443a0150,0xa3ab000b,0x7a3610e5}},	//   _због, ulp_, क्ल_, rátu
  { {0x2bf600b2,0x25f2005d,0x1bf60053,0x877b000a}},	//   עמען_, ीसदी_, עצער_, _מאיי
  { {0xeac90092,0x02060010,0xa5bb001a,0x30a60121}},	//   _mẹ_, эзен, _hjón, еркв
  { {0x2d84002c,0x24890026,0xb2370015,0x7a360030}},	//   vame_, csam_, ركها_, láts
  { {0xe7e3005d,0x6e94000d,0xd12f0015,0xdcc80016}},	//   खाया_, вику, حمه_, _rỉ_
  { {0x75f80227,0xf773000a,0xdb010012,0xdcc80016}},	//   _nízk, נקה_, nflä, _sỉ_
  { {0x433b00b2,0x63be0ccd,0xb148002b,0x6e3b001a}},	//   _זעלב, lepn, _قیام_, glub
  { {0x60c40064,0x79860213,0x2bca0054,0xf53f21f0}},	//   çimd, dakw, пуно_, _ubåt_
  { {0xdb1a2c85,0x2d8f20ea,0x6adb000b,0x764d0061}},	//   leté, _edge_, यमूर, zmay
  { {0x7a3600dc,0x764d0064,0xed590796,0x66161bf2}},	//   játs, ymay, veže_, kiyk
  { {0xdcc80092,0xdb1a00dc,0xe9190036,0xfe6d002b}},	//   _tỉ_, neté, домі_, _بگو_
  { {0xa3c2014e,0x984b0063,0x4e17000a,0xed590085}},	//   ्या_, зява_, _אחאב_, teže_
  { {0x2bd7000b,0xdb1a0003,0x7793002b,0x629e3c98}},	//   _भोपा, heté, دیدا, kupo
  { {0x764d01e2,0xdb010012,0x7a3d006f,0xed590b28}},	//   tmay, gflä, nétk, reže_
  { {0xed5910ca,0x8b3b000a,0xdb1a0003,0xd90f002b}},	//   seže_, _מתוצ, jeté, _هیج_
  { {0xdbf90050,0xdb1a0014,0xe7870001,0x764d0717}},	// [a5b0] _głów, deté, _пуно, rmay
  { {0x24180036,0xd91c0008,0x13680054,0x27e7007c}},	//   нією_, _מוחל, ешци_, _õnn_
  { {0x764d0064,0x7bca003f,0x91bf0092,0x90e70086}},	//   pmay, _mafu, _phù_, کسان
  { {0xdb1a0014,0xf7700086,0x15150010,0x7bca0026}},	//   geté, _پای_, _адмя, _lafu
  { {0x91bf0092,0xa3cc000b,0x659a004c,0x7a3d0030}},	//   _chú_, _शोक_, _קישק, tétj
  { {0x7e6107e9,0x9516000a,0x24460003,0x61420054}},	//   _pulp, _יקרא_, tôme_, јеша
  { {0xdb1a00dc,0xcf880015,0xd00e0015,0x8e490015}},	//   beté, رضون_, تلو_, ولتك_
  { {0x97580008,0xed590256,0x24463e3e,0x8ccd000b}},	//   עיהו_, мой_, rôme_, तिलो
  { {0x5dd40080,0x61f60064,0x9f5c02b9,0x7a3d47d0}},	//   ующу, öyle, rivò_, méth
  { {0x6e3b400c,0x443331aa,0x7e6147d1,0x0000006a}},	//   slub, nox_, _tulp,
  { {0xda78008f,0x44210092,0x49ba0029,0x3f87044c}},	//   няў_, inh_, واحد_, manu_
  { {0xa5bb002e,0xc332000f,0xbdfb0015,0xa91b001a}},	//   _sjón, שוט_, _عرضا_, maþj
  { {0xdb0100dc,0x6d5c0046,0xfbc50151,0x63b50085}},	//   jelö, ěrat, _абло, _obzn
  { {0xdb1a03c0,0x9d1a000a,0xdb0102ad,0x7d0947d2}},	//   zeté, _קוסט, tflä, mzes
  { {0x2cad3639,0x44333883,0x2ba6000b,0x96b947d3}},	//   lted_, dox_, _खाता, нуту_
  { {0xdb0100b8,0x3f870026,0x7a360f49,0x6b8347d4}},	//   rflä, hanu_, ráts, _heng
  { {0xdb1a0014,0x7bca003f,0x2cad47d5,0xdb010dca}},	// [a5c0] veté, _yafu, nted_, gelö
  { {0x6604000c,0x389b0053,0x2cad47d6,0x629e28ee}},	//   shik, _קיינ, ited_, tupo
  { {0xf626008f,0x2cad0020,0xdb1a00dc,0x6b832218}},	//   _адно, hted_, teté, _meng
  { {0x44210092,0xd764002b,0x91bf0016,0x7d090012}},	//   anh_, _جنگی, _phú_, kzes
  { {0xdb1a0014,0xe04a0086,0x629e47d7,0xa1930033}},	//   reté, وشته_, supo, раіч
  { {0x3f871521,0xdfd00029,0x91030001,0xdb1a0030}},	//   ganu_, صيب_, рпље, seté
  { {0xe7e3005d,0x52990063,0xa2e31017,0xc059005e}},	//   खाता_, _пътя_, _корд, хії_
  { {0x2cad003e,0x91bf0016,0x7bca01c2,0xd1b3002b}},	//   fted_, _thú_, _safu, _نیمک
  { {0xf063000d,0x763b0053,0x23670263,0x645c0ca6}},	//   _вкуп, ועקג, žnje_, _kiri
  { {0x443801c2,0x7a3d47d8,0x3f8747d9,0x6b8316aa}},	//   _jkr_, méti, canu_, _ceng
  { {0x2cad0041,0x6b83013c,0xcfa90031,0x7dc60015}},	//   ated_, _deng, _سالم_, _لتشك
  { {0xc33301c8,0x7bca003f,0xee290015,0x2cad00da}},	//   יות_, _wafu, _كأنه_, bted_
  { {0x7bca0f4d,0x2cad0041,0x6b8323f2,0x7d09005c}},	//   _tafu, cted_, _feng, czes
  { {0xf7700029,0xc051000a,0x6b8347da,0x645c02f2}},	//   قاف_, ֶ֖ם_, _geng, _niri
  { {0x25b20026,0x8bbb000a,0x7a3d0003,0xcb0700c3}},	//   ffyl_, _חזות, héti, _ليون_
  { {0x645c47db,0x6b8347dc,0x3f873f66,0xee31000a}},	//   _airi, _zeng, zanu_, ֶֽן_
  { {0x645c01e2,0xe4a7006b,0xca2a004c,0x6e350030}},	// [a5d0] _biri, ърво, _רופֿ, _ízbe
  { {0x93940029,0x3374080e,0x3944007c,0x645c47dd}},	//   لجما, игур, ümse_, _ciri
  { {0x41e70010,0x8934002b,0x1dd2000b,0x7d0902b9}},	//   кіда, _معیا, थयात, zzes
  { {0xa29413ae,0x69cf00c0,0x645c1a63,0x929401b0}},	//   раці, ndce, _eiri, рацц
  { {0xe134008f,0x69cd0020,0xc0a80029,0xf4840010}},	//   анцы, _maae, ناول_, _вусн
  { {0x645c01e2,0x13a70086,0xe50c000b,0x765d01d7}},	//   _giri, _جنسی_, _सेटि_, _hisy
  { {0x8ea40015,0xed5907c4,0x27ec0030,0xa3c2000b}},	//   لصين, deža_, ödni_, ्यर_
  { {0xce18008f,0x2cad0100,0x7a3d0936,0x656d0375}},	//   кцыі_, tted_, béti, ncah
  { {0x63a5002d,0x3f87128b,0x6b8347de,0x2cad00da}},	//   oghn, panu_, _peng, uted_
  { {0x2cad0041,0x753d005c,0x7d092029,0x63a5002d}},	//   rted_, _mysz, rzes, nghn
  { {0x7d0946a3,0xddda00dc,0x6b8347df,0x2cad47e0}},	//   szes, _ettő, _veng, sted_
  { {0x6b83000c,0x2cad0041,0x60c90595,0x63a50125}},	//   _weng, pted_, _ksem, hghn
  { {0x6ba4002e,0x6b8347e1,0x3c150046,0x99390033}},	//   útgá, _teng, těvě_, вяру_
  { {0x9d1a00b2,0x7c92003b,0x60c9000c,0xdc9a000a}},	//   _אונט, _الوص, _msem, _ניצל
  { {0x3f850020,0xf7190033,0x69cd02de,0x443801c2}},	//   _melu_, віты_, _faae, _rkr_
  { {0xd7570015,0x69cd063b,0xd6250015,0xf8aa005e}},	//   طلقت_, _gaae, لعقي, _звик_
  { {0x443800d9,0x04b60010,0x044a0004,0x765d30df}},	// [a5e0] _pkr_, ысвя, епак_, _disy
  { {0x1bfc000b,0x69c9003d,0xdb010030,0x67ef002a}},	//   एसएल_, īmeņ, eglé, _pójś
  { {0xabfa0053,0x60c947e2,0x62650015,0x92650015}},	//   עהער, _asem, لانق, لدنم
  { {0xd2590036,0x645c0335,0x7bc147e3,0xe2970004}},	//   вці_, _wiri, helu, ѓач_
  { {0x34930010,0x3f850085,0x75f80030,0x60c90030}},	//   _лаўр, _belu_, _bízv, _csem
  { {0x3f8547e4,0x7a3d0152,0x3eca0001,0xccf9002a}},	//   _celu_, réti, ећим_, dyś_
  { {0x60c947e5,0x3f8502c6,0xc7d7000a,0x69a50157}},	//   _esem, _delu_, טוסי_, _काली
  { {0x52b2005d,0x7a3d0152,0x7c380046,0x69d4000b}},	//   ीबीस, péti, _skvr, _बोली
  { {0xa0c90029,0x2dd70029,0xc5f30008,0x865b000a}},	//   _لذلك_, طبية_, מדה_, עדפי
  { {0x2007037f,0xd704000b,0x9b940054,0x6704000b}},	//   chni_, रनाथ_, јинц, रनाक_
  { {0xd4370053,0xedf40086,0x6b8802de,0x83b7004c}},	//   רטיי_, _پيشگ, radg, נפטע_
  { {0xccf9005c,0xdb08002a,0x6b8802de,0xda35004a}},	//   byś_, wedó, sadg, ремы
  { {0x7bc147e6,0x9f4b0030,0xdb1a0077,0xed5908a9}},	//   belu, ülön_, metí, peža_
  { {0xb8ed005d,0x753d002a,0x96eb02a3,0x7bc147e7}},	//   _रन_, _rysz, ньба_, celu
  { {0xf3f90011,0x7a280064,0x1bfb0008,0xda6f0033}},	//   _îţi_, sıta, _אלגב, _ыя_
  { {0xe4e7042b,0xe6643a2d,0xd4e7006d,0xab4b000a}},	//   лізн, стро, люзи, _אֲחֻ
  { {0x78270029,0xd7f10092,0x3d07000b,0xd795006b}},	// [a5f0] _معدل, ữ_, ाईये_, _кипъ
  { {0x59dd000b,0x4615002b,0x3395004a,0xad1b004f}},	//   याकर, _چودر, ражё, גומר
  { {0x753d0050,0x7afa0293,0x765d02f2,0xdb1a1949}},	//   _wysz, nytt, _tisy, letâ
  { {0x95640063,0x3f850085,0xdb1a0046,0x6b4f0030}},	//   _гърд, _selu_, jetí, lógé
  { {0x2127002b,0xc0e50b1e,0x20070034,0x7bc101c2}},	//   ديشی_, ролк, thni_, yelu
  { {0x23e70010,0x60c900bd,0xdfd100e5,0xa3ac000b}},	//   _сімв, _vsem, زيع_, _गाय_
  { {0xf7f80053,0x2c69002c,0xc7f8000a,0x7bc147e8}},	//   רזוך_, _súd_, רזות_, velu
  { {0x9db90010,0xfe450004,0xb5fb0030,0x7afa008c}},	//   тыку_, јнио, _hiáb, dytt
  { {0xb8820089,0x55bc000a,0xdfa70015,0x3f850085}},	//   říze, תמחו, _محاي, _telu_
  { {0x5e87008f,0xd13803ae,0x3b85004a,0x0000006a}},	//   _будз, _схс_, шлог,
  { {0x1605014e,0x7bc10011,0xbb450142,0x6a160015}},	//   रसार_, relu, ренк, لبحر
  { {0x186a18a9,0xd336000a,0x5336000a,0x71d5000a}},	//   ками_, ירתה_, ינתן_, בוֹד_
  { {0x39490050,0xe108000a,0x5d7a000a,0xdb0a0012}},	//   _czas_, ָּרָ, _סאסק, _abfä
  { {0xbd440029,0x98360010,0x7afa0595,0xf092000a}},	//   _انهي, рэмі, bytt, חנך_
  { {0xe73a1440,0x9f450144,0x7a3d0030,0x9f29004f}},	//   тев_, _dolç_, vétv, דֵּ֖
  { {0x2aba000a,0x673e005a,0x0000006a,0x0000006a}},	//   _ימצא, _vypj,   ,
  { {0xa3d1005d,0xd467066c,0x9a3b000a,0xc8b5002b}},	// [a600] वयं_, иите_, _שתפק, _هليک
  { {0xa6860766,0x0000006a,0x0000006a,0x0000006a}},	//   _клод,   ,   ,
  { {0xa79b000a,0xf79b000a,0x479b000a,0x979b000a}},	//   _בשיח, _בבימ, _בייס, _בשיק
  { {0x2fd70086,0xdb1801cb,0x64a615d1,0x3969000a}},	//   یوند_, _navý, _кама, ְבוּ_
  { {0xdb1a275d,0xab5c003d,0xd24f0015,0x23670b28}},	//   vetí, ieļa, ذنه_, žnja_
  { {0x60370010,0x7afa00f2,0xd037005e,0xd00f0040}},	//   апіў_, yytt, азії_, ولن_
  { {0xcf89002b,0x42d500e2,0x9e0612fd,0xb3bb004f}},	//   ائهٔ_, _літу, ичил, _שמלכ
  { {0x97570008,0x66f700a3,0x7afa008c,0x291e0061}},	//   סיקו_, ימצא_, vytt, ştay_
  { {0x4fa60036,0xafe62201,0x7d0f0030,0x442a01d7}},	//   _визв, _коал, úcsp, _kjb_
  { {0x34b7013a,0xf3f1000a,0x9f4c01c0,0x629e47e9}},	//   ספים_, ִ֣י_, _hodí_, orpo
  { {0x1b180010,0x8aa3087a,0x5a350063,0xa3ab000b}},	//   ужны_, оряд, йнот, क्ट_
  { {0xf2d300b2,0xc27b000a,0x4efb0c44,0x6df30015}},	//   קער_, כרטי, _שהאו, _وكلا
  { {0x1bd4010f,0x7afa00f2,0xdb1a00dc,0x79960026}},	//   _голя, sytt, ldtü, _ddyw
  { {0xd918004a,0x9f4c013f,0x26090065,0x1db40065}},	//   рью_, _lodí_, _सतही_, ंभवत
  { {0xc66800d7,0xa3e0000b,0xf8ae002b,0x66f4045f}},	//   иште_, थाई_, وکی_, опру
  { {0x7a280064,0x6a140029,0x94ab0015,0x201c47ea}},	//   nıtl, _وبير, َاءِ_, hivi_
  { {0xf3670549,0x24f8054f,0xc8c8002b,0x96340033}},	// [a610] атен, анты_, _نوين_, інуц
  { {0x201c01a3,0x04c80015,0x224d47eb,0x0000006a}},	//   jivi_, ؤولي_, _shek_,
  { {0x93190029,0x8c3d0064,0xd404005e,0xdb1a0144}},	//   دقاء_, nuşa, цяти, netà
  { {0x41550033,0x7a3d1d2c,0xee000033,0xdb0104d1}},	//   бвес, pétu, _маiм_, rflø
  { {0x838710a7,0x4615002b,0x701901c6,0xade5000b}},	//   _выбе, _نوگر, лікт_, कासन_
  { {0x386900d9,0xd0980015,0x25a945dc,0x3e6a002b}},	//   _muar_, شئها_, lgal_, گجوی_
  { {0xa2940036,0x38690375,0x67bc000a,0x92942a0b}},	//   _марі, _luar_, דמוק, _марц
  { {0x7db40010,0xf2d20053,0xf1cf000b,0x4c8540e5}},	//   осьц, _צען_, _सोचन, блив
  { {0xac960015,0x61ed008c,0xed5900bc,0x201c0160}},	//   منيا_, öalu, režo_, bivi_
  { {0x321d005c,0x5fae000b,0x9ff40015,0x7ff40021}},	//   liwy_, _घायल, _وألص, _وسلا
  { {0x39460024,0x0000006a,0x0000006a,0x0000006a}},	//   _šos_,   ,   ,
  { {0x4dd40015,0x8a39006b,0xf769000a,0xb7da009a}},	//   _وتنس, ияят_, _טק_, گوسا_
  { {0x2a600020,0xa923006b,0x89360015,0x39360033}},	//   _viib_, здял, إعجا, сэнс
  { {0xbb850015,0x1867387e,0x6d4b47ec,0x25a91ef1}},	//   _الثي, сари_, _izga, egal_
  { {0x2bb80029,0xe45f0123,0xfbd2004f,0x1a65009a}},	//   _خانة_, _esök_, _מתג_, _دیجی_
  { {0x05660063,0x201c044c,0x9fbd002a,0x38690125}},	//   сван, zivi_, ołów_, _fuar_
  { {0x7a3d002e,0x8b030089,0xd54a0010,0x69c617f7}},	// [a620] rétt, ěřuj, упае_, meke
  { {0x69c647ed,0x25a90a85,0xdb1a3d4e,0x77ca02ed}},	//   leke, agal_, letá, _слог_
  { {0x7a280064,0x8c1a0008,0x69c60159,0x7a3d47ee}},	//   yıtl, נועי, oeke, métr
  { {0x71a60210,0x75f80030,0x99820091,0xca96000a}},	//   садз, _vízs, mokų_, מדעי_
  { {0x465700b2,0x201c1303,0x74fa0010,0x10a347ef}},	//   _לױטן_, tivi_, _сэнс_, зичн
  { {0x76440064,0x7a3d1f0d,0xd0100015,0x201c0003}},	//   lliy, nétr, بلت_, uivi_
  { {0x3246000d,0x6f1e006f,0x865a000a,0x201c47f0}},	//   _гевг, ĺpco, ְדִי, rivi_
  { {0x69c600f2,0x5c9800a4,0x60db47f1,0xa3c2000b}},	//   jeke, акия_, _frum, ्यक_
  { {0x44441a62,0x90a50015,0x69c647f2,0x764447f3}},	//   ol_, _وحكم, deke, iliy
  { {0x7a280064,0x9d130010,0x76440061,0xda7a086e}},	//   sıtl, ядыч, hliy, лям_
  { {0xe3b30053,0x7644117f,0xc43b0008,0x9fbd005c}},	//   לױז_, kliy, רתיי, ałów_
  { {0x3f8e000c,0x4444018b,0x42db004c,0xdb1a1115}},	//   lafu_, hl_, אקטע, getá
  { {0x443a47f4,0x63bc05ba,0xfe37000a,0xad560015}},	//   kop_, _obrn, _פרדי_, _انشغ
  { {0x3f8e0026,0x444422f1,0x68fd002a,0x321d002a}},	//   nafu_, jl_, rysd, ziwy_
  { {0x8c1b0008,0x2bb70008,0x629800dc,0x444416dc}},	//   _תווי, _הפוך_, ávol, dl_
  { {0x3f8e4187,0x4444345f,0x69c647f5,0xdd08006f}},	//   hafu_, el_, ceke, _môžm
  { {0x60c401e2,0xd37b004a,0x67d508df,0xf3ff016e}},	// [a630] çiml, гче_, _допу, _quão_
  { {0x76443466,0xb8ed000b,0x3cfb000a,0x7c2847f6}},	//   aliy, रब_, אלמנ, nndr
  { {0x9fbd002a,0x76440061,0x236700bc,0x75f80030}},	//   złów_, bliy, žnjo_, _vízr
  { {0xddc104f9,0x81a70015,0x444447f7,0x7c3a47f8}},	//   _mulţ, إحال, al_, hotr
  { {0x44440026,0xf994000a,0x25d6000a,0x7c3a47f9}},	//   bl_, פרס_, _וורן_, kotr
  { {0xd0060254,0x7c3a0085,0x69c647fa,0xf8b8000a}},	//   жеше_, jotr, zeke, צפוי_
  { {0x69c600dc,0x57fc000a,0x7e6247fb,0x1dda0065}},	//   yeke, רלוו, _biop, _मोहत
  { {0x171c0053,0x7c2847fc,0x60db0472,0x72050015}},	//   טווע, endr, _trum, _بورم
  { {0x69c600dc,0x3f8e003f,0xe572000a,0x70740015}},	//   veke, bafu_, וַת_, _فالذ
  { {0x0c360029,0xeb990054,0x244f0061,0x8b25006b}},	//   يكية_, јин_, büme_, ждое
  { {0xdcfb0007,0x2fc747fd,0xc949000a,0x9fbd002a}},	//   mbuč, meng_, _סמ_, słów_
  { {0xe0c70074,0x3ea70251,0x6f0b0064,0xef18003d}},	//   وز_, munt_, ımcı, _ceļu_
  { {0x44440089,0x443a0035,0x7c46002e,0x6e3b0085}},	//   yl_, yop_, ðurö, moub
  { {0x69c60014,0x515a0008,0x290c005c,0xfd56000a}},	//   seke, יכרו, ąda_, _ושני_
  { {0x998c00dc,0xcc3a0053,0xdb0100b8,0x9a460015}},	//   ődő_, _דעסט, nflü, _وضعه
  { {0x2fc700b6,0x7644003f,0xf506000d,0xe57a0658}},	//   heng_, uliy, озбо, рза_
  { {0x9f88002e,0x444447fe,0x76440061,0x037a0015}},	// [a640] kóði_, tl_, rliy, لحات_
  { {0xa3e7021e,0x7656008c,0x244f0061,0x9f88001a}},	//   भाष_, smyy, yüme_, jóði_
  { {0x2fc700b6,0x3ea70251,0x599a000a,0x443a1a52}},	//   deng_, junt_, ֹשְׁ, rop_
  { {0xc6930053,0x660d0111,0x3aba0053,0xb5fb0030}},	//   _קאר_, chak, ימענ, _hián
  { {0x69bc005d,0x6e3b0493,0xc5f3000f,0x7c2847ff}},	//   ष्यी, doub, _חדר_, yndr
  { {0x2bae0372,0x98cb0008,0x7e620112,0x2fc70ac1}},	//   ज्ञा, שֶׁ֥, _siop, geng_
  { {0x2327010f,0xa3e7005d,0x3f8e003f,0x6e940015}},	//   _дори_, भार_, rafu_, ألبا
  { {0xdcba0063,0x660409e2,0x244f0061,0x6e294800}},	//   ащо_, nkik, rüme_, gneb
  { {0xf653013a,0xddc9003d,0x9f4c04b2,0x7c3a4801}},	//   וצה_, kmeņ, _dodá_, totr
  { {0x60cd122a,0x7c3a0007,0xc0d30115,0x28de000b}},	//   çame, uotr, _زيمب, मिनि
  { {0x6604008c,0x8c3d0061,0xdd8f007e,0x6e3b00aa}},	//   kkik, muşl, _ош_, boub
  { {0x5ce60029,0x8c3d0064,0x7c3a0fef,0xd2b7000a}},	//   _وكال, luşl, sotr, חלטת_
  { {0xfbcf0086,0x1e57000a,0x7c3a4802,0x7e7a308e}},	//   رتی_, _ושאר_, potr, _http
  { {0x39450048,0x6e200508,0x7d0c0061,0x58050015}},	//   āls_, limb, ılsı, أوسك
  { {0x4b7b0053,0xde78000a,0x758b0342,0x22460079}},	//   _דאוו, מְּך, исав_, klok_
  { {0x22461bf1,0x7e9b01ac,0xa5bb002e,0x6e200049}},	//   jlok_, יסלו, _njót, nimb
  { {0x19aa0053,0xa3e7000b,0xb5fb0030,0x660d4803}},	// [a650] _הױפּ, भाल_, _fián, rhak
  { {0x6e2004f9,0x66040035,0x660d151a,0x28c4000b}},	//   himb, akik, shak, _लैटि
  { {0x6e290026,0xc7b2039e,0x6e204804,0xdb08016e}},	//   yneb, _אבי_, kimb, cedô
  { {0xdce9016f,0x6e20003f,0x7bc80100,0xf1ab0015}},	//   zbeđ, jimb, hedu, شاؤه_
  { {0x25090086,0xd141005c,0xdb1a0064,0x2fc71f36}},	//   _طرحی_, knął_, betç, teng_
  { {0xb4fa000a,0x224602f2,0x6e2001c2,0xdb010012}},	//   _הפשי, alok_, eimb, tflü
  { {0x63b40057,0x22462349,0x60cd0527,0x7d00001a}},	//   žený, blok_, çamb, eyms
  { {0x2fc70035,0x909b0015,0xdb010012,0x2d8b006f}},	//   seng_, _نضطر_, rflü, úce_
  { {0xdb1a00f2,0xec760080,0x6e3b4805,0xdb010012}},	//   hetä, ппы_, roub, sflü
  { {0x442114b1,0x7bc82ed6,0x5fb5000b,0xd141002a}},	//   nih_, gedu, _आउटल, gnął_
  { {0xf8a900f3,0x6e202ddf,0xed59003d,0x4fda000a}},	//   _תש_, bimb, ieži_, _לַאד
  { {0xdeba0008,0xdb1a00f2,0x32150061,0xdcf70015}},	//   _למעל, detä, _çayı_, _وأشب
  { {0x257c0089,0xa5bb002e,0xdb1a0064,0x8c3d0064}},	//   nálů_, _ljós, yetç, luşm
  { {0xd7f20029,0x6cd20029,0x913a0053,0x6c7a000a}},	//   ركز_, _أقوا, מערק, _האספ
  { {0x8c3d0064,0xa3c1005d,0xc052000a,0x5b370015}},	//   nuşm, ्जन_, גזם_, _بعشر
  { {0x8afa013a,0x3e714806,0xba9a000a,0x9663014d}},	//   _להצי, _mát_, _הסקי, ексе
  { {0x6604022d,0x98ac003d,0x3e714807,0x66d50046}},	// [a660] rkik, ādē_, _lát_, týká
  { {0x6604020a,0xa5bb002e,0x44214808,0xc4c50015}},	//   skik, _bjós, gih_, بتفو
  { {0xdb1a01e2,0xb5fb00dc,0xa1c60e88,0x41e60010}},	//   retç, _kiál, збед, зіла
  { {0x23720048,0xdb1a0061,0x7bc80eb3,0x63ab0073}},	//   _šajā_, setç, zedu, ėgna
  { {0x38b60084,0x200e00e8,0x4421013c,0x9f5c0046}},	//   nær_, thfi_, bih_, rkví_
  { {0x6e200573,0x2246001a,0x44210815,0x4e8a004a}},	//   wimb, slok_, cih_, бщим_
  { {0xc059129a,0xd2a70036,0x3e710092,0x6e201177}},	//   ції_, _нкре_, _cát_, timb
  { {0xd29b0008,0x3e710057,0x64670030,0x23ac000b}},	//   _לשלט, _dát_, _óriá, _चाँद
  { {0x8d730087,0x10a3005e,0x38b600cb,0x6e201801}},	//   رايا, _питн, jær_, rimb
  { {0xac180036,0x307b000a,0xb4fb000a,0x798d205c}},	//   іону_, _לאמנ, צפיי, _seaw
  { {0x9f7b0008,0x201e0091,0x200c001a,0x3f7b000a}},	//   _הנבח, _imti_, _ildi_, _האבס
  { {0x44210796,0xd141002a,0x320602f2,0xdd90002b}},	//   zih_, snął_, nkoy_, _شوت_
  { {0x5c060063,0x386d00dd,0x7c2136b5,0xb5fb0656}},	//   _няка, êer_, bilr, _diál
  { {0xdb1a022d,0x9605000b,0x9d2b000a,0xe0ce00ce}},	//   tetä, रस्ट_, _לֵוִ, твi_
  { {0x3bbb0e22,0x98be0048,0x4421065d,0xed590844}},	//   _המוד, ātā_, vih_, veži_
  { {0x69d60f0a,0x4421088a,0x38b64809,0x5eeb004f}},	//   _gaye, wih_, bær_, זַמְ
  { {0xdb1a007c,0xa5f809c3,0xe4a40248,0xe57000c3}},	// [a670] setä, чету_, ерхо, اطف_
  { {0xb8830089,0xc8b40015,0x1be2000b,0x8c3d0061}},	//   říst, _أصيب, _कोमल_, yuşm
  { {0x56940010,0x8c4100b8,0x77ba0008,0x4421480a}},	//   _паэт, äßig, _ומתח, rih_
  { {0x661d002e,0xc2c40015,0x44211ae7,0xcb13004c}},	//   _umsk, عيني, sih_, עלף_
  { {0x3e710023,0xa5bb002e,0xa2cd005d,0xd0590033}},	//   _sát_, _fjór, _धैर्, оркі_
  { {0xc4d20008,0x257c0046,0xc0e20973,0x506407f9}},	//   _שגם_, rálů_, тошк, нтја
  { {0x66ff005d,0x74db000b,0x62080030,0x2902480b}},	//   ैनिक_, निवृ, árló, zyka_
  { {0xf2d20dab,0x8c3d0061,0x7c95002b,0xec792b12}},	//   _בעל_, ruşm, وشخا, опи_
  { {0x4c350010,0xae1c000b,0x62340099,0x69d6480c}},	//   дэнт, बोधन_, _чету, _raye
  { {0x69d60064,0x3e710016,0x8add0033,0xa0c40040}},	//   _saye, _tát_, аёмi, _سيمو
  { {0xff530029,0x61fb28df,0x69d619b0,0x539a000a}},	//   _أخذ_, _koul, _paye, חיתו
  { {0x2902005c,0x61fb00f2,0x38b60293,0x9d550015}},	//   tyka_, _joul, tær_, _قنات
  { {0x9f5800dc,0x61fb0493,0x6d4f0061,0xc9550033}},	//   özök_, _moul, ücad, етры
  { {0x60c40064,0x29021212,0xb8f6000b,0xb5fb0077}},	//   çimi, ryka_, _सन_, _diám
  { {0xa3e7005d,0x6fbf000b,0xa3de000b,0xf7430cab}},	//   भाई_, ल्यू, _दोष_, веро
  { {0xdbcc002e,0x2378044c,0x61fb480d,0xfa360015}},	//   lóðu, _sfrj_, _noul, _ترتد
  { {0x89eb0008,0x75d30029,0xa99b000a,0x9856004a}},	// [a680] _וַיֵ, ضيلا, _ובפר, _отош
  { {0x4a79000a,0x27f70015,0x4ad1000b,0x2d8f480e}},	//   ַרְב, _يفيد_, _तनाव, _lege_
  { {0x6b9c016e,0x61fb480f,0x130a0033,0xe56a0015}},	//   órgi, _boul, ўней_, _ومدى_
  { {0x6f03005c,0x61fb0493,0x7229005e,0x2d8f4810}},	//   dync, _coul, пців_, _nege_
  { {0x61fb0152,0xa5bb001a,0xdbcc001a,0x11d70015}},	//   _doul, _tjór, kóðu, بونة_
  { {0xd12f0086,0xdfd00015,0xdbcc001a,0xc223002b}},	//   جمه_, ايث_, jóðu, _یکنو
  { {0x61fb1a8b,0xe7c0000b,0x03d7000a,0x0443116f}},	//   _foul, श्यप, _קולם_, _рерн
  { {0x3ea006d5,0x2007058a,0x6d46002a,0x61fb4811}},	//   čit_, akni_, żkam, _goul
  { {0xdca30001,0xab5c003d,0x5e430058,0x0000006a}},	//   вањи, meļi, خَيْ,
  { {0x70fb000a,0x60fb000a,0x200705ca,0x95fb000b}},	//   _והמח, _והמק, ckni_, _एक्ट_
  { {0xfff50086,0x78a64812,0xa3c10065,0xb87b005a}},	//   _سکوت_, erkv, ्जत_, zvíd
  { {0x7de5005e,0x1ea90015,0x0000006a,0x0000006a}},	//   _піід, _رامي_,   ,
  { {0x9cb30015,0x6ba701d0,0x0000006a,0x0000006a}},	//   _لمنت, ærgå,   ,
  { {0xeaaf002b,0x236702d8,0x28090015,0x2d8f0079}},	//   دعی_, žnji_, أْسَ_, _zege_
  { {0x683f0089,0xc5fb000d,0x501b0008,0x80d5000b}},	//   vádě, оѓа_, קולו, _मैने
  { {0x7bda4813,0xf487098b,0x7bd84814,0x99671411}},	//   ldtu, дужн, _havu, _отпл
  { {0x7bd81e8c,0x61fb4815,0xed59003d,0xdb11001a}},	// [a690] _kavu, _roul, bežu_, úgöl
  { {0x61e9016b,0x61fb4816,0x2418005e,0xa87c000a}},	//   _snel, _soul, мією_, _ואזר
  { {0x7bd8003f,0x08f8002b,0x61fb4817,0x659501c6}},	//   _mavu, _فریب_, _poul, _пану
  { {0x50b50080,0x6aba0123,0xf992000a,0x91d400ce}},	//   еску, ittf, ָ֨א_, кціі
  { {0x61fb038d,0xd479004c,0x6829006f,0xdca60015}},	//   _voul, _מאָל, ažde, _حى_
  { {0x61fb0041,0xd0110029,0xa3ac000b,0xf0720058}},	//   _woul, طلع_, _गाए_, دُود
  { {0x2007002e,0x2d8f02de,0xd00e0015,0x61fb04e1}},	//   rkni_, _pege_, إلى_, _toul
  { {0x61e94818,0x63ad0011,0xd0d5006b,0x7a280061}},	//   _unel, şină, _побъ, nıtt
  { {0xc03503ae,0x6f034819,0x2b47481a,0x90d40058}},	//   _знај, sync, _sync_, _لآلا
  { {0xaf070e88,0x2d8f00b8,0xee870033,0x7f840015}},	//   _очек, _wege_, _жыдо, _للكن
  { {0x0c220033,0xd9eb000b,0x8c3d0045,0xda0a0015}},	//   умэн, टांत_, nuşi, كيده_
  { {0x7afc00c0,0xc332039e,0xb5fb0030,0x99d60067}},	//   ärta, רוט_, _diák, رتجا
  { {0xa3c1005d,0x487a006b,0xed590085,0x48e302da}},	//   ्जा_, ясня_, težu_, гояв
  { {0x3d18005d,0x7bd80007,0xa3de000b,0x660f481b}},	//   _बेटे_, _gavu, _दों_, _alck
  { {0x96560001,0x99860015,0x2cad00da,0xf656004a}},	//   еђај, _كلثو, lued_, етаю
  { {0xfb1a000a,0xd6040054,0x5ee00065,0xcb12004f}},	//   _מוצמ, jедн, कित्_, _תלה_
  { {0x2cad0041,0xa98b000a,0x7bd80061,0x8c3d0045}},	// [a6a0] nued_, _מָיִ, _yavu, euşi
  { {0xa3e7021e,0xd6d9002a,0xdb1a0030,0x68e4481c}},	//   भाग_, łła_, vetú, _irid
  { {0xa3c1005d,0x87b7000a,0xd3b5006b,0x826a004a}},	//   ्ज़_, _אליס_, ъсть, чаев_
  { {0xda10000b,0xa2d5000b,0x7afc0013,0x867b004f}},	//   ासित_, णिज्, ørti, _מרטו
  { {0x63ab0089,0xd132002b,0xab63002a,0x00da0040}},	//   álné, دمش_, ążym, ثبات_
  { {0xe8d90092,0x889b0008,0x289b000a,0x2ab80030}},	//   _ngờ_, לבני, לינא, yéb_
  { {0xa2e30758,0x69c4481d,0x361a000a,0xc7b3000a}},	//   _йорд, _obie, ּוִד, אבו_
  { {0x7bd8481e,0x387f0011,0xdce20016,0x25b20034}},	//   _savu, ţuri_, _ngoă, ngyl_
  { {0x2cad003e,0xed570054,0x5d54006b,0x645e481f}},	//   gued_, ноћ_, ъкит, ompi
  { {0x7bda00dc,0xa4b7000a,0xe0d701c6,0x69c44820}},	//   udtu, עליה_, _яву_, _abie
  { {0x6258002f,0xf4130008,0xb804000b,0x645e118c}},	//   ríof, רפת_, _रक़म_, impi
  { {0xdc1201e2,0xc33301e4,0xb87b0089,0x68e402ff}},	//   rşıl, טות_, jvíc, _brid
  { {0x8dfb0008,0x68e40251,0x7ae30012,0x6dc6006f}},	//   _מהאת, _crid, _ernt, _vďač
  { {0xdb1a00cb,0xbd2900c3,0x9cd705bd,0x68e400e7}},	//   ketø, _تأمل_, _נווה_, _drid
  { {0x05870001,0x35e70010,0x65950033,0x3d08000b}},	//   еузм, нцав, каву, िनके_
  { {0x6258002d,0xf6530029,0x9f450061,0xaa58004a}},	//   níod, ائس_, _rolü_, _пищу_
  { {0x95c40015,0xa634005e,0xdb010012,0x68e44821}},	// [a6b0] طيله, унті, uflö, _grid
  { {0x69cf4822,0x69c4066f,0xdb010400,0xd68701ca}},	//   lece, _zbie, rflö, _пумп
  { {0x78bd00b8,0x69c4002a,0xdb1a02de,0xf60b00c3}},	//   ltsv, _ybie, getø, _فتحه_
  { {0x69cf4823,0xbb3b000a,0x60cd016e,0x569a004c}},	//   nece, העבי, çamo, _קירצ
  { {0x764d0064,0xd3a7000d,0xa99c004c,0x629c25b6}},	//   mlay, _првп, לבאר, _evro
  { {0x60080036,0x63b5005c,0x52850015,0x78bd0012}},	//   ннім_, _uczn, _للسك, itsv
  { {0x764d0064,0x10140029,0x69cf2455,0x877c004c}},	//   olay, دبند, kece, לאגי
  { {0x764d18b8,0x7ceb001a,0x69dd0079,0x3f9a001a}},	//   nlay, jörð, jdse, ópur_
  { {0x764d0375,0xe7b2000b,0x82340067,0x69cf4824}},	//   ilay, _जालप, _صرفا, dece
  { {0x2367016f,0xc60e000b,0x7a2b008c,0x29190030}},	//   žnju_, _सत्य_, yötä, dzsa_
  { {0x764d01e2,0x2cad003e,0x2bd0005d,0x75f80030}},	//   klay, sued_, तज़ा, _vízz
  { {0xf2d200b2,0xa2c4000b,0x8288000a,0xdef6000a}},	//   בעט_, _रहस्, עְתֶ, _במעט_
  { {0xc19a0008,0x764d4825,0xe8f70142,0x39360033}},	//   ושרי, dlay, вля_, тэнс
  { {0x394c0024,0xf092000a,0x68e40804,0x69c4002a}},	//   āds_, שנם_, _vrid, _wbie
  { {0x69cf0896,0x78bd0f55,0xf7460457,0x0b160015}},	//   bece, atsv, тево, _لقوة_
  { {0xdeef0010,0x69c44139,0x7b07003d,0x49c7006b}},	//   рыi_, _ubie, īstī, _алън_
  { {0x05660785,0xc5660004,0x94a90058,0x0446011e}},	// [a6c0] тван, ткак, ّامِ_, веан
  { {0x7bc125d0,0xf41f006f,0x764d3359,0x645e4826}},	//   nflu, _zväz_, alay, umpi
  { {0xe73a0080,0x7236002b,0x475a004a,0x6d4b0034}},	//   _цен_, پراط, _юрия_, _lyga
  { {0xd7b2005d,0xdb1a0013,0xaaa9000b,0xb87b0077}},	//   _जाँच, retø, _किनक, lvía
  { {0x8c3d0064,0x20d30015,0x21670658,0x62851351}},	//   luşu, لتوج, вици_, apho
  { {0x9f65002c,0x63830254,0x69cf4827,0xb87b0077}},	//   _štát_, _вгра, zece, nvía
  { {0x69cf01e2,0xf7730008,0x8c3d0064,0x44444828}},	//   yece, סקה_, nuşu, mo_
  { {0xade3017f,0xc693000a,0x3eae0012,0x7cd806da}},	//   ацьк, באה_, ruft_, емир_
  { {0x7ceb002e,0xa3e7000b,0xd7b2000b,0x6d4b002a}},	//   vörð, _मोड_, _जांच, _cyga
  { {0x6258002d,0x1bf40033,0x764d0061,0x8af80709}},	//   síod, упоў, zlay, енос_
  { {0x764d0064,0x60140251,0x6d4f0089,0xaf0a0015}},	//   ylay, _càme, ýcar, _تقام_
  { {0x7f170067,0xdddc002a,0xa5bb006f,0x44444829}},	//   _جيمز_, żyłe, _amón, ho_
  { {0x69dd3f4d,0x3e78482a,0xa3b3000b,0x984b006b}},	//   rdse, _hét_, _टाल_, дява_
  { {0x3e780014,0x291900dc,0x69cf482b,0x4444482c}},	//   _két_, rzsa_, sece, jo_
  { {0x3e7800dc,0x764d2701,0xb4cb000b,0xd794006b}},	//   _jét_, tlay, लब्_, рисъ
  { {0x4444002f,0x3e780092,0x6edb000a,0xa634008b}},	//   eo_, _mét_, וחלפ, ансі
  { {0x764d2286,0xda10000b,0x68290091,0x4444482d}},	// [a6d0] rlay, ासरत_, ažda, fo_
  { {0xf8bf482e,0x4444482f,0x4cbb000a,0x764d4830}},	//   mté_, go_, וזמו, slay
  { {0xf8bf0152,0x8c3d0064,0x764d4831,0x3e784832}},	//   lté_, muşt, play, _nét_
  { {0x8c3d0064,0x68e20024,0xe298005e,0xf8bf4833}},	//   luşt, _šodi, таї_, oté_
  { {0xe3b00074,0x44444834,0xf8bf4835,0xd7c0000b}},	//   _ژرف_, bo_, nté_, श्वच
  { {0xf8bf0152,0x8c3d0064,0x62853d80,0x351a000a}},	//   ité_, nuşt, ppho, _טורנ
  { {0xa2940010,0x5e56002b,0x7e99002b,0x660d12a5}},	//   _васі, گليس_, رنظر_, okak
  { {0xa3c1005d,0x8db50010,0x64454836,0xdd910015}},	//   ंभव_, ускі, lohi, حوظ_
  { {0x626c0011,0xb5fb016e,0xc104002b,0x865c000a}},	//   _uşoa, _fiáv, _پولي, ודהי
  { {0x99820089,0xabd5049d,0x3b850033,0x64454837}},	//   tiků_, уциј, ылог, nohi
  { {0xdd910086,0x6d4b005c,0xf8bf0003,0x8b250f5c}},	//   _هوا_, _wyga, eté_, удне
  { {0x44444838,0xd336000a,0x7bc1047f,0x62580125}},	//   zo_, טרתה_, sflu, míoc
  { {0x6258002d,0x44444839,0xc9850054,0x6d4b0061}},	//   líoc, yo_, јуџи, _uyga
  { {0x315600b2,0x6e2900b8,0x3e71002c,0xe9df002d}},	//   טירן_, lieb, _ešte_, adú_
  { {0x3e780023,0x1b490036,0x8c1a0008,0xe5a60cfa}},	//   _xét_, _язки_, _רוצי, ливи
  { {0x660d00b6,0x4444483a,0x8c3d1d56,0x6e29483b}},	//   gkak, wo_, ruşu, nieb
  { {0x7d091498,0xf8bf0152,0x59830080,0x7d1b483c}},	// [a6e0] nyes, cté_, _улыб, nzus
  { {0x660d0035,0x6e290012,0xe3b70054,0xab5c003d}},	//   akak, hieb, лбу_, meļr
  { {0x2cbf0005,0x79962e36,0x41aa017a,0xd36f0015}},	//   htud_, _keyw, евен_, أهم_
  { {0xa2a5000b,0x6258483d,0x660d0123,0x4444483e}},	//   _चटर्, díoc, ckak, so_
  { {0x67360024,0x79b70008,0x3d0d000b,0x859b000a}},	//   šajā, רלנד_, िनों_, _אשכו
  { {0xf7ba004c,0xc0e700c3,0x799602f2,0x444400aa}},	//   גזַמ, افون_, _leyw, qo_
  { {0x6258002f,0xf8b1005d,0x6d5d002e,0xc7d7000a}},	//   ríob, _जम्प, ýsan, רוצי_
  { {0x7c280012,0x7d1b0012,0x6e29483f,0x6cd40015}},	//   widr, fzus, gieb, لقبا
  { {0xc19b0008,0xb8820089,0xcce60015,0x7d090030}},	//   _רשמי, říje, اسبي, gyes
  { {0x610a0048,0xc4d30008,0xd12f0806,0x0c730029}},	//   _vēlā, צגת_, _عمل_, حديد
  { {0x645c0026,0x23c6005d,0x5a350345,0x53c6000b}},	//   _mhri, र्यद, инот, र्यश
  { {0x9d9a0029,0xe9df002c,0x9f5e0140,0xdb1a0980}},	//   _أنشئ_, udú_, _noté_, metü
  { {0xf8bf0152,0xad8b0008,0x6445003f,0x9be6005e}},	//   uté_, _נְאֻ, yohi, _бійк
  { {0x1cb70008,0xf8bf0152,0x62810003,0x1d330033}},	//   _עלול_, rté_, _élog, _унія
  { {0xdce001e2,0x8c3d0064,0x6b9a4840,0x6b7b0135}},	//   mamı, ruşt, matg, _ארונ
  { {0xdce001e2,0xf8bf0152,0x9f5e0003,0x98750054}},	//   lamı, pté_, _coté_, _клиц
  { {0x645c002d,0x94770002,0x9f5e0003,0x23c6000b}},	// [a6f0] _bhri, ادرا, _doté_, र्भद
  { {0x6b9a0251,0xdce00064,0x645c1fe6,0xe3b00015}},	//   natg, namı, _chri, كرم_
  { {0x7c2f0003,0x6b9a0144,0x877a000a,0xd347002b}},	//   écri, iatg, _באתי, ایزه_
  { {0xa2940036,0xdb1a002a,0x92940033,0xf36403ca}},	//   саці, letó, сацц, стун
  { {0x759a0008,0xdce00064,0x71270029,0x645c002d}},	//   _בסרג, kamı, درال, _fhri
  { {0x287c00b2,0x28980008,0x6258002d,0x645c002d}},	//   ענומ, נדון_, tíoc, _ghri
  { {0xf2e40036,0x6e2945c1,0x2246171e,0x03c40033}},	//   _люто, tieb, book_, _усям
  { {0x6258002f,0x8237003b,0xc2c40029,0xdcf50015}},	//   ríoc, _إرسا, _ديفي, لأخب
  { {0xc2120008,0x7e7d0045,0x6e294841,0xdce00061}},	//   _והן_, _ăspu, rieb, famı
  { {0x7d1b00b8,0xb5fb002d,0xdb1a242f,0x60db02f2}},	//   rzus, _fhág, jetó, _isum
  { {0x7d1b33ae,0x2cbf0020,0xdd990264,0xdb1a002a}},	//   szus, stud_, paň_, detó
  { {0x26da01c2,0xaa4600f4,0xb87b4842,0xa2b6004f}},	//   _rspo_, ремл, rvín, ספרד_
  { {0xc9560256,0xdce00061,0x71d6000a,0x7c840054}},	//   ртны, bamı, בורד_, _лује
  { {0xb8ee005d,0x7d0600f2,0xf77200e6,0xac160054}},	//   _रह_, äkse, تاح_, _вољу_
  { {0xa5960063,0x9f5e4843,0x601f0091,0x96760033}},	//   иращ, _poté_, _išmė, рыгі
  { {0x78a90e6d,0x645c4844,0xda14002b,0x60db4845}},	//   ševa, _shri, _دستک, _osum
  { {0x3ce8005d,0x645c3c93,0xdb1a4846,0xf7720015}},	// [a700] जिये_, _phri, zetü, _واد_
  { {0x389b0135,0x8387005e,0x2cad17cd,0x889b000a}},	//   _שיינ, ибув_, ired_, _שביי
  { {0x2cad0026,0x032600d0,0x82f60033,0x60db4847}},	//   hred_, јден, шчац, _asum
  { {0xea8c0053,0x629e00f6,0x6d59002a,0x067b000a}},	//   גנאָ, rspo, _ozwa, _שנכל
  { {0xdce00064,0x629e0f99,0x645c22ec,0xe0d2006e}},	//   yamı, sspo, _thri, تزا_
  { {0xa2e6005f,0x4ea60457,0xf8b3000a,0x645c008c}},	//   _когд, ариа, קשו_, _uhri
  { {0x9999002c,0x0ff70029,0x2cad003e,0x6d5900d9}},	//   losť_, شعوب_, ered_, _azwa
  { {0xadf4000d,0xd677000a,0x4cb8004a,0x2cad010c}},	//   спиш, סתפק_, глию_, fred_
  { {0x9999002c,0x6d59005c,0xeb0e005d,0x6b9a0251}},	//   nosť_, _czwa, ान्त_, tatg
  { {0x61e20014,0xbea60127,0xd00f0015,0x4ae60033}},	//   ldol, _важк, _قلق_, аўма
  { {0x3377000a,0x2cad003e,0x6b9a0251,0x0377000a}},	//   יעים_, ared_, ratg, יתית_
  { {0x6b9a0251,0x6ab6000b,0x9999006f,0xdce00061}},	//   satg, _अमीर, kosť_, samı
  { {0x2cad16ac,0x61e006e8,0xdce00061,0x3e710f81}},	//   cred_, _maml, pamı, _išta_
  { {0x61e2022d,0xbb840029,0x9999002c,0x60c20007}},	//   hdol, _الغي, dosť_, itom
  { {0xdb1a001c,0xd8380010,0x6c5b000a,0x96270004}},	//   retó, рэя_, _שדוח, аќал
  { {0xbafb039e,0x8afb000a,0xae16000b,0x60c24848}},	//   _יהוש, _יהוי, तसिन_, ktom
  { {0x61e20026,0x04950115,0x3f9c4849,0x0000006a}},	// [a710] ddol, صلاح, kavu_,
  { {0xaada005d,0x44270092,0x3f9c049f,0x430b0342}},	//   _बनाक, òn_, javu_, кхем_
  { {0xb5fb484a,0x636b0054,0x38c9002b,0x8bd7000a}},	//   _diár, траг_, _شاکی_, שובו_
  { {0xaaa9000b,0x128a002b,0x61e0484b,0x27e1484c}},	//   _किसक, امنی_, _caml, _hahn_
  { {0x8467010f,0xddc2005c,0x55f6000a,0x9538004a}},	//   _въве, _okoł, _המרב_, _взят_
  { {0xdfd10029,0x6b9800bc,0x61e2233b,0x27e1188b}},	//   سيع_, _nevg, adol, _jahn_
  { {0x6d59005c,0x60c20c85,0xbec7003d,0xe2f8005e}},	//   _szwa, atom, ksīš, _кері_
  { {0xf0b80086,0xd7380008,0x6258002d,0xed590256}},	//   _چالش_, יטות_, líon, лой_
  { {0xa3ab005d,0x3eae002e,0x4c820256,0x60db0913}},	//   _गया_, arft_, плыв, _usum
  { {0x2cad003e,0x6258002d,0xbad50010,0x40590115}},	//   rred_, níon, бімы, _صلاح_
  { {0x1f140015,0x4a460c71,0xbb450a66,0x0000006a}},	//   _وبمج, йнов, сенк,
  { {0x20050026,0xc332000f,0x6258002d,0x2cad37f7}},	//   _holi_, לוי_, híon, pred_
  { {0x6c850029,0x200500bd,0x4dda0008,0xcd76000a}},	//   _التم, _koli_, _תחנו, _הענק_
  { {0x4b790053,0x9999002c,0xeb99006b,0xa3e7000b}},	//   _גאַו, vosť_, _сик_, _मोल_
  { {0x61e22c97,0xdb010012,0x2005484d,0xe73a0350}},	//   ydol, nglü, _moli_, уев_
  { {0x9999002c,0x3f9c16d3,0x36190033,0x291a00c3}},	//   tosť_, zavu_, ацую_, _مقعد_
  { {0x61e000d9,0x0556006b,0xf487002b,0x4d7a004c}},	// [a720] _raml, ствя, مالی, אָבא
  { {0x68fb0008,0x60c200bd,0x25e8000b,0x61e018e0}},	//   _עליה, vtom, _चोरी_, _saml
  { {0xe80d005d,0xba9a0053,0x9f640064,0xe9df0144}},	//   _सकता_, ָסני, ütün_, clús_
  { {0x60c2484e,0x90a60029,0x7afc00b8,0xe2970001}},	//   ttom, محتم, ärti, сац_
  { {0x2005002c,0x71e70015,0x987a004c,0xd24f0067}},	//   _boli_, صفوف_, נאַט, رنه_
  { {0x6ec60015,0x1eaa0015,0xdbf00046,0x8fa30054}},	//   متبق, هابي_, _příd, паље
  { {0x6ab6014e,0x66060005,0x8fa3484f,0x91e60608}},	//   _अमेर, _kokk, чаје, _лове
  { {0xdb010084,0x53370053,0x6b980061,0xbce60015}},	//   uglý, _האלב_, _sevg, مأخو
  { {0x91030004,0x8fa62a6b,0x66064850,0x9be601f3}},	//   _епте, _газе, _रवैए_, бінк
  { {0xb5fb0023,0xf3f10008,0xdbf00089,0x6011002e}},	//   _khác, ֵ֣י_, _tříd, rðmæ
  { {0x0dca0191,0x93fb0008,0xe9f9009e,0x3940003e}},	//   _були_, אליי, анні_, _axis_
  { {0x66060084,0xddc8002a,0x78600123,0xa3cf000b}},	//   _nokk, _ludź, hövd, _वॉन_
  { {0xa3b8005d,0x8c4615be,0x799d4851,0x0000006a}},	//   छला_, _леде, rasw,
  { {0xd9180080,0x7af7001a,0x79540015,0x7bc7007c}},	//   сью_, óatí, سَّا, õjut
  { {0xdb1e00f2,0x799d003f,0x7a860015,0x79840034}},	//   ävän, pasw, _اشتم, _ffiw
  { {0x442a0b4c,0x95d9000d,0xb5fb002d,0xbb82002b}},	//   _amb_, јдат_, _sháb, _بلژي
  { {0x26c300bd,0xc3990036,0x53990080,0x6258002d}},	// [a730] stjo_, икає_, ивая_, tíon
  { {0xb3670080,0x93ab0015,0x68ed4852,0x7e7a4853}},	//   бъек, طائف_, _irad, _outp
  { {0x6258002f,0x68ed0107,0x20053a6a,0x2bca000b}},	//   ríon, _hrad, _roli_, ़्या
  { {0x3abb0053,0x6258002d,0xd1310115,0x32b80015}},	//   רמאנ, síon, وما_, صدمة_
  { {0xb5fb002d,0x02440015,0x20054854,0xb87b0046}},	//   _tháb, أَنَ, _poli_, dvík
  { {0xa295078f,0x68ed003f,0x889c009d,0x389c000a}},	//   _магі, _mrad, רבגי, ניונ
  { {0x8db5005e,0xc7b4004c,0x1ea8002b,0x3e890015}},	//   оспі, לבס_, مايي_, جَبَ_
  { {0xf2d200b2,0x6258002f,0x2005005c,0x786000c0}},	//   _קען_, níol, _woli_, möve
  { {0xee36008f,0x23c6005d,0x4bd50033,0x78600123}},	//   ўны_, र्वद, оўну, löve
  { {0xeb990001,0x5ac90120,0x0000006a,0x0000006a}},	//   шио_, алом_,   ,
  { {0x68ed0064,0x4f670029,0xdddb005c,0x78a90085}},	//   _arad, _طائف, rmuł, ševl
  { {0xdd1e0089,0xd910002b,0x68ed3fd6,0x0000006a}},	//   _síťo, فیع_, _brad,
  { {0x786001d1,0xbd450067,0x68ed4855,0x7e7a4061}},	//   höve, _بنشي, _crad, _zutp
  { {0x78600d9c,0xcb69009c,0x907a004c,0x764f002a}},	//   köve, _кале_, יטשי, _akcy
  { {0xba3d0007,0x78600030,0x66e341f2,0x68ed4856}},	//   grįs, jöve, мора, _erad
  { {0x2d9f00b8,0x4df9004c,0xb90a030c,0x558a01b0}},	//   naue_, ספּא, _вниз_, рбам_
  { {0x644300bd,0xad19000a,0xd7760015,0x842a052b}},	// [a740] čnin, בוּר, _وادع, ажав_
  { {0xa5bb002a,0xb4634857,0x3e710160,0xb5fb00a1}},	//   _omów, дкул, _ošto_, _phác
  { {0x59c1000b,0x442a0012,0x2377002b,0x77f7000a}},	//   ष्कर, _vmb_, زمند_, _ומיד_
  { {0x4b4c0053,0x660600f2,0x3f850045,0x60ea004a}},	//   נגאַ, _uokk, _aflu_, имем_
  { {0x95880007,0x10a3224d,0x3e711c1e,0x50d6002b}},	//   grąž, дичн, _ašto_, تزار
  { {0xf5030010,0xb5fb0092,0x4fc60484,0xeeaa0b08}},	//   _ўзро, _thác, ісла, атик_
  { {0xb87b001a,0xddc9002a,0x9e660067,0xdefa08f0}},	//   tvík, kleń, يابن, рыл_
  { {0x2dd30063,0xf7730008,0x6ca6034e,0x82160015}},	//   джър, וקו_, орож, _بورص
  { {0x6258002d,0xbc770088,0x1d340195,0xddc90535}},	//   níom, обых_, яния, dleń
  { {0x8c430124,0x69cd0026,0xddc2005c,0x9b6a0a0b}},	//   мење, _sbae, _skoń, ишна_
  { {0x637b000a,0xa5bb016e,0x8ae60033,0x3b54006b}},	//   יניד, _imóv, ціпл, якор
  { {0x68ed00df,0xba2b0036,0xa2cd000b,0x25a04858}},	//   _prad, ріод_, _सहस्, jail_
  { {0xcd360074,0x78600014,0x0e69002b,0xed572535}},	//   _براب, zöve, _اصلي_, _доц_
  { {0xf1150053,0xb8670015,0x7c2a198f,0x984b2e38}},	//   פֿרי_, تاجو, _umfr, ряма_
  { {0xdb4f0036,0x25a013e2,0x65950a31,0x02c90065}},	//   _цю_, fail_, забу, _रहेन
  { {0x7afc0005,0xddc2005c,0x25a04859,0x95c50015}},	//   ärtu, _ukoń, gail_, ثيره
  { {0xd37b28e1,0x68ed41eb,0xb5fb0125,0x2d840125}},	// [a750] аче_, _urad, _cháa, icme_
  { {0xa3d4024f,0x3c54000a,0x7860186f,0x7c3a0b35}},	//   моуч, פֹּל_, töve, nntr
  { {0x25a0002f,0xd3710029,0x321d0034,0xf8bf0030}},	//   bail_, ءها_, thwy_, széd_
  { {0x25a0002f,0x2bca005d,0x92590080,0xf1a7005e}},	//   cail_, ़्ता, щает_, ірен
  { {0xc5fa013a,0x7860379f,0x45fa000a,0x443a01d7}},	//   _הפרט, söve, _ההרג, bnp_
  { {0xc0780036,0xd91c000a,0xdb1a007c,0xd006067a}},	//   ісії_, סוגל, letõ, зеше_
  { {0xa1950191,0x82a400d7,0x160f000b,0x11d70015}},	//   _навч, _оште, _सवार_, _وترد
  { {0x7c3a0531,0xf1c90015,0x2f120015,0x7e62485a}},	//   entr, _دورى_, عِير, _chop
  { {0xf654000a,0x2d9f0012,0x7ff7006e,0x81191673}},	//   וצק_, raue_, _وسطا, _ужас_
  { {0x4b25022a,0xbfbb0015,0x4c050058,0xdb1a0072}},	//   змов, _خطرا_, سِجل, hetõ
  { {0xc9490008,0xb17d002c,0xac380033,0xa5bb002a}},	//   _עמ_, _zaťa, ўчых_, _umów
  { {0x7a360007,0xceb2000a,0x7c3a485b,0xd946009b}},	//   kšte, _טיב_, antr, земи
  { {0x25a01a8b,0x18a30033,0x7e69485c,0x186a02ed}},	//   vail_, наям, mmep, йами_
  { {0x7c940086,0xdb1a007c,0x291e002a,0x7e69014b}},	//   _آشنا, eetõ, ąta_, lmep
  { {0x64430264,0x4e1f000b,0xabfa000a,0x25a044a3}},	//   čnil, _बताई_, _להסר, tail_
  { {0x6e3b002e,0xdb1a007c,0x25a00125,0xaa290015}},	//   nnub, tetö, uail_, _وثيق_
  { {0x6258002d,0x7e69003f,0x25a0485d,0xe944002b}},	// [a760] uíom, imep, rail_, _ترغی
  { {0x2d9d00dd,0x6258002d,0xdb1a05ff,0x637a004a}},	//   _lewe_, ríom, retö, ссар_
  { {0xb77b0008,0x877b000a,0x2ba60046,0x51860925}},	//   _לאיש, _לאיי, lící_, пула
  { {0xdb1a0020,0xc916000a,0xe6120015,0xa2cd000b}},	//   petö, ּחַת_, _أشد_, _सहर्
  { {0xb5fb0092,0xf772002b,0xc4830033,0x2ba60046}},	//   _khán, _تاک_, _пляк, nící_
  { {0x93260086,0xd12f00e5,0xaf06004a,0x7e623e30}},	//   _فرزن, دمه_, зчик, _shop
  { {0x877b0053,0xb7db0008,0x66160007,0x7e620034}},	//   זאצי, מקסי, okyk, _phop
  { {0x661600df,0x333b0008,0x51b50001,0x828b000a}},	//   nkyk, _התלמ, _осуђ, _לְמֶ
  { {0x2ba60089,0xd0260063,0xe611000a,0x66160091}},	//   jící_, _емай, דִי_, ikyk
  { {0xb5fb0092,0x2ba60046,0x6604008c,0x78a60789}},	//   _nhán, dící_, hjik, dskv
  { {0xeee4002b,0xbf130015,0x1a780033,0xddc80091}},	//   _تغذی, _كوكب, юбны_, _iudž
  { {0xd337000a,0x4efb004f,0x1eea009a,0x0000006a}},	//   לריה_, _להבו, _پوچی_,
  { {0xa2070008,0x09e40010,0xd7fb005e,0xbc67002b}},	//   לֶךְ_, хоўн, був_, تمین_
  { {0x36d50124,0x7a36032c,0xb5fb0092,0xa08b000a}},	//   могр, všte, _chán, מְלִ
  { {0x3f9e00df,0x7bda485e,0x77c80033,0xddc80f81}},	//   _metu_, metu, ялёг_, _mudž
  { {0x6443018c,0x8b3b0008,0x3abb000a,0x7abb000a}},	//   čnim, _לתוצ, _המהנ, _הצהו
  { {0xd8bb0086,0x7bda0020,0x70bb000b,0xf9900015}},	// [a770] _ادعا_, oetu, _ईमेल, _صبي_
  { {0xa4e40010,0x2bcf000b,0x9cd7000a,0xdb1a3268}},	//   эўск, त्पा, הומה_, setõ
  { {0xc2c40015,0x7bda485f,0x5334004a,0xc7b2004f}},	//   فيلي, ietu, нефт, _בבי_
  { {0x7bda4860,0x7a36016f,0x22140138,0xdcfb0160}},	//   hetu, pšte, нфір, zbuđ
  { {0xddc84861,0xd009000d,0x7bda11ec,0x3f9e0052}},	//   _budž, желе_, ketu, _betu_
  { {0xe0d8005e,0x2d9d00aa,0x4734002b,0x34fa000a}},	//   яві_, _sewe_, _آریز, _והשד
  { {0x7bda0005,0x6e3b0035,0x7e69007c,0x28df000b}},	//   detu, tnub, tmep, _पैसि
  { {0xc332000a,0x8db50033,0x31c41ebd,0x44334862}},	//   _סון_, фскі, _псув, lix_
  { {0xad250015,0x443300e9,0x1ee7002b,0x78600123}},	//   برغو, oix_, زوکی_, höva
  { {0x7bda04f9,0x2d9d000c,0x40e80008,0x139a004c}},	//   getu, _wewe_, _מַעֲ, ֿברע
  { {0xa3cf005d,0x64a20011,0xf412000a,0x9f550033}},	//   व्य_, mţiţ, דפי_, _ўвеч
  { {0xc7a90dab,0xce350086,0x3f9e003f,0x2ba60046}},	//   _כב_, _کوچک, _zetu_, tící_
  { {0x3f9e000c,0x6443016f,0x3ea0016f,0x7bda0776}},	//   _yetu_, čnij, ćite_, betu
  { {0x6c7a000a,0xdb0d001a,0xdb1a016e,0x7bda4863}},	//   _ואספ, þjóf, tetô, cetu
  { {0xeafb002b,0xeab10015,0x661600aa,0x8c420b27}},	//   _درشت_, _شعث_, tkyk, _шеше
  { {0x96550001,0x44330251,0x4a760015,0x75d60021}},	//   еђуј, eix_, _تُعر, بيرا
  { {0xb5fb0023,0x66160007,0x64a30c6e,0x53a60033}},	// [a780] _thán, rkyk, ката, дазб
  { {0x661600f2,0xdc88000a,0x752401c2,0x7794002b}},	//   skyk, לְעָ, rziz, _سیرا
  { {0xb7fb000a,0x2bcf000b,0x41e6005e,0xa22a0033}},	//   _ופית, त्या, діла, ожжа_
  { {0xc6930008,0x22400020,0xa5bb0125,0x44333bab}},	//   _שאר_, õik_, _clód, aix_
  { {0x7bda003f,0x00da0021,0x0000006a,0x0000006a}},	//   yetu, تبات_,   ,
  { {0xd0100029,0xd0070001,0x64a303ae,0xe29a4864}},	//   طلب_, деље_, _јара, _маг_
  { {0xc3340053,0xa2e3004a,0x69c4002a,0xc059005e}},	//   _װוּ_, _иорд, _ocie, чії_
  { {0xdb014865,0x3f9e003f,0x78a92064,0xa2060033}},	//   palê, _wetu_, ševi, _ўпад
  { {0xed570124,0xd6570008,0x7bda45ee,0xfcd40015}},	//   моћ_, ויקת_, tetu, ريدج
  { {0xf0630010,0x6aba00c0,0xa4fb000a,0x69c40a8b}},	//   _акуп, tutf, קליט, _acie
  { {0x83b7013a,0x68e40705,0x9f7b000a,0x7e970015}},	//   ופיע_, _asid, _ונבח, _ينكر_
  { {0x7bda0c58,0xdd9000e6,0x7c210012,0x7d0600cb}},	//   setu, _صوت_, ahlr, økss
  { {0xa3de000b,0x273c006f,0x200c4866,0x7bda4867}},	//   ढ़ा_, yšné_, _kodi_, petu
  { {0x7bc3002d,0x644302c6,0xb8f7000b,0x6aba02de}},	//   _gcnu, čnik, _सह_, putf
  { {0x3bbb0008,0xf7700115,0x45d504e0,0x200c4868}},	//   _ומוד, لاف_, новс, _modi_
  { {0x59c6005d,0x3e45003d,0x78600123,0x5eeb000a}},	//   _वायर, pēte_, röva, חַמְ
  { {0x69dd4869,0x189b0015,0xa99c000a,0xe53401c5}},	// [a790] mese, _بضعة_, _ובחר, веть
  { {0x7a360007,0xc86700e6,0x200c173a,0x787a000a}},	//   mšta, _تطبي, _nodi_, _צָפו
  { {0xddc80050,0x92950010,0x68e400dc,0xb284004a}},	//   _budż, хаец, _zsid, вычк
  { {0xa2940191,0x92940010,0x69dd486a,0x34950033}},	//   таці, тацц, nese, _памр
  { {0x629c0026,0x3e61002e,0x3d18005d,0x69dd05c7}},	//   _ewro, jóta_, धनों_, iese
  { {0xb87b0084,0xc9180008,0x200c486b,0x857405fc}},	//   lvís, וחדת_, _codi_, _шлях
  { {0x69dd030f,0x22b80015,0x179c000a,0x64a20045}},	//   kese, _يدفع_, חיוב, rţiţ
  { {0x261c002f,0x7a360007,0x63a50049,0xb0da000b}},	//   _líon_, kšta, lahn, _मैकग
  { {0x629c005c,0x50f50036,0x9f450057,0xe588000a}},	//   _zwro, _язат, _malé_, וָתָ
  { {0x200c0026,0x78bd0020,0x2bca000b,0x69c40738}},	//   _godi_, dusv, ़्ला, _scie
  { {0x7afc0020,0xb87b0089,0x7a360fcb,0xb0280015}},	//   ärtp, zvít, ešta, _تكلم_
  { {0x8ed80029,0x20070198,0x69dd486c,0x61e9008c}},	//   _تذكر_, ljni_, gese, _jael
  { {0x61e9000c,0x78bd0020,0x20c90030,0x200702d8}},	//   _mael, gusv, núi_, ojni_
  { {0x69c4002a,0xa3cf000b,0x63a5486d,0xfaa508a0}},	//   _wcie, _वॉल_, jahn, _зако
  { {0x8c1a0008,0x261c002d,0x7a360091,0xff47002b}},	//   _מוסי, _díon_, ašta, اخ_
  { {0x85b50124,0x69c4005c,0x69dd486e,0x6fd30061}},	//   кључ, _ucie, cese, lıcı
  { {0xb4661c0c,0x75d3002b,0xdb010030,0x261c0125}},	// [a7a0] екал, طيلا, dalé, _fíon_
  { {0x6fd301e2,0x61fb486f,0xe4570382,0xa5bb0125}},	//   nıcı, _anul, ежу_, _clób
  { {0x23c6005d,0x479b000f,0x4a7a000a,0xa79b000a}},	//   र्गद, _מייס, ִרְב, _משיח
  { {0x1a9a0053,0x2bcf005d,0x22930015,0xd36f0015}},	//   פינע, त्ता, النس, حهم_
  { {0x63a54870,0x083a004f,0x0000006a,0x0000006a}},	//   bahn, ֔עְל,   ,
  { {0x993b000a,0x69dd12e0,0xf73a000a,0x3e613e08}},	//   התנה, zese, ּתֵך, vóta_
  { {0x200c0263,0xe7d2000b,0x69c1000b,0x11d600fd}},	//   _vodi_, द्यप, _वाली, _піар
  { {0xadf40cb9,0x2dda0015,0x6d59051e,0x7a36006f}},	//   тпиш, سبعة_, _bywa, yšta
  { {0x59a7014e,0x69dd4871,0x25a2003d,0x6d590034}},	//   _ख़बर, vese, _mekl_, _cywa
  { {0x78bd0020,0x69dd4872,0xf1bf0030,0x9f470046}},	//   vusv, wese, _öár_, zdné_
  { {0xe3b3004c,0xb4bd000b,0x6ec50015,0xe26a000a}},	//   װױר_, _इम्_, _لتنق, ּדָֽ
  { {0xf2d300b2,0xda670029,0x23c7005d,0x78bd4873}},	//   נער_, عادي, _लाभद, tusv
  { {0x69a2005d,0x4974004a,0x48e40033,0x63a501d7}},	//   _ख़री, ллюс, гоўв, yahn
  { {0x69dd06ef,0x3e450024,0xdb0103bc,0x78bd4874}},	//   sese, mēta_, zalé, rusv
  { {0xc221005d,0x3e450024,0x6af30015,0x69dd4875}},	//   _मतलब_, lēta_, _مثير, pese
  { {0xcf570008,0x07080029,0x7a360085,0x63a5058a}},	//   גבלת_, ريقي_, pšta, wahn
  { {0x9f47002c,0x3e450024,0xdb010107,0x7a3600bc}},	// [a7b0] rdné_, nēta_, valé, oštn
  { {0x87070010,0x93880033,0x8d4b004f,0x0000006a}},	//   _зяме, есца_, הֲבֵ,
  { {0xa8580008,0x63a5013c,0x08f8002b,0xf8bf0003}},	//   _איזה_, rahn, _قریب_, lué_
  { {0x50b5004a,0x4b37004c,0x6fd30061,0xf2040fea}},	//   вску, עראל_, zıcı, лячо
  { {0x6fd301e2,0xc0e5009f,0xf8bf0003,0x61e9008c}},	//   yıcı, толк, nué_, _vael
  { {0x07380086,0x61e90026,0xe0570086,0x6d59005c}},	//   _آسیب_, _wael, ریات_, _rywa
  { {0x3ce600bc,0x660f4876,0x225b0015,0xddc2002a}},	//   _asov_, _kock, _فجرب_, _ukoś
  { {0xe8d90023,0xfe710015,0x8f140033,0x96fc000a}},	//   _ngữ_, جدت_, ыфіч, ללות
  { {0x6fd30064,0x660f4877,0x2bb90015,0x0000006a}},	//   tıcı, _mock, وادة_,
  { {0xb3ca005d,0xea89009c,0x660f156e,0xb87b0046}},	//   _सॉफ़्, мбол_, _lock, zvír
  { {0x5dd50015,0x6d59002a,0x2bb5000b,0x6fd30061}},	//   _لقائ, _wywa, ूलबा, rıcı
  { {0xdd95008f,0x8d870063,0x8e96000a,0x3e45003d}},	//   _рады, _чужд, _ידעו_, bēta_
  { {0x3e450024,0xf8bf4878,0xec6e0296,0x25a24879}},	//   cēta_, szén_, _вп_, _rekl_
  { {0x5fe1000b,0x4d640138,0x0000006a,0x0000006a}},	//   फ़िल, _сків,   ,
  { {0xc7a30cb9,0x5e8c000f,0xa3e5000b,0x798d0034}},	//   риск, ּאמֶ, भजन_, _ffaw
  { {0xceb2103d,0xf8bf178f,0x660f2395,0x0000006a}},	//   ייל_, bué_, _cock,
  { {0x59a7005d,0x3ddf0111,0x64a608f0,0x660f487a}},	// [a7c0] _ख़तर, ieuw_, таза, _dock
  { {0x14230323,0xb376002b,0x998902d8,0x7d0605ff}},	//   адум, نداش, _imaš_, äksi
  { {0x3e450024,0xc20f0036,0xe7b7000a,0xa7663797}},	//   zēta_, ає_, _בהיר_, _шкод
  { {0x68f606bb,0xe2970432,0x53c60065,0x41b30058}},	//   _kryd, тац_, र्जश, لممر
  { {0xdb0302de,0x45d30033,0x2cbf007c,0x00fa0015}},	//   _udnæ, _тоўс, juud_, بعاث_
  { {0x9053008f,0x7a360007,0x91bf0092,0xc4d3000a}},	//   авіц, kšto, _phụ_, _דגש_
  { {0x69d600e8,0x7ee30015,0x9e34006b,0x03d7000a}},	//   _obye, لكون, лекч, _שולם_
  { {0x2bcf005d,0x6ced005d,0x036703fc,0x3e45003d}},	//   त्सा, जिंग_, _риск_, tēta_
  { {0x2486002f,0xa2da000b,0x365b004c,0xc0e30239}},	//   íomh_, नबक्, וכקנ, _котк
  { {0x3e450048,0x261c002d,0x4fea005e,0x91bf00a1}},	//   rēta_, _síol_, _імен_, _thụ_
  { {0x0c73003b,0x6d44002c,0x3eb800dc,0x3e450024}},	//   جديد, _žiad, _írt_, sēta_
  { {0xf8bf0152,0x68f6487b,0x5f37000a,0x3e45003d}},	//   tué_, _bryd, _בטבע_, pēta_
  { {0xac0a0001,0xd90f0086,0x660f487c,0x5fc9000b}},	//   _онда_, زید_, _rock, _रामल
  { {0xd918005f,0x68f60335,0x261c0125,0xeb33002b}},	//   тью_, _dryd, _díom_, اریخ
  { {0xf8ae0086,0x07680010,0x660f0b62,0x68f60034}},	//   يکی_, ваёй_, _pock, _eryd
  { {0x62810152,0xd5b81402,0x69c00144,0x68f6487d}},	//   _éloi, ксу_, òmet, _fryd
  { {0xf8bf0152,0x2bcf000b,0xa3a70054,0x0000006a}},	// [a7d0] qué_, त्वा, вјек,
  { {0xa4d40127,0xe3b30015,0xd7f50033,0x7cfd001a}},	//   рофі, شرط_, _ёзны, lærð
  { {0xe2980036,0xe7ec005d,0x59a7000b,0x97a40033}},	//   ває_, _छोटा_, _ख़ार, _трыл
  { {0x41b400f4,0x645e487e,0x35550058,0x0000006a}},	//   асшт, alpi, _منجز,
  { {0x80e40029,0x6d4e00b8,0x25a9487f,0x20c80015}},	//   لأول, ßbal, maal_, نبوي_
  { {0x8e390086,0x1ec90b44,0xe2930021,0xe8d90016}},	//   کستر_, елки_, _نذر_, _ngử_
  { {0x1ea8002b,0x7a26001a,0xc7d8004f,0x7ed5009a}},	//   نايي_, _hóte, דווי_, ازتا
  { {0xdb030152,0x877c0053,0xb5fb002d,0xa3cf000b}},	//   _fenê, ואוי, _bhái, व्र_
  { {0xb5fb002f,0xacf5006e,0x0000006a,0x0000006a}},	//   _chái, اسبت,   ,
  { {0xdab9008f,0x25a90150,0xb5fb0125,0x0000006a}},	//   нымі_, haal_, _dhái,
  { {0xc4d0005d,0xe807005d,0x7cfd002e,0x03d6000a}},	//   _सङ्ख, शाना_, færð, אותם_
  { {0xb5fb002f,0x68f64880,0xf2da0053,0xa2c4005d}},	//   _fhái, _pryd, ײַטל, ांत्
  { {0x3e450024,0x91f60008,0xbd280029,0x25a9053a}},	//   lēto_, אמרו_, _لأول_, daal_
  { {0x395e0048,0x01360053,0xaa890015,0x2cad007c}},	//   āts_, אָלט_, _كنتم_, msed_
  { {0x186706ac,0x2cad0a54,0xfbd2000a,0x3e45003d}},	//   уари_, lsed_, _התו_, nēto_
  { {0x2bcf005d,0x68f60026,0x4df90053,0x25a90079}},	//   त्रा, _tryd, עפּא, gaal_
  { {0x05664881,0x2cad3bd6,0x9f4502b9,0xfbb7000b}},	// [a7e0] уван, nsed_, _salì_, _आयाम
  { {0x69c60111,0x2cad4216,0x389b00f3,0x53a60015}},	//   lgke, ised_, _ריינ, اماك
  { {0x3ce5005d,0xdb014882,0xd296005e,0xe29a0033}},	//   _जैसे_, kalí, урзь, хае_
  { {0x2cad0020,0x6b7a0053,0xa50a067a,0x25a90079}},	//   ksed_, גרענ, _зема_, caal_
  { {0xc05a008f,0x3e4c02d5,0xa856000a,0x69c60012}},	//   нік_, něte_, ְיֶה_, igke
  { {0x6e22049f,0xd0100015,0xd0070608,0x9e66002b}},	//   _slob, تلت_, лече_, گاتن
  { {0x2cad018c,0x44444883,0x99820091,0xc7b3000a}},	//   esed_, mn_, nikų_, זבו_
  { {0xb5fb002d,0x6258002d,0x444407b3,0x9e660015}},	//   _phái, ríos, ln_, داتن
  { {0x25370053,0x4444026e,0x2cad007c,0x867b004c}},	//   ָניש_, on_, gsed_, ערפו
  { {0x69c600dc,0x44444884,0xcbe605b3,0x3e4c0046}},	//   egke, nn_, уции, děte_
  { {0x2cad003e,0x501b0008,0xe4570135,0x44443d8d}},	//   ased_, _רובו, רייט_, in_
  { {0xb5fb002f,0xc333011f,0x61e2002d,0x33770008}},	//   _thái, מות_, neol, טעים_
  { {0xddc901e2,0xdddb0064,0x443a2bcc,0x2608000b}},	//   lleş, lmuş, kip_, हानी_
  { {0x44444885,0x9f470046,0x8c433d93,0xdc8b000a}},	//   jn_, zdní_, _лече, _נְדָ
  { {0xddc901e2,0xec370008,0xdddb0064,0x25a90150}},	//   nleş, _תאור_, nmuş, taal_
  { {0xa507006b,0x60c24886,0x7c3a13db,0x39150c31}},	//   лязл, kuom, litr, _вмир
  { {0x3e450024,0x44440b10,0x25a94887,0x7a26001a}},	// [a7f0] zēto_, fn_, raal_, _fótb
  { {0xddc901e2,0x8574022a,0x734b0a0b,0x47350725}},	//   kleş, слух, нчев_, _внос
  { {0x25a90409,0x287a000a,0x8bd7000a,0x60db4888}},	//   paal_, _שנתמ, רובו_, _spum
  { {0x443a00df,0x32b80029,0x644b0030,0x569a000a}},	//   aip_, ادلة_, égib, _שירצ
  { {0x9f470089,0x44444889,0xda4c000a,0xc0c80054}},	//   rdní_, bn_, עֲבָ, гује_
  { {0x2cad0020,0xb5fb0656,0x94ba000a,0x660d1e8f}},	//   vsed_, _cháv, _במשת, ljak
  { {0x92940010,0xb7fc000a,0x023b0015,0xdb03488a}},	//   _гасц, תפות, _كثرت_, _genè
  { {0x3e450024,0x2cad0020,0x6d5d005c,0xed59488b}},	//   rēto_, tsed_, żsam, кой_
  { {0xac850083,0x3e450024,0x10d800e5,0x4c85049d}},	//   јгол, sēto_, _مبلغ_, јлов
  { {0x2cad488c,0xf3f2000a,0x799d0012,0xd578000a}},	//   rsed_, ַ֣ת_, ebsw, נתזה_
  { {0x7f84003b,0x2cad003e,0x63a707c4,0x8f470033}},	//   _المن, ssed_, _mejn, _схад
  { {0xe0c70086,0xda790010,0x26c302c1,0x3e4c0089}},	//   يز_, ляў_, dujo_, těte_
  { {0x443a0064,0x4444488d,0xfc05004a,0x5fda000b}},	//   yip_, yn_, _впло, _मॉडल
  { {0x63a70089,0xa0680008,0x9cd6000a,0x6e290079}},	//   _nejn, ָׁלַ_, _כונה_, lheb
  { {0xcc3a0053,0x49910086,0x44440293,0x4c3a000a}},	//   _בעסט, غییر, vn_, _שתצב
  { {0xe8fa209b,0x6abc002e,0x44440495,0xfc7d0046}},	//   _али_, árfe, wn_, řádá_

  { {0x4a5b0008,0x62870152,0xddc90064,0x7d1b0049}},	// [a800] _בדקו, _aujo, zleş, nyus
  { {0x13a8002b,0x4444488e,0x26c30077,0x937a0015}},	//   انای_, un_, bujo_, نصار_
  { {0x67bb0008,0xd1860010,0xd7bb000a,0xfbb6000a}},	//   _במיק, алей, _בציר, שפעת_
  { {0xe7d2000b,0xdb030144,0x60c2008c,0x62870091}},	//   द्रप, _venè, tuom, _dujo
  { {0x85470142,0x859b000a,0xd757002b,0x3d1f000b}},	//   _взяв_, _בשכו, _ملیت_, यनों_
  { {0x60c200df,0xe296000d,0x6d4e0064,0x61e2002d}},	//   ruom, _враќ, şbak, seol
  { {0x2120065d,0x60c20007,0xc7b3000a,0xfae70015}},	//   ših_, suom, קבה_, _بث_
  { {0xddc901e2,0xfe6f0029,0xe3630036,0x2d82003c}},	//   rleş, ودي_, _єкти, øke_
  { {0x394d0050,0x7c28488f,0x5c0601f3,0xc1bb000a}},	//   żesz_, thdr, аяна, _שממש
  { {0x7ed60036,0x6fb30015,0xdb030030,0xcd330015}},	//   _відч, _ومقا, _zené, غريب
  { {0x752d02d7,0x6280315f,0xaab5002b,0x6bd8002b}},	//   zzaz, _kimo, مگير_, نوکس_
  { {0x7f3b0008,0xdd8f0031,0xdb23001a,0x6e2904dd}},	//   _בעבו, _قوم_, _þrýs, cheb
  { {0x7c94003b,0x3ea9016f,0x09e40010,0x7c3a429d}},	//   _التص, ćate_, цоўн, pitr
  { {0xe824004a,0x1b2a0015,0x5ba3006b,0x9cdb000a}},	//   офсо, _لأبي_, _дръз, _סקופ
  { {0xb5a70063,0x27f1003d,0x8bfb000a,0xdb080030}},	//   ирай, rdzn_, _שִׂפ, kadé
  { {0x6d5c01e2,0x4b7b0632,0x6b7b0008,0xdb7b000a}},	//   ğraf, _באוו, _ברונ, _בנוכ
  { {0x9f450107,0x7bc800aa,0x660d4890,0x645716c4}},	// [a810] _malá_, ogdu, rjak, toxi
  { {0x2246002c,0x7bc84891,0xa3b80015,0x92b70015}},	//   enok_, ngdu, لامر_, لحصا
  { {0x2d82002c,0x6672002b,0xd37b0088,0x22470046}},	//   ľkej_, تگیر, тча_, énko_
  { {0xdb0100dc,0x9756000a,0x672d003d,0xc692000a}},	//   nalá, _לשתף_, ģijā, _מאט_
  { {0x14f40010,0x62804892,0x69cf000b,0x84e40033}},	//   _дзяў, _dimo, _थानी, _доўж
  { {0xb97c0053,0x5576004c,0x7860008c,0xa3cf000b}},	//   דנדי, _לערן_, tövi, _वॉच_
  { {0xdb010264,0x3169006f,0xdb030077,0x6fb20015}},	//   kalá, ťaz_, _tené, سميا
  { {0xf2d20008,0x5fc9000b,0x59c6000b,0x6e920015}},	//   _מעל_, _रावल, _वाइर, أليا
  { {0xdb010014,0x7a26002d,0x6e294893,0x315b0015}},	//   dalá, _nóta, rheb, _شجرة_
  { {0x10140015,0x628008c1,0x7a360046,0x79840034}},	//   _وبلد, _zimo, mšti, _sgiw
  { {0xdce70064,0x8e850029,0x7a3601b2,0x44210e94}},	//   ımız, _الصه, lšti, ikh_
  { {0xdb0100dc,0x2bd8000b,0xa5bb001a,0x6822006f}},	//   galá, ब्बा, _blóm, _pôdo
  { {0xc956005f,0xf8bf0152,0x7a360107,0x3e61001a}},	//   стны, gré_, nšti, jóti_
  { {0x765d4894,0xeb96005e,0xd264003d,0x89630015}},	//   _aksy, _лиш_, miņš_, سُّن
  { {0xd8390010,0xd62a15bc,0xa6660015,0x68ed02b9}},	//   рэў_, гове_, مطرو, _esad
  { {0x7a360007,0xbbb7000b,0xdb080003,0xf8bf142b}},	//   kšti, _आयुक, xadé, bré_
  { {0xcc880023,0xf8bf0152,0x62804895,0x7a360089}},	// [a820] _lớn_, cré_, _rimo, jšti
  { {0xa3ba0015,0x4376004a,0x67430030,0x7a360046}},	//   طائر_, бует, ávjá, dšti
  { {0x38170008,0x4c3a004c,0x7c3a004c,0x644b435c}},	//   _הקים_, נגעצ, נגעז, égia
  { {0xd25913ae,0x6b5a004c,0xc1b40065,0x0000006a}},	//   аці_, אדעפ, ुलेग,
  { {0x25a00d25,0xdb0800dc,0xe5f7000a,0xf1a90067}},	//   mbil_, radé, _הזכר_, شانه_
  { {0x20b9008f,0x98a2002a,0xd0950033,0xd8d7000a}},	//   рыць_, czką_, ішчы, מונט_
  { {0xaf030010,0x7a36016f,0xfeb7002b,0xe2970180}},	//   зчык, ašti, مايت_, _гас_
  { {0x9e14005e,0x4cb8004a,0x7a360046,0xdee50015}},	//   ідпі, алию_, bšti, تأهي
  { {0xc5f30008,0x2dd70015,0x9f47006f,0x25a00045}},	//   לדה_, صبية_, rdná_, ibil_
  { {0x7c930029,0xf8bf0003,0xec34005e,0x20d20045}},	//   أشيا, vré_, іннь, mâi_
  { {0xdb014896,0x5f760029,0x7a260ac5,0xb5fb0125}},	//   talá, _طائر, _sóta, _mhár
  { {0x5d86003b,0xe37b0053,0xf8bf428a,0x2cbf02de}},	//   _الإل, טריר, tré_, brud_
  { {0xfdf70008,0xc7bb004a,0xd264003d,0xf8bf00e9}},	//   _לצאת_, лёв_, ciņš_, uré_
  { {0xdb0100dc,0x7a26002d,0xc7bb0010,0xf8bf4897}},	//   salá, _vóta, ыём_, rré_
  { {0x6fda005d,0x501b0008,0xdc3b0053,0x8bd70008}},	//   प्यू, נולו, _געגר, _לוגו_
  { {0x7e910024,0xe8d90092,0x682b0359,0x8698004a}},	//   _jāpa, _ngủ_, _südd, стёт_
  { {0x68ed470c,0x2bcf000b,0xb3870021,0xb5fb0125}},	// [a830] _usad, त्का, مجاه, _shás
  { {0x7a364898,0x3ce0005d,0x44272512,0x4b98000a}},	//   všti, _कहने_, ón_, שֹּׁ
  { {0xfa890092,0x6d5d003d,0xd264003d,0x92950e7c}},	//   _lẫn_, ļsai, ziņš_, цаец
  { {0x92590080,0x1fb3000b,0x7a360046,0x98a2002a}},	//   шает_, ील्ड, tšti, szką_
  { {0xdb0a02de,0x7a360f81,0x1fa9018d,0x0000006a}},	//   _udfæ, ušti, акли_,
  { {0xd5bf0024,0x3e450024,0x7a364899,0x3e4c0046}},	//   žādu_, mēti_, ršti, věta_
  { {0x0309000a,0x3e45003d,0x6a440030,0xb4f6000b}},	//   _דִּֽ, lēti_, lőfe, ीमॅप_
  { {0x7a36016f,0x9d550029,0x237e0030,0x8cb5009f}},	//   pšti, ينغت, _útja_, осоч
  { {0x9f5e08e0,0x3e450024,0xde160015,0x62810003}},	//   _botó_, nēti_, تقيت_, _éloq
  { {0xfa890023,0x8fa40001,0x3a2900dc,0xd264003d}},	//   _dẫn_, _нађе, _alap_, riņš_
  { {0xcb69489a,0xbfb40015,0x7e830030,0x93b6004f}},	//   ране_, _رحلت, _főpa, חלתו_
  { {0x6b9c0061,0x24830079,0xcf56000a,0x8d74002b}},	//   ırga, _lijm_, _ובעת_, _کاما
  { {0x9f5e00dc,0xe81b000b,0x88c7005e,0x998c0030}},	//   _fotó_, _नकशा_, оляв_, élők_
  { {0xf092013a,0x30790053,0xa5bb002e,0x3e45003d}},	//   ונך_, יאָנ, _flók, dēti_
  { {0x9f29000a,0x98ab003d,0x3a2904a9,0x224d01d7}},	//   בֵּ֖, ājās_, _flap_, _ojek_
  { {0x96660033,0x66e3006b,0x644b0030,0x166601f3}},	//   ікае, ьоса, égin, івам
  { {0x3ea0016f,0x682b00b8,0xb5fb002d,0xf9b7000a}},	// [a840] ćiti_, _süde, _phár, _והפך_
  { {0x37c60029,0xebac004c,0x9c82006f,0x7d040125}},	//   _بيدف, ָסאָ, _účta, _áise
  { {0xd6b60015,0x74130040,0x366a00ce,0x0000006a}},	//   _بإخب, بولا, _вано_,
  { {0x20d20011,0x7a26001a,0xd98d000a,0x76410030}},	//   tâi_, _móto, ְנוֹ, élyt
  { {0xe6110008,0x261c002d,0x3e45003d,0x61f70033}},	//   _אִם_, _díot_, cēti_, ўніў_
  { {0x2fc000b8,0x443e00dc,0x09a7000b,0xceba0054}},	//   ßig_, _öt_, _ख़्य, аљи_
  { {0x9f4c02b9,0x73f9004c,0xdb03489b,0x987b004f}},	//   _andò_, _פּשו, _bení, ברסק
  { {0x20052017,0x35b2000b,0xde730015,0x471b000a}},	//   _enli_, _ज़फ़, وديع, יוצג
  { {0x629e00f2,0xdb030089,0xd7aa000b,0xf8bf0030}},	//   lppo, _dení, कराच, nzét_
  { {0xfa890023,0xbfc300d7,0xc43a000a,0x69da0030}},	//   _vẫn_, _обук, יתִי, őtel
  { {0x7e910024,0x3e450024,0xc3fb004c,0x9f5e0077}},	//   _tāpa, zēti_, בליש, _votó_
  { {0x2d920064,0xed5a13ab,0x58870010,0x7a360007}},	//   _üye_, _кое_, жыва, kštu
  { {0xf1b30008,0xe807000b,0x127b004c,0x527b004c}},	//   וסר_, शाला_, יאטע, ינטא
  { {0xf7eb0015,0x6606008c,0x99990046,0xe8d90016}},	//   جرحى_, _ankk, pisů_, _ngụ_
  { {0x261c017e,0x67d4005e,0x56940421,0x60c233a7}},	//   _níos_, ьору, даст, hrom
  { {0x95cb000d,0xb5fb0057,0x442a489c,0x60c21630}},	//   јува_, _cháp, _alb_, krom
  { {0x98be0045,0xca1a000a,0x644b0003,0x84970015}},	// [a850] ătă_, _הֵיכ, égio, تجزئ
  { {0x3e450024,0x93270031,0xf367489d,0x442a0016}},	//   rēti_, يران, отен, _clb_
  { {0x3e45003d,0x261c0125,0x7a360091,0x200500e7}},	//   sēti_, _cíos_, aštu, _rnli_
  { {0x3619000a,0xd1b80015,0x5215004a,0x3e45003d}},	//   _הוֹד, قاها_, ядет, pēti_
  { {0x2608005d,0xae09000b,0x8596000a,0xe1f80033}},	//   हारी_, वासन_, _מדרג_, ўгі_
  { {0x389c0008,0xd3e30086,0xf8bf00dc,0x251a000a}},	//   סיונ, _تقسی, lzés_, _הושא
  { {0xd00e0029,0x224d0134,0x02450015,0xdb03489e}},	//   الى_, _tjek_, _فَسَ, _pení
  { {0x3e61002e,0x9258004a,0x7db40033,0xf8bf489f}},	//   jótt_, _даст_, мсьц, nzés_
  { {0x60c248a0,0xdb030077,0xb2840033,0x7bda0034}},	//   crom, _vení, _цырк, fftu
  { {0x98a2005c,0xa0c40015,0x2a6002de,0x5e870033}},	//   czkę_, _آيلو, _skib_, _дудз
  { {0xa3dd005d,0xdb0304f3,0xdb0800dc,0xda0a0018}},	//   थ्य_, _tení, badí, ميده_
  { {0x38c2002e,0x9f5e02b9,0xbef7000b,0xdef6004f}},	//   _nærð_, _totò_, ंटीन_, _ממעט_
  { {0x9aa50086,0x787202de,0x6fd2000b,0x260f0065}},	//   _کمبو, hæve, _सामं, डानी_
  { {0x261c002f,0x3ce0005d,0xeab10015,0x515a000a}},	//   _níor_, _कहते_, _كعب_, מכרו
  { {0x44ed0156,0xb5fb002d,0x2608000b,0xdbc6007c}},	//   _až_, _pháp, हाली_, töök
  { {0x69db0020,0x261c02c1,0xdb36000a,0xf8bf0030}},	//   õuet, _ríos_, _מנצח_, gzés_
  { {0x261c002f,0x6adb000b,0xa3ff0046,0xe83b0046}},	// [a860] _síos_, _बहुर, _řeší_, řeší
  { {0x1bf3005d,0x77ca0001,0x3e450024,0x2900001c}},	//   _असफल_, _улог_, mētu_, _iria_
  { {0x38c20084,0xf8bf00dc,0x3e45003d,0x23760015}},	//   _færð_, szét_, lētu_, سائح
  { {0x7aba013a,0xcc880092,0xb6030089,0xfe790089}},	//   מצעו, _sớm_, ášte, jmů_
  { {0xf9930008,0x261c002d,0x3e450024,0x9f4c0046}},	//   גרד_, _fíor_, nētu_, _vadí_
  { {0xf8b7000a,0xe2a30016,0x60c23a32,0xaffc0138}},	//   לפני_, _khứ_, rrom, рокi
  { {0xd7f10092,0xdb082c1a,0xa5bb002d,0x62660015}},	//   ỗi_, tadí, _slói, _فارق
  { {0x11da0029,0x682b0064,0xdd900015,0x26c50085}},	//   _دورة_, _müda, خوة_, šlog_
  { {0x42530015,0x90a50015,0x645e007c,0x80a60067}},	//   _أنقر, _يحكم, oopi, _رمان
  { {0x628e000c,0x3e450024,0x351b000a,0x8cbd0157}},	//   _kubo, dētu_, צוינ, _शिरो
  { {0xa5bb005c,0xfd0f0086,0xdb08001c,0x28af005d}},	//   _glów, نجی_, dadã, जीनि
  { {0xdee50029,0xdb03001c,0x68300123,0x6f79000a}},	//   _تأكي, _senã, _lädd, _וְנו
  { {0x8b66002b,0x629a0003,0x290048a1,0x645e3055}},	//   _کاشم, _étof, _cria_, kopi
  { {0xb8f50372,0xaa870086,0x645e016f,0x629c48a2}},	//   _हम_, _کنيم_, jopi, _otro
  { {0xe2a30092,0x7bdb000a,0x45d504e0,0xddc00030}},	//   _chứ_, _הקוו, мовс, lmmű
  { {0x2bd8000b,0x7e9b000a,0x3e45003d,0xba2b002b}},	//   ब्रा, מסלו, bētu_, _دستم_
  { {0x629c1cdb,0xf8bf00dc,0x19bc0008,0x3e450024}},	// [a870] _atro, rzés_, _המחב, cētu_
  { {0xf8bf0030,0xf8b20643,0xd3b9005e,0x69dd22fb}},	//   szés_, _ששי_, ілеї_, lfse
  { {0x41d1005d,0xf8bf00dc,0x2bd4000b,0xa2c4000b}},	//   _हादस, pzés_, _दाना, ांग्
  { {0x78720134,0x628e48a3,0xde8802a3,0xcb57000a}},	//   ræve, _dubo, _усiх_, הסבה_
  { {0xe0ce0063,0xc5fa0008,0x44ed48a4,0x45fa000a}},	//   ъв_, _ופרט, _už_, _והרג
  { {0x44250b7c,0x23c3038d,0x7a36002c,0x92c20064}},	//   _ôl_, _déjà_, nštr, üşün
  { {0x3e450048,0xfe790046,0x0000006a,0x0000006a}},	//   zētu_, tmů_,   ,
  { {0x9f47032c,0xdb030227,0x69dd0079,0x72050067}},	//   nené_, _nená, jfse, _تورم
  { {0x69b1005d,0x62920024,0xdb011446,0x81170015}},	//   _अज़ी, ējoš, mblé, _عذرا
  { {0x60cb0035,0x4b250127,0xa1840010,0x683000f2}},	//   mugm, дмов, _чысл, _käde
  { {0xbb850029,0x68e41af1,0xdb0301c0,0x39ea016a}},	//   بلدي, _spid, _bená, одно_
  { {0x20d1005d,0x0a3a0010,0x645e003f,0x29000523}},	//   _समाध, ічны_, zopi, _pria_
  { {0x645e000c,0x9f470264,0x682b15cb,0xfe36000a}},	//   yopi, dené_, _süda, _קרני_
  { {0x3e450048,0xaac5005d,0x26d804ed,0x7e620089}},	//   rētu_, _विपक, ttro_, _zkop
  { {0xcc560008,0x683000c0,0x26d848a5,0x2ba3000b}},	//   _קבצי_, _rädd, utro_, _ख्या
  { {0x764d00b6,0xd63a0010,0x3e4515e5,0x29000144}},	//   gnay, цягі_, mēts_, _tria_
  { {0x3e450024,0xdb0800dc,0x629c48a6,0x26d80e68}},	// [a880] lēts_, madá, _stro, stro_
  { {0xd7ca0074,0xe2a30092,0xf3ca0015,0xe3ba0033}},	//   _بوده_, _thứ_, تبره_, ібе_
  { {0x3e450024,0x9f470227,0x234b002b,0x14170015}},	//   nēts_, bené_, يسمی_, بيلة_
  { {0x9f4701b2,0xa5bb024b,0xd36f0021,0x7e690d57}},	//   cené_, _slóv, جهم_, jlep
  { {0xf5060033,0xdb080030,0x20d30015,0xa0970015}},	//   _ўзго, iadá, نتوج, وضوء_
  { {0xb937000a,0x889b000a,0x20540033,0x7e7b0079}},	//   וננו_, קבצי, экля, emup
  { {0xe7e0014e,0xdee30001,0xdb0800dc,0x61eb48a7}},	//   ख्या_, воји, kadá, begl
  { {0x4e770029,0xdcba005e,0x61eb02b9,0x3d26006b}},	//   وحيد_, ощо_, cegl, дьов
  { {0x40930029,0xe611000a,0x01d70040,0x016348a8}},	//   _للقر, אִי_, _توقع_, _акто
  { {0x9f47099c,0xdb0301b2,0xd577000a,0x7b140195}},	//   zené_, _sená, ותפה_, едох
  { {0xcc880023,0x59f90010,0xac370015,0x444448a9}},	//   _mới_, пеня_, بسيط_, ii_
  { {0xdb080014,0xd2b7000a,0xcc880016,0x444448aa}},	//   gadá, ולטת_, _lới_, hi_
  { {0x59380010,0x69dd002e,0x9f470264,0x99490021}},	//   дзяў_, rfse, vené_, سلسل_
  { {0x61eb0050,0x7e600375,0x6bd700e6,0x5bc6002b}},	//   zegl, lomp, _يونس_, _آتشف
  { {0x290d0011,0x3e450024,0x9f47163c,0x36d4004a}},	//   ţea_, cēts_, tené_, корр
  { {0x54990010,0xf1b90046,0x44990033,0xdb0302de}},	//   зваў_, _koše_, зваю_, _benæ
  { {0x9f47002c,0x49d60008,0xdce60091,0x444448ab}},	// [a890] rené_, _אֵין_, ėmėm, fi_
  { {0x68300020,0x61eb0012,0x61e60061,0x9f470069}},	//   _päde, wegl, _ıkla, rdnú_
  { {0x64890007,0xf1b9016f,0x7a26002d,0x38580015}},	//   _džia, _loše_, _bóth, _تشيد_
  { {0x7d0200dc,0x60cb0035,0x683000c0,0x05190029}},	//   _oros, tugm, _väde, _فيجب_
  { {0x3e450024,0x7536005c,0xd5b80010,0x759a000a}},	//   zēts_, czyz, _ўсю_, _מסרג
  { {0x61eb0844,0xcf250015,0x1ef90015,0x444448ac}},	//   segl, فرعي, كعبة_, ci_
  { {0x661d022d,0x64450035,0x7d023d15,0x61eb13f0}},	//   _kosk, mihi, _aros, pegl
  { {0x64450035,0x661d00f2,0xfe710015,0xfe09000b}},	//   lihi, _josk, ددت_, वाइस_
  { {0xca290008,0xdfdb0063,0x644500f2,0x7d022eb5}},	//   _ִם_, _мъж_, oihi, _cros
  { {0x7e690020,0x683000b8,0x7d020313,0x644518db}},	//   slep, _mädc, _dros, nihi
  { {0x2416000a,0x4279004c,0xe458004c,0xdb03016e}},	//   תחתן_, ּאָג, ויזט_, _menç
  { {0xc869013a,0x661d0048,0x3e450024,0x64450fd1}},	//   _הן_, _nosk, rēts_, hihi
  { {0x444401e2,0x644500b6,0xfce50036,0x3e45003d}},	//   yi_, kihi, _чоло, sēts_
  { {0x9d1a0008,0x6445003f,0xad1a000a,0x44441da6}},	//   _מונט, jihi, _מונר, xi_
  { {0xcf9200a3,0x2edd000b,0x661d48ad,0xcb660054}},	//   רטל_, _महोत, _bosk, _паше_
  { {0x6289005c,0xceb20008,0x4444306e,0x6445008c}},	//   _nieo, טיל_, wi_, eihi
  { {0x2bb6005d,0x661d48ae,0xf484002b,0x6a440030}},	// [a8a0] _आजमा, _dosk, ناطی, lőfo
  { {0x7536002a,0xdb03001a,0x6445007c,0x444448af}},	//   rzyz, _venæ, gihi, ui_
  { {0xdb0c00dc,0xa5bb002d,0x79fa000a,0x78ad0079}},	//   űköd, _clós, ּלְח, _zwav
  { {0xcc8800a7,0xf1b20015,0x64a60033,0xdb060046}},	//   _với_, اءا_, _пама, áméh
  { {0x56370053,0x644503ac,0xf1d1000b,0x444448b0}},	//   _טאטע_, bihi, _हारन, pi_
  { {0xcc880023,0x3e4c0089,0xdb030064,0x661d002c}},	//   _tới_, měti_, _genç, _zosk
  { {0xdb0a00fb,0x1ef70015,0xb5fb006f,0xa6fa004f}},	//   _udfø, فعية_, _okál, לִ֤י
  { {0xdb24001a,0x42db000a,0x7d022a33,0x7ee30058}},	//   ðsíu, _מקלע, _pros, اكين
  { {0xfd1200e5,0xa0c6002b,0x7e6048b1,0x7a2648b2}},	//   اجع_, _سياو, romp, _góti
  { {0xe0860029,0x853b004c,0x8c430004,0x7e6048b3}},	//   _أجري, פגיי, лење, somp
  { {0x200c48b4,0xbd8a0015,0x682b0012,0xaa590429}},	//   _indi_, _فنان_, _südo, дину_
  { {0xfe720086,0x6445003f,0x7d021266,0x8e97004f}},	//   _صدا_, zihi, _tros, _נדדו_
  { {0x644500f2,0xdca309a7,0x661d48b5,0x201e48b6}},	//   yihi, _бачи, _rosk, _koti_
  { {0xdb0300c0,0x3e4c0046,0xd7c9009a,0x0000006a}},	//   _benä, děti_, بوسه_,
  { {0xadf4005d,0xabfb000a,0x69a2000b,0x1b0a0033}},	//   _आसान_, _מהגר, _क्वी, _хэлп_
  { {0x5eeb000a,0xdb08001a,0xab290058,0xaa890058}},	//   הַמְ, tadæ, _تسهل_, _تنعم_
  { {0xa5bb002e,0x644548b7,0xb17d006f,0x03c703ea}},	// [a8b0] _slós, tihi, _obťa, есем
  { {0x93940029,0x7d0600f2,0xd37b0ea6,0x201e48b8}},	//   هجما, äksy, пче_, _noti_
  { {0x64453279,0xdb0348b9,0xf3350015,0x6aba128a}},	//   rihi, _venç, خفاج, nstf
  { {0xd3700074,0xa2940036,0x78720134,0xb6ba000a}},	//   حهٔ_, уаці, nævn, _קצרי
  { {0x68300f38,0xe1f00015,0x2127002b,0xa5bb48ba}},	//   _häda, إسم_, عيتی_, _flór
  { {0x28980008,0xa5bb016e,0x6aba48bb,0x60c40030}},	//   עדון_, _glór, kstf, áima
  { {0x5454000d,0xe4540139,0x479c004c,0x4ac5000b}},	//   _сврт, _скры, ליגס, _विधव
  { {0x60c400df,0x7e910024,0x682b00b8,0xf1d8000b}},	//   šima, _jāpi, _südl, _डायन
  { {0x6cd20029,0x9f473999,0x6e29476d,0xb6080046}},	//   لقيا, mení_, rkeb, lyší
  { {0xcce40029,0x9f4701b2,0x61fb48bc,0xd164006b}},	//   اسيي, lení_, _haul, _съси
  { {0x68300005,0xbf15012c,0x539a000a,0xb4450033}},	//   _näda, _جواب, ויתו, эмiч
  { {0x9f47002c,0x6f48000a,0xff16000a,0x6a440030}},	//   není_, _אֲנַ, _בקעת_, rőfo
  { {0x29040084,0x91ba0008,0x9f5e008c,0x25a90f81}},	//   íma_, ומרי, _entä_, dbal_
  { {0x69a2000b,0x61fb48bd,0x8c4516cf,0x3e4c005a}},	//   _क्री, _laul, _шеле, věti_
  { {0x23bc0046,0xf1b3000b,0xdb032300,0xf74348be}},	//   hájí_, ुणान, _benå, аеро
  { {0xdb0300f2,0x9f470107,0xe9df0125,0xcad6000a}},	//   _venä, jení_, liún_, _סופת_
  { {0x9f470057,0x44310079,0x39360033,0xe8f70138}},	// [a8c0] dení_, _blz_, _шэкс, _алы_
  { {0x64890091,0xb8f6000b,0xf8b7004f,0x232a00af}},	//   _džio, ां_, _שפיי_, мози_
  { {0x61fb222a,0xfbd4000b,0x201e3c23,0x338500ce}},	//   _baul, _दासम, _roti_, гуїв
  { {0x72290036,0xfb1a0053,0x64890007,0xdb0302de}},	//   нців_, וועמ, _užin, _genå
  { {0x201e48bf,0x260f000b,0xc05a00e2,0x61fb48c0}},	//   _poti_, डारी_, мік_, _daul
  { {0x03a30191,0x493b000a,0x3ff40015,0x6aba2c07}},	//   _виро, וגנו, اكثر, ystf
  { {0xf8370008,0x04430142,0x9f470107,0x7ed30015}},	//   כנסת_, _терн, bení_, لزيا
  { {0x9f4702d5,0x69a2000b,0x3df40004,0xadf403ae}},	//   cení_, _क्ली, узис, упиш
  { {0x9cb40086,0x71660015,0x59b6000b,0x201e1cb6}},	//   دمخت, _شارك, _अज़र, _toti_
  { {0xfa8a0023,0xa1050029,0xe9df002d,0x200c0553}},	//   _mẫu_, _حذفه, giún_, _undi_
  { {0x5b130010,0x61fb003f,0x8037004f,0x6ec50058}},	//   амэт, _yaul, _שנבע_, _متنق
  { {0xf2d300b2,0xb2bb0008,0xda350892,0x61e248c1}},	//   סער_, ומטר, уемы, nfol
  { {0x2e370008,0xcc880092,0x9f450057,0x7a26001a}},	//   _בראש_, _bớt_, _malý_, _nótu
  { {0xc7c40080,0x9f470107,0x68300012,0x61e2344e}},	//   исси, zení_, _päda, hfol
  { {0x6c790053,0x80cc000b,0xf539006f,0xf1b90085}},	//   _אָקס, _समझे, _ťť_, _loša_
  { {0xe6540036,0xb5a40080,0xdb01013f,0x36d40004}},	//   авсь, ируй, nalý, јотр
  { {0x49b80086,0x3ea9016f,0x25a620a9,0x9f470107}},	// [a8d0] _شايد_, ćati_, ñola_, vení_
  { {0x84340036,0xd7f10015,0xfa8a0016,0x25a9030b}},	//   анує, _اكد_, _dẫu_, sbal_
  { {0x9f4701c9,0xa3c4000b,0x78bd003d,0xdb78000a}},	//   tení_, _एयर_, lssv, תְּש
  { {0x2c790003,0x7a26001a,0xd37801fe,0x0000006a}},	//   mède_, _fótu, тчу_,
  { {0x9f47002c,0x7afd0024,0x32010046,0x61fb0f21}},	//   rení_, āsti, ěhy_, _vaul
  { {0x9f4701b2,0x10250058,0x4fc70a10,0x0000006a}},	//   sení_, طّبّ, тсда,
  { {0x2bb6005d,0x61fb48c2,0x9f470107,0xfbb6000b}},	//   _आज़ा, _taul, pení_, _आज़म
  { {0xc694004c,0xd9bf000b,0x7d1d0123,0xd1bb0058}},	//   סאפ_, ्लोट, ässo, _زارا_
  { {0x4bd9008f,0x7a260084,0x3155008f,0xb5fb006f}},	//   ньня_, _mótt, _сваё, _akák
  { {0x6e95006b,0x63b5013b,0x0000006a,0x0000006a}},	//   _бижу, _jezn,   ,
  { {0xcc880016,0x6dd50015,0xeab90174,0x63b50046}},	//   _rớt_, _مقاض, эйн_, _mezn
  { {0xe9df002d,0x0e9a004c,0x9f470144,0xa142003d}},	//   siún_, _טשעל, menà_, _šķid
  { {0x26c500dc,0xfd1000e5,0x4a43006b,0x6a76001a}},	//   álon_, _وجه_, сняв, gáfa
  { {0xa6aa0015,0x7a2609ae,0x08360033,0xdb030f01}},	//   فارق_, _rótu, ухмя, _menú
  { {0xdb010020,0xae17005d,0x1ae501f3,0x96b91923}},	//   nalü, थापन_, _сойм, куту_
  { {0x6721038a,0xb0ce000b,0xe6431bc8,0x95c60015}},	//   älja, हूँग, бесп, طيئه
  { {0x26d1003f,0x7a26001a,0x63b548c3,0xda7b004f}},	// [a8e0] auzo_, _dótt, _bezn, _אנקר
  { {0x6fd2000b,0xb376002b,0xf71a0033,0x41d1000b}},	//   _साइं, هداش, _зімы_, _हाउस
  { {0x7395005e,0x2c790003,0x316d0003,0x0bb6004c}},	//   ршує, cède_, _ayez_, רלעם_
  { {0x3265005e,0x9f470144,0x78a42ecb,0x61e202ad}},	//   атів, denà_, _ktiv, ufol
  { {0x9f47002c,0x61e21c9c,0xae17000b,0x7d1d0012}},	//   rdný_, rfol, थानन_, ässl
  { {0xa87a0053,0xdb0316bc,0x61e248c4,0x644b01f6}},	//   עאַר, _denú, sfol, égit
  { {0xb7db0008,0x9e140036,0x7ee30015,0x682b0012}},	//   תקצי, идкі, مكون, _südk
  { {0xb87b168c,0x12eb000a,0x9ed7006b,0x63b5002a}},	//   otíc, _אַמּ, умът_, _zezn
  { {0xd83f00bd,0x2fd60029,0xffd60015,0x8fa60fbd}},	//   ščih_, _متاح, _مغاد, _базе
  { {0x09bf005d,0x3e570045,0x3e4c0046,0x69c448c5}},	//   ्ल्य, răta_, větu_, _adie
  { {0x78a403af,0x6f930029,0x5f930029,0x2f5648c6}},	//   _ativ, _المض, _المئ, _стас
  { {0xa2cc005d,0xd3570008,0x5e9b000a,0xda670015}},	//   _हिन्, ריטי_, _נבדק, طاجي
  { {0xd90f0086,0x9f470f1b,0x69c40026,0xd5bf003d}},	//   سید_, mená_, _ddie, žāku_
  { {0x3ebd00f2,0x7a26002e,0x9f470227,0x63a90085}},	//   _äytä_, _sótt, lená_, _đeno
  { {0x682b00b8,0xdb9b0008,0x8b9b000a,0xae09000b}},	//   _jüdi, _אסור, _אבות, वाचन_
  { {0x9f47002c,0xadf9005d,0x63b50820,0x2c0c000b}},	//   nená_, ्ययन_, _sezn, ़ाकू_
  { {0xa4d501c6,0xd3a70b1e,0x95c40058,0x2c7901f6}},	// [a8f0] розі, греп, صيله, sède_
  { {0x68ed00b6,0x6e220020,0x69c4002c,0xa4d4042b}},	//   _ipad, _loob, _zdie, софі
  { {0xe2980036,0x64890007,0xf8bf0003,0x63b548c7}},	//   гає_, _užim, lsé_, _vezn
  { {0xa4d50191,0xd13100e5,0xd6e8000a,0x9f470264}},	//   _комі, يما_, _עַתָ, jená_
  { {0x629a0152,0x9f470264,0xf8bf2038,0x55ba000a}},	//   _éton, dená_, nsé_, _שמשו
  { {0x41260080,0x889c0053,0x389c0008,0xade2000b}},	//   рошо_, עבוי, עיונ, क्सन_
  { {0x90280010,0x656f0026,0xe9df002d,0xc7d8000a}},	//   ыцца_, _hych, tiúl_, אווי_
  { {0x68ed46c5,0x9f450144,0x9f4a0052,0x0000006a}},	//   _opad, _saló_, úmál_,
  { {0x6d44006f,0x7e91003d,0x5c5502ed,0x6e2602dc}},	//   _žiar, _rāpu, итоф, ökba
  { {0x3ce5005d,0xda0a0086,0x4423044c,0xa2cc000b}},	//   _कहीं_, چيده_, _joj_, _हिम्
  { {0x9f450014,0xdb0100dc,0x907a0053,0x30840029}},	//   _való_, való, _סטעי, _اللف
  { {0xa2d6014e,0x9f470089,0x68300012,0x7d14001a}},	//   मंत्, cená_, _pädo, ófsí
  { {0x61e9000c,0x672100c0,0x59760033,0xdb0148c8}},	//   _mbel, äljn, рыну, taló
  { {0xc05200b2,0x5d3a0008,0x80cd005d,0x6a9500ce}},	//   ַזן_, _בתנא, _सिने, _криє
  { {0x7c23002d,0xddc9002c,0xbb42135d,0x61e948c9}},	//   _ionr, tieň, _мешк, _obel
  { {0x656f16dc,0x2cbf0046,0x78a402b9,0x7c231e46}},	//   _bych, osud_, _ttiv, _honr
  { {0x656f0026,0x54a50015,0x44231417,0x7c2348ca}},	// [a900] _cych, محلف, _boj_, _konr
  { {0x656f0176,0x04460001,0x9f470227,0xb87b0bb6}},	//   _dych, шезн, zená_, rtíc
  { {0xb87b48cb,0xe73a198b,0x62821de9,0x2bdd29ac}},	//   stíc, _рен_, tmoo, _माना
  { {0x27ed010b,0xcc880092,0xdcf50046,0x30a60033}},	//   đene_, _lớp_, íběh, аркв
  { {0x6fb6003b,0x656f0026,0x9f470264,0x6f080264}},	//   لمشا, _gych, vená_, _srdc
  { {0x2d980089,0xc9530008,0x3ec60a61,0x7d04002d}},	//   ěrem_, חמד_, асиб, _áisi
  { {0x6e2200bd,0x9f47002c,0xb87b0077,0xdc2d0061}},	//   _poob, tená_, ntía, _sığd
  { {0x25a048cc,0xade3008b,0x0000006a,0x0000006a}},	//   ncil_, оцьк,   ,
  { {0x9f47002c,0xadf70029,0x10a30956,0x80a60031}},	//   rená_, شريط_, _митн, _ضمان
  { {0xddc00046,0x7c231aa9,0x682b007c,0x9f470069}},	//   pomů, _conr, _tüdi, sená_
  { {0x29050024,0x6397004c,0x5bb6000b,0xdfcf0040}},	//   ālam_, ידיא_, _आजीव, _زين_
  { {0x6c340086,0xade2000b,0xe919005e,0x26c530aa}},	//   _گفتا, क्शन_, гомі_, álom_
  { {0x984b0063,0x9d1a0015,0xf8bf0003,0xf99f0714}},	//   вява_, _جزاء_, usé_, rcè_
  { {0xad250086,0x2bdd005d,0x656f01b2,0xf8bf2c80}},	//   _درمو, _माया, _rych, rsé_
  { {0xfa560086,0xf8bf48cd,0xbc7b0008,0xe7300029}},	//   _گروگ, ssé_, _שנות, وصف_
  { {0x7a360007,0xa634005e,0x656f002a,0x8f37000a}},	//   kšty, онсі, _pych, באלו_
  { {0xd7e70036,0xadf9005d,0xa3a70018,0xe4d90015}},	// [a910] _кіно, ्यतन_, لحان, طوات_
  { {0x656f0107,0xa3a703ae,0xe8d6004f,0x47351114}},	//   _vych, рјак, _פותר_, _гнос
  { {0xd7dc014e,0x656f005c,0x682b00b8,0xd3710015}},	//   _बातच, _wych, _südw, أها_
  { {0x4423005c,0xed59016f,0x67280123,0x656f48ce}},	//   _woj_, laže_, ädje, _tych
  { {0x4423016f,0x81c80036,0x3ce5000b,0x181a002b}},	//   _toj_, ргів_, _कहें_, _شریک_
  { {0x73c50029,0x764d01d7,0x6a52003d,0xc0c80033}},	//   _ديسم, liay, rāfi, руце_
  { {0xf8380008,0x92f40015,0x57fa004c,0x752d0030}},	//   שנות_, _وأفض, טלװו, lyaz
  { {0x7c2348cf,0x5758000a,0x1758000a,0x9758000a}},	//   _sonr, יבוע_, יסור_, ישוף_
  { {0xed590796,0x1c45005e,0x752d0352,0xf532000a}},	//   kaže_, йним, nyaz, ּ֥ח_
  { {0x1c11005d,0x4ee70036,0x2d9f003e,0x5ba9056d}},	//   ़ाइल_, _відз, scue_, ыком_
  { {0xf989000a,0xdddb0045,0x1b49012e,0x764d02f2}},	//   _נר_, cluş, узни_, kiay
  { {0x8d950029,0x25b90046,0xdb060030,0xe2fa004f}},	//   _الإش, _nesl_, ámáh, נִים
  { {0x6abc002e,0xbca50087,0x5d850015,0x48e3006b}},	//   árfr, _امتي, _الشل, появ
  { {0x7c3a48d0,0xb4cb000b,0xdb0a0b12,0x07a30d7d}},	//   chtr, रूज़_, _befä, зарн
  { {0xf1d8005d,0xfb870010,0xfbb60008,0x89d6005e}},	//   _डालन, _тыдн, _הפצת_, _ліпш
  { {0xc68f0015,0x9f47008c,0xb87b0077,0xe9da0a0b}},	//   ِّف_, menä_, rtía, _ски_
  { {0x14c80086,0xe3b20015,0xca37000a,0xb87b0077}},	// [a920] شهای_, كرا_, _לנקה_, stía
  { {0x8ccf005d,0x9c29000a,0x0555005e,0x3e61002a}},	//   _दिनो, נֵּ֥, іття, róty_
  { {0xdb0a00b8,0xfdf9005d,0xf5290053,0xadf9005d}},	//   _gefä, ्यास_, עץ_, ्यान_
  { {0xd5b90080,0x8717000a,0x91ba0015,0x0269005e}},	//   _всё_, _הקטע_, اطار_, ашій_
  { {0x66040064,0x6e3b0a72,0x51180839,0x9989002a}},	//   mdik, dhub, ролю_, _znał_
  { {0x33d50191,0xdfd000e5,0xdfcf00e6,0xb97b000a}},	//   _міст, ذيب_, فيه_, ננסי
  { {0xe819014e,0x660448d1,0xdb010012,0x6d4f006f}},	//   दाता_, odik, nblä, úcan
  { {0x66040553,0x1d34006b,0x91e309dd,0x6e3b01c2}},	//   ndik, жния, _носе, ghub
  { {0xbd440029,0xed870036,0x6da3009c,0xc19b000a}},	//   تنظي, йськ_, чиња, _תשמי
  { {0x26c500dc,0xf411000a,0xa4fb000a,0x0137000a}},	//   álok_, ֵ֤י_, נליט, _הרמת_
  { {0x6e960029,0x60c2194e,0x7d0b0547,0x9f060058}},	//   _الصا, lsom, _ergs, _دواو
  { {0xcce60086,0xc333039e,0x33770447,0x7c3a48d2}},	//   _هستي, פור_, מעים_, shtr
  { {0x9e65003b,0xdd8f0015,0x63be48d3,0x4d760015}},	//   _بالن, _كوم_, kapn, _اطار
  { {0x60c22254,0xc157000a,0x7afc02de,0xbca4002b}},	//   isom, משכו_, ærts, _همچي
  { {0x63be0213,0xed5906f2,0x8f9b000a,0xc6770015}},	//   dapn, raže_, רילי, مطرب
  { {0x5b57039e,0x78d51092,0xee31000a,0x60c218e4}},	//   _לשון_, _джих, ֵֽן_, ksom
  { {0x5fc8014e,0xe5730029,0x3cb8000a,0x9f5e0003}},	// [a930] रणाल, سطر_, שֶֽׁ, _daté_
  { {0x7bda1a37,0xdb180003,0x7d1d0a84,0x60c21156}},	//   ngtu, _revê, ässi, dsom
  { {0xf2c40015,0x660401d7,0xd37b48d4,0x648948d5}},	//   كْلُ, bdik, уча_, _oživ
  { {0xddc9003d,0x8b07005a,0xdce901ec,0xdb1a48d6}},	//   kleš, _hoří, tceļ, ratè
  { {0xd14b0086,0x60e70036,0x21690054,0x22a10091}},	//   دشان_, сцез, јили_, _dėka_
  { {0x1ef90015,0xb97c004c,0xd009007e,0x9ea91cd9}},	//   لعبة_, ארדז, реке_, авка_
  { {0x629800dc,0x62350080,0x2fd60015,0x6d40003d}},	//   ívot, _деву, زويد_, ezma
  { {0x82370225,0x72370067,0x3cc90054,0x7bda48d7}},	//   _ارسا, _ارسط, алио_, egtu
  { {0x7e690384,0xddc900bd,0x3c190010,0xee360127}},	//   roep, gleš, аўня_, інь_
  { {0x40e8000f,0x9f47008c,0x0ae9056d,0x8c49012f}},	//   _לַעֲ, tenä_, адой_, рпов_
  { {0xcef9002b,0x6d400847,0x7f550015,0xddc90046}},	//   _خفاش_, azma, _بناؤ, aleš
  { {0xa2cc014e,0xc7a90dab,0x7bda02f2,0x7ed4002b}},	//   _हिस्, _יב_, agtu, _رزما
  { {0x3935008f,0xdb0301e2,0x9f4700f2,0x39430010}},	//   пэрс, _henü, senä_, дняг
  { {0xdb1a0014,0x2cad003e,0x60c4002d,0xb87b48d8}},	//   zaté, mped_, áimi, stín
  { {0x2cad003e,0x7d0948d9,0xf7190033,0x63be0123}},	//   lped_, lves, біты_, vapn
  { {0x27ed010b,0x8505005d,0xb5aa0029,0x75d600a2}},	//   đena_, रिंट_, شارك_, تيرا
  { {0x74160029,0x94a90015,0x14262556,0x660448da}},	// [a940] يورا, مطلق_, одам, rdik
  { {0x2aed005d,0xf7720086,0xf202000b,0xc4830180}},	//   _जहाँ_, _ياد_, _रोज़_, длук
  { {0x7c3a004c,0x4c3a004c,0x6a440030,0x660435aa}},	//   סגעז, סגעצ, sőfu, pdik
  { {0xe4da0086,0x27f848db,0x72160015,0xd25900fd}},	//   _پوست_, lern_, غذائ, бці_
  { {0x60c20007,0x7bda0007,0x51830010,0xa183004a}},	//   usom, ygtu, муша, мышл
  { {0x27f80b0f,0x20b90010,0x4ea605c4,0x64160015}},	//   nern_, сыць_, ориа, _بوسط
  { {0xaf030010,0x1ef70015,0x8ff7002b,0x2905003d}},	//   дчык, قعية_, زرور_, ālai_
  { {0x69d6005d,0x60cd0024,0x290000f2,0x27f848dc}},	//   _भागी, šama, _osia_, hern_
  { {0x7d540063,0x5e430015,0x63bc27fc,0xa2d6000b}},	//   явих, بَيْ, _kern, मूर्
  { {0xbc670029,0xe61f002c,0x629c48dd,0x63bc0cbb}},	//   يمين_, _zhôd_, _kuro, _jern
  { {0xda7b0080,0xdb1800dc,0xdb0300b8,0xd47b000a}},	//   иям_, _kevé, _genü, שאיל
  { {0x648906d5,0x7d0900bd,0x63bc0ecc,0x3c3b0152}},	//   _uživ, bves, _lern, _rêve_
  { {0x3204005c,0x27f848de,0x8b070046,0x0d560015}},	//   _mamy_, fern_, _poří, _بخاد
  { {0xeb4a0086,0xb87b002d,0x27f8079c,0xdb1848df}},	//   _پشتو_, rtío, gern_, _levé
  { {0x629c00df,0xba770029,0xdc3b0053,0xf7940010}},	//   _nuro, _واعت, _דעגר, дарэ
  { {0xdb180014,0x8b3b0008,0x26cd016f,0x7f3b000a}},	//   _nevé, _כתוצ, čeo_, בעלו
  { {0x89e80008,0x27f800b8,0x98a2005c,0xdb030896}},	// [a950] _וַתֵ, bern_, tyką_, _fenó
  { {0xf1d8005d,0x69dd0ed4,0xa8480015,0x6d8b000a}},	//   _डाउन, lgse, _وليم_, בָבְ
  { {0x63bc038d,0xdb180014,0x92950010,0x26d835f5}},	//   _dern, _bevé, чаец, curo_
  { {0x7d0944de,0xdddb0046,0xdb080030,0x20190030}},	//   yves, bouř, ladó, _ősi_
  { {0x361a0008,0xddc8005c,0xe3d70015,0x7a7c004c}},	//   _הורד, łośc, _وتسع, בראס
  { {0x629c04ed,0xa0690001,0x63bc48e0,0xdfd10115}},	//   _furo, љака_, _gern, ريع_
  { {0x9f47002c,0x91f70015,0xa49b0144,0xdb080030}},	//   lenú_, _وأرا, _eròt, iadó
  { {0xf1bf0084,0xa75c000a,0x6e920054,0x27f80028}},	//   _þá_, ידור, нију, zern_
  { {0x7d090007,0x69bf000b,0x2cad00da,0x9f47006f}},	//   uves, _वज़ी, uped_, nenú_
  { {0x7d0948e1,0x69dd48e2,0x63a50383,0x9f6b0054}},	//   rves, egse, nchn, _крез_
  { {0x63a5018b,0x4be6002b,0x27f848e3,0xcb693a02}},	//   ichn, سکوپ_, vern_, сане_
  { {0x2cad4220,0x20050f44,0xff7a000a,0xdb010046}},	//   pped_, _hali_, _הטעמ, nclé
  { {0x20051a07,0xb87b0046,0x7c360030,0x4e7a000a}},	//   _kali_, atím, ágró, _פאנצ
  { {0xfbd30086,0x27f800b8,0x9f47002c,0x69dd002e}},	//   _آتش_, uern_, denú_, agse
  { {0xec360008,0x7bc148e4,0x27f80012,0x8c1a000a}},	//   _מאסר_, malu, rern_, _לוסי
  { {0x629a0152,0x27f826af,0x7bc1013c,0xdb030144}},	//   _étoi, sern_, lalu, _fenò
  { {0x4a570008,0x63bc48e5,0x29000049,0x89db000a}},	// [a960] _משקל_, _pern, _usia_, _החפי
  { {0xdb08002d,0x244a0015,0xdb0a016e,0x320448e6}},	//   cadó, حجري_, _refú, _samy_
  { {0x7dd60064,0xe7b70008,0xa79b0008,0x682b0020}},	//   nüsü, _מהיר_, _לשיח, _tüdr
  { {0x11d70029,0xd36f00e5,0xb2260033,0x9f47006f}},	//   كومة_, دهم_, ямел, benú_
  { {0x26c5002c,0x63bc0375,0xe5720031,0x20050d86}},	//   álov_, _tern, _سطح_, _bali_
  { {0x660648e7,0x75320024,0x224d0061,0xb033005e}},	//   _hakk, īdzī, _emek_, нніш
  { {0x644e00b6,0x5f930292,0x660600f2,0xdb180030}},	//   _imbi, ништ, _kakk, _tevé
  { {0x225a0029,0x660648e8,0x20070e2a,0x6721008c}},	//   _الرد_, _jakk, adni_, älji
  { {0x361b0008,0xe62a0092,0x3cf8000b,0xac980015}},	//   מוקד, _độ_, ्टें_, غندا_
  { {0x200500df,0x113b0008,0x64890107,0x442a4173}},	//   _gali_, _התמל, _užit, _job_
  { {0xe9f90036,0xed590796,0x9f47006f,0x442a48e9}},	//   онні_, raža_, zenú_, _mob_
  { {0x0e9b0008,0xb87b002e,0x60c40007,0x1e861292}},	//   _השאל, rtím, šimu, _элем
  { {0x58870802,0x69dd41a5,0x9f5e0144,0xb87b48ea}},	//   зыва, rgse, _matí_, stím
  { {0x27ed016f,0x9f47002c,0x660600f2,0xc6a7004a}},	//   đeno_, venú_, _aakk, зраи
  { {0xdb0848eb,0x86c50015,0x9c450033,0x66061f70}},	//   radó, بيزن, _ўхіл, _bakk
  { {0xa2d3000b,0xdb080125,0x9f47006f,0x7c2a48ec}},	//   _डिब्, sadó, tenú_, _hofr
  { {0x63a548ed,0x6a7d02c1,0x442a0495,0xdb0848ee}},	// [a970] tchn, léfo, _bob_, padó
  { {0xb7d9002b,0x9f4d006f,0x9f47006f,0xe9df0144}},	//   _بودا_, čnúc_, renú_, lgú_
  { {0xd5ed0092,0xc7b200f3,0x63a548ef,0xd6d5004a}},	//   hoả, _שבט_, rchn, _южны
  { {0x63a5018b,0x6606002e,0x7c2a0026,0x7bce005c}},	//   schn, _gakk, _lofr, óbuj
  { {0x3cf8005d,0x25d6004c,0x63a5002a,0x00c80033}},	//   ्टों_, _קושן_, pchn, злік_
  { {0x8cbf000b,0x26c50046,0x60cd18df,0x660648f0}},	//   लीफो, šlou_, šamo, _zakk
  { {0x7d022c17,0xcee80015,0x200548f1,0x200737e6}},	//   _asos, كرين_, _vali_, rdni_
  { {0xbca50087,0xdb1a163c,0xc0ab0015,0x2d99079b}},	//   ومبي, gatí, _هائل_, øse_
  { {0x2bb90029,0xd0d40063,0x4c8505b3,0x2005309b}},	//   يادة_, _потъ, млив, _tali_
  { {0x69cd0026,0xa0c40029,0xfc310029,0xcac9004a}},	//   _adae, _أيلو, ئحة_, огое_
  { {0x60c40007,0x290c003d,0x7d0b002b,0x7bc148f2}},	//   šimt, ādam_, _گزاف_, ralu
  { {0x7bc148f3,0xed4e0086,0x7dd60061,0x8d92002b}},	//   salu, اپی_, rüsü, علیش
  { {0xbd450029,0xee360010,0x69cd0026,0x660648f4}},	//   _تنشي, _інш_, _ddae, _rakk
  { {0x7c2a0026,0x4c9a000a,0xb8f6000b,0x7bc7001a}},	//   _gofr, _ובסו, _हि_, ðjud
  { {0x28d3005d,0x3d03005d,0xe73a00a5,0x660648f5}},	//   _तिथि, _वनडे_, цев_, _pakk
  { {0x442a001c,0xcad6000a,0x98a2002a,0x3aba000a}},	//   _sob_, _חוקת_, zykę_, _ומקנ
  { {0x442a0176,0x15fd014e,0xfe790089,0x09030010}},	// [a980] _pob_, उज़र_, ilů_, _апын
  { {0x6e2b0298,0xdb1a0089,0x2c16000b,0x690b000a}},	//   _logb, zatí, ताएं_, _וּטְ
  { {0x98a20007,0x06860146,0x6606158b,0xfe790046}},	//   vykę_, _огон, _takk, klů_
  { {0x7df9005d,0xda21000b,0xb5da0015,0x222b002b}},	//   ्योग_, यायत_, _ببدء_, يزنی_
  { {0x98a2005c,0x10a30658,0xdb1a0030,0xd0d4009b}},	//   tykę_, вичн, vatí, холъ
  { {0x60c910ca,0x442a01d7,0xe16500c3,0xaffc0033}},	//   _dvem, _uob_, ردني, сокi
  { {0xe80f014e,0xd3720225,0xdb1a48f6,0x98a2002a}},	//   ायता_, _شهر_, tatí, rykę_
  { {0x7c2a168c,0xa63b004c,0x2498007c,0x42260033}},	//   _sofr, ַגיר, _hirm_, _ўдав
  { {0xab5c0048,0xdb1a0f19,0x0000006a,0x0000006a}},	//   daļa, ratí,   ,
  { {0x6fb30029,0xddc9002a,0x7c660015,0xcc870058}},	//   _لمكا, gieł, بابل, ونيه_
  { {0x03d70008,0xa08b0008,0x20570008,0x2025002c}},	//   ווים_, _וְאִ, _קיבל_, úpiť_
  { {0x629a0003,0x6ec50015,0xd7dc000b,0xaae5002b}},	//   _étou, _أتلق, _बाउच, رسپو
  { {0xf8ae0086,0xa92b0033,0xcd36012c,0x6da3153d}},	//   یکی_, ціне_, _تراب, _рича
  { {0x7d7b004f,0x0000006a,0x0000006a,0x0000006a}},	//   _ונדו,   ,   ,
  { {0x764100df,0x7793002b,0x1bf7000a,0x7bdb000a}},	//   ūlym, ضیحا, _חצור_, _וקוו
  { {0x6a84000d,0x2498002d,0xc6900015,0x645e008c}},	//   _илја, _airm_, لِّ_, enpi
  { {0xe80f005d,0x6a76002e,0x29050024,0x44f50033}},	// [a990] ायदा_, gáfu, ālas_, эпас
  { {0xcc78000a,0xdc9b000a,0xd3db0015,0xd37b1ab4}},	//   פְּר, קיבל, تبرا_, оче_
  { {0x60c9016f,0xfe790046,0x648910e7,0x926b0b98}},	//   _svem, ylů_, _džip, орда_
  { {0xdb1801b2,0xddc9002a,0x8ccf000b,0x6721007c}},	//   _neví, zieł, _दिलो, älju
  { {0x249807e9,0x25d6000a,0xf194005e,0x31580015}},	//   _firm_, _אורן_, виць, وجهة_
  { {0x751600b2,0x94ba0008,0xe3d40015,0xe822000b}},	//   _אַלע_, _ממשת, _لتفع, माया_
  { {0x20d50084,0x6fe0000b,0x25a90e19,0x11d70015}},	//   _búið_, _नारं, ocal_, _يترد
  { {0xb87b001c,0xfde60063,0xc332000a,0x1798000a}},	//   luíd, едък_, _גול_, ודול_
  { {0xfd1100c3,0xdb18013f,0x9cb20058,0x6a7d01f6}},	//   اجب_, _deví, هميت, réfl
  { {0xbc620010,0xa4b6000a,0xb87b016e,0xd578000a}},	//   лвык, עלתה_, nuíd, ותחה_
  { {0xab5c0024,0x3871006f,0x2eb40138,0x68f648f7}},	//   taļa, dozr_, _асіс, _spyd
  { {0xa96a0001,0xade90086,0xd9460004,0x65c1016d}},	//   зима_, _رفتم_, ееми, náhľ
  { {0x497a0033,0x64490091,0x9d44002b,0x5dc8004f}},	//   ясоў_, _įein, _لئون, _חֶצְ
  { {0xed56000a,0x68300123,0x7e7b48f8,0x998401d3}},	//   _אבנר_, _räds, llup, ómű_
  { {0xfbd20008,0xb5fb002e,0xcc3a004c,0x3756002b}},	//   _עתה_, _sjáa, _מעסט, رپرس
  { {0xdb0300b8,0xd6270001,0xa49b0251,0x34aa0001}},	//   _benö, носе_, _pròp, звао_
  { {0x056607de,0xddc9002a,0x24980091,0x9f5e016e}},	// [a9a0] хван, mień, _pirm_, _matá_
  { {0xdb1a0014,0x25a90125,0x7e7b48f9,0x69c648fa}},	//   latá, acal_, hlup, lake
  { {0xe29a01d9,0x6735005c,0x5c360053,0x6aab0011}},	//   чае_, cyzj, ערען_, _înfă
  { {0x71a60010,0xe646034e,0x7229005e,0x51860418}},	//   хадз, _чемп, мців_, нула
  { {0xb87b001c,0xe61f0092,0x33d6005e,0xc5f3000a}},	//   buíd, _khôn_, _півт, _גדר_
  { {0x69c648fb,0xd0370036,0x38a60026,0xdb1a00dc}},	//   hake, нзії_, _môr_, hatá
  { {0x4444017e,0x69c6020a,0x141b000a,0xdb1a0030}},	//   mh_, kake, _צולב, katá
  { {0x644b003d,0x7656172e,0x69c648fc,0x44441d80}},	//   īgie, niyy, jake, lh_
  { {0x2d82003c,0xe6110008,0x8066017f,0xdb1a0030}},	//   åke_, בִי_, _зваж, datá
  { {0x444400a7,0xdb0a002e,0x9f47099c,0xf531000a}},	//   nh_, _vefþ, lený_, ׁ֥י_
  { {0x3fc90086,0x444448fd,0x502b000a,0x29020535}},	//   _آگهی_, ih_, _מֵאֱ, ewka_
  { {0xb5fb0014,0xdb1a0014,0xa2d3005d,0x9f47002c}},	//   _aján, gatá, _डिस्, nený_
  { {0xc2130053,0x38a621a8,0x76410091,0xddc90045}},	//   אהר_, _côr_, ūlyk, lneş
  { {0x2c16014e,0x913b0053,0xad1b0008,0x7984005c}},	//   ताओं_, לעכק, _מודר, _dziw
  { {0x4444017e,0xb87b48fe,0x2904002e,0xddc9005c}},	//   dh_, ktív, æmar_, bień
  { {0x4b7b0135,0x387f0152,0x2608005d,0x9f470227}},	//   _מאוו, œur_, ाएगी_, jený_
  { {0xb87b001c,0x9f470227,0xa9680054,0x54990033}},	// [a9b0] tuíd, dený_, _пића_, дваў_
  { {0x44440541,0xf36715fd,0x61e2160a,0x25a9214d}},	//   gh_, нтен, egol, scal_
  { {0x93190029,0xb87b3a96,0x23e2000b,0xa3e2000b}},	//   بقاء_, ruíd, _पारद, _धार_
  { {0xd6d80036,0xc6b6000a,0x444448ff,0xd2d40015}},	//   _ять_, _שהרי_, ah_, اغلب
  { {0x4444017e,0x661d4900,0x660d0064,0xd00900f1}},	//   bh_, _insk, mdak, деле_
  { {0xdb1a00dc,0xdb0a00b8,0xb87b4901,0x660d4902}},	//   zatá, _befü, atív, ldak
  { {0xe822005d,0x9f470057,0x290c003d,0x403201ca}},	//   माता_, bený_, ādai_, рејс
  { {0x171c0053,0x9f474903,0x2902005c,0x660d3e82}},	//   לווע, cený_, ywka_, ndak
  { {0x69c60201,0xfc310015,0xbc650098,0xdb1a0030}},	//   vake, لحد_, квик, vatá
  { {0xe0c70086,0x7e7b002e,0xddc9005c,0xc0970015}},	//   یز_, slup, wień, _أجرت
  { {0xdb1a0014,0xdb0a00b8,0xa3e9005d,0xeb99000d}},	//   tatá, _gefü, _यान_, ќин_
  { {0xc8690008,0x2fc74904,0x3eaa099c,0x98a6239c}},	//   _ון_, lang_, žité_, киме
  { {0xdb1a34af,0x1d091119,0x98f500fd,0x69c622a0}},	//   ratá, _цели_, лярч, rake
  { {0x3ff90053,0x9cd60008,0xdd940010,0x6e290d9c}},	//   ופֿע, _יונה_, _сачы, ljeb
  { {0xdb1a00dc,0x6c56000a,0x6e3b00aa,0x96f90033}},	//   patá, _שיצא_, okub, нэту_
  { {0x09360010,0xadf9005d,0x2fc71636,0x64570144}},	//   _ахоў, ्यटन_, hang_, eixi
  { {0x69c40024,0xe61f0092,0xdb20002e,0x6e3b003f}},	// [a9c0] _ieie, _thôn_, ðtök, ikub
  { {0xb5fb0084,0x65930001,0x2fc70375,0x661d1fc7}},	//   _hjál, рађу, jang_, _ensk
  { {0x2fc70d25,0x9f47002c,0x41e60010,0x3ced01a3}},	//   dang_, tený_, віла, htev_
  { {0x78a40607,0x62894905,0x44444906,0x6e290030}},	//   _kuiv, _cheo, sh_, jjeb
  { {0x9f47002c,0xdb01002d,0x78a40003,0x69c43f4d}},	//   rený_, obló, _juiv, _meie
  { {0xa07308fb,0xb87b001c,0x61e20026,0x9f5c0152}},	//   агіч, stív, sgol, levé_
  { {0x2d801ce1,0xb87b438d,0x9f4719ae,0x6e8a0054}},	//   _šie_, quíe, denó_, мљив_
  { {0x27ed010b,0x69c40048,0xfe6f00e6,0xdb180264}},	//   đeni_, _neie, يدي_, _nevá
  { {0xf653013a,0x867b0008,0x7bc34907,0x2fc720fb}},	//   יצה_, ורקו, _benu, bang_
  { {0x660d4908,0x21750001,0x2fc7013c,0x9f5c0003}},	//   zdak, _суср, cang_, hevé_
  { {0xdb1800dc,0xd437000a,0x0c770015,0x6a7d0f63}},	//   _bevá, דריק_, خصيب_, léfi
  { {0x200c0f4d,0xdb1a0061,0x2f55008b,0x6aa301f9}},	//   _hadi_, hatç, _стус, _dunf
  { {0x200c0913,0x6a7d0936,0x91bb000a,0x5967006b}},	//   _kadi_, néfi, ומכי, тъна
  { {0x200c013c,0xe10b000a,0x7bc34443,0x78a40079}},	//   _jadi_, וּלָ, _genu, _duiv
  { {0xf1bf0264,0x69c40ccb,0x6aa300da,0xdd99006f}},	//   áška_, _feie, _gunf, meňa_
  { {0x27ed0089,0xf6440127,0xb0d2021e,0x7bc81804}},	//   řen_, ахун, _सिंग, ladu
  { {0x62890176,0x2fc71645,0x5fb4000b,0x6aa30012}},	// [a9d0] _rheo, yang_, ुराल, _zunf
  { {0x6289002f,0x2c34000a,0x6a7d0003,0x2e380003}},	//   _sheo, נָּם_, défi, _défi_
  { {0xd37100e6,0x2fc70234,0xc7d6000a,0xe3b00015}},	//   حها_, vang_, _גותי_, ترق_
  { {0x2fc72b20,0x7bc81751,0xa2e4005e,0x661d1f13}},	//   wang_, hadu, роїд, _unsk
  { {0xa3bb0115,0xc692000a,0x403512bd,0x2fc7294a}},	//   _ياسر_, _לאט_, ледс, tang_
  { {0x7bc80005,0xab5c003d,0x2fc70ad4,0xdb0a0324}},	//   jadu, taļl, uang_, _effé
  { {0x64540001,0x2fc72982,0x9ef50021,0xd141002a}},	//   _тврђ, rang_, استش, djął_
  { {0xc33200b4,0x7bc80005,0x60d600df,0x443100dc}},	//   _פון_, eadu, šyma, _hoz_
  { {0x7bc30d25,0x61e92082,0xe61f0016,0x2fc720fb}},	//   _penu, _icel, _nhôm_, pang_
  { {0xb5fb0084,0x69c44909,0x200c003d,0x78a4016e}},	//   _sjál, _seie, _gadi_, _ruiv
  { {0x78a4038d,0x8fa40015,0x2c550046,0x6d490e8c}},	//   _suiv, _ضمنه, vědě_, szea
  { {0xcf560c44,0x7bc3002a,0x7bc8019a,0xd141002a}},	//   _גבעת_, _wenu, aadu, ajął_
  { {0xed59065d,0xc9550010,0x69c42bbc,0xc95602bf}},	//   kaži_, атры, _veie, утны
  { {0x7aec00dc,0x69c400dd,0x6cd20018,0xac160054}},	//   öltö, _weie, _اقوا, _бољу_
  { {0x461a0010,0x69c4007c,0x7bda000a,0xf7860015}},	//   нцаў_, _teie, _טקסו, الأَ
  { {0x3ea504f9,0xdb180bfa,0xf5b5005e,0xd5ed0016}},	//   _mult_, _bevæ, исую, goà
  { {0xdb0a002e,0xddc90024,0x98f60029,0x75d30087}},	// [a9e0] _hefð, pieņ, _إثبا, صيلا
  { {0x61e9490a,0x4806017f,0xe4d70015,0xe577140a}},	//   _acel, _спов, اولت_, узу_
  { {0xb0c6005d,0xddc90263,0x59b8000b,0xab89000a}},	//   रीनग, dlež, _आभार, תָּ֖
  { {0xb87b0057,0x26cc013f,0x200c0160,0xdb1a007f}},	//   stít, ádou_, _sadi_, satç
  { {0x200c0049,0x443109ae,0x7ae1490b,0x2fc5490c}},	//   _padi_, _foz_, hult, _belg_
  { {0x40940029,0x53a302e1,0xddc900bc,0x7ae10514}},	//   جلتر, _гарб, glež, kult
  { {0xab610020,0x3ea5490d,0x7bc84060,0xae15000b}},	//   öüle, _cult_, vadu, _दोहन_
  { {0x2dda0029,0x5ea30015,0x53750054,0x7bc7001a}},	//   ربعة_, حميل, _ђурђ, ðjun
  { {0x21670124,0x5166008f,0x659a00b2,0x25d70008}},	//   _бити_, _сваб, עיִק, אופן_
  { {0x62980089,0x61e90089,0x3ace005c,0x3cf70015}},	//   ůvod, _zcel, tęp_, اعيد_
  { {0x7bc8490e,0x7ae10091,0xd5ed0016,0xc477000a}},	//   radu, gult, hoá, רתיו_
  { {0x6f4b000a,0xaa59005e,0x7b63004a,0xe9810033}},	//   _אֲדַ, тиму_, стье, жамi_
  { {0x3ea50111,0xd7fb006d,0xd9e6000b,0x7bc8490f}},	//   _zult_, нув_, _कारत_, padu
  { {0xb5fb0107,0xb8fd000b,0x7ae12e64,0xddc00046}},	//   _ukáz, _डि_, bult, nomž
  { {0x501b0008,0xdb0a002e,0xf1bf002c,0xb87b0533}},	//   עולו, _gefð, ššia_, guía
  { {0x35b54910,0x0000006a,0x0000006a,0x0000006a}},	//   рбар,   ,   ,
  { {0xa3e9005d,0xf599006b,0x89dc000a,0x2a6901d7}},	// [a9f0] _याद_, тващ_, _נחזי, _ijab_
  { {0xa3d50036,0x61e9151c,0xe4530015,0xc8b40015}},	//   рожч, _scel, حضر_, _اصيب
  { {0xe822005d,0x4431047e,0x289a000a,0xf4841c44}},	//   मारा_, _voz_, _שיתא, сутн
  { {0x27ed016f,0xb6ba0008,0xd5bb005e,0x50b50dfd}},	//   đenu_, _שצרי, _ясо_, аску
  { {0x3ea5002d,0x38d7000a,0x44314911,0x61e90247}},	//   _sult_, אֵ֔ל_, _toz_, _vcel
  { {0xc4f600b2,0x50b80086,0xdb1800f2,0x3ea52bff}},	//   _דזשי_, ادند_, _kevä, _pult_
  { {0x2fc506f5,0xf838000a,0x44ef0061,0x0309000a}},	//   _velg_, רנות_, lü_, _בִּֽ
  { {0x7ae100f2,0xa2a2005d,0x2ca60035,0x97580053}},	//   vult, गदर्, _buod_, טיוו_
  { {0x1c454912,0x9fe70015,0x31550033,0x660f4913}},	//   иним, _مساه, _тваё, _mack
  { {0x1c1f005d,0xdb950036,0x660f0708,0x609b0015}},	//   बाइल_, ишнь, _lack, _أخرج_
  { {0xff530002,0x9f4b008c,0x7a560015,0xcb6905a7}},	//   _اخذ_, älän_, لضحا, тане_
  { {0x7bce0030,0xf8bb0046,0x660f0b14,0xb5fb001a}},	//   óbur, ěžný_, _nack, _dják
  { {0xfe700070,0xe822000b,0x8d87004a,0x7ae14914}},	//   _عدم_, माला_, _сужд, sult
  { {0x5d840029,0xd116000a,0xdb180123,0xe7b6002b}},	//   _الهل, בקשה_, _bevä, شمرد
  { {0x66d93891,0x6c1a000a,0x6008000a,0x96560054}},	//   льтр_, _יֵהו, נִשְ, ађај
  { {0x29560063,0x7aee0227,0x75d60015,0xdb18006f}},	//   _въор, žití, شيطا, _devä
  { {0x290c0024,0xca7b000a,0xda65002b,0x93b60015}},	// [aa00] ādas_, _שנפט, _داوي, لحاض
  { {0x29370053,0x7d190034,0x291e003d,0xb87b0046}},	//   _כאפן_, _mrws, ātad_, stír
  { {0xe7db0008,0x660f0c77,0x23ba000b,0xed594915}},	//   _בקיש, _fack, ेरबद, mažu_
  { {0x11d70015,0x95c70033,0xbb46004c,0xed590085}},	//   لومة_, _клюб_, סנײַ_, lažu_
  { {0x05940074,0x03a60036,0x55bb000a,0x3eb90045}},	//   _دادگ, _виго, _במכו, _ăsta_
  { {0x66040084,0xc0760124,0x764100df,0x3ed40029}},	//   leik, шћењ, ūlyt, مقتر
  { {0xe7ee005d,0x8f340010,0x1c1f000b,0x237a002b}},	//   _जाना_, сейц, बाईल_, _شمرد_
  { {0xddc9005c,0x03670036,0x6d11000b,0x6604008c}},	//   mieś, _тиск_, ़िंग_, neik
  { {0xfe6f0029,0xafe60080,0xed590085,0x61433e28}},	//   بدو_, _возл, kažu_, _дета
  { {0x7d190034,0x6282074e,0x66044916,0xdb1a006f}},	//   _drws, lloo, heik, matú
  { {0x9d540086,0xddc9005c,0x24170008,0x62820171}},	//   شنگت, nieś, בחין_, oloo
  { {0x62510264,0xd2460040,0x62824917,0x7d190034}},	//   sťov, سن_, nloo, _frws
  { {0xd8770015,0x29870033,0xdb180123,0xb4d5000b}},	//   لاسب, рынг, _sevä, _सटे_
  { {0xdd3b0008,0x3cfb000a,0xd7c90067,0x0b5a0015}},	//   _בעדכ, _סלונ, طوره_, _لشعب_
  { {0xf7730018,0x660f297f,0xc6970015,0x62824918}},	//   زاس_, _pack, لشرع, kloo
  { {0x9f5c0089,0xe61f0092,0x6a680064,0xb87b0251}},	//   jeví_, _khôi_, nıfl, dríe
  { {0x58870010,0x660f00c0,0x55070033,0x95c83cc8}},	// [aa10] _вына, _vack, шчва, руса_
  { {0xe7ee005d,0x3cee000b,0x62820547,0x660f1cfd}},	//   _जाया_, _आमने_, eloo, _wack
  { {0x660f0876,0xa2f5054f,0x62d90033,0x6a680061}},	//   _tack, спеч, умеў_, kıfl
  { {0x80db005d,0x1af7000a,0xdcee0046,0xdb0d0030}},	//   _निदे, שמאל_, áděl, ékév
  { {0xe3e90086,0xd14b0086,0xe7ee000b,0xa2d3000b}},	//   _مکان_, خشان_, _जामा_, _डिक्
  { {0x6536000a,0xdb460015,0x32b7002b,0xc0d20015}},	//   _האשף_, _فَ_, _نصرآ, أيوب
  { {0x62820111,0x7bc7002e,0xb87b0125,0x41e700e2}},	//   bloo, ðjum, huío, _віза
  { {0xf99f0251,0x11d40029,0x6f0d002a,0x6282158f}},	//   ndès_, _وتقد, łaco, cloo
  { {0xadf8000b,0xec79018d,0x0000006a,0x0000006a}},	//   ्ज़न_, лпи_,   ,
  { {0x30850029,0x1c450286,0x20850015,0xdab90033}},	//   _الطف, сном, _الطّ, лымі_
  { {0x78b60123,0xcb69011e,0x0000006a,0x0000006a}},	//   _styv, ѓаме_,   ,
  { {0xdef60008,0xd356000a,0x7d190034,0x0000006a}},	//   _למעט_, מיתי_, _trws,
  { {0x660418a6,0x8e740029,0x7e9a004c,0xb87b0030}},	//   veik, _بالض, _עסנו, ttíp
  { {0x97be0033,0x7d7a004f,0x0000006a,0x0000006a}},	//   эрмi, _גננו,   ,
  { {0x660441ed,0x7c2322af,0xa2d3000b,0x0ab50015}},	//   teik, _innr, _डिग्, _احتد
  { {0xdb36000a,0xb87b0030,0xa50a243d,0xdce8002a}},	//   _לנצח_, stíp, леба_, śląz
  { {0xddc9005c,0xd4c60015,0xab5c003d,0x66044919}},	// [aa20] wieś, إغري, vaļi, reik
  { {0x17fa0015,0x7d1d008c,0x66041bbe,0xb0c70033}},	//   _صرخة_, ässy, seik, _спiс
  { {0x5c5a00b2,0xc2240086,0x656f491a,0x6a680061}},	//   נדעק, يکرو, _exch, yıfl
  { {0x6b7a0053,0xd12f0086,0x64900020,0xb87b491b}},	//   ארענ, کمه_, käig, críb
  { {0x3af10092,0xc05a042b,0x867b000a,0x628200ed}},	//   háp_, лік_, _תרכו, rloo
  { {0xdb1a002c,0x62822c0f,0x399b000a,0xd252002b}},	//   ratú, sloo, אינד, _کنر_
  { {0xb5fb002e,0x645e1f7a,0x7d090028,0xa2e30788}},	//   _sjái, mipi, ewes, _норд
  { {0xbe8a004a,0xbcb4006b,0x171b004c,0x0cd80054}},	//   ысле_, обищ, רוקע, адић_
  { {0x2176000d,0xa49b0251,0xfe6f0015,0x68e60123}},	//   _ѓубр, _pròx, عدى_, jukd
  { {0x6c540033,0x645e491c,0x6a680061,0x985d0535}},	//   ікну, nipi, sıfl, _kłąb_
  { {0x7f86003b,0x547b013a,0xa49b0144,0x4dda0015}},	//   _الان, רטיו, _isòt, _موضح_
  { {0xc3332721,0xfce60080,0xe61f0092,0x645e1b51}},	//   לות_, _годо, _thôi_, hipi
  { {0x6da303c4,0x7d960029,0x48e40033,0x645e47b0}},	//   _عموم, _الشؤ, поўв, kipi
  { {0xeaaf0086,0x5c730036,0x64900020,0x4d7b004c}},	//   بعی_, _еліт, näid, _ערגע
  { {0x4ed8000a,0x3ed8000a,0x2bf705bd,0xab2703ae}},	//   יַּנ, יַּא, _המון_, _гоја_
  { {0x7bca09f0,0x645e0026,0xb867002b,0x55b90033}},	//   _hefu, eipi, _گابو, ргаў_
  { {0x69cf491d,0xdb030f24,0x0595002b,0xb87b016e}},	// [aa30] mace, _agnè, زارگ, luím
  { {0x734b017a,0x645e3a81,0x69cf491e,0xf3f30058}},	//   лчев_, gipi, lace, ثأر_
  { {0xe9f90023,0xe7ee005d,0xc2eb0029,0xe975002b}},	//   _giả_, _जाता_, طعام_, _دهکد
  { {0xa2940010,0x7bca0030,0x6aaa491f,0x69cf4920}},	//   пахі, _lefu, _muff, nace
  { {0x69cf4921,0x9fc93aca,0x7bd80085,0x6aaa4922}},	//   iace, агла_, _odvu, _luff
  { {0xdff50127,0x02a74923,0x4104005e,0x442301d7}},	//   іяль, _грам, язів, _unj_
  { {0xd1bb003b,0x80db005d,0x985d002a,0x69cf0de8}},	//   _ماذا_, _निवे, _głąb_, kace
  { {0xa3e9000b,0x69cf1647,0xee3920f1,0xd5b2000a}},	//   _याँ_, jace, рни_, ֽׁי_
  { {0x6aaa00b8,0xa1370086,0x823400e5,0x7bca4924}},	//   _auff, _ارزش, _عرفا, _befu
  { {0xdfd10086,0xac390036,0xab650033,0xf3f2000a}},	//   _آيا_, рчих_, жвол, ֵ֣ת_
  { {0x7d093828,0x69cf4925,0x20074926,0xf989000a}},	//   swes, face, meni_, _סר_
  { {0xf2d20053,0x01f90053,0xdd91002b,0x60c40045}},	//   ועט_, ױפֿל, _قوا_, ţime
  { {0xfe420036,0x7e7b02c6,0xa3e9000b,0x9e080058}},	//   _іншо, moup, _यां_, _دينك_
  { {0xbb450080,0x7bca074c,0x07ba0015,0xc19a000a}},	//   _мелк, _gefu, شهرة_, ישרי
  { {0x2bbf005d,0x07a32103,0x9b950015,0xba760015}},	//   _श्या, дарн, _بلغت, _وابت
  { {0x38af0bcf,0x06860127,0xdb030125,0x69cf4927}},	//   _für_, іган, _ngné, cace
  { {0x75d30029,0x2900003f,0x80db000b,0x88c60015}},	// [aa40] بيقا, _upia_, _निषे, _بتعل
  { {0xe45f002e,0xf8b30008,0x20074928,0x7bc10383}},	//   _svör_, _קשת_, jeni_, nblu
  { {0x27e5005c,0x7e7b0089,0x41aa0254,0xf7720115}},	//   ólne_, koup, авен_, _زاد_
  { {0xdb1a0af5,0xb5fb001a,0x81460040,0xd36f0015}},	//   ratø, _sjáv, ينان, خهم_
  { {0x645e0035,0x73c60015,0x53e60015,0x6b834929}},	//   pipi, _ويحم, _وأسف, _lyng
  { {0xd91b0008,0x66160870,0xdfd000e5,0x76440061}},	//   יונל, ldyk, ريب_, lkiy
  { {0x44f4022d,0x4444492a,0x66160091,0x69cf492b}},	//   lä_, mk_, odyk, yace
  { {0x66160b53,0x479b0053,0xe2a6002e,0xe3570008}},	//   ndyk, סיקס, óðum_, _ושלח_
  { {0x44f4022d,0x463b0053,0x80660080,0x69cf01c9}},	//   nä_, שעפע, _дваж, vace
  { {0x661600f2,0xb4fb01ac,0x0137000a,0xe5410030}},	//   hdyk, ספיי, _ורמת_, égéé
  { {0x6b830176,0x7bca002e,0x4444492c,0xef17000d}},	//   _cyng, _vefu, ik_, _ммф_
  { {0x44381b19,0xb5fb02c1,0xb87b02c1,0x44440020}},	//   _lor_, _imág, dría, hk_
  { {0x44380f75,0x44f4022d,0x4444492d,0x7e600375}},	//   _oor_, jä_, kk_, mimp
  { {0x44440298,0x290b005c,0x44f400f2,0x443810df}},	//   jk_, rwca_, dä_, _nor_
  { {0x6b830026,0x90570008,0x6490007c,0x69cf492e}},	//   _gyng, קבלו_, käib, pace
  { {0xfa340029,0x38af08f5,0xa5bb002d,0x44442903}},	//   _يريد, _tür_, _gnól, ek_
  { {0x7ae802f2,0x53ab0054,0x20070061,0x9f470003}},	// [aa50] ludt, ађег_, yeni_, rgné_
  { {0xf7950010,0x7d02151c,0xc952000a,0x4438492f}},	//   _напэ, _mpos, _נמי_, _cor_
  { {0xf7700029,0x66161ed6,0xd8740015,0xb5fb001a}},	//   _لاَ_, bdyk, _تايب, _sjáu
  { {0x6d4000df,0x44444930,0x645c0061,0x63bb0061}},	//   kyma, ak_, _emri, _şund
  { {0x20070014,0xd49b000d,0x44380223,0x2769002b}},	//   teni_, _врв_, _for_, _خشکی_
  { {0x6d4000df,0x7c3800e8,0x759a0008,0x859a000a}},	//   dyma, _novr, _לסרג, _לשרו
  { {0x7e7b0089,0x2fd60029,0x20074931,0x7d02473d}},	//   toup, سويد_, reni_, _apos
  { {0x28dc014e,0x7bce0084,0x44380064,0x8d550063}},	//   _बिलि, ðbun, _zor_, зточ
  { {0xc2120053,0xb5fb00dc,0xab5c003d,0xd1080067}},	//   _אהן_, _imád, kaļs, _وقفه_
  { {0xbebc0048,0xc1040015,0x2ca30123,0xcf270021}},	//   _brīd, _توكي, öjd_, _وراي
  { {0x3b850010,0x7c384932,0x7d024933,0x3b090965}},	//   ялог, _dovr, _epos, щено_
  { {0x6d400026,0x60c900aa,0xdd1d0045,0x7e6007c8}},	//   byma, _kwem, câşt, cimp
  { {0x444400dd,0x2bbd000b,0x07a60033,0x7ae8007c}},	//   yk_, ोरदा, загн, audt
  { {0x44f400f2,0x29dc0092,0x31560053,0x00f60008}},	//   vä_, ửa_, לירן_, המשך_
  { {0xcb66227a,0x44440e01,0x76440061,0xec120021}},	//   _наше_, vk_, tkiy, _سويد
  { {0x44f40945,0x443800dc,0x25aa0029,0xe7ee000b}},	//   tä_, _sor_, صدري_, _जावा_
  { {0x44383975,0x764401e2,0xe51c000b,0x6e3900da}},	// [aa60] _por_, rkiy, निधि_, _mowb
  { {0x7d1b022d,0xd91b0053,0x6e3900da,0x66164934}},	//   ivus, _פויל, _lowb, sdyk
  { {0x7d1b0005,0x6d400050,0x44384935,0xf626017a}},	//   hvus, zyma, _vor_, _едно
  { {0xd25905d1,0x64a60ded,0xe297124a,0x4444220e}},	//   оці_, _нама, пах_, sk_
  { {0xf7720074,0xf1a90086,0xa4570061,0x39420091}},	//   _زاگ_, زانه_, _çağı_, nyks_
  { {0xf8b30008,0x7d1b0020,0x70540015,0xe424002b}},	//   עשו_, dvus, بنتا, _تکري
  { {0xd6560008,0x7d024936,0xf656000a,0x1eaa0040}},	//   ּיִת_, _spos, ּסִי_, حاتي_
  { {0x171b0008,0x7c384937,0x7ae80123,0x8cc40015}},	//   מוצע, _sovr, vudt, وقعه
  { {0xdd900086,0x644300b8,0xc0e30180,0x7c3805fb}},	//   کوک_, önig, _потк, _povr
  { {0x806301c6,0x7e604890,0x0ab40099,0x6d404938}},	//   _звуж, simp, мбоџ, ryma
  { {0x4fbb0008,0x2912117f,0x7e600509,0x60c90079}},	//   _הצבא, _asya_, pimp, _zwem
  { {0x224600dc,0xdb030034,0x6e390034,0xdb1a2ed9}},	//   nkok_, _egnï, _gowb, matü
  { {0x2e370008,0xdcf70086,0x9d9a0015,0xbd290015}},	//   _מראש_, _فروش_, _انشئ_, _وأهل_
  { {0x8cdb000a,0xb905000b,0xfc64002b,0x9ceb000a}},	//   _פחות, _पट_, _تخصی, _הַה֖
  { {0xabfb0447,0xf1cc000b,0x1bfb000a,0x22460030}},	//   _ההור, ारान, _הלוב, kkok_
  { {0xf8bf0152,0x9f5e01d3,0x7bc70052,0x0000006a}},	//   ppé_, _ható_, ðjuv,
  { {0xb5fb002e,0x9f5c008c,0x6a140015,0x44f50033}},	// [aa70] _sjás, levä_, _سبير, ьпас
  { {0x2349002b,0x6f0d002a,0xdb1a0061,0xe61f0034}},	//   يسای_, łaci, katü, _chôr_
  { {0x64451521,0x3a290134,0x2ab90053,0x44270064}},	//   rkhi, _knap_, ַמװא, ın_
  { {0xdb1a4939,0xd370002b,0x93940015,0x228e006f}},	//   lató, دهٔ_, رجلا, týka_
  { {0xb5fb0084,0xe1f00225,0xe0d8005e,0xb9c8004c}},	//   _fjár, اسم_, зві_, פּאַ_
  { {0xc9180008,0xe7bf005d,0xb97c0053,0x5f050010}},	//   פחות_, ्रिप, זנדי, дзка
  { {0xae1e000b,0xd00e0015,0x23650123,0xb87b0125}},	//   _मोहन_, شلي_, _älj_, hrío
  { {0x7d1b0020,0xdb1a06e7,0x6d25030c,0x3ea60045}},	//   tvus, ható, ддиз, _ciot_
  { {0xe7bf005d,0xdb1a002a,0x7bc5007c,0xd7bf000b}},	//   ्राप, kató, _õhuk, ्राच
  { {0x39420007,0xc1040087,0xac960015,0x7d1b007c}},	//   vyks_, _سومي, ونيا_, rvus
  { {0x7d1b0e95,0x93b6000a,0x28d0000b,0x1df90033}},	//   svus, ולתו_, तीनि, _межы_
  { {0x6e890015,0xb87b0125,0xff7a000a,0x7ed40058}},	//   _بنصف_, frío, _וטעמ, _أزلا
  { {0xdb0a0c77,0xb87b002d,0x8e5600a3,0x71d6000a}},	//   _affä, grío, _קינג_, וורד_
  { {0xdb1a493a,0x6b650a3f,0x6d9a004f,0x0000006a}},	//   gató, _окла, _ובנפ,
  { {0xbbd6000a,0xd7f90033,0x27e5002a,0x224d007c}},	//   _חוצץ_, чуў_, ólna_, _olek_
  { {0xb87b002f,0x2ca70a54,0x3eb800dc,0xe96a006b}},	//   brío, _hind_, _érte_, _майл_
  { {0xb87b002d,0x2ca70b20,0x33f601c5,0x1be1000b}},	// [aa80] crío, _kind_, дчес, _खयाल_
  { {0xdb1a493b,0x940600c3,0x22a80061,0xdb18005a}},	//   matò, ظواه, _aşka_, _levý
  { {0x38b427a9,0xeb930008,0xc7b30008,0x65c60c1c}},	//   _här_, תָּ_, _בבת_, _обна
  { {0x38b40123,0xdb030125,0xaf910033,0xdb1801c0}},	//   _kär_, _ngní, _явiл, _nevý
  { {0x3ea60c12,0x3969000a,0x4a9b000a,0x3cf9000b}},	//   _riot_, ּבוּ_, קינג, ्बों_
  { {0xceba0001,0x46d2005d,0xd0100015,0x38b4493c}},	//   ољи_, _तबाह, الث_, _mär_
  { {0x7ed30086,0x38b400c0,0xaa86016d,0xe3b7493d}},	//   نزيا, _lär_, _zmýš, _цбс_
  { {0x9d140818,0xbe970058,0xdb1a007f,0x0000006a}},	//   едич, وضيا_, ratü,
  { {0x38b427a9,0x21670036,0x420700fd,0xb87b00bf}},	//   _när_, _жити_, _інфо_, rtíz
  { {0x3a292529,0x113b000a,0x9f5c008c,0x9b580004}},	//   _snap_, _ותמל, tevä_, зиот_
  { {0xf4130008,0x60c200f2,0x9e3c0107,0x05ce000b}},	//   דפת_, lpom, _buďt, ़राब
  { {0xb87b002d,0x60d60007,0x2ca70159,0x38b40c77}},	//   trío, šymu, _eind_, _bär_
  { {0xdb1a493e,0xfe9b0008,0x2ca70838,0x58870892}},	//   tató, _ויאמ, _find_, дыва
  { {0x38b401d1,0x9c570029,0x3c440015,0x0000006a}},	//   _där_, _يجوز_, _سَعِ,
  { {0x442d0092,0xe80e005d,0xaa860046,0xdb1a493f}},	//   _đe_, ाज़ा_, _smýš, rató
  { {0xcb070086,0x5694071f,0xe4c7004a,0xb5fb001a}},	//   _آيين_, васт, дёжн, _smáb
  { {0xc7c70001,0x3af800dc,0x60c200bd,0x74f84940}},	// [aa90] _осни, lép_, jpom, метр_
  { {0xe8d80008,0x69db002e,0xad1b000a,0x60c200bc}},	//   _חוזר_, ðuef, חומר, dpom
  { {0x224d1786,0x28cb000b,0xdb180030,0x7c25001a}},	//   _plek_, ़ीरि, _nevü, _óhre
  { {0xeb910053,0xd6d8005e,0x979a000a,0x644e4941}},	//   אָד_, _ють_, _משתק, _elbi
  { {0xc0e50036,0x3af80092,0x3858002b,0x71270040}},	//   холк, hép_, _رشید_, برال
  { {0x41740029,0x3af800dc,0x64900604,0x3f150004}},	//   خامس, kép_, läin, еќит
  { {0x9f500084,0x670f000b,0x60c2174f,0x80db0065}},	//   ðaðu_, ाबिक_, apom, _निके
  { {0x2ca74942,0x7c2a018b,0x43940802,0x6490008c}},	//   _sind_, _anfr, _расс, näin
  { {0x6e920015,0x9982002a,0x660d002a,0x2ca74943}},	//   دليا, zekł_, ieak, _pind_
  { {0xfc31003b,0x628b0230,0x6490008c,0xa0c40040}},	//   احة_, llgo, häin, _شيمو
  { {0x2ca7020a,0x539a0008,0x3af800dc,0x7f550015}},	//   _vind_, ּירו, gép_, _ثناؤ
  { {0xee2e008f,0xfbbf000b,0x35d3000b,0xdb1a0144}},	//   _ён_, _श्रम, तरफ़, tatò
  { {0xed4e4944,0xadd60008,0x660d4945,0x88d60033}},	//   _со_, _נוסח_, deak, эўні
  { {0x26de016f,0xccf2000a,0xdb1a0144,0x5d3a000a}},	//   štom_, _עכו_, ratò, _מתנא
  { {0x8696000d,0x28dc000b,0x38b40012,0x96960c35}},	//   ејач, _बिकि, _wär_, ераш
  { {0x60c2002a,0xcd030046,0x660d01d0,0x0000006a}},	//   ypom, aměť_, geak,
  { {0x999e0007,0x442a4946,0xabf9000a,0xa507249a}},	// [aaa0] ėtų_, _pnb_, ּהֲר, нета_
  { {0x78fb013a,0x3957000f,0x2957000a,0x458305c0}},	//   _צפיו, _נשים_, _נסיך_, угув
  { {0xb8f3021e,0x47f7000a,0x77f7004f,0x23760058}},	//   ही_, _אציל_, _אמיד_, رائح
  { {0x23770086,0x78690007,0xb6bb000a,0x60c20085}},	//   رمند_, ržve, _מצטי, tpom
  { {0x7d1c0024,0x3af800dc,0xc693000a,0x442a01c2}},	//   ārsk, zép_, _תאר_, _tnb_
  { {0x60c204ed,0xf99300f3,0xd8d7039e,0x3cf3000b}},	//   rpom, ארד_, גוסט_, ंढने_
  { {0xfae70015,0x865a000a,0x6254002a,0x91e60719}},	//   _حث_, ּדִי, eżoś, _пове
  { {0x9df7006b,0x7f4700c3,0x063b000a,0xb87b3057}},	//   енът_, عليق_, ִׂימ, quív
  { {0x6ecc000b,0x28dc29ac,0x8d760015,0x20c90015}},	//   _सबकु, _बिगि, عاعا, _يبكي_
  { {0xf4f700b2,0x46e1005d,0x8fa6194a,0xb87b006f}},	//   עזיש_, _फिलह, _зазе, trím
  { {0x1c0f000b,0x9077000a,0x93fb000a,0x7afa0030}},	//   ़ज़ल_, _טעמא_, הליי, uttt
  { {0x3af80030,0x200e0061,0x0000006a,0x0000006a}},	//   rép_, lefi_,   ,
  { {0x6490008c,0x8c460588,0xa30d0065,0x0000006a}},	//   väin, _педе, _सन्ज_,
  { {0xdd8f0067,0xb87b0077,0x7c2a4947,0x0d17004f}},	//   _اوه_, prím, _unfr, _נקוט_
  { {0x8c1b000a,0xbc1b000a,0x45d54948,0x3ea9006f}},	//   _זווי, _מוגש, ковс, ňate_
  { {0xbb77000a,0xc6900015,0x65950033,0x0000006a}},	//   _רעהו_, مِّ_, вабу,
  { {0x649000f2,0xdb20002e,0xda7c000a,0xca7c000a}},	// [aab0] räin, ðtæk, _מנהר, _מנהט
  { {0xd1310086,0x649000f2,0x14190029,0x660d007c}},	//   یما_, säin, بيئة_, seak
  { {0x28b7005d,0xf6990e88,0xd37100e6,0x200e0064}},	//   _इंडि, _овој_, جها_, defi_
  { {0x7bc5007c,0x1fbb000b,0x7ae80030,0x0000006a}},	//   _õhuv, ॉर्ड, irdt,
  { {0x25d6000a,0xd4b80033,0x68fd4949,0x0000006a}},	//   _שושן_, _пляц_, ntsd,
  { {0xb1440010,0x212a002b,0x68fd01f1,0x61420bc0}},	//   ыніл, بيهی_, itsd, реша
  { {0x90280033,0x6474056d,0x1394004a,0x43940302}},	//   эцца_, _сгру, _бирю, _барс
  { {0xa2950010,0xdb030125,0xcf2400c3,0x4ada000b}},	//   _рабі, _ngná, اروي, _भिजव
  { {0x60db003f,0xc015006b,0xb87b0077,0xe628000a}},	//   _uvum, _имащ, rríj, ת֗וֹ_
  { {0x26de00dc,0x1c45006d,0x320f0046,0xad9d002a}},	//   átok_, тном, legy_, zeźw
  { {0x9f040002,0xb87b006f,0x3df50004,0x0000006a}},	//   _مولو, príj, _азес,
  { {0x3f640054,0xa96a0300,0x9f68000a,0xb87b006f}},	//   _стуб, дима_, _אֳנִ, brík
  { {0x2d8200dc,0x68fd02de,0x7ae808cf,0x0000006a}},	//   üket_, gtsd, ardt,
  { {0xed560124,0x66e60083,0xfd560008,0x7d56004c}},	//   _још_, кога, _בשני_, _בינד_
  { {0x17790146,0x7b67005e,0x8cd5000b,0x461a0033}},	//   есть_, _ятде, _मौतो, мцаў_
  { {0xe5f30011,0x60280024,0xceb200a3,0xa898003d}},	//   văţă, _zīmē, שין_, _šķēr
  { {0x46a30010,0xb4aa0033,0x2a790030,0x628200aa}},	// [aac0] ратв, дказ_, érbe_, vooo
  { {0xd7ca0086,0xf7720015,0x2ed1000b,0xa494002b}},	//   _توده_, _ناج_, _सबूत, ایست
  { {0x3e7a003d,0x0000006a,0x0000006a,0x0000006a}},	//   līte_,   ,   ,
  { {0xc4c60015,0xc6b7000a,0xbebc003d,0xb87b00e1}},	//   _لتسو, _שהכי_, _brīn, suít
  { {0x2444002e,0x6490008c,0xf8bf0030,0x60dc003d}},	//   _sömu_, läim, rvég_, _ārms
  { {0x321d0026,0xdcf50089,0xb87b016e,0xdb1a078a}},	//   adwy_, ůběh, luír, matö
  { {0xe8e00023,0xc7b30008,0x200e06ee,0x4375005e}},	//   _ước_, סבה_, refi_, _бутт
  { {0xf7730008,0x1317000a,0xb87b494a,0x877b0643}},	//   יקו_, _בחלל_, trík, ואצי
  { {0x5ea30015,0xdb1a494b,0xbbea002b,0x3cd30138}},	//   جميل, natö, وردم_, ажыс
  { {0xb87b002e,0xcf260015,0xc4d3000a,0x515b000a}},	//   rrík, _لرصي, סגת_, _חכמו
  { {0x3d17000b,0xdb1a007c,0x6fb30067,0xb87b001a}},	//   _बैठे_, hatö, _ضمنا, srík
  { {0xb87b002c,0x28b7000b,0xd337000a,0x4d4a012e}},	//   prík, _इंदि, דרטה_, _опен_
  { {0x1e57000a,0xdb1a007c,0x8e6b000a,0xc213004f}},	//   _בשאר_, jatö, _קֳבֵ, בהר_
  { {0xdddb0061,0x68fd494c,0x98a0005a,0x6f1c01d3}},	//   onuş, rtsd, _frič_, _árcs
  { {0x44d00050,0x386d010b,0x6490008c,0xd7950015}},	//   eń_, đer_, räil, الأخ
  { {0x04c90015,0xa5bb0125,0x13cb000b,0xdb1a001a}},	//   فوري_, _nnót, िर्भ, fatö
  { {0x35b423e3,0x6490008c,0x9a6800c3,0xa9fa000a}},	// [aad0] рбур, päil, _جميل_, _אִית
  { {0x7bc50020,0x54540484,0xd78b0015,0x5335024f}},	//   _õhut, авут, _يخدم_, лезт
  { {0x12b40029,0x6aad003f,0x320f494d,0xc7b2000a}},	//   لإنج, _kiaf, tegy_, _לבי_
  { {0xe45f00c0,0xd6e8000a,0xddc90045,0x4155018d}},	//   _stöd_, _בַשָ, ineţ, лвес
  { {0x91050139,0x4a5c000a,0xc7b80085,0xd0090004}},	//   упле, ודאו, žđe_, ееле_
  { {0xc0c80033,0x708401f3,0x661d1859,0xb4fa004f}},	//   туце_, агіз, _hask, _אפשי
  { {0x661d3204,0x6490007c,0xaed202d9,0x02a72fff}},	//   _kask, käij, бојш, _арам
  { {0x765800df,0xa5bb002d,0x661d1332,0xe8e00016}},	//   _įvyk, _gnót, _jask, âịn_
  { {0x798d0375,0x661d0a3a,0x4c850e3f,0xdbcd0077}},	//   _nyaw, _mask, ллив, _añád
  { {0x661d0a5e,0x57bf000b,0xec76056d,0x98a20073}},	//   _lask, ्रोह, лпы_, vykį_
  { {0x44fd0092,0xad24002b,0x5694004a,0x1ef80058}},	//   hì_, هریو, ва́т, _لعنة_
  { {0xceb2013a,0x63bb0064,0x1cb90029,0xa5bb002a}},	//   _היא_, _şunl, _كاتب_, _mnós
  { {0x82760053,0xfce50361,0x1d09006b,0x6aad494e}},	//   רערע_, _соло, _чели_, _diaf
  { {0x7e690007,0x6e3b116e,0x99d6002b,0x44fd02b9}},	//   liep, ljub, ختگا, dì_
  { {0x28750010,0x26de01b2,0x6aad002d,0x661d1ccd}},	//   рыяр, éto_, _fiaf, _bask
  { {0xdb1a494f,0x96550054,0x78690091,0x7e6917f4}},	//   tatö, ађуј, ržva, niep
  { {0x7bc50020,0xda650067,0x7996002a,0x661d0085}},	// [aae0] _õhus, _خاوي, _uzyw, _dask
  { {0xdb1a4950,0xb8f8005d,0x69d60064,0xf8bf0152}},	//   ratö, ाठ_, _heye, uvée_
  { {0x37750080,0xf8bf0152,0x91d0000b,0x11da0015}},	//   _выяс, rvée_, दरलै, فوضة_
  { {0xdb1a1ca2,0xe61200c3,0x661d229c,0x44fd01e0}},	//   patö, _اشد_, _gask, bì_
  { {0xf7720086,0x91e34951,0xb87b1ecf,0x7e690975}},	//   _خاک_, соче, bsíd, diep
  { {0x69d602c1,0x61430001,0xb97b004c,0xdfcf0015}},	//   _leye, сеља, ענסי, كيه_
  { {0x752400dc,0xe296000d,0xe51c005d,0x25f8000b}},	//   lviz, _браќ, निकि_, एलपी_
  { {0xe804000b,0x6490007c,0xf1b906c0,0x6d1f0065}},	//   श्ता_, käik, _paše_, बिंग_
  { {0xacb40001,0xe611000a,0xad260015,0x5637004c}},	//   јбољ, חִי_, اربو, ראפע_
  { {0x06f6000b,0xf1b94952,0x6fb6002b,0xa0a6067a}},	//   ुझाव_, _vaše_, _صمصا, _сазд
  { {0x04370053,0xeee7002b,0xeef50033,0x798d01c2}},	//   אטיש_, _مغنی, _вячэ, _syaw
  { {0xc333013a,0x201e4953,0xed5a006b,0x75244954}},	//   צור_, _hati_, _пое_, kviz
  { {0x201e000c,0x9a8404ab,0x661d4955,0xc213000a}},	//   _kati_, суэл, _rask, זהר_
  { {0x661d0048,0x201e0375,0x7afd0045,0xddc8002a}},	//   _sask, _jati_, ăstr, łońc
  { {0x7bda4956,0x661d4957,0xaae60015,0xf093004c}},	//   matu, _pask, _إستو, מנש_
  { {0xdb1800b8,0x201e4958,0x7bc5007c,0x6ac30015}},	//   _bevö, _lati_, _õhur, _اقيم
  { {0xdddb0089,0x752400dc,0xf5340004,0xb3eb0040}},	// [aaf0] nouš, gviz, бетќ, فعال_
  { {0x7d1d0134,0x6604101e,0x36d5227a,0x7bda3b10}},	//   æssi, afik, _коор, natu
  { {0x56950036,0xd5b10029,0xc2c400a2,0x67ba000a}},	//   _вант, _وفد_, ميلي, _במתק
  { {0x7bda1091,0xdddb0089,0x1af70053,0xeab10c44}},	//   hatu, kouš, רמאל_, קֹב_
  { {0x26de002c,0xb604002c,0x7bda4959,0xf8b5000b}},	//   átov_, íšet, katu, ंदिय
  { {0xd0091179,0xd2d70021,0x6d5b0061,0x648b0781}},	//   теке_, _مغرب, vzua, güit
  { {0x7e690111,0x201e495a,0x7bda495b,0xe454055f}},	//   tiep, _dati_, datu, _укры
  { {0xa0c50074,0xa267010f,0xfe45000d,0xddc2005c}},	//   _نيرو, _съгл, рнио, _iloś
  { {0xee3604ab,0x62060030,0x44210125,0x69bc000b}},	//   рны_, érlő, odh_, _एलबी
  { {0xeb10005d,0x40870080,0x7bda495c,0xd5ed0016}},	//   ़बूत_, _субб, gatu, hnà
  { {0x4421017e,0x66040050,0xceeb0086,0xbf150086}},	//   idh_, yfik, _سران_, _خواب
  { {0x8f44004a,0x69260088,0x7bda0601,0x0b4201f3}},	//   _ухуд, амма, aatu, інян
  { {0x7bda0005,0x8e8400a2,0x4431002a,0x0dc8006b}},	//   batu, _النه, _onz_, _сухи_
  { {0x6c790053,0x7d1c0024,0x8d5a000a,0x7bda2342}},	//   _שאַפ, ārst, _בכני, catu
  { {0x76a60029,0x45d607d5,0xbc380015,0x3e7a003d}},	//   لحرك, ицат, _حسنا_, līta_
  { {0x6604003f,0xc4c60015,0x8f88000a,0x75240030}},	//   ufik, لتطو, רְשֵ, tviz
  { {0x3e7a0024,0x66040375,0x44664085,0xb4661ab5}},	// [ab00] nīta_, rfik, авав, акал
  { {0x752402d7,0xb5a90029,0x3eaf0f55,0xe4573028}},	//   rviz, طاقك_, _ligt_, ажу_
  { {0x3a200780,0xa6ca0029,0xdddb0046,0x201e495d}},	//   _kaip_, _جوجل_, dluž, _rati_
  { {0x4421002f,0x290200f2,0x201e016f,0x7bda00dc}},	//   adh_, otka_, _sati_, zatu
  { {0xb87b001c,0x7bda058a,0xaa87001a,0x201e495e}},	//   rrív, yatu, _hlýð, _pati_
  { {0x3e7a0048,0x7ee60080,0xa3d7000b,0x26de0057}},	//   dīta_, ацие, सरण_, štou_
  { {0x7bda495f,0x5439000a,0xd4671092,0xa2e307c9}},	//   vatu, _עֲשׂ, _тире_, _морд
  { {0x7bda0ef3,0x9588002a,0x61fb0125,0xddc90091}},	//   watu, aląż, _gcul, tneš
  { {0x7bda4960,0xdd970080,0x5e430015,0xf657000a}},	//   tatu, ишь_, تَيْ, יסקי_
  { {0xe5710008,0x70fb000a,0x9c380004,0xb87b01c0}},	//   לַי_, _בהמח, упот_, isíc
  { {0xfee90029,0xb5fb002e,0x93b7000a,0xee3a006b}},	//   _معنى_, _smám, יליו_, _инж_
  { {0xdddb0089,0x7bda4961,0xaa670190,0x3ced2e1f}},	//   pouš, satu, рток, brev_
  { {0x7bda4962,0xe8550015,0xe9440a3e,0x3e7a01ec}},	//   patu, منحد, охро, cīta_
  { {0x27ed018b,0x5887008f,0xac930010,0xed4f0086}},	//   ßen_, рыма, _даіш, _تپه_
  { {0x80d8000b,0x3ea40012,0x29024963,0x6443008c}},	//   _नौसे, ommt_, atka_, önim
  { {0xe6540191,0x27ed0064,0x95c40015,0x9f5c0077}},	//   овсь, şen_, قيفه, levó_
  { {0x26c50007,0xf599006b,0x3ea40012,0x69dd4964}},	// [ab10] ūlo_, уващ_, immt_, mase
  { {0x69dd4965,0x84340036,0xd91c000a,0x57f502c4}},	//   lase, онує, _יוחל, _упот
  { {0xbebc0024,0xa6ab0029,0x94a80ea6,0x26de00dc}},	//   _drīk, _لاحق_, ртта_, átot_
  { {0x69dd3223,0xe1d9005e,0x7bd801f6,0x50b50138}},	//   nase, удді_, _levu, бску
  { {0xe4a7000d,0xe4e40210,0xd1090015,0xf1cc000b}},	//   _врво, _мірн, اقته_, ारजन
  { {0x32d90086,0x69dd4966,0xd0110015,0xe2d9002b}},	//   _مدرک_, hase, سلع_, _مارچ_
  { {0x2a690020,0xc7aa000a,0x69dd4967,0xa2950138}},	//   _omab_, ְׁפָ, kase, _гаві
  { {0x3e7a0024,0x27780447,0xdddb37e6,0xd5b2000a}},	//   tīta_, יגון_, služ, ּׁי_
  { {0x41550010,0xfd110015,0x4bd90418,0x69dd4968}},	//   _увас, سجة_, льня_, dase
  { {0x2d910024,0xe588000a,0x3e7a003d,0x69dd4969}},	//   āze_, יָתָ, rīta_, ease
  { {0x5f950029,0x6f950029,0x3b090001,0x3e7a0024}},	//   _الائ, _الاض, ћемо_, sīta_
  { {0x69dd496a,0x61f90026,0x6f7a000a,0x7bce001a}},	//   gase, ngwl, _גְדו, ðbur
  { {0x31790053,0x7e7e00dc,0x53a7005d,0xa3d7021e}},	//   ראָד, éppe, केतश, सरा_
  { {0x29024566,0x7bd808cf,0x9c840058,0x2bcb00af}},	//   rtka_, _gevu, _وشوه, _рудо_
  { {0x3a2000df,0x99f602a3,0x29022ed1,0xfaa6105a}},	//   _taip_, _ляпі, stka_, _лако
  { {0x69c10089,0x7bc106a8,0xaac4006e,0x69dd496b}},	//   ělec, lclu, _بتون, case
  { {0x291e0024,0x3ae30064,0x93b60015,0x13b60021}},	// [ab20] ātas_, lıp_, محاض, مصاح
  { {0xb3e90115,0x2eee0034,0xdceb0091,0x7bc1496c}},	//   لعمل_, yrff_, _lygį, nclu
  { {0x68e40134,0x3ae30064,0x2c09000b,0x8afc002a}},	//   _hvid, nıp_, ़्यू_, częd
  { {0x90e60029,0x2007002e,0x599a000a,0x3265005e}},	//   مستن, efni_, ְשַׁ, отів
  { {0xa225002b,0x7bc30034,0xaffc0138,0xb87b016d}},	//   ترله, _ofnu, волi, prít
  { {0x69dd17eb,0x34930033,0x3ae30061,0xf1b9496d}},	//   zase, _наўр, kıp_, _vaša_
  { {0x764600df,0x69dd0064,0x2bdb000b,0xdf0a004a}},	//   _koky, yase, _मज़ा, уэлл_
  { {0x0377000a,0x20da002b,0x5d54006b,0x1ed70021}},	//   _התלת_, _مورخ_, жкит, حبوب_
  { {0x764600df,0xb5fb002e,0x69dd496e,0xdd900015}},	//   _moky, _smák, vase, بوة_
  { {0x4096003b,0x69c40e18,0xa157000a,0x2f01002a}},	//   _الطر, _afie, _הבמה_, bóg_
  { {0xc43b000a,0xfbaa004a,0xa9290091,0x6a150fa4}},	//   אתיי, ытий_, _mažų, омну
  { {0x5f37000a,0x7bc30052,0x0000006a,0x0000006a}},	//   _לטבע_, _efnu,   ,
  { {0xd90f0074,0x69dd0390,0x3e7a003d,0xd877002b}},	//   رید_, rase, līto_, ماسب
  { {0x69dd0c8d,0x3cfb000a,0x9f450125,0x68e4496f}},	//   sase, _עלונ, _gcló_, _dvid
  { {0xf7730002,0x7ac613f1,0x68e41470,0x3e7a003d}},	//   ساس_, _усле, _evid, nīto_
  { {0x8afc0050,0x6f4b000a,0xda7b006b,0x0000006a}},	//   rzęd, אֲמַ, _щял_,
  { {0x95c83a0e,0x6e2200cb,0x26de4970,0x286b00af}},	// [ab30] суса_, _maob, átor_, _брно_
  { {0xa3a70180,0xa3940046,0xe4150033,0xbd9b004f}},	//   бјек, _důžé_, юдзь, רסמת
  { {0xb867002b,0xfa6b000a,0x69c40034,0x68e401c0}},	//   _ناگو, ְכְּ, _yfie, _zvid
  { {0xe1f00029,0x3e7a0024,0x8afb0053,0xb87b002c}},	//   فسه_, dīto_, רלאז, prís
  { {0x3ae30061,0x7bc10079,0x83d50015,0xa0c40058}},	//   zıp_, yclu, _ويحص, كينو
  { {0x3ae30064,0x7ff50087,0xdb460015,0xd8dc0643}},	//   yıp_, زستا, _قَ_, נקור
  { {0xcee80021,0x57fc015b,0x8fa20658,0x4fa20054}},	//   مرين_, אלוו, маше, мишв
  { {0x1758000a,0x24890091,0x2f014971,0x5e4901b7}},	//   מסור_, žimą_, róg_, рпим_
  { {0x4423018c,0x6447010b,0x628b1286,0x7bc131aa}},	//   _kaj_, _koji, mogo, tclu
  { {0x3d09005d,0x3ae30064,0x31780015,0x628b4972}},	//   _वहीं_, tıp_, _احفظ_, logo
  { {0x649000f2,0x68e40dba,0x229c4973,0x64473e36}},	//   päiv, _svid, líka_, _moji
  { {0xc9aa226a,0xbc39002b,0x7bc14974,0x3ae30061}},	//   ивне_, اسکا_, sclu, rıp_
  { {0xec6e0063,0xad27002b,0x229c4975,0xe8f74976}},	//   _жп_, _دراو, níka_, оля_
  { {0x4423018c,0x64900020,0x6ca70063,0x5d7a004c}},	//   _naj_, näit, _уреж, _דאנק
  { {0xf1b900bd,0x3b060036,0x661600f2,0x61e94977}},	//   _našo_, _дещо_, teyk, _odel
  { {0x68e400cb,0xc7a3012e,0x7c232511,0x61e94978}},	//   _tvid, фиск, _hanr, _ndel
  { {0x64900020,0x68e40264,0x628b10bd,0xfa36002b}},	// [ab40] käit, _uvid, dogo, _هرکد
  { {0x04960010,0xf4960010,0x442300d9,0x61e94979}},	//   іраў, іраю, _caj_, _adel
  { {0xb7240086,0x2605021e,0x628b0030,0x60c9497a}},	//   _عکسه, _हॉकी_, fogo, _atem
  { {0x7afd0050,0x6b7a00b2,0xd62a0001,0xa79b000a}},	//   ństw, ברענ, _томе_, _כשיח
  { {0x61e90026,0xfe790089,0xb87b002d,0xc5f3000a}},	//   _ddel, dnů_, isín, _קדש_
  { {0x29120f4d,0xe9f90023,0x399b00b2,0xc9530008}},	//   _mpya_, _khả_, בינד, ומד_
  { {0xcf260029,0xf8bf0030,0x6e2202f2,0x7d1b02ad}},	//   ترشي, evél_, _paob, ewus
  { {0xc7b30008,0x00ca006b,0x7c2308cf,0x44230030}},	//   ובו_, _влак_, _aanr, _zaj_
  { {0x3e7a0024,0x99800089,0x865b000a,0xb0160015}},	//   sīto_, _aniž_, ידקי, _وورث
  { {0x7c230026,0x718b000a,0x93fa000a,0xdfcf0015}},	//   _canr, _דְבַ, ׁלִי, _ليك_
  { {0x649000f2,0x6e22002d,0x23fb000a,0x61e902de}},	//   läis, _taob, ספטמ, _ydel
  { {0xf1b1005d,0xbebc0024,0xfe720021,0x8cd5000b}},	//   ुँचन, _brīv, _غدا_, _मौको
  { {0x649000f2,0xddc20045,0x7eb50091,0xbb47002b}},	//   näis, _emoţ, _išpa, ملین_
  { {0x7c230026,0x8afc002a,0x7d770015,0xd9180138}},	//   _ganr, rzęb, _بمهر_, цью_
  { {0xf64705d1,0x70d7005d,0x466b207f,0x1bf7000a}},	//   охан, _डब्ल, арам_, _וצור_
  { {0x4423018c,0x6490008c,0x85c90015,0xf1b90091}},	//   _saj_, käis, إِذْ_, _rašo_
  { {0x14f50010,0x64470089,0x0595002b,0xe4d90015}},	// [ab50] язаў, _poji, سارگ, صوات_
  { {0xb87b002f,0x8afc005c,0xc4f80086,0x3c78000a}},	//   msío, częc, تعفا_, צָּב
  { {0x8c1b0008,0xb87b002d,0x6f0d002a,0xfe790046}},	//   שובי, lsío, łacz, ynů_
  { {0xf1b9018c,0xd3700074,0x8b8b000a,0xb87b016e}},	//   _vašo_, خهٔ_, בָדֶ, juíz
  { {0x4423010b,0x64900020,0xe63a000a,0x63f70015}},	//   _taj_, täit, _התרכ, _وأسر
  { {0x94ba0008,0x1beb005d,0x44b40063,0x229c002e}},	//   _למשת, _फ़ाइल_, _обяс, ríka_
  { {0x00180010,0x13590015,0xe1f30015,0x43940033}},	//   іўшы_, _الأخ_, _يسر_, _жарс
  { {0xa77c0008,0x212d00bd,0x82370002,0x5214049d}},	//   ירופ, _treh_, _برسا, _одст
  { {0x5fcf005d,0x28b7005d,0xc0c8004a,0x61e4001a}},	//   _स्थल, _इंगि, _духе_, ðile
  { {0x71880008,0xf8bf002e,0xdfd10015,0xab653da0}},	//   _וְעַ, rvél_, _أيا_, звол
  { {0xf98900b4,0x69c10089,0x260c000b,0x7c230085}},	//   _ער_, ělen, ड्डी_, _vanr
  { {0xdce70064,0x69c1005c,0x8f9a0008,0xc869000f}},	//   şlık, ślen, _היעי, _גן_
  { {0x7c230064,0x39360033,0x5e440015,0x0000006a}},	//   _tanr, чэнс, _تَنْ,
  { {0x64900201,0xccf9002a,0xe9f90016,0x8d980015}},	//   häir, muś_, _phả_, _بخمس_
  { {0x07a300d7,0x186700d7,0xf7460e77,0x3ec9000a}},	//   еарн, чари_, чево, מֶּ֣
  { {0x6b9c00b8,0x7e7b0ed6,0x0000006a,0x0000006a}},	//   ürge, nnup,   ,
  { {0x14c80074,0xcaa503c4,0x05662774,0x2912003f}},	// [ab60] زهای_, _تصوي, чван, _upya_
  { {0xe9f90092,0x07a60004,0x6490008c,0xb87b016e}},	//   _thả_, _напн, väis, nsíl
  { {0xdc9a00b2,0x67bb0008,0x1beb000b,0x4c9a000a}},	//   ציעל, _למיק, _फ़ाईल_, צבעו
  { {0xf1260036,0x649000f2,0x5b7a000a,0xb5fb001a}},	//   зько, täis, זרעא, _smáv
  { {0xc5f30b7b,0xf1cb000b,0x1fb8004a,0x69c6497b}},	//   _אדר_, ाड़न, оллы_, icke
  { {0x649000f2,0x859b000a,0xc0e70015,0xc0aa0015}},	//   räis, _לשכו, أفون_, حاصل_
  { {0x649000f2,0x64a3070e,0xff230004,0x6383497c}},	//   säis, _чара, емјо, _згра
  { {0xbe8a0001,0x6490497d,0x4444497e,0x1d34006b}},	//   љске_, päis, lj_, дния
  { {0x7f86002b,0x9d130033,0x4fb60015,0x4444477c}},	//   _کلان, едыч, _فصار, oj_
  { {0x4444497f,0x515b000a,0xfd0f0015,0x61e2008c}},	//   nj_, _הכמו, اجي_, laol
  { {0x44440298,0x8ae30033,0xcf8d002b,0x443809f5}},	//   ij_, ніял, _پژو_, _mnr_
  { {0x7f3b0008,0x6aa40152,0xee290029,0xe39b0008}},	//   _לעבו, _chif, _وأنه_, משיכ
  { {0x5a34006b,0xbd54002b,0x3ebe4980,0xae890058}},	//   хнят, _تراژ, _hutt_, _بخلق_
  { {0x7b0500f2,0x7d37004c,0x8c430e71,0xad37000a}},	//   öttö, _מנדב_, _пече, _מנדס_
  { {0x3ebe0020,0x6beb000a,0xab93005e,0x44444981}},	//   _jutt_, _הַחַ, _пиші, dj_
  { {0x44440050,0x61e20020,0x4b7b000a,0xdb7b000a}},	//   ej_, jaol, _לאוו, _לנוכ
  { {0x61e20020,0x7afa4982,0xb87b001a,0x38a40123}},	// [ab70] daol, lutt, lsím, förd_
  { {0xf1b9016f,0xe2f9005e,0xc952000a,0xd49b08f0}},	//   _sgš_, жежі_, _סמי_, ёра_
  { {0x7afa4707,0x93190115,0x7c28001a,0xf367024f}},	//   nutt, تقاء_, iddr, чтан
  { {0x32550010,0x444410a4,0xe298005e,0x7afa02b9}},	//   ьвер, aj_, пає_, iutt
  { {0x3ebe001a,0xb87b0046,0x6d46008c,0x92b4012c}},	//   _autt_, ysíl, äkal, رحما
  { {0x7afa022d,0x3ebe118e,0x23e1000b,0x53e1000b}},	//   kutt, _butt_, _फ़िद, _फ़िश
  { {0x69c600c0,0xef190036,0x10080029,0xa858000a}},	//   ycke, іми_, ستوى_, היגה_
  { {0xa2940191,0xd7380008,0x7afa333f,0x1167002b}},	//   _засі, לטות_, dutt, _فلزی_
  { {0x3e6a0074,0xc2120008,0x6aa40026,0x2b49002a}},	//   تجوی_, _בהן_, _rhif, _łac_
  { {0x8b070089,0xe53c000a,0x0ae9004a,0x7afa166c}},	//   _naří, מתחר, одой_, futt
  { {0x8d870086,0x1ee7002b,0x28b7000b,0x3ebe0b35}},	//   _کشان, _روشی_, _इंजि, _gutt_
  { {0x6219000a,0x7eb50091,0x69d80030,0x69c64983}},	//   חוֹק, _išpo, _őveb, ucke
  { {0x7afa00f2,0xb5fb0107,0xceb2000a,0x39350033}},	//   autt, _mlád, _סיד_, нэрс
  { {0x1cba000a,0x5b250015,0xa7da0021,0x9cd6000a}},	//   _ומסע, _يفشل, توسط_, _חוסה_
  { {0x66e60036,0x7d094054,0x8cac000b,0x7afa165d}},	//   ьова, ltes, ुआरो, cutt
  { {0xa6950054,0x6e294984,0x44384985,0xb6a300c2}},	//   еруј, ndeb, _snr_, висл
  { {0xc986003b,0xa823002b,0x044a0151,0x7d094986}},	// [ab80] _تشغي, رکین, опак_, ntes
  { {0x58f70008,0xa3ba0029,0x660d00d9,0x44440a78}},	//   _קצין_, زائر_, afak, uj_
  { {0x0206008f,0x7d090005,0xf8b30008,0xa857000a}},	//   дзен, htes, _ששת_, _חייה_
  { {0x27a90053,0x8b070089,0xdb2400dc,0x644500bc}},	//   _מסתּ, _zaří, ésév, ajhi
  { {0x51830124,0xa0c40015,0x61e24987,0xb5fb0030}},	//   куша, ريغو, raol, _slág
  { {0xf1a90018,0xdfcf00e5,0x2056034e,0x7afa0061}},	//   سانه_, ليه_, ьтер, yutt
  { {0x3e7a0024,0x7d090100,0x90870015,0x0877004c}},	//   līti_, etes, بنوك_, ועסט_
  { {0x7afa00f2,0xddc90045,0x27e33387,0x68e90816}},	//   vutt, vieţ, zajn_, šedi
  { {0x7eb500df,0x3e7a0024,0xc0060eb0,0xa0c90015}},	//   _išpl, nīti_, _опак, _فذلك_
  { {0x60260036,0x61e0307c,0x3ebe02b9,0x7afa4988}},	//   _ідеа, _heml, _tutt_, tutt
  { {0x93f70008,0x7afa00f2,0x69c1005c,0x7d094989}},	//   וציא_, uutt, ślem, ates
  { {0xb87b0084,0x7afa498a,0xddc90011,0x61e000bc}},	//   rsím, rutt, rieţ, _jeml
  { {0x8b070089,0xbebc003d,0x27e3498b,0xb87b498c}},	//   _paří, _trīs, tajn_, ssím
  { {0xa8a4000d,0x3e7a0024,0xd6db067a,0xddc9498d}},	//   врск, dīti_, жта_, mieš
  { {0xf794008f,0xabfb0008,0xda67002b,0xddc9498d}},	//   варэ, _והור, _يابي, lieš
  { {0x7a870015,0xb5fb498e,0xd91b006b,0x69c80046}},	//   _تشتم, _amár, _дьо_, ědec
  { {0xddc90024,0xb5fb002e,0x5694005e,0xd371002b}},	// [ab90] nieš, _smás, татт, گها_
  { {0x752d04ed,0x201c044c,0xfdbb000b,0xf3f00015}},	//   rvaz, jevi_, _उल्फ, لأم_
  { {0xa3a9005d,0xc7d60008,0x3a2900dd,0xd3710070}},	//   खें_, _אותי_, _kaap_, دها_
  { {0xa4d50036,0xd3a40661,0x7d090c4d,0x38a4080d}},	//   _помі, труп, ytes, röre_
  { {0xb5fb0f1b,0x61e4002e,0x3e7a003d,0xddc918df}},	//   _vlád, ðila, cīti_, jieš
  { {0x78fc0008,0xd0110115,0x8fa52201,0x63f40015}},	//   קלופ, الغ_, нале, _لأفر
  { {0x2eb5000d,0xd00e0015,0x69c10046,0x26c1498f}},	//   нсис, صلي_, ělej, _juho_
  { {0x87b8000a,0x74d6000b,0x6d250162,0x6e920054}},	//   ולוס_, मीकृ, едиз, лију
  { {0x6fca005d,0xa0c40015,0xab64002a,0x7d094990}},	//   _स्कू, _ليقو, óżny, utes
  { {0x61e00a00,0xc01403fc,0xb05b0015,0x201c02b9}},	//   _zeml, _имущ, _بشرط_, cevi_
  { {0xddc900df,0xdbdc002e,0xf412004c,0x7d093d47}},	//   aieš, ráði, נפט_, stes
  { {0xdddb0046,0xc332000a,0x7de7002b,0x7d094991}},	//   louž, אוט_, _آسام, ptes
  { {0xddc90048,0x3ead153c,0x27e14992,0x0000006a}},	//   cieš, mmet_, _behn_,
  { {0x9d760053,0x3ead4993,0x0c390015,0x3c450015}},	//   _אײנס_, lmet_, _ركعة_, _سَبِ
  { {0x6a960036,0x5a96000d,0x60130064,0xa30e005d}},	//   _приє, _приф, mımı, _सहेज_
  { {0xb5fb4994,0x3e7a0024,0x60130064,0xe61f002c}},	//   _aláb, tīti_, lımı, _skôr_
  { {0xd5b20029,0x3ead3ff5,0xceb200f3,0x33f6058f}},	// [aba0] افذ_, imet_, רין_, ечес
  { {0x60130064,0x8726042b,0x3ead4995,0xd8d7004c}},	//   nımı, _змож, hmet_, _רויט_
  { {0x77940086,0x3e7a0024,0x224d0161,0x60c034b0}},	//   _شیرا, sīti_, _boek_, _summ
  { {0x27e100b8,0x7862002c,0xe3a7002b,0x321d00aa}},	//   _zehn_, _dôve, رشلی, gewy_
  { {0x645b0014,0x60130064,0x3e7a003d,0x3ead05e3}},	//   áció, kımı, nūte_, dmet_
  { {0x557700b2,0x3ea6003e,0xddc90024,0xe1370010}},	//   _װעלן_, _shot_, vieš, эзіі_
  { {0x543b0053,0x201c0720,0x5f9309c4,0x03a34630}},	//   _צעלא, revi_, лишт, _биро
  { {0xddc90024,0x97a9000a,0x2a60007c,0x4e1a0015}},	//   tieš, וֹפֵ, _nlib_, ستعد_
  { {0x442a00e8,0x644e4996,0x721b000a,0x60130061}},	//   _kab_, _kobi, _צומח, fımı
  { {0x224d0111,0x2cb800c0,0xfc320029,0x3ead4997}},	//   _zoek_, örd_, احظ_, amet_
  { {0x442a0026,0x8afc005c,0xdfa60015,0x59f915f1}},	//   _mab_, częl, _أحذي, меня_
  { {0x24560084,0x68fd0926,0x442a1abc,0xddc92647}},	//   _dæmi_, tusd, _lab_, pieš
  { {0x2bd1014e,0xf1b90024,0x8e470015,0x60130061}},	//   _द्वा, _paši_, _سلوك_, bımı
  { {0x60130064,0xdd3b000a,0xf65f001a,0x68fd00aa}},	//   cımı, _מעדכ, _slæ_, rusd
  { {0xa09b01ac,0xf1b94998,0x6b660003,0x9f490061}},	//   פילט, _vaši_, _dégé, ğaç_
  { {0xdb9b000f,0x6b9b000a,0x9f97000a,0x7f3b000a}},	//   _מסור, _משוד, גדלה_, העלו
  { {0x59d40029,0x94750086,0xc7cb0080,0x85b80015}},	// [abb0] _صغير, نگسا, _ныне_, فاكس_
  { {0x224d0f75,0x3ead01e2,0xb97c000a,0x225f02de}},	//   _soek_, zmet_, _מנחי, _sluk_
  { {0x644e060b,0xae21000b,0xf8b6000a,0x3e7a003d}},	//   _dobi, _मसलन_, _שפתי_, lītu_
  { {0x41b50002,0xd0d5006b,0xe0d50054,0x60130061}},	//   نمار, водъ, водњ, zımı
  { {0x3e7a0024,0x442a4999,0x00c8005e,0x60130061}},	//   nītu_, _fab_, елік_, yımı
  { {0x644e0467,0xe3b30086,0x442a00b8,0xd5760008}},	//   _gobi, _مرز_, _gab_, _יתרה_
  { {0xf8380008,0x867b000a,0x26c5013f,0x3ead3381}},	//   תנות_, ּר֥ו, íloh_, tmet_
  { {0xa2be000b,0x7c2a007c,0xf2d2000a,0x3eb9499a}},	//   षदर्, _aafr, _כעל_, öst_
  { {0x60130064,0x2d990134,0x22840010,0xdddb0227}},	//   tımı, æse_, _сург, použ
  { {0x3e7a0024,0x69cd0026,0x2a60077d,0xdca50054}},	//   dītu_, _afae, _slib_, ђани
  { {0x601301e2,0x68ed499b,0x6fca000b,0x5ba90342}},	//   rımı, _avad, _स्टू, ьком_
  { {0x1611005d,0x80d8000b,0x63ba001a,0x60130061}},	//   _डॉलर_, नीके, _útne, sımı
  { {0xb7e6005d,0x60130061,0xc172000a,0xed4e0129}},	//   _क़दम_, pımı, ֹ֗ר_, _то_
  { {0x38a400c0,0x31560053,0x68ed37f7,0xfaf8003d}},	//   föra_, דישן_, _dvad, brī_
  { {0xf0920008,0x38a400c0,0x6b6601c4,0x644e277e}},	//   ינך_, göra_, _végé, _robi
  { {0x69bc005d,0x644e499c,0xdbe20003,0x442a499d}},	//   _एलटी, _sobi, _rééd, _sab_
  { {0x6e2b00b6,0x644e259a,0x764f0034,0x442a0034}},	// [abc0] _magb, _pobi, _docy, _pab_
  { {0x44630083,0x78fb000f,0x42d6042b,0x037a00c3}},	//   авув, _קליפ, віду, وحات_
  { {0xf2060010,0x420a0054,0xe3160058,0x0000006a}},	//   вяло, днео_, ضباب,
  { {0x6e2b00b6,0xd2590036,0x90e60086,0xcb12004f}},	//   _nagb, нці_, نستن, שלא_
  { {0x644e499e,0x442a499f,0xa06a1d8c,0x66040c4e}},	//   _tobi, _tab_, мада_, mgik
  { {0x644e016f,0xa2d600a2,0x399d00dc,0xf1b91e1b}},	//   _uobi, _ليست, lású_, _našu_
  { {0x3e7a0024,0xaf070015,0xcf260015,0x987b000a}},	//   zītu_, نقوم_, ئرتي, ורסק
  { {0x66040375,0x7c2a49a0,0x387802ad,0x63b40535}},	//   ngik, _safr, hirr_, ęgnę
  { {0xa3d6005d,0xd0260063,0x6e2b49a1,0xdbdc001a}},	//   _सभा_, _имай, _dagb, _báðu
  { {0x3fcb002b,0xf1a9006e,0x8c43011e,0x0000006a}},	//   _قدمی_, _ساقه_, иење,
  { {0x7c2a0084,0xe4570053,0x6fd8021e,0x61ed002e}},	//   _vafr, דייט_, _न्यू, ðalg
  { {0xfee9003b,0x6f7900b2,0x3e7a0048,0x7c2a003f}},	//   _أعلى_, _אָנג, tītu_, _wafr
  { {0x29870010,0xfaa40010,0x6e202bd7,0x7c2a003f}},	//   тынг, ршэн, memb, _tafr
  { {0xf1b30008,0x1d170008,0x3e7a0024,0x0d17000a}},	//   יסר_, _סקור_, rītu_, _סקוט_
  { {0x8c1b0008,0x3e7a0024,0xf8bf0030,0xa3d6000b}},	//   _חווי, sītu_, evét_, सडन_
  { {0xb5950080,0x61e4002e,0x3e7a003d,0xf7480015}},	//   гибш, ðill, pītu_, خلفي_
  { {0xa5071e88,0x55070063,0x394400c0,0x6e200077}},	// [abd0] ъявл, ъчва, ämst_, iemb
  { {0x63f40029,0x648b0024,0xd37b017a,0xf9900015}},	//   لأمر, kļie, мче_, _ظبي_
  { {0x3e7a0048,0x7ea50084,0x764f0026,0x62352c0c}},	//   nīts_, hópa, _tocy, лежу
  { {0x62820020,0xcb130053,0x6b7b000a,0xd736000a}},	//   gnoo, ילע_, ורבנ, _עטרת_
  { {0xe4e40036,0xd1b800e6,0x2127002b,0x7d00390d}},	//   _вісн, ناها_, ئيتی_, jums
  { {0xf8b5000b,0x7eb50091,0xc2c50015,0x628202f2}},	//   ूदिय, _išpi, _ميسي, anoo
  { {0x6e2b025c,0x44210213,0xa8ac000a,0xdbdc001a}},	//   _pagb, meh_, וֹהִ, _ráðu
  { {0x3e7a0048,0x44210375,0x3cd9005e,0x7d00001a}},	//   dīts_, leh_, ньою_, fums
  { {0xf1b90024,0x0c790010,0x7d00003d,0x518449a2}},	//   _pašu_, есны_, gums, _куфа
  { {0x4421018c,0xe9f90023,0xbc620010,0xe572000a}},	//   neh_, _thẻ_, йвык, מַת_
  { {0xf1b949a3,0xf8bf0030,0x09e62282,0x7e6249a4}},	//   _vašu_, kvés_, лонн, _flop
  { {0xcd350225,0x7524002a,0x6e2029eb,0x442131f4}},	//   _مرتب, ywiz, cemb, heh_
  { {0x7afa0577,0x442107c8,0x7d000a46,0x9d44009a}},	//   artt, keh_, cums, _نئون
  { {0x4421016f,0x8c42006b,0x8f00005e,0x7e620085}},	//   jeh_, _геше, сiї_, _zlop
  { {0x3e7a0024,0x399d0030,0x442149a5,0x0000006a}},	//   lūta_, tású_, deh_,
  { {0xd627004a,0x4b7a004f,0x0000006a,0x0000006a}},	//   лосе_, _ראקו,   ,
  { {0xe9f90092,0xc2240086,0x85060015,0x34aa0054}},	// [abe0] _nhẹ_, یکرو, طوان, евао_
  { {0x29020509,0xb4e4000b,0x6e2049a6,0x44212069}},	//   muka_, _नबी_, zemb, geh_
  { {0x6e2000b6,0xb17d002c,0x628200dd,0x66e6005e}},	//   yemb, _reťa, tnoo, _щона
  { {0xa77b000a,0x1c13000b,0x6eca002a,0x0d82004a}},	//   _טריפ, त्तल_, _bębn, ́льн
  { {0x290249a7,0x7a3b008c,0x4a7b004c,0x3e7a003d}},	//   nuka_, _hätä, ערנב, zīts_
  { {0x3cf9014e,0xb87b03af,0x18360053,0xed590089}},	//   ोंने_, ssív, ראַל_, dyž_
  { {0xb87b002d,0x6e2049a8,0x77ba000a,0xe816000b}},	//   msít, temb, ׂמְח, द्या_
  { {0xe3c10061,0x7d0049a9,0xd357000a,0x8cf4012e}},	//   ğış_, tums, _גילי_, азиц
  { {0x127b00b2,0x9be60010,0xf6530008,0x38a4002e}},	//   _נאמע, лінк, מצה_, vörn_
  { {0x3e7a0048,0x711b0053,0x7ea500dc,0x7b140eb0}},	//   tīts_, _אומפ, rópa, адох
  { {0x8fa6098b,0x6e2012d3,0x0497000a,0x28be000b}},	//   _саже, pemb, רכיך_, _एंजि
  { {0xdd8f0086,0x53370053,0xfaf80024,0x3e7a15e5}},	//   _کوه_, אנטן_, dzīt_, rīts_
  { {0x6e93003b,0x5e930029,0x3e7a0024,0xd5ed0092}},	//   _النا, _النط, sīts_, hoạ
  { {0x6d4600f2,0xf7730067,0xa16c0033,0x36d51635}},	//   äkau, ماز_, яцiн, иогр
  { {0x395f02fd,0xab27049d,0xfc2f0015,0x103b004c}},	//   šus_, _боја_, _رحو_, עגלע
  { {0x7ea5002e,0xbb3b0008,0x8f9b000a,0xf8bf0003}},	//   hópn, _טעוי, גילי, uvés_
  { {0x62830152,0x229c0089,0xf8bf0152,0x44213f29}},	// [abf0] énom, níku_, rvés_, teh_
  { {0xe3b30029,0xa81d0033,0x53a50015,0xb5fb0077}},	//   مرض_, _ўзнi, لمذك, _glán
  { {0xd14b002b,0x69dd0e01,0x442149aa,0x289c004f}},	//   کشان_, obse, reh_, _איזא
  { {0xeb970053,0x6683002b,0x82f80021,0x98a9002a}},	//   נדאר_, _ایرل, ارلز_, _brać_
  { {0x41af000b,0x7bc60046,0x44210796,0x2d80006f}},	//   जेंस, ěkuj, peh_, _žien_
  { {0x00840036,0x656d0012,0x229c0046,0x9f470069}},	//   бліо, mzah, díku_, lané_
  { {0x656d00b8,0x27e5002a,0x6eca002a,0xa0660c30}},	//   lzah, ólny_, _dębo, раща_
  { {0x43840029,0x764d00d9,0x3ced0020,0x9f470264}},	//   _الفق, njay, tsev_, nané_
  { {0x7db40010,0x656d3282,0x7c2149ab,0xfd46006b}},	//   йсьц, nzah, telr, изък_
  { {0x9f6b010f,0x764d00d9,0x98b20046,0x29020573}},	//   _през_, hjay, _pryč_, vuka_
  { {0xc9490008,0x3e7a0024,0xba760029,0x3b090054}},	//   _קמ_, sūta_, لاحت, њемо_
  { {0x6dc70029,0xb5fb002d,0xdef6039e,0x6f030509}},	//   _إزال, _slán, _כמעט_, munc
  { {0x9f47099c,0x8c450fbd,0xb5fb49ac,0x6f032ee0}},	//   dané_, _веле, _plán, lunc
  { {0x2902010b,0x6cd20015,0x6f0300da,0x2007001a}},	//   ruka_, _بقوا, ounc, ngni_
  { {0xfaa620bb,0x6f0349ad,0x68fd0177,0x7d150091}},	//   _како, nunc, arsd, žasč
  { {0xdeef0010,0xfaf80024,0x2129002c,0x2902003f}},	//   цыi_, rzīt_, ťahy_, puka_

  { {0xd8f40086,0x61eb49ae,0x2104000b,0xba9b0447}},	// [ac00] _ازبک, dagl, _रमेश_, _בסקי
  { {0x6f0300d9,0xa443009c,0x33d6005e,0xb87b0227}},	//   kunc, онуд, ріат, usít
  { {0xb7fb000a,0xb87b0030,0x57fb000a,0x130a056d}},	//   _בפית, rsít, _בליו, тней_
  { {0xb87b0014,0x52760015,0xf1fa0015,0x61eb02b9}},	//   ssít, جائز, ئعات_, gagl
  { {0x7bc304ed,0xd132002b,0x69c40535,0xb17d016d}},	//   _ognu, تمش_, _mgie, _deťo
  { {0xa0730191,0xb9370008,0xd0100015,0x6f0349af}},	//   огіч, יננו_, سلب_, func
  { {0x69c4002a,0x53aa000b,0x2d800045,0x141b000a}},	//   _ogie, _करिश, _ţie_, _שולב
  { {0xa2cb005d,0xb0fa0015,0x8ed70015,0x61eb01e0}},	//   _तंत्, _لفرض_, جذور_, cagl
  { {0x90460086,0xe611039e,0xd657000a,0x5c98006b}},	//   _پناه, הִי_, שיפת_, лкия_
  { {0xeb4a0086,0x9f470227,0x6aad0fda,0x229c001a}},	//   نشجو_, zané_, _shaf, ríku_
  { {0xe9f90023,0x9b940054,0xd437000a,0xab86006b}},	//   _chế_, синц, בריק_, рупк
  { {0xc33301e4,0x9f7b000a,0xa2f7000a,0x7e6949b0}},	//   קור_, _בנבח, סמכה_, chep
  { {0x9f4704af,0xdd920806,0x27270026,0x68fd0079}},	//   vané_, _بوش_, _sŵn_, ursd
  { {0xdc080048,0x7862002c,0x611a0024,0x67d30046}},	//   _rēķi, _dôvo, mālā, dějí
  { {0xe9f90092,0x17540036,0x9f4701c9,0x4fd7000a}},	//   _ghế_, овря, tané_, שולב_
  { {0x3bbb0008,0x8f1b0008,0xe4d70015,0xdef7000a}},	//   _במוד, כולת, لتطب, ימלט_
  { {0xe4e70036,0x764d00d9,0x611a0024,0x9f4701c9}},	// [ac10] рібн, rjay, nālā, rané_
  { {0x6f030064,0xe816005d,0xea000092,0x9f4701c9}},	//   yunc, द्दा_, _trải_, sané_
  { {0xbebc0024,0x75360007,0x656d19e4,0xb87b001a}},	//   _drīz, avyz, szah, ssís
  { {0x80f50015,0x611a003d,0xb5fb001a,0x67d3005a}},	//   مستض, kālā, _klám, bějí
  { {0x98da005d,0x361a000a,0xf8da000b,0xe1f801f3}},	//   _बढ़ाए, _גורד, _बढ़ाय, ргі_
  { {0x6f030045,0x61eb49b1,0x96af000b,0x55ba004f}},	//   tunc, sagl, ंगकॉ, _תמשו
  { {0x61eb0035,0xf7f80053,0x3e7a003d,0x6235056d}},	//   pagl, בזוך_, gūto_, _леву
  { {0x443102c1,0x52850029,0xfe45000d,0x9758000a}},	//   _haz_, _الرك, снио, שיהו_
  { {0xee3602bf,0x69c400dd,0x6299002a,0x64552005}},	//   сны_, _rgie, mowo, _kozi
  { {0x3c650c9c,0xac180036,0x443100bd,0x61e9014c}},	//   ског, ацює_, _jaz_, _heel
  { {0x61e90005,0x6d5b00d9,0xe4580053,0x44310024}},	//   _keel, syua, ייזט_, _maz_
  { {0x6455016f,0x7862002c,0xddc200bd,0x6299002a}},	//   _lozi, _pôvo, _zmož, nowo
  { {0x61e90005,0xfe700015,0xdcc80016,0x60c149b2}},	//   _meel, _تدل_, _tỉa_, _kilm
  { {0xe9f900a7,0x29f80016,0x38a4001a,0x443111b7}},	//   _thế_, ọa_, mörk_, _naz_
  { {0xec120086,0x2d9200cb,0x6299002a,0x76a60015}},	//   _رويد, _øyer_, kowo, محرك
  { {0xcf920135,0x9f450107,0xc4c60015,0xfd640016}},	//   פטן_, _celé_, متطو, _nguờ
  { {0xceb20008,0x6299005c,0x05aa0063,0x98f60087}},	// [ac20] ליל_, dowo, увай_, _اثبا
  { {0x44310011,0x48060142,0xb937000a,0xe612002b}},	//   _caz_, _упов, _פניו_, _کشد_
  { {0xddcb005c,0x9f4500dc,0x61e9049c,0xb857000a}},	//   _mogł, _felé_, _beel, _השיג_
  { {0xdb9a0053,0xfaf60008,0x171b004c,0x66ed000b}},	//   אסער, מצעי_, _גוטע, _जबतक_
  { {0x86370008,0x61e90384,0x44312145,0x60c149b3}},	//   _הרכב_, _deel, _faz_, _bilm
  { {0xd2590024,0x84590180,0x70540021,0xdd04003d}},	//   _viņa_, _крст_, تنتا, ūpīg
  { {0x447b00b2,0x61e90388,0x1ef70015,0xbef70015}},	//   _ענלע, _feel, معية_, مريض_
  { {0x6299005c,0x60c10b35,0x611a003d,0x61e949b4}},	//   cowo, _eilm, tālā, _geel
  { {0x64690007,0x44310064,0xe9f90092,0x786b007c}},	//   šsių, _yaz_, _chẽ_, _hüve
  { {0xddc20264,0x26c23cb3,0xe0860015,0x611a003d}},	//   _umož, _liko_, _اجري, rālā
  { {0xb4db0251,0xfd0f0086,0x7fd7000a,0xe26a004f}},	//   _gràf, وجی_, _הובס_, ָדָֽ
  { {0xfe720015,0xe9810033,0xd30102a3,0x8ea60015}},	//   _عدا_, дамi_, сiйс, _اصطن
  { {0x127b0053,0x1dac005d,0x2e370008,0xc27b000a}},	//   ראכע, _चरित, _לראש_, ררכי
  { {0x7b070125,0xd7fb0033,0x67d4222c,0xd910009a}},	//   ósté, ыум_, зору, ریپ_
  { {0x9c170008,0x27ff0064,0x4431066f,0x5ef8000a}},	//   _החוק_, ğun_, _raz_, יִּס
  { {0xea000092,0x95d9000d,0xf1ba005d,0x645549b5}},	//   _trại_, рдат_, ेशान, _sozi
  { {0x54554014,0xa3e5000b,0x5dcb000a,0x645549b6}},	// [ac30] оват, नरल_, אֶבְ, _pozi
  { {0xe7870127,0x628a0533,0x61e949b7,0x93f50033}},	//   _гумо, éfon, _seel, іпец
  { {0x94a8010f,0x8afc005c,0x11d70029,0x38340010}},	//   стта_, częt, متشد, _энэр
  { {0x60c149b8,0x44310012,0x6455002a,0xa1eb0015}},	//   _silm, _waz_, _wozi, اراك_
  { {0x4acf005d,0x92940010,0x60c90077,0x3abc004c}},	//   _संभव, чацц, _quem, אמאנ
  { {0x212d018c,0x6299002a,0x859a05bd,0x26c200aa}},	//   _vseh_, sowo, _כשרו, _ziko_
  { {0x786b01e2,0x6299005c,0x40920015,0x7afd002a}},	//   _güve, powo, بلور, ąstk
  { {0x12870086,0xef160010,0xa77c00a3,0x60c9008c}},	//   _امری_, імы_, טרופ, _tuem
  { {0x60c100fb,0x60c90020,0xddcb002a,0x260a000b}},	//   _tilm, _uuem, _pogł, िलती_
  { {0xb4db0251,0xac9600a2,0x9f470b7e,0x9cb20015}},	//   _tràf, ينيا_, laní_, وميت
  { {0x2dd50c71,0xaa4a248c,0x661d49b9,0xb4db03a0}},	//   _джер, апна_, _obsk, _fràg
  { {0x753d0014,0x7afc03d9,0x6ffb003d,0x539a000a}},	//   _orsz, árta, sācē, ייתו
  { {0x38a4007c,0x26c249ba,0x27fe0535,0x0000006a}},	//   löri_, _riko_, ótno_,
  { {0x2a690020,0xb7da002b,0xf8b10015,0x91ba000a}},	//   _elab_, شورا_, ّةِ_, ימרי
  { {0x18a3008f,0x7aa60015,0xf656004a,0x9f4704b2}},	//   фарм, _وإعل, отаю, kaní_
  { {0x8afc005c,0xcb12000f,0x9f47016d,0x0000006a}},	//   rzęt, _חלה_, janí_,
  { {0x9f4701c9,0x786b2c37,0x99f7000a,0xeac90016}},	// [ac40] daní_, _süve, _וזפה_, _kẹo_
  { {0x8afc002a,0x58060015,0x4c99004f,0x61ed0052}},	//   częs, _بودك, בֹ֣א, ðaln
  { {0xeac90092,0x82f60033,0xd1ca0088,0x38a40052}},	//   _mẹo_, ючац, алее_, jöri_
  { {0xe816005d,0xe29a0010,0x7b0c004c,0x91e300af}},	//   द्रा_, шае_, רפאַ, доце
  { {0xf653000a,0xbba6000b,0xd0100015,0xdfd4004a}},	//   _חצר_, _ऑर्क, ّلت_, полы
  { {0xaff70015,0xb5fb0030,0x290249bb,0xe8d7004f}},	//   قفها_, _aláh, irka_, קוצר_
  { {0x787b0008,0x3e6a0098,0xb5fb0046,0xa6fa000a}},	//   יָהו, ишин_, _bláh, בִ֥י
  { {0xbe8a0001,0x20000011,0x42d501c6,0x5d54006b}},	//   јске_, şii_, _хіру, зкит
  { {0xd00a0124,0xddc20050,0x61e4002e,0x7c8a006b}},	//   _везе_, _umoż, ðilu, ищов_
  { {0x0bf3005f,0xaff70029,0xc157000a,0x71250015}},	//   мпью, _وفقا_, _ושמו_, _عرقل
  { {0x20d00092,0x61e2016f,0x4e2a0004,0x29021d08}},	//   _hài_, obol, _воен_, erka_
  { {0x539b00a3,0xb5fb01b2,0x5ce6006b,0x61e249bc}},	//   שיטו, _vlák, _дюка, nbol
  { {0x6c770086,0xb2bb000a,0xfc2f002b,0x49740138}},	//   صحیح_, ימטר, رحی_, дляс
  { {0x20d00016,0x9f470069,0x764649bd,0xd7c902be}},	//   _mài_, zaní_, _anky, صوره_
  { {0x7c280026,0xd8380033,0x8afc002a,0x57a40054}},	//   medr, цэя_, rzęs, дшта
  { {0x61e2065d,0xfb870086,0x1995008b,0x7c2849be}},	//   jbol, _بدهی, _найя, ledr
  { {0x9f4712c3,0x61e2145c,0x6eca002a,0x97c70015}},	// [ac50] vaní_, dbol, _dębi, _وتدم
  { {0xa3a70124,0x93a70080,0x61e2376f,0x83670040}},	//   ојек, ошед, ebol, يدال
  { {0x9f47002c,0xd498017f,0x58b80015,0xb867002b}},	//   taní_, іру_, _بايج_, _هاگو
  { {0x20d00023,0xe503000b,0x5274002b,0x7c2849bf}},	//   _bài_, _लिपि_, وانز, hedr
  { {0xdd86040b,0x20d00023,0x71270031,0xda7c000a}},	//   _أو_, _cài_, ترال, סנדר
  { {0x20d00023,0x55ba0008,0x660d007c,0xdb460015}},	//   _dài_, _למרו, lgak, _كَ_
  { {0xdb030107,0xff53002b,0xdb070061,0xd314006b}},	//   _ozná, بخش_, ülük, _омръ
  { {0x290200c0,0xb5fb002e,0x11d40015,0x69db0077}},	//   yrka_, _blái, _يتقد, ñuel
  { {0xb5fb002d,0x6447065d,0xa9240007,0xc1040015}},	//   _clái, _knji, įžki, _يوفي
  { {0x60db003f,0x7c2849c0,0x4c690763,0x0000006a}},	//   _itum, gedr, сион_,
  { {0x7ea5002e,0xbb450c71,0x628b49c1,0xeb99135d}},	//   hópi, ченк, ongo, син_
  { {0xce380029,0x752d0297,0xacf50015,0xd356000a}},	//   _وأنا_, kwaz, _فستت, ליתי_
  { {0x88d60033,0x20d00016,0x8d770015,0x7c2849c2}},	//   яўні, _xài_, _باضا, bedr
  { {0x5d3a0008,0xfd560008,0x60db003f,0x319a000a}},	//   _לתנא, _משני_, _mtum, מברנ
  { {0x7d0900f2,0x6c320029,0xfbd20008,0xfc160087}},	//   lues, _سفيا, _אתו_, _رقيب_
  { {0xbafa000a,0x61ed001a,0x2c17000b,0xc7a30004}},	//   _ההקש, ðall, ब्रू_, хиск
  { {0x2bd2005d,0x64c6002b,0x61e20123,0xb4db0144}},	// [ac60] _सलमा, سيال, vbol, _aràb
  { {0xd7f10092,0xd5af0015,0xdce00046,0x6eca0046}},	//   ữa_, افك_, ezmě, _hřbe
  { {0xf8b3013a,0x20d00092,0x53a60029,0xd5e40016}},	//   _רשת_, _sài_, أماك, ghĩ
  { {0x2ab200dc,0x316a017f,0x80a4000b,0x644749c3}},	//   lább_, йшло_, _चीजे, _enji
  { {0x463b0053,0xc2430010,0x30340080,0x61fb0026}},	//   _העכע, энцк, делё, _ddul
  { {0x20d00023,0x321a0086,0x7e880089,0xe0430001}},	//   _vài_, _گيرد_, měpi, енљи
  { {0x61e4002e,0x91e61bce,0xb5fb024b,0xd9b9000b}},	//   ðils, _нове, _slái, _इण्ट
  { {0x20d000a7,0xdceb0064,0x16570008,0x787000c0}},	//   _tài_, _aygı, ִׁים_, _hävd
  { {0x2ab200dc,0x62820201,0x90e50015,0x3e7a003d}},	//   kább_, mioo, _يسكن, nūti_
  { {0xf0440086,0xf3f10016,0xd577000a,0xba3b0003}},	//   _تعری, _ột_, פתיה_, zoïd
  { {0x2fd70074,0x7c2816a9,0x394049c4,0x09b7000b}},	//   _روند_, redr, _aris_, ृश्य
  { {0xaf49003b,0xcf250029,0x6fd8000b,0x3940082b}},	//   _بشكل_, _تركي, नुरू, _bris_
  { {0x7d0902c1,0x48e40010,0xb5fb0227,0x1e57000a}},	//   cues, ноўв, _kláv, _משאר_
  { {0x3cfb000a,0xd918004a,0xddc9002a,0x5dbb000a}},	//   _פלונ, чью_, zież, _הזדה
  { {0x8c1b009d,0x8c530086,0x628b0026,0x466b0010}},	//   _הווי, _سئوا, yngo, брам_
  { {0x443f01e2,0xdb030107,0x9f4700bf,0x394003a0}},	//   _şu_, _uzná, naná_, _fris_
  { {0x660d3010,0x3e7a003d,0x61ed001a,0x5fcc000b}},	// [ac70] rgak, gūti_, ðalm, ाशाल
  { {0x628b0176,0xcc78000a,0x734b006b,0x68f80046}},	//   wngo, קְּר, йчев_, řadí
  { {0x752d01c2,0xd37100c3,0x60db475f,0x27f8006f}},	//   swaz, خها_, _stum, šenú_
  { {0xe3b0003b,0x62820e95,0xa29400fd,0xd6e8000a}},	//   ارك_, gioo, нахі, _מַשָ
  { {0x91790023,0xdddb005c,0x9f470264,0xf656000a}},	//   _bấm_, ykuł, daná_, _חסרי_
  { {0xf99400b2,0x29380053,0x91790092,0x8fa549c5}},	//   ערס_, פאון_, _cấm_, мале
  { {0x90280010,0x662600dc,0xc7d80008,0xddc9005c}},	//   яцца_, _ütkö, לוגי_, pież
  { {0xb4db08e0,0xc332000a,0x96fc000a,0x02450015}},	//   _gràc, _בול_, צלחת, _تَرَ
  { {0x60db000c,0x29190d85,0x03d5000a,0xb5fb016e}},	//   _utum, jtsa_, ֽוֹם_, _fláv
  { {0x7870008c,0xab65008b,0xd335000a,0x290b49c6}},	//   _käve, двол, ֵרָה_, duca_
  { {0x6ee70196,0x2ab200dc,0x1a2a097d,0x9056000a}},	//   _رسال, vább_, ожни_, _קבעו_
  { {0x7d090467,0xc8690008,0x38a40b0f,0x4a430036}},	//   pues, _דן_, hört_, внюв
  { {0x7d091ee1,0x91f6000a,0x9f64008c,0x3c450015}},	//   ques, ומרו_, ätön_, _يَصِ
  { {0xcb690a82,0x0000006a,0x0000006a,0x0000006a}},	//   _мале_,   ,   ,
  { {0x2bf6000a,0x07ba0015,0x5b350033,0xe73714dd}},	//   _חמצן_, زهرة_, _цэлу, мер_
  { {0x39400007,0xaaba0086,0xd9f2000b,0xe61a0033}},	//   _tris_, _بدتر_, _अजित_, ўда_
  { {0x14c80086,0x6fa4000b,0xe45a0baf,0x38a40123}},	// [ac80] سهای_, _चुनू, ожа_, fört_
  { {0x88c60029,0xa2e60080,0x26cc0f14,0x9f470264}},	//   _تتعل, дожд, ídos_, zaná_
  { {0xb4db0251,0x62820601,0xb87b2dbd,0x3e7a01ec}},	//   _pràc, tioo, spíc, sūti_
  { {0x2a8800dc,0xb3550086,0x41aa017a,0xf126005e}},	//   lőbb_, ریقا_, овен_, дько
  { {0x62820005,0x9f4704af,0xb5fb49c7,0xc5f3000a}},	//   rioo, vaná_, _cláu, _בדר_
  { {0x6282267f,0x289b004c,0xa3c8000b,0x673b002a}},	//   sioo, ֿיקא, _उलट_, łuje
  { {0x7ea50084,0x443822ee,0x6564008c,0xb4db0144}},	//   hópu, _iar_, lyih, _tràc
  { {0x9f450152,0x1d340404,0xc7b3000a,0x44382731}},	//   _delà_, ения, כבו_, _har_
  { {0x645c49c8,0x44383e75,0x62800738,0x91790016}},	//   _kori, _kar_, _immo, _tấm_
  { {0x515b000a,0xac26004a,0xccf9002a,0x4fb60015}},	//   _וכמו, ффик, myśl_, _قصار
  { {0x443849c9,0x2a880f87,0x4ae7004a,0x645c2756}},	//   _mar_, zőbe_, мьям_, _mori
  { {0x6ab60176,0xaacf005d,0x443849ca,0x7ea50030}},	//   _chyf, _संरक, _lar_, fópu
  { {0xd12600e5,0x394d016e,0xc19b004c,0x3a741ece}},	//   دم_, ães_, ַשלי, тляр
  { {0x645c0780,0xf7730067,0x443849cb,0x291949cc}},	//   _nori, ناز_, _nar_, rtsa_
  { {0x67d40036,0x61ed002e,0xdca30054,0x4c9b000a}},	//   тосу, ðalk, _шаљи, _ובגו
  { {0xe4e70036,0x38a400c0,0x5afb000a,0x8afb000a}},	//   діжн, förs_, _ולהצ, _ולהז
  { {0x787000f2,0x7c380064,0x38a449cd,0x44380495}},	// [ac90] _säve, _kavr, görs_, _bar_
  { {0xc9520008,0x443802ff,0x47350484,0xe4530015}},	//   _עמי_, _car_, _знос, خضر_
  { {0x645c04f9,0xf2d00029,0x3e7a0024,0x2769002b}},	//   _dori, لآن_, lūtu_, _رشدی_
  { {0x23df0372,0x53df014e,0x4438003e,0x68ed23c0}},	//   _प्रद, _प्रश, _ear_, _kwad
  { {0x6d440007,0x81f600e5,0x443849ce,0x2ab20030}},	//   _šian, رفور_, _far_, nába_
  { {0x3e7104af,0x7c3849cf,0x443849d0,0x645c49d1}},	//   _máte_, _navr, _gar_, _gori
  { {0x60c80007,0x8fa20760,0xb4ab000b,0xef19005e}},	//   _didm, лаше, खती_, їми_
  { {0x2ab200dc,0x38b60293,0x69cd002d,0x9f450057}},	//   kába_, mære_, _ngae, _celá_
  { {0x2ab20014,0xd14b0029,0x6ab60026,0xb5fb0227}},	//   jába_, _بشأن_, _rhyf, _hlás
  { {0x6aa40293,0x31340054,0xb5fb013f,0xec76004a}},	//   _skif, _јефр, _klás, епь_
  { {0x7c380064,0x6d4249d2,0x6a860608,0xddc90045}},	//   _davr, _eroa, елна, gheţ
  { {0xdb1e0089,0xf8a9000a,0x5ee8000a,0xaf040033}},	//   áván, _הש_, _חַסְ, _шчук
  { {0x3e7a0048,0x7e69002e,0xc27a000a,0x2ab20030}},	//   gūtu_, mkep, פרשי, gába_
  { {0x30790053,0x40790053,0x7ea5002e,0x8d5a0008}},	//   לאָנ, לאָװ, rópu, _מכני
  { {0xd5b70023,0x443849d3,0x7ea5001a,0x38b600cb}},	//   ếng_, _rar_, sópu, jære_
  { {0x2a880014,0x26de0024,0x6aa4003f,0x3e7a0024}},	//   sőbb_, īto_, _ukif, būtu_
  { {0x765d01e2,0x443849d4,0xeb1f005d,0xa5260010}},	// [aca0] _dosy, _par_, _बहुत_, эмад
  { {0x7d1b022d,0xe3b20002,0xf977000a,0x7e69007c}},	//   itus, هرا_, _נגיש_, hkep
  { {0x7d1b0020,0xbb3a0053,0x645c49d5,0xb5fb49d6}},	//   htus, ּעני, _vori, _clás
  { {0xd2590036,0x44380334,0xe1f20115,0xa2260015}},	//   мці_, _war_, اسا_, عرضه
  { {0x7ea5002e,0xd0d70036,0x321a002a,0x21673589}},	//   hóps, едії_, ępy_, ници_
  { {0x442c002d,0x81430002,0xdfcf0002,0x645c008c}},	//   _úd_, انون, ميه_, _uori
  { {0x7d1b0020,0x2ab20030,0x232712ab,0x90430058}},	//   etus, zába_, _пори_, طنيه
  { {0xb65b0053,0x9f470064,0x7c38016f,0x20e00061}},	//   ִדיש, zanç_, _savr, eçiş_
  { {0x2dd70029,0xb5fb002e,0x3cf9005d,0x1dd70015}},	//   ربية_, _klár, ोंगे_, ربيع_
  { {0x60fb0008,0x70fb000a,0x0f31002b,0x7c3a02de}},	//   _מהמק, _מהמח, _چکيد, udtr
  { {0xdfcf0086,0x141b0053,0x7d1b048c,0xaf490029}},	//   _ايم_, הויב, atus, _يشمل_
  { {0x58d5005e,0x2ab20030,0xed5a0663,0x6d4249d7}},	//   комт, tába_, _ное_, _troa
  { {0x61ed002e,0x765d49d8,0x984b006b,0x7c380061}},	//   ðali, _rosy, пява_, _tavr
  { {0xd2590024,0x765d1dc1,0x2ab21754,0xb4db0144}},	//   _viņi_, _sosy, rába_, _bràn
  { {0xf7940010,0x36d50164,0x8bd7000a,0xc66b0033}},	//   гарэ, тобр, _טוגו_, пшае_
  { {0x99850015,0x25dc000b,0x69da0046,0x1634006b}},	//   _للعو, गुली_, ětec, леся
  { {0x68ed005c,0x243903ae,0x55070033,0xa3d5056d}},	// [acb0] _uwad, мпањ_, эчва, возч
  { {0xb4ab005d,0xb5fb49d9,0x38b60293,0x7bda49da}},	//   खते_, _clár, tære_, nctu
  { {0x430b0010,0x7219007a,0xf990002b,0xd37b01f3}},	//   яхам_, джер_, _نبی_, чча_
  { {0x61cb005d,0xd9f1000b,0xc2c40015,0x38b601de}},	//   िशेष, चरित_, هيلي, rære_
  { {0xe0d80036,0x229c01cb,0x865a000a,0x7d1b025d}},	//   еві_, níky_, _חדרי, xtus
  { {0x9992005c,0xc0c80054,0xa3d50004,0x7afa49db}},	//   _abyś_, нује_, _јовч, kstt
  { {0xd00e0029,0x201a0251,0x7ff40087,0xf838000a}},	//   زلي_, òpia_, اسها, גנות_
  { {0xfe45000d,0x7bda0011,0xada50033,0xc10500c3}},	//   тнио, ectu, кайл, _لوري
  { {0x7d1b159c,0x7a4200dc,0xee3604ab,0x26d3016e}},	//   utus, nítő, тны_, _luxo_
  { {0x44ef005c,0xbc62004a,0xc1b80067,0x1035002b}},	//   iż_, ивык, _ساقط_, _جبرگ
  { {0x7d1b49dc,0x9c64002b,0x3e7a003d,0x09e61eea}},	//   stus, اهپو, gūts_, конн
  { {0x7de70029,0x7ea507cf,0xc332000a,0x2c720045}},	//   _أسام, róps, בוט_, _râde_
  { {0x6fd8005d,0x4e7a01ac,0x3ead35d9,0xbdf80067}},	//   नुकू, _קאנצ, mlet_, _سرنا_
  { {0xcd760135,0x3ea005e3,0x88e3005e,0x3e7a003d}},	//   _בענק_, čite_, ржре, būts_
  { {0x44ef0050,0x26cb016e,0xb87b0030,0x07a6032d}},	//   eż_, _bico_, ppín, тавн
  { {0x7aed005c,0x224d0030,0x7d0949dd,0x6603018d}},	//   _łatw, _nnek_, ores, ипса
  { {0x26cb2001,0x7a420030,0x39360033,0x3ead49de}},	// [acc0] _dico_, gítő, _рэйс, ilet_
  { {0xb4db49df,0x386d0079,0x69c2000b,0x3c55000a}},	//   _tràn, ëert_, रेणी, כֹ֣ל_
  { {0x7d0900b8,0x3ead49e0,0x26cb49e1,0x57fb004f}},	//   hres, klet_, _fico_, _קלטו
  { {0x6d4400df,0x7791002b,0x518649e2,0x7d0949e3}},	//   _šiam, _ایفا, кула, kres
  { {0xc05a0036,0x01330029,0xd98d000a,0x51170015}},	//   дій_, لعود, ּנוֹ, نزوح_
  { {0xdc080048,0xc0130036,0xd12f0086,0x26c03aef}},	//   _mēģi, иміщ, تمه_, lmio_
  { {0x7d090014,0xceba0001,0x2ab90030,0x3ead49e4}},	//   eres, мљи_, lébe_, flet_
  { {0x8c3c0064,0x539b00f3,0x3ead30ca,0x6e440015}},	//   doğa, _חילו, glet_, انظم
  { {0x8cf30010,0x7d09240d,0x27f800bc,0x2d17002b}},	//   азыц, gres, karn_, نکوک_
  { {0xa3b9000b,0x3ead49e5,0x55bb000a,0x3ebf02f2}},	//   _चरम_, alet_, ומפו, amut_
  { {0x27f80026,0xc334000a,0xda670015,0x3ead35d9}},	//   darn_, נוֹ_, ناحي, blet_
  { {0x0e660004,0x27f827fa,0x7870007c,0x26c00085}},	//   _шкен, earn_, _räva, jmio_
  { {0x27f80026,0x2ab900dc,0x58870afa,0x5e57000a}},	//   farn_, jébe_, выва, _שידע_
  { {0x5c730036,0x58870033,0x7afa0012,0xd77700c3}},	//   _кліт, тыма, pstt, نازع
  { {0x59a50372,0xd2590024,0x26cb49e6,0x1cb7004f}},	//   _ऐडवर, _ziņu_, _pico_, _שלול_
  { {0x644e00b8,0x7f3b000a,0x4993002b,0x7a420030}},	//   _anbi, ועלו, _نیجر, títő
  { {0x44ef005c,0x65150015,0x2ab90030,0x95c40015}},	// [acd0] uż_, طوائ, gébe_, ليفه
  { {0x291e0011,0x3e71002e,0xd6db006b,0x69dd0030}},	//   ătat_, _máta_, _отм_, lcse
  { {0x3e710084,0x7a4200dc,0x93ab0015,0x3ea40079}},	//   _láta_, sítő, ذائف_, komt_
  { {0x69dd0014,0xf5e4005e,0x7a420030,0x3619000a}},	//   ncse, _вірм, pítő, _אוֹד
  { {0x3ead0064,0x764f002a,0x69dd0034,0xd14b002b}},	//   vlet_, _incy, icse, بشان_
  { {0xd12e0029,0xf3f6002b,0x7d0949e7,0x8f0001f3}},	//   سمى_, _متفک, vres, фiя_
  { {0x28da005d,0x7e770079,0xeaca0016,0x05b9000b}},	//   _यूनि, ëxpo, _kẹt_, _आरडब
  { {0x7219000a,0x02450015,0x7d0949e8,0x3ead282a}},	//   _רוּח, _حَرَ, tres, ulet_
  { {0x3ead49e9,0x61ed001a,0x3ebf49ea,0xc0ab012c}},	//   rlet_, ðalu, rmut_, _قائل_
  { {0xd2590024,0x40e8000f,0x3e710f45,0xbed500d7}},	//   _viņu_, _יַעֲ, _dáta_, _божј
  { {0xbe150021,0x5c540033,0x7c2e007c,0x26c00034}},	//   _مواع, ртыф, õbra, ymio_
  { {0x3f7a00b2,0x7d091b65,0x69dd0030,0x69aa0015}},	//   _אָדע, pres, gcse, ّاسُ_
  { {0x323600b2,0xf9920029,0x9dd6000f,0x427a000a}},	//   נטשן_, صبح_, _עוסק_, תארג
  { {0x38b6002e,0x9be70036,0xd9430001,0xe73a0256}},	//   færa_, _рідк, љери, нег_
  { {0xdc9a000f,0x4c9a000a,0xdbd1007c,0xbc1a000a}},	//   _איסל, _אבסו, _müük, _נוקש
  { {0x2ab90030,0x69dd0030,0xcb12000a,0xe5a649eb}},	//   tébe_, ccse, _הלה_, гиби
  { {0x26c0173a,0x1a9b015b,0xf98a00c3,0xa5070890}},	// [ace0] rmio_, _ריפע, _سندي_, лета_
  { {0x2ab90030,0x3957000a,0x9f4c013f,0x764f49ec}},	//   rébe_, _עשים_, _sedí_, _ency
  { {0xa3b9005d,0x1bf60053,0x2ab90030,0x420a0054}},	//   _चरण_, רצער_, sébe_, енео_
  { {0x2ca549ed,0x11d70058,0x61f60058,0x7e770546}},	//   hold_, هومة_, اساء, ëxpl
  { {0x6443001c,0x6a66001a,0x5ff42044,0xd1c90015}},	//   ônic, _hófs, азлу, نبهم_
  { {0xd8d70053,0xfe45002b,0x20d902b9,0x3e7149ee}},	//   אוסט_, یکنی, _dèi_, _ráta_
  { {0xa2e3004a,0xcf260021,0xaacf000b,0x0000006a}},	//   _госд, ارتي, _संगक,
  { {0x61ed002e,0x33930015,0x68e449ef,0xf773004f}},	//   ðalt, _الفز, _otid, מקו_
  { {0xa2a1005d,0x10160031,0xdd940033,0x61431d34}},	//   गकर्, _مباد, рапы, _лета
  { {0x1dc0005d,0x5477004c,0x3ea40723,0x2ca52cb6}},	//   शेषत, ָגטע_, somt_, gold_
  { {0x68e400df,0xfeea0015,0x69da0046,0x3861267b}},	//   _atid, _أعطى_, ěten, _rohr_
  { {0xdd000064,0x8f9b000a,0x6f79000a,0xa327000a}},	//   ştık, _איבי, _בְנו, אַךְ_
  { {0x786b0005,0x6c540083,0x8aa40010,0x1dc0000b}},	//   _hüvi, _вклу, срэд, शेशत
  { {0x6d3b013a,0x91820092,0x9f47002c,0x7e620100}},	//   _נתונ, _mềm_, vanú_, _hoop
  { {0x99990014,0x7bdb000a,0x7e6249f0,0x23c3000b}},	//   reső_, _אקוו, _koop, _वृंद
  { {0x58d5010f,0x7bcb000a,0x9f47006f,0x9f630030}},	//   _коит, _נֶגֶ, tanú_, ívét_
  { {0xd7fb0054,0xa5bb002a,0x93f50b1e,0x9e4b000a}},	// [acf0] _пун_, _zbój, ипац, עֲלִ
  { {0x4427001a,0x7e6215fc,0x66160030,0x9f4749f1}},	//   ýn_, _loop, agyk, ranú_
  { {0x998d005c,0x988c000a,0x7e6249f2,0x9f47006f}},	//   żeń_, _רָחֵ, _ooop, sanú_
  { {0xeb91000f,0xe3c40015,0xeab7000a,0x2ca50030}},	//   חָד_, حْمَ, נִ֑י_, zold_
  { {0xc5fa0008,0x21270086,0x61f949f3,0x70590033}},	//   _בפרט, ايتی_, rawl, кадр_
  { {0x216607c1,0xd00605b3,0xa3d4123e,0x1ee7009a}},	//   риши_, аеше_, _горч, هوتی_
  { {0x61ed002e,0xcee80029,0x6fcc000b,0x64740920}},	//   ðals, هرين_, ाशगं, _угру
  { {0x394900b6,0xa295005e,0x44330b9d,0xfde6006b}},	//   _oras_, _табі, lex_, адък_
  { {0x7ae406e1,0x628b08aa,0x8db50033,0x7e621002}},	//   _čita, migo, шскі, _doop
  { {0x3ea0044c,0x4c6903ae,0x69a9000b,0x443329a2}},	//   čita_, тион_, _घड़ी, nex_
  { {0xa0c40015,0x9f04006e,0x68e40085,0x394949f4}},	//   _ايلو, _هولو, _stid, _aras_
  { {0xa96a0124,0x394949f5,0x628b0a4c,0xfaa649f6}},	//   вима_, _bras_, nigo, рамо
  { {0xee780029,0xec6e3aeb,0x99750054,0x999e0046}},	//   _حصلت_, _дп_, бурш, ětů_
  { {0x290002b9,0x78700e1e,0x8c3c0061,0x5d7a000a}},	//   _vvia_, _gävl, noğl, _באנק
  { {0xe817000b,0x8c1a000a,0xe7e5000b,0x9a6a0015}},	//   _तारा_, _יוסי, कड़ा_, _لمثل_
  { {0x6d440007,0xc7a30894,0xd5b20015,0xf50609dd}},	//   _šiai, циск, قفز_, избо
  { {0x9f45002c,0xd4da0036,0x394949f7,0x20050034}},	// [ad00] _celú_, тьбі_, _gras_, _odli_
  { {0x628b0007,0x24970015,0x78fb000a,0x27010073}},	//   eigo, لنقد_, _שליפ, bėn_
  { {0x2bab005d,0xe1fa00ce,0x0000006a,0x0000006a}},	//   _घुमा, вге_,   ,
  { {0xd36f0029,0x9f4c0264,0x23090015,0xe5a60098}},	//   بهم_, _nedá_, اتلي_, _вими
  { {0x90c6057e,0x7e620601,0x10160058,0x786b0072}},	//   абде, _roop, لبغد, _süvi
  { {0x201a0020,0xe0180010,0xf1a90031,0x10f5005e}},	//   üpi_, ужкі_, دامه_, сяця
  { {0x628b1d0d,0xc7d7000a,0xa06702d9,0x0f170058}},	//   bigo, בוצי_, раја_, لغيب_
  { {0x290c005c,0x333b000a,0xd294002b,0xf2a314dd}},	//   ądaj_, _בתלמ, _اُرک, _дисп
  { {0xdcba0036,0x61ed02c1,0x69da0046,0xf8bf0003}},	//   кщо_, ñale, ětel, ltée_
  { {0xceea0036,0x2723006f,0x8c6614c2,0x4ff8000a}},	//   _адже_, nčná_, ртид, _תִּנ
  { {0xf8bf0152,0x93fb000a,0x26de0144,0x807b000a}},	//   ntée_, כליי, ítol_, _שנבצ
  { {0x1bf2005d,0xbd870086,0xfe790089,0x6fb30015}},	//   _आजकल_, انین_, chů_, _بمما
  { {0x787000c0,0xcd360086,0xdb030264,0x442a0030}},	//   _tävl, _خراب, _vyná, _obb_
  { {0x5d7b0008,0x4d7b0008,0xcd7b000a,0xe9df1279}},	//   _שָׁנ, _שָׁא, _שְׁכ, scú_
  { {0x1cbb00b2,0x4cbb000a,0x443349f8,0xf7700058}},	//   _שמוע, _שמוג, vex_, واف_
  { {0x39490467,0xaa2d00f2,0x8f9b000a,0xf7940033}},	//   _tras_, ämää_, דילי, іатэ
  { {0x6ac40029,0x05a7000b,0x55b90033,0x449901f3}},	// [ad10] _بقيم, _कुशब, угаў_, гваю_
  { {0xc3cb0029,0xeaca0092,0x25bd0061,0x628b002a}},	//   نظام_, _hẹp_, _ızlı_, wigo
  { {0x628b03af,0x389c0135,0xe3b0006e,0xeaca0016}},	//   tigo, _ביזנ, ورم_, _kẹp_
  { {0x07360053,0xf6d4002b,0x443349f9,0xdb070030}},	//   _פארם_, _گزید, sex_, ülék
  { {0xc244008f,0x95cb0001,0x628b49fa,0x0656000a}},	//   ўнік, _јуна_, rigo, _הירך_
  { {0x753d00dc,0xd7f10016,0x7084005e,0xc1080033}},	//   _issz, ữu_, огіз, рэце_
  { {0xf8bf0003,0x83340015,0x8c3c0061,0xa6fb000a}},	//   ctée_, _ورفض, roğl, דִ֖י
  { {0x17980008,0x7c2a00b8,0xd2b8002b,0xddd3006f}},	//   ידול_, _abfr, _ناقض_, ťaže
  { {0xc2120008,0x6289046a,0xddd9002a,0x20d4005e}},	//   _מהן_, _imeo, _powł, _дієс
  { {0x3e71002c,0x7d02044c,0x1017002b,0xd578000a}},	//   _táto_, _dvos, _خبرد, יתחה_
  { {0xdce70064,0x5f740015,0x7c640015,0xcaca004a}},	//   ılım, _وامر, تايل, лгое_
  { {0xc869103d,0x2d7f002a,0x753d0030,0xd356000a}},	//   _אן_, _płeć_, _ossz, צירי_
  { {0xeaca0016,0x2c69006f,0xa3d7000b,0x59a5000b}},	//   _dẹp_, _súdu_, ाखा_, _गुआर
  { {0x6ca40029,0xec78005e,0x9f43001a,0x189a0015}},	//   _وصول, _кпі_, _þjó_, اضحة_
  { {0x66e60839,0x753d0030,0xf746004a,0x656d0061}},	//   соба, _assz, щево, eyah
  { {0xaad0000b,0xf655005e,0x442a0012,0xb67900ce}},	//   _सूचक, отую, _sbb_, ащує_
  { {0x442a0049,0xba17000a,0xe3d60058,0x0000006a}},	// [ad20] _pbb_, _החפץ_, متاع,
  { {0x98a90007,0x290249fb,0xf8bf0003,0x27eb0046}},	//   _ypač_, mska_, ttée_, činí_
  { {0x1bfa0053,0xf8bf0003,0x083b004c,0x41e60033}},	//   רלעב, utée_, _געיל, біла
  { {0xfad6013a,0xd7bb0008,0xd9fa005d,0xf8bf0152}},	//   צונך_, _תצטר, ्णित_, rtée_
  { {0xf8bf0152,0x290249fc,0x6114005e,0x76440061}},	//   stée_, nska_, ідку, mdiy
  { {0xf8bf0152,0x76440061,0x290249fd,0xd00f00c3}},	//   ptée_, ldiy, iska_, فله_
  { {0x5f43003b,0x68f60026,0x444449fe,0x6eca0046}},	//   كنول, _lwyd, md_, _hřbi
  { {0x2296003b,0x32960029,0x3ea0016f,0x444449ff}},	//   _الرس, _الرأ, čito_, ld_
  { {0x68f60026,0x265b0053,0x44444a00,0x75244a01}},	//   _nwyd, רכפא, od_, ntiz
  { {0x447b0053,0x61e208b4,0x6d4b002a,0x9b940054}},	//   ָנטע, lcol, _drga, жиоц
  { {0x68f60026,0xd00f0015,0x2fd7002b,0xda350033}},	//   _awyd, _ألم_, _اومد_, оены
  { {0x6d440007,0x539b0008,0x68f60026,0x29020263}},	//   _šiau, ריטו, _bwyd, fska_
  { {0x0c730074,0xd5a7005d,0x05a7005d,0x76440061}},	//   زدید, _कुंज, _कुंब, ddiy
  { {0x44440298,0x69d600dc,0x8c430e77,0x9f470417}},	//   jd_, _egye, _нече, haný_
  { {0x44440b7c,0x1bfb0008,0x3f780008,0x4bfb01ac}},	//   dd_, _גלוב, בָּע, _גלוס
  { {0x68f60034,0xeb97000a,0x44444a02,0xd6d81f61}},	//   _fwyd, _לדור_, ed_, стр_
  { {0xc4350086,0x44440111,0x68f60026,0x9f470227}},	// [ad30] يکست, fd_, _gwyd, daný_
  { {0x44444a03,0x80dc005d,0x28150015,0xb8df000b}},	//   gd_, _पढ़े, _بودس, ेष_
  { {0x57fa000a,0x656d4a04,0xd1d90477,0x45d5257f}},	//   _דלתו, syah, адец_, _монс
  { {0x656d0035,0x73c40029,0x44444a05,0xe3c40015}},	//   pyah, سينم, ad_, سْنَ
  { {0x128a002b,0x1a9c004c,0x44444a06,0x0000006a}},	//   جمنی_, נידע, bd_,
  { {0xcee9004a,0x61e202b9,0x9475002b,0xb4d5000b}},	//   адке_, acol, _بگرا, हदी_
  { {0x6d470024,0xcf240015,0x64554a07,0x94ba000a}},	//   ājam, كريي, _inzi, _כמשת
  { {0x6289003f,0x61e2052a,0xc1050015,0xb87b001a}},	//   _umeo, ccol, _ووزي, mpíu
  { {0xec790419,0xb5fb2a0d,0xec9900af,0x0000006a}},	//   ипи_, _bláz, итој_,
  { {0xe588000a,0x3fa4001a,0x68f60034,0x29021c97}},	//   מָתָ, áruð_, _rwyd, vska_
  { {0x68f60176,0xf4120008,0x2902005c,0x6445003f}},	//   _swyd, ופי_, wska_, idhi
  { {0x5cf50036,0x29022064,0x60db0607,0x5ee8000a}},	//   _дяку, tska_, _kuum, _הַסְ
  { {0xb23a0053,0xddc21927,0x823a0053,0x29040f49}},	//   בערז, _zlož, בערצ, éma_
  { {0x38b600fb,0x7870022d,0x9f470264,0x91ba000a}},	//   mærk_, _kävi, zaný_, שמשי
  { {0x6d494a08,0x44444a09,0x2f09000a,0x66e30bbb}},	//   lvea, vd_, יִּ֑, доса
  { {0x61fb4a0a,0x29021822,0xe5060015,0x44444a0b}},	//   _neul, pska_, قبطي, wd_
  { {0x9f4704af,0x446609ef,0x76442286,0x66030033}},	// [ad40] vaný_, овав, rdiy, ьпта
  { {0x629920e3,0x44440495,0x93260015,0x75244a0c}},	//   enwo, ud_, قرصن, rtiz
  { {0x673e010b,0xd2aa0080,0x01da0029,0x3e780089}},	//   _uspj, акже_, لوضع_, _léta_
  { {0xdb9a0053,0x7229005e,0x75240b52,0x316a19a5}},	//   בסער, йців_, ptiz, ишло_
  { {0x01360029,0xa50a0001,0x61fb0026,0x61ed02c1}},	//   تعاد, _њега_, _deul, ñala
  { {0x1df2005d,0xb87b0089,0x9f4704b2,0x3ff40015}},	//   घर्ष_, spív, saný_, أكثر
  { {0xdfcf00e5,0x6e292215,0xc80b004f,0x6d4901f9}},	//   نيه_, ffeb, שִׂ֨, evea
  { {0x3e7800dc,0xddc22f2b,0x9e660015,0xa2d7000b}},	//   _béta_, _vlož, تاتن, यदर्
  { {0x3eb80024,0x467b0053,0x067b0053,0x91030099}},	//   ērt_, יװקײ, ינקל, _опте
  { {0xdca30001,0x61fb0045,0x9f5c013f,0x22464a0d}},	//   мањи, _zeul, havé_, ldok_
  { {0xee3a0080,0xddc232d9,0x33db000a,0x39404a0e}},	//   _вне_, _ulož, יחיד, _asis_
  { {0x7f3b0008,0x9f4c00f2,0xeab00015,0x22464a0f}},	//   _כעבו, _vedä_, َعَ_, ndok_
  { {0x2246005c,0x48e40010,0x2126064e,0x394d20a9}},	//   idok_, моўв, ntoh_, íes_
  { {0xfbcf0086,0x3ea90582,0x8c430001,0x26c200bc}},	//   عتی_, čate_, _жеље, _ahko_
  { {0x6443001c,0x5a470010,0x0c73002b,0xf748005e}},	//   ônim, _дэпа, _زدود, оїти_
  { {0xcb13011f,0x66090024,0x2cac0026,0x6b7b000a}},	//   _חלק_, _ķeks, lodd_, _כרונ
  { {0x3e71002d,0x95cb0254,0xd5c5000b,0x88c70015}},	// [ad50] _dáth_, рува_, लेंज, _وتخل
  { {0x61fb038d,0x2cac0026,0x18680001,0x60db0209}},	//   _seul, nodd_, _мањи_, _ruum
  { {0x3e71002f,0x2c18000b,0xb30b012c,0x29194a10}},	//   _fáth_, _दाईं_, شغال_, lusa_
  { {0x2cac0176,0x05870124,0xa4d50036,0x9f450227}},	//   hodd_, _дугм, _номі, _celý_
  { {0x865a000a,0x61fb0003,0xd13b4a11,0xb4db0144}},	//   _הדרי, _veul, рхе_, _cràt
  { {0xe0420036,0x21580015,0x493c000a,0xc918000a}},	//   енши, تجمع_, יגדו, קחות_
  { {0x2cac0176,0x9028008f,0x2919000c,0x61fb0cf9}},	//   dodd_, юцца_, husa_, _teul
  { {0xe1ff0084,0x8d650ea6,0x1ea8002b,0x2264006f}},	//   _þó_, звие, يايي_, ľská_
  { {0x2cac0176,0xfd110029,0x226401c0,0x29194a12}},	//   fodd_, رجة_, žská_, jusa_
  { {0xe820005d,0x3b850001,0x2cac0026,0x03d50008}},	//   _बाधा_, злог, godd_, ּוֹם_
  { {0xf4120053,0xcf780015,0x3b090054,0x3e71001a}},	//   עפט_, _وإما_, љемо_, _láti_
  { {0x5fba000a,0xaf340015,0x5e440015,0x29194a13}},	//   _הצענ, _تركت, _يَلْ, fusa_
  { {0x8c640086,0xcdf60008,0x4dda000a,0x3ead0079}},	//   سطین, _זמני_, _החנו, moet_
  { {0xb87b002c,0xc0ac000a,0x3c450015,0xb7da0015}},	//   dpís, ֙יךָ, _رَبِ, صورا_
  { {0x9bfa000a,0x7bfa000a,0xc654002b,0xeb96027c}},	//   _ההצט, _הפצצ, وفسک, _ниш_
  { {0xb9060063,0xe9a6022a,0xc4e60088,0x090603ae}},	//   _език, _найп, зжай, _епин
  { {0x3ae1002e,0xceb20008,0x69c2000b,0x3667030c}},	// [ad60] _hóp_, תין_, रेखी, чато_
  { {0xf507004a,0x53a60033,0xdbe301f6,0x63b5005a}},	//   янул_, пазб, _déçu, _byzn
  { {0xb7db0008,0xe7db0008,0xb87b006f,0x47f7000a}},	//   _לקיי, _לקיש, apís, _מציל_
  { {0x82890036,0xf8bf00dc,0x91e315ec,0xb6a600af}},	//   осіб_, ntén_, еоце, _химл
  { {0x25d70008,0x224600dc,0x3ead0079,0x2cac0034}},	//   _מוכן_, rdok_, doet_, yodd_
  { {0x38b6002e,0xa5050010,0x55bb0008,0xe20a002a}},	//   færi_, _ўяўл, _למכו, dróż_
  { {0x07360053,0x22160010,0x27470089,0x90290015}},	//   לאַם_, _нфар, míná_, تأنف_
  { {0x2cac0026,0x3ead0134,0x139b000a,0xe39b000a}},	//   wodd_, goet_, _הבלע, _השלכ
  { {0x443a00aa,0x2cac0034,0x76460061,0xa2d30058}},	//   oep_, todd_, _maky, _سيكت
  { {0x9588005c,0x1ab7005d,0xb1170015,0x3ae10016}},	//   ciąż, ृष्ठ, _رقما_, _bóp_
  { {0x2cac0176,0x59a5005d,0x200c0026,0x3af30033}},	//   rodd_, _गुजर, _iddi_, няўс
  { {0x2cac0026,0xcd2a002b,0x29193b23,0x7ac70033}},	//   sodd_, _هستن_, tusa_, яспе
  { {0x3d13005d,0x443a4a14,0x1ea90015,0x6480007c}},	//   _दिये_, kep_, _بالي_, _köid
  { {0xdd3b0008,0xc19b000a,0x291905eb,0x443a0085}},	//   _לעדכ, משכי, rusa_, jep_
  { {0x3ae10023,0x57a4009c,0xf7730115,0xdc8b000a}},	//   _góp_, ешта, راس_, _לְהָ
  { {0x291900dc,0x8aa40010,0xfbb70008,0xcb9b000a}},	//   pusa_, _прыд, _מפות_, _לסוט
  { {0x200c0176,0x764600d9,0xe534005e,0x29040030}},	// [ad70] _oddi_, _daky, неть, ámat_
  { {0x19b80015,0x7c3a4a15,0x78fc004f,0xb97c004f}},	//   _عطية_, netr, _הפזו, _לנחי
  { {0x04c80015,0x99820091,0x7c3a4a16,0x8c2b004f}},	//   أولي_, bekų_, ietr, מֵאֵ
  { {0xa5070010,0x63b50057,0xbb3b004c,0xd3780033}},	//   _нягл, _vyzn, מעבי, ччу_
  { {0x63b5005c,0x5045000d,0x443a0064,0x7c3a00cb}},	//   _wyzn, делб, bep_, ketr
  { {0xdb03006f,0x2d84006f,0x443a20ff,0x64c50015}},	//   _vynú, dzme_, cep_, _آيسل
  { {0x2295006b,0x8c3c0061,0x44230fc1,0x8fa21560}},	//   _живя, noğu, _icj_, каше
  { {0x9588005c,0x64470a72,0xece94a17,0x877c004c}},	//   siąż, _haji, одил_, מאוי
  { {0x64470509,0xf2d2000a,0x3ead4002,0xccc500eb}},	//   _kaji, _יעל_, roet_, мбий
  { {0xeb990001,0xc1040029,0xcc89005e,0x7c3a0599}},	//   жио_, _أولي, ібне_, getr
  { {0x290900f2,0xe37a0053,0x9a8a0029,0x64474a18}},	//   _avaa_, ַרשר, قَدْ_, _maji
  { {0xdd8e0086,0x644700f2,0x6ee70061,0x8c3c007f}},	//   اوی_, _laji, _tıbb, doğu
  { {0xda1f005d,0x76460375,0x62980003,0x6e3b16c3}},	//   _भारत_, _raky, évoi, meub
  { {0x64474a19,0x7d1b0209,0x61e90030,0x76464a1a}},	//   _naji, muus, _lfel, _saky
  { {0xa088000a,0x8b94006b,0x7c3c007c,0x5ae40015}},	//   פְשִ, _пръч, õrre, _كثيف
  { {0xfbd20008,0x8afa0008,0x6ba30045,0xbafa000a}},	//   _בתו_, _והקי, ăugă, _והקש
  { {0x97da0015,0x7d1b01be,0x64474a1b,0x443a4a1c}},	// [ad80] _وبدأ_, nuus, _baji, tep_
  { {0xe73a0124,0x61e904ed,0x3ea0060b,0x9f4c006f}},	//   _део_, _afel, čiti_, _vedú_
  { {0xc20a0018,0xb87b001a,0x366a02c8,0x04570015}},	//   ققان_, ppír, _дано_, ظلمة_
  { {0x7d1b0604,0xd2500018,0x7c3a0eba,0xe2974a1d}},	//   kuus, طنت_, zetr, мах_
  { {0xd13003c4,0x60f70010,0xa2b5000b,0xc0e3030c}},	//   امت_, днія_, ेषज्, вочк
  { {0x66044a1e,0xa0670099,0x03a607f7,0x64474a1f}},	//   laik, даља_, _жиго, _gaji
  { {0xdfd0003b,0x57fb0008,0x7337004a,0x61e90034}},	//   ديث_, קלקו, _озёр_, _ffel
  { {0x667b4a20,0x644702d5,0x941e005d,0x66044a21}},	//   ַװיג, _zaji, _पाँच_, naik
  { {0xf1a8000b,0x2d840085,0x7d1b02f2,0x0c95002b}},	//   _छँटन, uzme_, guus, کديگ
  { {0x3e780089,0x62821304,0xf55b000a,0x9f5c0046}},	//   _této_, lhoo, קדימ, laví_
  { {0xeb97000d,0x6e4700c0,0x6d5d03a4,0x2417000a}},	//   диќ_, örbä, äsar, וחין_
  { {0x39520026,0x62824a22,0x0ab40015,0xed5a2372}},	//   _brys_, nhoo, َحَد, _мое_
  { {0x984b0063,0x941e000b,0x1ea90015,0x44e4007c}},	//   оява_, _पांच_, _عامي_, _nö_
  { {0xa3c0000b,0x58d4030c,0xeb8f009a,0x0000006a}},	//   ुधा_, коят, اظی_,
  { {0xc7b8004a,0x8c1b004c,0xbb830015,0x39520034}},	//   дёт_, _וווי, _للوي, _erys_
  { {0x9f5c002c,0x0b57002b,0x64474a23,0x39520034}},	//   javí_, _آشوب_, _saji, _frys_
  { {0x395217bb,0x3e71001a,0xf9fc000a,0x0595002b}},	// [ad90] _grys_, _gátu_, _והחמ, رارگ
  { {0x3e710084,0x442b0033,0x44e40400,0x5cb8000a}},	//   _hátt_, ўцам_, _dö_, פֶּס
  { {0xa5bb002f,0xf8bf001c,0x82150015,0x81f90015}},	//   _gcón, ntém_, فواص, كفار_
  { {0xfd5e0092,0x44e400c0,0xdd14006f,0xf8bf0030}},	//   _quyể, _fö_, dĺžt, ztél_
  { {0xc616013a,0x3e71002e,0x50b504ab,0xa4e40033}},	//   _אחרי_, _mátt_, нску, _аўск
  { {0x7d1b00f2,0xc0c80054,0x61520067,0x34fa004f}},	//   vuus, мује_, انوئ, _מהשד
  { {0xfd5e0092,0x38b60595,0xd00e0015,0x9f5c0de4}},	//   _tuyể, mært_, حلى_, baví_
  { {0x7d1b00f2,0x38b601f0,0x7d0f0030,0x05c3000b}},	//   tuus, lært_, ácso, _शराब
  { {0x8c95042b,0x41770015,0xf8bf0030,0x21550033}},	//   ерні, _غارس, ttél_, _якаў
  { {0x0d82008f,0x7d1b0604,0x00d80015,0x66042621}},	//   ульн, ruus, _قبلت_, zaik
  { {0x4421017e,0x7d1b00f2,0x0c220033,0x201a006f}},	//   igh_, suus, ымэн, ópie_
  { {0x26d9018c,0xef1802e1,0x395219c3,0x6e450015}},	//   _niso_, _імі_, _prys_, _سنتم
  { {0x61190008,0xceb2000a,0x7e280033,0xfe790046}},	//   הוָה, _גיא_, _ціха_, mků_
  { {0x2d94005c,0xfe790046,0xa41e000b,0x8c420ac9}},	//   ódeł_, lků_, _पाइप_, _беше
  { {0x660424b8,0x9be40036,0x7d094a24,0x8b640015}},	//   taik, _річк, lses, _لايم
  { {0x39520007,0x9f9b007c,0xfe790046,0x7bc30085}},	//   _trys_, määr_, nků_, _iznu
  { {0x1a9b0053,0x38b6002e,0x7d094a25,0x5a9b000a}},	// [ada0] _מיקע, fært_, nses, _משקא
  { {0x7d090c8d,0xe72a0063,0x69c40024,0xa4460015}},	//   ises, _еоод_, _izie, عَاو
  { {0x7aeb0011,0x6282069b,0xbfa30016,0x660446f3}},	//   _întă, thoo, uyế, paik
  { {0x7d094a26,0x2366016f,0xb97a000a,0xdcb10016}},	//   kses, ćoj_, ּנַי, hỏ_
  { {0xfe7902d5,0x9f5c0107,0x75d60015,0xc2070015}},	//   dků_, raví_, _سيسا, رقون_
  { {0x8f46006b,0x9fe6006e,0x62824a27,0x7d094a28}},	//   ехид, رسته, shoo, dses
  { {0x37db0053,0x645c4a29,0x64a306c3,0xcfe70015}},	//   פֿגע, _inri, _сара, رفيه_
  { {0x1d340063,0x9f5e0003,0x02d60015,0x5d660788}},	//   вния, _jeté_, _ستأخ, етоз
  { {0x6280022d,0xdd900086,0xf653000a,0xe16a0015}},	//   _ilmo, شود_, רצח_, _عصره_
  { {0x3e71001a,0xeaa8004f,0x90490058,0x9f5e005a}},	//   _sátt_, _וֹ_, _يؤلف_, _leté_
  { {0x69c404ed,0xfe790046,0x8ae30033,0x8a190004}},	//   _azie, bků_, ліял, монс_
  { {0xc3330008,0x7d0901d7,0xe9d10054,0x60da0401}},	//   נור_, bses, игнy_, _hitm
  { {0xf8bf0107,0xae890015,0x4d730015,0x3a7448a8}},	//   stém_, _تخلق_, _مطور, уляр
  { {0x69c40050,0xf7730015,0xdc2a002b,0xba3b0003}},	//   _dzie, هاز_, _رسته_, roïq
  { {0x60da357b,0x77930086,0xf8bf00dc,0xdc8b000a}},	//   _mitm, ایجا, lték_, _צְדָ
  { {0xba770002,0x3bbb000a,0x9bbb000a,0x98c10061}},	//   _ساعت, _ממוד, _מצופ, ısır_
  { {0x26d94a2a,0x44b5005e,0x386d00aa,0xf8bf0030}},	// [adb0] _viso_, вбас, êers_, nték_
  { {0x44210041,0xad9d005c,0xfe790089,0x7d1d0251}},	//   ugh_, kaźn, zků_, àssi
  { {0x57670029,0xad9d002a,0x44214691,0x68b8004c}},	//   _أدخِ, jaźn, rgh_, _אלזא_
  { {0x25b90029,0xe2980036,0x7afc00dc,0xa3cd021e}},	//   _يهدد_, нає_, árty, शेष_
  { {0xfe790089,0xdced003d,0x764d0061,0x765d4a2b}},	//   vků_, ējīg, mday, _insy
  { {0x2249016f,0xf8bf0030,0x62801351,0x7d090926}},	//   žak_, dték_, _elmo, vses
  { {0xfe790089,0xb4bd000b,0x268b000a,0x60da0079}},	//   tků_, आती_, ּנִּ, _ditm
  { {0x7d090005,0x57de000b,0x375c000a,0x764d4a2c}},	//   tses, _मल्ह, לכוד, nday
  { {0x752d02d7,0x290b005c,0x2240007c,0x7bc3002a}},	//   ntaz, jsca_, õike_, _sznu
  { {0x60da0064,0x6ab600dd,0xfe790046,0x7d094a2d}},	//   _gitm, _skyf, sků_, rses
  { {0x5f790074,0x8c3c01e2,0x6ee70029,0x20074a2e}},	//   _تماس_, toğr, _أسئل, mani_
  { {0xaf340015,0x8a06006b,0x20070d06,0xf8a9000a}},	//   _حركت, ъзме, lani_, _וש_
  { {0xf2d20053,0x9f5c01c0,0x6d47003d,0x9f5e03a0}},	//   יעט_, mavá_, ājas, _reté_
  { {0xd7f20029,0x62880091,0x7e7b4a2f,0xd9430054}},	//   شكر_, _įdom, lkup, јери
  { {0x66e615bc,0x29194a30,0xfaa6004a,0x200702b9}},	//   тоба, arsa_, _иако, iani_
  { {0x20071498,0x6aa4003f,0xb9960015,0x99990046}},	//   hani_, _ujif, _للعب, cesů_
  { {0x20070455,0x7ae34a31,0xe4e5005e,0x6619002a}},	// [adc0] kani_, _hunt, гієн, ówka
  { {0xba3b0026,0xa5bb0125,0x7ae34a32,0x20074a33}},	//   mnïa, _gcóm, _kunt, jani_
  { {0xf8bf00dc,0x68e400f6,0x187b0008,0x73360029}},	//   zték_, _huid, _חטיב, ضرائ
  { {0x68e40005,0xa1f70015,0x35fa0040,0x7ae34a34}},	//   _kuid, نّما_, _تردد_, _munt
  { {0x04b60010,0x20074a35,0x7e691948,0x7e7b10cd}},	//   _асвя, fani_, djep, dkup
  { {0x443e0084,0xf1a90087,0xd00f0015,0x3ff30015}},	//   _út_, رانه_, قله_, لكهر
  { {0x389b0053,0x81fa0015,0x7ae34a36,0xd0590033}},	//   ויסנ, _يفسر_, _nunt, эрці_
  { {0xf8bf0014,0xad9d005c,0xf773000a,0x20070072}},	//   tték_, raźn, שקה_, aani_
  { {0xc693013a,0xc0e60036,0xe2970001,0x5cc60063}},	//   יאה_, _розк, _рат_, ксоз
  { {0xa0c90029,0xf8bf00dc,0x8b660015,0x60da016b}},	//   _كذلك_, rték_, ناجم, _uitm
  { {0x7ae3002f,0x441b0053,0x09bd005d,0x9b940015}},	//   _cunt, וויס, ोध्य, الجت
  { {0x68e44a37,0xbb93004a,0xeaf7002b,0xad660015}},	//   _buid, рающ, کریت_, _لاته
  { {0x68e44a38,0x99990046,0x290b00e1,0x29194a39}},	//   _cuid, resů_, usca_, ursa_
  { {0xcb540002,0x68e40161,0xa8a408c9,0xf8f40033}},	//   _منتظ, _duid, арск, рпрэ
  { {0xd6db22d7,0xa7d40015,0xc1080016,0x7ae34269}},	//   дта_, لتفص, hỗ_, _gunt
  { {0x0bb7013a,0xa3d6005d,0x20070198,0x752d04ed}},	//   _שלהם_, ाइन_, zani_, ttaz
  { {0x752d003f,0x68e41af1,0x20072411,0x764d06a2}},	// [add0] utaz, _guid, yani_, rday
  { {0x44270064,0x752d4a3a,0x97c70015,0x7ae300ac}},	//   ün_, rtaz, _لتجم, _yunt
  { {0x752d02d7,0x68e40111,0xa3cd000b,0x20074a3b}},	//   staz, _zuid, शें_, vani_
  { {0x20070445,0xf6790053,0xe2f8005e,0xe3c40015}},	//   wani_, _נאָמ, теці_, جْمَ
  { {0x95640063,0x361a0135,0x20074a3c,0xa5040138}},	//   _кърд, _אורד, tani_, _вясл
  { {0x349509e8,0xb97c0447,0x90c50033,0x9fc9257f}},	//   _сагр, ונדי, ыбле, нгла_
  { {0x20074a3d,0xd00e0015,0x61e40085,0xf838000a}},	//   rani_, سلي_, žila, דנות_
  { {0x39490005,0xdb2500dc,0x78b500dc,0xc1050115}},	//   _osas_, épít, hozv, _موري
  { {0x7ae3046c,0x7e6922a4,0xed590033,0x20074a3e}},	//   _sunt, rjep, хоп_, pani_
  { {0x6299005c,0x7ae34a3f,0x1abe000b,0x3af512ae}},	//   liwo, _punt, ोष्ठ, лямс
  { {0xb0b60053,0x68e400dd,0x39490338,0x6d46001a}},	//   _עפעס_, _suid, _asas_, ækar
  { {0x8f880008,0x68e40fb2,0xdb03002a,0xff7a004c}},	//   _בְנֵ, _puid, _synó, _אטעמ
  { {0x127a0053,0x20050205,0x72b6000a,0xad640067}},	//   גארע, _keli_, רִיב_, _ناوه
  { {0xad1a0008,0x3ebf0df4,0xb0c3000b,0x68460033}},	//   _נוצר, llut_, षतिग, ынга
  { {0x39494a40,0x2005003f,0xe7b60067,0x7c340030}},	//   _esas_, _meli_, امزد, égrő
  { {0xcf920053,0x7d1b4a41,0x8b76004f,0x200501d3}},	//   צטן_, orus, _תתקע_, _leli_
  { {0xee5c002e,0x3ebf008c,0xe9da0c30,0x1c17000b}},	// [ade0] æðið_, ilut_, _яки_, _दयाल_
  { {0x20050020,0xf484002b,0x7d1b21b3,0x61e00535}},	//   _neli_, جاری, irus, _sgml
  { {0x9bc9000a,0x6e2e0030,0x7d1b4a42,0x0000006a}},	//   תֶּ֖, őbbi, hrus,
  { {0x979b0053,0x479b000a,0xd67a0015,0xd36f0015}},	//   _טשיק, _טייס, _أحدا_, ثهم_
  { {0x9989002a,0x2005227c,0x6e94009a,0x0000006a}},	//   _zdał_, _beli_, یلتا,
  { {0x6f010026,0xc3060015,0xad9d002a,0xf8b6000b}},	//   _bwlc, _مبرو, raźl, ृतिय
  { {0xd8d70053,0x7d1b11fa,0x3ebf0012,0x66064a43}},	//   נוצט_, erus, flut_, _kekk
  { {0x644e164a,0x9757000a,0xb5fb09ae,0x6299002a}},	//   _habi, ריקו_, _inác, ciwo
  { {0xd24f0029,0xe29b0008,0x26c02a66,0x5c064a44}},	//   _عنك_, _נשמר, ilio_, ляна
  { {0x9b580083,0x6f010034,0x200501c2,0x4c940ac9}},	//   виот_, _fwlc, _geli_, риос
  { {0x644e03ac,0xa4b70008,0x2ee5003e,0x26c00007}},	//   _mabi, רליה_, _gulf_, klio_
  { {0x3ebf0003,0xddea0015,0x644e4a45,0x7d1b4a46}},	//   clut_, _أرضه_, _labi, brus
  { {0xa3d6005d,0x44381827,0xc984012e,0x26c00091}},	//   ाइड_, _obr_, бури, dlio_
  { {0xac18385e,0xf1b3000a,0x6299002a,0x644e4a47}},	//   _року_, מסר_, ziwo, _nabi
  { {0xbca30015,0x6619002a,0x78b54a48,0x67d51b5d}},	//   _دموي, ówko, rozv, рову
  { {0x26c002d7,0x35f50b75,0x758b005e,0x46f4004a}},	//   glio_, рпар, нсзв_, счёт
  { {0x65150029,0x66062716,0xd347002b,0xa8a7002b}},	// [adf0] شوائ, _dekk, گیزه_, _مصدو
  { {0x45b80139,0x8883002b,0x644e29eb,0x8cca0065}},	//   угую_, _ایسن, _cabi, _सीमो
  { {0x200516d3,0x8c1b000a,0xf3f00015,0xe6c70021}},	//   _reli_, תובי, سأل_, _متحي
  { {0xd6fa0053,0x44380026,0x4155007a,0x32b80015}},	//   _שפרכ, _ebr_, ивес, هدنة_
  { {0x98a2002a,0x9f5e006f,0xa15800e2,0x95c8071d}},	//   stką_, _detí_, лацу_, _бура_
  { {0xdc1e005d,0xe3b3002b,0xf8bf0003,0x2938004c}},	//   पलोड_, _هرز_, buée_, טאדן_
  { {0xfe710015,0x1878000a,0xb5fb0125,0x3e78001a}},	//   قدة_, רעור_, _gnác, _létu_
  { {0xfe710015,0xfee80015,0x3ebf008c,0x7d1b27f4}},	//   تدت_, دعوى_, ulut_, trus
  { {0x1e82017f,0x1138012c,0x645a016e,0xac85007e}},	//   ільм, _مثلث_, _ótic, игил
  { {0x3ebf11bc,0xec76004a,0x7d1b4a49,0x31840015}},	//   slut_, ипы_, rrus, _الكِ
  { {0x26c00026,0x5aca0a3e,0x3ebf084a,0xac380033}},	//   ylio_, клом_, plut_, учых_
  { {0xeb960080,0x93b6000a,0xc332000a,0x99860015}},	//   рию_, ילתו_, חוט_, للجو
  { {0x6606003c,0x8288000a,0xb9b30015,0xc4c5000b}},	//   _rekk, רְתֶ, ْمُع, वताओ
  { {0x26c00026,0x8d740067,0x66064a4a,0xa5bb0125}},	//   wlio_, _داما, _sekk, _gcói
  { {0x644e4a4b,0xd719005e,0xa696023e,0xf6b60015}},	//   _rabi, люті_, арај, لمسج
  { {0x26c04a4c,0x6d59002a,0x442a0123,0x443800aa}},	//   ulio_, _krwa, _scb_, _sbr_
  { {0x15ba0010,0x98a6005e,0x660600cb,0x056649a2}},	// [ae00] тывы_, _випе, _vekk, шван
  { {0x44630191,0xf8bf0152,0x26c0016f,0x33f60210}},	//   овув, tuée_, slio_, рчас
  { {0x66060005,0x57fb0008,0x644e00bd,0xf837000a}},	//   _tekk, _שלטו, _vabi, _דנית_
  { {0xc2170036,0xd25900fd,0xfd070015,0x644e0535}},	//   аєш_, лці_, _وج_, _wabi
  { {0xa06a023e,0x644e1b1f,0x201a016e,0x115412ba}},	//   када_, _tabi, ópio_, склю
  { {0x9326002b,0x3e78001a,0x75240079,0xb97b000a}},	//   _پرسن, _létt_, muiz, כנני
  { {0xa2d60086,0xf8bf0152,0x6d594a4d,0x3378000a}},	//   _نيست, quée_, _arwa, _גְּב
  { {0x9df7006b,0xc7d7000a,0x44444a4e,0x68f602dc}},	//   анът_, סוקי_, le_, _otyd
  { {0xf536000a,0x42530015,0x2259001a,0x69c0068c}},	//   ׁנֵי_, _بنقر, _óska_, ümel
  { {0x73f9000a,0x44444a4f,0x6d59002a,0x1fb62b12}},	//   ְּתו, ne_, _drwa, _ксер
  { {0xe45700b2,0xe47b0008,0x6d590b8e,0x75240079}},	//   בייט_, דריכ, _erwa, huiz
  { {0xff7b0053,0x44444a50,0xbf9b000a,0x1eda0021}},	//   _שטאמ, he_, _ביבש, _شباب_
  { {0x8cf40029,0x2e37000a,0xb8b70015,0x58d5005e}},	//   _اكتش, _כראש_, لإست, йомт
  { {0x75244a51,0x44444a52,0x8c432658,0x9f5e007f}},	//   duiz, je_, _мече, _odtü_
  { {0x7e621786,0x764f002a,0xc6d70015,0x44444a53}},	//   _knop, _pacy, لترت, de_
  { {0x9f5e04ed,0x6d4b0026,0x7bdb000a,0x8367002b}},	//   _metà_, _ysga, _בקוו, یدال
  { {0x444418b4,0x96080033,0x752441d5,0x53e70054}},	// [ae10] fe_, рэса_, guiz, ацеа
  { {0x3ea90582,0x7c28170c,0x3c78000a,0x49bc000a}},	//   čati_, ngdr, נָּב, _במחס
  { {0xf367209b,0x11f7002b,0x7e6208cf,0x23b50058}},	//   штан, لواک_, _onop, حماس
  { {0x44440176,0x4b37011f,0xd370002b,0xe290009a}},	//   ae_, שראל_, بهٔ_, وذن_
  { {0x660d0991,0x463a0053,0x27ec002c,0xe0ce0054}},	//   maak, _גערע, ždne_, зв_
  { {0x67540086,0x660d008c,0x0576000a,0x25d6000a}},	//   _اخیر, laak, _הגשם_, _לורן_
  { {0x6445003f,0xf8bf4a54,0x3f8101c0,0x5fd4006b}},	//   mehi, ltés_, áhu_, оцъф
  { {0xc3320008,0x2bba005d,0xd1090015,0x64454a55}},	//   _מול_, _उड़ा, _مقره_, lehi
  { {0x3e780084,0xf8bf4a56,0xe1f00058,0x0000006a}},	//   _rétt_, ntés_, _آسف_,
  { {0xcc890074,0x70740029,0xf8bf0152,0xe572000a}},	//   انده_, _والذ, ités_, לַת_
  { {0xbb450142,0x7524003f,0x5f790031,0x09e601e5}},	//   щенк, zuiz, _حماس_, йонн
  { {0x6d59005c,0xff50006e,0xa5c2001a,0x44444a57}},	//   _trwa, _زخم_, þókn, ze_
  { {0x444420df,0x644532da,0x499a005e,0x6d4b0012}},	//   ye_, kehi, утня_, _usga
  { {0x3ff900b2,0xfd560008,0xd9430004,0x6da40015}},	//   טפֿע, _לשני_, џери, _بمهم
  { {0x1779087a,0x9a6a0029,0xe6c60087,0xcaf500e5}},	//   асть_, _ممثل_, متري, _استب
  { {0x3f7a0053,0x07a3156b,0x9bba004c,0x6e2902b3}},	//   אָמע, часн, _עֶגז, ngeb
  { {0xc4860010,0x6d494a58,0x6e290012,0x68f600cb}},	// [ae20] блак, nwea, igeb, _utyd
  { {0xa3ea01b7,0x6e290012,0x64450374,0x44441a2a}},	//   уджа_, hgeb, gehi, ue_
  { {0x1877013a,0x0395005e,0x44444a59,0x6e294a5a}},	//   _העיר_, орця, re_, kgeb
  { {0x41d9000b,0x366a113a,0xf8bf0030,0x6e290079}},	//   _बृहस, _само_, stét_, jgeb
  { {0xdd8f005e,0xf8bf00e9,0x645b0030,0x64454a5b}},	//   _ншi_, ctés_, íció, behi
  { {0x7416002b,0xe1650015,0x6e294a5c,0xf993004f}},	//   _دوسا, تدمي, egeb, הרד_
  { {0x4386003b,0xe7fb005d,0xf8bf002e,0x48890008}},	//   _الأق, ्रता_, bréf_, שׂוּ_
  { {0x3d13000b,0x1317000a,0x01da0015,0x37a9000a}},	//   _दिखे_, _לחלל_, _موزع_, ידוּ_
  { {0xd59b00b2,0xf6530008,0xdb180107,0x98a2002a}},	//   ָביל, לצה_, _vyví, stkę_
  { {0x05770008,0xf8bf0030,0x20c90125,0x660d17f4}},	//   צגים_, mrég_, lúin_, zaak
  { {0x6fb60086,0x2d824a5d,0xe457004c,0x7f170015}},	//   _امضا, ške_, זייט_, _هيلز_
  { {0x8c180086,0x5eeb0008,0x6282310a,0x7e6200da}},	//   ديگر_, _עַבְ, nkoo, _unop
  { {0x1e57000a,0x929b000a,0xcd330067,0x6e2e0030}},	//   _לשאר_, ריכת, _فروب, őbbs
  { {0xd918005f,0x7dc50015,0x660d0234,0xadd7000a}},	//   щью_, _بتمك, waak, _הודח_
  { {0xec370008,0x62821024,0x5c37000f,0x660d3b8e}},	//   _האור_, kkoo, _הטוב_, taak
  { {0xf96b010f,0xe6940080,0xfaa40180,0x96350033}},	//   _брой_, писы, _најо, ўнац
  { {0x5499008f,0xf8bf0152,0x62821c62,0x63e70015}},	// [ae30] аваў_, utés_, dkoo, مساك
  { {0xf807023e,0xdd7b000a,0x200e001a,0xf8bf4a5e}},	//   _учин, אטמל, jafi_, rtés_
  { {0x64450019,0xe7dd000b,0x91f90015,0xf8bf4a5f}},	//   rehi, _मणिप, لفاء_, stés_
  { {0xaac9005d,0x64450020,0x62820020,0xf8bf4a60}},	//   रतिक, sehi, gkoo, ctér_
  { {0x47d50074,0xd2d40015,0xd0090004,0x7aea4a61}},	//   _ديگر, أغلب, аеле_, _luft
  { {0x7bc6005c,0x11d40002,0xb7fb000b,0x2054006b}},	//   ękuj, ستند, ्रिम_, зтър
  { {0x987c0053,0xa6fb000a,0x287c004c,0x20c9001a}},	//   ררוק, אִ֖י, רנומ, búin_
  { {0xdee2006b,0x62341e98,0x6d4900da,0x62824a62}},	//   мощи, _несу, twea, ckoo
  { {0xa0c40086,0x7aea00b8,0x6e292312,0x4d65042b}},	//   _کيلو, _auft, rgeb, іков
  { {0x9f6300dc,0xf536000a,0x6d4900da,0x6e294a63}},	//   ívót_, קנתי_, rwea, sgeb
  { {0x3940005c,0x3df50010,0x3b090001,0xbfab0033}},	//   _spis_, _дзес, јемо_, _стае_
  { {0xc86904dc,0x3a9a005e,0x4a9a0033,0x7aea1490}},	//   _בן_, ртою_, ртоў_, _duft
  { {0x6dc70029,0x3eb800dc,0xc236000a,0x7aed003d}},	//   _ازال, _írta_, חררו_, _čatu
  { {0x62890176,0x394000bd,0x7bc7001a,0x66e61a2d}},	//   _lleo, _vpis_, ýjus, жова
  { {0x869a000d,0xf8bf00dc,0x3940002a,0xaac60015}},	//   атат_, ttér_, _wpis_, _وتعن
  { {0x9586004a,0x4df9004c,0x6aad001a,0x0000006a}},	//   олбе, שפּא, _gjaf,
  { {0xe6c50015,0x39400085,0xb8d60058,0x98f60058}},	// [ae40] ستفي, _upis_, _وتخش, _بثبا
  { {0xa3d6005d,0x03a605c4,0xb97b000a,0x56f60015}},	//   ाइल_, оизо, _כנפי, _وأجز
  { {0x7ae44a64,0xb716002b,0x883b000a,0x8c1a000a}},	//   _kiit, _ببخش, _דתיו, שועי
  { {0xe2460029,0x84e3000b,0x26c40077,0x6289072c}},	//   تخطي, कआउट_, _ómo_, _cleo
  { {0x200e002e,0xc5d60033,0x78bc0079,0x3229005e}},	//   tafi_, _фінь, oorv, сієм_
  { {0x7ae40356,0x67210198,0x20c90125,0x62824a65}},	//   _liit, šlje, súin_, skoo
  { {0xdfd30033,0x865a000a,0xb67a000a,0x4e8a005e}},	//   мошы, ֹדִי, ֙רֶץ, ищим_
  { {0x7ae4022d,0x877b0008,0x8e200036,0xa9f4000b}},	//   _niit, יאצי, _вiн_, ंडोज़_
  { {0x78bc0e95,0x0dca005e,0x7536002a,0x6619002a}},	//   korv, шуки_, ntyz, ówki
  { {0x7d1d00dc,0x853b015b,0x60860015,0xb5fb4a66}},	//   ássa, סגיי, _بشرك, _anál
  { {0x7bc30176,0x54570053,0x7f4a006e,0xaa590a3e}},	//   _cynu, קסטן_, _خلاق_, бину_
  { {0xe8d90023,0xfce64a67,0x200c01d7,0x314a000a}},	//   _trị_, _додо, _hedi_, ֑תָּ
  { {0xc213000a,0x6aae0061,0x200c0061,0xdd92002b}},	//   והר_, _şofö, _kedi_, _توش_
  { {0xdfc60029,0x7aea4a68,0xa5bb0144,0x78bc0030}},	//   في_, _tuft, _ocór, gorv
  { {0x7bc30026,0x200c2296,0xc7c40c91,0x20c90125}},	//   _gynu, _medi_, дсти, dúil_
  { {0xf8bf1b89,0x07e402a3,0x95cb0aed,0x68fd156a}},	//   drée_, ьцям, ауза_, ppsd
  { {0x200c0026,0xd7e700fd,0xd371002b,0xe534034e}},	// [ae50] _oedi_, _міно, کها_, меть
  { {0x26cc0251,0x2cfb0053,0xe5700015,0x28d2000b}},	//   ïdor_, ילמא, خطف_, _दीपि
  { {0xf8bf0003,0x8c3c0061,0xc8b40058,0x38c9009a}},	//   grée_, ciğe, _تصيب, _پاکی_
  { {0x2909003f,0x7ae4001c,0x77ba000a,0x67ba000a}},	//   _kwaa_, _xiit, _למתח, _למתק
  { {0x41040010,0x1a9c0053,0x68ed00d9,0x4a5c000a}},	//   дзів, סידע, _juad, ידאו
  { {0xf8bf0003,0x6abd0034,0xc57a004f,0x0000006a}},	//   brée_, hosf, _הרשת,
  { {0xa5bb002d,0xf8bf0152,0x200c0568,0x68ed0125}},	//   _gcór, crée_, _dedi_, _luad
  { {0x64553249,0xe29f001a,0x2d951638,0x31352c63}},	//   _hazi, _öð_, зрос, _небр
  { {0x7ae400f2,0xa0c50115,0x64554a69,0xdca54a6a}},	//   _riit, _فيرو, _kazi, запи
  { {0x7ae4022d,0x11440015,0x1089004f,0x7ff40058}},	//   _siit, _تَكُ, _פָּֽ, _قسما
  { {0xbb850015,0x9f040015,0x64554a6b,0x9ee90015}},	//   سلحي, _يوكو, _mazi, _افصل_
  { {0x539a0008,0x64554a6c,0x68e5008c,0x8d770021}},	//   מיתו, _lazi, _aihd, _واشا
  { {0x68ed02c1,0x200c0064,0x0eb80087,0x7ae44a6d}},	//   _cuad, _yedi_, _بالغ_, _viit
  { {0xacfa0008,0x64554a6e,0x8d5a000a,0xcd76000a}},	//   _ההסכ, _nazi, _לכני, _מענק_
  { {0x2aa400dc,0x366a0661,0x7ae4007c,0x461a0033}},	//   rűbb_, баво_, _tiit, йцаў_
  { {0xfb1a0008,0xf8bf0140,0x61e40085,0x68ed0125}},	//   _הוקמ, vrée_, žili, _fuad
  { {0xb4d7005d,0x20c9002d,0xceb2000a,0x2917002b}},	// [ae60] ागू_, túil_, גין_, _فقيد_
  { {0xf8bf0152,0xa84a0029,0x36360086,0xd7760087}},	//   trée_, _الدم_, _کردس, _فاجع
  { {0xa87b0008,0x987b009d,0x20c9002d,0xb5fb0f1b}},	//   _האיר, _האיט, rúil_, _znám
  { {0x20c9002f,0x3d1c005d,0x01da0029,0x25ad016f}},	//   súil_, _मिले_, موضع_, _žele_
  { {0x05630033,0x64554a6f,0xa5bb0030,0x200c4a70}},	//   _звян, _fazi, _adóf, _pedi_
  { {0x6604007c,0xaf060342,0x91e30121,0x61e94a71}},	//   lbik, пчик, хоче, _egel
  { {0x43430a2c,0x200c04ed,0xddcb005c,0xe366004a}},	//   _перв, _vedi_, _nagł, _экви
  { {0x200c0b7c,0x2e4a006b,0x75244a72,0x645518d0}},	//   _wedi_, сяко_, oriz, _zazi
  { {0xe6110008,0x4e170002,0xc10600e5,0xfe6f0015}},	//   כִי_, ستيد_, _رواي, ادى_
  { {0x7c3a00b8,0xdc98005e,0x70fb000a,0xb3fa0033}},	//   uftr, івні_, _להמח, амiт
  { {0x752401c2,0x8de60058,0xcf890058,0x6abd4a73}},	//   hriz, _فكاه, _وضمن_, tosf
  { {0xe9810033,0xfa8b004a,0x602f01d3,0x0000006a}},	//   вамi_, ссой_, rőmű,
  { {0xc4be014e,0xac182f51,0x68ed08a2,0x62980003}},	//   ्ताओ, _долу_, _quad, évoy
  { {0x387a0034,0xe8d90016,0x75244a74,0x0000006a}},	//   _copr_, _trọ_, driz,
  { {0x6af30029,0xddc9016f,0xdc3b000a,0x4c3b000a}},	//   _كثير, mješ, _העור, _התוב
  { {0x64554a75,0x6ee70064,0xddc9016f,0xcb8b000a}},	//   _sazi, _kıbr, lješ, _לְחֹ
  { {0xdddb016f,0xddcb005c,0xa3df005d,0x95cb05b3}},	// [ae70] okuš, _zagł, देन_, сува_
  { {0x89340015,0x6604007c,0x26c24a76,0xc954004f}},	//   _أعيا, abik, _ekko_, _טמפ_
  { {0x92590080,0x64554a77,0xa87c000a,0x69c10061}},	//   жает_, _vazi, _לאזר, şled
  { {0x6455000c,0xc708000a,0x75240a22,0x0000006a}},	//   _wazi, _מִשֹ, briz,
  { {0xdb18022d,0x752404ed,0x69cb02de,0x865a000a}},	//   _hyvä, criz, _øged, _ודרי
  { {0xe0d30086,0xf958000a,0x1df7000b,0x26c904a5}},	//   رزش_, פסות_, ीर्ष_, llao_
  { {0xdb18008c,0xd00e0015,0x4f32009a,0xddc90160}},	//   _jyvä, جلى_, نفوذ, dješ
  { {0x69ce000b,0xc332000a,0x0000006a,0x0000006a}},	//   _सरली, _שון_,   ,
  { {0x9fe70029,0x067c000a,0x6e3b001a,0x9f5c01c0}},	//   _فساه, מנהל, rfub, mavý_
  { {0xfce5005e,0x660f4a78,0x3b850979,0x11d40058}},	//   ьопо, _leck, длог, _ستقد
  { {0xf8bf001c,0xa3d6000b,0xda0a00c3,0x5bb50248}},	//   guém_, ाइए_, ييده_, ьсиф
  { {0xedd50029,0x2f180010,0x2fc00012,0x660f1419}},	//   _قياد, _хоць_, ßige_, _neck
  { {0x3ead02ce,0x3ebf0046,0xed58005e,0x6480007c}},	//   mnet_, mout_, _ної_, _köit
  { {0x661d0bfa,0x7188000a,0x48e3006b,0x4dda000a}},	//   _adsk, פְרַ, кояв, _וחנו
  { {0x9bfa000a,0x661d00aa,0x1bfa000a,0x66040061}},	//   _והצט, _bdsk, _ולצב, tbik
  { {0x3ebf02d5,0x25f5005d,0x672100dc,0x3ead3583}},	//   nout_, एँगी_, álja, nnet_
  { {0xe5a30b0c,0xcad7000a,0x98a2003d,0x3ead4a79}},	// [ae80] вити, _קופת_, aukā_, inet_
  { {0x3ead00b8,0x67210263,0x3ebf40ae,0xc8b60033}},	//   hnet_, šlja, hout_, _іспы
  { {0x93c30011,0xa5bb00dc,0xb8e4000b,0x63030015}},	//   _ţări, _adód, ौत_, َوْل
  { {0xd1ca0afa,0xdddb0a05,0xf773000a,0x26c20696}},	//   олее_, zkuš, _סקר_, _ukko_
  { {0x8f00005e,0x3ead4a7a,0x2257009a,0x3ebf41a2}},	//   цiю_, dnet_, بلند_, dout_
  { {0x74e70036,0x660f01f1,0x8997000a,0x32e80061}},	//   _одяг_, _zeck, וכנס_, _eşya_
  { {0xddc9010b,0x20b9008f,0x3ead00b8,0x3ebf016b}},	//   vješ, чыць_, fnet_, fout_
  { {0x3ead0b30,0x539b000a,0x3ebf4a7b,0x5d540aed}},	//   gnet_, _וילו, gout_, екит
  { {0x320609cf,0xbda60015,0xbc4a247d,0x0000006a}},	//   mboy_, بحثو, очне_,
  { {0xd197000a,0x320600da,0x0000006a,0x0000006a}},	//   _חכמי_, lboy_,   ,
  { {0x3ebf0493,0xda3504ab,0xc334000a,0xddc90085}},	//   bout_, нены, עוֹ_, rješ
  { {0xbd460029,0xdddb00bd,0x0d860142,0xcfa900e5}},	//   _يناي, skuš, _олен, _عالم_
  { {0xddc9016f,0xdb18008c,0x660f00c7,0x26c002b9}},	//   pješ, _syvä, _reck, doio_
  { {0x0000006a,0x0000006a,0x0000006a,0x0000006a}},	//     ,   ,   ,
  { {0xbc670086,0xe758005e,0xe0ce0033,0x660f4a7c}},	//   _زمين_, мирі_, ывi_, _peck
  { {0x85050029,0xcf57000a,0xe8d90016,0x98a2003d}},	//   فورن, ובלת_, _trỏ_, rukā_
  { {0xf8ae0074,0x660f01d1,0xd9e3000b,0xb4d50457}},	// [ae90] شکی_, _veck, _गणित_, ежащ
  { {0xdb1800c0,0x49d80033,0x26c94a7d,0xf484006b}},	//   _tyvä, _ідэю_, slao_, кухн
  { {0x660f01d1,0xebd4000a,0x3ead4a7e,0x3ebf4a7f}},	//   _teck, תֵּי_, ynet_, yout_
  { {0xe2980191,0x661d0134,0x29193ce6,0xd324004a}},	//   має_, _udsk, ossa_, тьфи
  { {0x2919022d,0xe1670029,0x563a0053,0xd14b0086}},	//   nssa_, بداي, _צעשײ, تشان_
  { {0x7ff50074,0x29192691,0xf5360008,0x8f000036}},	//   رستا, issa_, _אנשי_, цiя_
  { {0xa295017f,0xdbd60044,0x5f770015,0x3ead4a80}},	//   _заві, _jääk, باشر, tnet_
  { {0x0000006a,0x0000006a,0x0000006a,0x0000006a}},	//     ,   ,   ,
  { {0xc0cb385e,0xdbd600f2,0x6e2600dc,0xd0110015}},	//   _дуже_, _lääk, ókba, _ملء_
  { {0xeb990001,0x3ebf0003,0x3ead4a81,0x0000006a}},	//   зио_, sout_, snet_,
  { {0x200700bd,0x29194a82,0x2056004c,0x77fb000b}},	//   mbni_, essa_, _ריעל_, ्रैक_
  { {0x2f5a000a,0x3d950aed,0x0000006a,0x0000006a}},	//   _מדענ, _пиер,   ,
  { {0xf2d20053,0x61fb003f,0x8d870015,0x20070030}},	//   טעט_, _mful, _تشان, obni_
  { {0x6c350029,0x752d02b9,0xe002000b,0xeb991411}},	//   _أفغا, duaz, रुपद_, _нил_
  { {0x2ca5002e,0xb222002e,0xfaa6070e,0x2bc6005d}},	//   mild_, _þægi, _пако, _रुपा
  { {0xc6a50054,0x69c00061,0x22b8036d,0xb7e302ed}},	//   врђи, ümes, očke_, ужск
  { {0xdc39000a,0x79660015,0x22b800bc,0x28030046}},	// [aea0] ּעֲר, _أطعم, nčke_, írné_
  { {0x6aa602de,0x68390125,0x3206072c,0x0000006a}},	//   likf, rúdó, wboy_,
  { {0x389b00b2,0xda5a000a,0xf8c70003,0x2d844a83}},	//   _זיינ, ּכְל, éées_, zyme_
  { {0x2ca535e2,0x0000006a,0x0000006a,0x0000006a}},	//   hild_,   ,   ,
  { {0xc1e70080,0x2ca500c0,0xa87a000a,0x1154033d}},	//   ньше_, kild_, ּאֶר, тклю
  { {0x1836004c,0x7e6b02f2,0x673c00bc,0x03a600af}},	//   גאַל_, _angp, otrj, _зиго
  { {0xb5fb002f,0xce940063,0xb355002b,0xa6fa000a}},	//   _snái, какъ, _لیلا_, הִ֥י
  { {0xf773000a,0x333b000a,0x433b004c,0x2d840091}},	//   רקה_, _מתלמ, _מעלב, tyme_
  { {0xc693000a,0x2ca50160,0x3d944a84,0x0000006a}},	//   טאה_, fild_, типр,
  { {0x4f962f87,0x859b0008,0x253701ac,0xd117000a}},	//   _преу, פשיו, עניש_, _נקבה_
  { {0xa3d6014e,0xab27000d,0x3d10021e,0xc43b000a}},	//   ाइट_, ноќа_, _दौरे_, התיי
  { {0xdbd60020,0xaf490029,0x9210000b,0xf8bf0030}},	//   _rääk, _تشكل_, ारिज_, grén_
  { {0x291900f2,0x612a0008,0x2e230015,0x712a000a}},	//   ussa_, הוָ֔, _صفوف, הוָ֤
  { {0x672100dc,0x3a200064,0xdbd600f2,0xfd57000a}},	//   áljo, _edip_, _pääk, _נשוי_
  { {0x2bf7000a,0x9210000b,0x69c00359,0xeaf70015}},	//   _אמון_, ाराज_, ümer, _كريت_
  { {0x752d04ed,0x44f6001a,0xf8bf0030,0x5b13009b}},	//   tuaz, _bæ_, ntéz_, _смът
  { {0xf48700eb,0x6594107b,0x0000006a,0x0000006a}},	// [aeb0] нужн, гату,   ,
  { {0xa6f50054,0x44f60052,0x39490073,0x0000006a}},	//   _изош, _dæ_, _ipas_,
  { {0xe787000d,0x0000006a,0x0000006a,0x0000006a}},	//   _чупо,   ,   ,
  { {0x44f6002e,0x78a70079,0x471a004f,0xb98b004f}},	//   _fæ_, lijv, _קורג, ּרַ֖
  { {0x69da005c,0x95cb007e,0x8234002b,0x44f62526}},	//   ęteg, _хуна_, ارما, _gæ_
  { {0x27ab000a,0x8fa54a85,0xe057002b,0xd1b800c3}},	//   ּסֵּ, кале, عیات_, رانا_
  { {0xb8820089,0xa3d42cd1,0x2eb51cc9,0xb858004f}},	//   _říka, _борч, ксис, גשוג_
  { {0x61fb0293,0x3949008c,0x78a70079,0xd1bb0015}},	//   _uful, _opas_, hijv, _فاذا_
  { {0x2d8b0107,0x6d320058,0x0000006a,0x0000006a}},	//   áce_, لفيض,   ,
  { {0x4c850036,0x2ca5118e,0x6abc0065,0x22b83405}},	//   тлов, uild_, ैत्र, rčke_
  { {0x7bca0026,0x907a000a,0xe452000a,0xc4d2000a}},	//   _cyfu, _קטעי, בֶר_, שגי_
  { {0xfeb8003b,0x780a005d,0x0f180029,0xfaa604e0}},	//   _كانت_, वर्क_, _أغلب_, тамо
  { {0x827600b2,0x6aa60123,0x7e9a000a,0x3f874a86}},	//   דערע_, rikf, _קסנו, lynu_
  { {0x7d1b0020,0x5dc8000a,0x2d82008c,0x6aa64a87}},	//   msus, _אֶצְ, äkee_, sikf
  { {0x7d1b0020,0x7bca0026,0x8cca005d,0xec36000a}},	//   lsus, _gyfu, _सीटो, _יאסר_
  { {0xcf92000a,0x98a20091,0x6be8000a,0xf484009a}},	//   בטל_, duką_, _אַפַ, گاری
  { {0xa8060063,0x9583006d,0x7d1b4a88,0xa6a90015}},	// [aec0] _изпл, алте, nsus, رافق_
  { {0x14c80074,0xe4030036,0xdbcc002e,0xf484002b}},	//   رهای_, изуп, _kóði, داری
  { {0x7d1b000c,0xe2a30092,0xddc20085,0x436a0004}},	//   hsus, _trừ_, _mnoš, ќаен_
  { {0x6b7a00b2,0xd36f06e4,0x7d1b0458,0x52750180}},	//   ורענ, تهم_, ksus, лучу
  { {0xc434002b,0xd40a0015,0x60c3272c,0x98a20091}},	//   _مکات, _يتسم_, fonm, auką_
  { {0xa3df005d,0x7d1b0abb,0x399b004c,0x70540015}},	//   देह_, dsus, וינד, انثا
  { {0xa0670054,0x2240007c,0x64a30e40,0xa8a9004f}},	//   таја_, õiks_, _тара, עֹנִ
  { {0x7d780029,0xc7b30008,0x645c47b5,0xd357000a}},	//   فمبر_, יבו_, _hari, _בילי_
  { {0x7d1b1b4a,0xdd9000e6,0x645c4a89,0x6ea1000b}},	//   gsus, صود_, _kari, गफ़ु
  { {0x01370008,0x645c4a8a,0x9f980057,0xa3df000b}},	//   _ברמת_, _jari, lším_, देव_
  { {0x6148001a,0x5fb60157,0x7d1b433c,0x39492cb3}},	//   _félö, _अखिल, asus, _spas_
  { {0x2fd70074,0x6d26008f,0xc333000f,0xdfcf002b}},	//   _شوند_, _аддз, סור_, _بيم_
  { {0x9d9a0029,0xfd380015,0xf9890015,0x8d73002b}},	//   _تنشئ_, _أكتب_, رنسي_, _ناوا
  { {0x645c4a8b,0xcb34006b,0x6d4e002a,0xa19a0033}},	//   _nari, _бекъ, łbas, яцiг
  { {0x9cd70008,0x78a70111,0x6cd90053,0x8e200036}},	//   _שווה_, rijv, _אַקצ, _вiд_
  { {0x628000e8,0x645c0035,0x9f980057,0xa5bb0030}},	//   _nomo, _aari, jším_, _adóa
  { {0x645c4a8c,0x3f87002a,0xb5d50054,0x645e0079}},	// [aed0] _bari, zynu_, ужај, fdpi
  { {0xa8550124,0x14770196,0x98a20870,0x7d1d4a8d}},	//   _скоч, خارج, tuką_, ássi
  { {0x645c19e8,0x8bd8000a,0x6e224a8e,0xfa6b000a}},	//   _dari, תַּח, _odob, ֽכְּ
  { {0x7d02008c,0x6e2201d7,0xf36409c4,0x645e00bf}},	//   _otos, _ndob, штун, adpi
  { {0x7aed0014,0x6234044a,0x645c4a8f,0x92940033}},	//   _miat, речу, _fari, шацц
  { {0xc1080010,0x759a0053,0x765d00e8,0xf4090015}},	//   тэце_, _טירח, _hasy, _سيرى_
  { {0x60c3003e,0x32bb0029,0xa3df021e,0xd346002b}},	//   ronm, _قدرة_, देश_, _میله_
  { {0x7d1b0005,0x72040029,0xb5fb002d,0x645c4a90}},	//   tsus, _نوفم, _gnát, _zari
  { {0xc2120008,0x5c150139,0x765d469f,0x50f4005e}},	//   _להן_, льну, _masy, _взут
  { {0xb5fb0089,0x7d1b1b97,0x27ec006f,0x7aed4a91}},	//   _znát, rsus, ždni_, _aiat
  { {0xf989000a,0xe452000a,0x3e350021,0xdfd100c3}},	//   _צר_, זֶר_, _مفار, _ايا_
  { {0x7d1b0020,0x765d2cf7,0x69c10061,0x3b820033}},	//   psus, _nasy, ğlen, ёляг
  { {0x7aed25d2,0xe8f72a7b,0x69c10061,0x3eba0030}},	//   _diat, лля_, şlen, épte_
  { {0x6e221212,0xe874002b,0xddc20085,0xf8bf0046}},	//   _zdob, جنسگ, _unoš, brém_
  { {0x20c9002d,0x765d00e8,0x1cba004c,0x4c3a000a}},	//   lúis_, _basy, _אמסע, _נתקב
  { {0x645c00b6,0xa6950054,0x9986006e,0x44234a92}},	//   _sari, аруј, _ملبو, _adj_
  { {0x9f980089,0x05660139,0x645c2ebb,0x62804a93}},	// [aee0] vším_, ыван, _pari, _romo
  { {0x399b0008,0x62800896,0x59aa000b,0xb4250015}},	//   _נייד, _somo, _चेयर, لعمو
  { {0x883b0008,0x9f980247,0x73360015,0xe61f0034}},	//   _אתיו, tším_, طرائ, _clôs_
  { {0x6d4b44f1,0xa25a0015,0x99990091,0x06560033}},	//   _opga, عشاء_, cesų_, _стоў
  { {0xa1582df1,0x645c3e82,0xd5750088,0xe7b3002b}},	//   талу_, _tari, _курь, _نمید
  { {0x29120026,0x7e7b0024,0xe8d90092,0xd91b000a}},	//   _mwya_, ejup, _trễ_, גוסל
  { {0x7d020050,0xb4e0005d,0x6d4b1cdb,0xb5fb002d}},	//   _stos, दगी_, _apga, _gnás
  { {0x1ef70029,0x44442903,0x91e62d8a,0xb1160015}},	//   دعوة_, lf_, _бобе, _مورغ
  { {0x7aed04ed,0x20c9002d,0xe2970f09,0x44442903}},	//   _riat, gúis_, _сат_, of_
  { {0x44444a94,0x51930015,0x8b660021,0x7aed4a95}},	//   nf_, _الكذ, هاجم, _siat
  { {0x656400f2,0x54770053,0x1bd40127,0x44444a96}},	//   hvih, אגיע_, роня, if_
  { {0xbb93004a,0x20c90125,0x6e2240ea,0x6d4b02ad}},	//   сающ, búis_, _udob, _fpga
  { {0xa80201e2,0x984b0063,0x3ea6003c,0x7aed42e1}},	//   ğınd, нява_, _imot_, _viat
  { {0x44440298,0xa80201e2,0x7aed005c,0x68f60064}},	//   jf_, şınd, _wiat, _duyd
  { {0xc4350086,0x6d404a97,0xc66b0033,0xf7940033}},	//   یکست, ltma, ншае_, барэ
  { {0x29120026,0x44444a98,0x7bd80085,0xddc90045}},	//   _fwya_, ef_, _izvu, ndeş
  { {0x99990007,0xf1a4005d,0x44444a99,0xb8eb006b}},	// [aef0] resų_, _खेलन, ff_, _пфое_
  { {0x78a5002e,0xdce207c4,0x9f5e0030,0x6d402322}},	//   _umhv, _oroč, _betü_, itma
  { {0xf367008f,0x1cbb0053,0x8c1b0008,0x36d5000d}},	//   ытан, עמבע, גובי, _вонр
  { {0xf6790053,0x44444a9a,0x6d404a9b,0x9f5e0144}},	//   _סאָמ, af_, ktma, _letó_
  { {0xe1f80010,0xe1f00015,0x8f000033,0x660d4a9c}},	//   угі_, أسم_, хiў_, mbak
  { {0x660d02df,0xc918000a,0xbf650015,0xc0c80054}},	//   lbak, נחות_, لدعو, лује_
  { {0x8fa2004a,0xd00e0015,0x1e950350,0x6d404a9d}},	//   жаще, ذلي_, ирир, etma
  { {0x92b70015,0x6d4004a3,0xc1050040,0x6d4b00cb}},	//   _إحسا, ftma, _نوري, _ppga
  { {0x212b0092,0x7e7b0d48,0xadf6000b,0x20750033}},	//   _ích_, rjup, ीड़न_, _клаў
  { {0x3ea601d1,0x10350086,0x20c90125,0x5ca509c3}},	//   _emot_, _خبرگ, rúis_, риоб
  { {0xbb452031,0x752d0089,0x60da004c,0xde950054}},	//   шенк, hraz, _סקענ, _кажњ
  { {0xfc3f0089,0xf2d20053,0x09e60404,0xbdfb0015}},	//   ří_, ַעם_, ионн, _أرضا_
  { {0x660d0134,0xa96a0001,0x88c60015,0x26de0046}},	//   dbak, њига_, لتسل, ůtok_
  { {0x00f6000a,0x752d4a9e,0xf1b2000a,0xcdb6000a}},	//   ימשך_, draz, קסם_, _דפנה_
  { {0xe616000d,0x7d094a9f,0xab760015,0x66e60015}},	//   ифаќ, lpes, _نموا_, لأرق
  { {0xfb240074,0x44440026,0xcf920135,0x6bb4005e}},	//   _اروپ, wf_, קטן_, _усіє
  { {0xa3e8005d,0x752d04ed,0x33f603fc,0x0563005e}},	// [af00] मेन_, graz, ачес, овтн
  { {0x4444018b,0xc7a6005e,0x89db000a,0x76440061}},	//   uf_, _виок, _בחפי, sfiy
  { {0xd4d50010,0x44444aa0,0xd764002b,0xd3360033}},	//   сітэ, rf_, _انجی, рэзы
  { {0xd7bb013a,0xe2460029,0x752d0264,0xf8bf0003}},	//   _יציר, شخصي, braz, bués_
  { {0x28db014e,0xc05a0036,0xdd020024,0x752d02b9}},	//   _मीडि, вій_, ērīg, craz
  { {0x01150010,0xdce206cf,0x7e0e000b,0x394d0061}},	//   сьцю, _proč, सर्ग_, çesi_
  { {0x20c9002d,0xd37200e5,0xc829000a,0x7d094aa1}},	//   túir_, _ظهر_, אֵפֹ, epes
  { {0x2a6000d9,0xe8d90016,0xdce200bc,0x7ee30015}},	//   _naib_, _trệ_, _vroč, يكون
  { {0x8c3c01e2,0xddc90064,0xf3f90045,0xfaf8003d}},	//   liği, rdeş, _şţi_, rvīm_
  { {0x6721018c,0xf3f10008,0x113b000a,0x6d404aa2}},	//   šlji, ּ֣י_, _בתמל, rtma
  { {0xcaa70015,0xa09b000a,0xee3a1adc,0xa5bb0030}},	//   لصحي, _שיבט, _ане_, _adól
  { {0x69c10064,0x66fc0089,0xa8020064,0x7f3b000a}},	//   şlem, _ačko, şıld, _יעבו
  { {0xf8bf00dc,0x0e9b000f,0xf3ff003d,0xcb67009a}},	//   nség_, _בשאל, žģis_, همیه_
  { {0x8d850086,0xdd930010,0x8c430054,0xd918004a}},	//   _دشمن, _фашы, _деље, шью_
  { {0x23a5005d,0x62980024,0x9cdb000a,0xc1d3000b}},	//   _गेंद, īvoj, _שקופ, _तर्ग
  { {0x8c3c01e2,0xeb970008,0x752d3aab,0xf8bf1f0d}},	//   diği, _כדור_, traz, tués_
  { {0x95cb0ea6,0x95d90004,0x36040015,0x752d02b9}},	// [af10] тува_, удат_, توقف, uraz
  { {0x8c3c0064,0x201c01a3,0x449804ab,0xf36715ee}},	//   fiği, javi_, авую_, итен
  { {0xa8560008,0x660a00dc,0x290b00bd,0x9327002b}},	//   _היתה_, ímké, lpca_, شران
  { {0xf8bf02c1,0x64450125,0x62350659,0x0bb70c44}},	//   pués_, sfhi, седу, סלאם_
  { {0xf8bf4aa3,0xcad8000a,0x6735002a,0x02440058}},	//   qués_, בואת_, luzj, تَنَ
  { {0x3861018b,0xb97c0053,0x77f5000b,0x290b002a}},	//   _jahr_, כנדי, _आलोक_, ipca_
  { {0x33950029,0x43850015,0xfe710015,0x66260030}},	//   _الأز, _الزق, كدة_, _átkö
  { {0x57b80008,0xdc01005d,0x87b8000a,0xc5f2004c}},	//   ילוב_, ोर्ड_, ילוס_, ּדי_
  { {0x201c0b6c,0x59d3000b,0x2a6001d7,0x8b070046}},	//   bavi_, _सरगर, _raib_, _odří
  { {0x0dc80124,0xf1dc000b,0x2a604aa4,0x201c02b9}},	//   јући_, _बरतन, _saib_, cavi_
  { {0xa0c40015,0x1fa72126,0x7d094693,0x0000006a}},	//   _بيلو, _траг, spes,
  { {0x2cac0026,0xdb1e1724,0x2a9a0015,0xc332000a}},	//   aidd_, íván, ائدة_, הוט_
  { {0xddc9016f,0x3ead4aa5,0x290d0045,0xa49b0144}},	//   ljež, miet_, ţean_, _atòm
  { {0xdd8e0029,0xc8b6004a,0xe73a2c89,0x3ead4aa6}},	//   _سوى_, ссмы, лег_, liet_
  { {0xf8bf00dc,0x2a6000d9,0xd62a4aa7,0xa6960099}},	//   zség_, _taib_, лове_, брај
  { {0x3ead4aa8,0x201c00bd,0xa3cb000b,0xfbd2000a}},	//   niet_, zavi_, _लड़_, _מתו_
  { {0x3cfa0053,0x94260010,0x98a601c5,0x94d60015}},	// [af20] ָלענ, ймае, _гипе, ميرش
  { {0xb97b013a,0x8c3c01e2,0x33f6004a,0xe97b000a}},	//   _עניי, tiği, счас, _עניש
  { {0x8c1a0008,0xa2c4005d,0x9cd6000a,0x3ead4aa9}},	//   רועי, िकल्, צועה_, kiet_
  { {0x3ead03eb,0xf8bf0014,0x8c3c01e2,0xb7db000a}},	//   jiet_, tség_, riği, _תקטי
  { {0x72430086,0xea8d0053,0x64430251,0x3ead4aaa}},	//   سپول, כנאָ, ònic, diet_
  { {0x04960029,0x2eb2005d,0xf8bf00dc,0x3ead0024}},	//   _السح, ुक्त, rség_, eiet_
  { {0xf8bf0014,0x33780008,0x2378000a,0x57d6000b}},	//   sség_, _דְּב, _דָּמ, _धरोह
  { {0x93b70008,0x877b0053,0xf7730008,0x25ad0263}},	//   _הללו_, טאצי, לקו_, _želi_
  { {0x1ee90086,0xe0490086,0x25a029c3,0xa5bb0030}},	//   جويی_, _چشمه_, nzil_, _adój
  { {0x3ead2919,0x7f1a00ce,0x0000006a,0x0000006a}},	//   aiet_, _біду_,   ,
  { {0xe47b0008,0xf8bf0152,0x547b01ac,0x3ead4aab}},	//   אריכ, nsée_, אטיו, biet_
  { {0x3ead4aac,0x7a040010,0x59aa005d,0xf8bf0003}},	//   ciet_, зярж, _चेहर, isée_
  { {0xe10b000a,0xa3e8000b,0x6ec50015,0x6ce6005e}},	//   ְּךָ, मेत_, _بتلق, _ліке
  { {0xb0ba005d,0x321d005c,0x98ab0011,0x6735002a}},	//   ेविग, zawy_, ducă_, tuzj
  { {0x48a8007a,0x8c1b000a,0x9cd7000a,0xc6d70058}},	//   стям_, _גווי, _הוגה_, مترت
  { {0x386100b8,0x151501b7,0x9f4d0003,0x0000006a}},	//   _wahr_, ждая, înée_,
  { {0x941905b3,0x84e90015,0xc6d40015,0x44f40214}},	// [af30] ижат_, لفرق_, ستفت, зпус
  { {0x3ead0048,0x3c78000a,0x7e62007c,0x7c3a4aad}},	//   ziet_, סָּב, _laop, ngtr
  { {0x321d005c,0xd3710115,0x798f0034,0x0000006a}},	//   tawy_, بها_, lycw,
  { {0x672100dc,0x7a4400dc,0xddc9016f,0x7e620264}},	//   álju, mító, vjež, _naop
  { {0x2bcf2033,0x321d005c,0x3ead3dbb,0xc1040015}},	//   _सुना, rawy_, viet_, كوني
  { {0xa0694aae,0xb938000a,0xd0060190,0x0000006a}},	//   рака_, מנדו_, оеше_,
  { {0x3ead0048,0x03090008,0x7a440030,0xa29501f3}},	//   tiet_, _כִּֽ, nító, _даві
  { {0xd1090018,0x2f54005e,0x645703f0,0x3ead01f9}},	//   _نقره_, ятіс, lexi, uiet_
  { {0x8d550036,0x361c0008,0x0c7904ab,0x3ead4aaf}},	//   ітич, אוחד, асны_, riet_
  { {0x3ead0048,0xa5bb0030,0x64574ab0,0x4b250442}},	//   siet_, _adók, nexi, омов
  { {0xfbd10029,0x2909008c,0x3ead003d,0x3f670085}},	//   بتة_, _ataa_, piet_, _uđu_
  { {0x28d2000b,0x7a440030,0x39ea0e71,0xe8d900a1}},	//   _दीजि, dító, идно_, _trớ_
  { {0x2d82003c,0x6abd0077,0x672502dc,0xbebc01ec}},	//   øket_, érfa, _avhj, _kvīn
  { {0xfc460089,0x64b8000b,0x7e621ed5,0xd70a05ab}},	//   čích_, _आदेश, _zaop, инге_
  { {0x9aa60015,0x37870fbd,0x64574ab1,0x9f29000a}},	//   _ومتو, обро_, dexi, יֵּ֖
  { {0x6e3b0509,0x6f7a015b,0xb9c60015,0x64570069}},	//   ngub, בְמו, _وتظه, eexi
  { {0x34aa0001,0xda7b000a,0xb4aa1ece,0x34860138}},	// [af40] авао_, _כנקר, аказ_, огаг
  { {0x14260036,0xe3b20115,0x67ba0015,0x5cac000a}},	//   ідем, ورا_, _ناجح_, ְׁאַ
  { {0xe1fa1179,0xf8bf0003,0xc20a006e,0x7879000a}},	//   аге_, usée_, لقان_, _הָרו
  { {0x316d018c,0x366a0001,0xf8bf0152,0x3636002b}},	//   _brez_, _тамо_, rsée_, _بردس
  { {0xf8bf0152,0xeab3000a,0x5183004a,0x41e300fd}},	//   ssée_, וֹס_, дуща, міша
  { {0xe5710008,0xa87a0053,0x7e62016f,0x2bcf021e}},	//   _אַל_, שאַר, _saop, _सुभा
  { {0x9f03002b,0x6604006f,0xfbc70015,0x987b004f}},	//   وووو, ocik, _آت_, ירסק
  { {0x66044ab2,0x75244ab3,0x01da0058,0x0000006a}},	//   ncik, osiz, _نوزع_,
  { {0x6026006b,0xdcba006b,0x75244ab4,0xc1760058}},	//   _мдаа, ищо_, nsiz, _بدأت
  { {0x628200f2,0x5577000a,0x7a440030,0x752402b9}},	//   ljoo, קעין_, yító, isiz
  { {0x0eba0010,0x93fb000f,0xd126002b,0x5457000a}},	//   _куды_, יליי, کم_, חסין_
  { {0x75244ab5,0x2d8200cb,0x442a4ab6,0x0dca2c40}},	//   ksiz, økes_, _ldb_, _клей_
  { {0xa2b2005d,0xfee90029,0x6ef50007,0xbda60015}},	//   _आगन्, _اعلى_, _išba, _بحضو
  { {0xd7f801c5,0x7a440030,0x6e204ab7,0x0000006a}},	//   жут_, tító, lamb,
  { {0x5c37000a,0xec37000a,0x5bc60015,0xaac70015}},	//   _וטוב_, _ואור_, _بتشف, _وتبن
  { {0x644e3331,0x8f9b0008,0x6e20064e,0xa5f80286}},	//   _abbi, בילי, namb, жету_
  { {0x7a4400dc,0x55070063,0x58870010,0x6e20003f}},	// [af50] sító, ючва, _дына, iamb
  { {0xd5b8017f,0xc9540135,0x0cd4000a,0x7a440030}},	//   іст_, _חמץ_, פֵּר_, pító
  { {0xd37b0010,0x32550a61,0xd498009c,0x5b3a000a}},	//   шча_, звер, црт_, שׂ֣ו
  { {0x47340033,0xf2c40015,0xc2c40015,0x52740004}},	//   _ўняс, وْلُ, ويلي, душу
  { {0x661d0024,0xcad80008,0xf67a0008,0xc617005d}},	//   _iesk, קודת_, _הארמ, तरीय_
  { {0x80a80036,0xa5bb002d,0x6282007c,0x104b0214}},	//   овів_, _ndói, ajoo, ряди_
  { {0x661d0356,0x389c000a,0xa6fb000a,0x83340015}},	//   _kesk, שיונ, בִ֖י, _يرفض
  { {0x44210931,0xc332000a,0xd7bc000a,0xdd910021}},	//   lah_, _רון_, יצור, فوع_
  { {0x2d8b038d,0x661d013c,0x7d090054,0x40350033}},	//   âce_, _mesk, љног_, _неас
  { {0xd0110029,0x1c450142,0xddd9005c,0x44214ab8}},	//   _ألا_, чном, _pawł, nah_
  { {0x2d82003c,0x764f002a,0x442100c7,0x0bb5006b}},	//   øker_, _obcy, iah_, ящия
  { {0x4a9a0010,0x6e204ab9,0xf8a9000a,0x661d4aba}},	//   стоў_, camb, _גש_, _nesk
  { {0xed580036,0x09d60010,0x44210375,0x0dcb0b1e}},	//   _мої_, яцоў, kah_, _тужи_
  { {0x20cb014e,0xcdda0053,0x2bc6005d,0x629b0026}},	//   िविध, _פֿאר, _रुका, _lluo
  { {0x8c1a0008,0x66e611c0,0x44214abb,0x6c7a000a}},	//   _הוצי, зова, dah_, _לאספ
  { {0xe7370431,0x75240064,0x6f7a004f,0x6bd60058}},	//   џет_, tsiz, זְמו, _عويس_
  { {0x9a3b0008,0xba9b0008,0x442a47d5,0xf8bf0ad3}},	// [af60] _התפק, _לסקי, _pdb_, grés_
  { {0x661d0020,0x75244abc,0xb46304ae,0x1dce000b}},	//   _eesk, rsiz, нкул, _हँसत
  { {0x77940086,0xb7fb0008,0xd7fb000a,0x656f4abd}},	//   _غیرا, _לפית, _להיל, _erch
  { {0x661d020a,0xdcb10092,0xc4c90135,0x254e003d}},	//   _gesk, hỉ_, אג_, tēlā_
  { {0x44210375,0xf8bf0003,0xe1380033,0x22b807c4}},	//   bah_, crés_, ізкі_, nčki_
  { {0x6e20003f,0xf9930053,0x6282007c,0x661d06ed}},	//   wamb, ערג_, sjoo, _zesk
  { {0x7c210014,0xb4d8005d,0x7ae400f2,0xe4510008}},	//   dalr, ाती_, _ohit, _בֶן_
  { {0x3da60191,0x2bcf005d,0xb3bb0008,0x03bb000a}},	//   зроб, _सुधा, _המלכ, _הצלל
  { {0xa3e8000b,0xd657000a,0xc27b000a,0x6e204abe}},	//   मेर_, ליקת_, _פרמי, ramb
  { {0xc19b0008,0x6e201b8d,0x219b000a,0x50650015}},	//   _השמי, samb, _הבמא, _يطلق
  { {0x6e20003f,0xba190015,0x547b004f,0xda35066a}},	//   pamb, ييدا_, צטטו, мены
  { {0xc333011f,0x44214abf,0x201e3ff5,0x3d88002b}},	//   עור_, zah_, _heti_, _وحشی_
  { {0x44210d25,0x9b43002b,0x2df40033,0x3a740033}},	//   yah_, ونیو, _ўзлё, хляр
  { {0x7ae40005,0x661d0089,0xf9900015,0xf8bf0003}},	//   _ehit, _sesk, ابَ_, vrés_
  { {0x44214ac0,0x37c5002b,0xfca9002b,0x201e0085}},	//   vah_, ذيرف, _بانو_, _meti_
  { {0x3bbb0008,0x44210375,0x8f9b0135,0x201e0844}},	//   _למוד, wah_, זילי, _leti_
  { {0xcebf0046,0x44214ac1,0x661d4ac2,0xf8bf01f6}},	// [af70] ířil_, tah_, _vesk, urés_
  { {0xd37b0063,0x656f0107,0xf8bf0999,0x201e3785}},	//   йче_, _vrch, rrés_, _neti_
  { {0xd6d1003b,0xa3e8014e,0x442119f8,0xe705002b}},	//   _لقد_, मेल_, rah_, _تسخی
  { {0xf8bf0251,0x6abd003c,0xb1840264,0xe3c40015}},	//   prés_, nnsf, _šťas, رْنَ
  { {0xf1940036,0x44214ab8,0x201e4ac3,0x61140681}},	//   ниць, pah_, _beti_, едчу
  { {0x442101c2,0x201e1c73,0x69cb01d0,0x0000006a}},	//   qah_, _ceti_, _øgeu,
  { {0x7c21003e,0x201e002c,0xcf390033,0xcee9004a}},	//   valr, _deti_, ічкі_, одке_
  { {0xee390b1e,0xbf58005e,0x2d952c63,0x629b0072}},	//   цни_, ярії_, дрос, _uluo
  { {0x4c35008f,0x62980024,0x02440015,0xe1350033}},	//   мэнт, īvot, _سَلَ, _інжы
  { {0x201e002e,0x51f40015,0xe588000a,0xbc69002b}},	//   _geti_, _أسفر, לָתָ, آمدن_
  { {0x7fb90086,0x656d007c,0x60c40125,0x5f950015}},	//   _بهار_, hvah, éime, _تلائ
  { {0x201e01c2,0xf8c60065,0x0000006a,0x0000006a}},	//   _zeti_, लक्प,   ,
  { {0x7c2903c5,0x8c451ff4,0xa3b4000b,0x08d60138}},	//   _долг_, _желе, _जेन_, дцвя
  { {0x17fa0029,0x7ae41d40,0x0136000a,0xacfa000a}},	//   ترحة_, _whit, ורשת_, _והסכ
  { {0x5c140015,0x7ae400da,0x6d494ac4,0x7e690046}},	//   _أظهر, _thit, ltea, odep
  { {0xe8d90023,0xbae60015,0xfbd2000a,0xb5fb01c0}},	//   _trở_, _تكبي, _שתה_, _znáz
  { {0x75d3003b,0x7d7a0053,0xceb20008,0x448a0054}},	// [af80] نيفا, ֿרעג, דין_, обан_
  { {0xb4d8014e,0xb9370053,0x6d49002d,0x045a0015}},	//   ाते_, _קריג_, itea, تلطة_
  { {0xa3e8005d,0xf9920086,0x69c10064,0xa87b0008}},	//   में_, _سبک_, şlet, _ואיר
  { {0x201e4ac5,0x7e694ac6,0x673c3405,0x0000006a}},	//   _seti_, jdep, murj,
  { {0xba4800df,0x66290089,0xc1040015,0x2054033d}},	//   _grįž, řský, روغي, екля
  { {0x6d49002d,0xd00f00e5,0x2bc6000b,0xcf9a01ca}},	//   dtea, لله_, _रुझा, жји_
  { {0xe29a0142,0x9f98007a,0xe81f000b,0x3cf1000b}},	//   _дав_, явку_, भरता_, ँगने_
  { {0xf1a9002b,0xb5fb0046,0x6298003d,0x60c102de}},	//   _کافه_, _snáz, īvos, _ejlm
  { {0x81460086,0x63ae0091,0x6d493d0f,0x90e600c3}},	//   _زنان, žinė, gtea, _قسطن
  { {0xe57100b2,0x2bcf000b,0xecba0058,0x0000006a}},	//   אַט_, _सुहा, تطعت_,
  { {0x764d01e2,0x40eb0008,0xaab50010,0xd4370053}},	//   yfay, _וַאֲ, ейні, וריק_
  { {0xbb930080,0x3d19000b,0x2aab005e,0xe9810033}},	//   тающ, _मौके_, ітно_, гамi_
  { {0x6d494ac7,0x0217000a,0xdd920067,0x9c860058}},	//   ctea, וחכם_, _جوش_, _يشته
  { {0x48e40010,0xddc2002a,0x29000144,0x656d0072}},	//   коўв, _mnoż, _duia_, vvah
  { {0xdc3b000a,0x7c3b000a,0xeaf8002b,0xd68b006b}},	//   _ועור, _ותוס, ثریت_, ощад_
  { {0xfaa80058,0x0000006a,0x0000006a,0x0000006a}},	//   _يهوي_,   ,   ,
  { {0x29000ade,0x99840015,0x88c70015,0x9539006b}},	// [af90] _guia_, _لليو, _يتخل, язат_
  { {0xf1b91c4e,0x2a694ac8,0x344b0138,0x656d4ac9}},	//   _neša_, _haab_, ўчан_, rvah
  { {0x656d0005,0x08760053,0x2900003f,0x98ab0045}},	//   svah, _װערט_, _zuia_, arcă_
  { {0x3619004f,0xf92b004f,0x7205009a,0x6d494aca}},	//   _מוֹד, ַוֶּ, روتم, ytea
  { {0x7e69002c,0x78b500bd,0xd1b80021,0xd0090912}},	//   vdep, oizv, واها_, пеле_
  { {0x78b5003d,0x251a000a,0x7172006e,0x3f69058c}},	//   nizv, _מושא, اهوا, зико_
  { {0xff510086,0xcef50004,0xc7aa000a,0xa3f400ce}},	//   اخت_, нчињ, ּׁפָ, _апрі
  { {0xc7f80008,0x4d650001,0x6d494acb,0xfbcf000b}},	//   וזות_, екив, ttea, _सुषम
  { {0x80da000b,0x7e694acc,0x2d9930ff,0x6d494acd}},	//   _पीके, rdep, áse_, utea
  { {0x31780015,0x6d494ace,0xa3b4000b,0xe0440054}},	//   _تحفظ_, rtea, _जेड_, _инђи
  { {0xde350010,0xc4d2000a,0x6d4932d8,0x1ee7002b}},	//   _зэль, רגי_, stea, _قوطی_
  { {0x539a000a,0x9b920015,0x6d493d32,0x78b51253}},	//   פירו, الَت, ptea, eizv
  { {0x2bcf000b,0xbd450015,0xac950174,0x0000006a}},	//   _सुरा, _أنتي, _падш,
  { {0x6f0103c0,0xdce900bc,0x3ebf00c7,0x0000006a}},	//   _kulc, oveč, lnut_,
  { {0xac740086,0x7bd80091,0x75ea0030,0xe7b6002b}},	//   _جانش, _gyvu, közé, رمرد
  { {0x3ebf4acf,0xcb12000a,0xb4d8000b,0xdce20085}},	//   nnut_, _גלה_, ात्_, _proć
  { {0x69c101e2,0x75d60029,0xcdac0053,0x3ebf4ad0}},	// [afa0] şler, ريطا, ֿיבֿ, inut_
  { {0x62990111,0x05770029,0x03a60164,0xa3be000b}},	//   ekwo, عملة_, низо, ुअल_
  { {0xdce9018c,0x083b0053,0x69cb02de,0x8afa000a}},	//   jveč, _צעטל, _øger, ִהְי
  { {0x599a0008,0x41e60010,0xe6120015,0x926700fd}},	//   ּשַׁ, ніла, _حشد_, ерша_
  { {0x26d24ad1,0x50660015,0x26c04ad2,0x3ebf0f81}},	//   moyo_, ّابِ, mnio_, dnut_
  { {0xa02a0015,0x26c00091,0x7416006e,0x3ebf00aa}},	//   سستك_, lnio_, _سورا, enut_
  { {0x82a60036,0x6f010045,0xcfd30054,0x645e4ad3}},	//   _завж, _culc, лошћ, mepi
  { {0x5d540608,0x96b8000b,0xc0aa002b,0x645e4ad4}},	//   вкит, ्कटॉ, _کارل_, lepi
  { {0x8ffa0018,0xfd0f002b,0x26c04ad5,0x0000006a}},	//   _فرار_, یجی_, inio_,
  { {0xc5f300b2,0x2a690005,0xc334000a,0x645e4ad6}},	//   נדז_, _saab_, ֣וֹ_, nepi
  { {0x34b7000f,0x645e149a,0xbf36002b,0xdb1c0061}},	//   תפים_, iepi, _سراغ, _özür
  { {0x3af40033,0x6ee54ad7,0xda670058,0x645e4ad8}},	//   ляўс, tóbe, راجي, hepi
  { {0x26c00050,0xbb47002b,0x1ea90015,0x78b5003d}},	//   dnio_, ولین_, _تالي_, tizv
  { {0x645e37e6,0x26c04ad9,0x3b54004a,0x0000006a}},	//   jepi, enio_, _аккр,
  { {0x67d52440,0x78b50030,0x645e4ada,0x0000006a}},	//   тову, rizv, depi,
  { {0x7bdb01e4,0x57f404c2,0xc6680033,0xd6d84adb}},	//   _מקוו, упст, ншуе_, ету_
  { {0x7d0200df,0xeaf8002b,0xa8020061,0x35f54729}},	// [afb0] _juos, _ثروت_, ğırd, тпар
  { {0x64a40124,0xe7870036,0x52c9000b,0xb5d40054}},	//   гађа, _зумо, िक्स, ужуј
  { {0x8c1b000a,0x7d1d0030,0x3cf1000b,0x7d0204f8}},	//   פואי, ássz, ँगते_, _luos
  { {0x46a5005d,0x21f50029,0xe716000a,0x6e222a33}},	//   _ऐतिह, نكاس, _שחרר_, _neob
  { {0x7d0200df,0x50450004,0xdd000046,0x02040033}},	//   _nuos, велб, čtěj, узін
  { {0xe1f00015,0x859a000a,0x6536000a,0xdceb003d}},	//   حسم_, _חששו, _באשף_, _orgā
  { {0x6e2200b8,0xb2ab0063,0xfe710015,0xb4bf000b}},	//   _beob, _етаж_, لدة_, ुकी_
  { {0x44234adc,0x44314add,0x6f013620,0x51870c4c}},	//   _hej_, _hdz_, _vulc, _пуза
  { {0xc05b0036,0x6ee500dc,0xdce900bd,0xd658000a}},	//   _ніж_, tóbb, sveč, תיחת_
  { {0xeb9902c4,0x1fa73589,0x116a002b,0x44230b15}},	//   дио_, _прег, _زلمی_, _jej_
  { {0x8d84002b,0xfaa6366a,0x26c00c84,0x3ebf01c0}},	//   نشین, вано, ynio_, pnut_
  { {0x645e005c,0xe6bd005d,0x2ecc005d,0xeb960080}},	//   zepi, ्कोज, ावृत, тию_
  { {0x6455044c,0xc963006b,0xbd280015,0x8e380058}},	//   _obzi, авяй, _كأول_, _أسمر_
  { {0x44234ade,0x26c00034,0xbb850015,0x25a9006f}},	//   _nej_, wnio_, _للتي, dzal_
  { {0x26c0005c,0x80480008,0x26d201d7,0x7c3c0144}},	//   tnio_, עֲשֶ, toyo_, órre
  { {0x64550eb3,0x2a360033,0xc6c3302e,0x7c234adf}},	//   _abzi, _рэкр, айск, _henr
  { {0x7e6b00b6,0xa4460001,0xf5030063,0xa2c0005d}},	// [afc0] _magp, кнад, изто, लचस्
  { {0x97da0029,0x26c000f0,0x7e6b4ae0,0x7c230030}},	//   _يبدأ_, snio_, _lagp, _jenr
  { {0xc7a60191,0xbfa50092,0xb8f60157,0x7c2301d7}},	//   _ринк, uyệ, िक_, _menr
  { {0x7e6b00b6,0xe2971899,0x99820046,0x6d5908cf}},	//   _nagp, ках_, naků_, _opwa
  { {0x44230030,0x63530046,0x40340302,0x115402ed}},	//   _fej_, věnš, гелс, уклю
  { {0x76440064,0x212d00bd,0xa1930033,0x6e220085}},	//   lgiy, _dveh_, рашч, _seob
  { {0x7d02022d,0xb17d002c,0xee86004a,0x7f840015}},	//   _suos, _vzťa, выпо, العن
  { {0x44444ae1,0x1eaa0015,0x7d021284,0x7644089c}},	//   lg_, باتي_, _puos, ngiy
  { {0xade30191,0xa2cf000b,0xdb090046,0xbd430015}},	//   ицьк, धकर्, ěným, لنيي
  { {0x7d0200f2,0x5c730a66,0x44444ae2,0xdb01005a}},	//   _vuos, альт, ng_, azlí
  { {0xdeef4ae3,0xeb97000d,0xc43b0008,0x44444ae4}},	//   _вы_, виќ_, ותיי, ig_
  { {0x7d0216fc,0x0000006a,0x0000006a,0x0000006a}},	//   _tuos,   ,   ,
  { {0xf2d300b2,0x3d1b000b,0xfe9b000a,0xeef7004f}},	//   שער_, पीआइ_, _קידמ, _סמדר_
  { {0x8bb60029,0xed57000a,0x44444ae5,0x7bb60015}},	//   _لإعا, _סבור_, jg_, _لإعط
  { {0x87040f13,0x7c2804ed,0x48a80036,0x6ee500dc}},	//   ияте, madr, ттям_, lóba
  { {0x7c28230a,0xfe0f0016,0x44234ae6,0xeab00015}},	//   ladr, hắng_, _sej_, _وعي_
  { {0x7e604ae7,0x15150033,0x55750174,0x5455018d}},	// [afd0] iemp, удзя, ыгат, лват
  { {0xb4bf000b,0x34bf000b,0x44444ae8,0xe4d90015}},	//   ुके_, ्वेद, gg_, روات_
  { {0x44234ae9,0xd795006b,0xdce9006f,0x6d402dd9}},	//   _vej_, _синъ, zveď, huma
  { {0x75d50029,0x32d40010,0x1de2005d,0xf2e4005e}},	//   _ميجا, аціс, _परंत, аючо
  { {0x6d400048,0xdd8604c9,0x44234aea,0x7e604aeb}},	//   juma, _او_, _tej_, demp
  { {0x7c28002c,0xc0c80001,0x6d400d11,0x7e6034d8}},	//   jadr, кује_, duma, eemp
  { {0x7e6b025c,0xa3e7005d,0x80a4000b,0xe084002b}},	//   _pagp, _परि_, _कतरे, شجوي
  { {0x92940010,0x6d404aec,0x660d3494,0xa2940033}},	//   _касц, fuma, ncak, _касі
  { {0x752d04ed,0x6d404aed,0xf1b7000b,0x41b7000b}},	//   nsaz, guma, _अधिन, _अधिस
  { {0x64450375,0x4c85194a,0xd335000a,0x5f450015}},	//   nghi, улов, ְרָה_, _منطل
  { {0x6d400035,0x6445002d,0x2d820c77,0x7e6b19f0}},	//   auma, ighi, äker_, _tagp
  { {0xc86901e4,0x6d404aee,0xc9aa0004,0x7c28007c}},	//   _מן_, buma, евме_, aadr
  { {0x7c2823b0,0xed59005e,0xf2d2000f,0x8d84002b}},	//   badr, _чол_, מעט_, _نشون
  { {0x91ba013a,0xf8b0002b,0x7c284aef,0xf7461cc9}},	//   תמשי, تکب_, cadr, лего
  { {0xc7950010,0xb8dc005d,0xe6c6002b,0xcc3a004c}},	//   арты, _आग_, هتري, _טעסט
  { {0x6b9c0bfa,0x07a3005e,0xe6c50015,0x64450030}},	//   ørge, щасн, لتقي, eghi
  { {0x6aa4003f,0x343a0029,0x76440f0a,0xe50600c3}},	// [afe0] _ilif, فساد_, rgiy, ابري
  { {0x74160029,0xa9b2000b,0x3942007c,0x44444af0}},	//   اوضا, ीपीए, muks_, ug_
  { {0xd62a0063,0x6d400011,0xe29a0b75,0xc3050015}},	//   _поне_, zuma, наж_, لبنو
  { {0x44440026,0x64454af1,0x7e604af2,0x9c7c0046}},	//   sg_, aghi, xemp, mlče
  { {0x39420020,0xc434002b,0x8936000a,0x7e600696}},	//   nuks_, _نکات, רָ֣א_, vemp
  { {0xc9530008,0x6aa40026,0x141a0015,0x8857004c}},	//   צמו_, _llif, _سيرة_, ָשקע_
  { {0xc294002b,0x3942007c,0xb7fa000a,0x7e604af3}},	//   _پیشب, huks_, ׂפְת, temp
  { {0x39420005,0x1d34250c,0x7c28002a,0xed8a044a}},	//   kuks_, ания, wadr, есок_
  { {0x22930029,0x91e30036,0xc6930008,0xdd900087}},	//   _القس, _готе, מאה_, زود_
  { {0xfc460089,0x7e604af4,0x6aa4179a,0x3942007c}},	//   _číst_, semp, _alif, duks_
  { {0x5457004c,0xf8bf0030,0x6aa407a3,0x6d404af5}},	//   נסטן_, ssék_, _blif, suma
  { {0x6aa402b1,0x22462941,0x7c284af6,0x6d404106}},	//   _clif, ngok_, sadr, puma
  { {0x7e7b004c,0xdebb015b,0x3942007c,0x7e0b000a}},	//   _ראדז, _אמאל, guks_, _אִוֶ
  { {0x2a6d0089,0xd71b0015,0x6aa4233b,0x0000006a}},	//   žeb_, فترض_, _elif,
  { {0xa3b4005d,0xe78401e5,0x1cb70447,0x62804af7}},	//   _जेल_, буто, _גלגל_, _onmo
  { {0x7d0d002d,0x6beb0008,0xa3d8000b,0x7bc60061}},	//   _éasc, _אַחַ, ाथन_, şkus
  { {0x660d0375,0x7aed02f2,0x29040046,0x44b51356}},	// [aff0] rcak, _ihat, ímat_, абас
  { {0x628000fb,0x752d04ed,0x95d80080,0xdb080030}},	//   _anmo, rsaz, удут_, ezdé
  { {0x04c80029,0x752d02b9,0x7aed0a3d,0x64454af8}},	//   دولي_, ssaz, _khat, rghi
  { {0x27fc0046,0xe298005e,0x979a004f,0x0000006a}},	//   ůzné_, лає_, _ישתק,
  { {0x1af8004c,0x7aed0034,0xe0d10015,0xca38000a}},	//   אמאל_, _mhat, يزت_, רנדה_
  { {0xe53a0008,0xf487022a,0xc9b8000a,0x10a20054}},	//   _בתשר, _сумн, נהגת_, жишн
  { {0x2898000a,0xafe5005e,0xa87c000a,0x987c004f}},	//   רדון_, шокл, תאור, תרוק
  { {0x8d550a61,0xed59194a,0x02450015,0xdd9100c3}},	//   аточ, вои_, _خَرَ, قوع_
  { {0x31580029,0xc0470029,0x98a2005c,0x710b005e}},	//   _مجلة_, _مخاو, lską_, _їхав_
  { {0x929d002a,0x8b070046,0xbebc003d,0xaa7b0046}},	//   _biłg, _neří, _svīt, ylýc
  { {0x9bd40010,0x6a8606ac,0xf989000a,0x4c82005e}},	//   йцюш, ална, _קר_, ілюв
  { {0x39420005,0x7f4304ed,0x03d6000a,0xbca5002b}},	//   tuks_, munq, יותם_, امگي
  { {0x7f4304ed,0x7aed0125,0x0000006a,0x0000006a}},	//   lunq, _dhat,   ,
  { {0x8f000036,0x8c42006d,0x98b9003d,0xfd56000a}},	//   цiї_, _деше, tusā_, _כשני_
  { {0x4cba0008,0x39420020,0x1cba0008,0x98a2005c}},	//   _במסג, suks_, _במסע, jską_
  { {0x39420020,0xa6950054,0xb5c6008b,0x7aed28a7}},	//   puks_, бруј, айбл, _ghat

  { {0x94260080,0xa507006b,0xe9df0077,0xe9da0004}},	// [b000] имае, иета_, lgún_, _јкп_
  { {0xa99b000a,0xd70a004a,0xb4250021,0xc4830c30}},	//   _סביר, _иное_, معمو, олук
  { {0xa3d3005d,0xe9df02c1,0xa2060010,0x73360015}},	//   _हुआ_, ngún_, апед, شرائ
  { {0x5b560053,0x0000006a,0x0000006a,0x0000006a}},	//   ישען_,   ,   ,
  { {0x61e9005c,0x27f60046,0xe297012e,0x7cef02de}},	//   _czel, ženě_, јач_, mørf
  { {0x61e90024,0xd0d7005e,0x64a63188,0x2612000b}},	//   _dzel, адії_, _тага, धुरी_
  { {0x8fa30001,0x1ee9002b,0x61e94af9,0x0000006a}},	//   жаје, گويی_, _ezel,
  { {0x7ed30015,0x73f9004c,0xe29700e2,0x62804afa}},	//   يزيا, _תּשו, _кас_, _unmo
  { {0xe9df02c1,0x7aed0034,0x1ee9002b,0xe2970bb1}},	//   egún_, _rhat, دويی_, _тат_
  { {0x7aed26b0,0xd00f0058,0x0000006a,0x0000006a}},	//   _shat, _يلق_,   ,
  { {0xb47900b2,0xe47900b2,0x9e6605cb,0x7aed0034}},	//   אָרי, אָרש, _введ, _phat
  { {0xd90f0086,0x7d7a0015,0x6e930015,0x4fbb000a}},	//   ویب_, _لمصر_, _وللا, _בצבא
  { {0xa3d3005d,0x1e57000a,0xc27b000a,0x1ea90021}},	//   _हुई_, _כשאר_, דרכי, _حالي_
  { {0x7aed003e,0xdb0100dc,0x98b90011,0xdfc60029}},	//   _what, szlá, dusă_, كي_
  { {0xd8c80010,0x787c00c0,0x7c650086,0xd6db09e5}},	//   рыяд_, _såvä, _دانل, вта_
  { {0xabfb000a,0x9bfb000a,0x75e70033,0x63700030}},	//   _בהור, _בהוט, аўзе, zóná
  { {0x98a2005c,0x04c900e6,0x38c9002b,0x442b0920}},	// [b010] wską_, هوري_, _مادی_, вцем_
  { {0x6abd0084,0xe5c4042b,0x44274afb,0x929d002a}},	//   lisf, істо, ún_, _miłe
  { {0x61e912e0,0xd37100a2,0xf8b2004c,0x8c1b000a}},	//   _szel, ثها_, _זשי_, דובי
  { {0xddc90011,0xd3780010,0x98a2005c,0x01350015}},	//   ndeţ, шчу_, rską_, معتد
  { {0xe1670001,0x61e00034,0x63700030,0x27250034}},	//   рђен, _cyml, tóná, lŷn_
  { {0x41744257,0x2bcf005d,0xe0d80036,0xf3170086}},	//   غانس, _सुझा, аві_, _نظرخ
  { {0x3ea60134,0xd00e00a2,0xf83800f3,0x10480342}},	//   _blot_, رلي_, בנות_, рячи_
  { {0xa3d3005d,0x6ee5005c,0x29010020,0x1e853023}},	//   _हुए_, róbo, _liha_, слим
  { {0xf2d200b2,0x17e4000b,0xdfd1002b,0x6abd02b9}},	//   _זען_, _गर्व_, _کيا_, disf
  { {0x8d540010,0xddc90045,0x290135f9,0xb5470033}},	//   ітыч, edeţ, _niha_, улiс
  { {0x60da0053,0x1a2a0004,0xcf25002b,0x3ea64afc}},	//   _עקענ, лжни_, _چرچي, _flot_
  { {0xe8b2000b,0x8e740015,0xd35a000a,0xdb060030}},	//   ुच्च, _وانض, נדרל, émáh
  { {0xceb2000a,0x88c60015,0x99d60015,0xee78002b}},	//   _ציד_, متسل, إتجا, _خصلت_
  { {0x6abd002e,0x9620000b,0xdc35004c,0xad1a000a}},	//   érfr, बर्ट_, _האַט_, _עוצר
  { {0x31ae00dc,0x2bcf000b,0x78bc3399,0xc7a3067a}},	//   _közé_, _सुचा, rirv, пирк
  { {0x59860036,0xf7430180,0xcb36004f,0x7d1b4afd}},	//   _глиб, џето, _האקי_, opus
  { {0xf5ea004a,0xe45a009b,0xe57a0138,0x0000006a}},	// [b020] умал_, лжа_, ыза_,
  { {0xc5d50010,0x98b90045,0xf9b7000a,0x141a0015}},	//   цісь, rusă_, _להפך_, ايضة_
  { {0x28970008,0x37750010,0xc7b90033,0x61e00034}},	//   _הדין_, _дыяс, _вёў_, _syml
  { {0x200502d7,0x98b90011,0x25f0000b,0xcb12000a}},	//   _agli_, pusă_, _आरपी_, פלד_
  { {0xb1130029,0xc05a017f,0xfc45006f,0xa1130015}},	//   كونغ, гій_, _číne_, كونت
  { {0x987a0053,0x94072b44,0x3ea64afe,0x61e0005a}},	//   ראַט, _герб_, _slot_, _vyml
  { {0x3ea64aff,0x2ef4005e,0x987b004c,0x30770015}},	//   _plot_, озкр, טאסט, صحوة_
  { {0x442a4b00,0x200504ed,0x66f8005d,0x539b0008}},	//   _heb_, _egli_, ंगिक_, _גילו
  { {0x3a2900da,0x7c3c0077,0xc106009a,0x3ea60546}},	//   _reap_, órro, _طواي, _vlot_
  { {0x442a0024,0xd12f0015,0xdce20085,0x0000006a}},	//   _jeb_, _أمل_, _prođ,
  { {0x645c002d,0xef1a0a21,0x799d0034,0x6fa50015}},	//   _mbri, _сме_, wysw, _وإمك
  { {0xe8d90092,0xe9f90036,0xa9790033,0xddc90045}},	//   _trừ_, инні_, айму_, udeţ
  { {0x588704ab,0x98a2002a,0xddc90045,0x645c4b01}},	//   быва, lskę_, rdeţ, _obri
  { {0xac1823dd,0x6da30001,0x60c4002d,0x2d9900f2}},	//   _току_, _хиља, éimh, äsee_
  { {0x49930086,0xe7840054,0x6ef50091,0x290105ff}},	//   زیگر, путо, _išbr, _viha_
  { {0x59da005d,0x645c4b02,0x6d403a14,0x0000006a}},	//   _युवर, _abri, orma,
  { {0xe6940080,0xd4b907c1,0xca38000a,0x65150015}},	// [b030] читы, алац_, _הנחה_, زوائ
  { {0x6d404b03,0x9874055f,0x69da0045,0x7c2a2a88}},	//   irma, _ельц, ştec, _jefr
  { {0x442a4b04,0x6d404024,0x64430144,0x9888000a}},	//   _deb_, hrma, òniq, _הָרֵ
  { {0x645c0026,0x7cef0134,0x77ba000a,0x91190033}},	//   _ebri, pørg, _כמתח, ацку_
  { {0xd13b004a,0x442a0a25,0x7c383637,0xda4c004f}},	//   ухе_, _feb_, _odvr, אֲוָ
  { {0xb608099c,0xe3b30021,0x00c8008b,0x7c2a4b05}},	//   _vyšš, _فرز_, блік_, _nefr
  { {0x389c0008,0x02450015,0x889c000a,0xd00e0015}},	//   ריונ, _وَسَ, רבוי, خلى_
  { {0x645c0582,0xf99f0251,0x4421002d,0x82370067}},	//   _zbri, ncès_, lbh_, _درسا
  { {0x4421002f,0xa2d6005d,0xa5bb00dc,0x7d090001}},	//   obh_, यकर्, _adóz, јног_
  { {0x3c650080,0xe58c000a,0xf8bf0003,0x44210125}},	//   цког, רָהָ, isés_, nbh_
  { {0x4421002d,0xda664b06,0x7cef003c,0x6008000a}},	//   ibh_, овни, jøre, _הִנְ
  { {0xc332013a,0x4fd600b2,0x6f0202d7,0x7d1b4b07}},	//   ווט_, _וועב_, _gioc, ppus
  { {0xdce9010b,0x38c80086,0xc1b7005d,0x3d8a0086}},	//   jveć, ماسی_, _अधोग, _نحوی_
  { {0x7cef0293,0x7c2a04de,0x7188039e,0x25dd000b}},	//   føre, _gefr, צְרַ, _खड़ी_
  { {0x7d0b002e,0xfcf80053,0x7cef0134,0x44210125}},	//   _hugs, _פּױל, gøre, dbh_
  { {0x443801d7,0x442a04f6,0x7d034b08,0x3ead4b09}},	//   _sdr_, _seb_, _hins, nhet_
  { {0x6e2b00dc,0x64360029,0x54360031,0x7d040125}},	// [b040] _megb, قراء, قرار, _éist
  { {0x7d03000c,0x27ed0089,0x98b90007,0xfe790089}},	//   _jins, řena_, tusą_, dlům_
  { {0x3ead02d2,0x33660015,0xf206004a,0x36060015}},	//   khet_, تهاف, ояло, _وودف
  { {0x4b4c00b2,0xf99f0152,0x4421002d,0x71660015}},	//   רגאַ, ccès_, abh_, قاتك
  { {0x64430c98,0x2257002b,0x6f020125,0x442a0542}},	//   ónic, تلند_, _rioc, _teb_
  { {0x3ead00dc,0x297b0008,0x14d8000a,0xe3b20015}},	//   ehet_, יטנא, _הַֽמ, _قرأ_
  { {0x7d0b0048,0x6f0210e0,0x7c2a330e,0x60cd0125}},	//   _augs, _pioc, _refr, éama
  { {0x7d03038d,0x3ead1edc,0x63a30293,0x179b000a}},	//   _ains, ghet_, ønne, ייצב
  { {0x9df70063,0x6e390026,0x6fda021e,0x24980030}},	//   онът_, _ddwb, _पुरू, _korm_
  { {0x26c9016f,0x7d034574,0x3cf6000b,0x55bb000a}},	//   znao_, _cins, ीदें_, ימפו
  { {0xf4130008,0x5c310086,0xe0430036,0x6f020125}},	//   ופת_, رکوز, _інци, _tioc
  { {0x7d033ed4,0xddc90091,0x7c2a0034,0xed5a4b0a}},	//   _eins, sdeš, _wefr, _вод_
  { {0x59c50015,0xed570033,0x7d034b0b,0x0000006a}},	//   سيسك, _моц_, _fins,
  { {0xf7730087,0x7cef0293,0xbce60015,0xb08a000a}},	//   واز_, tøre, _بأصو, ׁנָ֖
  { {0x262b0054,0xe7a8004a,0x8c1b05bd,0xeabf02b9}},	//   ицао_, овёл_, _דווי, più_
  { {0x7d030ec2,0x7cef0595,0x69da0045,0xab830342}},	//   _zins, røre, ştea, _цушк
  { {0x261a000b,0x5a9c000a,0x8e97000a,0x20bc0065}},	// [b050] बड़ी_, _כשהא, קדמו_, ्चाध
  { {0x3ead00dc,0xde8f0092,0x44f4017f,0xd37b364e}},	//   zhet_, _kịch_, дпус, иче_
  { {0x4421002f,0xf8bf0152,0x656f005c,0xdce9016f}},	//   rbh_, ssés_, _wsch, sveć
  { {0x656f4b0c,0x6ee5002a,0x130800fd,0x0000006a}},	//   _tsch, róbk, іній_,
  { {0xde8f0023,0x442100d9,0xe4a705e6,0xbbc7000b}},	//   _lịch_, pbh_, _дрво, _लश्क
  { {0xc5fa0008,0xccf80089,0x249825f3,0x45fa000a}},	//   _לפרט, jmě_, _gorm_, _להרג
  { {0x3ead4b0d,0x4424005e,0xbea5006b,0xbf680015}},	//   thet_, _ієра, зайк, قصيم_
  { {0xccf80089,0x764d11ac,0x7d034b0e,0xf1b9003d}},	//   emě_, ngay, _sins, _sešu_
  { {0x41770086,0x656d0012,0x23a0003d,0x31790030}},	//   _بازس, nwah, _vājš_, _ész_
  { {0x34960008,0x99801071,0x2ca90a2b,0x6e2b02f7}},	//   ִ֣ים_, _afiş_, скоп_, _wegb
  { {0x7d0309f0,0xcb690063,0xa2f500a3,0xc949000a}},	//   _vins, щане_, ּמָה_, _תמ_
  { {0xde8f0023,0xa96a057e,0xe1e700c3,0x25a001d7}},	//   _dịch_, бима_, فس_, yyil_
  { {0x49990080,0x6ed30011,0x290f0152,0x6e9200c3}},	//   отря_, răbd, _égal_, _سلوا
  { {0x23bd014e,0xad1a0008,0xa3ab000b,0xb7fa000b}},	//   ्पाद, _הוסר, गना_, ूशलम_
  { {0x1779005f,0xfaa64b0f,0x8c1a000a,0x86ea0015}},	//   ость_, _нако, _פוקי, معرف_
  { {0x8b3a013a,0x784e00dc,0x46f50036,0x6b9c00c0}},	//   _התקצ, _bőví, дчут, ärge
  { {0x2f11002e,0x39130015,0x850600c3,0x656d4b10}},	// [b060] _lág_, _كويز, سوان, gwah
  { {0x7e690111,0x6aac000b,0xb97b000a,0x897b000a}},	//   heep, _चतुर, _פניי, _פריצ
  { {0x389b103d,0x35fa0086,0xb89b000a,0xf529000f}},	//   _היינ, _گردد_, _הביש, רץ_
  { {0x87170008,0x24984b11,0x929d0535,0x644b0073}},	//   _מקטע_, _worm_, _piła, ėgia
  { {0x3a370008,0xc2190036,0x05550457,0x867b000a}},	//   פרסם_, ієї_, _отря, _הרכו
  { {0x7109005e,0xd3780160,0x0000006a,0x0000006a}},	//   іхів_, _šću_,   ,
  { {0xa8570008,0xc6b6000a,0xb17d04b2,0x0000006a}},	//   פיקה_, ּהִי_, _vyťa,
  { {0x877b00b2,0x333b000a,0xf773000a,0xd357000a}},	//   מאצי, _לתלמ, תקה_, _מילי_
  { {0x5046008f,0x61430925,0x41260040,0x60e90052}},	//   _неаб, _пета, _رفاق, ðsmö
  { {0xd00f0029,0x2f11002d,0x718b0008,0x0137000a}},	//   _ملك_, _fág_, _לְבַ, _מרמת_
  { {0xe4570053,0xccf80089,0xa06707be,0x5ba3009b}},	//   הייט_, rmě_, _хаха_, еряз
  { {0xdcfc0061,0xbd6a0054,0xfeea0058,0xdc02005a}},	//   ıyıc, _грке_, _اعطى_, _učím
  { {0x69da0011,0x5eeb000a,0xc9870054,0xc98400c2}},	//   şten, _הַגְ, чуни, нури
  { {0xddeb00b2,0xde8f0023,0x7dc50029,0xdde90086}},	//   _פֿאָ, _tịch_, _تتمك, _برمه_
  { {0x6c5b0008,0x7b060089,0x5c5b000a,0xfc5b000a}},	//   _הדוח, ístě, _הדוק, _הכומ
  { {0xe8d90092,0x27ed0089,0x1ae407c1,0x56941236}},	//   _trữ_, řeno_, _појм, наст
  { {0xba740086,0x54990010,0x764d0375,0x44990033}},	// [b070] _سايت, оваў_, rgay, оваю_
  { {0x87070010,0x656d0012,0xe827004a,0x04590058}},	//   _няме, rwah, _эфио, تلئة_
  { {0x98ab0011,0x98b90011,0x656d12e4,0x12e7005e}},	//   ască_, arsă_, swah, підг
  { {0x05190029,0xe2f80033,0xddd40046,0x38af02ad}},	//   _ويجب_, пехі_, žařs, _würd_
  { {0xaa38004c,0xd0090004,0x7e69007c,0x20d502a3}},	//   לטאק_, оеле_, veep, мікс
  { {0x6aad0026,0x2054006b,0x2f1116ee,0xa0a40033}},	//   _llaf, етър, _pág_, наід
  { {0xb4d9021e,0xc4d2000a,0xcef50004,0x44334b12}},	//   ावी_, _סגל_, мчињ, max_
  { {0x0d850080,0x2eb40033,0x6d490045,0x44334b13}},	//   длин, есьс, tuea, lax_
  { {0x8db50210,0xdb080264,0x7e694b14,0xa15907f8}},	//   ьскі, vzdá, reep, _фазу_
  { {0x6aad1f59,0x0b59055f,0x4c6902ed,0x44334b15}},	//   _alaf, ормы_, цион_, nax_
  { {0xbc69002b,0xeb9941f2,0xaa46248c,0xae19009b}},	//   ممکن_, цин_, менл, _джеф_
  { {0x1fc9014e,0x929d005c,0x60c34b16,0x3ad6003d}},	//   िपीड, _miło, linm, kāpe_
  { {0x3ea200c0,0x6d49047e,0xc236000a,0x690b002a}},	//   ökte_, quea, וררו_, _ażeb
  { {0x4c84005e,0xb69b016e,0x20dd000b,0xfbc52791}},	//   _плів, _diâm, यविध, _обло
  { {0x869a0004,0x66e6436a,0xdcf60058,0x480702db}},	//   отат_, дова, _تفوت_, дерн_
  { {0xfe790046,0x6443001a,0xddc0003d,0x6f7a004f}},	//   ndů_, ónin, lemš, חְמו
  { {0x38af01e2,0x60c30064,0xe5720029,0x9a3b000a}},	// [b080] _süre_, kinm, خطأ_, _ותפק
  { {0x03a60001,0xf8d2000b,0x66164b17,0xddc000bc}},	//   мизо, _सदिय, scyk, nemš
  { {0xf6261acb,0x833a01b7,0x60c34b18,0x0000006a}},	//   _одно, ючат_, dinm,
  { {0x41e60010,0x2d800024,0x9c7c00bd,0xeb960053}},	//   міла, _šiem_, moče, ודער_
  { {0x9c7c1eae,0x5fc3000b,0x60180a66,0x0000006a}},	//   loče, _वेबल, поля_,
  { {0x1de1005d,0x60c34b19,0x79b7000a,0xf993000a}},	//   _पड़त, ginm, ולנד_, כרד_
  { {0xb4ea005d,0xd0070054,0x7ae44b1a,0x2d994922}},	//   मती_, меље_, _okit, äsen_
  { {0x1ef70029,0xb3bb000a,0x3da605ae,0xf8bf0003}},	//   وعية_, _ומלכ, дроб, mpée_
  { {0x60c4002d,0x9c7c0046,0x8ed70015,0x7d6a005e}},	//   éims, hoče, بذور_, ішив_
  { {0xe0860029,0xc19b000a,0x40960033,0x219b000a}},	//   _تجري, _ושמי, _ўрат, _ובמא
  { {0x9c7c00bd,0x8c9f000b,0x69da0045,0x547b000a}},	//   joče, _ओवरो, ştel, קטטו
  { {0xa2a1005d,0x5337004c,0xf8bf0003,0xcf93000a}},	//   कॉप्, ונטן_, ipée_, _שטף_
  { {0xb9e40036,0x4efb000a,0xac73002b,0x7e62016e}},	//   віри, _והאו, رایش, _ibop
  { {0x8f0d000b,0x1bd40361,0xbca40015,0x7d1d016e}},	//   _ढूँढ़_, _поля, _سمعي, ísse
  { {0x9c7c018c,0x248d0092,0x2ca30123,0xc7c400ce}},	//   goče, _đem_, öjde_, всти
  { {0x8f9b0008,0x60c30064,0xbebc003d,0x659502bb}},	//   חילי, zinm, _avīz, набу
  { {0xe3b0002b,0x7afd198f,0x929d002a,0xd3010033}},	// [b090] یرم_, mmst, _siło, цiнс
  { {0x9c7c4b1b,0xa7750185,0xf992000a,0x629b0046}},	//   ločb, _злоч, _ערי_, _souo
  { {0xca480086,0x0219005e,0x44334b1c,0x26c50030}},	//   _علیه_, піль_, rax_, élos_
  { {0xd627003b,0xe1350033,0xa159008b,0xddc03497}},	//   _تعدي, енды, заду_, zemš
  { {0x35b40010,0xb2360015,0x361a000a,0x58b8002b}},	//   _абяр, ركوا_, _מורד, _رایج_
  { {0xe1f00029,0xe4c70010,0x7afd02ad,0x7bc6007f}},	//   جسم_, _цёмн, hmst, şkuy
  { {0xa5bb016e,0xd006029f,0x60c307c2,0xb4db0065}},	//   _geór, неше_, rinm, डकी_
  { {0x443100dc,0x62890011,0x67ce00dc,0xfe710031}},	//   _hez_, _uneo, lőjé, ادث_
  { {0xc05b13ae,0x44310064,0x98ef005d,0xfe790046}},	//   _між_, _kez_, छताछ_, rdů_
  { {0xd011003b,0x1601005d,0x7afd2d5d,0xdf570015}},	//   _إلا_, लेयर_, emst, _يخضع
  { {0x7af64763,0x4431005a,0x27180081,0x0000006a}},	//   _phyt, _mez_, _očna_,
  { {0xff7a0008,0xeab20115,0x8e840015,0xfb24002b}},	//   _מטעמ, اعد_, _للمه, کریپ
  { {0xbda70029,0x3eaf0024,0xc9550033,0x8c4520b9}},	//   _تحاو, _ilgt_, ктры, _зеле
  { {0x6ee5005c,0x26fa005d,0x7d760015,0x61e41348}},	//   róbu, ्द्र_, _أمور_, üili
  { {0xfc56000a,0x46f61119,0x290c006f,0x67ce0030}},	//   _נבקש_, ечат, _žiaľ_, dőjé
  { {0x7ae4000c,0xcf9200b2,0x9c7c04c0,0x7e7b00e8}},	//   _ukit, נטן_, roče, ndup
  { {0x3946002d,0xceb2000f,0x9c7c00bc,0x61e901d7}},	// [b0a0] _íos_, אין_, soče, _nyel
  { {0x4431002c,0xb9db0008,0x2d800007,0xb4ea000b}},	//   _cez_, _מחפש, _šiek_, मते_
  { {0x7b090064,0x44314b1d,0x6d5b0020,0xc5e9000a}},	//   _üstü, _dez_, htua, צד_
  { {0xe8d90023,0xdbc60020,0xa50a4b1e,0x171b0643}},	//   _trợ_, _tööo, _нема_, _מוטע
  { {0x4431001c,0xd1c90015,0xd24f0015,0xb89a000a}},	//   _fez_, وبهم_, إنه_, ּבֶש
  { {0xf8bf0152,0xd00f0115,0x2937004c,0xa5bb195f}},	//   ppée_, مله_, גאסן_, _teór
  { {0xde8f0092,0x25fc000b,0x61e94b1f,0xb6ba000a}},	//   _vịnh_, लेरी_, _eyel, ּצִי
  { {0x38b400c0,0x1757000a,0x38af007c,0xd1320015}},	//   _färg_, גסקר_, _müra_, _ممر_
  { {0xde8f0016,0xa3bc000b,0xe611004f,0x0000006a}},	//   _tịnh_, इज़र_, יִי_,
  { {0x387a002c,0xe0850029,0x35c7000b,0x4cb7004a}},	//   _napr_, _لجمي, _रेफ़, елью_
  { {0xa4b70008,0xe7e0005d,0xcf890029,0xd00f0021}},	//   גליה_, _खुला_, _يضمن_, _الم_
  { {0xd3370008,0x67ce00dc,0x9e730002,0x93b7000a}},	//   ערכה_, zőjé, _مهمت, תלטו_
  { {0xf2d300b2,0x5a340010,0x291202c1,0x0e9b000a}},	//   רער_, ынят, _cuya_, _משאל
  { {0x916d0023,0x9b940029,0xdfc600a2,0xab940015}},	//   _hộp_, _للتت, لي_, _للتغ
  { {0xe7db014e,0x64430c98,0x9c85002b,0x67ce0030}},	//   _मुखप, ónim, _جشنه, vőjé
  { {0x14770086,0x63a50069,0x44314b20,0x59c50058}},	//   کارج, vyhn, _sez_, _ليعك
  { {0x99840029,0x67ce00dc,0x54550254,0x44314b21}},	// [b0b0] _مليو, tőjé, кват, _pez_
  { {0xdce20046,0x47d50058,0x0000006a,0x0000006a}},	//   _opoč, _ليخر,   ,
  { {0x92590080,0x44310e75,0x8cdb000a,0x67ce0030}},	//   дает_, _vez_, לחמת, rőjé
  { {0x916d0092,0x76a70015,0x6d5b002a,0x28070046}},	//   _nộp_, _أحدك, ytua, ětně_
  { {0x8636004c,0x7cef0723,0x38b40123,0x6d5b4b22}},	//   _בארג_, førl, _färd_, xtua
  { {0x1ee7002b,0x3f690973,0xe04204ae,0x9f64005a}},	//   کوبی_, дико_, анши, _štáb_
  { {0xe0d00015,0x61e9002a,0x6d470091,0x8f7502a3}},	//   حزن_, _wyel, ąjam, тулі
  { {0x6d5b4b23,0xf0bb002b,0xee09006b,0x0000006a}},	//   ttua, _کارش_, мейл_,
  { {0x6b9c0020,0x3ea200c0,0xc212000f,0x98e1000b}},	//   ärgn, ökta_, _כהן_, पकाए
  { {0xfc310029,0x4c8201b0,0x69da0061,0x38b40123}},	//   جحة_, альв, ştek, _käre_
  { {0xf4120008,0x2b141402,0x79844b24,0x29124b25}},	//   יפי_, льяр, _sriw, _suya_
  { {0x5d850015,0x752f002a,0x7c64002b,0x2d990723}},	//   _للصل, _owcz, پایل, øses_
  { {0x6e290049,0x89d5005e,0xb23a004c,0xdce20046}},	//   mbeb, гірш, וערז, _zpoč
  { {0x6b65005f,0x60cd002d,0x661d4b26,0x6d5c0045}},	//   _акка, éamh, _afsk, ărat
  { {0xe73a0080,0xc052039e,0xf092000a,0x2aa2002a}},	//   ьев_, יזם_, סנל_, _dóbr_
  { {0x798419b9,0x29120077,0xcb12000a,0x89d60015}},	//   _triw, _tuya_, _דלה_, _لتخط
  { {0x9c7c00bd,0x6d494b27,0x61380030,0xf50a0663}},	// [b0c0] loča, nrea, _múlá, днал_
  { {0x6d49002f,0x29370008,0x7ebe0007,0xb90a0015}},	//   irea, _שאין_, rūpi, _تزعم_
  { {0x6d49002d,0x8c420064,0x38b400c0,0xaac6000b}},	//   hrea, _öğen, _värd_, _लगाक
  { {0x23270ea6,0x673a0030,0x65c60033,0x6d491181}},	//   тоци_, átju, _абма, krea
  { {0xaa7b0264,0xdce24123,0x6e290012,0x75430a93}},	//   plýv, _spoč, dbeb, _княз
  { {0x30d80033,0x49bb000a,0x94230004,0x6e294b28}},	//   эмль_, ומנס, _вмре, ebeb
  { {0x547b000a,0x690b002a,0x824a0015,0x3af90046}},	//   _קטלו, _ożen, _يشرف_, lépe_
  { {0xb7db00b2,0x6d49002d,0x63a3043b,0x8e840015}},	//   וקצי, frea, änne, الظه
  { {0x26d200b6,0x6ee5002c,0x71650015,0xa26a002a}},	//   inyo_, tóbr, _مالك, zęść_
  { {0x8ffa03c4,0x212600d9,0xcb980036,0xc157000a}},	//   _قرار_, mpoh_, евої_, _בשמו_
  { {0xdce200bd,0x9c7c00bd,0xda3504ab,0xb5fb002d}},	//   _upoč, goča, лены, _abál
  { {0x4ea300d0,0x3af90030,0x6d494b29,0x8aa7144a}},	//   _врша, képe_, brea, трод
  { {0x3ed90053,0x6d4914e6,0x6c860015,0xe947006b}},	//   _אַסא, crea, _للإم, ъхно
  { {0x929d005c,0xa9c40010,0xa3b2005d,0xdce6003d}},	//   _piłk, рсюк, टना_, īmēj
  { {0x57a42c04,0x2f1801d3,0x0000006a,0x0000006a}},	//   ашта, _jég_,   ,
  { {0x2f180014,0x5a47008f,0xa3e6005d,0xba550001}},	//   _még_, _рэка, _पड़_, _свиј
  { {0x15180029,0xa3c00046,0xf8ae002b,0xd68401ca}},	// [b0d0] نزلة_, výší_, زکی_, јусп
  { {0x8d5b004c,0xd3a7009f,0x2db7000a,0xa8750033}},	//   וכמי, креп, דלמן_, _слоі
  { {0x53e4008f,0x128a002b,0x7eb5006f,0x8bf8000a}},	//   ацца, کمنی_, _hápe, תִּפ
  { {0xe2980036,0xfb150053,0x25de005d,0x02440015}},	//   кає_, אַסט_, _कुकी_, لَمَ
  { {0x7abc013a,0xc2440010,0x38b400b8,0xc2c40015}},	//   וצאו, рнік, _wäre_, جيني
  { {0x69da00b8,0xb6020046,0x4f79006b,0x2f55005e}},	//   ßtei, čátc, ещия_, гтис
  { {0xfe710029,0xd25b0001,0x289c0053,0x53340b97}},	//   مدة_, _оца_, ויגא, _вест
  { {0x77f8004c,0x72050015,0x8e55008b,0x9c7c10cd}},	//   כמוד_, _موزم, уткі, voča
  { {0x6468002e,0x2d940010,0x25a94b2a,0x6e294b2b}},	//   _þrið, арэс, nyal_, rbeb
  { {0xdb0a0046,0x6d4916c8,0x9c7c02d8,0xddca0045}},	//   ěním, rrea, toča, ţişe
  { {0x7e5500e6,0x2d8602b9,0xb3310033,0x50c80033}},	//   _مناص, _eroe_, апiл, _рытм_
  { {0x9c7c018c,0x6d5c0011,0xbe64002b,0x38af0475}},	//   roča, ărar, _نهمي, _büro_
  { {0x38c80074,0xc95604ab,0x2d8200d6,0x5c950040}},	//   ناسی_, ытны, åket_, _مؤثر
  { {0x9c7c0f5d,0xdd8e0029,0x290c0f38,0x3ead0a3a}},	//   ločn, _روى_, öda_, lket_
  { {0xaa7b09f0,0x9cda0008,0x1be9006b,0x3fe9004f}},	//   glýs, _אקספ, _ядки_, גַּ֣
  { {0xa3d7014e,0xeab20015,0x3ead30ef,0xfbd2000a}},	//   ापन_, _دعت_, nket_, _לתו_
  { {0x59830010,0x45860033,0xdb020030,0x7ae64b2c}},	// [b0e0] _глыб, ыгав, szló, mokt
  { {0xa9bb000a,0x19bb000a,0xa8560054,0xa2a10065}},	//   _נזיר, _נמיב, _стиј, कॉस्
  { {0x08770053,0x39400293,0x3ead0293,0x04570015}},	//   _געיט_, _hvis_, kket_, المة_
  { {0x5b560053,0xd2500067,0xa79b000a,0x2f180030}},	//   טשען_, زنت_, _נשכח, _rég_
  { {0xc1e70a7f,0x10a6080e,0xb2370015,0xc69305bd}},	//   льше_, лидн, اكها_, _האר_
  { {0xe9f90016,0x3ead0030,0xc0e3030c,0x3d0d0065}},	//   _hoả_, eket_, бочк, सदों_
  { {0x33780008,0x80a5000b,0x6378000a,0x2378000a}},	//   _בְּב, _कवरे, _בְּס, _בָּמ
  { {0x6b9c0020,0x9f17002b,0x443a399b,0x2f180030}},	//   ärgm, دآور_, lap_, _vég_
  { {0xe0560002,0x7ae64232,0xfd140004,0xadd40054}},	//   _مخاب, dokt, јмоќ, ропљ
  { {0x443a4b2d,0x0577000a,0xd117000a,0x5b260a93}},	//   nap_, נגים_, _עקבה_, льма
  { {0x3b63005f,0xdd920086,0x8f45005e,0xdfcf0015}},	//   бъяв, _گوش_, _вхід, _فيك_
  { {0x3ead0876,0x7eb5002c,0x2e160015,0x690b002a}},	//   cket_, _pápe, _إباح, _eżel
  { {0x443a4b2e,0xdd92002b,0xc8f5006b,0x6e3d001a}},	//   kap_, _دوش_, измъ, ðsbe
  { {0xed57013a,0x6b9c00fb,0xfd570008,0x443a0213}},	//   _עבור_, ørgs, _עשוי_, jap_
  { {0x8c1b0008,0x443a0375,0x5c37000a,0x3cf9000b}},	//   _אווי, dap_, _גרון_, _उठते_
  { {0xaa7b002e,0x7c3a4b2f,0x644a001a,0x6ffb000a}},	//   rlýs, latr, ófin, תפלג
  { {0xf487023e,0x8435005e,0xd83b0033,0x86240033}},	// [b0f0] лужн, инає, _пэн_, сьсе
  { {0xaa7b09f0,0x25a904a7,0x443a2ddf,0x9c7c0085}},	//   plýs, ryal_, gap_, zočn
  { {0xd3710070,0xe7870010,0xdc3b0053,0x25a90eeb}},	//   تها_, _супо, געבר, syal_
  { {0xf53f01d1,0x7c3a0a54,0x179a000a,0x8b57000a}},	//   _två_, hatr, _סירב, ריאס_
  { {0x210f005d,0x11670086,0x763a004c,0x9c7c00bc}},	//   ादेश_, التی_, _בערג, vočn
  { {0xa0690124,0x8fa50063,0x29380053,0x38b404d6}},	//   така_, иале, ראגן_, _kära_
  { {0xc4d20008,0x9c7c2c98,0xf0b8002b,0x3ead008c}},	//   _וגם_, točn, دانش_, tket_
  { {0xa3b2000b,0x7c3a4b30,0x0000006a,0x0000006a}},	//   टनर_, eatr,   ,
  { {0x38b400c0,0x6d460fcb,0x7c3a1519,0x0c9501b0}},	//   _lära_, škan, fatr, ашня
  { {0xa2a1014e,0x8bb50015,0x3ead2049,0x212a002b}},	//   कॉर्, لإجا, sket_, _شيمی_
  { {0xc1044b31,0x38b400c0,0x9c7c016f,0x2d82003c}},	//   _اولي, _nära_, počn, åker_
  { {0x8a060457,0x9c7c00bc,0x4a43005e,0x8f9a000a}},	//   изне, ločl, онюв, _ביעי
  { {0xfeb80086,0xb2760053,0x99820091,0xed592666}},	//   _حالت_, בערג_, vakų_, _рол_
  { {0x6e3b00b8,0x91f6000a,0x38b40123,0x7ae60030}},	//   laub, שמשו_, _bära_, sokt
  { {0xac740074,0x443a0064,0x7cef003c,0xe73705b3}},	//   _دانش, vap_, jøri, иер_
  { {0x7a0c0024,0xd6260015,0x7bda000a,0x75d6006e}},	//   _pētī, شعري, _בקצו, ليزا
  { {0x80d6005d,0xe6170800,0x443a4b32,0xe523006b}},	// [b100] _बदले, рду_, tap_, ждуп
  { {0x25fc005d,0x7cef0d2b,0xe3b20196,0xe4d70029}},	//   लेगी_, føri, يرا_, لوقت_
  { {0x38cb0086,0x6e3b2a52,0x74130015,0xe9f90016}},	//   _جايی_, kaub, زونا, _toả_
  { {0x63a300c0,0x443a2bcc,0x7c3a0694,0xe9f90016}},	//   änna, sap_, zatr, _hoạ_
  { {0xa1ba0015,0x7c3a0f0a,0x715a0588,0xb1170058}},	//   خطاء_, yatr, трес_, لقنا_
  { {0x6ab60176,0xe8d90092,0x045a0029,0xc953000a}},	//   _llyf, _trụ_, _جلسة_, קמו_
  { {0xdfcf0031,0x38670030,0xd0970015,0x44382619}},	//   ويه_, _önre_, شئوا_, _ier_
  { {0x44383753,0xf536000a,0x1d34006b,0x7c3a4b33}},	//   _her_, ֑נִי_, бния, watr
  { {0x4438018c,0xdddb0011,0xe51c000b,0xdd900115}},	//   _ker_, reuş, _भूमि_, سود_
  { {0x4438010b,0xf4110008,0x515b0008,0x62820161}},	//   _jer_, ּ֤י_, _בכמו, ldoo
  { {0x443802d2,0x62804b34,0x501b004c,0xc43b000a}},	//   _mer_, _kamo, _סואו, כתיי
  { {0xdfcf0074,0x44384b35,0x6aa4096f,0x6ab60034}},	//   _تيم_, _ler_, _coif, _clyf
  { {0xdd8f003b,0x094b0063,0x79a4004a,0xf677002b}},	//   _يوم_, ъчни_, орре, یارخ
  { {0x8cf3008f,0x443801d1,0xc051000a,0x4dbb0643}},	//   _дзіц, _ner_, ּ֖ם_, _שֶׁנ
  { {0x1b770029,0xacfb0008,0xe9f90016,0x62824b36}},	//   _نصية_, _שהוכ, _doạ_, kdoo
  { {0x0bb70008,0xee31000a,0x3acf002a,0xdb9b015b}},	//   _כלום_, ּֽן_, tępu_, _יסור
  { {0xf5590015,0x44384b37,0xe945002b,0x15eb005e}},	// [b110] طلاب_, _ber_, _اربی, тєво_
  { {0x7c38016f,0x44384b38,0xb956000a,0x6d404b39}},	//   _jevr, _cer_, _פיתח_, isma
  { {0x44380854,0x82150015,0x7c380079,0xd37b006b}},	//   _der_, مواص, _mevr, ъча_
  { {0xe695003b,0x98b90024,0x4438049c,0x6d404b3a}},	//   _الحد, pusē_, _eer_, ksma
  { {0x7cfd0152,0x78a50020,0x44384b3b,0xa2b8000b}},	//   lère, _kohv, _fer_, ्फ़्
  { {0x44384b3c,0x62804b3d,0x3e710016,0x7c3817d1}},	//   _ger_, _eamo, _ạt_, _nevr
  { {0xc0580036,0xc0d20015,0x7cfd0003,0x8f320004}},	//   річ_, ثيوب, nère, пејц
  { {0x44210c8c,0x41770086,0x62803297,0x6ee40015}},	//   lch_, _پارس, _gamo, يسيل
  { {0x443801e2,0x9c7c018c,0x6e3b00b8,0x7c380150}},	//   _yer_, močj, raub, _bevr
  { {0x442117ce,0xbb75006b,0x62804b3e,0x0c95006b}},	//   nch_, бумъ, _zamo, сшия
  { {0x0c220010,0x7c384b3f,0xa3d7000b,0x44214b40}},	//   ямэн, _devr, ापि_, ich_
  { {0xcff60008,0xf8a90008,0x7e770015,0x7cfd0003}},	//   _הצעה_, _אש_, _خاطئ, dère
  { {0x82760053,0x6b8a0079,0x64470046,0x7d25002b}},	//   זערע_, _erfg, _odji, _افتن
  { {0x7c380150,0x7cfd0003,0x27fa002a,0x44211c65}},	//   _gevr, fère, _pzpn_, jch_
  { {0xd7f20029,0x7cfd0152,0x7eb50057,0x9b450067}},	//   سكر_, gère, _zápa, _انبو
  { {0x96950036,0x645c4b41,0x442123e5,0x44384b42}},	//   оруш, _scri, ech_, _ser_
  { {0x44384b43,0x46a3006b,0x4a57000a,0xe9f90016}},	// [b120] _per_, чатв, _השפל_, _toạ_
  { {0x99920089,0xb4650029,0xa99b000f,0x7cfd0003}},	//   _když_, قدمه, _עביר, bère
  { {0x6280000c,0xa9050086,0x7c3a0053,0x66e60010}},	//   _pamo, _ببين, רגעז, _гона
  { {0xd2590191,0x6b9c0005,0x443805c7,0xf2c50010}},	//   иці_, ärgi, _wer_, осін
  { {0x62820298,0xc0ca0001,0x673b016f,0x6280047e}},	//   rdoo, луке_, ćuje, _vamo
  { {0xdb1a03c0,0x6d4000c0,0xc0e30a61,0xe5f7000a}},	//   szté, vsma, почк, _לזכר_
  { {0xd0950010,0x20b90010,0x9c7c00bc,0x6fb40015}},	//   ўшчы, шыць_, bočj, تمثا
  { {0x6d462823,0x03d7000a,0x7eb50030,0x27ec0046}},	//   škam, _הולם_, _pápa, ýdny_
  { {0x4cb8004a,0x65644b44,0x6d404b45,0xadbc0138}},	//   илию_, ntih, usma, тапi
  { {0x9c7c018c,0x6564077c,0x757b0135,0x7cfd0003}},	//   močk, itih, נטיפ, yère
  { {0xc49b000a,0x6d401281,0xc5f5000b,0x95f5000b}},	//   אשית, ssma, _आर्य_, _आर्ट_
  { {0x38af0064,0xbe850029,0xda670087,0x7cfd0152}},	//   _türk_, _وجنو, حادي, vère
  { {0x984b0063,0x2d9900f2,0xe9190484,0x44214b46}},	//   лява_, äset_, рогі_, ych_
  { {0xd90f0086,0x7cfd0291,0x4c94080e,0x6f1a4b47}},	//   ژیک_, tère, _фикс, _kutc
  { {0x38af2017,0x4919000b,0x501b000a,0x38b4007c}},	//   _jüri_, _यूरो_, רולו, _tärn_
  { {0x44210b7c,0x7f3b00b2,0x7cfd0152,0xa3ec000b}},	//   wch_, טעלו, rère, _झड़प_
  { {0x69da409f,0x6594000d,0xa5d80015,0x7cfd0003}},	// [b130] şter, пату, مبكر_, sère
  { {0x9d1b013a,0x44214b48,0x6f1a003e,0x3f8c0064}},	//   טומט, uch_, _outc, _ordu_
  { {0x44210abe,0x27ed0012,0x61fb13c3,0x656401c2}},	//   rch_, ßend_, _szul, atih
  { {0x44212259,0x41b50067,0x798d0647,0x2b430030}},	//   sch_, يمار, _kraw, ájci_
  { {0x61450cad,0x9c7c00bc,0xa2bf000b,0x15ab009b}},	//   цела, ročj, लोग्, _съни_
  { {0x6f1a2ac8,0x929d002a,0x3f8c0085,0x493c0643}},	//   _butc, _piłs, _brdu_, נגוו
  { {0x10480080,0xf3f30115,0x3ea602b3,0x752d068c}},	//   сячи_, _رأس_, _boot_, lpaz
  { {0x92b70086,0x6f1a2476,0x3f8704c6,0x9c7c0227}},	//   _احسا, _dutc, rvnu_, bočk
  { {0x2d8b0089,0x52b5000b,0x1c890015,0x31341e58}},	//   íce_, ंसीस, لَةٌ_, _нетр
  { {0x6cc50010,0x985d0024,0xa0c40015,0x35d00065}},	//   ійна, gāļu_, _فيقو, _सेफ़
  { {0x3ea60bf5,0x4ee70010,0xf989000f,0x798d4b49}},	//   _foot_, _лідз, _שר_, _araw
  { {0x6ee70029,0xef0e05fc,0x798d0335,0x271800bc}},	//   _اسئل, _ім_, _braw, _učni_
  { {0x31790053,0x7cef079b,0xbdab0015,0x798d0108}},	//   באָד, ført, _حطام_, _craw
  { {0x798d0495,0xd9430004,0x7eb50030,0x0000006a}},	//   _draw, ќери, _kápo,
  { {0xf0920008,0x752d0024,0xe9a7002b,0xfaa61cc9}},	//   ונם_, epaz, مگین_, _мако
  { {0x798d0313,0xd7570015,0x6abd0012,0x3ad6003d}},	//   _fraw, تلفت_, chsf, kāpi_
  { {0x284a005e,0x98160015,0x38b4007c,0x798d4b4a}},	// [b140] _кзпп_, _وبدا, _härm_, _graw
  { {0x3e4c0091,0x33f6058f,0x9f45008c,0x77ca0923}},	//   mėtų_, очес, _kylä_, _влог_
  { {0x3e4c0007,0x7eb50107,0x33d6005e,0x14170015}},	//   lėtų_, _nápo, ціат, زينة_
  { {0x7ebc0014,0xfbd2000a,0x6d46001a,0x65641d9b}},	//   _képe, ותב_, ákak, ptih
  { {0x90e6002b,0x3ea61c67,0x3e4c0091,0xd98d000a}},	//   يستن, _root_, nėtų_, ָנוֹ
  { {0x113902bf,0x5066005e,0x69fb000a,0x27ed1d56}},	//   сяцы_, ітла, בלנק, şene_
  { {0x7ebc00dc,0xdfd00015,0xe36316c7,0x7e6900cb}},	//   _lépe, عيب_, _окри, ffep
  { {0x3393003b,0xbe8a0001,0x7cef0134,0x3e4c0007}},	//   _تلفز, рске_, kørs, kėtų_
  { {0x9c7c018c,0xeeb70036,0x7ebc00dc,0xbdf70015}},	//   loči, ільш_, _népe, يرًا_
  { {0x3e4c0007,0x5cb80033,0x38af007c,0x0caa4b4b}},	//   dėtų_, слоў_, _türi_, ртии_
  { {0x7cf40251,0x3f8c41f6,0xa4fb000a,0xfaf9003d}},	//   nàri, _urdu_, שליט, stīm_
  { {0x798d4b4c,0x7cef079b,0x7cf40144,0x0efa0138}},	//   _praw, førs, iàri, _тэзы_
  { {0x2bb50023,0x9992005c,0xadb70029,0x2ca74b4d}},	//   ác_, _gdyż_, _وهما_, _fond_
  { {0x6da30124,0x7ebc0152,0x2ca70030,0x9c7c1a33}},	//   _циља, _dépe, _gond_, koči
  { {0xa814000d,0x9c7c00bd,0x69da0011,0x8bc30063}},	//   ддрш, joči, ştep, _осъд
  { {0xc6f90010,0x5694070e,0x6ac40029,0x3704017f}},	//   ёнах_, маст, _يقوم, дчув
  { {0x7ebc0f87,0x05770015,0x65150015,0xbae40015}},	// [b150] _gépe, غارد, سوائ, _تكيي
  { {0x04670033,0xd4e7005e,0x442b01b0,0x44981028}},	//   ўтам, цюби, рцам_, овую_
  { {0x9c7c018c,0xa87a0008,0x78a1002e,0xd2510029}},	//   goči, _האתר, ölvu, فنا_
  { {0xb77a00b2,0x877a00a3,0x7bdb000a,0x9756004f}},	//   _פארש, _פארי, סקאו, _צירו_
  { {0xc69200b2,0xd1b8012c,0x39594b4e,0x569a004f}},	//   _נאך_, ياها_, nuss_, _הירצ
  { {0xb97c4b4f,0x997c000a,0x63a300cb,0x897c004f}},	//   ינדי, שָׁפ, ønns, שָׁה
  { {0xf8380008,0x7cf40251,0x39590012,0x2ca7100c}},	//   חנות_, càri, huss_, _rond_
  { {0xfe45000d,0x3eb9002e,0xcee800e6,0x6f024b50}},	//   чнио, óst_, يرين_, _choc
  { {0xee36008f,0x38610026,0xaf240053,0x628c0057}},	//   чны_, _ochr_, _פּאַסי, álož
  { {0x7ebc0152,0xdc990bb1,0x7eb501c0,0x16c80065}},	//   _répe, стиш_, _zápl, _रग्ब
  { {0x6f02002d,0x2ca70111,0x2bb50016,0xe822000b}},	//   _fhoc, _vond_, úc_, _मलबा_
  { {0x539a0008,0x6ffa000a,0x09e60054,0x7cef01de}},	//   צירו, _ההעפ, зомн, tørs
  { {0xf9920015,0x427a004c,0x39430033,0xbc9503ae}},	//   ربح_, זארג, нняг, _надј
  { {0x3e4c0007,0x7188000a,0xed590046,0x4c84005e}},	//   rėtų_, קְרַ, muž_, _олів
  { {0x4c9a0008,0xc7a60063,0x3b0a0e44,0xdc3a000a}},	//   _לבסו, чивк, _леко_, _העצר
  { {0x7cef00cb,0x6f090012,0x9c7c0247,0x3ebf2ebe}},	//   pørs, nmec, voči, nhut_
  { {0xcb13013a,0xda5b000a,0x1818002b,0x38b4007c}},	// [b160] _אלה_, _הכפל, _وردک_, _järk_
  { {0x7cf40251,0xf8e0000b,0x5fdb000b,0x6f090012}},	//   tàri, _नदिय, यपाल, hmec
  { {0xb80a0086,0x6f0900bd,0xe3160015,0x9c7c0091}},	//   _ديدم_, kmec, سباب, uoči
  { {0x7cf40251,0x9c7c12d7,0xa79b000a,0x71660015}},	//   ràri, roči, _השטח, كاتك
  { {0x290a06fd,0xea8d004c,0x7ebc0030,0xa158005e}},	//   omba_, ינאָ, _lépc, іаку_
  { {0x26d2003f,0x6f020541,0x7053002b,0x6f09006f}},	//   liyo_, _shoc, فنها, emec
  { {0xdfd00029,0x7eb500dc,0xa2d60015,0xdddb00bc}},	//   ضية_, _tápl, _فيست, vduš
  { {0x6d550050,0xaf030033,0x52550054,0x74130058}},	//   ązan, нчык, _отуђ, _أوفا
  { {0x5d980010,0x4d98005e,0x38af0061,0x5d630033}},	//   ікоў_, ікою_, _kürt_, нтэз
  { {0x31bb013a,0xc1bb013a,0xdb1a00dc,0x26d202f2}},	//   _הזמנ, _הממש, sztí, hiyo_
  { {0x7cef01f0,0xa08b000a,0x70530015,0x6f020125}},	//   tørr, _לְאִ, _أنما, _thoc
  { {0x39590048,0x93fb000a,0xcfb7000a,0x8f9b015b}},	//   tuss_, מליי, _מלבי_, _ליבי
  { {0x6ec50029,0x26d20b63,0xa2a10065,0xcee9009a}},	//   _تتلق, diyo_, कॉट्, _برلن_
  { {0x58870010,0x7d7b000a,0x6b9c060a,0x39594b51}},	//   чыма, _לנדו, ärgs, russ_
  { {0x6c830115,0x4ccb000a,0x7cef00cb,0xf7940033}},	//   _سليم, _לֶהֱ, pørr, нарэ
  { {0x1bf7000a,0xc6f90484,0x2bf7000a,0x7bdb000a}},	//   _מצור_, інах_, _ממון_, _לקוו
  { {0x27ed002a,0xf6c80138,0x0000006a,0x0000006a}},	// [b170] łen_, чырк_,   ,
  { {0x19bc000a,0x53350004,0xddc00030,0x49bc000a}},	//   _למחב, дежт, nemű, _למחס
  { {0x23790002,0xc828000a,0x33950058,0x0000006a}},	//   تماد_, _מֵרֹ, بلاز,
  { {0x645e0035,0x26c04b52,0x1b7b004f,0x93940058}},	//   agpi, chio_, מטבע, عجلا
  { {0xe1340033,0x98b9003d,0x95c80054,0x929d0535}},	//   енчы, jusī_, _еура_, _chła
  { {0xf4840063,0x7e622999,0xd59a000a,0xc05b005e}},	//   _пусн, _acop, _ובשל, сід_
  { {0xd3470086,0xfe710021,0xbea5006b,0x38b4007c}},	//   _ریشه_, ندة_, дайк, _särk_
  { {0x67bc000a,0xd7bc015b,0xcd290a32,0x0000006a}},	//   ממוק, מצור, ожие_,
  { {0xdceb003d,0x0c790033,0xcd05033d,0x2eed0547}},	//   _apgā, осны_, мпий, roef_
  { {0xaf370087,0x38b4007c,0xa0380015,0x7188000a}},	//   _فرصت, _värk_, _فأمر_, _מְעַ
  { {0x3ebf01d7,0x39494311,0x3b0a01eb,0x0000006a}},	//   phut_, _avas_, жено_,
  { {0x9f040029,0xeb96004a,0x690b002a,0x3c460046}},	//   _كولو, фию_, _ożes, tíví_
  { {0xdd940033,0x2d8f4b53,0x6208004f,0x0000006a}},	//   _пацы, _urge_, ּ֔רֶ,
  { {0x315600b2,0x9d1a000a,0xa3bd000b,0xdc3c006f}},	//   וישן_, _ווסט, इना_, _záľu
  { {0x26c00176,0x7ebc0003,0x6d46005a,0x0000006a}},	//   thio_, _hépa, ákav,
  { {0xf4840086,0x8b3a000a,0x7ebc0030,0xb4b6000b}},	//   کاری, _ותקצ, _képa, जस्_
  { {0x34aa0001,0xddc2005c,0xba76002b,0xb4aa14fd}},	// [b180] овао_, _zdoł, _فاکت, оказ_
  { {0x26d20fd1,0x224d00d9,0x3957000a,0x1957000a}},	//   siyo_, _adek_, _קשים_, _קביל_
  { {0xaa570086,0x889b000a,0x389b000a,0x463a0015}},	//   _علیا_, _וביי, _ויינ, _وأحد_
  { {0xe1fa0175,0x68070030,0x38af2e56,0xdb1a01d3}},	//   оге_, séjé, _fürs_, nztá
  { {0x7ebc0003,0xbebc003d,0x067b004f,0x867b004f}},	//   _népa, _ktīv, _ונכל, _ורכו
  { {0x7e6230c5,0x15430054,0xcf2600c3,0x6d55002a}},	//   _scop, _јерм, وربي, ązal
  { {0x6d4f006f,0x63830317,0x44442560,0xd8d7004f}},	//   ácan, _игра, ma_, ווסט_
  { {0xf8bb014e,0x2f170080,0x38b40123,0x75490030}},	//   _उत्प, мощь_, _däri_, _ószö
  { {0x7ebc0003,0x44444b54,0x9d140004,0x61460555}},	//   _cépa, oa_, ндич, _цеза
  { {0x7ebc4b55,0xd59b000a,0x1fb60342,0x9b580004}},	//   _dépa, קביל, _осер, пиот_
  { {0x40330191,0xe4570135,0x5457000a,0x60d7004c}},	//   _реєс, וייט_, וסין_, _קובא_
  { {0x6d5b00b6,0x6e930015,0x5e930015,0x63a3039b}},	//   buua, _للما, _للمط, änni
  { {0xc237000a,0x644e1363,0x1d330033,0x764401d7}},	//   ורכו_, _odbi, _анія, daiy
  { {0xfbcf0074,0x2f01002d,0x44444b56,0x8dfb004f}},	//   اتی_, móga_, ja_, _והדת
  { {0xd7f8005f,0x3c77000a,0x5bc30015,0xaac70015}},	//   дут_, _חתום_, _لقول, _يتبن
  { {0x442a2538,0xaae70021,0x44444b57,0x70db000b}},	//   _afb_, _تستو, ea_, _बद्ल
  { {0x44444b58,0x06a40015,0x05190369,0x394904e6}},	// [b190] fa_, خصَّ, سياب_, _uvas_
  { {0x59960008,0x9c7c006f,0x44444b59,0x442a01f9}},	//   _נכתב_, poču, ga_, _cfb_
  { {0x7e7b003f,0x70db000b,0x325515f7,0x442a04c4}},	//   yeup, _बदौल, евер, _dfb_
  { {0x44444b5a,0x5334005e,0x95cb007e,0x7d182e25}},	//   aa_, тецт, _дуга_, _livs
  { {0xda01005d,0x7c2a4b5b,0x44444b5c,0xf1ab0058}},	//   ोधित_, _offr, ba_, غاؤه_
  { {0x7ebc0152,0xc10400e6,0xd1b80115,0x8505002b}},	//   _répa, نوني, باما_, _سوزن
  { {0x7ebc0152,0x64454b5d,0xc4d2004f,0x32671979}},	//   _sépa, mahi, _עגל_, _отав
  { {0x38b400f2,0x2d8d253c,0xd2580054,0x64454609}},	//   _väri_, tvee_, _оцу_, lahi
  { {0x61da005d,0xa3d7000b,0xcee80015,0x7e7b2a6d}},	//   बपृष, ापक_, برون_, reup
  { {0xb16e02d5,0x644503ac,0xf0bb002b,0xf8bf0003}},	//   ížeč, nahi, _بارش_, ipés_
  { {0xde950001,0xeb992b5f,0x6b9c0123,0x4ea706ff}},	//   _пажњ, чин_, ärgp, _орда
  { {0x1a660086,0x44444b5e,0x7c2a2114,0xc869000a}},	//   ریخی_, za_, _effr, _לן_
  { {0xed4e129a,0x644500b6,0x6d460030,0x7cf40144}},	//   _що_, kahi, ákat, tàrt
  { {0xdb1a0014,0x444429ab,0xfc310018,0x6d491406}},	//   sztá, xa_, _صحت_, msea
  { {0xd7f20029,0x69c600dc,0x1cba0008,0xbb850015}},	//   اكز_, szke, _ממסע, _ألبي
  { {0x6443002e,0x7ebc00dc,0xf65512ba,0x44444b5f}},	//   ðnin, _lépn, ктую, wa_
  { {0xaadb0008,0x9c7c0057,0xe466001a,0x343a0015}},	// [b1a0] _מחקר, počt, _þökk_, كساد_
  { {0x64450035,0x6d494b60,0x7ebc0030,0x661d00aa}},	//   gahi, isea, _népn, _egsk
  { {0x7c2401e2,0x929d005c,0xd62a0004,0x083b05bd}},	//   _şirk, _chło, _ноне_, _מעיל
  { {0xd2520086,0xaa7b12c3,0xf7d70053,0x6f190026}},	//   انش_, mnýc, _טויש_, _niwc
  { {0xaa7b0057,0xcb13004c,0x291a2117,0x64454b61}},	//   lnýc, אלא_, _kipa_, bahi
  { {0x6e29016e,0xfaf9003d,0x10a307d1,0x6445007f}},	//   eceb, ltīt_, личн, cahi
  { {0xf8b30008,0x7eb50057,0xaa7b0227,0x6d4b4b62}},	//   רשו_, _zápi, nnýc, _avga
  { {0xc306002b,0xaa7b0046,0x3da62d90,0x62890034}},	//   _سبزو, inýc, ероб, _gaeo
  { {0x91e30063,0xfaf90024,0x301a0015,0x66db008c}},	//   _боте, itīt_, _فتاة_, läkä
  { {0xa1130018,0xfd73002b,0x7c66002b,0x8fa6084f}},	//   _موقت, اديخ, راخل, _пазе
  { {0x54570053,0xaa7b0107,0x4f650015,0x40570058}},	//   עסטן_, jnýc, _لانف, _ألمح_
  { {0xaa7b099c,0x34dd000b,0xad260015,0x644501c2}},	//   dnýc, _मद्द, _كرتو, zahi
  { {0xddea0086,0x64450035,0x6d49002d,0xcb67002b}},	//   _عرصه_, yahi, csea, ومیه_
  { {0x26f9005d,0x7eb50656,0x6d460091,0xb4af000b}},	//   ंत्र_, _rápi, škas, _ओके_
  { {0x0b93006e,0x291a01d7,0x37070b59,0x64454b63}},	//   _مجيد, _dipa_, ечав, vahi
  { {0x3ae90086,0xef11000a,0x64454785,0x8f9b000a}},	//   _تبتی_, ֹּל_, wahi, הילי
  { {0x64450508,0xaa54004a,0xf8bf0003,0x5eeb000a}},	// [b1b0] tahi, _свыш, upés_, לַמְ
  { {0xa8a4085d,0xaa7b0264,0xa3bd000b,0x7afd4b64}},	//   _брюк, bnýc, इनल_, llst
  { {0xf09f0092,0xd6d10087,0x64454b65,0xe1ff04b2}},	//   _đà_, _نقد_, rahi, _šó_
  { {0xe3b00029,0x64454b66,0xf8bf0003,0xd1790033}},	//   حرك_, sahi, ppés_, дскі_
  { {0x644500b6,0xb2240036,0x42240036,0xc2c40029}},	//   pahi, уміл, удів, ديني
  { {0x7afd4b67,0x628b0034,0x0000006a,0x0000006a}},	//   hlst, sdgo,   ,
  { {0x23e40010,0xa3ce0046,0x66cb000a,0xab310030}},	//   _бітв, píší_, ּמִ֔, _töéű_
  { {0x7ebc0152,0x6d490020,0xf79c0008,0xa6fb000a}},	//   _dépo, tsea, לבומ, הִ֖י
  { {0x26b60008,0xaa7b0107,0x6e290341,0x98b90091}},	//   דִים_, znýc, rceb, jusį_
  { {0x27ed0089,0x3099002b,0x62860030,0x656d01c2}},	//   řeny_, _تحرک_, _ókor, itah
  { {0xa3ba000b,0x38b4007c,0x6d494b68,0x7ebc0030}},	//   आईए_, _märt_, ssea, _képl
  { {0xe61f0092,0xaa7b0264,0x656d11ac,0x38b40123}},	//   _ngô_, vnýc, ktah, _lärt_
  { {0x3ed800b2,0x98d60036,0x6d4628b4,0x7c950015}},	//   _אַװא, вівщ, škar, _للإص
  { {0xaa7b099c,0xec79226a,0x7afd138a,0xdca501ca}},	//   tnýc, _цпк_, alst, _јаки
  { {0xf743000d,0x46f6006d,0x98a30c71,0x16660015}},	//   иеро, вчат, шире, َارَ
  { {0xcf920632,0x321f0092,0x7ae4003f,0xaa7b0227}},	//   סטן_, _nguy_, _ujit, rnýc
  { {0x60c1002d,0xceb2039e,0xaa7b0227,0x656d02f2}},	// [b1c0] _ollm, בין_, snýc, gtah
  { {0xfaf90024,0x19b7000a,0xaa7b0227,0x66db008c}},	//   stīt_, _ספיר_, pnýc, täkä
  { {0x14590010,0x61e910ad,0x44160004,0x7eb5001a}},	//   эшты_, _axel, тфат, _hápu
  { {0x7ebc038d,0x60c14b69,0xb2370058,0x0000006a}},	//   _répo, _allm, نكما_,
  { {0x7ebc0152,0xa2d30015,0x80b3000b,0x66db008c}},	//   _dépl, جينت, _अवशे, säkä
  { {0x3cfd000b,0x50f30033,0xbf660015,0xa0c40015}},	//   ॉगों_, азіт, ندبو, طيعو
  { {0x7ee6004a,0xd467098b,0xb2260099,0x54672b16}},	//   кцие, _шире_, _амбл, _шарм_
  { {0x9999002c,0x8fa30001,0xc7b30008,0x66c30020}},	//   lasť_, раће, שבה_, _tõke
  { {0xd257000a,0x7c2d0061,0x51662f72,0x98b40065}},	//   _ששמה_, _şara, _шваб, ुसाए
  { {0x7afd0111,0x98b90091,0x0000006a,0x0000006a}},	//   wlst, vusį_,   ,
  { {0x34b70008,0xc4d30008,0xead90036,0x9bd400fd}},	//   דפים_, שגת_, емні_, ужні
  { {0x4fd900b2,0x28d5000b,0x7ebc0030,0xed594b6a}},	//   _אַנד, डोनि, _képm, brž_
  { {0x394d0b7a,0xdd920086,0x39400026,0x1e57000a}},	//   ées_, _خوش_, _cwis_, _ישאר_
  { {0x6bd60029,0x799600e7,0x98b90091,0xdfc602be}},	//   _لتعر, _dryw, rusį_, مي_
  { {0xe918005e,0xad1b000a,0x97250040,0x7ac72dfa}},	//   торі_, _קוור, افرو, _аспе
  { {0x9c170008,0xe654005e,0xaa890015,0x6c19004f}},	//   _בחוק_, ивсь, _أنظم_, _אֵפו
  { {0xfaf90024,0xcb14000a,0x54990033,0x7ebc4b6b}},	// [b1d0] stīs_, _דלק_, нваў_, _népm
  { {0xf992000f,0x656d45ae,0xdb09008c,0x6abd4b6c}},	//   _פרי_, rtah, sydä, lksf
  { {0xa2b4014e,0x656d4049,0xf8b20053,0x7996002a}},	//   _आवश्, stah, _השי_, _zryw
  { {0x656d06a7,0x33980015,0xd2290015,0x1228005e}},	//   ptah, ضخمة_, ركته_, воїй_
  { {0x865a0008,0xe290002b,0x2005002a,0xa2b4000b}},	//   _אדרי, تذل_, _szli_, _आवर्
  { {0xe057002b,0x6725007c,0xd00901ca,0x67480052}},	//   ئیات_, _kuhj, неле_, _þrjó
  { {0x3d06005d,0xa4d4005e,0xbf640058,0xcef5011e}},	//   _सीधे_, _торі, لديو, лчињ
  { {0x7cfd0251,0x6d5c0091,0x5f760021,0x24810072}},	//   mèri, ąran, اميس_, lehm_
  { {0x403528ff,0x9d52006e,0xd2280015,0x4d150a1f}},	//   _безс, منيت, _شكله_, льот
  { {0x6f640086,0x609b0015,0x24810012,0x60c101b3}},	//   _چهلم, _تخرج_, nehm_, _ullm
  { {0x7c950074,0x7f59005e,0x7a6a0658,0x7cfd0144}},	//   نشگا, _чаес_, нинг_, nèri
  { {0x7ebc0014,0x7996005c,0x7376000a,0x66e50091}},	//   _lépj, _pryw, נגרד_, dėko
  { {0x99d60029,0x6e3b013c,0x0000006a,0x0000006a}},	//   اتجا, mbub,   ,
  { {0x99d5005e,0x799600aa,0x11da000a,0x68f500bc}},	//   рююч, _vryw, תחשב, gozd
  { {0xe71a002b,0x2cb84b6d,0xc5f8003d,0xe9a7002b}},	//   فيست_, örde_, _ņē_, نگین_
  { {0x2925002f,0x79960026,0xceb2000a,0x4b7a000a}},	//   úpaí_, _tryw, ֖ין_, _נאפו
  { {0xceb2000f,0xe5a32535,0xa5450015,0xe57a0033}},	// [b1e0] זין_, бити, لضلو, эза_
  { {0x9c7c00bc,0x7cfd0144,0x80b9000b,0xf7f6012c}},	//   onča, fèri, ्सफे, _مسجد
  { {0xfaf90048,0x9cd60008,0x80a7000b,0xd7ca0015}},	//   brīd_, נועה_, चाने, _أوجه_
  { {0x2bf60053,0x41e60033,0x1bf6004c,0x8c1a000a}},	//   אמען_, ліла, אצער_, גועי
  { {0xc5b6008f,0x35fa002b,0x60d84b6e,0xd12f0058}},	//   _сёнь, _سرحد_, tivm, كمن_
  { {0x2b59002a,0x8f340033,0x7cfd0144,0x7ebc0030}},	//   ńscy_, аекц, bèri, _gépj
  { {0x6d5b039f,0x6abd01d0,0xa0a3116f,0x0000006a}},	//   erua, yksf, сајд,
  { {0x7d540063,0x6e3b1c07,0x539b000a,0x727902b0}},	//   авих, gbub, _אילו, _исус_
  { {0xad260021,0xcd36002b,0x0000006a,0x0000006a}},	//   دربو, درعب,   ,
  { {0x7ebc00dc,0xddcb0045,0x6e3b02f2,0xefea0015}},	//   _képk, ţişt, abub, _كعضو_
  { {0x6d5b048c,0x1a65002b,0x4f5a0067,0x7646008c}},	//   arua, لیغی_, _سجاد_, _oeky
  { {0x68f5002a,0x5967006b,0x6d5b4b6f,0x6a150eaf}},	//   wozd, лъга, brua, имну
  { {0xd12600e6,0xddc90045,0x7c240045,0x6abd02f0}},	//   تم_, rfeţ, _şiru, rksf
  { {0x64580077,0xa3c4000b,0xe7871638,0x47352d99}},	//   óvil, एना_, лубо, ингс
  { {0x3cfb009d,0x764628e6,0xd6b5006b,0x7ebc0030}},	//   _רפוב, _beky, айвъ, _népk
  { {0x963549e2,0x79a70190,0x6d5d0052,0x0000006a}},	//   рнац, _брое, ásag,
  { {0xf8ae0086,0xe78a0046,0x95cb07be,0x984b006b}},	// [b1f0] سکی_, _míří, хува_, _пяна_
  { {0x7cfd0251,0xdce90089,0x64a40054,0xddc20b28}},	//   tèri, yteč, бађа, _obož
  { {0xc7ab0029,0xd2510015,0xf5040015,0xd37b0033}},	//   _أدخل_, قنا_, حِلُ, эча_
  { {0x0ce1000b,0x764600aa,0x62820079,0x569500e2}},	//   _पद्म, _geky, geoo, _тамт
  { {0xc24402e1,0xdd860040,0xa0691034,0xe0451c80}},	//   снік, _بو_, вала_, анли
  { {0xf770002b,0x2f550429,0xdb4600c3,0x7eb501c0}},	//   _بای_, атис, _وَ_, _nápr
  { {0x256f3240,0x6455005c,0x7c2d0064,0x88f8000a}},	//   lül_, _idzi, _şaro, אזגו_
  { {0xdf280015,0xdce920c0,0x6d5b4b70,0x0000006a}},	//   دأون_, rteč, trua,
  { {0x256f00dc,0xdce901b2,0x067c000a,0x7bdc001a}},	//   nül_, steč, תנחל, úrun
  { {0x64470089,0xeb990001,0x1d090001,0x7ebc00dc}},	//   _jeji, вио_, ђени_, _léph
  { {0x109a000a,0xdb22001a,0x64470077,0xb09a000a}},	//   _שבעב, ærðf, _meji, _שיער
  { {0x256f4b71,0x5e270015,0x141a004f,0x7ebc4b72}},	//   kül_, _إعاق, כותב, _néph
  { {0xddc20089,0xdca5080e,0x64553218,0x66e50091}},	//   _zbož, _вали, _odzi, rėkl
  { {0x21ba0053,0xe8f7007a,0x64470046,0x291e0f3a}},	//   דזשא, иля_, _neji, öta_
  { {0x29040048,0x9c7c00bc,0x75260012,0x3fe9000a}},	//   ēma_, ončn, _sukz, דַּ֣
  { {0xd5e6068e,0x7ebc0003,0xc6c3352f,0x26cb009a}},	//   ажби, _céph, ойск, نطقی_
  { {0xbafb0008,0x256f0a55,0xe7f2000b,0x8afb000a}},	// [b200] _בהקש, gül_, _आँका_, _שהפי
  { {0xc3960054,0x49bb004f,0x0000006a,0x0000006a}},	//   ијењ, _סמיס,   ,
  { {0x6447002c,0x7d014b73,0xd6c4002b,0x62821de9}},	//   _deji, ills, _همدی, teoo
  { {0xd4090015,0x6447003d,0xd2500040,0x256f068c}},	//   اتكم_, _eeji, سنت_, bül_
  { {0x6900022d,0x3ead016f,0xf19403e7,0x27f7002b}},	//   töeh, djet_, силь, _مفید_
  { {0x64550050,0x89970008,0x21290086,0x60f7022a}},	//   _gdzi, יכנס_, ديوی_, анія_
  { {0x656400f2,0x5756000a,0x26c00091,0x201a008c}},	//   luih, ׁבַע_, okio_, äpi_
  { {0xb5fb002d,0x6455005c,0xdd900015,0x26c00091}},	//   _scái, _zdzi, كوب_, nkio_
  { {0x5d830029,0x7b330045,0x27ed0061,0x5d670058}},	//   قليل, _lăud, ğeni_, لميّ_
  { {0x6e3d002e,0x00e4002b,0x5577004c,0x9c7c10cd}},	//   ðsbr, _اتری, סעין_, ančn
  { {0x256f0014,0x9e660086,0xa5bb0016,0x94bb004f}},	//   zül_, _ناشن, _ngón, דמית
  { {0x6564008c,0xbfb50015,0xe9810138,0x7d0115c8}},	//   kuih, _احْت, памi_, alls
  { {0xe8b4000b,0x7ebc0030,0xfce6222c,0x3dcd0535}},	//   ुसूच, _népi, _кодо, czew_
  { {0x256f00dc,0x4bd7002b,0xe7330021,0x8afd002a}},	//   vül_, ابید_, قصر_, kręg
  { {0xab27050e,0x644728f8,0xa037000a,0xc7b8004a}},	//   _која_, _reji, שאלה_, аёт_
  { {0x256f0014,0x8c1b0008,0xcf570008,0x56a40004}},	//   tül_, _בווי, יבלת_, ојуз
  { {0xaa7b01c0,0x38c8009a,0xd94400af,0x0000006a}},	// [b210] nným, _چاپی_, _дењи,
  { {0x35e4008f,0x256f0014,0x7ebc0003,0x74580015}},	//   іцтв, rül_, _dépi, لشمس_
  { {0x644700bd,0xb3670063,0x2d910024,0x290301a3}},	//   _veji, ръзк, āzei_, mlja_
  { {0xb69b0152,0x6455005c,0x4368005e,0x75d5006e}},	//   _chât, _wdzi, раїн_, _هيجا
  { {0x7d01002e,0x816b0805,0x50b504ab,0x64470077}},	//   ylls, треб_, йску, _teji
  { {0x64550050,0xaa7b0227,0x50b9002b,0x3ead086c}},	//   _udzi, dným, دگرد_, wjet_
  { {0xf78a00b2,0xa2670063,0x3ebf00f2,0x987c0135}},	//   ָנפֿ, _възл, tkut_, דרוק
  { {0x764d0035,0x212b0003,0x3ead0003,0x26b7004f}},	//   naay, _écho_, ujet_, יִ֖ם_
  { {0xf1fb0015,0x9e64002b,0x29034b74,0x61440004}},	//   _شعرت_, زاين, klja_, _меѓа
  { {0x5f770067,0xddc20045,0x3ead4354,0x155a000a}},	//   _ناصر, _scoţ, sjet_, נכתב
  { {0x798d0035,0x2cb800c0,0xddc2002a,0x26c00091}},	//   _asaw, örda_, _zboż, ykio_
  { {0xaa7b0264,0xcaca0054,0x0eb80033,0x29034b75}},	//   bným, угме_, _вушы_, elja_
  { {0xfe700002,0x8f1a000a,0xc212000a,0xe2fa000a}},	//   _آدم_, _עונת, ּ֔ר_, רִים
  { {0x6c3504b6,0x656400f2,0x7ebc01f6,0x7e694b76}},	//   _افغا, vuih, _répi, lgep
  { {0x5b3503c4,0xdc360053,0x27950054,0x7ebc4b77}},	//   _اعتر, _פאקט_, оштр, _sépi
  { {0x75d6003b,0x7e690f86,0x6564008c,0x6b9c02de}},	//   ميزا, ngep, tuih, ærge
  { {0x29030796,0x0585005e,0x26c00091,0x060a0937}},	// [b220] blja_, жуєм, rkio_, унак_
  { {0x07fa0087,0x088a004a,0xdb0f008c,0x764d02f2}},	//   _مرجع_, _сбой_, ädök, aaay
  { {0x6aa4003e,0xa2e609ef,0xaa7b4b78,0xb69b0003}},	//   _knif, божд, zným, _châs
  { {0xc1ea0033,0x6ab600da,0x74130021,0x0000006a}},	//   льле_, _joyf, سونا,
  { {0xf1d2005d,0x7ebc00dc,0x8717000a,0x4153005e}},	//   _देखन, _képv, _לקטע_, звіс
  { {0xf9930008,0xaa7b0264,0xb97b000a,0x3f980030}},	//   פרו_, vným, רנסי, _áruk_
  { {0x4f570029,0xef18003d,0xdddb002a,0x3f9a006f}},	//   مجيد_, _apļa_, aduż, ípu_
  { {0x1dd9014e,0xa5bb005c,0xaa7b0264,0xf773000a}},	//   _बेहत, _ogól, tným, פקח_
  { {0xc6930008,0x6143018f,0x3eb90123,0x2ec30058}},	//   לאה_, _нета, östa_, ثقيف
  { {0x6aa40026,0xb5b70008,0x0137000a,0xc19b000a}},	//   _anif, צליח_, _לרמת_, _גשמי
  { {0xb4fb0135,0x2903060b,0x6ab600da,0xaa7b01c0}},	//   רליר, vlja_, _boyf, sným
  { {0x635c0011,0x2bca000b,0x7ac7004a,0xaa7b0069}},	//   mănă, ानबा, ссое, pným
  { {0xc987006b,0x4974042d,0x0000006a,0x0000006a}},	//   щуни, пляс,   ,
  { {0x66e500df,0xd90f002b,0xac184b79,0x5ba60189}},	//   mėki, عید_, _колу_, _гриз
  { {0x66e500df,0x9cdb011f,0x78ba001a,0xb6c74b7a}},	//   lėki, _תקופ, ötva, бсай
  { {0xbb3b00b2,0xeab7000a,0x8f37000a,0xc639005e}},	//   _געהי, _לִ֖י_, מאלו_, рпає_
  { {0xe4e70036,0x66e50007,0x58d5017a,0x2903044c}},	// [b230] біжн, nėki, _моит, plja_
  { {0x764d0035,0x7aed008c,0x0000006a,0x0000006a}},	//   saay, _hjat,   ,
  { {0x7c2d0064,0x92950033,0x764d02f2,0xdce00085}},	//   _şark, жаец, paay, jumč
  { {0x26d90012,0x66e50091,0x22490030,0x60da4b7b}},	//   _umso_, kėki, úak_, _amtm
  { {0x212a002b,0x60250b1e,0xeab2000a,0x0000006a}},	//   لينی_, одла, וֹג_,
  { {0x66e50007,0x90c5006d,0x8f690015,0xcf590342}},	//   dėki, юбле, لمتك_, арич_
  { {0xaa7b002e,0xc0c80054,0x9ea9261d,0x7e69120d}},	//   rnýj, ључе_, ивка_, tgep
  { {0xc2c50015,0x41e701f3,0x8d550da4,0x0000006a}},	//   _بيري, _ліза, оточ,
  { {0x2d940010,0xfde9002b,0x3cc91377,0x7e694b7c}},	//   прэс, جکاو_, илио_, rgep
  { {0xcd2806e4,0xcce50029,0x7e6900b8,0x7aed0044}},	//   حسين_, تسعي, sgep, _ajat
  { {0x6a860661,0x8afd002a,0x6488000a,0x0aea004a}},	//   олна, dręb, זְרְ, идой_
  { {0x66e50007,0x93fa000a,0x644a0030,0x9f050015}},	//   bėki, ילתי, ófiz, _بوصو
  { {0x527a0053,0x272e002e,0x0f180087,0x3e32006e}},	//   סנשא, _sýn_, _اغلب_, _غفور
  { {0x8afd0f9a,0x186a0cb9,0x52b6005d,0x7ebc0152}},	//   stęp, јави_, _अक्स, _dépu
  { {0xd7f20029,0x76b60054,0x0000006a,0x0000006a}},	//   ذكر_, ољац,   ,
  { {0xcf920008,0x78a50293,0x672f0046,0x46a30033}},	//   וטל_, _enhv, _žijí, масв
  { {0x2bc1005d,0x0b170029,0x89360021,0x673c00aa}},	// [b240] शनका, _بقية_, _بعبا, sprj
  { {0x4aa8000b,0x63be4b7d,0x0000006a,0x0000006a}},	//   गावव, typn,   ,
  { {0x987b0053,0x7ebc00dc,0x6d460227,0x98a9002a}},	//   _דריק, _képt, ákaz, _stać_
  { {0x42560036,0xf1db005d,0x68fc4b7e,0x6b7a004c}},	//   ітет, _मेहन, lord, ירענ
  { {0x68fc4b7f,0x9c7c3bdf,0x0000006a,0x0000006a}},	//   oord, liče,   ,
  { {0x68fc1893,0xd0d7005e,0x399b015b,0xdce90046}},	//   nord, одії_, יינד, čněn
  { {0xf8b30008,0x9c7c4b80,0x8fa30054,0x2d9902de}},	//   ושג_, niče, даје, æsen_
  { {0x1ef70029,0xbdb407c1,0xb5fb0125,0x7ebc0030}},	//   يعية_, збиј, _gcás, _népt
  { {0xb05a0115,0x30760080,0x68fc4b81,0x0caa0317}},	//   _نشاط_, _мужс, kord, атни_
  { {0x7ebc0152,0x66e50007,0x2b470026,0x8afd002a}},	//   _répu, rėki, _bwnc_, kręc
  { {0x2fe60015,0x7ebc0003,0x9c7c0085,0x6d4f016e}},	//   _بكاف, _sépu, jiče, ácar
  { {0x8afd005c,0xb882006f,0x25740123,0xdfcf0040}},	//   dręc, _šípo, käl_, _جيم_
  { {0xfd380029,0xacea0036,0xae16000b,0x68fc4b82}},	//   _اكتب_, _кмда_, देशन_, ford
  { {0x2bca000b,0x9c7c00bc,0xab78002b,0xc7c7006b}},	//   ानदा, fiče, _همتا_, осби
  { {0xcb670001,0xd6db4b83,0xf7940033,0x3ea64b84}},	//   _даје_, ата_, марэ, _knot_
  { {0x75e70033,0x9a270015,0xa53508f7,0x25740123}},	//   оўзе, _بعثن, знач, fäl_
  { {0x38c90086,0xdb17002a,0x15090015,0x68fc4b85}},	// [b250] _هادی_, ńców, مْرٍ_, bord
  { {0x7afd4b86,0x68fc050d,0x9c7c07c4,0x9984002b}},	//   lost, cord, biče, _کلیو
  { {0x7afd0e95,0xc2d9002b,0x83ab0323,0x9c7c005a}},	//   oost, رباﻳ, штаб_, ciče
  { {0x8c1b000a,0x3949002a,0xd7fa000a,0x42d802a3}},	//   בובי, _kwas_, _להתל, офія_
  { {0x66c3007c,0x7afd4b87,0x26c50091,0x7ebc0030}},	//   _lõkk, iost, ūlos_, _léps
  { {0xe0d80191,0x55ba0008,0xfbca000b,0xd12e0040}},	//   ові_, _המשו, ानाम, دمو_
  { {0x7ebc00dc,0x12e70036,0x387c00c0,0x96bf000b}},	//   _néps, _діаг, _övre_, _एकाउ
  { {0x0ea9005f,0xee390063,0x7afd0371,0x68fc00d4}},	//   ский_, щни_, jost, zord
  { {0x3f9e0084,0x68fc01e2,0xc10503c4,0x9c7c00bd}},	//   _ertu_, yord, _فوري, ziče
  { {0x2b470176,0x3ea6431b,0x7ebc0077,0x34b6000a}},	//   _pwnc_, _enot_, _sépt, ִ֤ים_
  { {0xfaaa0029,0x68fc4b88,0xa3c4000b,0x3949088a}},	//   مهدي_, vord, एनए_, _awas_
  { {0x7afd4b89,0xef0e0036,0x9c7c04c0,0x63b8063b}},	//   gost, _їм_, viče, øvni
  { {0x99160010,0x2d910024,0x224d17cd,0x6da50588}},	//   зьві, āzes_, _meek_, _хила
  { {0xa3bd005d,0x257400c0,0xcdb6000a,0x224d1e33}},	//   ेना_, väl_, _מפנה_, _leek_
  { {0x07a3110c,0x68fc4b8a,0x7afd4b8b,0xdbf70058}},	//   нарн, rord, bost, _بأشع
  { {0xcf9200b2,0x7afd4b8c,0x68fc4b8d,0x9c7c06c0}},	//   עטן_, cost, sord, riče
  { {0x05664b8e,0xc5660063,0x38b400b8,0xa2bf005d}},	// [b260] яван, якак, _märz_, _वक़्
  { {0x9c7c10cd,0x799b000a,0x5503011a,0x77ca03de}},	//   piče, _פשיס, епуб, _глог_
  { {0x7ebc0152,0x38cb002b,0xb8e2000b,0x88bb000a}},	//   _mépr, _دايی_, ूस_, _המיז
  { {0xc7b300a3,0x7ebc01f6,0x0000006a,0x0000006a}},	//   _טבת_, _lépr,   ,
  { {0xd24f00b0,0x28b0000b,0x171b004c,0x76440061}},	//   انه_, ञापि, _לוטע, mbiy
  { {0x7afd1ad1,0x2005037f,0x7ebc0030,0x442d0054}},	//   zost, _byli_, _népr, _јe_
  { {0x44441ee1,0x645c4b8f,0xd00f0021,0x644e003d}},	//   mb_, _idri, هله_, _iebi
  { {0x4444018b,0x9f5e002a,0xbd6a004a,0x224d4b90}},	//   lb_, _śród_, брое_, _geek_
  { {0x644e064e,0x44444b91,0x7afd4b92,0x7cfd0144}},	//   _kebi, ob_, vost, tèrp
  { {0xdb1b0014,0x7afd005c,0x3157000a,0x113b000a}},	//   sztü, wost, _מימן_, _לתמל
  { {0x28b0005d,0x5477000a,0x103b000a,0x7ebc0003}},	//   ञानि, הגיע_, _הגבע, _dépr
  { {0x7afd0a6f,0x644e013c,0xa9790033,0x672600bc}},	//   uost, _lebi, ойму_, _nikj
  { {0x0e9b0008,0x3c460029,0x3257000a,0x645c4b93}},	//   _לשאל, _فَإِ, הסכם_, _odri
  { {0xdfc60015,0x8cf40015,0x644e1f6d,0x66c3007c}},	//   ني_, _تكتش, _nebi, _tõkk
  { {0x6280018c,0x6c7b009d,0xbc7b0008,0x44444b94}},	//   _obmo, _האופ, _הנות, db_
  { {0x96d8005d,0xb603002c,0x37041a11,0x7bcb000a}},	//   नोलॉ, úšob, ечув, _לֶחֶ
  { {0xc42b0029,0xdb1b062e,0x442a0012,0x6564007c}},	// [b270] مثال_, sztó, _bgb_, grih
  { {0x224d003e,0x2907002d,0xc952000a,0x442b0033}},	//   _seek_, _óna_, _שמי_, сцам_
  { {0x65640064,0xa87a000a,0xd8d8004c,0x645c0034}},	//   arih, _ואתר, _מוזט_, _ddri
  { {0x66ca0227,0x44440dfa,0xf4100015,0xa635005e}},	//   _týka, ab_, اؤك_, _інгі
  { {0xda7c0053,0x9c7c0007,0x44440832,0xc692004c}},	//   מנאר, anči, bb_, _סאך_
  { {0x224d15fc,0x644e4b95,0x63a10030,0x6aba0065}},	//   _week_, _gebi, _álno, _उक्र
  { {0xb606002c,0x73c50018,0xf838000a,0x7ebc0003}},	//   _vráť, _غيرم, הנות_, _répr
  { {0x3eb9002e,0xa2b50010,0xd346002b,0xa5bb0125}},	//   ðst_, _ўбач, _آینه_, _agói
  { {0x80270086,0x628b4b96,0xcee80058,0x7bc10416}},	//   _فرام, mego, ثرون_, wylu
  { {0x602300dc,0x7b330045,0x9c7c0046,0x76440061}},	//   _címü, _dăun, vičc, zbiy
  { {0x2ca700b8,0x6d400064,0x765d002a,0x62994b97}},	//   _vnnd_, apma, _odsy, odwo
  { {0x628b02ea,0xbe150115,0x539a000a,0x63a3008c}},	//   nego, _قواع, קירו, änny
  { {0x8ed6000a,0x6e440015,0x5e440015,0xed4e4b98}},	//   _קונצ_, _أنهم, _أَهْ, _шо_
  { {0x66060293,0x6f091915,0x628b2a67,0x0000006a}},	//   _rykk, llec, hego,
  { {0xa3dd005d,0xd7060036,0xaae60015,0xf092000a}},	//   _तेल_, дзви, _يسعو, כנם_
  { {0xcaf60029,0x628b01a3,0x44440034,0xd70a0033}},	//   _تستب, jego, wb_, інае_
  { {0x764f005c,0x75270111,0x9c7c0263,0xcb13000a}},	// [b280] _decy, _bijz, liča, _בלה_
  { {0x6f0900b8,0x44444b99,0xf993000a,0xbb39000a}},	//   hlec, ub_, _ירח_, ַעְי
  { {0xe29a0010,0xd4d50010,0xd90d002b,0x2cfa004c}},	//   жае_, хітэ, _طیف_, קלעא
  { {0xfbd20008,0x51861c64,0xfbb6000a,0xc7b3000a}},	//   כתב_, дука, ופעת_, _סבר_
  { {0xdce00011,0x6f090a56,0xaa7b001a,0x290a05ca}},	//   numă, dlec, mnýt, olba_
  { {0x6f02005c,0x75270079,0x6f094b9a,0x70540058}},	//   _skoc, _gijz, elec, رنبا
  { {0xdfd0003b,0x6f0903fe,0x9c7c0160,0x0000006a}},	//   طية_, flec, jiča,
  { {0x6f090838,0x24984b9b,0xf773000a,0x23770046}},	//   glec, _harm_, דקה_, žejí_
  { {0x8c8a0054,0x6d40001a,0x2498007c,0x22464b9c}},	//   ољна_, upma, _karm_, mbok_
  { {0xa2da014e,0xc1bb000a,0x91bb000a,0x9c7c0085}},	//   पोर्, _וממש, _וממי, fiča
  { {0x6f090467,0x7d0800c0,0x7bf70010,0x8cd4000b}},	//   blec, rlds, днэр_, योगो
  { {0x7c2d01e2,0xddc6004a,0x0357004c,0x6f02002a}},	//   _şart, _обеи, ויטש_, _ukoc
  { {0x7c930086,0x4dd30015,0xfaff00aa,0x7a040033}},	//   رشیا, _لتوس, roë_, вярж
  { {0x7b760018,0x9c7c0263,0xab97002b,0x26f9000b}},	//   _قطعا, biča, أخیر_, ूत्र_
  { {0x67d50036,0xd7e40036,0x764f0026,0x62990535}},	//   хову, віто, _pecy, ydwo
  { {0x290a0205,0xef11000a,0x99d70015,0x9f97000a}},	//   alba_, ָּל_, _يتظا, ודלה_
  { {0x99480029,0x082b0015,0x224600d6,0x0000006a}},	// [b290] _قليل_, _وأدى_, dbok_,
  { {0x6f092adb,0x63e70058,0x2cbc0546,0x0000006a}},	//   zlec, وساك, _jovd_,
  { {0xdce9016f,0x6445002d,0x7aef0152,0x6f0929d6}},	//   steć, rbhi, onct, ylec
  { {0x75270298,0x21750036,0xd25b0010,0x628b0077}},	//   _wijz, еукр, іце_, uego
  { {0xc2440010,0x24980708,0x9c7c016f,0x463a01ac}},	//   тнік, _farm_, ziča, _מערע
  { {0x4f95000d,0x3cf8000b,0x6f09002a,0xaf950004}},	//   ериу, ँवों_, wlec, ешиј
  { {0xfe710029,0x656d00d9,0x628b1f13,0x9378116f}},	//   هدة_, luah, pego, _обрт_
  { {0x273500c0,0x6d5d0091,0x9c7c0aee,0xf53f0ef2}},	//   _mån_, šsam, viča, _tråd_
  { {0x9980005c,0xada50010,0x22680046,0xd109002b}},	//   _dziś_, хапл, ítků_, _فقره_
  { {0x91e40124,0x9c7c016f,0x7aef0026,0xc4d20053}},	//   _рође, tiča, enct, ָגט_
  { {0x3cf0000b,0x20ac000b,0xd910002b,0x7c940033}},	//   ीक़े_, चारध, ییع_, трыц
  { {0x5f740015,0x9c7c0a30,0x6f48004f,0x5ea40058}},	//   _جاكر, riča, _חֲסַ, _لممل
  { {0xf217005d,0x9c7c0844,0x9d75004c,0xc9560033}},	//   _तरफ़_, mičn, _נײַס_, этны
  { {0x6c7900b2,0x317a000a,0x25f3000b,0x26c90085}},	//   _זאַפ, הרשמ, ंपनी_, ekao_
  { {0x9cd60008,0xac160001,0x97c60021,0xe9df001a}},	//   _רוצה_, _пољу_, رتسم, rbúa_
  { {0x7bda0008,0x66ca0264,0xfaf20015,0x9c7c2ed8}},	//   _מקצו, _výko, _حثت_, ničn
  { {0x27ff0064,0xaa7b001a,0xfaf7004f,0xf60a009a}},	// [b2a0] ğuna_, rnýt, _רצפי_, ستره_
  { {0xca4a0086,0x27ff0064,0x85060018,0x98a40024}},	//   _بلکه_, şuna_, روان, īmē_
  { {0x929d0050,0x2246003c,0xaa9a000a,0x8266006e}},	//   _skła, tbok_, ּבְכ, فهان
  { {0x8ca1000b,0x9c7c00bc,0x7ae64b9d,0x24984b9e}},	//   _कोसो, jičn, nikt, _warm_
  { {0x32650036,0x27f20024,0xb2d30015,0x9c7c25b6}},	//   ттєв, šanā_, دينغ, dičn
  { {0x7ae60111,0xc953000a,0xdd32002a,0x22460795}},	//   hikt, נמו_, ręży, sbok_
  { {0x9c7c01a3,0x929d002a,0xa87b004c,0x7f180021}},	//   fičn, _wkła, פאקר, ويتز_
  { {0xc7b30008,0x877b0053,0xdd900115,0x2583003d}},	//   רבה_, לאצי, لوب_, bīlā_
  { {0x929d005c,0x00860004,0xadd40054,0x7ae61a1b}},	//   _ukła, _плао, топљ, dikt
  { {0x23670a00,0x7ae60cd4,0x2a6001d7,0x515b000a}},	//   šnje_, eikt, _adib_, _מכמו
  { {0xdeef0802,0xc4d30008,0x9c7c29b6,0x5ba3004a}},	//   _бы_, רגת_, bičn, гряз
  { {0x273500c0,0x7ec60003,0xcfd20061,0xbe850015}},	//   _rån_, _dépê, ışır_, _لجهو
  { {0x6ce600e2,0x66ca01c0,0x5887004a,0x0c95009a}},	//   _піке, _výkl, ныва, ردیگ
  { {0x52bd000b,0x29050016,0xdde9002b,0xc213000a}},	//   _ऍक्स, ôla_, _ترمه_, טהר_
  { {0x394001d7,0xf53f0cbb,0x9c7c04b2,0x5bc3012c}},	//   _etis_, _stå_, ličo, _مقول
  { {0xf1c60023,0x7ae626b6,0x7c250107,0x3b53006b}},	//   _đánh_, cikt, _úhra, _скър
  { {0x6aad003f,0xdce90011,0xe4750054,0xbafc000a}},	// [b2b0] _inaf, _înăl, клањ, _מההש
  { {0x47350760,0x656d01c2,0xd6240015,0x9c7c427c}},	//   _инос, ruah, اعِي, zičn
  { {0x2903000c,0xa295005e,0x7c3a0125,0xf8dc000a}},	//   moja_, кажі, ictr, _מחזמ
  { {0x290300f2,0xddc90011,0xd6db05fc,0x97a8000a}},	//   loja_, ngeţ, _хто_, _נֹתֵ
  { {0xd656000a,0xca38000a,0xcad8000a,0xcb140643}},	//   _בירת_, גנדה_, עודת_, אלף_
  { {0x2903022d,0x9c7c0264,0x9105006b,0xc1040015}},	//   noja_, dičo, ъпле, هوني
  { {0x9c7c0198,0x6aad0150,0x883c0447,0x69c60046}},	//   tičn, _onaf, הגות, zyke
  { {0x2903008c,0x7fe800c3,0x3dd2002a,0x64574b9f}},	//   hoja_, عروف_, _żywa_, laxi
  { {0xdd8e0015,0x213f013c,0x9c7c2f84,0x39c6000b}},	//   قوي_, _utuh_, ričn, रैफ़ि
  { {0x6aad4ba0,0x2903180a,0x9c7c4291,0x2d9f0003}},	//   _anaf, joja_, sičn, rvue_
  { {0x7ae64ba1,0x29030f28,0xd10e000b,0x9c7c0263}},	//   tikt, doja_, ितरण_, pičn
  { {0x9ee90015,0xdd8e002b,0x6e1900c3,0xcf92000a}},	//   _تفصل_, حوی_, _قياس_, _כטב_
  { {0x7d014ba2,0x1dd9000b,0x7ae64ba3,0xbd89002b}},	//   pols, _बेचत, rikt, _آنتن_
  { {0x80b9000b,0x7ae64ba4,0x394000bc,0xd943005e}},	//   ्सटे, sikt, _vtis_, рери
  { {0xd7060029,0x66e64ba5,0xd876002b,0x6d5b01d7}},	//   نظري, вова, _یادب, lsua
  { {0x24640048,0xe3b20086,0x6e3b4ba6,0x96630555}},	//   zīmē_, یرا_, ncub, иксе
  { {0xe4d7002b,0x6d5b4ba7,0x78be0ffd,0x29034ba8}},	// [b2c0] چوقت_, nsua, _topv, boja_
  { {0xdce0003d,0xb957000a,0x1957000a,0x0446009f}},	//   ormā, _שייח_, _שביל_, тежн
  { {0x6d5b01c2,0xe5050015,0x7ae44ba9,0xf7460099}},	//   hsua, ابقي, _kmit, _шено
  { {0x6146008f,0x25ad00bd,0x3bba004c,0xdce0003d}},	//   веда, _šele_, ומעד, irmā
  { {0x28a7000b,0xa9ed000a,0x6fb3002b,0xd130006e}},	//   खाचि, ּחוֹ, یمها, حمت_
  { {0xe04a0086,0x89db000a,0x04434baa,0x2fc70034}},	//   ذشته_, וחני, _верн, fyng_
  { {0x6d5b0509,0x5f730015,0x7ae403b8,0x84e3030c}},	//   esua, لاير, _omit, _торж
  { {0x3da6005e,0x93fb000a,0x0cca000b,0x68e70079}},	//   вроб, _חללי, िस्म, zijd
  { {0x127b0053,0x52d7004c,0x5bca000b,0xb2370015}},	//   _קאמע, _סומע_, ान्व, _شكلا_
  { {0x4c940124,0x628200dd,0xe611000a,0x6cd40015}},	//   ћинс, lfoo, מִי_, اقدا
  { {0x9d130010,0x29031b86,0x8e860015,0x9c7c006f}},	//   рдэч, voja_, _للاه, sičo
  { {0xdb140084,0x68e70111,0x2903005c,0x1eea002b}},	//   ðaða, wijd, woja_, _کوچی_
  { {0x2903022d,0xddc904f9,0x68e70111,0x80b9000b}},	//   toja_, rgeţ, tijd, ्सचे
  { {0x86c5002b,0x29030d91,0x9f580030,0x3cc7067a}},	//   گيرن, uoja_, _áró_, _илчо_
  { {0x68e70111,0x29034bab,0x37070342,0xc7c41cd9}},	//   rijd, roja_, вчав, асти
  { {0x9bb7013a,0x8f9b0135,0x6aad06e8,0x86c50015}},	//   _יהוה_, וילי, _unaf, ديرن
  { {0x2bca005d,0x96340010,0x929d005c,0x95540021}},	// [b2d0] ानका, рнуц, _skło, لخلا
  { {0xe5700029,0x6d5d0f08,0xca2a004c,0x89da002b}},	//   تطف_, ásai, _אופֿ, _سوپر_
  { {0xed460086,0x44271b45,0x7e6204b2,0x64574bac}},	//   _گپ_, än_, _odop, raxi
  { {0x6d5d0048,0xe8e10092,0x7b350053,0x628210df}},	//   šsai, _đột_, אָסע_, gfoo
  { {0x208901b7,0x6d420045,0x9c7c0046,0x6f190034}},	//   ейли_, _ntoa, tičl, _rhwc
  { {0x41040036,0xaf99057e,0x7e62352d,0x6282007c}},	//   азів, етих_, _adop, afoo
  { {0x2f540010,0x6fb50015,0x929d002a,0xd006029f}},	//   атыс, امعا, _ukło, леше_
  { {0x200c0026,0xdd9100e5,0x02a42fe4,0x02440058}},	//   _dydi_, موع_, _крум, _نَفَ
  { {0x26b6000a,0xa1940004,0x63ab002a,0x6e3b4bad}},	//   אִים_, _катч, łonę, rcub
  { {0x6e3b0896,0x645518e6,0x7ae44bae,0x9c7c06c0}},	//   scub, _jezi, _smit, ličj
  { {0xd0110029,0x7e6e002d,0x645506d5,0xa3d6000b}},	//   _الا_, áipé, _mezi, िनय_
  { {0xcf270074,0xa96a4a11,0xd9464baf,0x63b80123}},	//   _شراي, нима_, леми, ävni
  { {0x527a0053,0x60c109e7,0xdbc90020,0xc27a004c}},	//   ענשא, _kolm, _rõõm, ערשי
  { {0x8d5a0008,0xf74a002b,0x66d10123,0x64552cea}},	//   _טכני, فجره_, _råka, _nezi
  { {0x7bc8005c,0xb736002b,0x66d101f0,0xac091301}},	//   cydu, افرب, _såka, _янка_
  { {0xdb040003,0x66d104d1,0x0000006a,0x0000006a}},	//   _orné, _påka,   ,
  { {0x64550596,0xdb09002b,0x4e36004c,0x25a60125}},	// [b2e0] _bezi, _جزوه_, אָבן_, íol_
  { {0x77940086,0x94a90015,0x89db000a,0x394d0045}},	//   _پیرا, َالِ_, _נחיי, ţesc_
  { {0x287b00f3,0x64554bb0,0x78ba001a,0x987b000a}},	//   _אנימ, _dezi, ötvu, _אריק
  { {0x236700dc,0xe1fa0b98,0xd6c3009a,0x44310535}},	//   ánja_, нге_, _همپی, _egz_
  { {0xa0540036,0x20540033,0x21760004,0x7bc80535}},	//   авлі, акля, ѓудр, zydu
  { {0xa50a0001,0xcf9a0001,0x236701a3,0x987a004c}},	//   _чега_, еји_, šnja_, גאַט
  { {0x26c2022d,0x7f830015,0x60c14bb1,0xe398000a}},	//   _koko_, ملون, _dolm, _בֹּש
  { {0x26c2160f,0x8fa30054,0x6da40015,0x4d880058}},	//   _joko_, саће, لمعم, نَعُ_
  { {0x3d260036,0xb23b0053,0x7ebc00dc,0x50464bb2}},	//   льов, _װעבז, _képz, _безб
  { {0x859700b2,0x55970053,0x200c0026,0x9c7c18b1}},	//   נדיג_, נדיע_, _tydi_, mičk
  { {0xfaf90024,0xee8604f7,0x34b7000a,0xa4b7000a}},	//   krīt_, _было, אפים_, אליה_
  { {0xbda60070,0x39520026,0xdfcf0031,0xdc3c0060}},	//   _محتو, _bwys_, _عين_, mšči
  { {0xdc3c00bd,0x6d42003f,0x9c7c06cf,0x7bda12e0}},	//   lšči, _utoa, ničk, sztu
  { {0x4ddb0008,0xd0060115,0x39520034,0xe1ee0033}},	//   _אחדו, قل_, _dwys_, ўгi_
  { {0xdc3c018c,0xbb4305e6,0x9c7c0085,0x7c3b000a}},	//   nšči, _лејк, hičk, _אגוז
  { {0x645502d7,0x501b0008,0xdc3c00bc,0xcf57004f}},	//   _sezi, תולו, išči, טבלת_
  { {0xa3dd000b,0x16380015,0x545506c3,0xc9870015}},	// [b2f0] _तेज_, اسفة_, иват, _إشبي
  { {0xf53f27a9,0xdc3c00df,0x41b5002b,0xfaf9003d}},	//   _från_, kšči, یمار, arīt_
  { {0x9259005f,0x5c370053,0xdc3c00bd,0x2815002b}},	//   вает_, ארבן_, jšči, _خودس
  { {0x9c7c016f,0x60c14bb3,0xdc3c00bc,0x9948002b}},	//   fičk, _solm, dšči, _جلیل_
  { {0xb4650086,0x865a0008,0x66d100cb,0xe1670054}},	//   _نگاه, _בדרי, _håko, уђен
  { {0xf9580008,0xe057002b,0x1958000a,0x3d14000b}},	//   נסות_, ایات_, נבול_, _नीले_
  { {0x7b220003,0xc0580067,0x9c7c00bc,0x389c000a}},	//   _mœur, اشها_, pičj, גיונ
  { {0x0ea9006d,0x8d650184,0x1619000b,0x9c7c1c6d}},	//   ткий_, авие, _दरार_, bičk
  { {0xdc3c00bc,0x764d01d7,0x60c14bb4,0xe6c8004f}},	//   ašči, ibay, _tolm, ר֔וֹ_
  { {0x660f01d1,0x69dd00dc,0x63a2005c,0xdc3c00bd}},	//   _myck, dzse, łone, bšči
  { {0x660f00c0,0x764d02f2,0x0000006a,0x0000006a}},	//   _lyck, kbay,   ,
  { {0x2d990134,0xef0e005e,0x0376000a,0x39520034}},	//   æses_, _єм_, סתרת_, _pwys_
  { {0x660f00c0,0x19fa0010,0x656d01c2,0x26c21289}},	//   _nyck, тэнь_, jrah, _roko_
  { {0x6d49002f,0x99060001,0x7c940063,0x4dda000a}},	//   mpea, ртмa, _гръц, _בחנו
  { {0xd63a0010,0xf6560a61,0x9c7c0263,0x6d494bb5}},	//   вязі_, итаю, zičk, lpea
  { {0x764d00b6,0x6d5d0007,0x9bfa000a,0x6d49008c}},	//   gbay, šsau, _בהצט, opea
  { {0x656d0005,0xceb20008,0x7afd00dc,0xf50a0004}},	// [b300] grah, חין_, érte, внал_
  { {0x6d49002d,0x764d4bb6,0x9c7c2398,0x2ed20065}},	//   ipea, abay, vičk, _तत्त
  { {0xb4db0251,0x26c200e8,0x66ec0064,0x656d4bb7}},	//   _itàl, _toko_, aşka, arah
  { {0x9c7c010b,0xdc3c00bd,0x8c1a000a,0x9343005e}},	//   tičk, všči, דועי, інче
  { {0xcb13000a,0x70560015,0x60560015,0x67243268}},	//   קלד_, لنشا, لنشط, mmij
  { {0x9c7c010b,0x3f66023e,0x273c4bb8,0xdc3c00bc}},	//   ričk, атиб, _kín_, tšči
  { {0x2b06000b,0x2f01006f,0xdc3c2ca2,0xb4fb000a}},	//   रवाँ_, lógy_, ušči, _ספלי
  { {0x273c0084,0xbe8a0001,0xdc3c3713,0x539b000a}},	//   _mín_, тске_, ršči, _בילו
  { {0x273c002d,0x9c7c4438,0x6724008c,0x50960054}},	//   _lín_, liči, imij, _вређ
  { {0xdc3c00bd,0xccb80036,0x4cb8005e,0xba3b0034}},	//   pšči, угої_, улою_, ddïa
  { {0x764d00b6,0xdce90064,0x2d990134,0xbe6600e5}},	//   ybay, steğ, æser_, _نهاي
  { {0x7b220003,0xeef50033,0x66d101de,0x69dd02ad}},	//   _sœur, _лячэ, _råko, tzse
  { {0x29870033,0x8ca1000b,0xdebb004f,0xdd900058}},	//   шынг, _कोको, _שמדל, _روث_
  { {0x386d00b8,0xa3d6021e,0x2ddb000a,0xbd43002b}},	//   ßer_, िना_, _שַׁב, _بنوي
  { {0x386d01e2,0x66ca002e,0xdce00089,0x57a43448}},	//   ğer_, _lýku, zumě, ошта
  { {0x96f80001,0xba550054,0x386d0061,0x764d02f2}},	//   аест_, _увиј, şer_, ubay
  { {0x7d08020a,0xef110053,0xbafc000a,0x8afc000a}},	// [b310] oods, פּל_, _שהחש, _שהחי
  { {0xb895003b,0x95c40015,0x93a7004a,0x04590015}},	//   _الدع, غيله, ишед, الاة_
  { {0xd2510029,0x656d0e95,0xb5fb0046,0xd1b8002b}},	//   كنا_, srah, _zdál, یاها_
  { {0x660f00c0,0x236700bd,0x56940286,0x4734002b}},	//   _tyck, šnjo_, _дают, _گریز
  { {0x471a0008,0x2178004a,0x9564006b,0xe1f0012c}},	//   _תורג, ийцы_, _мърд, وسه_
  { {0x6f650015,0x6536000a,0x66d801c0,0xe572004f}},	//   مهتم, _לאשף_, _víke, _צַר_
  { {0x225b0015,0x7d08005a,0xc0c800af,0x0000006a}},	//   _لجذب_, dods, јуче_,
  { {0x77f80008,0x47f8000a,0x62d90033,0x29f80016}},	//   ימוד_, יצול_, _ёмаў_, ọai_
  { {0x50670029,0x6d490003,0xbd86002b,0x7b330045}},	//   _نطاق, upea, مچون_, _lăut
  { {0x2ba50048,0x25ff000b,0x67240085,0xb4450033}},	//   _pēc_, _रखनी_, zmij, амiч
  { {0xc10400e6,0xeb06005e,0x59e0000b,0xe217000b}},	//   _بولي, йпоп, _पेजर, _तरुण_
  { {0x6d4914dc,0xeec4002b,0xb2b9004f,0x0000006a}},	//   ppea, _ويلپ, אמֹר,
  { {0xfe700086,0x273c002e,0xd141002a,0xdca50c7c}},	//   _زدن_, _sín_, _ująć_, _гали
  { {0xbbe80086,0x2eed0220,0x7b330045,0xaba90015}},	//   اریم_, lief_, _băut, _مهتم_
  { {0x7b3304f9,0xb8f0005d,0x9d1a000a,0x366a4bb9}},	//   _căut, _शव_, _גוסט, лаво_
  { {0x3ebf0049,0x6eb0000b,0x9c7c4bba,0xa6b5004a}},	//   njut_, झाएँ, viči, осущ
  { {0xf7720086,0x99860029,0xb5fb0089,0x54360015}},	// [b320] _کاخ_, _الخو, _udál, مرار
  { {0x273c0023,0x656b0030,0xdce91c4e,0x67244bbb}},	//   _tín_, ágha, kreč, smij
  { {0x889b000a,0xb89b000a,0x1d16004c,0x74130015}},	//   _גביי, _גביש, צקער_, كوكا
  { {0x71660015,0x2bf6004c,0x9c7c4bbc,0x290a4bbd}},	//   ماتك, זמען_, riči, loba_
  { {0x52830015,0xa0a60033,0x0000006a,0x0000006a}},	//   سلوك, йадд,   ,
  { {0xc953000a,0x70530015,0x26c00085,0x15430515}},	//   למד_, كنها, ljio_, _херм
  { {0x6576008c,0xe0850015,0xdce90091,0x7d08174f}},	//   luyh, تجني, greč, vods
  { {0x2eed020a,0xb3f7000a,0xc7b3000a,0x645e4bbe}},	//   gief_, _המלח_, לבו_, lapi
  { {0x290a0b6c,0xe1fa0033,0x7cd8125c,0x5d830058}},	//   koba_, _сга_, имир_, كليل
  { {0x645e1636,0xf36a000a,0x459b000a,0x0000006a}},	//   napi, ְדָּ, נסיע,
  { {0x8afd002a,0x6d5d001a,0x94bb000a,0xac180839}},	//   kręt, ásar, אמית, рону_
  { {0x3f9e31b0,0x645e4bbf,0xee3a022a,0xf8d1000b}},	//   _istu_, hapi, _снд_, हस्प
  { {0x09e40033,0x645e4bc0,0x2e160015,0x7d0800bf}},	//   зоўн, kapi, _اباح, pods
  { {0x7d7b015b,0x645e05ff,0xdca31afd,0x1bd44bc1}},	//   _ענוו, japi, _начи, _моля
  { {0xccf80089,0x2d840064,0x7b460087,0x67d4405a}},	//   mně_, ltme_, _ائتل, пору
  { {0xccf80089,0x1bf7000a,0xbb470015,0xbbf7000a}},	//   lně_, _לצור_, _الين_, _לזוז_
  { {0x634500df,0xfaf80086,0x09e40054,0x95570015}},	// [b330] _mėne, _دروغ_, _ноћн, إخرا
  { {0x645e00b6,0xccf80089,0xa3570029,0x3f9e0020}},	//   gapi, nně_, مخصص, _ostu_
  { {0x16350080,0xe4c4004a,0x2d84007c,0x93880033}},	//   _меня, чётн, htme_, йсца_
  { {0xdb7b004c,0x7aef4bc2,0xeb97000a,0xe3c40015}},	//   רנאכ, nict, מדבר_, ثْمَ
  { {0x4a9c000a,0x416b0054,0xccf80046,0xa5bb0030}},	//   טיאג, ујем_, kně_, _szóf
  { {0x661d0048,0xccf80089,0x9fc90175,0x645e0738}},	//   _izsk, jně_, игла_, capi
  { {0xccf80089,0x2eed09f2,0xa87c004c,0xff2501c5}},	//   dně_, tief_, טאגר, омко
  { {0xee390b97,0x9758000a,0xef19012e,0x63b4013f}},	//   шни_, זיהו_, јми_, šený
  { {0x0c950010,0x66d1003c,0x8c9502e1,0xdce900bd}},	//   ошня, _påkj, орні, sreč
  { {0xe4560053,0x2eed0159,0xdce90796,0x6f040844}},	//   ֿירט_, sief_, preč, čica
  { {0x66d8002e,0x3949013c,0xeaba4bc3,0x7aef158f}},	//   _líka, _atas_, айн_, fict
  { {0xeb96005f,0xc9aa000d,0x3b0a0036,0xccf80046}},	//   цию_, авме_, ремо_, aně_
  { {0xdd94008f,0xccf80089,0x44260092,0x645e003f}},	//   _нацы, bně_, ̀o_, yapi
  { {0xccf80089,0x6efe0024,0x26d90334,0x00b9000a}},	//   cně_, mība, _also_, ׁמָמ
  { {0x6efe0024,0x8afd002a,0xd826005e,0x645e4bc4}},	//   lība, tręt, ідби, vapi
  { {0x7e7b41ca,0xa6860033,0x3dd2002a,0x464a0763}},	//   ngup, ўлад, _żywi_, рзан_
  { {0x05660191,0x6efe0024,0x959a0054,0xe45a0a0b}},	// [b340] юван, nība, штву_, ижа_
  { {0xdb2100f2,0x6aa44bc5,0xa3d5000b,0xd46a004a}},	//   ätök, _haif, ाईं_, риже_
  { {0x645e2664,0x23b30015,0xfa76000a,0x39840da7}},	//   rapi, ومكس, ַעַת_, lös_
  { {0xccf80089,0x673a00dc,0x130a0088,0x599a000a}},	//   zně_, ítju, шней_, ֹשַׁ
  { {0xccf80089,0x7643002a,0x39844bc6,0x4153008b}},	//   yně_, śnyc, nös_, двіс
  { {0x3d03005d,0x6efe0024,0x3cf5005d,0x25ff005d}},	//   रकों_, dība, ीकों_, _रखती_
  { {0xc059008f,0xccf80089,0xa857000a,0x04430033}},	//   сіі_, vně_, קיקה_, _цесн
  { {0x76440061,0x5d540923,0xa2d60015,0xeeb80ffe}},	//   nciy, пкит, _بيرت, слиш_
  { {0xccf80089,0xdd900002,0x016309fe,0x645c4bc7}},	//   tně_, رود_, _окто, _keri
  { {0x8cf3008f,0xa5b70008,0x7d230015,0x4fb60015}},	//   дзьц, קליק_, وفين, _وصار
  { {0xccf80089,0xc43b000a,0xd0e7002b,0xd00a0054}},	//   rně_, יתיי, _بکنم_, _теже_
  { {0xccf80089,0x6efe0024,0x9c7c00bd,0xe8e10092}},	//   sně_, bība, viču, _đốt_
  { {0xccf80089,0x6efe0024,0xcce60015,0x9c7c0046}},	//   pně_, cība, _وستي, fičt
  { {0xd8380033,0x645c4bc8,0x7e601c83,0x9c7c00b3}},	//   жэт_, _neri, lamp, tiču
  { {0x7aef003e,0x656401c2,0xf034000a,0x44444bc9}},	//   pict, esih, לָֽי_, dc_
  { {0xf7700029,0x6aa40026,0x44441136,0x656b0030}},	//   ضاف_, _gaif, ec_, ágho
  { {0x645c4bca,0x61e20030,0x7aed4bcb,0x39490030}},	// [b350] _beri, jzol, _imat, _utas_
  { {0x0d150053,0xc952000a,0xe4500015,0x94770015}},	//   ִקײט_, _רמי_, نضم_, تدرا
  { {0x6efe0024,0x889a000a,0x63a2002a,0xa5bb0030}},	//   zība, _הבתי, łonn, _szód
  { {0xf77201ac,0x479a000a,0x1bfb000a,0x44444bcc}},	//   _אקט_, _פירס, סלאב, ac_
  { {0x27ff01e2,0x661d0048,0x78a50706,0xb6ba000a}},	//   ğunu_, _uzsk, _kahv, _הצרי
  { {0x85050074,0x27ff0064,0xcf590063,0x62860a83}},	//   _روزن, şunu_, брич_, _ökon
  { {0xd3430086,0x398400dc,0xe0d00015,0x753d0030}},	//   _آفری, zös_, خزن_, _husz
  { {0x92b70029,0x398400f2,0x6efe0024,0x57fc01ac}},	//   _بحسا, yös_, tība, ילוו
  { {0x645c01e2,0x765d00d9,0x62991c67,0xdea4002b}},	//   _yeri, _mesy, mewo, بینی
  { {0x6efe0024,0x753d4bcd,0x6aa40375,0x64452678}},	//   rība, _musz, _saif, nchi
  { {0x6efe0048,0xeb99013e,0xfaa6090a,0x64454bce}},	//   sība, щин_, пано, ichi
  { {0x6efe0048,0x03d6000a,0x39844bcf,0x7e604bd0}},	//   lībn, פורם_, tös_, camp
  { {0x6e3a000a,0xceb2000a,0x9c7c0046,0xec6e18fa}},	//   _התנד, _ריד_, tičt, _пп_
  { {0x17fa0029,0x39840d9c,0x75354bd1,0x7aed4bd2}},	//   مرأة_, rös_, _nizz, _emat
  { {0x1cba0008,0x753d11e2,0x6aa42d1b,0x3f870085}},	//   _למסע, _ausz, _taif, ntnu_
  { {0x3b07010f,0x64454710,0x6299005c,0x96750033}},	//   _нещо_, echi, jewo, дыфі
  { {0xda7b000a,0xdcfb0045,0x66d8001a,0x753526e7}},	// [b360] _הנפר, ctuă, _fíkn, _bizz
  { {0x753d005c,0x65640509,0x7aed0247,0x3f870085}},	//   _dusz, rsih, _zmat, ktnu_
  { {0x7aed0176,0x2bae005d,0x765d00d9,0x73360115}},	//   _ymat, टिया, _fesy, سرائ
  { {0xd7bb0008,0x64454bd3,0x44442f48,0x78a501a3}},	//   _הצטר, achi, sc_, _zahv
  { {0xa9280007,0x46160086,0x60c828e0,0x503800fd}},	//   pažį, _روسر, _podm, оплю_
  { {0x644502d7,0xe4da0086,0x0ef6000b,0xa91b001a}},	//   cchi, _اوست_, ुक्स_, etþj
  { {0x61e20014,0x083b0053,0x6d4b4bd4,0x6fa70015}},	//   szol, זעצל, _atga, كهوف_
  { {0x33fb000a,0xbdb40054,0xa78d000a,0x6f040085}},	//   _ההלנ, дбиј, ׁאוֹ, čico
  { {0xa11600c3,0x7e6020f8,0xa06a33e2,0xf536004f}},	//   _فورت, ramp, _газа_, ֔נִי_
  { {0xa0c9003b,0x7aed010b,0x7e60013c,0xe10a056d}},	//   _وذلك_, _smat, samp, _уезд_
  { {0x78a50005,0x3f56002b,0x648b004f,0x73fa004f}},	//   _rahv, _رضاز, זְכְ, מּ֛ו
  { {0x2f3b0008,0x7f3b000a,0xdee30818,0x4fbb004f}},	//   _הגאד, _התאג, _похи, _לצבא
  { {0xf2d300b2,0x2d960036,0x765d0026,0xdee500c3}},	//   גער_, _хрес, _resy, _تألي
  { {0x3d14005d,0x6299005c,0x753d0fce,0x23670263}},	//   _नीचे_, zewo, _rusz, šnji_
  { {0x78a5022d,0xc66b0010,0x753d002a,0x75354bd5}},	//   _vahv, йшае_, _susz, _rizz
  { {0xabfb0008,0x753d12f7,0x4b7b000a,0x9c17000a}},	//   _להור, _pusz, _האהו, _מחוק_
  { {0x64454bd6,0xa5bb0030,0xa5350c53,0x7afd0123}},	// [b370] tchi, _szób, днач, mnst
  { {0xda070086,0x3ea602f2,0x3f870046,0x64451852}},	//   _ويژه_, _laot_, ytnu_, uchi
  { {0xdc8b000a,0x629900c7,0xaa7b0264,0x7afe111e}},	//   מְאָ, tewo, chýc, čstv
  { {0x21f50029,0x7afd4bd7,0xe3b00015,0x64450b9d}},	//   وكاس, nnst, درك_, schi
  { {0x35a40010,0x6ec0000b,0x629904a9,0x21690054}},	//   _заўг, वानु, rewo, цили_
  { {0x66d8002e,0x55ba000a,0x25d6000a,0x7afd4bd8}},	//   _líkl, _ומשו, _חושן_, hnst
  { {0xdb2400dc,0x4394070e,0xb4fb000b,0x3f8701ec}},	//   őség, _парс, ्वीप_, utnu_
  { {0xe7dc0008,0xdd9100e5,0xdce200bc,0x1ea90015}},	//   מקוש, نوع_, _dvoč, زاعي_
  { {0xc3320053,0x3f870183,0xfce5135d,0xb5fb01c0}},	//   _יול_, stnu_, допо, _edáv
  { {0xd13104b6,0xa91b002e,0x03d5000a,0x91640015}},	//   _شما_, stþj, ֥וֹם_, _أهله
  { {0xe452004f,0x0000006a,0x0000006a,0x0000006a}},	//   כֶר_,   ,   ,
  { {0xc869013a,0xdb1b002a,0x7afd4bd9,0x26f90065}},	//   _כן_, dytó, gnst, ्कोर_
  { {0xdce200bd,0x6d4b02df,0xc9560138,0x0000006a}},	//   _zvoč, _utga, ьтны,
  { {0xbbe90029,0x225f0079,0xe73a029f,0x7afd4bda}},	//   _ورغم_, _leuk_, жев_, anst
  { {0xaa7b0046,0x97360138,0x0000006a,0x0000006a}},	//   uhýc, дэач,   ,
  { {0x9c08000a,0xcf92004c,0xdb08007c,0x2ca702b3}},	//   _מִפִ, כטל_, öläh, _hand_
  { {0x09060036,0xe7ba000b,0xc9660033,0xf9920015}},	// [b380] _опин, _उपकप, _ўвой, _شبة_
  { {0xa5bb0014,0x0000006a,0x0000006a,0x0000006a}},	//   _szóc,   ,   ,
  { {0x33d5008f,0x2ca70f47,0x39400150,0xaae2000b}},	//   ніцт, _mand_, _huis_, _पताक
  { {0xab620061,0x39404bdb,0x2ca74bdc,0x0000006a}},	//   _şükr, _kuis_, _land_,
  { {0xddc2002c,0x61434bdd,0x394000aa,0xa1580088}},	//   _odoš, веча, _juis_, чалу_
  { {0x39400234,0xddc00091,0x2a600353,0x2ca74bde}},	//   _muis_, samū, _leib_, _nand_
  { {0xa3e6000b,0x3940178e,0xdce0003d,0xaff70015}},	//   _बेच_, _luis_, zumē, وفها_
  { {0xbd6a0080,0x2ca700dd,0x93260067,0x8fa300af}},	//   орое_, _aand_, _آرسن, таће
  { {0xf1aa002b,0x1d34006b,0xdb1b002a,0x2ca74bdf}},	//   _بازه_, нния, zytó, _band_
  { {0x2ca74be0,0x7afd0b58,0x3b544be1,0xdd270058}},	//   _cand_, wnst, нкор, وكيو_
  { {0xc4770008,0xdfa60029,0x4477000a,0xee860033}},	//   ותיו_, _تحذي, ועיל_, _жыло
  { {0x2bac0089,0x394012d6,0x25a002f2,0x7afd3046}},	//   _věc_, _buis_, kwil_, unst
  { {0x2ca72c21,0xb5fb0125,0x3257000a,0x5887056d}},	//   _fand_, _meác, וסכם_, мыва
  { {0xa8030064,0xdfc60029,0x6e220844,0xdd930033}},	//   _çıkm, هي_, _izob, _рашы
  { {0x6c7b000a,0x26cb4be2,0xbc7b000a,0x61240144}},	//   _ואופ, _poco_, _ונות, còle
  { {0x3704005e,0x2ca7158f,0xdb1b002a,0x9a470015}},	//   вчув, _zand_, rytó, _غضبه
  { {0xcb14000a,0x66d8001a,0x44b50a31,0xe6100015}},	// [b390] _בלק_, _kíkj, нбас, لشك_
  { {0xd138005c,0xdb0400b8,0x9855005e,0x2edb000b}},	//   _nią_, _ernä, _якої, _बत्त
  { {0x68f50064,0x8ba9000a,0xa856000a,0x04c80015}},	//   mizd, ּׁנִ, _איתה_, بولي_
  { {0x9327002b,0x2258004a,0xc7d6004f,0xe855009a}},	//   ذران, дицы_, _נורי_, _تنگد
  { {0xfb1c000a,0x2167004a,0x8234002b,0x6d460046}},	//   קודמ, фтег, نرها, íkal
  { {0x68f501e2,0x6458001a,0x297c05bd,0x397c000a}},	//   nizd, ðvit, קטוא, קטונ
  { {0x3861018b,0xbf640015,0x2ca702a1,0x0000006a}},	//   _mehr_, نديو, _rand_,
  { {0xf83801e4,0x7fe80029,0xf774000a,0xa838000a}},	//   ונות_, ظروف_, דקק_, ורוד_
  { {0xc0ab0015,0x2ca72c8c,0xb2840138,0xf53f3be0}},	//   _وائل_, _pand_, _шырк, _gråt_
  { {0x2367016f,0x81c2003d,0xbca50015,0x61240144}},	//   šnju_, ķēta, رمجي, tòle
  { {0x39400152,0x2ca70f47,0x02f3000b,0xa3d5000b}},	//   _suis_, _vand_, _आगाह_, ाईट_
  { {0x3940038d,0xdd8e0086,0x63ba00dc,0xfe70002b}},	//   _puis_, جوی_, _átne, _نده_
  { {0x3940001c,0x5e56004c,0x427a004c,0x5cf50138}},	//   _quis_, _װיצע_, הארג, _пяку
  { {0x91f60008,0x2a600012,0x6f1b14a0,0xcdf6000a}},	//   תמשו_, _weib_, lluc, _אמני_
  { {0x25a001d7,0xccf2004f,0xd7060788,0x6f1b4be3}},	//   wwil_, _תכו_, езви, oluc
  { {0x63a20050,0xab270063,0x68f50007,0x394000dd}},	//   łonk, _поща_, aizd, _tuis_
  { {0xe6e0005d,0xb9c60029,0xd4d60010,0xb5fb002d}},	// [b3a0] _नतीज, _ستظه, ніжэ, _reác
  { {0x0d3a004c,0x6f1b0012,0xb5fb0030,0x672d4be4}},	//   פגעב, hluc, _adás, amaj
  { {0x6576022d,0x6f1b0050,0xa34a005e,0x62860072}},	//   sryh, kluc, їзда_, _ökok
  { {0xc7b30008,0x89da000a,0x01662fa0,0x020603a7}},	//   _עבר_, ּחַי, екдо, нзен
  { {0xc69300b2,0x7b160533,0xe1f20058,0xe6350138}},	//   _גאר_, láus, دسا_, _ахрэ
  { {0x24560029,0xd0d7005e,0xd1300015,0xf993000a}},	//   _سنرس, ндії_, جمت_, טרד_
  { {0x6e2200dc,0xdfd00029,0xe296000d,0x66d8002e}},	//   _szob, شية_, _праќ, _ríkj
  { {0x23890089,0x9326002b,0x8fa30004,0xf773000a}},	//   žují_, _سرزن, ѓање, אקה_
  { {0xfe6f0029,0x74c4000b,0xd737000a,0x569b000a}},	//   حدى_, रापृ, עטפת_, ליקצ
  { {0x2dd70015,0xc0ea0015,0x4c940054,0xa5bb04b2}},	//   عبية_, _عفان_, њинс, _ozón
  { {0x3e7a0064,0x54770053,0x2911044c,0xa3d6000b}},	//   gütü_, עגטע_, voza_, िनट_
  { {0x3861018b,0x93fb000a,0x62824be5,0x33fb004f}},	//   _sehr_, לליי, ngoo, להינ
  { {0xba3b0251,0x4dd300e5,0x672d0072,0x38612f34}},	//   veïd, _متوس, vmaj, _pehr_
  { {0x7c2b001a,0xc211000a,0xddc90247,0x5dbb004f}},	//   ámrö, ׁ֔ם_, dceň, _מזדה
  { {0xed350010,0x0cdc000b,0x69c0008c,0xf7940033}},	//   _рэцэ, यसीम, ämer, ларэ
  { {0xf5e7042b,0xfbd3000a,0x8c1b000a,0x7e624b1f}},	//   нізм, _תתק_, _מווי, _jeop
  { {0x96350010,0x95cb00d0,0xe598005e,0xea78000a}},	// [b3b0] тнац, чува_, нкті_, _נגזר_
  { {0x99640063,0x672d4be6,0x442b0920,0x0614027a}},	//   _стъл, smaj, пцем_, удую
  { {0xd2510029,0x28b0000b,0xdcfb0085,0xc5140015}},	//   لنا_, फ़ारि, stuć, ابقت
  { {0x628200dd,0x91f90015,0x9756000a,0x6458001a}},	//   ggoo, وفاء_, _שירו_, ðvir
  { {0x6f1b4be7,0x6d5d003d,0xe0ce06ab,0xf0b8002b}},	//   vluc, šsaz, ав_, کانش_
  { {0xf994004f,0x26c90160,0x0000006a,0x0000006a}},	//   ררס_, ljao_,   ,
  { {0xbea50063,0xc4d20008,0xa8ac039e,0x5437002b}},	//   вайк, _דגם_, לֹהִ, _سرسر
  { {0xa9a60053,0x26c90085,0x533426de,0xf1c7005a}},	//   ופּעס_, njao_, _бест, _pláč_
  { {0x7e620045,0x8e09005e,0x6f1b0e3c,0x0000006a}},	//   _deop, ьнив_, rluc,
  { {0xe6120008,0x7ce40144,0x3eb8003d,0x63b506c0}},	//   יִת_, _nòrd, ērta_, _krzn
  { {0x2d9804f9,0x5e950015,0x7c940033,0xd10e000b}},	//   ărea_, _للاط, урыц, ाकरण_
  { {0xf4120008,0xdce9016f,0xa96a0001,0x66d8001a}},	//   שפט_, kreć, мима_, _víkk
  { {0x4e780029,0xc332000a,0xd256000a,0xdbde4be8}},	//   _أحمد_, יוט_, כשרה_, síða
  { {0x63a2005c,0x61e60061,0x3ead1bd6,0x7ce40144}},	//   łoni, _ükle, ldet_, _còrd
  { {0xb90a005d,0x3ead4be9,0xdce90160,0x3d240138}},	//   _मत_, odet_, ereć, _сьцв
  { {0x3ead4bea,0x66d80052,0x0000006a,0x0000006a}},	//   ndet_, _kíki,   ,
  { {0x04460001,0xba3b00dd,0x3ead4beb,0x66d10595}},	// [b3c0] везн, teïe, idet_, _påkr
  { {0x3ead00f2,0xb97b01d8,0xf9890015,0xe8f708fc}},	//   hdet_, _קניי, _أخيه_, _аль_
  { {0x316d038d,0x18770008,0x94790010,0xa8570008}},	//   _avez_, _בעיר_, эсту_, _שיטה_
  { {0x3ead0134,0x2bc2000b,0x63b507c4,0x97360138}},	//   jdet_, षमता, _drzn, _шэпч
  { {0x64430007,0xc3050029,0x7e6200da,0x42730033}},	//   žnia, دبلو, _reop, ргіс
  { {0x224d00e8,0xc9530008,0x2d8d0020,0xdce2006f}},	//   _efek_, סמו_, dtee_, _spoľ
  { {0x7e620041,0x74160074,0x78fb0008,0x673b0264}},	//   _peop, _شورا, ופסו, ňuje
  { {0xb5fb002d,0x200000d4,0x0000006a,0x0000006a}},	//   _meán, ăii_,   ,
  { {0x6ce60010,0x80c2000b,0xfe790046,0x7e62007c}},	//   віне, लादे, chům_, _veop
  { {0x9b580083,0x8f760036,0x3ead0072,0x0000006a}},	//   ниот_, _ауді, adet_,
  { {0x316d00bd,0xd10f000b,0xcd330015,0x547b000a}},	//   _zvez_, िवरण_, جريب, וטיו
  { {0xf4130008,0xbe8500a2,0xf773002b,0x8c3c0061}},	//   יפת_, _مجهو, یاز_, değe
  { {0x644e001a,0x1dda0015,0xdb160030,0xac940054}},	//   _ofbi, _تباع_, óbáv, _балш
  { {0x0d970008,0xfd0f0086,0xdce60024,0xb9250029}},	//   _סכום_, _وجو_, ēmēj, افسي
  { {0xd7f80080,0xd7f401b0,0xb717002b,0x03120065}},	//   вут_, азры, نظرت, ़वाह_
  { {0xdce000df,0xef11000a,0xec37000a,0xa3b6000b}},	//   tumė, ֶּן_, _באור_, जिन_
  { {0x35b50010,0xa5f82c2a,0xe6642fff,0x9f8e0072}},	// [b3d0] ыбар, вету_, ртсо, mõõt_
  { {0x94740015,0x0519002b,0x5454005e,0xfaf9003d}},	//   لدما, رياب_, ивут, asīt_
  { {0x3ae2002e,0xdce9016f,0x3ead1695,0x67d50004}},	//   _hópa_, sreć, ydet_, _сону
  { {0xe2ab0015,0xa6db001a,0x02f00061,0x6aad4bec}},	//   بائن_, _siðf, _üçlü_, _jaaf
  { {0x667a000a,0x26de003d,0x3ead4bed,0x290320f6}},	//   _אטרק, ītot_, vdet_, onja_
  { {0x89dc013a,0x66d8002e,0x0efd000b,0x3d0c000b}},	//   וחדי, _ríki, ॉक्स_, सकों_
  { {0x93880180,0xd347002b,0xa6db001a,0x94050015}},	//   _иста_, _شیشه_, _viðf, _صوره
  { {0x2d8d003e,0x3ead0ac8,0x8d590004,0xe29f001a}},	//   ttee_, udet_, ншот_, _úð_
  { {0x656d025c,0x6234000d,0x673d00ba,0x3ead0613}},	//   nsah, _вету, _misj, rdet_
  { {0x3375000a,0xdca50054,0x29030085,0xe572000a}},	//   ְעָם_, ћани, jnja_, צַח_
  { {0xa5bb00dc,0x2903060b,0x0b42004a,0x9f550299}},	//   _szól, dnja_, йнэн, _свеч
  { {0xf8a9000a,0xe1e700c3,0x673d00cb,0x0000006a}},	//   _מש_, مس_, _nisj,
  { {0xbebd0024,0xb5fb0125,0xaa7b00bf,0x09f60033}},	//   elūg, _seán, chým, учня
  { {0xd9430c5b,0xcdb6004f,0x6bd50058,0x0000006a}},	//   сери, _תפסה_, _متبر,
  { {0x37e30142,0x6fb3005d,0x1cb80115,0x66e63589}},	//   борг, ंटिं, _جانب_, гова
  { {0x75d60087,0xdb9a000a,0x673d26a8,0xfb52002b}},	//   هيزا, _נספר, _cisj, _اپيد
  { {0x7ae4000c,0xd7070080,0x1a9b0053,0x2bcb005d}},	// [b3e0] _ilit, унте_, _טיקע, ाहका
  { {0x661d0050,0x7afd00dc,0x05770029,0xe6174bee}},	//   _dysk, értv, املة_, уду_
  { {0x2b4f04f9,0x42d60036,0x753c0024,0x656d0035}},	//   _încă_, ліду, _virz, asah
  { {0xf1c50023,0x26de0024,0x6efe0024,0x656d0057}},	//   _trợ_, ītos_, lībv, bsah
  { {0x6b8110cc,0x31760004,0x6fb8000b,0x9f4b0046}},	//   hulg, уѓет, ्मभू, ělým_
  { {0xf9930008,0x7ae42296,0xbfaa0fdc,0xe04a009a}},	//   צרו_, _llit, етие_, رشته_
  { {0xe7f9005d,0xb5fb00dc,0x661d005c,0xfbc70115}},	//   ृपया_, _leál, _zysk, _ات_
  { {0xa6db001a,0x75490030,0x6b81073e,0x62890125}},	//   _viðg, _öszö, dulg, _gceo
  { {0xa2060803,0xf1a9002b,0x2bdc0065,0xaa7b005a}},	//   _спад, _لاله_, मन्थ, uhým
  { {0x90d50023,0x7ae44bef,0xbebd003d,0x66ca0069}},	//   _hìn, _alit, elūd, _výky
  { {0x7ae41885,0x447b0053,0xf1b9002c,0xab94005e}},	//   _blit, ענטע, _vyše_, шині
  { {0xb5fb0014,0xc9870608,0xd437015b,0x0f7b000a}},	//   _beál, луги, טריק_, _טרבל
  { {0x90d50092,0x8d5627f6,0x7ae40125,0x290306f2}},	//   _mìn, _стеч, _dlit, tnja_
  { {0x661d00c0,0xee290015,0x7ae42ef8,0x6b814bf0}},	//   _rysk, _شأنه_, _elit, bulg
  { {0x66d8002e,0x6aad0a72,0x2903044c,0xdc9b000a}},	//   _líku, _taaf, rnja_, _ניהל
  { {0xdce0003d,0x7ae44bf1,0x501b000a,0x661d037c}},	//   kumī, _glit, גולו, _pysk
  { {0x9f47002c,0x290302c6,0xa3e7000b,0x764d169a}},	// [b3f0] rzné_, pnja_, मैन_, rcay
  { {0x96340010,0xf994000a,0x661d4bf2,0x656d2573}},	//   снуц, _הרץ_, _vysk, rsah
  { {0x90d50092,0x7ae400f2,0xf3150010,0x661d005c}},	//   _bìn, _ylit, аджэ, _wysk
  { {0x51550036,0xa2950036,0x656d008c,0x661d0a3a}},	//   атку, раді, psah, _tysk
  { {0x213e002f,0xe1350010,0x212a009a,0x12180138}},	//   _bith_, анды, چينی_, люшы_
  { {0x6ae2005d,0x210f000b,0xc57a000a,0x31580015}},	//   _पत्र, िवेश_, _ברשת, اجنة_
  { {0x8cc8000b,0x0000006a,0x0000006a,0x0000006a}},	//   ़ानो,   ,   ,
  { {0xfe450083,0xdddb0024,0x2d95427f,0x7bda1501}},	//   шнио, eguš, арос, dytu
  { {0x60870029,0x26b60008,0x5187023e,0xd045002b}},	//   _مشاك, בִים_, _љуба, _نپذي
  { {0xb5fb0154,0xf1b90091,0xee360174,0x7ae44bf3}},	//   _reál, _irš_, шны_, _slit
  { {0x66d8002e,0xa2f5000a,0xfb840033,0xa6db001a}},	//   _kíkt, ֹמָה_, быўн, _miðb
  { {0xa3b6005d,0xde590036,0x4e190080,0x2f5a000a}},	//   जित_, _раді_, _июля_, _ידענ
  { {0xd946009f,0x08d60033,0x9aa6009a,0xadbc0138}},	//   реги, ацвя, همگو, _пацi
  { {0xcc890074,0x271e000b,0x6e260030,0x4236000a}},	//   _شنبه_, पत्र_, ükbe, ינרל_
  { {0x366a0805,0xacfa000a,0x46f608f7,0x18670c68}},	//   каво_, _בהסכ, ачат, раси_
  { {0xfd4c0092,0x7ae433c8,0x64430107,0x29d8006f}},	//   _nhiễ, _ulit, žnil, eľať_

  { {0xd547004a,0x3eaf0c11,0xb4661cd9,0x4466123a}},	// [b400] ипте_, _magt_, икал, ивав
  { {0x3eaf4b37,0xdb0b0012,0x84560054,0xd910002b}},	//   _lagt_, _erfä, рњач, _ریز_
  { {0xa87b009d,0x213e002d,0x987b000a,0x287b00f3}},	//   _באיר, _rith_, _באיט, _בנימ
  { {0xeb960053,0xc4c90008,0x68fc0064,0xa69600d7}},	//   ידער_, וג_, lird, _трој
  { {0xaa7b0089,0x7bda002a,0xdce94bf4,0x045a0058}},	//   lkýc, zytu, eseč, _لجأت_
  { {0xa6db0084,0x79b70008,0xa3b6000b,0x68fc0061}},	//   _viðe, ילנד_, जिद_, nird
  { {0x90d50023,0x4ea606f6,0x4f670033,0xc6b6000a}},	//   _tìn, арпа, ашым_, ֹהִי_
  { {0x213e03c2,0x68fc0548,0xd1760033,0xba3b00aa}},	//   _with_, hird, _выжы, deïn
  { {0xbd870029,0x68fc0064,0x291819c6,0x91e32f04}},	//   لنين_, kird, kora_, _доте
  { {0xa5bb00dc,0xdddb0024,0x7bda10da,0x14c9000b}},	//   _szók, uguš, tytu, रायण
  { {0x26c200f2,0x68fc0064,0xa1130115,0x7b15006b}},	//   _onko_, dird, _بولت, йдох
  { {0xe57f003d,0x19590088,0x7bda0c00,0x9e650058}},	//   ņķis_, ламы_, rytu, _هاهن
  { {0x28c3005d,0x5337004c,0x7bda0091,0x29181ccb}},	//   शालि, ינטן_, sytu, fora_
  { {0xd0060029,0x9cb30015,0x6bd60015,0x68fc4bf5}},	//   كل_, _ومنت, _نتعر, gird
  { {0xbb840029,0xdcfb0061,0x67d42066,0x368b18c5}},	//   _العي, ltuğ, оору, ксан_
  { {0x8f9b0008,0x7c3b000a,0xdc3b000a,0xcaf40015}},	//   כילי, _בתוס, _בעור, _وسيب
  { {0xb9950029,0xaae70086,0x09e40001,0x7afd4bf6}},	// [b410] _الخب, _مسکو, _моћн, mist
  { {0x291802d7,0x69dd006f,0xf9fc000a,0xfd57000a}},	//   cora_, myse, _שהזמ, ישמי_
  { {0x7afd022d,0xa6db0084,0x92590080,0xaa7b04af}},	//   oist, _viðb, гает_, ckýc
  { {0x92580015,0x6354005e,0x7b1d0077,0x2d84007c}},	//   لشهر_, івчу, céut, kume_
  { {0xf1a8002b,0x35a40033,0xdcb10016,0x2d841667}},	//   لاوه_, _даўг, hỏa_, jume_
  { {0xf958000a,0x71720015,0xd0090bb1,0x7afd4bf7}},	//   ססות_, أهوا, леле_, hist
  { {0xc0780036,0x39494bf8,0xc7aa000a,0x389c000a}},	//   рсії_, _luas_, ָׁפָ, דיונ
  { {0x69dd00f2,0x291812b8,0x7afd4bf9,0x8145002b}},	//   kyse, zora_, jist, _هنرن
  { {0xd011002b,0xce190033,0xee39004a,0x7afd4bfa}},	//   _کلا_, ыцкі_, ыни_, dist
  { {0x50db005d,0x98aa0045,0x2b470125,0x90d40015}},	//   _भविष, imbă_, _punc_, _وآلا
  { {0x7f840029,0xeb990001,0x29184bfb,0x6ac60015}},	//   _ولكن, ћим_, vora_, مقدم
  { {0x239a0053,0xab19005e,0x139a004c,0x68fc00a9}},	//   נברײ, ицях_, נברע, wird
  { {0x68fc0064,0x59750033,0x29184bfc,0x8c45058c}},	//   tird, жысу, tora_, _леле
  { {0x7d760074,0x394903af,0xcdb60008,0xaa7b002c}},	//   _امور_, _duas_, _לפנה_, tkýc
  { {0xe0d20053,0x7afd4bfd,0x2ca54bfe,0x68fc0359}},	//   הײם_, bist, meld_, rird
  { {0x98790048,0x69dd0026,0x5b7a00a3,0x29184bff}},	//   kšķu_, byse, _ערפא, sora_
  { {0x63450007,0xaa7b0107,0xceb2004c,0x9fa2001a}},	// [b420] _mėnu, skýc, הין_, _líða_
  { {0xf484002b,0x37e60054,0xa81a0015,0x88860a3e}},	//   تاری, _гоог, _متجر_, _улож
  { {0xf7720029,0x324600e6,0x1604000b,0x493b000a}},	//   _عاد_, مناف, _रखकर_, _תגיו
  { {0xa2940036,0x2ca54c00,0xe433002b,0x6efe0091}},	//   іалі, held_, سفند, kūba
  { {0x2ca50298,0x2b910092,0x3636002b,0xf484002b}},	//   keld_, hác_, _دردس, _واسی
  { {0x3d11005d,0x836a0087,0x9fa2002e,0x67242c0f}},	//   ठकों_, _مصرف_, _bíða_, llij
  { {0xcd790053,0x22490085,0x7afd4c01,0x8f34135d}},	//   _שפּראַ, žaka_, yist, оекц
  { {0x67243eee,0xef19002a,0xdcfb0061,0x9757000a}},	//   nlij, goż_, ttuğ, זיקו_
  { {0x6d5b00b6,0xad660015,0x2ca52eb6,0x67244c02}},	//   gpua, حابه, feld_, ilij
  { {0xa6db0084,0x39494c03,0x25d7000a,0x9cf4005e}},	//   _miða, _ruas_, צוין_, ізні
  { {0x2a690005,0x74c9005d,0x39494353,0x00570008}},	//   _peab_, रातः, _suas_, _השבת_
  { {0xbb930080,0x39490375,0x7afd0f80,0x612d001a}},	//   чающ, _puas_, uist, rúle
  { {0xac9a002b,0x2ca50079,0xb9e4005e,0x2a69007c}},	//   _منشا_, beld_, піри, _veab_
  { {0x1d07000d,0xa3e8005d,0xadb70086,0x7afd4c04}},	//   _лечи_, यना_, _دهها_, sist
  { {0x2a690020,0x50db0053,0x644303cd,0x3cfb000a}},	//   _teab_, נקלא, žnik, _תלונ
  { {0x387f0064,0xaae70002,0x25a90035,0x3dd2002a}},	//   şur_, _دستو, twal_, _żywy_
  { {0x86270010,0xf8ae0086,0x9e4b000a,0x84470015}},	// [b430] сьве, رکی_, אֲבִ, مخال
  { {0xf990003b,0xfaff0161,0xb09a02a3,0x67244c05}},	//   _أبي_, lië_, _абiт, alij
  { {0xb5fb002d,0x7d084c06,0x69ce0045,0x25a902f2}},	//   _meái, inds, ăieş, swal_
  { {0x326b0029,0xfaff0150,0x8c1b000a,0xb8ec000b}},	//   احاً_, nië_, נואי, रफ़_
  { {0xdd860086,0x9f470089,0x9fa2002e,0xc6b6000a}},	//   _تو_, rzní_, _síða_, _והרי_
  { {0x7bc5002e,0x4f790063,0x2f554c07,0x361a000a}},	//   _áhug, ащия_, отис, _כורד
  { {0xef19002a,0xfaff00aa,0x2ca52c54,0xc8dc000a}},	//   toż_, kië_, veld_, רקוט
  { {0x2ca54c08,0x7d080c0a,0x92940033,0x9fa2001a}},	//   weld_, ends, _насц, _víða_
  { {0x2ca52c54,0xfaff0234,0xbd450015,0x808b00c3}},	//   teld_, dië_, غندي, _مضاف_
  { {0x6d5b0375,0x59b8000b,0x3cfe007c,0x67240085}},	//   rpua, इटसर, gitv_, zlij
  { {0x2ca5049c,0xca29000a,0xeb993ee0,0x7ced0144}},	//   reld_, _סם_, шин_, _lúrg
  { {0x3f870064,0x3af60010,0xbe64002b,0x6d5b008c}},	//   munu_, іянс, _فهمي, ppua
  { {0x3f871e8c,0x6f1b1e80,0xacf50015,0x7d1a4c09}},	//   lunu_, mouc, _وستت, bots
  { {0x4a430033,0xf74632b1,0x290c007c,0x18670302}},	//   ьняв, жево, õda_, жари_
  { {0x3f870064,0x67243ca0,0x6c56000a,0x07ba0015}},	//   nunu_, tlij, _ויצא_, جهزة_
  { {0x6d4b000c,0x7c3e0264,0xfb170031,0x6d434c0a}},	//   _kuga, _úpra, _وقوع_, _hina
  { {0x67240298,0x6d430508,0x7e6b00dc,0x6d4b4c0b}},	// [b440] rlij, _kina, _megp, _juga
  { {0x67243b03,0x6d434c0c,0x7e6b4c0d,0xa6db001a}},	//   slij, _jina, _legp, _viða
  { {0x389b0135,0x6d4b4c0e,0xdce00046,0x037a0021}},	//   _דיינ, _luga, esmě, شحات_
  { {0xdcfb010b,0x6d4321a0,0x6d59005c,0x3f870064}},	//   druč, _lina, _otwa, dunu_
  { {0x6f1b0089,0x4a9b0008,0x7d08002e,0x1a9b0053}},	//   douc, שינג, ynds, שינע
  { {0x6d434c0f,0xfaff0079,0x49bb000a,0x99bb0c44}},	//   _nina, zië_, ימנס, יזנט
  { {0xa6db002e,0xb6ba000a,0x6d4b4c10,0xba3b0144}},	//   _miðn, ֹצִי, _auga, veïm
  { {0xdce9016f,0xf1aa0086,0x6d434c11,0x6d4b4c12}},	//   dređ, _پاره_, _aina, _buga
  { {0x3f870024,0xddc90011,0xfaff0079,0x61240144}},	//   aunu_, rbeş, vië_, hòli
  { {0x3f8743fc,0x7d084c13,0x6d430061,0x7d1a008c}},	//   bunu_, unds, _cina, uots
  { {0x6d5900b8,0x7d1a0020,0x7c230026,0xdb1d00dc}},	//   _etwa, rots, _cynr, őzít
  { {0x7d1a0e95,0xe9810033,0x7dc60015,0x6f1b0618}},	//   sots, намi_, _وقان, couc
  { {0x5a440010,0xdd8f0029,0x09e40010,0xfaff0150}},	//   дэра, _لون_, доўн, rië_
  { {0x6d4300b6,0xad650086,0x7ced002d,0xfaff0234}},	//   _gina, _راهه, _cúrd, sië_
  { {0x7c230026,0x6d4b00b8,0xd66b0180,0x466b06a6}},	//   _gynr, _zuga, ијал_, ирам_
  { {0x6d43000c,0xdb04002d,0xe607005e,0x25a201c2}},	//   _zina, _tsná, оїзн, _bpkl_
  { {0x291a002e,0x3f870061,0xa92b0033,0x344b08d7}},	// [b450] ófað_, zunu_, _віне_, ачен_
  { {0x3f870061,0xceb90046,0x61240144,0x6f0d04b2}},	//   yunu_, moře_, bòli, čaci
  { {0x14190029,0xa5bb00dc,0xa4d4005e,0x6b8802de}},	//   حياة_, _azót, ьофі, nudg
  { {0x99480074,0x75d50015,0x0000006a,0x0000006a}},	//   _دلیل_, _فيجا,   ,
  { {0x81a70029,0x32b80015,0x6f1b0046,0xd24e002b}},	//   تحال, تدلة_, vouc, اچف_
  { {0x3f870064,0x6b8802de,0xdcfb3817,0x6d4b4c14}},	//   tunu_, kudg, truč, _ruga
  { {0xceb90089,0x6d431287,0xc4d2000a,0x6d59002a}},	//   hoře_, _rina, _אגם_, _stwa
  { {0x32550010,0x59cb000b,0xdce90085,0x3f874c15}},	//   _хвар, ामार, vređ, runu_
  { {0xddcb0048,0x6f094c16,0x3f874c17,0x6d431636}},	//   _iegū, rnec, sunu_, _pina
  { {0xa3df005d,0x21a40015,0xfd110015,0x10d80015}},	//   _तथा_, _تمكّ, عجة_, _وبلغ_
  { {0x6d434c18,0x8b260080,0x3ae2002e,0x8ccd005d}},	//   _vina, здне, _hópi_, ताबो
  { {0xe9a60033,0x03d6000a,0x6d4b41e4,0xbfb4002b}},	//   памп, לותם_, _tuga, _زحمت
  { {0xdc3c03eb,0x6d4300b6,0x44260092,0xc9560088}},	//   kšķi, _tina, ́o_, ятны
  { {0xadd60008,0xdce9016f,0x61240251,0xe8e10092}},	//   _מונח_, pređ, tòli, _đợt_
  { {0x8cc8005d,0x3f770011,0x5fbd005d,0xb8e4000b}},	//   ़ारो, nău_, ्मिल, _एफ_
  { {0x3f510092,0x9c7c0107,0x4b7a000a,0x2bb0000b}},	//   _máu_, nkčn, _האקו, _जनता
  { {0x0585005e,0x7d010125,0xb062008c,0xe5a316e7}},	// [b460] дуєм, oils, ääkk, нити
  { {0xe5060015,0xfe790046,0x6fbd000b,0xe5770033}},	//   أبري, dkům_, ्मां, язу_
  { {0x74160015,0xe7760015,0xd8db000a,0xf365005e}},	//   أوضا, _عادة, _הקיר, дтін
  { {0x8b56004c,0xdc3c003d,0x74130021,0x7d014c19}},	//   ליעס_, ašķi, رونا, hils
  { {0xa6db002e,0xf1940080,0x66bb000a,0x76bb05bd}},	//   _miðl, филь, _המכה, _המכפ
  { {0xc953000a,0x90c30054,0x3f510016,0x4f6a004a}},	//   עמו_, ебље, _báu_, бшим_
  { {0xdfd00086,0xf8b3000a,0xdd90002b,0xf80d000a}},	//   ئيب_, גשו_, چوب_, ֙הוּ
  { {0x6462005c,0xdd9000e6,0x644a0064,0xc7b3000a}},	//   świę, نوب_, şliğ, תבה_
  { {0x21670001,0x6f000061,0x612d1f4f,0x1d34006b}},	//   _нити_, rimc, súla, мния
  { {0xa1770008,0x515b000a,0x71730015,0xacf8005e}},	//   _מעמד_, _לכמו, _أهلا, інну_
  { {0x3f770045,0xa6db001a,0x60c802de,0xa2c1000b}},	//   cău_, _biðl, _indm, _रोड्
  { {0x96570010,0x6b881ef2,0x60da26a3,0xdc3c003d}},	//   вiны_, rudg, _hotm, zšķi
  { {0x7d010048,0xa3b3000b,0x61e24c1a,0xa2f7000a}},	//   bils, _जैन_, nyol, למטה_
  { {0x7d570008,0x7d7b0135,0x7ae6001a,0xed57000a}},	//   _ציוד_, _פרוג, akkt, _צבור_
  { {0xdc9b000f,0xb8f5005d,0x26d9162c,0x7ad50015}},	//   _הסוכ, _सच_, _poso_, _يقتص
  { {0xf77000c3,0xd6d80e41,0x36d4018d,0x60da0a6a}},	//   طاف_, пту_, носр, _lotm
  { {0xf6500029,0x4a7c0008,0xdc3c0024,0x7aed11ac}},	// [b470] ائف_, _הרחב, tšķi, _ilat
  { {0xfe790046,0xa5bb1506,0x64a40054,0x95c40058}},	//   vkům_, _szós, нађа, عيله
  { {0x9295008f,0x389a000a,0x889a000a,0x29034c1b}},	//   даец, _ויתנ, _ובתי, mija_
  { {0x60c80005,0x629e00dc,0xe2990036,0x91bf0016}},	//   _andm, őpon, іал_, _ngũ_
  { {0x20d50036,0x3f512431,0xb6ba000a,0xbb3c000a}},	//   дійс, _sáu_, _וצרי, צעדי
  { {0x7aed3a42,0xe588000a,0xc0c80054,0x7ced2ea8}},	//   _llat, _צָרָ, зуће_, _múrc
  { {0x7ae60084,0xa858000a,0x7d014c1c,0xa87c000a}},	//   ykkt, ליגה_, vils, זאור
  { {0x290324e6,0xc2c50058,0x3f7700d4,0x0000006a}},	//   hija_, _تيري, rău_,
  { {0xdd8e0015,0x29034c1d,0x7d012994,0x0000006a}},	//   لوي_, kija_, tils,
  { {0x6ab60482,0xdd8e0086,0xfbd10021,0x7aed4c1e}},	//   _sayf, گوی_, نتج_, _alat
  { {0x30780029,0xa3b6005d,0x75200030,0x7aed4c1f}},	//   _رحلة_, जिए_, _ímze, _blat
  { {0xdd8e0086,0xa6db001a,0x7d0100bc,0x2a360033}},	//   دوی_, _biðm, sils, дэгр
  { {0x80b4005d,0x7aed005c,0x82760053,0xec79000d}},	//   _इसमे, _dlat, וערע_, _дпл_
  { {0xdcfb003d,0x29034c20,0x7aed01fc,0xfc05257f}},	//   bruā, gija_, _elat, _опло
  { {0xcaf60015,0xd5af002b,0x7aed296e,0x61e20061}},	//   _يسبب, یفف_, _flat, zyol
  { {0xb6a3030c,0x7aed4c21,0x7a560058,0xdddb0535}},	//   кисл, _glat, _غضبا, mbuł
  { {0xcb13013a,0xa5bb00dc,0xcb37004c,0x29034c22}},	// [b480] _שלח_, _szór, _קאפי_, bija_
  { {0xb4e8005d,0x61e2003f,0x04ca0015,0xc483006b}},	//   बसे_, vyol, غواي_, клук
  { {0xa6db002e,0xc5e9000a,0x60da4c23,0x637a00ce}},	//   _miðj, סד_, _rotm, юсар_
  { {0x60da0251,0x3f98003d,0xf1aa0015,0xfbb00065}},	//   _sotm, _īru_, قاته_, _जनसम
  { {0x7bd5002c,0x7584002b,0x0000006a,0x0000006a}},	//   äzuj, _سیام,   ,
  { {0xd13000e6,0x61e20061,0x09f7004f,0x0000006a}},	//   دمت_, ryol, ומנם_,
  { {0xa4b7000a,0x61e20061,0xa248009a,0xe2aa02be}},	//   _קללה_, syol, _فیال_, _وارن_
  { {0x3f800007,0x23fb000a,0x7de6005e,0xaa7b006f}},	//   čiu_, _והלא, діод, tkým
  { {0x64590050,0xa6db0084,0xa3b6005d,0x6443006f}},	//   świe, _biðj, जिक_, žnit
  { {0x7aed4c24,0x8c3c0061,0xe056002b,0x90360015}},	//   _slat, leği, _غیبت_, _قراص
  { {0x3cf70015,0x2fe60015,0x29034c25,0x6fb30015}},	//   بعيد_, _تكاف, vija_, _لملا
  { {0x8c3c01e2,0x3eb8003d,0x5f03006b,0x2903297a}},	//   neği, ērts_, _изха, wija_
  { {0xf2d300b4,0x8d9300c3,0xda090015,0x29030eb7}},	//   דער_, _للنش, سيسه_, tija_
  { {0xa6db002e,0x3cf70029,0x4cb7005e,0xe76b03ae}},	//   _viðm, _يعود_, _олію_, жјак_
  { {0xf7940033,0x67470033,0x29034c26,0x07a40033}},	//   карэ, дэаз, rija_, каён
  { {0x7aed0020,0x98a40024,0x2cac0026,0x8b080046}},	//   _ulat, ēmā_, ledd_, _vyří
  { {0x2cac0176,0x2b980030,0xa5354a11,0xdce00061}},	// [b490] oedd_, léc_, енач, ltmı
  { {0x2cac0176,0xcd970008,0xd49b0033,0x0000006a}},	//   nedd_, ודמת_, ўра_,
  { {0x2c34000a,0x29010061,0xd37b058c,0x44a4009a}},	//   תָּם_, _imha_, юча_, ئممق
  { {0x2cac0026,0xae0e000b,0xf1bf0030,0x7ce40144}},	//   hedd_, ापान_, _áák_, _dòri
  { {0x865a039e,0x81ab0015,0xb65a000a,0xfaf8000a}},	//   _מדרי, تطاف_, _מדרש, וצאי_
  { {0x98ba0007,0x2cac00cb,0xa29f000b,0xd164006b}},	//   _tipą_, jedd_, _गॉर्, тъци
  { {0xdfd10018,0x2cac0026,0xf1b90227,0xb5fb0030}},	//   ايع_, dedd_, _myši_, _teás
  { {0x8c3c01e2,0xb4db0144,0x680e0030,0x52840015}},	//   ceği, _guàr, lődé, _للفك
  { {0xc1050029,0x2cac0026,0x1d09005e,0xc1150054}},	//   _كوري, fedd_, зепи_, _змај
  { {0xdb0b00b8,0x2cac0026,0x0d8202bf,0x2c190033}},	//   _erfü, gedd_, ыльн, зюмэ_
  { {0x543a004c,0xab2a249a,0xc4d2004f,0x66090073}},	//   ּערא, зона_, אגי_, _žekl
  { {0x73fa0053,0xf4120053,0x0f560053,0xcf56000a}},	//   פּיו, רפט_, _טיעם_, _טבעת_
  { {0xc332000a,0x38c8002b,0xd95a0033,0xdcb10016}},	//   טוט_, واسی_, яшні_, hỏi_
  { {0x4dda000a,0xade80015,0x26cb02b9,0xdce90085}},	//   _מחנו, _تفهم_, _anco_, dseć
  { {0x68e1002e,0xc0520008,0x07a3049d,0x17c7007e}},	//   ölda, רזל_, ларн, нгри_
  { {0x3ead022d,0x05760015,0x7bc30091,0x91b00065}},	//   neet_, فائد, _irnu, _आईलै
  { {0xd6cf00e6,0x3f8701cb,0xddc2002a,0x63b50030}},	// [b4a0] حقق_, hrnu_, _zgoł, _aszn
  { {0xa99b000a,0x399b000a,0x3ead4c27,0x98e60058}},	//   _צביר, _צייד, heet_, _أكدو
  { {0x8c3c01e2,0x04930015,0xa857000a,0x2aba000a}},	//   teği, المح, _ריטה_, ּמְא
  { {0x3ead00f2,0x69c44c28,0xdb190de4,0x0000006a}},	//   jeet_, _krie, _krvá,
  { {0x3ae2002e,0xcb13000a,0x8c3c0061,0xdddb0091}},	//   _hóps_, נלד_, reği, eguž
  { {0xc1040021,0x224d0030,0x91c20065,0x2a7202ad}},	//   ضوعي, _egek_, लिबै, _leyb_
  { {0xeb870015,0x75f50030,0x13890015,0x8c3c0061}},	//   _حظ_, _tüzé, _يخفى_, peği
  { {0x539b013a,0x2cac0176,0x69c403fe,0x8fa30067}},	//   _מילו, wedd_, _orie, اميه
  { {0x7ced006f,0x25b20034,0x10a60195,0xcd06130d}},	//   _súra, nwyl_, _пиан, ечни
  { {0x559700b4,0x9b58000d,0x85970053,0x60660015}},	//   עדיע_, миот_, עדיג_, _أهال
  { {0x2cac0176,0x9e660127,0x2b490030,0x25b20034}},	//   redd_, _звед, _piac_, hwyl_
  { {0xa6db002e,0x2cac0230,0xf413000a,0x69c41fe6}},	//   _viðk, sedd_, טפת_, _brie
  { {0x2b49002c,0x7e270010,0x69c40aff,0x62800030}},	//   _viac_, _піша_, _crie, _mdmo
  { {0xd0060086,0x69c40106,0x0bd40058,0x6564013b}},	//   لل_, _drie, _ليتح, dpih
  { {0x8ccd000b,0xdce20085,0x7793002b,0x9c63012c}},	//   तारो, _uvođ, دیجا, _صهيو
  { {0x6d4a000c,0x25b20026,0xb063002c,0x69c44443}},	//   _hifa, fwyl_, _zväč, _frie
  { {0x6d4a000c,0x7c2a0026,0x97240015,0x69c402b3}},	// [b4b0] _kifa, _hyfr, افقو, _grie
  { {0x6abd0595,0xa6db001a,0x6b882123,0x6726001a}},	//   ldsf, _miði, ordg, _ekkj
  { {0xa6db002e,0x9d1b0008,0x6d4a003f,0x69c4002c}},	//   _liði, לומט, _mifa, _zrie
  { {0xf67900b2,0xbebd0048,0x877a0135,0x8c1b000a}},	//   _קאָמ, rlūk, _קארי, הובי
  { {0x645c0176,0xf6e40010,0x7c2a0026,0x8234002b}},	//   _ffri, _сцэн, _lyfr, هرها
  { {0x3d1a005d,0xc954000a,0xa1560054,0xbebd003d}},	//   नकों_, אמס_, њају_, plūk
  { {0x6fb2003b,0x3ead0c8d,0x02a70010,0xe0e40033}},	//   لموا, teet_, _прам, ыўцо
  { {0xd00e0015,0xdce0003d,0x8fc4002b,0x78bc0183}},	//   تلى_, ksmē, ازون, zdrv
  { {0xa6db002e,0x6d4a0011,0x7bdc00b8,0x3ead4c29}},	//   _viðh, _bifa, ärun, reet_
  { {0x2d830198,0x80270015,0x02440015,0x81c7003d}},	//   čje_, _كرام, _صَلَ, rvēģ
  { {0x7c2a0b7c,0x4ee70036,0x28d5005d,0x6d4a4c2a}},	//   _cyfr, _підз, दानि, _difa
  { {0x29114c2b,0x799d0012,0xe3b2004c,0x5dd50015}},	//   enza_, ftsw, בױט_, _لتتأ
  { {0x9f340010,0xc27a000a,0x6b880079,0x2d8d0077}},	//   _сеці, וררי, ardg, quee_
  { {0x69c409f2,0x8884002b,0xd9460054,0xdc120061}},	//   _vrie, دیدن, ђеви, ağım
  { {0x7c2a0176,0xa6960001,0xf092000f,0x656f0034}},	//   _gyfr, крај, ינם_, _awch
  { {0xdb190089,0x77430015,0x29114c2c,0x6008000a}},	//   _trvá, لَّم, anza_, תִשְ
  { {0x9aeb000a,0xb91a0015,0x7a49003d,0xf7430129}},	// [b4c0] _חַיִ, _يتخذ_, _cītī, рето
  { {0x25b2020a,0x7ce40251,0xe5a310a6,0xe4e5005e}},	//   rwyl_, _fòru, рифи, лієн
  { {0xe29a008f,0xd24f004a,0x25b20034,0x7e6900aa}},	//   дае_, иц_, swyl_, kbep
  { {0x42d5005e,0x6d460107,0x14170015,0x672d0077}},	//   лічу, íkaz, خيمة_, claj
  { {0x6459005c,0x672400f2,0xf8c6000b,0xe737004a}},	//   świa, moij, _लफाय, _шею_
  { {0x28d5000b,0xc5ee000b,0x81c2003d,0x7e694c2d}},	//   दायि, छनीय_, _ķēde, ebep
  { {0xdfd0003b,0xc29a0001,0xaab2000b,0xc0e301ca}},	//   صية_, _отац_, ज़ाक, ројк
  { {0x7c3e002c,0x3f8e2822,0x6d4a0509,0xf773000a}},	//   _úpri, rufu_, _sifa, בקה_
  { {0x81a50015,0x7c2a0034,0x9f410046,0x3f9c37e6}},	//   _محلل, _syfr, áhá_, stvu_
  { {0x9be600ce,0x3cd400ce,0x0000006a,0x0000006a}},	//   вімк, ужос,   ,
  { {0x6d4a000c,0x9c7c0007,0x5ea60015,0x8d86002b}},	//   _vifa, nkči, _لمال, رشکن
  { {0xb69b3f2e,0x83d5000a,0xfeea0015,0x6f024c2e}},	//   _amân, אֵשׁ_, _تعطى_, _umoc
  { {0x6abd4c2f,0x0000006a,0x0000006a,0x0000006a}},	//   rdsf,   ,   ,
  { {0xac180124,0xdb0b001a,0x799d408e,0xab940117}},	//   _полу_, _erfð, rtsw, _бикі
  { {0xa6db001a,0xba3b00aa,0x672d002a,0x4bd70058}},	//   _miðv, teïs, tlaj, _لبيد_
  { {0x6609002e,0x672d00dc,0xeafb0058,0xab8300ce}},	//   _þekk, ulaj, _زرعت_, _тушк
  { {0x9539000d,0x6702000b,0x7cf60045,0xd49b1c4d}},	// [b4d0] езат_, रोधक_, _vârf, дре_
  { {0x04f40121,0x672d008c,0x7d080085,0x44f41943}},	//   азую, slaj, nids, апус
  { {0xb4ac005d,0xd2510029,0xd4980063,0xa3b3000b}},	//   कड़े_, منا_, ърт_, _जैश_
  { {0x9f4700dc,0xaad6000b,0x22950015,0x966b0015}},	//   sznú_, धायक, الإس, _تصدق_
  { {0x656f0176,0x4aa5000b,0x5afc004c,0xa15809c2}},	//   _uwch, ग्यव, ולאצ, вачу_
  { {0x6e2b0026,0x3ea60035,0xe1340010,0xd59a000a}},	//   _rygb, _abot_, анчы, _אבשל
  { {0x3f58001c,0x63b80134,0xc7b2000a,0xbea50238}},	//   _céu_, ævnt, ֶ֑ה_, гайк
  { {0x3f580251,0xddc00007,0xf838000f,0x3dc600da}},	//   _déu_, jamų, כנות_, _brow_
  { {0x5215004a,0xad650015,0x3dc628a7,0x7e694c30}},	//   _сдат, داعه, _crow_, rbep
  { {0xee36008f,0xd1b80015,0x8b690004,0x3f580144}},	//   ыны_, _جافا_, ниов_, _féu_
  { {0xa2f5000a,0xd120000b,0xfc054c31,0x0000006a}},	//   ָמָה_, मकरण_, упно,
  { {0x6f7a000a,0x60c60091,0xb4e0000b,0x7bc10546}},	//   _נְבו, _ėkmi, _तव्_, rvlu
  { {0x6f090050,0x3dc6003e,0x6bd60086,0xddeb0015}},	//   miec, _grow_, نویس_, _تراه_
  { {0xa6db0084,0x6f090024,0x394c00c0,0x5bc50015}},	//   _miðu, liec, öds_, _مقتل
  { {0x9d1a0008,0xdc9a01ac,0xad1a000a,0xab990015}},	//   _אוסט, _ניקל, _אוסר, _أختر_
  { {0x6f0902ef,0xb8eb000b,0x29d8006f,0x3ebf4c32}},	//   niec, _रो_, ežať_, ndut_
  { {0xa6db0084,0x86750010,0x3ebf0321,0xda0a0015}},	// [b4e0] _niðu, рысц, idut_, _سيده_
  { {0xf993000a,0xf50702ed,0x69090081,0x0000006a}},	//   _פרת_, гнул_, lžen,
  { {0x389b00b2,0x6d410034,0xb89b000a,0x9a25002b}},	//   _איינ, imla, _אביש, _معین
  { {0xa6db002e,0xe2920029,0xdcb10092,0x7cf60045}},	//   _biðu, إذا_, hẻ_, _târg
  { {0xc05a0191,0x28130074,0x3f580084,0xca97000a}},	//   ній_, _نویس, _séu_, רדני_
  { {0xe5a30001,0x79b7000a,0x70530015,0xd5cb0643}},	//   _ћири, טלנד_, منها, _אֶלָ
  { {0xdfa60029,0xa8570008,0xa6db002e,0x6d5d4c33}},	//   احتي, ניקה_, _viðv, ísan
  { {0x2d8204c0,0x71760018,0xf773000a,0x83ab000a}},	//   škem_, _مهرا, זקה_, _אֱמֶ
  { {0x26c00026,0x5d5405e6,0xe80b000b,0x6380013f}},	//   idio_, јкот, _हेना_, _dánš
  { {0x8f760191,0xdce9002c,0x114a0015,0x71730067}},	//   _буді, ateľ, _أجرى_, _طهما
  { {0x6f094c34,0x5b1507be,0xd00f0015,0x7b15006b}},	//   biec, имот, _فلك_, идох
  { {0x93fb000a,0x6f09002a,0xaa670033,0x501b000a}},	//   תלטי, ciec, ыток, _אובו
  { {0x26c00176,0x588704ab,0x2d9f1a87,0xa2d5000b}},	//   ddio_, лыва, ctue_, णात्
  { {0x5d83003b,0xac97003b,0x25a00134,0xcd97000f}},	//   _الول, _منها_, dtil_, _עדות_
  { {0xd7f8005f,0x07090015,0xe7330015,0xf99f0144}},	//   гут_, نيسي_, مصر_, stè_
  { {0xa4ff005d,0x7c38052c,0x290a016e,0xdb0b0123}},	//   ोच्च_, _izvr, aiba_, _arfö
  { {0xe8f4002b,0xe66410ff,0x65950829,0x4ab20065}},	// [b4f0] _گسيخ, стсо, разу, ज़रव
  { {0x753c005c,0x6f09005c,0x290a0077,0xd9440054}},	//   _chrz, ziec, ciba_, _лењи
  { {0x325501d9,0x29d8002c,0xb08400fd,0x67d5123a}},	//   авер, ržať_, _свiд, _тону
  { {0xd6db1e88,0x65950010,0xb7da0008,0x25a04c35}},	//   _что_, _каму, _סקרי, btil_
  { {0x067a0008,0xf67a000a,0x3619000a,0x867a000a}},	//   _שנשל, _בארמ, _יוֹד, _שרשו
  { {0xc05b0036,0x6f09005c,0xa6db002e,0xca38000a}},	//   хід_, wiec, _viðu, אנדה_
  { {0x6f094c36,0x6e950015,0x4fc80015,0xe80b000b}},	//   tiec, للغا, ُوهُ_, _हेमा_
  { {0x3ebf008c,0x2d9f04ad,0x0d851c86,0x9758000a}},	//   udut_, ttue_, алин, ניחו_
  { {0x3ebf0f23,0xee39006b,0x6ea1000b,0x66e8000a}},	//   rdut_, ъни_, क्षु, ר֥וּ_
  { {0x6f090b90,0x2d9f0bf5,0xe572000a,0x6d41013c}},	//   siec, rtue_, קַח_, umla
  { {0x6f0945a5,0xeb990001,0xd01100e6,0x2fd90087}},	//   piec, њим_, _بلا_, _جواد_
  { {0x69091483,0xf1bf0030,0xa6db001a,0xb2f1005e}},	//   užen, _áás_, _miðs, йбiл
  { {0x69090c6d,0x290a4c37,0x0d67004a,0x9a1a005e}},	//   ržen, tiba_, _съем, тюну_
  { {0x1a660086,0x7e7b08c0,0x8dfa000a,0x2ca70016}},	//   دیکی_, laup, _שהסת, _ubnd_
  { {0x61eb1d06,0xc7460015,0x290a4c38,0x2f1a003d}},	//   hygl, لضري, riba_, līga_
  { {0x25a000cb,0x09e6009f,0x1666023d,0x46160021}},	//   ttil_, _воин, рвам, لوزر
  { {0x2f1a003d,0xe64a03ae,0x6d5b4c39,0xaa7b0046}},	// [b500] nīga_, тпад_, nqua, rkýt
  { {0x9a3b0008,0x7e7b00b8,0xa6db002e,0x25a011b2}},	//   _בתפק, haup, _biðs, rtil_
  { {0x46a60010,0x6d5b003e,0x25a04c3a,0x2d8d00da}},	//   _канв, hqua, stil_, hree_
  { {0x7ae4022d,0x82a62971,0xe57a0063,0x25a0003c}},	//   _joit, радж, _изм_, ptil_
  { {0x44260050,0xa6db002e,0x6d5d002c,0x7ae40f61}},	//   ło_, _viðt, ísal, _moit
  { {0x6d5b003e,0x7af60026,0xf9930008,0x9097005e}},	//   dqua, _llyt, קרו_, ивіт_
  { {0xd00f00e5,0x4fb30015,0x351b000a,0xa5070bdb}},	//   وله_, قصير, _סולנ, _тера_
  { {0x7ae403d0,0x9757000a,0xb3bb000a,0xddcb003d}},	//   _noit, סיפו_, _במלכ, _segš
  { {0x50b60036,0x2d8d003e,0xbce60029,0xf1a90029}},	//   _всеу, gree_, لأدو, _ماله_
  { {0xc19b000a,0xe611000a,0x8078000a,0x9078000a}},	//   _בשמי, לִי_, _תְּה, _תְּפ
  { {0xdeef008f,0x6ab2005d,0x60fb000a,0x5457000a}},	//   _ды_, ज़ूर, _שהבק, יסין_
  { {0x6da622b2,0x7ae44c3b,0xcfa90029,0x4aeb005e}},	//   _вида, _coit, _حاكم_, тьом_
  { {0x2d8d00da,0x298b006b,0x2f1a003d,0x59b0000b}},	//   cree_, ъсно_, cīga_, फ़िगर
  { {0xa6db002e,0xdca30054,0x0000006a,0x0000006a}},	//   _niðr, _даљи,   ,
  { {0x7d1d2ab5,0x0d3b000a,0xd918004a,0x5d3b000a}},	//   ésse, _שגוב, рья_, _שתוא
  { {0x501b0008,0x8655006b,0xddc90045,0x5b240058}},	//   דולו, сках, nceş, _وفول
  { {0xc6390036,0xa6db001a,0x9b440015,0x63ae01d7}},	// [b510] упає_, _biðr, _بنيو, _apbn
  { {0x629b04ed,0x69090085,0xd7f10016,0x04670a96}},	//   _scuo, ožem, ỡ_, ртам
  { {0xd6d1003b,0x61360011,0x6ef50030,0x78b50030}},	//   _فقد_, tâln, _lába, mezv
  { {0xa6db4c3c,0x91b5000b,0x92940033,0xa1590033}},	//   _viðs, _आईआई, жацц, гаду_
  { {0x68e5022d,0xcb140008,0x1bed000b,0xf994004c}},	//   _kohd, חלף_, _चॅनल_, ַרק_
  { {0x68e500f2,0x61eb0026,0xe4c7004a,0x6754002b}},	//   _johd, rygl, _тёмн, _دخیر
  { {0x92030024,0x13b40015,0x78b5003d,0xa3bb000b}},	//   _šādu, _وصفح, iezv, _अनि_
  { {0x38180008,0x2bb0000b,0xcc89002b,0x2f1a003d}},	//   יקום_, _जनजा, گنده_, tīga_
  { {0x78b500dc,0x6b5e0024,0xdea4002b,0x7bda4c3d}},	//   kezv, _rīga, تینی, extu
  { {0x7ae400f2,0x2f1a0024,0x6d5b4c3e,0x78b50030}},	//   _soit, rīga_, rqua, jezv
  { {0xb4fa0008,0x69094c3f,0x7ae44c40,0xfbd1002b}},	//   רפתי, ržel, _poit, ستد_
  { {0xdce00024,0x3d950080,0xa96a025f,0x60c14c41}},	//   rpmā, _гидр, лима_, _halm
  { {0x7ae439d2,0x7bca483c,0x60c14c42,0x6f1e0030}},	//   _voit, _erfu, _kalm, épce
  { {0xcc08002b,0x60c1008c,0x78b50030,0x991601f3}},	//   ازین_, _jalm, gezv, сьмі
  { {0xbb85003b,0x6d5900b6,0x9b950029,0x7ae42607}},	//   _البي, _huwa, _العت, _toit
  { {0xaa7b0084,0x6d5921a0,0xcaf6002b,0xcc140015}},	//   skýr, _kuwa, _دستب, _بذهب
  { {0x057a0015,0xe73724bf,0xc4560015,0x629901d0}},	// [b520] امطة_, сет_, مضاع, dgwo
  { {0x4583005e,0x7e790012,0xf86a0015,0x3f8e0034}},	//   ягув, _lewp, _حمدي_, yrfu_
  { {0x8ca9005d,0xc5e90008,0x59b8005d,0x387a003d}},	//   ज्यो, עד_, ेटवर, _iepr_
  { {0x9186003b,0x645500f0,0x60c10c99,0x96960099}},	//   مجتم, _egzi, _aalm, _урош
  { {0x26c2016f,0x29180064,0x1a9b0053,0x4a9b000a}},	//   _iako_, onra_, רינע, רינג
  { {0xa50a0403,0x629900dd,0xa3b3000b,0x8637000a}},	//   _сега_, agwo, _जैक_, _לרכב_
  { {0x26c2090c,0x6ef5047e,0xf8b3000a,0x68e14c43}},	//   _kako_, _sába, פשה_, öldi
  { {0x6d5900b6,0x26c2037f,0x6ab2000b,0x9316012c}},	//   _buwa, _jako_, ज़ोर, _اورش
  { {0x2dda0029,0x7bc60024,0xa2d5005d,0xbd870029}},	//   ابعة_, ākum, णार्, منين_
  { {0x26c20f58,0x2d8a00bd,0x6d5902f2,0x60c13e5a}},	//   _lako_, čbe_, _duwa, _galm
  { {0xead9005e,0x2487006f,0x6eaa006b,0xe0430004}},	//   амні_, ónmi_, _бълг_, _енфи
  { {0x6ec50015,0xcf57000a,0x441b000a,0x2f1a003d}},	//   _وتنق, _הבאת_, רוטס, mīgo_
  { {0xaa640010,0xcf250002,0x2f1a003d,0x78b50030}},	//   ятэк, _برلي, līgo_, tezv
  { {0x2ee6020a,0x61fd0061,0xf8690015,0x195801b0}},	//   _hoof_, _üsle, شمري_, сары_
  { {0x7d37000a,0x41b5000b,0x2f1a003d,0x6d592a58}},	//   _הנגב_, _आईऍस, nīgo_, _zuwa
  { {0xdce00048,0xceb90089,0x9c170008,0xfc17000a}},	//   ksmī, toři_, _לחוק_, _לקוי_
  { {0x26c702d5,0x4ad6000b,0x99640033,0x7afd0125}},	// [b530] ěno_, धारव, _нтэл, mhst
  { {0xe4150010,0xf992000a,0x89dc000a,0x4aa5000b}},	//   одзь, _קרי_, _תחזי, ग्रव
  { {0xb6090024,0x23b50015,0xaadd000b,0x7afe01c0}},	//   _sašķ, تماس, यापक, ďstv
  { {0x9258002b,0xa7e8000a,0x2f1a003d,0x60c14c44}},	//   مشهر_, _הַשֻ, dīgo_, _salm
  { {0x9948002b,0x320b002b,0x018b004a,0x08f8002b}},	//   _خلیل_, دتاً_, ущей_, _ضریب_
  { {0x26c2000c,0x297c000a,0x397c000a,0x656d3359}},	//   _zako_, נטוא, נטונ, mpah
  { {0x26c20f4d,0xfe710029,0x289c0053,0x70b9000b}},	//   _yako_, ودة_, טיגא, _इसील
  { {0xe2f8005e,0xbf150015,0x6d5902f2,0xb364006b}},	//   _лесі_, توعب, _puwa, _хърк
  { {0xa5db000a,0x26b6000a,0x30a70004,0x62894c45}},	//   רַ֔י, חִים_, _грев, _ideo
  { {0xff0800f2,0x7d090001,0x5ba92374,0x6aad03a6}},	//   äärä_, рног_, аком_, _abaf
  { {0x2f1a0024,0x03d5000a,0xfc310015,0x656d01d7}},	//   cīgo_, קוֹם_, بحة_, hpah
  { {0x63a5002d,0x539a0135,0xc869000a,0x5dd50015}},	//   ithn, סירו, _ין_, _وقائ
  { {0x6ef500dc,0xfa360015,0xdb020030,0x25fb0065}},	//   _hábo, تردد, ntlé, लैमी_
  { {0x672f005c,0x69cd0026,0xbd450015,0x26c24c46}},	//   _akcj, _drae, _بنتي, _sako_
  { {0x4fac000a,0x69cd007c,0x8cd6000b,0x628921ae}},	//   ְׁמְ, _erae, बारो, _odeo
  { {0x7afd018b,0x6289002d,0x05760058,0x9f47005a}},	//   chst, _ndeo, قائد, kyní_
  { {0x656d0035,0xceb2039e,0x6d5d0046,0xc4e60342}},	// [b540] gpah, וין_, ísah, ожай
  { {0x26c2000c,0xe5771aef,0x6d88000a,0xd2a602a3}},	//   _wako_, юзу_, מָעְ, _вiль
  { {0x26c2065d,0xe3ba0001,0x656d2325,0x6ef50057}},	//   _tako_, рбе_, apah, _nábo
  { {0x8c1a0008,0x7d060030,0x316a0788,0x35d10065}},	//   בועי, éksz, ашко_, समख़
  { {0x63a5002d,0x2ee6003e,0xf204005d,0xc6b7000a}},	//   athn, _roof_, _शेख़_, _והכי_
  { {0xc5f3013a,0x2f8a0054,0x3f660850,0xa2ca0065}},	//   _חדש_, аљин_, отиб, _सोर्
  { {0xc8db0053,0xaff70015,0xa88b000a,0x2d8b0046}},	//   יקסט, يفها_, שָׂ֥, ácen_
  { {0x2f1a0024,0x9f5f0030,0xe29716bb,0x9757004f}},	//   rīgo_, úrák_, _мас_, חיקו_
  { {0xfd460010,0x71650015,0x867b000a,0xe0da0204}},	//   жэнн, _فالك, ברפו, _ква_
  { {0xa3ae005d,0xbc4a226a,0xc106002b,0xffd60058}},	//   _कहा_, ичне_, _بوئي, _وغاد
  { {0x7afd003e,0x28de000b,0xe0850015,0xce34002b}},	//   thst, मानि, _رجلي, _کوشک
  { {0xeb070191,0x7f190010,0x69cd4c47,0x4e2a029f}},	//   ічно, _лічу_, _prae, _коен_
  { {0x9e650086,0xad5a0080,0xae160015,0xb9e7005e}},	//   _رانن, _трех_, _بذات, ціни
  { {0x63a50026,0xd90f0086,0x6ef500dc,0xfe37000a}},	//   ythn, ئید_, _lábl, _ורדי_
  { {0xbd430021,0x36d501ca,0x2d84003d,0x0000006a}},	//   _تنوي, повр, lsme_,
  { {0x8b240001,0x64580091,0x0a6b0004,0x69cd4c48}},	//   _одје, žvil, _трки_, _trae
  { {0x61e4008c,0x5555002b,0x7d1a4c49,0x8ca10065}},	// [b550] äill, سپار, onts, _खामो
  { {0x34940010,0xd3710015,0x67360091,0x7d1a0012}},	//   дафр, ّها_, alyj, nnts
  { {0x68e1002e,0x6d480091,0x04c80015,0x29114c4a}},	//   öldu, imda, تولي_, miza_
  { {0x63a50176,0x2d84231a,0xd3780248,0xdb190046}},	//   rthn, ksme_, ючу_, _osví
  { {0x41b5005d,0x2d840089,0x1a9c004c,0xc2c40040}},	//   _आईओस, jsme_, שידע, بيني
  { {0x79bc000a,0xdcfb003d,0x91050033,0xd14800c3}},	//   שֶׁה, ksuā, япле, يشون_
  { {0x92b70015,0x2d844c4b,0x0000006a,0x0000006a}},	//   _وحرا, esme_,   ,
  { {0x2d951725,0x7d1a4c4c,0x3e890015,0x7f424c4d}},	//   прос, ents, حَةَ_, _choq
  { {0x2911003f,0xe8d90016,0x69090091,0xfe71002b}},	//   kiza_, _cuị_, ažei, ودک_
  { {0xeb990001,0xe0d00015,0x6efc0003,0x24810012}},	//   био_, _لزم_, _rébe, nahm_
  { {0xca2901c8,0xc10403c4,0xb445005e,0x2d840f29}},	//   _עם_, _تولي, омiч, asme_
  { {0xdb040134,0x672d008c,0x6d4837c8,0x7d1a4c4e}},	//   _opnå, joaj, amda, ants
  { {0x7f3a000a,0x8e490015,0xae5a000a,0x0000006a}},	//   _פענו, _الشك_, _הכנר,
  { {0x2911000c,0xccc40036,0x291e007c,0xbd280015}},	//   giza_, _обій, õta_, _وأول_
  { {0xf746005e,0x6f1b0061,0x6443001a,0x69db02ad}},	//   зево, onuc, ýnil, äuer
  { {0x4b7a0053,0x9f5600dc,0xa3c1005d,0x056608d7}},	//   _פאפו, ógép_, ्टन_, зван
  { {0xba9b0008,0x8afb0008,0x69c00064,0x6ab8000b}},	// [b560] _הספי, _להקי, çmed, इजीर
  { {0x291141d5,0x7f490012,0x2eb80065,0x68e101d3}},	//   ciza_, hmeq, _आस्त, öldt
  { {0x1877000a,0xa85b000a,0xd3360033,0xd7ca0015}},	//   _מעיר_, _לדיכ, пэды, _اوجه_
  { {0x7395005e,0xdcfb0061,0xd36f0021,0xe29a2df1}},	//   ьшує, yruğ, اهن_, сад_
  { {0x98aa0091,0x23270004,0x7cf60045,0x6d484c4f}},	//   albą_, чоци_, _bârl, ymda
  { {0x6604003f,0xd12f002b,0x7cf600d4,0x0000006a}},	//   mzik, همن_, _cârl,
  { {0xd0100029,0x6ef51718,0x4f670033,0x63ab0046}},	//   ضلة_, _tábl, пшым_, ělní
  { {0x24530029,0x1657000a,0xc7b3000a,0x2d84007c}},	//   _أنفس, ּׁים_, גבה_, tsme_
  { {0x27f1005c,0x7d1a0030,0x9c7c0046,0x0657000a}},	//   zyzn_, tnts, ejča, היפך_
  { {0x6d43002d,0xc106002b,0xe8d90016,0x2d84003d}},	//   _chna, _عواي, _vuị_, rsme_
  { {0x0a95008b,0x6d48068c,0x29114c50,0x0000006a}},	//   маню, rmda, viza_,
  { {0x23be0089,0x2417000a,0xcff7000a,0xd00f0021}},	//   _můj_, לחין_, _מצבה_, _حلم_
  { {0x7ced002d,0x7ee30015,0xc8c8000b,0xdd8f0040}},	//   _cúrs, _سكون, िएंट, _مون_
  { {0x7bdc0005,0xa3c1005d,0xf77300e6,0xdce9003d}},	//   ärus, ्टम_, فار_, rreģ
  { {0x8ca1005d,0x660402c6,0xbb830015,0x67d408e8}},	//   _खातो, ezik, _كلوي, нору
  { {0x8c1b013a,0x70b9005d,0x8c370008,0xb8f4000b}},	//   _לווי, _इस्ल, _מטוס_, _सो_
  { {0xdce904af,0x7ada000a,0xa92b0033,0x6b9a2078}},	// [b570] zpeč, _וַיה, _гіне_, lutg
  { {0xb97c0008,0x28de000b,0xe945002b,0xe3b30015}},	//   _הנזי, माणि, _تربی, فرص_
  { {0xccf300b2,0xc7ab0029,0x6b9a0c4e,0x0000006a}},	//   עכע_, _ادخل_, nutg,
  { {0xd251003b,0xa2f50033,0xa3ae000b,0x91f90058}},	//   ننا_, ьпеч, _कहर_, يفاء_
  { {0x2d91005c,0xdd860002,0x26d902ad,0x0000006a}},	//   ązek_, _جو_, _inso_,
  { {0xf7700074,0xc24413ae,0x25a91fc7,0x68470003}},	//   _جای_, хнік, mtal_, cédé
  { {0xe0840086,0x33750033,0xdce90046,0x25a94c51}},	//   رجوي, _ігар, upeč, ltal_
  { {0x26c90f4d,0xdb19002c,0x6f1b0061,0x69d0000b}},	//   ndao_, _prvý, unuc, दिमी
  { {0x25a90106,0x9e640067,0xf194004a,0xa194011e}},	//   ntal_, راين, _пить, _патч
  { {0xb1140127,0xfb890248,0xab6510b7,0x25a90ff0}},	//   _змуш, обок_, мвол, ital_
  { {0x1c45006d,0x90280033,0x7cff00aa,0x3cde000b}},	//   ьном, _ецца_, _nêre, _कचरे_
  { {0xc9aa0004,0x66040069,0x0000006a,0x0000006a}},	//   овме_, yzik,   ,
  { {0x6bd5002b,0xdca50bdb,0x0000006a,0x0000006a}},	//   ستگر, _жали,   ,
  { {0x7cff00aa,0x3d2a002b,0xa91b001a,0x6b9a4c52}},	//   _bêre, _وتوی_, lsþj, butg
  { {0x07a34c53,0x25a94c54,0x8b640058,0x0000006a}},	//   карн, etal_, _كايم,
  { {0xba56006b,0x25a90079,0x68e10030,0xf743004a}},	//   _отпъ, ftal_, öldr, весо
  { {0x385a0015,0x9aa90067,0x68f90030,0x54c64c55}},	// [b580] _وشدد_, _رديف_, áadó, мбаб
  { {0x448a005e,0xf53f0123,0x7e7d001a,0x6ef5006f}},	//   ібен_, _spår_, ðspj, _bábk
  { {0xc953000a,0x25a900ac,0xe3b20015,0x28cb000b}},	//   _שמת_, atal_, ضرا_, ायरि
  { {0xf773000a,0xbec3003d,0x23be0046,0xdb04006f}},	//   _שקר_, _šūna, _vůj_, _apnú
  { {0xe1630086,0x7177005e,0x690900bc,0xf1940342}},	//   نگلي, дбір_, ržev, хиль
  { {0x2f1a0024,0x6ef5002d,0x7bc30844,0xe4da0015}},	//   mīgi_, _hábh, _osnu, _بوست_
  { {0x2f1a0024,0xf8b3000a,0x3ead0b30,0xc917000a}},	//   līgi_, דשו_, ffet_, וחסת_
  { {0x78a9016f,0x69c44c56,0xdd900015,0x78bc4c57}},	//   đevi, _osie, هوب_, herv
  { {0x6909016f,0x2f1a0024,0x78bc1c08,0x5d540254}},	//   ožet, nīgi_, kerv, нкит
  { {0x6efc0152,0x62804c58,0x6b9a00cb,0xb1431ecc}},	//   _déba, _hemo, tutg, _анул
  { {0xd497000a,0x25a90030,0x62804c59,0x78bc4c5a}},	//   וכית_, ztal_, _kemo, derv
  { {0x6b9a02df,0x60c80030,0x44384c5b,0x7dc60058}},	//   rutg, _hadm, _myr_, _يتشك
  { {0xbce60015,0x3f9c0069,0x62803200,0xb1a7000a}},	//   _يأتو, luvu_, _memo, ֵ֣ךְ_
  { {0x25a900c0,0x62800c0a,0x2f1a003d,0x645c0cb4}},	//   vtal_, _lemo, dīgi_, _ngri
  { {0x69c40024,0xe73300a2,0x69094c5c,0xc051000a}},	//   _esie, نصر_, džet, ָ֖ם_
  { {0x6d580014,0xe7840001,0xf7700021,0x25a94c5d}},	//   _hiva, ђусо, شاف_, ttal_
  { {0x7cff020a,0xe4e70036,0x60da0150,0xf599006b}},	// [b590] _wêre, міжн, _ontm, яващ_
  { {0x14740029,0x44381a63,0x60c80787,0x25a94c5e}},	//   نامج, _byr_, _nadm, rtal_
  { {0x22950015,0xe4a4006b,0x316d00bc,0x443810eb}},	//   فلاس, ърто, _stez_, _cyr_
  { {0xaabc0053,0x6faf000b,0x69090085,0x25640030}},	//   ַזוכ, ूबसू, ažet, _föl_
  { {0x2f1a0024,0x7d080007,0xeab2000a,0x60c84c5f}},	//   cīgi_, _kūrė, רֹב_, _badm
  { {0xe588000a,0x81440015,0xc0c80054,0xa0691d90}},	//   _קָרָ, نننن, дуће_, чака_
  { {0xa295008f,0x6ef50c98,0x6efc00e9,0xe4540033}},	//   _паві, _hábi, _séba, _акры
  { {0x62802514,0x6fb20087,0x6d580607,0xa3470033}},	//   _gemo, اميا, _aiva, _цэгл
  { {0x63b80046,0x6d58440d,0xd234006b,0x6abd4c60}},	//   čanš, _biva, _антъ, desf
  { {0x62010064,0x6d580064,0xeb990feb,0x8638000a}},	//   ızlı, _civa, пио_, ורחב_
  { {0xa3c1005d,0x7c950086,0x7aed1e0f,0x28de000b}},	//   ्टि_, وشگا, _boat, मासि
  { {0x4e350015,0x3e350015,0x8a06004a,0x7aed4c61}},	//   _كفاء, _كفار, езме, _coat
  { {0x78bc189e,0x6e9200c3,0xec790b45,0x0000006a}},	//   terv, _صلوا, _епл_,
  { {0x6ef5002f,0xa3c1005d,0xdc120061,0x2f1a003d}},	//   _sábh, ्टा_, aşım, vīgi_
  { {0xfc640063,0xacfa000a,0x67290046,0x5bc50015}},	//   _ръчн, _מהסכ, čejn, _أقبل
  { {0xc4c60074,0x645c0026,0x69c40026,0x2f1a0024}},	//   کترو, _sgri, _tsie, tīgi_
  { {0x443e018c,0x98a3005c,0xf98a0029,0x44380026}},	// [b5a0] _št_, woją_, _عندي_, _syr_
  { {0x3d1d005d,0x2f1a0024,0x98a30007,0x2564002e}},	//   _पदों_, rīgi_, toją_, _völ_
  { {0x6ef5002d,0x7e694c62,0x62800509,0xa87b0447}},	//   _tábh, kcep, _pemo, _מאיר
  { {0x869a005f,0x22280086,0xd7360036,0x2f1a0024}},	//   _этот_, وزشی_, _їхнь, pīgi_
  { {0x645c003d,0x62801407,0x44382ccc,0xddcb0061}},	//   _tgri, _vemo, _wyr_, _ğişi
  { {0xd1750010,0x61d70010,0x3f9c003d,0xc0e300f4}},	//   тыцы, эмія_, tuvu_, лочк
  { {0x443e0014,0xb89b004c,0x62804c63,0xa523012e}},	//   _át_, לבסש, _temo, _смрд
  { {0x03d7013a,0xc0590010,0x395a4216,0x1eaa0015}},	//   _אולם_, фіі_, _lips_, سابي_
  { {0x31260033,0x865b000a,0x7aed0045,0x7ced072a}},	//   _здаг, הדפי, _roat, _púrp
  { {0x7153002b,0xafe615be,0x0000006a,0x0000006a}},	//   _منقض, _позл,   ,
  { {0x7aed04f9,0x20180020,0x2007005c,0x6d584c39}},	//   _poat, _äri_, czni_, _viva
  { {0x141b0053,0x78a504af,0x7e694c64,0x7c3801c0}},	//   לויב, _schv, ccep, _vyvr
  { {0xfaa40033,0xdc120061,0x69094c65,0x6d584c66}},	//   ышэн, rşım, džer, _tiva
  { {0xf7950010,0x6d5801f6,0xe76b011e,0x0000006a}},	//   кагэ, _uiva, зјак_,
  { {0x7aed04f9,0x7a490048,0x913b0053,0x6ef5016e}},	//   _toat, _sūtī, פעלק, _sábi
  { {0xdc3b0008,0x36d5006b,0xcc3b000a,0xdddb003d}},	//   _מעור, ъобр, _מעוט, lauš
  { {0x395a003e,0x99d70015,0x6594110c,0x0000006a}},	// [b5b0] _fips_, _أتعا, лату,
  { {0xa3e2005d,0x2f1a0024,0xd7e70010,0x57f50054}},	//   _गपशप_, mīgu_, _зімо, _апот
  { {0x2901001c,0xd4980010,0xf8b20053,0xdc8b000a}},	//   _ilha_, эрт_, _דשי_, לְאָ
  { {0xf2e4106d,0xf776000f,0xa295005e,0x7e694c67}},	//   лючо, _שערי_, таді, xcep
  { {0x2b49002d,0x2f1a003d,0x10a5011a,0x6fd60065}},	//   _mhac_, nīgu_, вилн, _मज़बू
  { {0xdddb0024,0xb97c0008,0x6e390026,0x93960061}},	//   jauš, לנדי, _rywb, üşür
  { {0xafe50033,0xbfa803ae,0x29010046,0x7df30535}},	//   тойл, етње_, _mlha_, zęsą
  { {0x6efc0152,0x7b240085,0xc2c50015,0x0e55006b}},	//   _débo, eđun, _جيري, къпя
  { {0x7c99006b,0x2901016e,0x2d8b0030,0x200713c3}},	//   мънс_, _olha_, éce_, szni_
  { {0x6b5e0024,0xfc3f0089,0x9d450054,0x7e694c68}},	//   _līgu, řím_, ђенд, scep
  { {0xaadd005d,0x5f940063,0x2b490125,0xf3f2000a}},	//   यांक, _бихт, _bhac_, ֹ֣ת_
  { {0xdfcf002b,0x0000006a,0x0000006a,0x0000006a}},	//   _پيچ_,   ,   ,
  { {0xed4e4c69,0x1eea0086,0x82760053,0xc212000a}},	//   _во_, _تونی_, כערע_, ֹ֔ר_
  { {0xd94605aa,0x7c870f82,0x9bc90058,0xfce500af}},	//   теги, _чуде, _يوشك_, _јоко
  { {0xe73a1068,0xdc88004f,0xdca202ed,0x26cb4c6a}},	//   дев_, _נְסָ, _тащи, _baco_
  { {0x3ebf00b8,0x07a3000d,0xcf920135,0x26cb4c6b}},	//   neut_, јатн, יטל_, _caco_
  { {0x2f1a0024,0xe812000b,0x96630033,0x26cb0045}},	// [b5c0] cīgu_, _डेरा_, ркуе, _daco_
  { {0x09f70008,0x14c8002b,0xe9a90015,0x80c0000b}},	//   _סמים_, عهای_, _أدين_, _एसें
  { {0x94060086,0x78fb000a,0x2897000a,0x6369005e}},	//   خواه, _חליפ, _בדין_, еріг_
  { {0x52760054,0x29184c6c,0x98a30091,0x6ef54c6d}},	//   тужу, lira_, doję_, _kábu
  { {0xe731000a,0x6ecc000b,0x92930033,0x6efc0003}},	//   _הֵם_, _दोगु, раіц, _débl
  { {0xc1040015,0x29184c6e,0x28c8000b,0xc05a008b}},	//   طوعي, nira_, िएटि, мій_
  { {0xf8b3000a,0x73e30724,0x2f1a003d,0x98a30091}},	//   ישג_, _корз, zīgu_, goję_
  { {0xbd870074,0xa3c1005d,0x5f730015,0x29184c6f}},	//   چنين_, ्टर_, جاور, hira_
  { {0xf1aa0074,0x1d340063,0xe357000a,0x9325002b}},	//   _تازه_, лния, _ישלח_, _صرفن
  { {0xedb50086,0x6443005c,0x6fb60015,0x0e330342}},	//   اجيک, żnie, _لمطا, рнью
  { {0x69c00064,0x8bc30033,0x1b1901b0,0x29184c70}},	//   çmen, асяд, ежны_, dira_
  { {0x25a000dd,0xc334000a,0x29184c71,0x2f1a003d}},	//   kuil_, רוֹ_, eira_, tīgu_
  { {0xc333013a,0xd2460029,0xc27b000a,0x127b004c}},	//   שור_, إن_, ורכי, ואכע
  { {0xd5bf0048,0x2f1a0024,0xcdf7000a,0x69d600da}},	//   šāku_, rīgu_, _במדי_, _drye
  { {0x195804f7,0x6f022631,0x5d47000a,0xe695004a}},	//   тары_, _kloc, _בָהּ_, ливы
  { {0x25a0017e,0xd7740029,0x1b2b0029,0x26c00026}},	//   fuil_, شافع, _تأتي_, geio_
  { {0xf99f0251,0xfdf4000b,0xfdfb000b,0x2f1a003d}},	// [b5d0] què_, ेनिस_, एनएस_, līgs_
  { {0x6f0208e0,0xa3c1005d,0x29184c72,0x7afd4c73}},	//   _lloc, ्टल_, cira_, lkst
  { {0xaaaa000b,0x2bd5000b,0x7d1d0144,0x2f1a003d}},	//   _कामक, धिया, éssi, nīgs_
  { {0x7afd4c74,0x26c04c75,0xc7d6004f,0x0000006a}},	//   nkst, ceio_, _עורי_,
  { {0xf62b0036,0xf1a70724,0x9258002b,0x2258004a}},	//   _ціни_, трен, نشهر_, вицы_
  { {0x6f02046d,0x80cd000b,0x00c80033,0x93970015}},	//   _aloc, _धोखे, клік_, _لجرا
  { {0xdfce0015,0x6f021470,0xa382007c,0x7afd2628}},	//   كيو_, _bloc, õõtm, kkst
  { {0xfe71003b,0x7afd0111,0xb7f6005d,0x7fb60115}},	//   حدث_, jkst, ीनतम_, اهير_
  { {0x6d4a002f,0x8d920015,0xdbf8002a,0x3ebf0012}},	//   _bhfa, مليش, kłóc, reut_
  { {0x2fd70015,0x6f0225dd,0x7afd4c76,0x0000006a}},	//   _لتصح, _eloc, ekst,
  { {0xdfd10015,0x2bb90015,0x6f024c77,0x29184c78}},	//   _ديا_, رادة_, _floc, vira_
  { {0x139a0053,0x539a000a,0x6008000a,0x6f024c79}},	//   עברע, עירו, _בִנְ, _gloc
  { {0xc332000a,0x82d6000a,0x52d6000a,0x27f80034}},	//   מוט_, אורג_, אורע_, wyrn_
  { {0x98360010,0x7afd144e,0x8d920015,0x69d6042f}},	//   гэбі, akst, _الوش, _vrye
  { {0x9bc90015,0x3156004c,0x26c0016e,0x61f90034}},	//   _أوبك_, טישן_, teio_, hywl
  { {0x29184c7a,0x6ef5016e,0xef19002a,0x7ae9007c}},	//   sira_, _tábu, niż_, öett
  { {0xd4d60010,0xb5aa0029,0xa5260054,0x612d0030}},	// [b5e0] ліжэ, عارك_, гмад, súly
  { {0xe5a300a5,0x2d8d008c,0xb97b004f,0x6ed50065}},	//   сифи, isee_, _רניי, _मोसु
  { {0x1d160053,0x78fb000a,0x3957000a,0xe29a0054}},	//   נקער_, _נפטו, _תשים_, еае_
  { {0x5c360053,0x7cf60045,0xdb0202de,0x518601f3}},	//   ארען_, _hârt, stlæ, гука
  { {0x2f1a003d,0x67240e2a,0x25a04c7b,0xdb0202ad}},	//   zīgs_, mnij, quil_, mtlä
  { {0x7056002b,0x61f70033,0xf487002b,0xd0d4006b}},	//   هنشا, ыніў_, _مافی, рокъ
  { {0xdfd0003b,0x7afd0007,0xf503088d,0x6f024c7c}},	//   زية_, ykst, _узро, _ploc
  { {0x6443005c,0xaf030033,0x2f1a003d,0x4ea62b43}},	//   żnic, йчык, vīgs_, урка
  { {0x69c00064,0x1ed70015,0xe297006b,0x644b002a}},	//   çmel, طبيب_, _щат_, ęgie
  { {0x65662ddf,0x4c940054,0x1bb40033,0x7e7b01d7}},	//   _mukh, јинс, абоў, abup
  { {0xf537004c,0x7b160091,0xdb020c9e,0x5ea60040}},	//   רטיר_, ašum, ktlä, _ممال
  { {0x2f1a0048,0x6724016f,0xe4570053,0xbb93004a}},	//   rīgs_, jnij, טייט_, щающ
  { {0x6724016f,0xb69b0045,0x2f1a003d,0x2d8b0046}},	//   dnij, _blân, sīgs_, ácet_
  { {0xc237000a,0xbd02013f,0x67243f66,0x7b160de4}},	//   טרכו_, _šéfr, enij, nšuj
  { {0xd7e400fd,0xdb020400,0x7d1a4c7d,0xd6db213b}},	//   біто, ftlä, mits, нта_
  { {0x7d1a2e32,0xeafb0086,0xc8780064,0xf5e7017f}},	//   lits, _سرعت_, ığa_, лізм
  { {0xb4c2005d,0x9f4b0030,0xdb0200aa,0x95390004}},	// [b5f0] ्यू_, élén_, kulê, взат_
  { {0x98aa0011,0x656602f2,0xb69b016e,0x7d1a4c7e}},	//   robă_, _dukh, _glân, nits
  { {0x6724016f,0x201a006f,0x7d1a0072,0x0000006a}},	//   bnij, úpil_, iits,
  { {0x6b7b01ac,0x877a000a,0xd874002b,0x67240085}},	//   גראנ, _שארי, _پایب, cnij
  { {0xd49b000d,0x02c2005e,0x91e50965,0x7d1a13e8}},	//   _прв_, ійшо, роле, kits
  { {0x361a000a,0x40c80015,0x8ca9000b,0x8fa50015}},	//   _יורד, ُونَ_, ज्ञो, لمته
  { {0x7d1a0020,0xb4440010,0xf8dc000a,0x799d0012}},	//   dits, _гэтк, תחומ, hrsw
  { {0x2d8d00f2,0x64630064,0x0e6509c3,0x9e65005e}},	//   tsee_, ştiğ, шкин, швид
  { {0x7bd80005,0x7d1a0020,0x90a70029,0x8d750029}},	//   _arvu, fits, _محام, جابا
  { {0x5f950063,0xa3bc005d,0x69c00061,0x67244c7f}},	//   _вижт, _अहम_, çmem, znij
  { {0x3b0a0a21,0x2d8d2457,0x5f74002b,0x8c450055}},	//   вено_, ssee_, _هانر, рене
  { {0x60c301e2,0x7d1a0e95,0x8ca1000b,0xf1a70015}},	//   lenm, aits, _खाको, يء_
  { {0x6724016f,0x7bca02c1,0xb69b0011,0xfce54c80}},	//   vnij, _esfu, _plân, _воло
  { {0x395e00c0,0x6f1b0007,0x660d2396,0x2eed0085}},	//   öts_, liuc, dzak, ljef_
  { {0xc716000d,0x6724016f,0x60c30024,0x9d1a00a3}},	//   аќањ, tnij, ienm, _בוסט
  { {0x6f0903af,0x60c30012,0x67240b46,0xd703005e}},	//   nhec, henm, unij, озси
  { {0x2fc70026,0x6b830026,0x8b3b000a,0x7b160057}},	// [b600] hwng_, _hwng, _בתקצ, yšuj
  { {0x67241007,0x79fb0008,0x6d414c81,0xb896006b}},	//   snij, _סליח, nlla, _триъ
  { {0x389b01ac,0x845a12ba,0x2b590046,0xd7ff0045}},	//   _ביינ, трат_, ůrce_, ţări_
  { {0xd80b000a,0x65664c82,0xe61a0238,0x628b0144}},	//   _יִכָ, _tukh, _адм_, gago
  { {0x867b039e,0xb0e2000b,0x660d002a,0x60c30012}},	//   _ברכו, पालग, czak, fenm
  { {0x2fc70026,0x6443005c,0xb113005e,0xe1370033}},	//   fwng_, żnia, оміш, азіі_
  { {0x628b00b6,0x7b162786,0x7b24016f,0xa0670001}},	//   bago, ršuj, rđuj, шаја_
  { {0xf7730008,0xa8570008,0x479b004c,0xff4f0015}},	//   חקה_, סיקה_, דיקס, وخي_
  { {0x10a60191,0xa0a60001,0xdfd00086,0xdb0200dd}},	//   _визн, _вазд, زيک_, pulê
  { {0x62080064,0x80b0000b,0xe0d7005e,0x7d1a2252}},	//   ırlı, _आउटे, _кву_, uits
  { {0x9b59000d,0x14d90053,0x2fd7002b,0xe8d90016}},	//   лиот_, אַרמ, _پوند_, _huệ_
  { {0x7d1a4c83,0x8f8b000a,0x501b000a,0x6d414c84}},	//   sits, _יְדֵ, _בובו, alla
  { {0x799d00dd,0xd357000a,0x753c002a,0x6b830034}},	//   ursw, ייטי_, _okrz, _ewng
  { {0x7cf60011,0x29054c85,0xf77300c3,0x6cd30015}},	//   _vârs, óla_, قار_, _وقنا
  { {0x9b9403c4,0xdb0b0134,0xab940021,0x2bd9002b}},	//   _البت, _opfø, _البغ, _مايک_
  { {0x27ed016f,0x6c5b0008,0x628b1254,0x7bcb004f}},	//   ćen_, _בדוח, xago, _יֶחֶ
  { {0x95d90010,0xe758005e,0xd6d80b1e,0x628b1351}},	// [b610] ыдат_, риті_, јтс_, vago
  { {0x660d4c86,0xe3b30015,0x7e0b000a,0x5fc6000b}},	//   rzak, قرص_, כִבֶ, लबाल
  { {0x660d00dc,0xfc3f0046,0xdb0217ca,0x628b4c87}},	//   szak, řív_, stlå, tago
  { {0x3cdd000b,0x98aa002a,0x7d0d0073,0x0000006a}},	//   _कोने_, robą_, _įasm,
  { {0x31c700d0,0x6aad4c88,0xa2270067,0xd1c8006e}},	//   рсев, _mcaf, جراه, لبوم_
  { {0x80a80036,0x628b2fec,0x2fc70034,0xe8d90016}},	//   ивів_, sago, twng_, _duệ_
  { {0xa1560001,0x60c34c89,0x5ea50015,0x2054006b}},	//   љају_, renm, ممثل, отър
  { {0x3eb9002e,0x01650015,0x69c00061,0x2fc70034}},	//   ýst_, _هُرَ, çmek, rwng_
  { {0x20c7005f,0xc3320053,0x6d410251,0x7b240030}},	//   _всег, _זון_, tlla, lőug
  { {0xa5da00b2,0x6d4101e2,0x5fc2005d,0xdca50001}},	//   אַטי, ulla, _वैकल, љани
  { {0x6d410026,0x6f094c8a,0x63a50509,0xf092000a}},	//   rlla, phec, nuhn, _זנב_
  { {0x6d413a42,0xb69b0003,0xc869015b,0x5ed40015}},	//   slla, _blâm, _טן_, _وتنز
  { {0x22da000a,0xdb024c8b,0x0000006a,0x0000006a}},	//   אחרא, nulé,   ,
  { {0xcd760008,0xed440036,0x6c850029,0x7d080010}},	//   _העסק_, _дніп, _الثم, _кніг_
  { {0xab990029,0x66e6124a,0x0000006a,0x0000006a}},	//   _إختر_, бова,   ,
  { {0x753c0e23,0x96660256,0xb679005e,0x166601b7}},	//   _skrz, скае, ищує_, свам
  { {0x98a60142,0x09ba0015,0x7ae424cd,0xf484002b}},	// [b620] _липе, _إطبع_, _init, قاضی
  { {0x88ca0a2c,0x7ae4002e,0xdb0201f6,0x673d4c8c}},	//   _слов_, _hnit, dulé, _eksj
  { {0x63a50049,0xa7b60054,0xb4e8000b,0xddc9006f}},	//   guhn, _успј, _मची_, jbež
  { {0xddc9006f,0x82a6008b,0xb283056d,0x0000006a}},	//   dbež, садж, пышк,
  { {0x91b70029,0xdce2016f,0x614605b3,0xe4760033}},	//   مطور_, _suoč, беда, _губэ
  { {0xa2d8000b,0x63a5013c,0xa43e0033,0xdf78005e}},	//   _नोर्, buhn, _зьбi, абкі_
  { {0x33780008,0x03a30342,0x6378000a,0xc8db000a}},	//   _כְּב, _ниро, _כְּס, טקסט
  { {0xe8d90092,0x3da6059c,0xc3060015,0xf1a9002b}},	//   _tuệ_, броб, _ابسو, _چاله_
  { {0xfe6f0015,0x9df7006b,0xdb020003,0x7a1c003d}},	//   ردي_, йнът_, culé, nātī
  { {0x25a00c48,0x6aad4c8d,0x7ae44c8e,0x35cf0065}},	//   iril_, _scaf, _anit, _सैफ़
  { {0x853b000a,0x25a04c8f,0x6f1e0030,0x0000006a}},	//   רגיי, hril_, épcs,
  { {0xdb0b0086,0x8fe50015,0x25a000bc,0x0000006a}},	//   ازده_, _بأكم, kril_,
  { {0xaaaa005d,0x4aaa000b,0x5ebb000a,0x2d9f0730}},	//   _कारक, _कारव, _תזדק, crue_
  { {0x7ae400f2,0x6b730011,0x5e57000a,0x8d56131f}},	//   _enit, _săge, _הידע_, _утеч
  { {0x28de005d,0xd7e4008b,0x0000006a,0x0000006a}},	//   माजि, піто,   ,
  { {0x501b0008,0x07090015,0x66390015,0x5b7b004f}},	//   אולו, جيري_, لكأس_, _גרהא
  { {0xfc3f0046,0xddc90085,0x44f508d7,0xb4670058}},	// [b630] řít_, zbež, опас, مداه
  { {0x4c78000f,0x63a501d7,0x04671fdd,0xed14000a}},	//   שָּׁ, tuhn, стам, קַּת_
  { {0x25a00020,0x47350010,0x645a4c90,0x344b1923}},	//   aril_, _мнос, _útil, учан_
  { {0xa2940191,0xe812005d,0x6443005c,0x63a5013c}},	//   заці, _डेटा_, żnio, ruhn
  { {0x63a501c2,0x2089070c,0x62890072,0x0000006a}},	//   suhn, айли_, _veeo,
  { {0x29030030,0xaf9915bc,0x15440033,0xdb0201d3}},	//   nkja_, атих_, _неўм, rulé
  { {0x2903002e,0xd01100e6,0xcee9005e,0xb1160015}},	//   ikja_, بلغ_, идке_, تقوا_
  { {0xdcfb0024,0x2d95107c,0x4ed5005e,0x2d9f00da}},	//   stuļ, орос, іюйт, true_
  { {0xdd8e0029,0x2903002e,0xa0c50002,0x51740015}},	//   نوي_, kkja_, _ويرو, _فالأ
  { {0x7ae4014c,0x9d5200c3,0x7e99002b,0x2d9f1d2c}},	//   _snit, ونيت, _چنار_, rrue_
  { {0x28ad005d,0xddc2005c,0x351a000a,0xdceb0046}},	//   ञ्छि, _czoł, שותנ, řiďt
  { {0x03d6000a,0xbdf8002b,0xcae4000b,0xa3da000b}},	//   קורם_, _گرما_, गाइड_, ़ित_
  { {0x7ae40089,0xa96a03de,0x5cf500ce,0x0000006a}},	//   _vnit, рига_, _мяку,
  { {0x6efc038d,0xddc90011,0xaa47005e,0x61f600cb}},	//   _débu, aceţ, іпра_, øyli
  { {0x46f60036,0x8b460015,0x9919008b,0xd943012b}},	//   очат, _وضعن, сіях_, фери
  { {0x7ae4050d,0x25a04c91,0x7b240085,0x224d013b}},	//   _unit, tril_, eđuv, _ozek_
  { {0x249800d9,0xca97000a,0x6443002a,0xae0c0065}},	// [b640] _pdrm_, _ודפי_, żnil, ाईयन_
  { {0x7a1c0024,0xd7760015,0x25a0129e,0x44a60058}},	//   rātī, _واجع, rril_, تحرّ
  { {0xb3760074,0x25a001d7,0x96660033,0x80d4000b}},	//   زداش, sril_, _мкне, _योगे
  { {0xf1aa0015,0x3bba004c,0xfa6d000a,0xdce20061}},	//   لاته_, ימעד, ְכוּ, _otoğ
  { {0xb2d30015,0x224d002a,0xcb13000a,0x8b57000a}},	//   بينغ, _czek_, ולא_, קינס_
  { {0xcf9a0001,0xdfd00002,0x89cb000a,0x79cb000a}},	//   аји_, فيت_, שֶׁ֤, שֶׁ֔
  { {0x28b2014e,0x224d0014,0x4ea60004,0x04430a86}},	//   _जानि, _ezek_, орпа, _жерн
  { {0x644e116e,0xa8570008,0x63b4005c,0x63b30107}},	//   _izbi, חיצה_, ągnę, žení
  { {0xaf330029,0x80e60015,0x1168002b,0xd1320040}},	//   بروت, _وأطل, _طلای_, _قمر_
  { {0x4cb7004a,0x62824819,0x84a9004f,0xe0850058}},	//   олью_, lboo, ֖יתִ, _فجمي
  { {0x3cf70015,0x1eaa002b,0xdfcf00c3,0xdcf7009a}},	//   تعيد_, _ناشي_, _ليل_, تريش_
  { {0x539b0008,0x628205a0,0x4a740138,0x0000006a}},	//   סיכו, nboo, дыёт,
  { {0xddc90011,0xfe42002b,0x2a64006b,0xcf57004f}},	//   rceţ, _تکثی, дърг, _ובאת_
  { {0x644e016f,0x6cd4002b,0x62820383,0x26150065}},	//   _ozbi, _رقبا, hboo, _नेगी_
  { {0x290305d8,0x368b1191,0x28ca000b,0x1dd2000b}},	//   rkja_, исан_, ाज़ि, तिकत
  { {0x442d0955,0x8f9b00a3,0xb902000b,0x9be30033}},	//   _će_, יילי, _नो_, _цішк
  { {0x95cb000d,0x443f003d,0x99840058,0xb8670058}},	// [b650] шува_, _ņu_, _قليو, _وادو
  { {0x4d7b0053,0x224d002a,0x47d50015,0x62822f25}},	//   ירמע, _rzek_, _فيخر, eboo
  { {0x7b160091,0xf8b2000a,0x0000006a,0x0000006a}},	//   ršuv, _אשי_,   ,
  { {0x2ae4000b,0x2d4b00cb,0xa856000a,0x9259004a}},	//   गाएँ_, jøen_, _מיתה_, бает_
  { {0x2169013e,0x28b2000b,0xdb0201de,0x6b7300d4}},	//   щили_, _जामि, rtlø, _măga
  { {0x98aa0089,0x865a000a,0xb5fa000a,0xc4c70015}},	//   době_, _לדרי, _הלשכ, _بتحو
  { {0xa3b4005e,0x3d09000b,0x389c000a,0x2fd60015}},	//   _обрі, िससे_, ביונ, كوود_
  { {0x6b8d002a,0x268b0643,0x0d850a0b,0x62824c92}},	//   _łago, ׁנֶּ, плин, cboo
  { {0xb3640063,0x26b600f3,0x9e090015,0x25a94c93}},	//   _църк, הִים_, صيدك_, nual_
  { {0x7d090001,0x0d820033,0x61ed008c,0x9fe70015}},	//   сног_, эльн, äalu, _وساه
  { {0xe4560053,0x0c220033,0xeb990054,0x2f19004a}},	//   ּירט_, емэн, љим_, _ложь_
  { {0x6910007c,0x7d0a4c94,0x0000006a,0x0000006a}},	//   _käeg, _elfs,   ,
  { {0x38c80086,0x316d02c1,0x25a90049,0xd24f005e}},	//   ياسی_, _juez_, jual_, нцi_
  { {0xb23a0053,0x7b24016f,0xcdf6000a,0x4dda000a}},	//   מערז, eđut, _ממני_, _לחנו
  { {0x7d060024,0x3ead02de,0x62822e8a,0x66e60839}},	//   īkst, oget_, yboo, пова
  { {0x9bfa0008,0xa3df005d,0x6efc0003,0xa3da000b}},	//   _להצט, तिन_, _hébr, ़िस_
  { {0x25a90676,0xd6cf0058,0x316d039f,0x64a60138}},	// [b660] gual_, دقق_, _nuez_, заза
  { {0xd8840086,0x4536005e,0x7413002b,0xf216000b}},	//   _تهدی, їхат, کوما, _देग़_
  { {0xc953000f,0x62820009,0x78fb0447,0xe73a2cb0}},	//   _רמת_, tboo, _הפיו, _ген_
  { {0x25a901c2,0xe2971d67,0x3f9a001a,0x0000006a}},	//   bual_, зац_, ápum_,
  { {0xcb130053,0x237f0085,0x023a0015,0x3ead4c95}},	//   עלד_, _čuje_, حثات_, dget_
  { {0x7bc3001a,0x3ead063b,0x673b32f8,0x62824c96}},	//   _opnu, eget_, čuje, sboo
  { {0xdfda0063,0xdea20086,0x62824c97,0x50b70369}},	//   съл_, فیای, pboo, سدود_
  { {0x69c44c98,0x3ead02cd,0x9ed7006b,0x7646008c}},	//   _opie, gget_, змът_, _kyky
  { {0xa0a60010,0x5d540254,0x66ad000a,0x7bc34c99}},	//   _наад, мкит, ׁיהֶ, _apnu
  { {0xcb980191,0xa6170008,0xe1f70010,0x98aa0046}},	//   ової_, פקיד_, _эгу_, robě_
  { {0xc0590036,0x6efc0152,0x7db3002b,0x307b000a}},	//   _дії_, _débr, وصیا, _האבנ
  { {0xbd870086,0xcb0b2c03,0xae1d0065,0xeb0700ce}},	//   _کنون_, сход_, _बेवन_, їчно
  { {0x7646022d,0xbef70008,0x35e0000b,0x25a908aa}},	//   _nyky, _מצאו_, निफ़, xual_
  { {0xa3df005d,0xd90f0086,0x52c90065,0x0000006a}},	//   तिम_, اید_, _रस्स,
  { {0x1cbb01e4,0x4cbb009d,0x8c4100b8,0xc7c40de5}},	//   _המוע, _המוג, ößte, нсти
  { {0x6d484c9a,0x6443002a,0xada5006f,0x25a90390}},	//   llda, żnik, spúš, tual_
  { {0xa6340036,0x7b160007,0x34950010,0x99490015}},	// [b670] енті, ršut, дазр, _ولعل_
  { {0x2f250024,0xf9920008,0xdb0e0030,0x35b40033}},	//   lēgt_, _שרי_, óköt, эбур
  { {0x28b2000b,0x6d5a4c9b,0x2b79004c,0x5b79004c}},	//   _जाति, imta, ַטװײ, ַרװא
  { {0x27fe006f,0xe3c40015,0x2d990046,0x69dd00bc}},	//   ätne_, عْنَ, ásek_, ovse
  { {0xb5fb002d,0x7abc000a,0x25a904a9,0x672d2a08}},	//   _ogái, מצאו, qual_, mnaj
  { {0x69dd0020,0xf9940008,0x4f79006b,0x672d003d}},	//   ivse, גרס_, ощия_, lnaj
  { {0x656f003f,0xdfce00e6,0x389c000a,0xdbcb001a}},	//   _huch, ليو_, זיונ, jóðe
  { {0x656f000c,0xa3da005d,0xe3b20053,0x0ea90080}},	//   _kuch, ़िर_, _שױן_, цкий_
  { {0x51870063,0xfde90036,0x3ead4c9c,0x61e00085}},	//   _хуба, ідок_, rget_, _grml
  { {0x656f0467,0x69dd00bd,0x02440015,0xdb02001a}},	//   _much, dvse, _أَكَ, rulí
  { {0x4ee70010,0x69c44c9d,0xfaa61c4c,0x656f4c9e}},	//   _нідз, _spie, мано, _luch
  { {0x7f490015,0x6d484c9f,0x6910007c,0x6d5a4ca0}},	//   _بلصق_, alda, _mäee, amta
  { {0xbcf50029,0x8eb2002b,0x672d0d64,0xacf50058}},	//   _يستغ, _شموش, dnaj, _يستت
  { {0xdce2032c,0xa3c2005d,0xae5a000a,0x672d2575}},	//   _zvoľ, ्बम_, _וכנר, enaj
  { {0x69dd0123,0x86ea0015,0x69c4002a,0x9a9e01f3}},	//   avse, يعرف_, _wpie, _купi
  { {0x69c00064,0x5b360029,0xeab200e6,0x656f4024}},	//   çmes, _تعتر, _شعب_, _buch
  { {0x9aeb011f,0x2bd5005d,0x65670111,0xceb2000f}},	// [b680] _וַיִ, धिका, _bijh, כין_
  { {0x80bf000b,0xc4c60015,0x656f4ca1,0xe5a308a6}},	//   ल्मे, بترو, _duch, тифи
  { {0xd38a005e,0x656f2189,0x7879004f,0x43830058}},	//   ійде_, _euch, _מָרו, َلْق
  { {0x2bf600b2,0x71a60010,0xaac1000b,0x4e0d000b}},	//   ומען_, дадз, ष्पक, िनाई_
  { {0x6d48002e,0xc69300a3,0x6d430244,0x0000006a}},	//   ylda, _באר_, _okna,
  { {0x6d460046,0x20540033,0xa989000a,0x5a17004f}},	//   ůkaz, нкля, פָנִ, וקנן_
  { {0xa0670001,0xd0100029,0x64a30054,0x656f0470}},	//   маља_, طلة_, _јаса, _zuch
  { {0x079b000a,0x6d434ca2,0x141b000a,0x441b000a}},	//   קספל, _akna, _וולב, _וולס
  { {0x6da30001,0x66040278,0xd1b3002b,0xdb250030}},	//   виња, nyik, _لینک, ósít
  { {0x51fb000a,0x81fb000a,0x672d2737,0xf657000a}},	//   _והמצ, _והמז, znaj, וספי_
  { {0x672d005c,0xeb970004,0xb11702be,0x6d5a0073}},	//   ynaj, миќ_, _تقلا_, rmta
  { {0xdd8f0074,0xa3df014e,0xdce2006f,0xe9810033}},	//   _چون_, तित_, _uvoľ, ламi_
  { {0x6abd002e,0x7db30015,0xda670015,0x6b560030}},	//   rfsf, _لمنص, بادي, zágg
  { {0x656f005c,0xab940001,0x61e400f2,0x8d170015}},	//   _ruch, _закљ, äily, _يزور_
  { {0x656f018b,0xb8820b7e,0xdc8b000a,0x9c370004}},	//   _such, _číta, _וְחָ, _општ_
  { {0xba6b0029,0x63a50264,0xe7300015,0x656f4ca3}},	//   _بحثك_, vrhn, لصق_, _puch
  { {0xd5b10018,0x66040030,0x05740040,0x672d4ca4}},	// [b690] طفا_, gyik, نالد, rnaj
  { {0x88c4005c,0x454b0010,0xa87b0015,0x63a5013f}},	//   ęści, ічам_, _بحظر_, trhn
  { {0x442b0010,0x656f020d,0xe1f0002b,0x66160264}},	//   ццам_, _wuch, یسه_, azyk
  { {0x82370086,0xe9df002c,0xd2510015,0x9259004a}},	//   ورشا, ovú_, هنا_, пает_
  { {0x6616005c,0x90c50457,0xa294005e,0xdb020030}},	//   czyk, ебле, тачі, nulá
  { {0x6b560077,0x5fd53334,0x3f69011e,0x659400af}},	//   máge, ециф, пико_, _јару
  { {0x26d90035,0xa0661923,0xb0280058,0x60250138}},	//   _kaso_, наша_, وكهم_, эдка
  { {0xd1bb0015,0xff51002b,0xdb024ca5,0xaac10065}},	//   _واذا_, دخت_, kulá, ष्मक
  { {0x2d9903c0,0x2d8b0152,0xa2d8005d,0x0dc6004a}},	//   ése_, èce_, _नोट्, елый_
  { {0x10d80029,0xe0d30029,0xdb024ca6,0x398d0024}},	//   _يبلغ_, _جزر_, dulá, džs_
  { {0x8b26071a,0x6b5f0024,0xd13e002a,0xc1040040}},	//   едне, _lūgu, żąca_, _جولي
  { {0x7b160048,0x28b2000b,0x2d8b0003,0x8d750015}},	//   gšup, _जाहि, âces_, _كاتا
  { {0xfe790089,0xdca54ca7,0x0f180015,0xc212000a}},	//   mců_, _зали, _تغلب_, ָ֔ר_
  { {0x91ba0008,0xfe790089,0x1cb90015,0xc212000a}},	//   המשי, lců_, _راتب_, נהם_
  { {0x3b0a0001,0x97560054,0x26d901d7,0x6d414ca8}},	//   _неко_, етаљ, _baso_, mola
  { {0xfe790089,0x8c1a0008,0x6d412ee0,0x317f0061}},	//   nců_, _מוצי, lola, _otuz_
  { {0x99d60029,0x7bdd002a,0x6616002a,0x798d0034}},	// [b6a0] _أتبا, łsud, uzyk, _gwaw
  { {0x6616005c,0x9a3b0008,0x2f1a0024,0x845a0080}},	//   rzyk, _מתפק, lūgt_, прет_
  { {0x66161515,0xe3b20015,0x04b5006b,0x23e5005e}},	//   szyk, طرا_, ъстя, кіїв
  { {0xe292003b,0x6b5600dc,0xfe790046,0xe73a17b6}},	//   اذا_, lágb, jců_, _хем_
  { {0xfe790089,0x6d410375,0xf5b6005e,0x91e30e3b}},	//   dců_, kola, _ясню, лоце
  { {0x999b000a,0x6d414ca9,0x290a0030,0x399b000a}},	//   לבנט, jola, nkba_, לינד
  { {0x7cf60011,0x26c00026,0x6d414caa,0xf8b3000a}},	//   _târz, ofio_, dola, אשו_
  { {0xb3bb0008,0x6d414cab,0x5f73002b,0xb1830069}},	//   _ממלכ, eola, داور, šťan
  { {0x6d41002f,0xe2a6002e,0xd357000a,0x26c00034}},	//   fola, æðum_, _טילי_, ifio_
  { {0xf19b0008,0x6b5f0024,0x6d414cac,0xc19b000a}},	//   _משמש, _lūgt, gola, _משמי
  { {0xdce30091,0x7c340b1e,0xfe790046,0xdee60974}},	//   _ginč, тенх, bců_, _пожи
  { {0xdb0200dc,0xbebd0091,0xdb0900cb,0xd5d00065}},	//   tulá, liūn, ntdø, हबाज
  { {0xc333000f,0x4efb000a,0x96570033,0x60da4cad}},	//   רור_, _מהאו, аiны_, _katm
  { {0x98b80024,0xa3c2005d,0xfd380029,0xbebd0007}},	//   torā_, ्बा_, _تكتب_, niūn
  { {0x26d902c1,0x3cf700e6,0xdcf7002b,0xdb020030}},	//   _paso_, _سعود_, _سروش_, sulá
  { {0x798d003f,0x0bb7000a,0xd6d81e98,0xf7700040}},	//   _twaw, _נלחם_, нту_, صاف_
  { {0x0708003b,0xe5730031,0x7aed4cae,0x89391eaf}},	// [b6b0] ريكي_, اطر_, _inat, _опис_
  { {0xce370008,0xdb020bfa,0xfe790046,0x7aed001a}},	//   תאמת_, gulæ, zců_, _hnat
  { {0x9295008f,0x26d9008c,0xd91c000a,0x03c70033}},	//   ваец, _taso_, _מוזל, эсам
  { {0x43840029,0xdc3b000a,0x6d414caf,0x7d1d0030}},	//   النق, העבר, zola, éssz
  { {0xfe790089,0xe4a70292,0xbebd003d,0x60da4cb0}},	//   vců_, _прво, inūt, _batm
  { {0xe4a70010,0x4fa50063,0xdb1b002a,0xeafe0065}},	//   _ярмо, викв, owtó, _उक्त_
  { {0xe5340080,0x6d410107,0x24e40033,0xfe790046}},	//   _серь, vola, _сцяг, tců_
  { {0x6b5600dc,0x6d410034,0x6d584cb1,0xdce34cb2}},	//   zágb, wola, _ahva, _vinč
  { {0x20090048,0x6b9a0012,0xfe790046,0x98b80045}},	//   ņai_, estg, rců_, noră_
  { {0x270e005d,0x25a90035,0xd0d90036,0x6dc40029}},	//   _सत्र_, iral_, _ідеї_, ازيل
  { {0xa3da005d,0xbf8b002b,0xac39005e,0xfe790046}},	//   ़िए_, _رئال_, ьчих_, pců_
  { {0xf3f20008,0x6d410c0a,0x25a901d7,0x92a6002a}},	//   ׁ֣ר_, sola, kral_, _gołę
  { {0xee840010,0x98b80045,0x6d414cb3,0x3cf90058}},	//   _сыхо, joră_, pola, _يعتد_
  { {0x9c840046,0x929d002a,0x25a927d1,0xdca504bb}},	//   tečň, _hołd, dral_, _раки
  { {0xa96706a6,0x7e7b0a35,0x38330088,0xd823135f}},	//   тира_, ocup, анёр, адри
  { {0x6b5600dc,0x3d09000b,0x7aed2360,0x18670054}},	//   ságb, िसके_, _gnat, ђати_
  { {0x26c00026,0xad9d002a,0x929d002a,0x68fe1ef2}},	// [b6c0] rfio_, zyźn, _mołd, _topd
  { {0x48060010,0x7aed044c,0xdb020125,0xf487002b}},	//   _апов, _znat, irlí, نامی
  { {0xd3790036,0xb8e8005d,0xcf85002b,0xa3df000b}},	//   ечі_, ोज_, _دژ_, तिष_
  { {0xf6260010,0x2aeb005d,0x60da0064,0x2ba9000b}},	//   _адмо, टाएँ_, _satm, _किना
  { {0x41b6000d,0xdb022d27,0x91b7002b,0xc2432044}},	//   тсет, pulæ, نطور_, анцк
  { {0x64a6056d,0x11540174,0xa3df0065,0xdb02005b}},	//   _шага, ыклю, तिश_, lulä
  { {0xd00f0031,0x443e0045,0x52860015,0x2b590046}},	//   يله_, _ât_, _للأك, ůrci_
  { {0x6d58016f,0xc0590033,0x0000006a,0x0000006a}},	//   _shva, хіі_,   ,
  { {0x1ef70015,0xd3350033,0x32461305,0x60da068c}},	//   ضعية_, _сэры, _реаг, _tatm
  { {0x645a002e,0xbd87002b,0x6b9a0079,0x7aed4cb4}},	//   _útis, کنین_, tstg, _snat
  { {0x61e24cb5,0x3fa50015,0x1bf30033,0xdb024cb6}},	//   lvol, _مصنف, апэў, kulä
  { {0xbb930080,0x501b000f,0x539b05bd,0x7e7b4c68}},	//   шающ, _קואו, וסטא, ccup
  { {0xf2d300b2,0x79a70063,0x61e24cb7,0x88c4002a}},	//   בער_, ърне, nvol, ęśni
  { {0xfbcf0086,0x6d58016f,0x2bba0015,0xa8a410b9}},	//   حتی_, _uhva, _قاعة_, ирск
  { {0xe8940010,0xd9180080,0xed57000a,0x3943003d}},	//   рась, тья_, _שבור_, rojs_
  { {0x7aed385d,0xdb0200b8,0x1bf7000a,0x673b00bc}},	//   _unat, gulä, _יצור_, čujo
  { {0x2007037c,0x6b560030,0x25a91495,0xe664125c}},	// [b6d0] zyni_, ságc, ural_, атфо
  { {0x58d5005f,0x61e20227,0x25a94cb8,0xe4d90015}},	//   _соот, dvol, rral_, عوات_
  { {0xdd860086,0xb8820089,0xa4d4005e,0x2f11001a}},	//   _گو_, číte, рохі, _lága_
  { {0xf6790053,0xef1f002a,0xb8e8000b,0x61e20012}},	//   _ראָמ, ężko_, ोड़_, fvol
  { {0xdd860074,0x29010020,0x28c0000b,0x21270016}},	//   _دو_, _koha_, श्वि, tinh_
  { {0x9582005c,0xb1440010,0xe3b3002b,0xe1f00015}},	//   żące, аніл, _پرس_, تسم_
  { {0x64550048,0xb4c1005d,0x8d75002b,0xf3670a0b}},	//   _uzzi, ्जी_, گابا, _атан
  { {0xa3c2005d,0x2f11001a,0x6910008c,0x1ea90015}},	//   ्बर_, _bága_, _näen, راعي_
  { {0x9d45000d,0xde050080,0x2007001a,0x3f9c007c}},	//   леид, уппи, syni_, asvu_
  { {0xdb020012,0xf8b2000b,0x290116ce,0x7188004f}},	//   zulä, _जाइय, _noha_, _יְעַ
  { {0x853c000a,0x236d002a,0x1dd8000b,0x6488000a}},	//   וגזי, _kiej_, _बैठत, כְרְ
  { {0x62994cb9,0x2f110052,0x0000006a,0x0000006a}},	//   nawo, _fága_,   ,
  { {0xed4e3132,0x8d770015,0x236d002a,0xf9910015}},	//   _го_, _شاشا, _miej_, ْبِ_
  { {0x6be50015,0xdce3003d,0x8cc90015,0x7c870a1f}},	//   _مكتم, _finā, _أوثق_, _руде
  { {0xab2a005f,0x6299005c,0xf0920008,0x61e24cba}},	//   _пока_, kawo, מנם_, zvol
  { {0x236d005c,0xc5f6006b,0x61e200bf,0x0000006a}},	//   _niej_, лязъ, yvol,
  { {0xe737005f,0xdce30048,0x62990026,0x89360015}},	// [b6e0] ует_, _zinā, dawo, _معدا
  { {0x09f7000a,0xe5060015,0x28070030,0xa3c20065}},	//   _עמים_, دبري, ívná_, ्बल_
  { {0xdb0204d4,0x29180125,0x6e2d0085,0x58bb004f}},	//   pulä, mhra_, _žabl, _אמיצ
  { {0x24870064,0x28c0000b,0x798400aa,0x61e24cbb}},	//   ınma_, श्रि, _ktiw, tvol
  { {0xf12620fe,0x0000006a,0x0000006a,0x0000006a}},	//   лько,   ,   ,
  { {0xbebd00df,0xd24f0029,0xdfd000e6,0x10a30001}},	//   siūl, أنه_, قيت_, биљн
  { {0xf8b2014e,0xc04f0036,0x4f6a005e,0xc0e70015}},	//   _जाईय, сі_, ншим_, طفين_
  { {0x285b0053,0x61e22b99,0x0000006a,0x0000006a}},	//   עכקײ, pvol,   ,
  { {0xa0b60002,0x9d140de5,0x91e30121,0xf1c3005a}},	//   _محاص, идич, _лоте, ěší_
  { {0x98c1003d,0x02030ffe,0xc19b004f,0x0000006a}},	//   ēsīs_, _узун, _נשבי,
  { {0x9b590083,0x88c4005c,0x3d28002b,0x6c5413d6}},	//   киот_, ęśli, فتگی_, ркну
  { {0x290100dc,0x7de60115,0x0000006a,0x0000006a}},	//   _soha_, _مستم,   ,
  { {0xf2d300b2,0x6aa40176,0xff57000a,0xcf57000a}},	//   זער_, _ddif, _עבדך_, _עבדת_
  { {0x2db7000a,0x6299002a,0x6aa44cbc,0x6b560030}},	//   _עלון_, zawo, _edif, rága
  { {0xac180010,0xd014000a,0x6b560030,0xccf3000a}},	//   _шоку_, בַּח_, sága, _לכס_
  { {0x656e002f,0x2ba9005d,0xa3e8000b,0x6b560030}},	//   _aibh, _किता, बिन_, lágn
  { {0x2918002d,0x35f50010,0x95d9006b,0x5eeb000a}},	// [b6f0] bhra_, шпар, ъдат_, עַלְ
  { {0x7afd01a3,0xb4c1000b,0x291800a9,0xd7fb1ab3}},	//   ljst, ्जे_, chra_, _зум_
  { {0xa87a0008,0x6299005c,0xdb020123,0x7afd00bc}},	//   _באתר, tawo, rtlö, ojst
  { {0xdb024cbd,0xb7fa000a,0x644e028a,0x7afd4cbe}},	//   orlá, _ספרת, _dybi, njst
  { {0x62991138,0x32b80015,0xb6070239,0xa2270015}},	//   rawo, ادمة_, _сянк, دراه
  { {0x8fe50015,0xe97c000a,0xf3970015,0xc0e500f4}},	//   لأعم, תנגש, _مؤرخ, рокк
  { {0xfe71003b,0x23e4008f,0xd0980029,0xa1560001}},	//   يدة_, _літв, ائها_, јају_
  { {0x3eb94cbf,0xb3d10065,0x7fe80369,0xdb090052}},	//   üst_, सबीऍ, اروف_, itdó
  { {0x9e62006b,0x8d84002b,0x30a719a5,0x6b8400bc}},	//   овъд, یشین, _брев, _čiga
  { {0x7d090001,0xdca50180,0xc5f2000a,0xec79006b}},	//   тног_, јани, קדי_, ъпо_
  { {0x79840026,0xfc310015,0x2d18002b,0x91640058}},	//   _stiw, تحة_, دکنک_, _اهله
  { {0x6336000a,0xab2a0a3f,0xda662dfa,0xfbb60065}},	//   ֹאשׁ_, тома_, ивни, _अमरम
  { {0x4a430063,0x82d600a3,0x637401c0,0x29184cc0}},	//   жняв, בורג_, ožný, thra_
  { {0xfc310015,0x26d200aa,0x6910007c,0x7afd4cc1}},	//   _وحث_, weyo_, _väeo, ajst
  { {0x7d03002d,0x96960ea6,0xa696009c,0xf74a002b}},	//   _ions, ираш, ирај, نجره_
  { {0x4c3a0008,0xf1c5005d,0x656e002d,0x61e94cc2}},	//   _שתקב, लझान, _sibh, _orel
  { {0xa526008f,0x6b5600dc,0x78bb016f,0xb4f2000b}},	// [b700] амад, lágo, đuvr, घालय_
  { {0x7bc10020,0x64a63d46,0xa99b000a,0x999b000a}},	//   otlu, ража, _שביר, _שביט
  { {0xe29a008f,0x33f60010,0x7d034cc3,0x14260004}},	//   вае_, шчас, _mons, јдем
  { {0x083b0008,0xa79b000a,0x8cc5000b,0x61e90fab}},	//   _יעיל, _בשטח, ़्तो, _brel
  { {0x644e0050,0x7bc10020,0x6b5d00dc,0xd24f002b}},	//   _wybi, htlu, ségg, ونم_
  { {0x25a00064,0x644e0034,0x7d03273f,0x61e90416}},	//   msil_, _tybi, _nons, _drel
  { {0xdfd0003b,0x98a30024,0x35ac000b,0xdfda006b}},	//   سية_, nijā_, _चिड़, тъл_
  { {0x3ec3054f,0xcef40054,0x61e94cc4,0x7e98009a}},	//   осьб, спић, _frel, اچار_
  { {0x9df70063,0xcee70054,0x7d0314a0,0x6b730045}},	//   инът_, рдње_, _bons, _măgu
  { {0xdceb0440,0xbd430029,0xc1bb0008,0x31bb000a}},	//   _rugă, ينيي, _בממש, _בזמנ
  { {0x6c34003b,0x6fb30015,0x73f9000a,0x9f5c008c}},	//   صفحا, _ومكا, ָּתו, tyvä_
  { {0x929d002a,0x98a3003d,0x6b560030,0x70530067}},	//   _koła, dijā_, ságn, _بنما
  { {0x4efb000a,0x1efb000a,0x2f180030,0x7bc1007c}},	//   _שהדו, _שלדע, _cége_, atlu
  { {0x6c840015,0x9f5c008c,0x3e330015,0x0ec2000b}},	//   _الغم, syvä_, _بفهر, व्रड
  { {0x6d484cc5,0x764f002a,0xe7a8004a,0xd8e40033}},	//   moda, _sycy, ивёл_, ццяп
  { {0x6d484cc6,0x07090015,0xabfb000a,0x7d030079}},	//   loda, ديري_, _יהור, _zons
  { {0xa4870015,0x25b90015,0xbb3c000a,0x6d480bb5}},	// [b710] لجان, طهاد_, _שתחז, ooda
  { {0x44f41cd9,0xa8a70189,0x6d484cc7,0xc5170058}},	//   опус, _трик, noda, جبرت
  { {0x9cd70008,0x98a30024,0x7d1a0020,0x25a00049}},	//   שובה_, cijā_, ihts, asil_
  { {0x2ba9005d,0xe3b00015,0xc7fa000a,0x6354005e}},	//   _किसा, برك_, _עִיר, овху
  { {0x672d000c,0x6b5600dc,0xc2c40029,0xa282002b}},	//   miaj, zágo, تيني, سیلو
  { {0xe1340010,0xc1040115,0xc2c5002b,0xe1640015}},	//   ончы, يوني, _گيري, يدوي
  { {0x6d480944,0x4918000a,0xe3d40015,0x20050015}},	//   doda, שקול_, _وتفع, إِبِ
  { {0xf838013a,0x28380008,0x9838000a,0x28a7000b}},	//   ינות_, ינוך_, ירוף_, कृति
  { {0xa3df005d,0x52150001,0x6d480026,0xd6fa0008}},	//   तिक_, _удат, foda, אִיש
  { {0xeb10005d,0x672d0020,0x2d9f003e,0x7bc1177b}},	//   ास्त_, hiaj, rsue_, ttlu
  { {0x351a0008,0x2d9f0bf5,0x3b0a0054,0x8c450783}},	//   רותנ, ssue_, гено_, сене
  { {0xa3e8005d,0x2b160063,0x6b5600dc,0xf1bb000b}},	//   बित_, сьор, rágo, _ईमान
  { {0xfce5087a,0x6d484cc8,0x5d850029,0x9e760008}},	//   _голо, boda, _التل, _הגנה_
  { {0x7d1a2259,0x6b5d00dc,0x2f1800dc,0xbdf8002b}},	//   chts, vége, _vége_, _خرما_
  { {0x3156004c,0x672d002a,0x31d4000b,0x660d088a}},	//   מישן_, fiaj, _धन्ध, eyak
  { {0x98a30024,0x6b5d0152,0x69cd007c,0x6910007c}},	//   rijā_, tége, äleõ, _käek
  { {0x660d00e8,0xdce90024,0x98a3003d,0xc4ca02ed}},	// [b720] gyak, kseļ, sijā_, ллаж_
  { {0x2ed4005d,0x67360007,0xaa7b0264,0x46130015}},	//   _दस्त, snyj, ndýn, أوكر
  { {0x6b5d0014,0x18770008,0xe8d7000a,0x25a04cc9}},	//   sége, _לעיר_, _פוטר_, ssil_
  { {0x73490191,0x1db7005d,0x81a60015,0x0f11000b}},	//   ачів_, _आमंत, محتل, ़सोस_
  { {0xc297008f,0x24982577,0x6910007c,0xc2c30015}},	//   скіх_, _term_, _näek, سيوي
  { {0xc05a0127,0xf5062df1,0xb97b015b,0x69c00061}},	//   лій_, _узго, אנסי, çmey
  { {0x08770053,0x6d480057,0x487b000a,0x9fe60015}},	//   זעצט_, voda, נטקס, إسته
  { {0xf7730008,0x6d48005c,0x645c4cca,0xba3b01f6}},	//   הקה_, woda, _izri, laïe
  { {0x6ce6192f,0xa0a600d0,0xc27b000a,0x6d484ccb}},	//   біне, _газд, _תרמי, toda
  { {0xd24f0029,0x6d4809e2,0xdb020012,0x6b560030}},	//   _أنك_, uoda, hrlä, ságl
  { {0xb4fb01d8,0x6d484ccc,0xa4fb015b,0xa42b000a}},	//   אפיי, roda, אליט, ָֽיִ
  { {0x8fa30010,0x2ba9005d,0x6e930015,0x6f660659}},	//   _хаце, _किरा, _فلما, _увез
  { {0x63ab005c,0x2bda0231,0x6d48053e,0x5a470033}},	//   ągni, _बनवा, poda, сэна
  { {0x672d0050,0xf7730029,0x2905002e,0x645c006f}},	//   wiaj, كار_, ðla_, _ozri
  { {0x907b013a,0x672d2ed0,0x5bc30015,0xd7f81dd4}},	//   רטלי, tiaj, _فقول, бут_
  { {0xec370008,0xef110008,0x6b5d00dc,0x8f9b000a}},	//   _לאור_, ֵּן_, ségb, טילי
  { {0x29c80015,0xa5f820cc,0x672d4ccd,0x79960416}},	// [b730] _هِيَ_, бету_, riaj, _gwyw
  { {0xe6c00085,0xdb090125,0x660d0f0a,0x394a4cce}},	//   čišć, irdí, ryak, cobs_
  { {0x3e6f0064,0x660d00d9,0x672d28c7,0x8ba9000a}},	//   _kötü_, syak, piaj, ֹׁנִ
  { {0xd808000a,0x325515d5,0xd6db4ccf,0xe7f70065}},	//   _הִשָ, овер, _сто_, ीहीथ_
  { {0x28c0005d,0x5b58004c,0xbb3c004c,0xf487030c}},	//   श्कि, זשאן_, נעדי, _губн
  { {0x64400050,0xc2440010,0xc5f2000a,0xd5b802e1}},	//   _śmie, чнік, _קדם_, _усю_
  { {0xdbf10089,0x229d0007,0x2938004c,0xaff60015}},	//   _přít, eškų_, זאגן_, قفوا_
  { {0x38180008,0x6fd4005e,0x0d85143a,0xe8b6000b}},	//   מקום_, яціє, олин, _अञ्च
  { {0xfe6e002b,0xa6e2001a,0xccd50033,0x313503ae}},	//   نگه_, öðin, оцны, _деар
  { {0xf0b80015,0x929d002a,0x4d650033,0x690b0061}},	//   _هامش_, _koło, ўков, _mües
  { {0x28c4005d,0xeb990001,0x2fd9002b,0x229d0091}},	//   _लॉगि, јим_, _خواد_, aškų_
  { {0x3a9a0036,0xba3b0079,0x929d002a,0xbfb4006e}},	//   штою_, zaïe, _moło, _رحمت
  { {0x7de70074,0x4e780002,0x6b560030,0x5ca5045f}},	//   _دسام, _احمد_, lágk, _дилб
  { {0x779603ae,0x317a000a,0xcd76000a,0xee3801f3}},	//   жјац, ירשמ, _ועסק_, _уні_
  { {0x869a275e,0x186a1021,0x0fa9000a,0x0000006a}},	//   итат_, рави_, יֹּֽ,
  { {0xd6d20015,0x629b4cd0,0x0000006a,0x0000006a}},	//   بقر_, _neuo,   ,
  { {0xd7f80011,0x6f190026,0x7ae402e4,0xae19000a}},	// [b740] ţă_, _mlwc, _iait, בוּכ
  { {0x7ae44cd1,0x6f190034,0x2f180003,0xb82a005e}},	//   _hait, _llwc, _méga_, _вооз_
  { {0x7b2b0089,0x6b5d0152,0x7ae44cd2,0xd3ba005e}},	//   dřuj, léga, _kait, рузі_
  { {0x74130015,0x929d002a,0x83690015,0xa3df000b}},	//   بوما, _doło, مصنف_, तिज_
  { {0x69c60014,0x7ae44cd3,0xf194005e,0x6b5d0003}},	//   ntke, _mait, чиль, néga
  { {0x45d900b2,0x7ae44cd4,0x66030010,0x753c005c}},	//   _פֿרא, _lait, _ўпра, _ujrz
  { {0x6f190176,0xea010016,0x929d002a,0x7f8300c3}},	//   _blwc, _đậu_, _goło, ولون
  { {0x3da60036,0x7ae44cd5,0x98a30091,0x7d010101}},	//   ороб, _nait, miją_, ejls
  { {0xaf070002,0xf1a9002b,0x98a30091,0x9f410046}},	//   تقيم_, _هاله_, liją_, íhá_
  { {0x7af6003e,0x85f70053,0x6b5600dc,0xad260015}},	//   _anyt, קציע_, lágh, تربو
  { {0x98a300df,0x547b0008,0x747b0053,0x6f190026}},	//   niją_, יטיו, יניג, _flwc
  { {0x7ae4002f,0x74ca005d,0xa3d2000b,0xdce3002a}},	//   _cait, स्तृ, _वहन_, _minę
  { {0x7ae408f6,0x220a000a,0xdb090123,0x7e2701f3}},	//   _dait, ׁפֹּ, vudä, _міша_
  { {0xdc2a002b,0x5e57000a,0xe0ce00ce,0x257f0416}},	//   _پسته_, _וידע_, евi_, _rîl_
  { {0x7ae40493,0xf72b0033,0x80bf000b,0xd90f002b}},	//   _fait, ацай_, ल्टे, فیک_
  { {0x501b0008,0xab28049d,0x7ae44cd6,0x8c1b000a}},	//   בולו, _моја_, _gait, _כווי
  { {0x690b0251,0xdb020107,0xaded000b,0xd5b00015}},	// [b750] _qües, nulý, जियन_, َفِ_
  { {0x929d0050,0x6abd0134,0x98a30091,0x64b70058}},	//   _poło, lgsf, fiją_, تحرر
  { {0x98a30007,0x7ae400e8,0x44270092,0xb4ab000b}},	//   giją_, _yait, àn_, _गयी_
  { {0x92940010,0xa294005e,0x8cca000b,0xd1790033}},	//   дацц, даці, त्तो, бскі_
  { {0x82340074,0x68e500f2,0x929d005c,0xcb14000a}},	//   ورها, _kahd, _woło, ולף_
  { {0x673b010b,0xd1780033,0xfe790046,0x69dc004f}},	//   čuju, ісіі_, rdům_, שַׁו
  { {0x68e5022d,0x98a300df,0xa29505fc,0xd9a8005d}},	//   _mahd, ciją_, _наві, _कट्ट
  { {0x657d000c,0xdfce0087,0xe29f002e,0xe70b000a}},	//   _kush, ايي_, _þð_, יהֶֽ
  { {0xc3320053,0x6b560030,0x7ae44cd7,0x0000006a}},	//   _נומ_, ságk, _rait,
  { {0x361c0008,0x80b4017c,0x7ae44cd8,0x6abd0012}},	//   יוחד, _обух, _sait, egsf
  { {0xe57200b2,0xdb0e00dc,0x7c950086,0x7ae44cd9}},	//   ײַז_, űkít, يشگا, _pait
  { {0x0eb80010,0x6abd00cb,0xcf270015,0x3a850033}},	//   _душы_, ggsf, _برئي, дыёв
  { {0x4e7a013a,0x98a30091,0x7e7a000a,0x7ae44cda}},	//   _האנצ, ziją_, _האנז, _vait
  { {0x7ae40495,0x6b5d0003,0x6b560030,0x69c64cdb}},	//   _wait, réga, zágh, rtke
  { {0xec350053,0xacfa0008,0xc172000a,0x657d0012}},	//   _מאַר_, _להסכ, תחם_, _aush
  { {0x23d2005d,0xab290015,0x6910007c,0x5c140015}},	//   _सहबद, _وسيل_, _näev, _تظهر
  { {0xf1da005d,0x7abb0008,0x3abb000a,0x657d4cdc}},	// [b760] _मैंन, _הצפו, _המפנ, _cush
  { {0x98a30007,0xd5af0002,0x8d76000a,0xa3e8000b}},	//   tiją_, افل_, פגעו_, बिल_
  { {0xa87b0008,0x2897000a,0x987b0447,0x487b000a}},	//   _לאיר, _מדין_, _לאיט, _לטיס
  { {0x98a300df,0xe2830345,0x2b814cdd,0xf1aa0015}},	//   riją_, елци, _móc_, ماته_
  { {0xa6e2002e,0xc69304dc,0x98a30007,0xc2e90015}},	//   öðun, _ראש_, siją_, تعلم_
  { {0x28c0014e,0x98a30007,0x2d820089,0x64550227}},	//   श्चि, piją_, íkem_, _fyzi
  { {0xb4b8005d,0x351b0008,0x6abd00c0,0xdb020030}},	//   छली_, _פולנ, ygsf, nuló
  { {0x543b013a,0x671c000b,0xe2aa002b,0x040b0016}},	//   _העלא, नसिक_, _داسن_, hượn
  { {0xe1260124,0xdb0200dc,0x43431411,0x3d28009a}},	//   _емаи, cslé, _четв, قتدی_
  { {0x2b810016,0x42530015,0x6910007c,0xb1d30058}},	//   _bóc_, _أنكر, _käeu, _سيمث
  { {0xdbf10089,0x2b810092,0xdfcf0031,0x40eb000a}},	//   _přát, _cóc_, _ميل_, _לַאֲ
  { {0x7c420024,0xe9810010,0xf017000a,0xaa591017}},	//   _ātrā, камi_, _מקבץ_, жиму_
  { {0xdddb0045,0x6abd0400,0x0000006a,0x0000006a}},	//   rcuţ, rgsf,   ,
  { {0xb4ab005d,0xdddb0011,0xa9280010,0xcdf7000a}},	//   _गये_, scuţ, пісе_, _ממדי_
  { {0xd7f80001,0x31570053,0x2b810092,0x375b0015}},	//   пут_, פילן_, _góc_, مؤرخ_
  { {0x443f016f,0x657d032f,0x3bbb000a,0xdc3b000a}},	//   _ću_, _push, _המהד, _לעור
  { {0x68e5008c,0x6b5d0003,0x99840058,0x80bc0065}},	// [b770] _tahd, légo, _كليو, ईलाइ
  { {0xe61f0176,0x6440005c,0x046709fe,0x96340033}},	//   _ffôn_, _śmia, птем, хнуц
  { {0x69100005,0x23810073,0x7bc842e7,0x0000006a}},	//   _päev, _vėjo_, ntdu,
  { {0x6b56016e,0x6363007c,0x7d0a4cde,0x63a501f9}},	//   tági, kõne, _lofs, rshn
  { {0x95d802ed,0x64550535,0x0000006a,0x0000006a}},	//   _едят_, _wyzi,   ,
  { {0xe4e40036,0xdb1b08b1,0x15fa000a,0x798d0573}},	//   _пісн, lttä, _והשע, _mtaw
  { {0x20540063,0xd0060063,0x5fd40033,0x9f4d006f}},	//   нтър, деще_, ецыф, žníc_
  { {0xdb1b022d,0x77f80008,0xff290015,0x41e702a3}},	//   nttä, למוד_, تكبي_, _ніза
  { {0x2d990152,0xdb0930a8,0x2b814cdf,0xdb1b008c}},	//   èse_, budú, _sóc_, ittä
  { {0xee3601d9,0x69100020,0x5ba9227a,0xfd110058}},	//   ьны_, _jäet, оком_, ئجة_
  { {0x3c650191,0xbb850015,0x798d01d7,0x41740015}},	//   ьког, بلجي, _ataw, _ساكس
  { {0x6008000a,0x6b5d0030,0xf8a9000a,0x2b810016}},	//   _מִנְ, ségn, _כש_, _vóc_
  { {0xddcb002a,0xbebd0091,0x6aad0034,0xed4e0ac9}},	//   _wygł, siūs, _ddaf, _ао_
  { {0x3ebf0251,0xeb9918fe,0x7d7a000a,0x2b810016}},	//   lgut_, _дик_, _ונסו, _tóc_
  { {0x3ebf0144,0xfce2006b,0x3b0a098a,0x0000006a}},	//   ogut_, _рощо, _меко_,
  { {0x3ebf4ce0,0x0bb6000a,0xdb9a000a,0xb7d70015}},	//   ngut_, _חלקם_, _וסקר, بوفا_
  { {0xc689000a,0x8cca000b,0xe5a30883,0x69c80045}},	// [b780] ֹא_, त्वो, кити, ădes
  { {0xb4b8005d,0x89d7002b,0x8c3c0061,0x39c50015}},	//   छले_, _کویر_, lağa, _أغيّ
  { {0xd7ca0015,0x68fb000a,0x03a3005e,0x78fb004f}},	//   _بوجه_, _וליה, вихо, _ופיו
  { {0x9586029f,0xc4c9000a,0xe29700af,0x0000006a}},	//   _олме, יג_, дац_,
  { {0xcb13000a,0xc448002b,0x92930033,0xb5fb01c0}},	//   כלא_, _کیان_, таіц, _vzác
  { {0x291800dc,0x26c04ce1,0x40a8002b,0x3ebf0144}},	//   nkra_, lgio_, سختی_, egut_
  { {0x2bdd005d,0x2f11001a,0xb937000a,0xdb1b0123}},	//   _फैला, _lágu_, ונסו_, lttå
  { {0x69100005,0xef910086,0x940b0008,0x26c04ce2}},	//   _käes, ایند, _וּמֵ, ngio_
  { {0x2918002e,0xbebd0007,0x1757000a,0x71fa0015}},	//   kkra_, tiūr, וסקר_, _برأس_
  { {0x9ffa0029,0x6b5d0152,0xffd60015,0x40930015}},	//   _وراء_, tégo, _يغاد, _للكر
  { {0xdb1b0945,0x34b70008,0x7d780086,0x798d005c}},	//   yttä, ופים_, _کمتر_, _staw
  { {0xc3340008,0xef690029,0x7bc80150,0x0000006a}},	//   תוֹ_, _فإنه_, rtdu,
  { {0xff270086,0xd2460115,0x7bc80546,0x0000006a}},	//   _تبلی, ان_, stdu,
  { {0xfc2f0086,0xd0060040,0x49740033,0x26c0053a}},	//   احی_, هل_, кляс, egio_
  { {0x9be60036,0x1cbb0008,0x57a40010,0x4cbb000a}},	//   _цілк, _ומוע, кшта, _ומוג
  { {0x8cca014e,0x26c002d7,0x69c80011,0x96f8207f}},	//   त्रो, ggio_, ăder, мест_
  { {0x798d000c,0xf6500015,0x163401b7,0x55b90033}},	// [b790] _utaw, لئك_, ветя, ягаў_
  { {0x29180123,0xdb1b02ad,0xdce60073,0xd7fb4ce3}},	//   ckra_, sttä, ėmėj, _дум_
  { {0x6910007c,0xf3150033,0xa7750c45,0x9b44002b}},	//   _väet, нджэ, _плоч, _سنیو
  { {0xfe0e014e,0x5c37000a,0xd1790033,0x6595098a}},	//   िहास_, ורבן_, пскі_, _паму
  { {0xa696000a,0xa159227a,0xf1a7016a,0x0000006a}},	//   _רכשה_, паду_, френ,
  { {0xd2b5008f,0x2f11002e,0x25a90064,0xd5b80010}},	//   _гiпэ, _lágt_, msal_, _ўся_
  { {0x92c70036,0x6fb2002b,0xdfce0015,0x44253e55}},	//   _ощад, هموا, ميو_, _ål_
  { {0xc7b40008,0x0ea9005e,0x6d5a4ce4,0x0000006a}},	//   דבק_, чкий_, elta,
  { {0x98a300df,0x2d940010,0xee39475c,0x69db0144}},	//   siję_, крэс, яни_, çuel
  { {0x6b5d0030,0x3ebf0012,0x51840099,0xfc050912}},	//   ségl, sgut_, _јута, епоо
  { {0xc4d20053,0xe4a80008,0xc49a000a,0xd0110015}},	//   נגט_, וֹרָ, השתת, _حلا_
  { {0x441a0008,0xaa5c004c,0xba3b0144,0x25a9494b}},	//   פורס, דאַרד_, raïn, ksal_
  { {0x8c3c007f,0x0000006a,0x0000006a,0x0000006a}},	//   rağa,   ,   ,
  { {0xdcf90021,0x291e4ce5,0xbb850015,0x8d650da4}},	//   _رفعت_, óta_, _كلتي, _явле
  { {0xc0520053,0x2918002e,0xad1a0008,0x9d1a0135}},	//   ָזן_, rkra_, _מוסר, _מוסט
  { {0xeab200c3,0x29184ce6,0x66e31100,0x0000006a}},	//   _صعب_, skra_, лоса,
  { {0xea010023,0x99160010,0xbb3b0053,0x8b3b000a}},	// [b7a0] _đầu_, _зьні, _מעקי, _מתקצ
  { {0x691000f2,0x59970008,0x7794002b,0x7d7a004c}},	//   _väes, _רכיב_, _لیسا, פרעג
  { {0x389b00b2,0x1d16004c,0xd3360033,0x6b8b0045}},	//   _מיינ, עקער_, нэды, _îngă
  { {0x2ca50084,0xfe670087,0xc1ea005e,0x96ba006e}},	//   hald_, _مد_, зьке_, _عاجز_
  { {0x2ca50134,0x6b5600dc,0xa3e5000b,0xf67b004c}},	//   kald_, lágs, _बैठ_, _מאכמ
  { {0x2ca5002e,0xe1660015,0xd24f0067,0xd0d4006b}},	//   jald_, ردشي, حنه_, токъ
  { {0xd0100015,0xe29a008b,0x7e621506,0x0000006a}},	//   شلة_, _нав_, _szop,
  { {0xc7b3000a,0x7ff30015,0x4f670033,0xa6fa000a}},	//   אבה_, اسوا, ншым_, לִ֥י
  { {0xa3dc005d,0xa3e8005d,0x61e40064,0x2ca51639}},	//   तौर_, बिक_, çild, fald_
  { {0xeb19000b,0x71d7000a,0xc0d60015,0x3ea44ce7}},	//   दस्त_, _אומד_, _سيصب, samt_
  { {0xf36a000a,0x20c90015,0x9c7c006f,0x351b000a}},	//   ּדָּ, _تبقي_, ndči, פוטנ
  { {0xa4fd005d,0x4e960015,0xd00f002b,0xc43b000a}},	//   _उच्च_, _أشار, _دلم_, לתיי
  { {0x2ca50ecc,0x298b00a4,0x0a68004a,0xdb1b0069}},	//   bald_, ясно_, ерри_, nuté
  { {0x4bda0015,0xab5d003d,0x63be4298,0x1d07004a}},	//   _فبعد_, itļi, kupn, _печи_
  { {0x98480063,0x5fab000a,0xccf80046,0xe759005e}},	//   еята_, ּ֑לֶ, směs_, диві_
  { {0x7bcf005c,0x9f47002c,0x63be0049,0x25a94ce8}},	//   ńcuc, yvní_, dupn, tsal_
  { {0xf65300a2,0x776d0012,0x63ba0123,0x25a9055e}},	// [b7b0] ائز_, rmax, _åtnj, usal_
  { {0x7d1a10cc,0x2edd000b,0xf9900015,0x6b560030}},	//   nkts, _मस्त, _ابي_, ságt
  { {0x25a94ce9,0x7d080079,0x61e2002a,0xa3dc000b}},	//   ssal_, ijds, ewol, तौल_
  { {0x67240298,0x62750029,0x25a90089,0x6b560030}},	//   chij, نهائ, psal_, lágr
  { {0x6664010f,0xaad3000b,0x6910007c,0xdd86002b}},	//   _бърз, ध्यक, _käep, _خو_
  { {0x9f470089,0x78a70085,0xccf80046,0xe1f80033}},	//   rvní_, najv, změr_, эгі_
  { {0xa4d40036,0x22950029,0x61120004,0x2ca54cea}},	//   _щорі, _للأس, рдју, vald_
  { {0x25660152,0x63b8006f,0x2ca53834,0x1dc50058}},	//   rôle_, ávne, wald_, نْبِ
  { {0x2ca50123,0x62840085,0xfd110015,0x0000006a}},	//   tald_, žioc, لجد_,
  { {0x61e40064,0x8d7500e5,0x84fa000a,0x91a80058}},	//   çile, خابا, ֵּיה, _أهلك_
  { {0xd0f6000a,0x4ed50015,0xe572000a,0x8c454ceb}},	//   _שמעת_, _لقاء, סַח_, тене
  { {0xde950001,0x2b160063,0xc949000a,0x3986016e}},	//   _радњ, тьор, _ומ_, _pôs_
  { {0xdd940010,0xb5fb00dc,0x0b4300fd,0x5ee8000a}},	//   _бачы, _szán, рнян, _רַעְ
  { {0x9e640191,0x6fd8005d,0xb0e1000b,0x91ba000a}},	//   _свід, _महमू, फ़िग, ומשי
  { {0xea010023,0x61e20050,0xdb09001a,0x98a30fd5}},	//   _đấu_, zwol, ludý, рисе
  { {0x6b830586,0x2b03000b,0x6f094cec,0x0000006a}},	//   _iung, षाणु_, njec,
  { {0x80e1005d,0x67242b1a,0x76f50033,0x35a60033}},	// [b7c0] फ़ाइ, rhij, ыярх, тазг
  { {0x63be0107,0x6b834ced,0x6d4144be,0x385a0015}},	//   tupn, _kung, nnla, _يشدد_
  { {0x8afa000a,0xe3b20015,0x6616008c,0x6aa401c2}},	//   ֽהְי, شرا_, syyk, _keif
  { {0xf5290008,0xf7730086,0x7984003f,0x6fd8000b}},	//   חץ_, _پاپ_, _kuiw, _महबू
  { {0x2eed0026,0x9c7c053e,0xf1fa0015,0xc2970033}},	//   ddef_, leče, بعات_, ткіх_
  { {0x61e20026,0x2eed0064,0xf9930008,0xe4da002b}},	//   rwol, edef_, סרו_, _توست_
  { {0x63630020,0xb4de005d,0xf8b3000a,0xaed40033}},	//   sõna, ढ़ी_, בשו_, гойш
  { {0xdb1b0152,0xff4f0015,0x6b560030,0x6d414cee}},	//   puté, يخي_, zágr, enla
  { {0x6b5d0014,0x5d540661,0x6d41002e,0xcf770002}},	//   ségk, лкит, fnla, خصوص_
  { {0x6b834cef,0x18a4004c,0x60ea0033,0x2d76002a}},	//   _bung, טעגאָ, _імем_, _złej_
  { {0xa3e8005d,0x3eb90007,0x6f094cf0,0xb09b000a}},	//   बिट_, ųsta_, bjec, _חיבר
  { {0x19950033,0x6b830dad,0x645c16c4,0x6d414cf1}},	//   ламя, _dung, _myri, anla
  { {0xdd900074,0x6e29005c,0x7def00dc,0x64de000b}},	//   _اوت_, czeb, rősö, _नक़्श
  { {0xc171000a,0x6b834cf2,0x798400aa,0x35ac0065}},	//   ֶ֗ם_, _fung, _duiw, _चिज़
  { {0x28d2005d,0xb5fb00dc,0x39340010,0xf77300e5}},	//   द्धि, _ezál, рэўс, لار_
  { {0x27fe00c0,0x3c77000a,0x6c57000a,0x6b560030}},	//   åtna_, _בתום_, _שיהא_, ságr
  { {0x6b831fd5,0xfa34002b,0xf7700015,0x1bea000b}},	// [b7d0] _zung, _پريد, زاف_, टिकल_
  { {0xe5c4009c,0x645c0034,0xdb02001a,0x45d40248}},	//   јсто, _byri, mslá, рофс
  { {0x389a0008,0x1bfb005d,0xdb02002e,0x7aed0604}},	//   _איתנ, एमएल_, lslá, _kaat
  { {0xdc3b000a,0x2bae002a,0xc7f6000a,0x7aed007c}},	//   ועבר, ięc_, _עזרת_, _jaat
  { {0x78a50020,0xdb02001a,0x7aed43b4,0xf772000a}},	//   _kehv, nslá, _maat, _לקט_
  { {0x645c09f0,0x1bf4014e,0x7aed48fb,0x6b5d00dc}},	//   _fyri, ेमाल_, _laat, ségh
  { {0x6f09016f,0x645c0026,0xe53400c2,0x0000006a}},	//   tjec, _gyri, _терь,
  { {0x765d022d,0x929d005c,0x287c0008,0xa87c00f3}},	//   _kysy, _połu, ונומ, ואור
  { {0x74ca005d,0xc332000a,0x6aa44cf3,0x6b8326c9}},	//   स्कृ, _הון_, _reif, _sung
  { {0x6e29005c,0x6d411dc1,0x61e94cf4,0x60990015}},	//   rzeb, unla, _isel, _أناس_
  { {0x91b00023,0xb5fb00dc,0x798400aa,0xfaa64cf5}},	//   _đảm_, _szál, _suiw, лано
  { {0xe452000f,0xdb02001a,0xf8ec000b,0x6d584cf6}},	//   מֶר_, fslá, _छोड़ा_, _ekva
  { {0x3f850375,0x2727007c,0xa2f6000a,0x9c7c2db3}},	//   _hulu_, _mõnd_, אמרה_, veče
  { {0x2f1800dc,0x6b834cf7,0x3f854cf8,0x0000006a}},	//   _régi_, _tung, _kulu_,
  { {0xc8150191,0xd141005c,0x3f850085,0x6aa40034}},	//   аєть, czął_, _julu_, _teif
  { {0xd7f700a7,0x2fd80020,0x7bc14cf9,0xeccf000b}},	//   ững_, _ärge_, mulu, त्रफ
  { {0x765d0176,0x166605b3,0x645c4cfa,0x99d60015}},	// [b7e0] _cysy, увам, _syri, _إتبا
  { {0xda7b0053,0xb4de005d,0x645c384d,0x7aed002a}},	//   _אנפר, ढ़े_, _pyri, _zaat
  { {0x657c022d,0x7bc14cfb,0xd91b000a,0xd575005e}},	//   _virh, nulu, _נוטל, руть
  { {0xd3870010,0x7bc10011,0x645c1185,0xd379005e}},	//   уйце_, iulu, _vyri, вчі_
  { {0x765d0176,0x1a9b0053,0x61e900dc,0xbb3b004c}},	//   _gysy, גינע, _csel, עעני
  { {0xdce30048,0x645c0007,0xa2d4021e,0x929d002a}},	//   _minē, _tyri, _यॉर्, _sołt
  { {0xd5470063,0x7bc12da3,0x91030054,0xf776000a}},	//   _спре_, julu, спје, ְעִי_
  { {0x7bc10011,0x3f850849,0x35a9000b,0x273f008c}},	//   dulu, _dulu_, _चौड़, mänä_
  { {0xd335008f,0x8f670015,0xba490046,0x7bc10034}},	//   _тэры, دميك_, omůž, eulu
  { {0x2dd70029,0x1dd70029,0x7bc10011,0xe1660015}},	//   ابية_, ابيع_, fulu, _إدري
  { {0xeb97000d,0x1ee9002b,0x853b000a,0x78a5007c}},	//   лиќ_, رویی_, תגיי, _rehv
  { {0xb5fb03c0,0x6da60083,0x27270020,0x61e9008c}},	//   _szám, _бида, _kõne_, _ysel
  { {0x7aed0458,0x69360024,0x7bc101be,0x2d961377}},	//   _vaat, aņem, aulu, _срес
  { {0x8cd3014e,0x27270020,0x6d5800bd,0x7bc14cfc}},	//   ब्दो, _mõne_, _ukva, bulu
  { {0xbd5b000a,0x7bc14cfd,0x273f008c,0xdb1b3e08}},	//   _רכוש, culu, jänä_, lutí
  { {0xcb690074,0x765d00f2,0xba490089,0x7bcf0011}},	//   _جمعه_, _pysy, emůž, ăcut
  { {0xdb1b0227,0xf62b005e,0xa5351923,0xb5fb0de4}},	// [b7f0] nutí, хіви_, анач, _izák
  { {0x98c7005e,0xd6680015,0x765d0de4,0xdb0201d0}},	//   _ссил, امكو_, _vysy, gslæ
  { {0x765d0050,0xb97a0008,0x9cd7000a,0xf990002b}},	//   _wysy, _שנתי, רובה_, _وبی_
  { {0x92eb003b,0x23740021,0x179a000a,0x05b7000b}},	//   عراق_, مانح, _שירב, ेंदब
  { {0x69360024,0x28d2000b,0x05790015,0x7bc11252}},	//   zņem, द्वि, _لمحة_, zulu
  { {0xf77f0064,0x55ba000a,0x61450054,0x7bc10061}},	//   _hiç_, _במשו, јека, yulu
  { {0xd92c000a,0x7e0d000b,0x6b5d0003,0x7bc10045}},	//   עֵדָ, ाङ्ग_, légu, xulu
  { {0x7bc14cfe,0xf838000a,0xd343002b,0x61e94cff}},	//   vulu, טנות_, _افری, _tsel
  { {0x1d25226a,0x80cd000b,0xb5fb0030,0x3eb90091}},	//   имим, _सापे, _száj, ųsto_
  { {0x3f850020,0x7bc14d00,0x9d520015,0x636a001a}},	//   _tulu_, tulu, ينيت, rýne
  { {0x3084003b,0xc1040029,0x53350008,0xd335000a}},	//   _المف, _دولي, ֹאָב_, ֹרָה_
  { {0x7bc10b0e,0xb5fb0107,0xed5918b1,0xbf9a000a}},	//   rulu, _vzáj, drže_, _ייעש
  { {0xfe9a0008,0x39e90010,0x8f1a0008,0xd356000a}},	//   _סיסמ, льён_, _שונת, שירי_
  { {0x827600b2,0x7bc14d01,0xa96a1032,0x6936003d}},	//   יערע_, pulu, тига_, pņem
  { {0xc7a6005e,0xbd6800d7,0x07a61ab1,0xd94301cf}},	//   рибк, _срце_, рабн, цери
  { {0x273f00f2,0x6fd8005d,0x44240024,0x68430033}},	//   vänä_, _महसू, _ām_, інта

  { {0x25760015,0x96760033,0x6ffc0045,0x84960015}},	// [b800] لهرس, рыві, _zăcă, لجائ
  { {0x33f60b18,0x26cb04ed,0xf993000a,0xd52d0016}},	//   ичес, _ecco_, _ורז_, gừn
  { {0x3958014c,0x889b000a,0xbcb6000a,0xc3da00c3}},	//   mors_, _שבטי, שפעו_, ضباط_
  { {0x28d2005d,0x6b5d00dc,0xa2af005d,0x41b60015}},	//   द्रि, ségv, ुलग्, لمصر
  { {0xf8aa005d,0xb2d30015,0x23270004,0xdb020123}},	//   _क़ाय, تينغ, шоци_, mslä
  { {0xc05a0191,0xc1560001,0x6fb40015,0xdfd00015}},	//   кій_, шњењ, ممتا, كيت_
  { {0xf8b301e4,0x98b10011,0xddea0086,0xbfa7004a}},	//   קשה_, liză_, چرخه_, атые_
  { {0x9c7c016f,0x39584d02,0xdb020c77,0xd0070054}},	//   ječa, hors_, nslä, реће_
  { {0x1d34006b,0x60ea06a6,0xcd061088,0xb145002b}},	//   йния, _имам_, ачни, _گیوم_
  { {0x64430050,0x7fd60036,0x62590036,0xf536000a}},	//   źnie, _віді, _срср_, ינִי_
  { {0x395808e0,0x3ea6008c,0x3b55005e,0x7b670912}},	//   dors_, _teot_, йкор, итме
  { {0x103b000a,0x7de60015,0x6ffc0045,0x539b004f}},	//   _בגבע, _نستم, _văcă, כסטא
  { {0x8d94003b,0x6ab60026,0x39584d03,0xdb02038f}},	//   _التش, _ddyf, fors_, dslä
  { {0x6ca3006b,0x58840033,0x7d1c0123,0x0000006a}},	//   _дръж, жыта, örsd,
  { {0xdb0900dc,0x6f020334,0x08c40033,0xe7872ad9}},	//   álóz, _knoc, юбён, руго
  { {0x6c7b039e,0x2cac0bc8,0x37043878,0xbc7b000a}},	//   _באופ, ladd_, очув, _בנות
  { {0x87540036,0x69c00144,0x39581392,0xdb1b0045}},	// [b810] ікує, àmet, bors_, putâ
  { {0xe58a00dc,0x6aa7000b,0x6b5d0003,0x03b70015}},	//   óváí, _ख़ुर, régu, لإصد
  { {0x84390015,0xc4550015,0x14ca002b,0x0000006a}},	//   دكار_, حَاب, اهمی_,
  { {0x256f0020,0xd7fa0053,0x2b590011,0x3c79004c}},	//   külg_, _עהרל, nosc_, אָנב
  { {0xdb1b0030,0x0000006a,0x0000006a,0x0000006a}},	//   lttó,   ,   ,
  { {0x70e1000b,0xf616000a,0x64520003,0x6f024d04}},	//   फ़ेल, _החשש_, édié, _anoc
  { {0x64580020,0x2ca74a54,0x26c90085,0x63be0085}},	//   üvit, _rend_, ogao_, crpn
  { {0x24890007,0x8505005d,0xcee9011d,0x2ca749ed}},	//   šimą_, रावट_, удие_, _send_
  { {0x9c7c0582,0xcee80029,0x7d150030,0x39584d05}},	//   veča, شرين_, özso, yors_
  { {0x0d82009e,0xd1310029,0x7d090054,0x6f024d06}},	//   яльн, _عما_, уног_, _enoc
  { {0x7f850029,0x38c8002b,0x39584d07,0xc4d2000a}},	//   _الصن, یاسی_, vors_, הגי_
  { {0x7d250086,0xa03a0053,0xbef40015,0x2ca7086c}},	//   _گفتن, _געעפ, _وأنت, _wend_
  { {0xc3320008,0x3ead0293,0x9c7c0b6c,0x2ca70493}},	//   לוט_, maet_, reča, _tend_
  { {0x8a39004a,0x9c7c12c4,0xdb020123,0x7c950058}},	//   ряют_, mečn, dslå, _الغص
  { {0x9c7c4d08,0x7d0321b7,0xccf20008,0x39581ee1}},	//   lečn, _inns, _זכו_, rors_
  { {0xfbb6000a,0xdb020d4a,0xa6860d7a,0xe73714fd}},	//   _הפקת_, uslä, слад, бес_
  { {0x7ae601e2,0xdb0200c0,0x9c7c0057,0x290c007c}},	// [b820] mekt, gslå, nečn, ödas_
  { {0xd2a6005e,0x6b5d0030,0x98b10045,0xdb1b0247}},	//   _бiль, ségt, riză_, vrté
  { {0x80b3005d,0xe29a0010,0x7ae60409,0x52860015}},	//   ीलैं, гае_, oekt, ملاك
  { {0x7ae64d09,0x6b5d3e8b,0xe64602ed,0x78ae01ec}},	//   nekt, légr, _гемп, labv
  { {0x6126002e,0x9c7c1dd7,0x023a0015,0xe505000b}},	//   _aðla, ječn, دثات_, राशि_
  { {0x201c0007,0xdb1b00dc,0x28db000b,0x9c7c0107}},	//   tyvi_, iutá, म्पि, dečn
  { {0xdfd00029,0x8f540015,0x877a000a,0x4fc60033}},	//   ذية_, ينتش, ְאִי, ёска
  { {0x69c600f2,0x70e1005d,0x80c4000b,0x3849000a}},	//   kuke, फ़ॉल, _राके, יאוּ_
  { {0xa63b00b2,0x98b1002a,0x7ae64d0a,0x4226226f}},	//   ָגיר, lizą_, dekt, _удав
  { {0x1d340036,0xdce30091,0x69c60926,0xf617000a}},	//   іння, _minė, duke, מחפש_
  { {0x2cac0026,0x62850089,0xa0970008,0x60660087}},	//   radd_, ěhov, _הדבק_, _اهال
  { {0x2bb50092,0xdcf80024,0xf413000a,0x8e860015}},	//   ích_, _divā, לפת_, _الإه
  { {0xc33301c8,0xdb090052,0x0000006a,0x0000006a}},	//   פוש_, kudö,   ,
  { {0x9e770135,0x200d002a,0xab64002a,0xdb020c4e}},	//   _הגדה_, ślił_, ążaj, vslå
  { {0x0d3b0008,0xd52d0092,0x69c60007,0xd6db4d0b}},	//   _תגוב, hữn, auke, лта_
  { {0x7ae601e2,0xf7700070,0xe699006b,0xdb1b2439}},	//   cekt, فاق_, рваш_, butá
  { {0xb505005d,0xdb2400dc,0xa4870029,0x8ccf000b}},	// [b830] रालय_, _írás, مجان, _दामो
  { {0x6aaf002d,0x256f0012,0xa4d40033,0x6d5a4d0c}},	//   lacf, küle_, зофі, nota
  { {0x68e70045,0x6d483062,0xe46b0a24,0xb4440138}},	//   mejd, inda, ушал_, пэцк
  { {0xc2c40029,0x61fb0111,0x321d005c,0xfa6b000a}},	//   كيمي, _prul, tywy_, ְכַּ
  { {0x2bb50092,0x6d5a0a6f,0x21750342,0x0085030c}},	//   ách_, kota, оукр, олло
  { {0x4f95000d,0x68e70085,0x85050067,0xe0d8005e}},	//   ориу, nejd, _بوسن, йві_
  { {0x3d0c005d,0xdfce00e6,0x69c60012,0xdb1b0030}},	//   ़ाने_, نيو_, zuke, zutá
  { {0x9c7c0089,0x61fb4d0d,0x6d484d0e,0xdcf8003d}},	//   tečn, _trul, enda, _rivā
  { {0x6b8a018b,0xddcb003d,0xd6fa000a,0xf1bf0046}},	//   _aufg, _izgū, בִיש, _íá_
  { {0x02440029,0x1c450142,0x9c7c3150,0x63710123}},	//   _عَلَ, жном, rečn, fång
  { {0x5fdd014e,0x637101d1,0xab5d0024,0x3b0a000d}},	//   _महिल, gång, guļo, аено_
  { {0x2fc700b8,0xcf92000a,0x9c7c0107,0x2056000a}},	//   mung_, _חטא_, pečn, _ויעל_
  { {0x1d090083,0x6b5d0152,0x2fc74893,0x28db000b}},	//   _вели_, tégr, lung_, म्भि
  { {0x69c606f5,0xa80603e7,0x2fc700da,0x7d0300cb}},	//   ruke, озгл, oung_, _unns
  { {0x27270020,0xd5460092,0x2fc74d0f,0x4aba006b}},	//   _sõna_, _lện, nung_, _купя_
  { {0x6b5d00dc,0x291e0020,0xa7660010,0x672d00dc}},	//   ségr, ötab_, ікад, ghaj
  { {0xf09f0023,0x68e700fb,0x2fc7018b,0x4b7b0053}},	// [b840] _đàn_, bejd, hung_, _דאקו
  { {0x91b00092,0x61e40064,0x6b8e0064,0x2fc70476}},	//   _đàm_, çilm, _öngö, kung_
  { {0x2fc7235a,0x6b841814,0xa3ea0004,0x7ae10030}},	//   jung_, _kiig, рдеа_, őlte
  { {0xc7b300a3,0xe1fa0164,0x6d5a0410,0xd5460016}},	//   _קבר_, иге_, zota, _bện
  { {0x6d5a000c,0x6d48002e,0xc4c60015,0x637102de}},	//   yota, ynda, _وتسو, dånd
  { {0x6b84267f,0x2fc700b8,0x256f0064,0xa3e5000b}},	//   _liig, fung_, tüle_, _बैक_
  { {0x4fc602e1,0x2fc74d10,0xe97b004c,0x6d5a4d11}},	//   іска, gung_, בנסש, vota
  { {0x68e7005c,0x3f82002e,0x6d480026,0x672446d3}},	//   zejd, öku_, wnda, nkij
  { {0xf7730008,0x1ee80086,0x6d5a18a2,0x41d1000b}},	//   וקה_, لوژی_, tota, _समयस
  { {0x2fc74d12,0x61ed0144,0x672d3198,0x6d5a4d13}},	//   bung_, çale, zhaj, uota
  { {0xe61f0023,0x7fd60484,0x6d5a4d14,0x6d484d15}},	//   _ngôn_, _фізі, rota, rnda
  { {0x8ae70036,0xf1b1000b,0x7f170021,0x8fc5002b}},	//   ціол, ुंचन, _ويلز_, _رزمن
  { {0x6d5a4d16,0xbf130015,0xda670067,0x63710123}},	//   pota, _تونب, تادي, sång
  { {0x010a000a,0x672420dd,0x63710f94,0x0000006a}},	//   ׁלָּ, ekij, måne,
  { {0x68e70816,0x7d57000a,0x29050061,0x6e200034}},	//   rejd, _ויגד_, ıla_, lymb
  { {0x7aea0053,0xa3e5000b,0x9f4c0125,0x9f4e0144}},	//   אָטעס, _बैग_, _ardú_, ïnès_
  { {0x86270010,0x2fc700b8,0x3eb9002e,0x7bc84d17}},	// [b850] цьве, zung_, ósti_, ludu
  { {0x672d000c,0x8505005d,0xf09f0092,0x44270015}},	//   shaj, राइट_, _đào_, يراف
  { {0x3eb900df,0x80c4000b,0xb8e1000b,0x753c00bc}},	//   ųsti_, _राजे, ुल_, _dmrz
  { {0x7bdb000a,0x3318002b,0x7d184d18,0x80cd0065}},	//   שקאו, يزند_, _lovs, _साहे
  { {0x7bc8000c,0xa2cc005d,0x96fa000a,0xeb3c004c}},	//   hudu, _हार्, _פלשת, סעדש
  { {0x7bc8003f,0x2fc74d0f,0x3f8c04c6,0xa99c00a3}},	//   kudu, tung_, _budu_, סבור
  { {0xe8d90092,0x637100c0,0x2fc700b8,0xc4d2000f}},	//   _quỹ_, tånd, uung_, _רגל_
  { {0x2fc74d19,0x7bc80375,0x1ef90015,0xe6cb000b}},	//   rung_, dudu, صعبة_, िलिङ
  { {0x6b841c23,0x2fc70747,0xdeee0369,0xed590160}},	//   _riig, sung_, اًً_, luži_
  { {0xee3604ab,0x2fc72982,0xdb020013,0x412800af}},	//   яны_, pung_, lslø, _дођо_
  { {0x7bc80020,0x7d1c0123,0x6f0f0030,0xcb0a002b}},	//   gudu, örsa, öccs, ميدن_
  { {0x1bec005d,0x09e61aea,0x612f2e9e,0x68e30061}},	//   _जनरल_, помн, _bølg, _ında
  { {0xb0d2014e,0x7ed40086,0xd1480092,0x6ed0000b}},	//   _सामग, _آزما, iễn_, _धातु
  { {0xfe700074,0x2d9f0003,0xbbe8002b,0x6ce7005e}},	//   _شدن_, mpue_, حریم_, _фіде
  { {0xab99003b,0x6724043c,0xfbd10015,0x6b84007c}},	//   _اختر_, tkij, _أتت_, _tiig
  { {0x612f02e9,0xdaaa00d0,0x3bba039e,0x91cc000b}},	//   _følg, _увид_, _המקד, _समलै
  { {0x5bdb005d,0x09ba0015,0x6443001a,0xdb020013}},	// [b860] _बहुव, _اطبع_, únin, dslø
  { {0x9a3b0008,0x6d412411,0x69fb000a,0xe8ca004a}},	//   _לתפק, nila, _פליק, _угол_
  { {0x3d0c000b,0x64a307be,0x7af61af8,0xdce3003d}},	//   ़ाते_, хаха, _kayt, _ainī
  { {0xeb9600b2,0x6d413ee7,0xdcb10016,0x5186029f}},	//   לדער_, hila, hả_, пука
  { {0x291a0024,0x96fb000a,0x225a0015,0x6d412411}},	//   _kopa_, _הלכת, حجاب_, kila
  { {0x291a00f2,0x25a0013c,0xf993000a,0x3ce5000b}},	//   _jopa_, mpil_, ערו_, क़ों_
  { {0xc4480086,0x6d414d1a,0x53a602ed,0x0000006a}},	//   _بیان_, dila, _хабб,
  { {0x0eea0036,0x02460029,0x57fb000a,0xb3bb000a}},	//   ськи_, _فَأَ, מלצו, _למלכ
  { {0x9f6300dc,0xa2d30029,0x4e930021,0xfeb7002b}},	//   ívás_, _سيلت, رشير, سايت_
  { {0xd24f0029,0xc19b000a,0xa3c3000b,0x25a001d7}},	//   _إنك_, _לשמי, _एटम_, ipil_
  { {0x6db501e2,0x9c7c0089,0x7bc80fb2,0xd12f0031}},	//   _aşağ, mečk, uudu, _حمل_
  { {0x6d410035,0x9c7c0046,0xcf260015,0xdb1b007c}},	//   aila, lečk, _عرضي, httö
  { {0xc333013a,0x7bc80061,0x7af60ca8,0xbea30054}},	//   תור_, sudu, _dayt, _чачк
  { {0x256f007c,0x9949002b,0x291a4d1b,0x9c7c0046}},	//   küla_, زلزل_, _copa_, nečk
  { {0xd1480023,0x36d50036,0x9cdb0008,0xd7e4042b}},	//   yễn_, мовр, _הקופ, ніто
  { {0xf09f0092,0x8f9b00a3,0x649100bc,0xba3b0003}},	//   _đàm_, מילי, zžič, saïq
  { {0x2abc000a,0x3abc000a,0x80cd000b,0x2bc4000b}},	// [b870] _המחא, _המחנ, _साले, लंका
  { {0xf9940b7b,0x9c7c4d1c,0xe4b90033,0x291a0034}},	//   _ארץ_, večj, ілеі_, _gopa_
  { {0x2938000a,0x0394005e,0x44274d1d,0x9c7c0046}},	//   _מאזן_, ерія, án_, dečk
  { {0xaabf005d,0x9999005c,0x673d002e,0xa294005e}},	//   ्लिक, mysł_, _umsj, еаці
  { {0xd49b009c,0x6d410030,0xb5fb0030,0x0000006a}},	//   _грб_, yila, _ezár,
  { {0x3cf8005d,0x44270092,0x9c7c10ca,0xe4c5002b}},	//   ्ञों_, ơn_, rečj, _تصحی
  { {0x31580015,0x4abf000b,0x7fd5008b,0x612f00cb}},	//   أجنة_, ्लाव, філі, _nøle
  { {0xbf350029,0x2566006f,0xa6fb000a,0xcf390033}},	//   برتغ, vôli_, מִ֖י, ўчкі_
  { {0xe087002b,0x02440015,0x6d414d1e,0x8e09005e}},	//   _فجاي, _كَفَ, tila, інов_
  { {0x251a0053,0xfe420805,0xdcb10092,0x51740015}},	//   ַורא, тньо, uả_, _كالأ
  { {0xac390036,0xdcb10092,0x6363007c,0x8079000a}},	//   ючих_, rả_, sõnu, _וְ֠ה
  { {0xf1d1014e,0x8ccf000b,0x2d8b0077,0x63b80264}},	//   _समान, _दावो, íces_, ávni
  { {0xdb1b0945,0x7ae9007c,0x291a4d1f,0x6d414d20}},	//   yttö, õeta, _popa_, pila
  { {0x61e40064,0x612f0293,0x75f80030,0xdb0b0123}},	//   çili, _føle, húzá, _avfä
  { {0x2d8f003e,0x4c9a000a,0x25740012,0xdd0b002a}},	//   _huge_, _ובצו, näle_, półd
  { {0x2d8f4d21,0x0000006a,0x0000006a,0x0000006a}},	//   _kuge_,   ,   ,
  { {0xb5fb00dc,0x2d8f0152,0x25a00089,0x36670001}},	// [b880] _szár, _juge_, upil_, дато_
  { {0x186a0124,0xc8ca0074,0x3eaf0b8e,0x64a8000b}},	//   _мапи_, _بودن_, _legt_, गरेश
  { {0x25a0290f,0xfb53002b,0xe424002b,0xd3360033}},	//   spil_, _سپید, رکسي, мэды
  { {0xdb1b4d22,0x2d874d23,0x2bc5000b,0x929d002a}},	//   ortá, _line_, _विना, _koły
  { {0xd00f0086,0x4426003d,0x44a60015,0x04b60121}},	//   یله_, ņo_, _يحسّ, _освя
  { {0xcf9a0124,0x2d87003e,0x61ed0061,0x7056002b}},	//   оји_, _nine_, çala, ونشا
  { {0x399401d1,0xe29a0036,0x46b2005d,0x3d11000b}},	//   _läs_, _мав_, _ज़ाह, ताने_
  { {0xadf40345,0x2d874d24,0x6d4f0003,0x98a40091}},	//   епиш, _aine_, écan, ėmę_
  { {0x2d8704f9,0x9c7c0007,0xd6eb000a,0x51930015}},	//   _bine_, meči, חַיָ, _للقذ
  { {0x2b400251,0x21a3004a,0x2d8f0085,0x2d874d25}},	//   _amic_, _рифм, _duge_, _cine_
  { {0x2d874d26,0xccf80046,0xdfcf012c,0x69c04d27}},	//   _dine_, rdě_, _نيل_, ámen
  { {0x2d870bcf,0x80da014e,0x39430111,0x7e260a61}},	//   _eine_, प्रे, wijs_, _одеж
  { {0x2d874d28,0x69c01c4e,0x9c7c0091,0xedd30040}},	//   _fine_, šmen, ieči, _ليند
  { {0x3eaf0111,0xfbcf002b,0x2d874d29,0x0000006a}},	//   _zegt_, دتی_, _gine_,
  { {0x2bad005d,0x2d8f00b8,0x9c7c0007,0x39434d2a}},	//   झीदा, _zuge_, keči, rijs_
  { {0xdce90024,0x9c7c01a3,0xf6530015,0xb5ab0015}},	//   zpeļ, ječi, نئذ_, قائك_
  { {0xda670086,0x2d870064,0x7bda00f2,0xe7840c71}},	// [b890] _تاثي, _yine_, lttu, туро
  { {0x2bc5005d,0xe46b0080,0x98c70033,0x7bda4d2b}},	//   _विमा, ошел_, _ўспл, ottu
  { {0xa4d402a3,0x7bda005b,0x0000006a,0x0000006a}},	//   тохі, nttu,   ,
  { {0x5b7c0053,0xa87a0008,0x91d50010,0x7bda4d2c}},	//   ַרגא, _מאתר, ецкі, ittu
  { {0xa1eb0029,0xdb2600dc,0x2bc5021e,0x0736000a}},	//   تراك_, épés, _विभा, _נאשם_
  { {0x7d1c00c0,0xf6520008,0xc4c70015,0x51920015}},	//   örsl, _עצם_, _تتحو, دلوذ
  { {0x60960015,0x13f4024f,0xd01100c3,0x2d8f4d2d}},	//   رنيس_, _изря, الع_, _suge_
  { {0x69c60293,0xc2c40015,0x2d874d2e,0x25740012}},	//   yrke, _ليفي, _sine_, räle_
  { {0xf1a70484,0x2d874d2f,0xdb1b02de,0x7bda4d30}},	//   _іран, _pine_, ortæ, ettu
  { {0xfd110029,0x3ea20064,0x6e9f005d,0xc5f2039e}},	//   اجة_, ıkta_, _ग्रु, נדי_
  { {0xcb6a0f09,0xcc89002b,0x2d874d31,0x3eb9001a}},	//   зане_, ينکه_, _vine_, ósts_
  { {0x2d87003e,0xef0e0010,0x929d002a,0x2d8f471b}},	//   _wine_, _ём_, _poły, _tuge_
  { {0xed4e02e5,0x6d4c002e,0x2d87173e,0x5e270015}},	//   _бо_, ðlað, _tine_, _تعاق
  { {0x2916002b,0xc236000a,0x11da000a,0x98b80091}},	//   روزآ, גרשו_, החשב, kirą_
  { {0xb8930015,0x929d002a,0x1ae60033,0xdb24002b}},	//   الفع, _woły, _зойм, _لوثی
  { {0xdc3a000a,0x2eed0079,0x34a80065,0x6378039f}},	//   _מעצר, neef_, गर्द, míng
  { {0x69da0045,0xbcd9004f,0x6ed70065,0x9c7c0081}},	// [b8a0] ătes, ּחֲך, _यानु, veči
  { {0x637100c0,0xda5b000a,0x2ba6000b,0x96630033}},	//   våna, _מכפל, कीका, укуе
  { {0x20c9005d,0x8afa009d,0x80c9005d,0xc2c6002b}},	//   _राजध, ּהְי, रलैं, فياي
  { {0xeb9200b2,0x179b000a,0xa79b000a,0xa3c1000b}},	//   אָס_, _מיטב, _משטח, ूढ़_
  { {0x171b00b2,0xd252002b,0x471b004c,0x9c7c4ba8}},	//   _זוכע, دنش_, _זוכג, reči
  { {0xdfd00087,0xdb02002d,0x7bda002e,0x80bc000b}},	//   ليت_, osló, yttu, ैलें
  { {0xa87a0053,0x7ae40398,0x50b70015,0x30a5005e}},	//   האַר, _obit, ردود_, трів
  { {0x20d2005d,0x9ed7006b,0x78b50085,0xb7db004f}},	//   _सावध, емът_, zazv, לקצי
  { {0x02060191,0xdb020152,0x657e0152,0x9e97002b}},	//   _язан, mplè, omph, رخيز_
  { {0x7ae44d32,0x80a60015,0x62840091,0x3eb9002a}},	//   _abit, _أمان, žios, óstr_
  { {0xbea6006b,0x7bda4d33,0x6c5413d6,0x8d730058}},	//   _заек, uttu, ткну, دايا
  { {0xf09f0092,0x7bda3ff5,0x600b000a,0x28d3000b}},	//   _đài_, rttu, _מִדְ, _ताहि
  { {0x7c66002b,0x1df801b0,0x6ea60065,0x6e930058}},	//   باکل, _целы_, _ट्यु, _إلها
  { {0xdb020084,0x2e37000a,0x63782ec8,0x0000006a}},	//   fsló, _ארדש_, línd,
  { {0x272e0084,0xc6a70292,0x19580010,0xd7c4004a}},	//   _sýna_, ерзи, хары_, лёто
  { {0x6443005c,0x0000006a,0x0000006a,0x0000006a}},	//   źnik,   ,   ,
  { {0x273500c0,0xdb02002d,0x6126002e,0xaaa8000a}},	// [b8b0] _lång_, asló, _eðli, _אֹת֖
  { {0x48ab0080,0x27270020,0xd49822c5,0x95c40015}},	//   _этим_, _mõni_, ерц_, ايله
  { {0x98c4005f,0x32040041,0xd40403a9,0x8cd8000b}},	//   _ссыл, _army_, ляци, _मानो
  { {0xe8d90092,0x7afd1d40,0x7aef4d34,0x69cf0003}},	//   _tuỳ_, ndst, nect, ouce
  { {0x69dd0698,0x7aef0011,0x471a000a,0x7bc80012}},	//   ntse, iect, _חורג, hrdu
  { {0xe61f0092,0xf9940135,0x0165006b,0xa06933bc}},	//   _ngôi_, ארס_, ъкло, мала_
  { {0x2bc5005d,0x62960064,0x2fd60015,0x389c000a}},	//   _विधा, ıyor, نوود_, ליגנ
  { {0xc7b40008,0x7afd27f7,0x69dd4d35,0x02940015}},	//   אבק_, jdst, ktse, _مؤكد
  { {0xa1950063,0xdb0200dc,0x60f50001,0x26b6000a}},	//   _разч, zsló, _изађ, כִים_
  { {0xdb020152,0x69cf0939,0x27350293,0x7de40015}},	//   mplé, duce, _hånd_, اسيم
  { {0x273501d1,0x7afd0111,0x7aef0287,0xcc89002b}},	//   _gång_, fdst, fect, بنده_
  { {0xe6270092,0xf412000a,0x7f490015,0x69dd4d36}},	//   _phổ_, ׁ֤ר_, _تلصق_, ftse
  { {0xfeb800a2,0x7dc4002b,0x69cf0085,0x7bc84d37}},	//   _سانت_, _مقنن, guce, ardu
  { {0xa021007c,0x63784509,0x636a001a,0x8cd80065}},	//   _ööse, míne, rýni, _मायो
  { {0x290c0064,0x69dd4d38,0x28d3000b,0x3859005e}},	//   ıda_, atse, _तारि, ертю_
  { {0xc6c30b18,0xcf920053,0xed591007,0xdb02002e}},	//   ийск, שטן_, drži_, rsló
  { {0xceb205af,0xb0d2000b,0x6378216b,0x4b7b0643}},	// [b8c0] יין_, _सालग, níne, _קאפו
  { {0xd5af0029,0x79b70008,0x19b7000a,0x7794002b}},	//   تفك_, _שליד_, _שפיר_, _میسا
  { {0x6b5d00dc,0xccf2000a,0x0555005e,0xb8e8000b}},	//   végz, שכב_, уття, ॉल_
  { {0x8c1a01ac,0xa3d3005e,0x33290033,0x71a60033}},	//   וועי, роїч, нцін_, вадз
  { {0x51f30015,0xd24f002b,0x27350123,0x7d1c4d39}},	//   لسور, ينم_, _sång_, örsk
  { {0x16b2000b,0x64a311ea,0x63780046,0xf518004f}},	//   _ज़ुब, _вара, díne, _אֵֽל
  { {0xd010003b,0x7aef0467,0xdea20086,0xefb30086}},	//   صلة_, yect, لیای, لیلگ
  { {0xd0070124,0x2ef4023e,0xc7b3000a,0x9df81236}},	//   ђење_, узир, בבה_, енит_
  { {0x28d3014e,0xe0da03f1,0x629e0089,0xe3550010}},	//   _तालि, _ова_, ěpod, _стрэ
  { {0x867b000a,0x21764d3a,0x067b000a,0x9d140248}},	//   ורפו, _рубр, ונפל, удоч
  { {0x5c730080,0x7bc80064,0xe4ab000a,0xdfcf0015}},	//   ильт, urdu, וֹכָ, _ويك_
  { {0xbea60afb,0x4dda0015,0xddc61adc,0x69dd4d3b}},	//   _радк, _يوضح_, _абди, ttse
  { {0x69dd31d4,0x9c7c00bc,0x9e370015,0x7afd1590}},	//   utse, veču, _لسوء_, rdst
  { {0x69dd0f51,0x7aef11e8,0x273502d6,0xcc2a0058}},	//   rtse, sect, _måne_, _يأثم_
  { {0x660600f2,0x984802e1,0x7aef1d0a,0xe8240674}},	//   _arkk, вята_, pect, афто
  { {0x6d482d85,0x69dd0012,0xf7700040,0x2fd8007c}},	//   lida, ptse, قاق_, _ärgu_
  { {0x6d4800f2,0xd5b10015,0x7c280034,0x20d2000b}},	// [b8d0] oida, صفا_, lydr, सलाध
  { {0xa4870087,0x6d482d85,0xc17e0091,0x39470123}},	//   نجان, nida, žėja_, _öns_
  { {0xe3b00029,0x66060604,0xcc78000a,0x3c78000a}},	//   قرن_, _erkk, תְּר, תָּב
  { {0xe3b00029,0xc2c40029,0x925915e6,0xa1950010}},	//   ترك_, ليمي, нает_, гадч
  { {0xe9df002d,0x672d4d3c,0x320b0067,0x6d483a53}},	//   ntú_, mkaj, بتاً_, kida
  { {0x3075005f,0xe4f9004c,0x6d480077,0x61e900bc}},	//   луйс, _אפֿש, jida, _vpel
  { {0x99820089,0xe9df002d,0xcfa40054,0xdb020125}},	//   zyků_, htú_, ашњи, splé
  { {0xe1f30086,0xdb020152,0x6abf005d,0x672d3827}},	//   _پسر_, pplé, ्लोर, nkaj
  { {0x3cd90010,0x6d48354b,0x61e92254,0x4d65004a}},	//   ньню_, fida, _upel, лкив
  { {0xe0d30086,0x5ba9171b,0x6d484d3d,0xacf501ca}},	//   _خزر_, нком_, gida, учиј
  { {0x3ed500e6,0xe8d90016,0x7c280034,0x5335000a}},	//   _مقار, _huỷ_, gydr, ָנָן_
  { {0x6378049a,0xf989000a,0x20df000b,0x16b2000b}},	//   píne, _זר_, प्रध, _ज़ेब
  { {0x2bc5005d,0x0b430036,0x433a000a,0x6d484d3e}},	//   _विवा, снян, תערב, bida
  { {0x82760053,0x6d480e75,0x6f1b016f,0xfe70006e}},	//   טערע_, cida, ljuc, _بدم_
  { {0x4fac000a,0x0d16004f,0x635c013b,0x0000006a}},	//   ֽׁמְ, _תקצט_, lčne,
  { {0x80cd005d,0x6f1d0012,0x635c00bc,0x9c7c013f}},	//   _साझे, ösch, očne, rečt
  { {0x635c198d,0xc6060010,0x6e290849,0xa3b6000b}},	// [b8e0] nčne, ызай, nyeb, चीन_
  { {0xe7940074,0xdff3021e,0x2a3b000a,0x850e000b}},	//   _پادک, _आनंद_, _נעימ, साइट_
  { {0xe4d70086,0xceb90046,0xe3b20015,0x6ab64d3f}},	//   اومت_, kař_, صرا_, _keyf
  { {0xe73a005f,0x12880086,0xe29a119f,0xfa76000a}},	//   _чем_, نمای_, хад_, ְעַת_
  { {0x7c28002a,0x69c0006f,0x0000006a,0x0000006a}},	//   zydr, ámeh,   ,
  { {0x6ab60084,0xe3a40086,0x66040123,0x15462c63}},	//   _leyf, _نشری, mvik, _сегм
  { {0x9fe60070,0xf3f80008,0x6d484d40,0x66041de4}},	//   استه, _בִּל, vida, lvik
  { {0x24530015,0x6e3b0012,0xc7b3000a,0x63a30030}},	//   _انفس, fzub, זבה_, ínne
  { {0x7c280026,0x61340251,0x50d60002,0x10a63b54}},	//   wydr, _càlc, _مزار, _бизн
  { {0x6d484d41,0x2bc5000b,0xb5f7015b,0x6b8d01d7}},	//   uida, _विशा, נציג_, _siag
  { {0x4093003b,0xa11300b0,0x3b550268,0x6d484d42}},	//   _المر, _دولت, икор, rida
  { {0xee3a0124,0x2bc5005d,0x8aa70010,0x4e960029}},	//   _пне_, _विरा, ырод, _إشار
  { {0x7c3a0014,0x6d484d43,0x6b8d3342,0xa143003d}},	//   sztr, pida, _viag, _šķit
  { {0xe9df002d,0x68fe2bee,0x66041661,0x7bdd0045}},	//   rtú_, _capd, dvik, ăsur
  { {0xf7730031,0xb8fd000b,0x3d11000b,0xdb1b0003}},	//   مار_, _डा_, तारे_, ystè
  { {0xd6d8070e,0x3d0c000b,0xe9df0144,0x6e2d002a}},	//   лту_, ़ाके_, ptú_, _żabi
  { {0x256f00dc,0x6d5d0003,0xf770006e,0x27fa2ac8}},	// [b8f0] lüli_, ésag, ساف_, _espn_
  { {0x672d4d44,0x9e77000a,0x44b41a2f,0x45d40a96}},	//   skaj, רגמה_, йбус, софс
  { {0xa9260048,0x53a40029,0x672d0796,0x889a000a}},	//   _dažā, مملك, pkaj, _בבתי
  { {0x2d8e0041,0x63780ade,0x929d002a,0xe3b0002b}},	//   _life_, vínc, _małg, سرم_
  { {0x86270010,0x62860089,0x23160029,0x1af8004c}},	//   _сьне, _úkol, شيوخ_, טמאל_
  { {0xc0c80001,0xa99c009d,0xfbc5000b,0x7ff50015}},	//   гуће_, עבור, _विलम, لسبا
  { {0x98b10024,0xe8d8000a,0xaff60015,0x6fb50021}},	//   lizē_, אוור_, لفوا_, جمعا
  { {0x29040024,0xcf250029,0x2727007c,0x64430030}},	//   ēmai_, شرعي, _tõnu_, úniu
  { {0xed59066c,0xef160139,0xd6e8000a,0x98b1003d}},	//   кои_, рмы_, אַתָ, nizē_
  { {0xd167010f,0xed450036,0x61fb4d45,0xceb90089}},	//   _съби, рноп, _isul, sař_
  { {0x610b0024,0xcb0a002b,0x6e3b39ea,0x66090160}},	//   _vēlē, نيدن_, szub, _šekl
  { {0x8f9a0008,0x92a6002a,0x6a860663,0x8a0612fd}},	//   _סיני, _gałę, илна, азме
  { {0x61ed001c,0xdb24002b,0x3da72124,0xfda70054}},	//   çalh, لوگی, _среб, _сјем
  { {0xdca51328,0x6604156a,0x8b9532b1,0xdb1b0030}},	//   _таки, vvik, _крич, futó
  { {0xa7860029,0xdb1b00dc,0x29040089,0x98b1003d}},	//   لشرو, gutó, ěma_, eizē_
  { {0xb6a60404,0xd6d20031,0x0aea0015,0xdb1b0227}},	//   риал, تقر_, _شرعي_, ysté
  { {0x59760080,0x68fe0091,0x75460138,0x3ead02ad}},	// [b900] _выну, _tapd, аназ, ibet_
  { {0x3ead0064,0xda7b0008,0x66044d46,0xdb11001a}},	//   hbet_, _בנפר, rvik, öföl
  { {0x3cdd005d,0x66e60fd2,0x61fb007c,0x3dcd00da}},	//   _खाने_, _кона, _asul, hrew_
  { {0x78bc0005,0x74130029,0xf3c90086,0x88770008}},	//   larv, توما, ابله_, _כתיב_
  { {0x27f80026,0x4a9b004f,0x71f70058,0x05b9009a}},	//   lwrn_, דינג, لروس_, _مدّت_
  { {0xd0d70036,0x78bc39ff,0x3dcd02e7,0x3f8f0003}},	//   идії_, narv, drew_, _aigu_
  { {0xc917000a,0xf8b3000a,0x42d601c6,0x61fb1f50}},	//   יחסת_, חשו_, _візу, _esul
  { {0x0eea0036,0x256f00dc,0xdb21007c,0x232718fc}},	//   тьки_, vüli_, õtüh, _коси_
  { {0xb5fb0014,0x0caa080e,0x78bc0ed7,0xad260058}},	//   _száz, ктни_, karv, لردو
  { {0x3f8f0cdd,0x92a6002a,0x00e4002b,0x78bc0e1e}},	//   _eigu_, _wałę, _دتری, jarv
  { {0x05770008,0x7bc70007,0x3ead0832,0xdd90002b}},	//   שגים_, šjun, bbet_, _کوت_
  { {0x2d8e003e,0x27f80026,0x3dcd4d47,0x8f760033}},	//   _wife_, dwrn_, brew_, _тузі
  { {0x9da70063,0x257400c0,0xa3b6000b,0x2f3b000a}},	//   _къща_, täll_, चीत_, _בגאד
  { {0x27030092,0x3a2400c0,0x61e24d48,0x98b1003d}},	//   _ổn_, ämpa_, itol, vizē_
  { {0xed570001,0xad1b000a,0x27f80034,0x7ac7006b}},	//   _њој_, _בוגר, gwrn_, _кспе
  { {0x2011006f,0x78bc4887,0x1ab5009b,0x61e24d49}},	//   _ázie_, aarv, _убия, ktol
  { {0xfdf8000b,0xadf8000b,0x58d50054,0xdb020123}},	// [b910] ्टिस_, ्टिन_, _лопт, tslö
  { {0x929d005c,0xe975002b,0x25a94d4a,0xdb020012}},	//   _małe, _دهخد, rpal_, uslö
  { {0x44270b19,0x7588007a,0xdb020123,0xf8b2000a}},	//   ân_, рств_, rslö, _משי_
  { {0x25a900dc,0xc8780064,0x52154d4b,0x291e007c}},	//   ppal_, üğe_, йдет, ötav_
  { {0x877a013a,0x8234002b,0xd5b8006b,0x10a509fe}},	//   _תארי, يرها, _всс_, билн
  { {0x09f8011f,0xe0d80036,0x29034d4c,0xa2d3000b}},	//   שֶׁר_, иві_, ndja_, _डाक्
  { {0x63f40015,0x637804b2,0x29014d4d,0xdb09001a}},	//   _وأفر, sína, _maha_, nsdó
  { {0xaf020063,0x63780227,0x7e99002b,0xa87c000a}},	//   зпъл, pína, دنظر_, כאור
  { {0xf2d200b4,0x929d005c,0x68f500dc,0x7c950086}},	//   _מען_, _całe, kezd, یشگا
  { {0xa0c4003b,0x68f52fb8,0x28dc000b,0x29014d4e}},	//   _ويقو, jezd, _बाधि, _naha_
  { {0xdfa70029,0x853a000a,0xad2400c3,0xfb8a03de}},	//   _ضحاي, רגתי, تريو, лбок_
  { {0x5e950029,0xdce70061,0x4e44002b,0xff530058}},	//   _الإط, ımıy, _ژئوف, _بخط_
  { {0x8e85003b,0x78bc4d4f,0x29014d50,0x0000006a}},	//   _الشه, tarv, _baha_,
  { {0x7d1c00c0,0x387a002a,0xf9910015,0x18a32cb0}},	//   örst, _pzpr_, ِبِ_, зарм
  { {0x29010482,0xf1d1005d,0xad1a000a,0x6d4f0003}},	//   _daha_, _समझन, _תוצר, écau
  { {0x78bc0201,0x7bc14d51,0x2ca2005a,0x0000006a}},	//   sarv, mslu, ěkde_,
  { {0x75d60029,0xe61f0026,0x7bc10bfa,0xfad7000a}},	// [b920] إيطا, _sgôr_, lslu, _הופך_
  { {0x8d29000a,0x236d006f,0xe9e8006f,0x7bc14d52}},	//   נֵּ֤, _akej_, ľúč_, oslu
  { {0x0577003b,0x69c4002c,0x04570029,0x4cba0053}},	//   حملة_, _hvie, ملكة_, רמעג
  { {0x69c400df,0x59af005d,0x32ba0029,0x61e2333f}},	//   _kvie, जीकर, اداة_, ttol
  { {0xd36f0021,0x889a000a,0x61e24d53,0x916200a1}},	//   رهه_, ְבֵי, utol, _hử_
  { {0x7bc10007,0x20d600fd,0x61e24d54,0x348602ed}},	//   kslu, сідс, rtol, _гггг
  { {0x443e01d1,0x2600005d,0x61e2393f,0x289b004c}},	//   _åt_, रिकी_, stol, ניקא
  { {0xc692000a,0x8356002b,0x3f84003d,0x929d002a}},	//   ּא֙_, _اپرا, ummu_, _pałe
  { {0x171b0053,0x8e140036,0x160b000b,0xe717000a}},	//   רופע, ідоц, _हज़ार_, מחקר_
  { {0xccfa0124,0xb5fb0053,0x6aa400e8,0x45fb0008}},	//   ући_, נליכ, _afif, נהיג
  { {0x29010005,0x351b0053,0x3fcb0086,0xb02a0015}},	//   _raha_, אוינ, _مدنی_, _حكام_
  { {0xa3e0000b,0x2d8501de,0x29014d55,0x5477004f}},	//   _दमन_, amle_, _saha_, מגיע_
  { {0x4f65003b,0xf2d300b2,0x8aa40010,0x6d5d0003}},	//   _بالف, הער_, ярэд, ésac
  { {0x69c40007,0xcdf7000a,0xd257000a,0xad26002b}},	//   _dvie, _למדי_, משכה_, _درصو
  { {0x3cdd0372,0x7c93003b,0x5d47000a,0xfc64002b}},	//   _खाते_, _عشوا, _לָהּ_, _بخشی
  { {0xfc57000a,0x2901002a,0xdb090052,0x0000006a}},	//   _לבוש_, _waha_, rsdó,
  { {0x29010020,0x69c00077,0x46580015,0xd4b90054}},	// [b930] _taha_, ámet, مؤكد_, илац_
  { {0x96340010,0xdb1b1f4f,0x6f020395,0x8d18000a}},	//   чнуц, istí, _laoc, סֵּפ
  { {0x69c40a7e,0x69c0003d,0xa8a40033,0xf3f9091b}},	//   _zvie, šmet, _эрык, рнеш_
  { {0xd25100e5,0x6f020535,0xc275116f,0x2d85007f}},	//   ونا_, _naoc, олеј, zmle_
  { {0x9aec000a,0x6d4a1003,0x69da002a,0xe4a701ca}},	//   רַבִ, _omfa, ąteg, _грбо
  { {0x7bc100f2,0xdb1b4d56,0x23bb0015,0xca7c004c}},	//   yslu, nstâ, _مدرب_, אנדט
  { {0x69a0005d,0x91620092,0x272e002e,0x7aed01d7}},	//   _गंभी, _xử_, _sýni_, _obat
  { {0x249b00df,0xdb1b002e,0xf83801d8,0x20070796}},	//   šymą_, fstí, מנות_, rvni_
  { {0xcee80015,0x200c2fd9,0x6ec40058,0x0000006a}},	//   صرين_, _erdi_, ستيق,
  { {0x7bc1016b,0x11440015,0x2d91078e,0xdb02013f}},	//   tslu, _فَقُ, öze_, dplá
  { {0xc4d20008,0x01640029,0x51840033,0x98b10091}},	//   וגי_, _عُمَ, _хута, lizė_
  { {0xf8a9013a,0x7bc14d57,0x6008000a,0x613d0144}},	//   _יש_, rslu, _לִנְ, _bèlg
  { {0x916200a7,0x2bc5005d,0x1eea002b,0xaa43004a}},	//   _sử_, _विका, _خونی_, деял
  { {0x7aed0020,0xfc310029,0x3ebf4d58,0xdcf8003d}},	//   _ebat, _يحث_, laut_, _divē
  { {0x2d9f038d,0x273c002d,0x07a30010,0xd7060c71}},	//   lque_, _líne_, дасн, озви
  { {0x256f0c19,0xeafa00c3,0x7d034d59,0x3ebf4d5a}},	//   zült_, _ضربت_, _hans, naut_
  { {0xa5260191,0x69c4002c,0xb5a90029,0xdb1b001c}},	// [b940] омад, _uvie, مالك_, bstâ
  { {0x29040048,0x2bed005d,0x91620092,0x2d9f4d5b}},	//   ēmas_, _जहां_, _tử_, ique_
  { {0x0d3a0053,0x2497002b,0xb8e0000b,0x256f0030}},	//   סגעב, زنند_, ुण_, vült_
  { {0x4c6c0053,0x386d00b8,0xdcb6000b,0x7d034d5c}},	//   נדאַ, ßere_, _आज्ञ, _lans
  { {0x386d0061,0xdb210030,0x61f60015,0x637804b2}},	//   ğere_, áték, تساء, síno
  { {0x257400f2,0x320d0012,0x14d8000a,0x26c04d5d}},	//   käli_, _drey_, _לַֽמ, laio_
  { {0xdfd0003b,0x256f0014,0xa2d60029,0x3ebf0152}},	//   رية_, rült_, _ويست, faut_
  { {0x7d03049c,0xcf260029,0x256f00dc,0x74130018}},	//   _aans, ترتي, sült_, _توفا
  { {0x7d030253,0x320d437f,0x2600000b,0x93250015}},	//   _bans, _grey_, रिटी_, _عرفن
  { {0xbebd0091,0x200c00bc,0x7d034d5e,0x7aed01e0}},	//   ukūr, _trdi_, _cans, _sbat
  { {0xc49b0008,0x3ebf00b8,0xd12f0015,0x635c4d5f}},	//   ישית, baut_, _جمل_, nčno
  { {0x2011006f,0x635c0085,0x929d002a,0x3ebf4d60}},	//   _ázia_, ično, _kała, caut_
  { {0xed5a4d61,0xde0302c4,0x2d9f4d62,0x7d034d63}},	//   _код_, _опци, cque_, _fans
  { {0x6d4a1611,0xc9870015,0x5cf60033,0x7d0338cd}},	//   _umfa, تشجي, _фяду, _gans
  { {0x28dc005d,0xdb020f7b,0xdb1b007c,0x19580033}},	//   _बारि, splá, dutö, цары_
  { {0x4c3b013a,0x7aed00d9,0x291e0123,0xdc3b000a}},	//   _כתוב, _ubat, ötar_, _כעור
  { {0x9ae80008,0x7d030064,0xd49b1791,0xdb1b0144}},	// [b950] _וַתִ, _yans, аре_, mstà
  { {0xa4d4005e,0x6d5a4d64,0xdb1b007c,0xf9930040}},	//   дофі, nnta, gutö, _تبع_
  { {0xa2f5166e,0x78fa0008,0x6908000a,0x273c0125}},	//   зпеч, _הפתו, _וּרְ, _síne_
  { {0x8c1b0008,0x320d003e,0xc2c50015,0x6d5a0012}},	//   יובי, _prey_, سيتي, hnta
  { {0x10a50004,0xe4d70015,0x471a000a,0xb867002b}},	//   пилн, _وتسب, _הורג, _داکو
  { {0x82340021,0x7bc70030,0xe1880058,0xdb1b005a}},	//   برما, ájuk, يئون_, vrtý
  { {0x7d034d65,0x31560015,0x8fa20248,0xc95405bd}},	//   _rans, ثلوج_, наще, ומס_
  { {0xf412000a,0x25740604,0x2ca90046,0x6d5a3006}},	//   _אפל_, väli_, _řad_, enta
  { {0x7d034d66,0x998c002a,0x02450015,0x30e700fd}},	//   _pans, ądź_, _عَطَ, _міжб
  { {0x559c00b2,0x1c45006d,0x3ebf0003,0xc616000a}},	//   בסזײ, зном, saut_, פחתי_
  { {0xc4d20053,0x929d005c,0x2d9f0493,0xa0380015}},	//   עגט_, _zała, sque_, _وأمر_
  { {0xf1cf005d,0xa0880008,0xac380010,0x2d990e57}},	//   _हटान, _וְנִ, ючых_, íses_
  { {0x5e9a0008,0x7d034d67,0x82d6000a,0x0000006a}},	//   _הבנק, _tans, הורג_,
  { {0x7d030293,0x5bc50015,0x8c450ae6,0xdb1902dc}},	//   _uans, _فقتل, _неле, _avvä
  { {0x7b0500f2,0x9bc90015,0x3156004c,0x2bc5000b}},	//   öttä, _اوبك_, לישן_, _विटा
  { {0xc6920015,0xdb3a002b,0x030b000b,0xac160054}},	//   ِّر_, _دستش_, _सोलह_, _хоћу_
  { {0x26c004ed,0x8b3b0008,0xdce10045,0xb9c60015}},	// [b960] raio_, _לתקצ, colă, _عقدي
  { {0x69c64d68,0x26c011f0,0x649a4d69,0x0000006a}},	//   mske, saio_, стар_,
  { {0x389b00b2,0xf8b3000a,0x78fb000a,0xa3b6000b}},	//   _ליינ, _אשת_, _פלטפ, चीं_
  { {0x63780089,0x929d005c,0x69c600f2,0xc8dc005d}},	//   mínk, _pała, oske, _बाँट
  { {0x2d9d020a,0x6d5a4d6a,0xdb0200cb,0xdb1b4d6b}},	//   _nuwe_, ynta, pplæ, putö
  { {0x9f5e002c,0x98a40007,0xdb1b01bb,0x867b000a}},	//   _isté_, ėmė_, istá, _לרכו
  { {0xb4ca000b,0x80a30015,0x78fb000a,0x653b004c}},	//   ोली_, رمين, מפסו, _פעלד
  { {0xe80d000b,0x67360091,0xdb020012,0x67244d6c}},	//   हिता_, nkyj, nplä, njij
  { {0x7d6a0036,0xdfd00086,0x69c64d6d,0xe731000a}},	//   йшов_, ريک_, jske, דֵי_
  { {0x613d0003,0x423b004c,0x3f9a0030,0xd23b000a}},	//   _pèle, _הײמא, ípus_, _הגמל
  { {0x44444d6e,0xf1d2000b,0x4c940004,0x69c64d6f}},	//   nz_, _सिडन, ќинс, eske
  { {0xaf050036,0x44444d70,0x547b000a,0x9057000a}},	//   _очік, iz_, מטיו, _צבאו_
  { {0x6e93003b,0x3e850152,0xc33300f3,0xa327000a}},	//   _كلما, rêté_, גור_, לַךְ_
  { {0x2bc5014e,0xfbcf0086,0x3f9e4d71,0x6c540054}},	//   _विचा, ختی_, _kutu_, _оклу
  { {0x5bc30015,0x4ccb000a,0xa177004c,0xdb1b4d72}},	//   _كقول, _הֶחֱ, פעלד_, astá
  { {0x44444d73,0x6b844d74,0x6c5b000a,0x57790033}},	//   dz_, _ghig, _לדוח, ібаў_
  { {0x7bda0458,0x69da002a,0x69c60030,0x44443f26}},	// [b970] lutu, ątec, cske, ez_
  { {0x272e002e,0xd49b000d,0x2a58000a,0x19bc000a}},	//   _sýnt_, сра_, _מבחן_, _המזב
  { {0x25f9005d,0xe57004c9,0x9f5e26f1,0xdc9b039e}},	//   _उनकी_, اطق_, _esté_, ציאל
  { {0xa2550086,0x42550040,0x799f00aa,0x628001d3}},	//   وپاش, ونار, _kuqw, _bzmo
  { {0x7bda0020,0xa3cf000b,0xf60b0015,0x9394012c}},	//   hutu, _शिव_, _اتجه_, رجما
  { {0x7bda4d75,0xe1f80033,0x212a002b,0x2d9d08cf}},	//   kutu, ягі_, يينی_, _ruwe_
  { {0x44440050,0x7bda0020,0xdb1b002e,0x272e001a}},	//   cz_, jutu, mstæ, _týnt_
  { {0x7bda014b,0x80140033,0xee3905a7,0xdb1b4d76}},	//   dutu, эфіц, жни_, ystá
  { {0x6b840034,0x63780030,0x0d85052b,0x81d403ae}},	//   _rhig, zínk, млин, _потх
  { {0x273c002e,0xdbc90010,0x69c61ea8,0xd2500015}},	//   _mína_, огод_, vske, _إنْ_
  { {0x273c002e,0x7bda0020,0x660d007c,0x929d002a}},	//   _lína_, gutu, hvak, _jało
  { {0x60c3376d,0x2b160063,0x929d005c,0xd368000a}},	//   lanm, фьор, _mało, ִים֙_
  { {0xba230036,0x25fd005d,0x8e7404c2,0x44440c0a}},	//   вдяк, _रैली_, _пушч, zz_
  { {0xdd940010,0x7bda4d77,0x6d9a000a,0x69c60362}},	//   _зачы, butu, _ובספ, rske
  { {0x660d0111,0x6d41002d,0x39440007,0x66e6313e}},	//   evak, mhla, ėms_, мова
  { {0x257400b8,0x44440007,0xbb860015,0x3bba000a}},	//   hält_, vz_, _تلبي, _ומקד
  { {0xa5f7000d,0xcb13000a,0xfb87002b,0xdb1b001a}},	// [b980] меѓу_, _ילה_, _تدوی, fstæ
  { {0x637803af,0x44444d78,0xa9e50015,0xd876002b}},	//   míni, tz_, _أثين, _يادب
  { {0xd91b0632,0xf9930008,0x929d005c,0xdb0200c0}},	//   _וויל, _שרת_, _cało, pplä
  { {0x44444d79,0x68fc4d7a,0xc7b3000a,0x929d0535}},	//   rz_, lerd, _שבר_, _dało
  { {0x257401d1,0x444410fe,0x6f090026,0x6d410375}},	//   fält_, sz_, ddec, khla
  { {0xf6530008,0x7bda0064,0x3f9e154e,0xe009000b}},	//   _יצר_, yutu, _putu_, विंद_
  { {0x2b0e014e,0x68fc020a,0xd0100225,0x6378002d}},	//   ियाँ_, ierd, الب_, híni
  { {0x7bda0209,0x68fc4d7b,0x7d080416,0x0000006a}},	//   vutu, herd, wdds,
  { {0x10a615ed,0x929d005c,0xb0fa0015,0x6e180015}},	//   _жизн, _zało, _وفرض_, سيدس_
  { {0xe0d70124,0x6d414d7c,0x6f092062,0x81f70015}},	//   _ову_, ghla, adec, _تفكر_
  { {0x718b0008,0x7bda0e95,0xb09b000a,0xa4fb000a}},	//   _וְאַ, uutu, _ויבר, חליט
  { {0x2cb10064,0x68fc0159,0x9a870033,0x7c440085}},	//   ızda_, eerd, дугл, _đurđ
  { {0x7bda0005,0xd2b7000a,0x6d410125,0x68fc4d7d}},	//   sutu, ולכת_, bhla, ferd
  { {0x6d411d10,0xe1ee0010,0xf7730086,0x7bda4d7e}},	//   chla, угi_, چار_, putu
  { {0x212c002f,0x5c060063,0x273c002e,0xf7730115}},	//   _modh_, _цяла, _sína_, نار_
  { {0x60c30064,0x68fc0034,0x660d4d7f,0x2d8c1d5a}},	//   zanm, aerd, tvak, lmde_
  { {0x35f50010,0x6378016e,0x660d008c,0x60c34d80}},	// [b990] эпар, cíni, uvak, yanm
  { {0x69dd4d81,0x5d78000a,0x15e1000b,0x660d4d82}},	//   muse, פָּנ, गंबर_, rvak
  { {0x69dd0005,0xf99200a3,0xa2d50015,0xdb1b4d83}},	//   luse, _תרי_, فيات, rstæ
  { {0xdb1b002e,0x6d410057,0x212c0125,0x69dd4d84}},	//   sstæ, zhla, _aodh_, ouse
  { {0x69dd0005,0xfe080023,0x92940010,0xa294017f}},	//   nuse, _nữ_, вацц, ваці
  { {0xdb1b04d4,0x55ba015b,0x3a24008c,0xca38000a}},	//   lstä, _ממשו, ämpi_, ונדה_
  { {0x6f0900b8,0x60c34d85,0x7afd4d86,0x7fd50033}},	//   tdec, ranm, kest, хілі
  { {0xdb1b2e6f,0x60c30134,0x7afd4d87,0x2d8c0234}},	//   nstä, sanm, jest, emde_
  { {0x9f47002c,0x60c30061,0xdb1b0a64,0x69dd0fd8}},	//   ntné_, panm, istä, juse
  { {0xfe080023,0x69dd4d88,0x50f40004,0x0c25008d}},	//   _dữ_, duse, _изут, емон
  { {0x116a0086,0xdb1b00c0,0x69dd0152,0x6d41002e}},	//   _علمی_, kstä, euse, rhla
  { {0xf41200b2,0x9f47002c,0x69dd0493,0x9f050015}},	//   אפט_, ktné_, fuse, _سوتو
  { {0x69dd0005,0x8de40029,0x60c14d89,0x386d0012}},	//   guse, _لكنه, _kelm, ßern_
  { {0xf1b2013a,0x61eb0012,0x3f8d0045,0xfce5012e}},	//   רסם_, itgl, lmeu_, _чоко
  { {0x9989002a,0xdb1b0012,0x7afd4d8a,0x60c14d8b}},	//   _brał_, fstä, best, _melm
  { {0x613408e0,0x05aa02c5,0x7afd4d8c,0x49ca006b}},	//   _vàli, звай_, cest, _елин_
  { {0xcf920632,0xdce80024,0xceb2039e,0x958605c4}},	// [b9a0] רטן_, lodā, טין_, елае
  { {0xec090023,0x6d86001a,0x85060015,0xe5770382}},	//   _kế_, rðag, عوان, езу_
  { {0xccf20008,0x2b4000bd,0xe3b20029,0xdb1b0012}},	//   רכב_, _klic_, ارئ_, bstä
  { {0xb376002b,0x2a3a000a,0x9989002a,0x44260085}},	//   رداش, ּעַמ, _grał_, ćo_
  { {0x2d87018b,0x635c00bd,0x798e003f,0x20050509}},	//   _ohne_, nčni, ombw, _asli_
  { {0x7afd0050,0xe1370010,0x8006006b,0xdb1b1156}},	//   zest, нзіі_, ечие, mstå
  { {0x91620023,0x7afd003c,0x224600dc,0x21770010}},	//   _cứ_, yest, szok_, эйшы_
  { {0x60c10005,0x80030080,0x77f70008,0x1013002b}},	//   _eelm, учше, תמקד_, ابود
  { {0x916200a7,0xe3570008,0x60c10db2,0xa09a0015}},	//   _từ_, _נשמח_, _felm, _فضاء_
  { {0x69dd0005,0x60c10064,0x9f5e002c,0x2d984d8d}},	//   vuse, _gelm, _istí_, öre_
  { {0x3f86003e,0xdb1b2438,0xdfcf00e6,0x2d8c0159}},	//   _thou_, irtö, _هيل_, rmde_
  { {0x3f5304f9,0x69dd4d8e,0x7afd4d8f,0xc334000a}},	//   nţul_, tuse, uest, דוֹ_
  { {0xdb1b00c0,0xd138002a,0x9b440015,0xdb24001a}},	//   vstä, _ciąg_, انُو, _ósýn
  { {0x7afd3b28,0x69dd3664,0xe80d000b,0x8d27004a}},	//   sest, ruse, हिला_, _почв_
  { {0x69dd0005,0xd90f0086,0xd7f812d2,0x6378002e}},	//   suse, لیک_, нут_, línu
  { {0x6c7b000a,0x2b400026,0x5c7b000a,0xbc7b000a}},	//   _מאופ, _glic_, _מאוה, _מנות
  { {0xa5f80036,0xdb1b4d90,0x80e0000b,0xbef7000a}},	// [b9b0] нету_, rstä, नलाइ, עצמו_
  { {0xfaff00dd,0x9f47002c,0xdb1b04d4,0x1be4000b}},	//   leë_, rtné_, sstä, _कमाल_
  { {0x59960008,0x9f470264,0x9cd7000a,0xec090016}},	//   _שכתב_, stné_, תובה_, _xế_
  { {0xd6db1e88,0x92590080,0x2b1a005d,0xd324034e}},	//   _это_, мает_, धाएँ_, льчи
  { {0xe28e0010,0x1a9c0053,0x5274045f,0x39840123}},	//   ра_, פיגע, лушу, lösa_
  { {0xd184042b,0x7d0a0049,0xe0d3002b,0x98b40085}},	//   глій, _nafs, ازش_, čeći_
  { {0xe8140372,0x60c10089,0xb814005d,0xc9180008}},	//   डिया_, _velm, डियम_, תחות_
  { {0x27e700c0,0xa3b80015,0x43940888,0xbe39005e}},	//   _ännu_, _سافر_, _басс, дчої_
  { {0x5f760029,0x3f8d0251,0x1ea8002b,0xd9e30065}},	//   خميس_, rmeu_, رايي_, कूमत_
  { {0x29cd002c,0x80a40029,0xf1c80029,0x03d5000a}},	//   dľa_, _ممكن, _أولى_, ֣וֹם_
  { {0x0c220010,0xbb4605e6,0xcb6a4d91,0xdde8002b}},	//   амэн, венк, дане_, وریه_
  { {0x3cdd005d,0xe9a60010,0xec090016,0x0000006a}},	//   _खाके_, камп, _vế_,
  { {0x8f360008,0x99f5005e,0x61340144,0x26c202d8}},	//   _שאנו_, лярі, _vàlv, _reko_
  { {0x4999005f,0xec090023,0x23d1014e,0x7d0a002e}},	//   ется_, _tế_, _हिंद, _gafs
  { {0x929d005c,0x8c4203ad,0x4fac000a,0x6aad0034}},	//   _całk, _веще, ּׁמְ, _ffaf
  { {0x41d2005d,0xdb1b01a7,0x2eff0003,0x2b404d92}},	//   _सिलस, tstå, neuf_, _ulic_
  { {0x96760010,0x64a60138,0x0000006a,0x0000006a}},	// [b9c0] тыві, ваза,   ,
  { {0x045a00c3,0xdb1b39bc,0x98e90065,0x851c0065}},	//   وجات_, rstå, _जायज़_, नाइट_
  { {0xd7ca03c4,0xd4f50010,0x232a000d,0x69650015}},	//   _توجه_, ыяты, можи_, _حديق
  { {0xdb1b0b56,0x9f4e0061,0x29070125,0xa2d30369}},	//   pstå, ünür_, _ónar_, ليمت
  { {0x6b46002d,0xe297023e,0xcb1300a3,0x21f40015}},	//   _tógf, вац_, ילא_, اكتس
  { {0xd12f0029,0xdfd00002,0x39580da5,0xca37000a}},	//   يمن_, ميت_, nirs_, כננה_
  { {0x7af60069,0x8006029f,0x7d0a4d93,0x30a500ce}},	//   _obyt, тчле, _rafs, урів
  { {0x831a0029,0x35a7000b,0xc7d7004f,0x5f190065}},	//   _تقرر_, _कूड़, דוקי_, भाग्_
  { {0x52d7000a,0x64670045,0x71fa0015,0x61340144}},	//   _שומע_, ăriţ, _ترأس_, _bàlt
  { {0x91620023,0xfaff00aa,0xf5e20033,0x20561079}},	//   _dữ_, weë_, упiў_, _итер
  { {0xa515004c,0xfaff00aa,0x6378006f,0x2eff19ad}},	//   אַרג_, teë_, sínu, beuf_
  { {0xee3a0001,0x00570008,0x2055005e,0x98a70061}},	//   _оне_, _בשבת_, _стур, _ını_
  { {0x7d0a28fa,0xda780033,0x672f0085,0x637801c0}},	//   _tafs, вяр_, _rocj, líns
  { {0x672f005c,0x6f000064,0x8c53002b,0x6604002a}},	//   _socj, lemc, ائیا, dwik
  { {0x3cfb0008,0xd7f50033,0xfaff00aa,0x57a405f8}},	//   _חלונ, ызвы, peë_, ишта
  { {0x6aad003f,0x7b140063,0xd6d83e7f,0x2d9c00da}},	//   _ufaf, _вдъх, кту_, _hive_
  { {0xf794008f,0xa6340036,0x69c0016e,0x6f00002a}},	// [b9d0] ратэ, анті, âmet, iemc
  { {0xf8b70372,0x7af61837,0x99800061,0xdb0e0030}},	//   _अभिय, _zbyt, _iriş_, ökös
  { {0xc7ab0029,0x7afa00dc,0xd8790015,0x2b590125}},	//   _تدخل_, őtte, _سمحت_, oisc_
  { {0x2d9c4d94,0x2011006f,0x73e4005e,0x6f002398}},	//   _live_, _ázii_, роїз, jemc
  { {0xd1790010,0x66f600a3,0xccf80046,0x31a40015}},	//   нскі_, _גמרא_, vněn_, لمنف
  { {0xc24401f3,0x6441007c,0x0000006a,0x0000006a}},	//   шнік, _ülio,   ,
  { {0x7ff50074,0xf99401ac,0x6ff50015,0xdb0200cb}},	//   استا, ברס_, استط, pplø
  { {0xa2950010,0xaff60029,0x6458002a,0x389c000a}},	//   _бабі, افيا_, ócił, ויונ
  { {0x22940142,0x80a6000b,0x2018001a,0x7bda4d95}},	//   _витя, _क़्वे, _árin_, ertu
  { {0x9f5e08e0,0x3afe0016,0xfc2906b3,0xbd450040}},	//   _està_, _ắp_, ежок_, اندي
  { {0xccf80046,0x2d9c2ac8,0x9f470046,0xd011009a}},	//   mněl_, _dive_, ltní_, _دلا_
  { {0xa3f6000a,0x27350123,0xab2a4d96,0x0000006a}},	//   נמרק_, _måns_, хома_,
  { {0x9f4702d5,0x2d9c003e,0xa1420024,0xdd8e002b}},	//   ntní_, _five_, _šķie, توی_
  { {0x2b59002d,0x98760001,0x2d9c0838,0xcc350021}},	//   aisc_, губљ, _give_, _مربع
  { {0x7d014d97,0x4c040015,0x6d08000a,0x18670719}},	//   mels, _نظيف, _יִקַ, гари_
  { {0x290c010b,0x9f470089,0x8b950010,0x660400f6}},	//   žda_, ktní_, _крыч, twik
  { {0xb5a90015,0x056612ae,0x9aeb000a,0x7d010079}},	// [b9e0] نالك_, гван, _אַיִ, oels
  { {0xe3b80061,0xba9b0643,0x2d9c0003,0x273521f0}},	//   _çık_, _אספי, _xive_, _sånt_
  { {0x0d3a0053,0x41c6000b,0xa93b004c,0x3c89000a}},	//   עגעב, रीनस, _נײטי, תָּ֑
  { {0x71a60010,0xb7db00a3,0xf26a05b3,0xdb040123}},	//   гадз, _אקטי, ниел_, _utnä
  { {0x599a0008,0x4b4d0053,0xdcf80046,0x7d013e55}},	//   ֲשֶׁ, וגאַ, _chvě, kels
  { {0xc5ff0024,0x7d011639,0x82370033,0xd1300015}},	//   ģētu_, jels, ызіс_, تمت_
  { {0x656b00dc,0xb97b0053,0x99820007,0xd0100015}},	//   éghe, ענצי, lykų_, زلة_
  { {0x7d01007c,0x57fb015b,0x2dd413d9,0x43430033}},	//   eels, תלקו, ажир, _лесв
  { {0xdb1b0f47,0x6da30004,0x7d014d98,0xdd9000c3}},	//   mstø, биња, fels, يوب_
  { {0xbdf700a2,0x61e20007,0x7d0102cd,0xdb1b0293}},	//   اريا_, muol, gels, lstø
  { {0x9f5e06d4,0x51930029,0x7ee60029,0x0577000a}},	//   _está_, _اللذ, _مكان, רגים_
  { {0x543b004c,0xe9f90016,0xdb1b01de,0xbea6062f}},	//   געטא, _ngả_, nstø, _садк
  { {0xd3570008,0x61e20a6f,0x2d9c016e,0x5a440033}},	//   ריכי_, nuol, _tive_, бэра
  { {0xdd9000a2,0x273c0016,0xdc55002b,0xdd8f0040}},	//   _بوت_, _hính_, اریک, _فون_
  { {0xa2c7005d,0x273c0092,0x6d5a3311,0xe895004a}},	//   ारम्, _kính_, mita, равь
  { {0x8c1b000a,0x8b67002b,0x6d5a4d99,0x63780030}},	//   _טווי, _حاتم, lita, zínr
  { {0x6d4800f2,0xc4db0001,0x6d5a0f7a,0xe667005e}},	// [b9f0] ohda, еђе_, oita, утво
  { {0x273c0092,0x6d5a0b8b,0xf8c6000b,0x94d50a31}},	//   _lính_, nita, वरणय, рожц
  { {0xe97c0053,0xb97c000a,0x61fb4d9a,0x6d5a0bb5}},	//   _אנזש, _אנזי, _spul, iita
  { {0x6d5a2e59,0xd2150001,0xaab5000b,0x6441007c}},	//   hita, имећ, ंडिक, _ülim
  { {0x90c5008f,0x20c90015,0xeb98004c,0x6d5a18bb}},	//   абле, نبغي_, אדאר_, kita
  { {0x69cf002d,0x6d5a0aa5,0x672d3c11,0xb4f9004c}},	//   isce, jita, ljaj, _בפֿי
  { {0x9f470089,0x7d0117ec,0xdb040003,0x33950033}},	//   stní_, vels, _funè, _вавё
  { {0x6d5a0084,0x7d01003f,0x70520015,0x672d4d9b}},	//   eita, wels, غنيا, njaj
  { {0x3f830048,0x32552a7b,0x90e70015,0x69cf002a}},	//   ēju_, _твар, _مسان, jsce
  { {0x6d5a0ce4,0xdd8e0015,0x867c004c,0xdfd50033}},	//   gita, ووي_, ערזו, _вожы
  { {0x29034d9c,0xca29000a,0x7d01313a,0xdb24002b}},	//   deja_, _קם_, rels, مودی
  { {0x6b8d000c,0xbd450086,0xe1e70029,0x6d86001a}},	//   _chag, انگي, يس_, rðaa
  { {0x6d5a162d,0x672d4d9d,0x8b67005e,0xc9b30015}},	//   bita, djaj, рияв_, يمَة
  { {0x186a0036,0x29030209,0xfce20004,0x68461006}},	//   ваги_, geja_, _дошо, анга
  { {0x5c790053,0x63a700bd,0x975603ae,0x69dd4d9e}},	//   _באַה, _nujn, атаљ, arse
  { {0xf863005e,0xb6a3005e,0xb75900ce,0x0000006a}},	//   івто, житл, гшує_,
  { {0x4b7b00b2,0x6d86002e,0x7b08003d,0x929d002a}},	// [ba00] _באקו, iðan, āstī, _kału
  { {0x14c80086,0x443a4d9f,0x75d30015,0xf53f146d}},	//   اهای_, typ_, زيما, _står_
  { {0x35da005d,0x05770029,0xd8db0008,0x4ada000b}},	//   यूज़, جملة_, _בקיר, _भयाव
  { {0x6d5a3860,0x69c4005c,0x1bf60053,0x2bf60053}},	//   zita, _kwie, יצער_, ימען_
  { {0xdb1b02e9,0x7c3a002a,0x22400030,0x64a64da0}},	//   rstø, zytr, áik_, _вага
  { {0x41530036,0xf1c20007,0x90c30054,0x61e24da1}},	//   овіс, višą_, обље, ruol
  { {0x4034008f,0xa0070029,0xcae6000b,0x6d5a1851}},	//   сейс, لقول_, _कांड_, vita
  { {0x61e2022d,0x3ea2003c,0x69c4005c,0xc7b30008}},	//   puol, økt_, _owie, חבה_
  { {0x6b8d0176,0x386d01e2,0xe2970036,0x5d540063}},	//   _rhag, ğeri_, _ват_, йкит
  { {0xc5f30008,0x2366016f,0xf531000a,0x6b8d4da2}},	//   קדת_, lnoj_, ִ֥י_, _shag
  { {0x273c0023,0xa3c9000b,0x672d002a,0xb53b000a}},	//   _tính_, लीप_, yjaj, דגיש
  { {0xdb020084,0x6d5a08aa,0x2911002a,0x7c3a1807}},	//   pplý, sita, wdza_, rytr
  { {0x29034da3,0x69dd4da4,0x7db40015,0x6d5a1bee}},	//   teja_, urse, _امتص, pita
  { {0xf9890015,0x5dfb000a,0x69c4002a,0x63780030}},	//   انسي_, _ספונ, _dwie, zínp
  { {0x6b8d002d,0x60c84da5,0x18980015,0x29111835}},	//   _thag, _medm, لضفة_, rdza_
  { {0xdc9b009d,0x29034da6,0x2366016f,0x63a7016f}},	//   _ביול, seja_, jnoj_, _rujn
  { {0x2366016f,0x672d10ca,0xa3c9021e,0x9f47006f}},	// [ba10] dnoj_, rjaj, लीन_, ntná_
  { {0x64410005,0x4a7c0008,0xa3bb00a2,0xb8590015}},	//   _ülik, _ברחב, ناصر_, _ملخص_
  { {0x69c42029,0xf4590015,0x66160091,0x23e7005e}},	//   _zwie, دلاع_, avyk, різв
  { {0xc7b20008,0x92950010,0x66160107,0xd347002b}},	//   _מבט_, баец, bvyk, جیره_
  { {0x62800176,0xe9df002d,0x6d584da7,0x83160058}},	//   _cymo, nrú_, _omva, صقور_
  { {0x2bac0089,0x8636000a,0x628023bd,0x7ff50015}},	//   _něco_, _הרשב_, _dymo, مسبا
  { {0xe9df002f,0x7aed4da8,0x10154da9,0x23660085}},	//   hrú_, _ocat, إبتد, bnoj_
  { {0x75350014,0x929d002a,0xdb040030,0x7bd50030}},	//   _hozz, _bałt, _tuné, ázum
  { {0x6d860084,0x62800026,0x66ef000b,0xf1c6000b}},	//   rðan, _gymo, _छानक_, रीदन
  { {0xcc350029,0x1d090001,0x415403fc,0xd1b3002b}},	//   مرجع, ћени_, _двус, _هیچک
  { {0xcf27002b,0xe9df0077,0xeb9a0de9,0x66160247}},	//   _پراي, erú_, лио_, zvyk
  { {0x1b4a0054,0xa3c9000b,0x0000006a,0x0000006a}},	//   узми_, लीय_,   ,
  { {0x5f740029,0x8f9a0008,0x3ebf0509,0xe9df0125}},	//   _بالر, _עיני, mbut_, grú_
  { {0x4e7a00b2,0xdd940010,0x9f5e00f2,0x127a004c}},	//   _גאנצ, _дачы, _estä_, ראשע
  { {0x7aed00f2,0xa78600e6,0x6441007c,0x0d54002b}},	//   ältö, مشرو, _ülih, _بخند
  { {0x69c4005c,0x7aed002d,0x4c3a000a,0xceb2000a}},	//   _twie, _gcat, _תתקב, ִיב_
  { {0xe9df002f,0x2366016f,0x69c4005c,0xd6270bb9}},	// [ba20] crú_, vnoj_, _uwie, боте_
  { {0x6d414daa,0x99860086,0x86750010,0xf5570015}},	//   nkla, _دلخو, цысц, ملقب_
  { {0x2366016f,0xa937000a,0xb937000a,0x60c8185e}},	//   tnoj_, _הטיה_, _הניו_, _redm
  { {0xd3790036,0x2b21005d,0xfdf9005d,0x6d86002e}},	//   ачі_, याएँ_, ्बास_, eðal
  { {0xa2aa014e,0x2366016f,0x26c029c1,0x4b7b000a}},	//   टशब्, rnoj_, mbio_, נטנג
  { {0x2366016f,0x26c00007,0x1a9b004c,0x3ebf1e0b}},	//   snoj_, lbio_, אינע, ebut_
  { {0x63a000e8,0x62804dab,0x23660085,0x26c00085}},	//   _timn, _wymo, pnoj_, obio_
  { {0x62800026,0x543b0053,0x04570015,0xbdb4009c}},	//   _tymo, _געלא, _طلقة_, обиј
  { {0xc2460001,0xad260015,0xb355009a,0x6da300af}},	//   _унак, مردو, _بینا_, пиња
  { {0xf1bf0089,0x7aed1ca3,0x9f47006f,0xe16600c3}},	//   ášen_, _scat, rtná_, _ادري
  { {0xdefa005f,0x3086003b,0x929d005c,0x9f470264}},	//   _был_, _الاف, _fałs, stná_
  { {0x6d414dac,0xe9df001a,0x140b000a,0x395a4dad}},	//   akla, trú_, נִיּ, _amps_
  { {0x44270023,0x6e96003b,0x09e40010,0x5e960015}},	//   ̣n_, _الشا, поўн, _الشط
  { {0x6d414dae,0xd0060115,0x273c002e,0xd90f002b}},	//   ckla, ول_, _mínu_, ریج_
  { {0x273c002e,0xc051000a,0x4fd8000a,0xa8994da0}},	//   _línu_, ֵ֖ל_, יַּד, ркву_
  { {0x6b46002d,0xf62b005e,0xdb1b0012,0x6c830058}},	//   _tóga, лізи_, nstü, _عليم
  { {0x54a700e6,0xe6880015,0x75353d61,0xa535249a}},	// [ba30] محاف, منفى_, _pozz, онач
  { {0x85050029,0x3cb80008,0x98c709ef,0xf7b9002b}},	//   توطن, שֶּׁ, _усил, _نگرش_
  { {0x63550036,0x26c004ed,0x293801ac,0x7588004a}},	//   овжу, bbio_, _לאזן_, сств_
  { {0xd8b80074,0x8c1b000a,0xdc8b000a,0xdb1b001a}},	//   _پدیا_, טובי, רְמָ, mstó
  { {0xdb1b001a,0xd5b80054,0x65950fd5,0x6d414daf}},	//   lstó, _гсс_, _маму, ykla
  { {0xa5bb0084,0x661d25b6,0x2b494db0,0xdb1b002a}},	//   _próf, _irsk, _llac_, ostó
  { {0x6d860084,0x7fd501f3,0x493c000a,0x661d0085}},	//   rðal, цілі, רגוו, _hrsk
  { {0x1dd4005d,0x63b8002c,0xfe45000d,0xd00e0015}},	//   _दिखत, ívne, жнио, ئلي_
  { {0xf1e0005d,0x82370086,0xee3604ab,0x161c000b}},	//   _नियन, _ارزا, жны_, नियर_
  { {0xbc190010,0xdb1b4db1,0x569c000a,0xec79004a}},	//   аімі_, kstó, ניזצ, ипп_
  { {0x25a30079,0xdce80046,0x26c00034,0xdb1b0012}},	//   _mijl_, lodě, ybio_, bstü
  { {0xa3e1014e,0xf1e0000b,0x1df90033,0x26cb4db2}},	//   _दिन_, _निमन, _веды_, _neco_
  { {0x6d414db3,0x5f74006e,0x937a004f,0x5e5800ce}},	//   pkla, _عامر, שטרת, _лиця_
  { {0x07a64db4,0xac74002b,0x8c454db5,0xf1b2004f}},	//   жавн, _کاهش, _меле, וסך_
  { {0xe73a1a4d,0x7ce8000a,0x7b760015,0x25b9003d}},	//   аев_, _הַפֶ, _وطبا, _atsl_
  { {0x661d018c,0x236d00bd,0x6843005e,0x26cb0a2d}},	//   _brsk, _njej_, єнта, _ceco_
  { {0x3b830033,0x29130123,0xdb044db6,0x2d854db7}},	// [ba40] _ільг, _faxa_, _juní, olle_
  { {0x2d850034,0xd5b10016,0x0585005e,0xe8fa06bf}},	//   nlle_, _ắt_, пуєм, _тло_
  { {0x273c002e,0x386d00b8,0x8c4c000a,0xa7d60015}},	//   _sínu_, ßert_, ְׂדִ, _بتخص
  { {0x032609ef,0x32d60033,0xdc88000a,0x70b40065}},	//   юден, іцес, זְנָ, ुर्ल
  { {0x2d09000b,0xb77b004c,0x64c60015,0xe1ef00c3}},	//   _वसूल_, _כאטש, _ويحل, نسو_
  { {0x61430892,0xd578000a,0xd0100015,0x64a60033}},	//   меча, _הָֽר, فلت_, _фава
  { {0x9f5e002c,0x74160015,0xaada000b,0xc3060015}},	//   _istú_, _بوزا, _भयंक, _وبرو
  { {0x6d86002e,0x9326002b,0x389b000a,0xf73a000a}},	//   rðam, _برسن, סיקנ, יתֶך
  { {0xdb1b018b,0x28bf005d,0x00da00c3,0xcd0614dd}},	//   rstü, ्रमि, _نبات_, очни
  { {0xdd9000e5,0x6259005e,0xdb1b4db8,0x6b6b002a}},	//   عود_, _урср_, ystó, tęgo
  { {0xf19b000a,0xf1b90085,0x20180030,0x61e40125}},	//   _כשמש, _vrše_, _éri_, áilf
  { {0x8cba005d,0x273c002e,0xbe160015,0x201e008c}},	//   _श्रो, _míns_, _ووضع, _irti_
  { {0xfd0f0074,0xf2d300f3,0x539b0135,0x639b000a}},	//   رجی_, וער_, יסטא, יסטנ
  { {0x3c460029,0x6b46002d,0xdc2a0015,0x929d002a}},	//   _وَإِ, _hógl, _نسبه_, _małp
  { {0x58840010,0xa1570008,0x4cbb000a,0x78b0013f}},	//   дыта, קבלה_, _דמוג, _živý
  { {0x7d080134,0xb5ab0015,0x9f5e0125,0x61e24db9}},	//   leds, لائك_, _astú_, krol
  { {0x25a30111,0x26cb003d,0x29134dba,0x7afb007c}},	// [ba50] _pijl_, _veco_, _taxa_, õutu
  { {0xef19005c,0x61e24dbb,0xbef8000b,0x15150033}},	//   może_, drol, ्जुन_, ядзя
  { {0xfa34002b,0xf3f90238,0x42b90033,0xe6c70015}},	//   _فرید, снеш_, былю_, _وتحي
  { {0xa87a0008,0x7d080134,0x4bfb0053,0xdb0b00c0}},	//   _לאתר, heds, שלאס, _utfä
  { {0xd25b05e6,0x20d5017f,0x171a000a,0x9dbf000b}},	//   јце_, пійс, _פושע, लीफ़ो
  { {0x398400f2,0xc692000a,0x2b92006f,0xdce80046}},	//   tösi_, _נאם_, máce_, rodě
  { {0xd12e0015,0x2b920046,0xf1c70046,0xdb02001a}},	//   امى_, láce_, _řády_, mplö
  { {0x61e24dbc,0x6d4a0d3d,0x1f550138,0x0000006a}},	//   brol, _alfa, ятлё,
  { {0x201e00d9,0x3984008c,0x3eb0006f,0x61e24dbd}},	//   _erti_, sösi_, _žltý_, crol
  { {0xc5f20008,0xcc89002b,0x2d854dbe,0x4d4903ae}},	//   עדי_, ینکه_, ulle_, спон_
  { {0x212a002b,0x0000006a,0x0000006a,0x0000006a}},	//   _ديلی_,   ,   ,
  { {0x8db5005e,0x98b80091,0x671b000b,0x660d00aa}},	//   _ескі, ikrą_, _पोलक_, kwak
  { {0x4a430063,0xdb040045,0xed4e05c0,0xfa67005e}},	//   еняв, _punâ, _зо_, заяк_
  { {0xfbd10029,0xdce10024,0x271800a1,0x0000006a}},	//   _كتب_, rolē, _ọn_,
  { {0x99190036,0xb8f4000b,0x1a66002b,0xd7f20015}},	//   ціях_, _हज_, تیکی_, عكر_
  { {0xcc3a00b2,0xdb1b0003,0x7c3c1f15,0x61e21e7e}},	//   _לעצט, ypté, ärre, yrol
  { {0xe73709ef,0x26e4000b,0xa3c9000b,0x273c001a}},	// [ba60] чет_, गलौर_, लीस_, _síns_
  { {0x2bc2014e,0x4583000d,0x22d90053,0x4a5b000a}},	//   वीका, егув, _פּראָט, _לדפו
  { {0xe7eb005d,0x493b000a,0x4915000b,0xd36f4dbf}},	//   जूदा_, _הגיו, _फोटो_, еч_
  { {0x7d080050,0xe5a6000d,0x988b000a,0x29184dc0}},	//   zeds, _ними, _לָכֵ, ldra_
  { {0xa79b000a,0x291808cf,0x26d24dc1,0x61e2014b}},	//   _לשטח, odra_, mayo_, urol
  { {0xe4da0074,0xdfd003c4,0x61e225d7,0x6458002c}},	//   _دوست_, نيت_, rrol, úvis
  { {0x28bf005d,0x7d080293,0x9f9803e7,0xd9d9000b}},	//   ्रति, veds, овку_, _भट्ट
  { {0x7dc4003b,0x99890011,0x64a302bf,0x26d20b63}},	//   وقعن, _oraş_, _часа, nayo_
  { {0x7d0800fb,0x91e33da0,0x91e600af,0x63ae005a}},	//   teds, _поте, _хозе, _hubn
  { {0xc1bb0008,0xd657000a,0xb3e0000b,0x6ab5000b}},	//   _לממש, פיית_, _पटाख, ंड्र
  { {0x26d20297,0x29180677,0x351b000a,0xa5bb002a}},	//   kayo_, ddra_, זוינ, _króc
  { {0x600b000a,0x6fb30015,0x59a5000b,0xbebd003d}},	//   _לִדְ, _أمنا, _गूजर, sjūr
  { {0xd3570008,0xbdf70015,0x63ae01c2,0x7e9a0058}},	//   ליטי_, _فروا_, _lubn, _انشر_
  { {0xada3000d,0x290a0091,0x3a200702,0x2deb004f}},	//   _зачл, geba_, _drip_, _הַה֑
  { {0x6cfb000a,0xd6db4dc2,0xacfb000a,0x67d5005e}},	//   _הפוס, йта_, _ההוכ, ьову
  { {0x29180d0f,0x8e20005e,0xcaa70015,0x657e0085}},	//   adra_, _пiд_, _عصبي, eoph
  { {0xaac3014e,0x4ac3014e,0xae1f000b,0x3a204dc3}},	// [ba70] _व्यक, _व्यव, बियन_, _grip_
  { {0xa5bb4027,0x660d0665,0xd49b1fdb,0x290a016e}},	//   _prób, rwak, бре_, ceba_
  { {0x26d2000c,0x6d86002e,0x493c000a,0x78fa000a}},	//   bayo_, rðah, _לגזו, _ולתפ
  { {0x1ddd005d,0x63ae1483,0xf62b005e,0x1868012e}},	//   _मिलत, _dubn, _ліги_, _хаџи_
  { {0xe2900029,0xa5bb002a,0xdb020123,0xdb0400bf}},	//   هذه_, _wrób, pplö, _juná
  { {0xf8bf014e,0x2bac0089,0x35a40010,0xdca60015}},	//   ्रिय, _těch_, _паўг, _لى_
  { {0xe0d00074,0x7bdc00dc,0x70550015,0x3ff20015}},	//   ازه_, árul, بنغا, نكور
  { {0x321f0023,0x2f540191,0x290a005c,0x3984079c}},	//   _truy_, етьс, zeba_, löst_
  { {0x7bca00da,0xf8bf000b,0xa0a70c31,0x6f09055e}},	//   _awfu, ्राय, _ешел, reec
  { {0x61e4002d,0xed590036,0x0dc80054,0x9f47006f}},	//   áile, іон_, чући_, ntnú_
  { {0xa4b6000a,0x3b0a15f9,0x7afd03c1,0xdca50004}},	//   ולתה_, оено_, ffst, ќани
  { {0xddc9002a,0x141a000a,0xc949000a,0x441a000a}},	//   rzeł, קורב, _דמ_, קורס
  { {0x3e690086,0xcd350015,0x3984001a,0x657e4dc4}},	//   _بجای_, _يرتب, köst_, yoph
  { {0x7db40015,0xdb040030,0x657e1254,0x7afd4dc5}},	//   _أصنا, _duná, xoph, afst
  { {0x26d20358,0x9cd6000a,0x35a7000b,0x29184dc6}},	//   tayo_, _חוצה_, _कंज़, rdra_
  { {0x3a200495,0xe4f0000b,0x9a6a0015,0x29180034}},	//   _trip_, _चाहि_, _ومثل_, sdra_
  { {0x24f603ad,0x3a2001d7,0x61eb0085,0x63ae4dc7}},	// [ba80] дчер, _urip_, jugl, _subn
  { {0x7bc10064,0x80ac000b,0x26d20077,0x3bb9000a}},	//   oplu, _चलें, sayo_, ַמְד
  { {0x26d200b6,0xe73a066c,0x690b0008,0xd24f002b}},	//   payo_, _ден_, _וּכְ, ینم_
  { {0x27e5032c,0xb2860010,0xd62a054f,0x5c36004c}},	//   álne_, мылк, _доме_, ורען_
  { {0x2bac0089,0x754900dc,0x96760033,0x2005003d}},	//   _věci_, ászó, _цыні, _apli_
  { {0xa5bb005c,0x3cf9000b,0x518303fc,0x0000006a}},	//   _wróc, ौजों_, куща,
  { {0x61eb002e,0x7afd00dd,0x6b6400dc,0xf993000a}},	//   augl, yfst, zőga, דרג_
  { {0xdea20086,0x444405b2,0x1e1401b7,0x8e14012b}},	//   نیای, my_, емия, едиц
  { {0x753c0050,0x3ea200c0,0x6ce6005e,0xe731000a}},	//   _korz, äkt_, міне, אֵי_
  { {0xdb1b2061,0xe2a6001a,0xddc9002a,0x44444dc8}},	//   nstö, áðum_, dzeń, oy_
  { {0x8c43000d,0xddd10024,0x753c0fce,0xdb1b0a75}},	//   веќе, ēgša, _morz, istö
  { {0xa08b000a,0x0ed6002b,0x7afd0012,0x444402f2}},	//   _וְדִ, _آغاج, ufst, iy_
  { {0x527b00b2,0x753c0111,0xc33301d8,0x8fa3000d}},	//   ַנלא, _oorz, דור_, _раце
  { {0x44440156,0x753c01c2,0x0000006a,0x0000006a}},	//   ky_, _norz,   ,
  { {0x7afd0012,0xd7890015,0x6e2201c0,0xd7f84dc9}},	//   pfst, كنسو_, _hrob, мут_
  { {0xf7700196,0x95c50015,0x6017000a,0x7d1830a6}},	//   لاق_, فيره, וחלף_, _havs
  { {0xddc9005c,0x753c4dca,0x44444dcb,0xa5f809da}},	// [ba90] czeń, _borz, ey_, мету_
  { {0x6d484dcc,0x44444dcd,0xdb1b001a,0x2b92006f}},	//   nkda, fy_, gstö, máca_
  { {0x79850273,0xa3c9000b,0x36d5004a,0x753c002a}},	//   _ikhw, लीं_, _понр, _dorz
  { {0x16350063,0x9f47002c,0x28bf005d,0xc2c40015}},	//   _земя, stnú_, ्रवि, نيمي
  { {0x7d1800c0,0xb6ba0b7b,0x753c01ef,0x6d4800cb}},	//   _oavs, _מצרי, _forz, kkda
  { {0x41e0005d,0x753c005c,0xf1e0000b,0xd656000a}},	//   _निरस, _gorz, _निरन, _טירת_
  { {0x444407e9,0x6286079b,0x2617000b,0xb938000a}},	//   cy_, _økon, निकी_, ונגו_
  { {0x6e220176,0x7bc1007c,0x61e40125,0xee390988}},	//   _brob, vplu, áilc, зни_
  { {0xe1f00086,0xde160086,0xada507be,0x399602de}},	//   _نسل_, فقيت_, наил, læse_
  { {0x6aad0251,0x9f5e002c,0xa0c40029,0x63a94dce}},	//   _agaf, _istý_, _ليكو, _hien
  { {0x63a9000c,0xdb04016e,0xb5470033,0x6b66067a}},	//   _kien, _junç, ялiс, екна
  { {0x7c3c00c0,0xf0920135,0xf989039e,0x7bc11bc0}},	//   ärra, _גנב_, _הר_, rplu
  { {0xdc3b0844,0x63a94dcf,0xfce5034e,0xdf360015}},	//   _išče, _mien, _золо, _سكوت_
  { {0x63a9038d,0x6e3a000a,0x6f02002a,0x7f85016e}},	//   _lien, _מתנד, _zboc, róqu
  { {0x6e22005c,0x3da6005e,0x2796006b,0xddc9002a}},	//   _zrob, _якшо_, ешар, szeń
  { {0xe7371742,0x44443e71,0xdc9a000a,0x6f1b08ab}},	//   нес_, vy_, _ציקל, nduc
  { {0x6b720048,0x444426c2,0x69cd0026,0x6b46002d}},	// [baa0] lāgo, wy_, _gwae, _rógh
  { {0x63b8002c,0xdce10007,0x63a90152,0x99fb000a}},	//   ívno, rolė, _aien, _צפיפ
  { {0x753c00b8,0xdb1b4dd0,0x130a04ab,0xc689000a}},	//   _vorz, rstö, зней_, צא_
  { {0x291a000c,0x44444dd1,0xe29a0010,0xd7bb000a}},	//   _hapa_, ry_, пае_, _מצטר
  { {0x291a4dd2,0x63a94dd3,0xdb1b001a,0x44444dd4}},	//   _kapa_, _dien, pstö, sy_
  { {0x63a94dd5,0xdb04001c,0x4444037f,0x6f0202b9}},	//   _eien, _funç, py_, _sboc
  { {0xa2e6006b,0x63a925e7,0x6b460125,0x6441007c}},	//   _повд, _fien, _tógh, _ülip
  { {0x291a0048,0xdb0b003c,0x63a90eb3,0x02460015}},	//   _lapa_, _utfø, _gien, _كَأَ
  { {0x8fa30054,0xfeb70015,0x62894dd6,0x9e660058}},	//   ћање, رايت_, _gyeo, عابن
  { {0x361b013a,0xd24f0029,0xf1a90015,0x6d480091}},	//   לופד, _انك_, _قاله_, ukda
  { {0x6d484dd7,0xbdf7002b,0x69cd042f,0x6f1b47eb}},	//   rkda, وریا_, _swae, bduc
  { {0x6e2208e0,0xf093000a,0x8e860015,0x59dc000b}},	//   _trob, _ענף_, _كلاه, _बिखर
  { {0x7d1801e2,0x6e22002c,0x673d005c,0x291a00d9}},	//   _tavs, _urob, _rosj, _bapa_
  { {0x90d50023,0xa3e1005d,0x2b92006f,0x291a1a2a}},	//   _lòn, _दिल_, ráca_, _capa_
  { {0x673d010b,0x2d9e00b8,0x1cb700a3,0xf7730031}},	//   _posj, mmte_, _אלול_, هار_
  { {0x4788000d,0x7bda0843,0x07090015,0x2d8c0123}},	//   есум_, mstu, بيري_, llde_
  { {0x63a94dd8,0x8f9b0008,0x44230085,0x79a71021}},	// [bab0] _rien, לילי, _srj_, _прое
  { {0xd49b4dd9,0x63a94dda,0x213e01f1,0xc6a40fdc}},	//   пре_, _sien, _noth_, урси
  { {0x9cd70008,0x2d9e0159,0x3319005e,0x63a94ddb}},	//   גובה_, imte_, діля_, _pien
  { {0xe6950015,0x2d9e0012,0xe1f10021,0x6d5d0030}},	//   _للجد, hmte_, لست_, ésaz
  { {0x213e0041,0xa2940036,0xe4e70036,0x90d50092}},	//   _both_, гаці, _півн, _dòn
  { {0xdb0400b8,0xc2440010,0x1c10000b,0xa3cc000b}},	//   _zunä, ынік, ़बाल_, _शौक_
  { {0x63a94ddc,0xdfd10021,0x213e00da,0x34940888}},	//   _tien, جيع_, _doth_, _барр
  { {0x2d8c0161,0x6006006b,0xaec2006b,0xa6fb000a}},	//   elde_, тнъм_, абъл, לִ֖י
  { {0xc115209b,0x26c9003f,0xb1150254,0x3e890015}},	//   _имај, ibao_, _имаш, بَةَ_
  { {0xdca5029b,0x7bda1b54,0x7af61e7e,0x213e4ddd}},	//   капи, fstu, _scyt, _goth_
  { {0x7bda4dde,0x2ef504b4,0xd01100c3,0x0000006a}},	//   gstu, _азер, _خلا_,
  { {0x291a4ddf,0x1036000a,0x7c940033,0x2d8c4de0}},	//   _sapa_, _בטעם_, ырыц, alde_
  { {0x42da0053,0x98d60036,0x6b640030,0x7bda31c2}},	//   וקרע, ківщ, sőgo, astu
  { {0x3f8d4de1,0xfce50442,0x7c650040,0xfc310015}},	//   lleu_, _роко, _لاعل, _نحب_
  { {0x6d86001a,0x3f8d0251,0xbc190036,0x504c000a}},	//   rðat, oleu_, _цілі_, ִׂמְ
  { {0xba760029,0x27e532a9,0xfaff0079,0xddc9003d}},	//   _لاخت, álna_, liën_, rzeņ
  { {0x3f8d0026,0xdcfa003d,0xc7a30674,0x291a4de2}},	// [bac0] ileu_, lotā, ритк, _tapa_
  { {0xca970008,0xa5bb1754,0x4aa7000b,0xdce1003d}},	//   _בדפי_, _trón, _गणतव, dolī
  { {0xdcfa0024,0x213e1852,0x66e61bb1,0xb937004f}},	//   notā, _roth_, _иона, _סנטו_
  { {0xa5bb0050,0x7c3a0053,0x41e602e1,0x798e0034}},	//   _król, וגעז, віка, llbw
  { {0x90d50092,0x2d87002c,0x333f0152,0x6d86001a}},	//   _vòn, _okne_, _doux_, iðar
  { {0xdcfa003d,0x7bda2f58,0x3f8600aa,0x9103006b}},	//   kotā, ystu, _skou_, ипче
  { {0x351b0008,0xb502005d,0x7ff30029,0xcf9a000d}},	//   _קולנ, र्णय_, لسيا, мји_
  { {0xdcfa0024,0x3f8d016f,0xc224002b,0x2d8c0079}},	//   dotā, gleu_, _مکتو, wlde_
  { {0x2dd30033,0x110a0015,0x8fa30054,0x7bda4de3}},	//   ажыр, _يغطي_, шаће, wstu
  { {0xfe6f0029,0xa09a0015,0xa225002b,0x569b004c}},	//   تدى_, _قضاء_, _حرفه, ויפצ
  { {0xc0a90029,0xa0a60063,0xdcfa003d,0x7bda4156}},	//   _كامل_, _ражд, gotā, ustu
  { {0x8eda0029,0xe502000b,0x7bda443a,0xa3ea000b}},	//   _آذار_, र्ति_, rstu, _मिन_
  { {0x9f47002c,0x9b58006b,0x7bda4de4,0xfee90058}},	//   ntný_, тият_, sstu, _أعمى_
  { {0x6d860084,0x929d005c,0xe80f005d,0xf8bf000b}},	//   rðas, _cały, ाबला_, ्रेप
  { {0xcd970008,0xed570001,0x7d37000a,0x6db2002a}},	//   _שדות_, _јој_, _בנגב_, _błag
  { {0x34cb005d,0x5ba40010,0x5c37000a,0x9f47006f}},	//   िर्द, _крыз, _ירון_, ktný_
  { {0x333f4de5,0x387a1a0f,0x0000006a,0x0000006a}},	// [bad0] _roux_, _expr_,   ,
  { {0xeaaa00b2,0xe29f001a,0x2d830085,0x6abd0030}},	//   _אױפֿ, _úði_, čjeg_, lcsf
  { {0x316700b8,0x2911179d,0x4c98000a,0x8234002b}},	//   vinz_, meza_, תֹּא, یرها
  { {0x3f840024,0x6db2002a,0xdce100bc,0x6abd0030}},	//   jomu_, _kład, vilč, ncsf
  { {0xcb140053,0x2ca20046,0x61e400bc,0x69dd4618}},	//   ילף_, ěkdy_, šiln, nsse
  { {0xd5fa013a,0x29114de6,0x04c90029,0xc5fa0135}},	//   _אפשר, neza_, _سوري_, _אפשט
  { {0x787200dc,0xd3a7049d,0x614203ad,0xdce1003d}},	//   művé, _арап, сеща, solī
  { {0xdcfa003d,0x69dd4de7,0xc2c40058,0x3f840160}},	//   votā, ksse, _نيفي, gomu_
  { {0x917b0023,0x2911003f,0x9e090015,0x0d850ac9}},	//   hể_, keza_, ريدك_, ллин
  { {0xdcfa03eb,0x80ca021e,0xee490046,0x51841ece}},	//   totā, _स्पे, jvýš_, _куха
  { {0x9c650086,0xfaff0079,0x69dd4de8,0xcb6a09c3}},	//   اهجو, riën_, esse, еане_
  { {0xdcfa0024,0x99f60010,0x3f840046,0x1613000b}},	//   rotā, лягі, comu_, डबार_
  { {0x6d860084,0xd35a000a,0xee2e0221,0x7f3a000a}},	//   rðar, תדרל, _ун_, _רענו
  { {0x2911000c,0xf8a5000b,0xdcfa003d,0xb9960058}},	//   geza_, _गृहय, potā, السب
  { {0x929d002a,0xac160054,0xd943006b,0x69dd027e}},	//   _obło, _боју_, щери, asse
  { {0xfaff0079,0x20d80091,0x80ca000b,0x69c6007c}},	//   niël_, mžių_, _स्ने, ppke
  { {0xda650086,0x291102c1,0x7ae4016f,0xceb2000f}},	// [bae0] _پايي, beza_, _idit, מין_
  { {0x3a370008,0xd7640086,0x6e2400bc,0x672f002a}},	//   _ערים_, _چندی, _šibk, _encj
  { {0x78fb009d,0x68fb000f,0x9cd6000a,0x61eb0353}},	//   _אליפ, _אליה, רועה_, ergl
  { {0x2d854de9,0x883b000a,0x59cb0065,0x9f47005a}},	//   hole_, _נתכו, ़ीकर, brné_
  { {0xdb04002d,0x61460c45,0xbadb000a,0x0594002b}},	//   _bunú, леда, תקנת, _ناآگ
  { {0x3ff40029,0xd0100029,0xca7b0053,0x9f47006f}},	//   لكتر, قلت_, ענסט, rtný_
  { {0xa3e1014e,0x9f470264,0x2d854dea,0x7ae40b28}},	//   _दिए_, stný_, dole_, _odit
  { {0x20d800df,0xdb19002c,0x140b000a,0xa6db001a}},	//   džių_, _otvá, _אִמּ, _koða
  { {0x76070024,0x70f60087,0x63a2052a,0x5d5405b3}},	//   cīzā, _مسائ, mmon, икит
  { {0xd5fb0053,0x2d852a1a,0x81c7003d,0xc2431368}},	//   עפיר, gole_, umēš, _унук
  { {0x2614005d,0x2911044c,0x63a20003,0x2537004c}},	//   नौती_, veza_, omon, אניש_
  { {0x29110f4d,0x5e260002,0xd366002b,0x0eba0033}},	//   weza_, _معتق, زه_, _чужы_
  { {0xbf130015,0xbdd4004a,0x29114deb,0x6f4b000a}},	//   _دونب, _толщ, teza_, _אֲגַ
  { {0x6e930196,0xfdf700a3,0x2d854dec,0x644304d1}},	//   _الها, _עצות_, cole_, ønik
  { {0x6db20050,0x29114ded,0x67d519b2,0x69c44dee}},	//   _wład, reza_, робу, _etie
  { {0x9f470247,0xa71500af,0xa6db0052,0x17682be2}},	//   trné_, јдаљ, _boða, груп_
  { {0x63a24def,0x61e408ae,0x57640058,0xfaff0073}},	// [baf0] dmon, áill, حدِّ, snës_
  { {0x63a24df0,0xe9df22a8,0xd91b004a,0x61eb00bc}},	//   emon, msú_, _чьи_, vrgl
  { {0xb8f9005d,0x6b46002d,0x44274df1,0xe3c40015}},	//   ार_, _tógt, ín_, مْلَ
  { {0xd2510196,0x2bf7004c,0x63a20030,0xe9df0125}},	//   ينا_, רמאן_, gmon, osú_
  { {0xe704002b,0xa3c9000b,0xf1b902d8,0x964702ed}},	//   _اسپی, लीज_, _krši_, _сэнд
  { {0x98ba0048,0x7607003d,0xa0691520,0x63a24df2}},	//   _kopā_, rīzā, кала_, amon
  { {0xe9df002d,0x2d854df3,0x2f550cec,0x63a206a8}},	//   hsú_, vole_, итис, bmon
  { {0xddc9005c,0x00180033,0x8e090fea,0xcf450a32}},	//   cześ, уўшы_, внив_, рний
  { {0x00e50086,0xed350033,0x2d854df4,0xd24f00af}},	//   _نتای, аэнэ, tole_, ицe_
  { {0x1d090001,0x2d8502b9,0xa5bb0077,0x4d6515df}},	//   њени_, uole_, _prój, рков
  { {0x6616005c,0x3a291e8c,0x70d1000b,0x2d854df5}},	//   zwyk, _arap_, हरील, role_
  { {0x34b2005d,0x60d70024,0x2056004c,0xfaa6033d}},	//   _जल्द, šamī, _דיעל_, иано
  { {0x1a66002b,0xed4e08a0,0xfdeb004a,0x2d854df6}},	//   شیدی_, _до_, _чьей_, pole_
  { {0xdce10024,0xa5bb4df7,0xe29f001a,0x63a24df8}},	//   bilā, _trój, _úðu_, zmon
  { {0x6d434687,0xccf2000f,0x18a60784,0xf746004a}},	//   _iona, _וכו_, равм, аево
  { {0xe6c60018,0x7ae402b9,0x6d430123,0x26db00aa}},	//   شتري, _udit, _hona, gaqo_
  { {0x6b46002f,0x05664df9,0xe9df002d,0xe61a006b}},	// [bb00] _fógr, аван, csú_, ъда_
  { {0xa3e1005d,0xe4520029,0x75d30029,0x84e60210}},	//   _दिख_, يضا_, تيكا, рожж
  { {0xaaba014e,0xc2c60086,0xe4d7002b,0xd7ca002b}},	//   _इलाक, لياي, شونت_, _جوجه_
  { {0x4c6c0053,0xdb190134,0x2897000a,0xa87b000a}},	//   עדאַ, _etvæ, _כדין_, _יריח
  { {0xddc9005c,0x2486002a,0x42170015,0x6263004a}},	//   rześ, łom_, لزوج_, овца
  { {0x26c02a51,0xc16f005e,0x7416002b,0xe502000b}},	//   lcio_, ії_, _پورا, र्शि_
  { {0xd0100029,0x03a6005e,0x70530067,0xa1570342}},	//   سلة_, _виво, ينها, ращу_
  { {0x24530029,0x6d43002d,0x9c820264,0x26c04dfa}},	//   _بنفس, _aona, _účin, ncio_
  { {0x6db2005c,0x161c005d,0x2b920227,0x6d434dfb}},	//   _słab, निटर_, mách_, _bona
  { {0x20b9008f,0x6d43002f,0x5d54066c,0x30d80008}},	//   _быць_, _cona, скот, _תַּע
  { {0x34b70008,0xa4b70008,0x515b000a,0x8cb7000b}},	//   יפים_, יליה_, _שכבו, ोड़ो
  { {0x645e0024,0x2b924dfc,0x3f770045,0x1e8608ad}},	//   izpi, nách_, năul_, _клем
  { {0xe94702e1,0xfe720015,0xda7b0248,0x6d434dfd}},	//   ахво, _بدا_, тян_, _fona
  { {0xc98705b3,0xfe5b000a,0x2b924dfe,0x442a00ee}},	//   руми, _שֻׁל, hách_, _orb_
  { {0xf1b9016f,0x2b920107,0x91d8000b,0x9848006b}},	//   _vrši_, kách_, _नौसै, аята_
  { {0x442d0e6d,0x6d434dff,0xcc57000a,0xd301005e}},	//   _če_, _zona, _כבוי_, _вiйс
  { {0x61e4116e,0x29050020,0x6d5a0604,0xf69900d0}},	// [bb10] šilj, õlas_, ohta, увај_
  { {0x94ab0029,0xdce80007,0x58870010,0xa16c005e}},	//   نطاق_, rodė, _выма, _оцiн
  { {0xdcf80089,0xb97c000a,0x6d5a007c,0xdb1b0c9e}},	//   _skvě, _בנזי, ihta, pptä
  { {0xe5680053,0x602000dc,0x92590080,0x26c04118}},	//   ײַ_, zámá, лает_, ccio_
  { {0x3ebf01e2,0x6d5a4e00,0xe2f8005e,0xab0c000a}},	//   vcut_, khta, речі_, ד֔וֹ
  { {0xea18000a,0x82340067,0x45d4153d,0x0000006a}},	//   שַׁי_, ترما, _форс,
  { {0x3f692f87,0x442508e7,0xd347002b,0x2b9201c0}},	//   лико_, _él_, _پیشه_, bách_
  { {0x7c250084,0x18780008,0x8878000a,0x389c000a}},	//   _áhri, יעור_, יתוב_, כיונ
  { {0x3cd902e1,0x764d17fa,0x6d434e01,0x3ebf04a9}},	//   льню_, nyay, _pona, rcut_
  { {0xa5bb002d,0x3ebf0f23,0x2b92006f,0x98780085}},	//   _crói, scut_, máci_, _ušća_
  { {0x4095003b,0x30850029,0x6d433c21,0x6db2005c}},	//   _الار, _الضف, _vona, _płac
  { {0xa3ea005d,0x4b56006b,0xc949000a,0x6d430012}},	//   _मिस_, съот, _אמ_, _wona
  { {0xc3320008,0x42790053,0x12790053,0x6d5a002d}},	//   פוך_, ראָג, ראָע, bhta
  { {0x6d5a017e,0xd99a0086,0x670a000b,0x764d0061}},	//   chta, انست_, ह्नक_, dyay
  { {0x07ba0029,0x26d90077,0x175600af,0x0000006a}},	//   اهرة_, _beso_, бњар,
  { {0x5bc40015,0xd5b20015,0x764d007f,0x0000006a}},	//   _بتوف, كفر_, fyay,
  { {0x764d0035,0x2b920057,0xf7434e02,0x644316a0}},	// [bb20] gyay, jáci_, чето, änin
  { {0x9a3b0008,0x6a3b004c,0x26c04e03,0x75d300c3}},	//   _עתיק, _עגיפ, scio_, سيما
  { {0x649a0c53,0x2b920227,0x59be000b,0xa2aa000b}},	//   утар_, tách_, _एंडर, जेन्
  { {0x2bb70011,0xf1b9016f,0xe73a1c55,0x41e60015}},	//   _căci_, _buš_, _сем_, مستف
  { {0x2b924e04,0x6d5a0061,0x93250058,0x6303009a}},	//   rách_, yhta, ترلن, سوول
  { {0xdb0b00b8,0x19bb015b,0x2b9201c0,0x64a60c02}},	//   _zufä, אמסב, sách_, _гага
  { {0xdc18005c,0x90440015,0x67240085,0x22520091}},	//   ołąc, تنغه, odij, šyk_
  { {0xc7b30008,0x3f51002e,0xcf260015,0x660412c8}},	//   הבה_, _fáum_, صربي, otik
  { {0x50d60086,0xa5bb002d,0xd337000a,0x1e340033}},	//   _هزار, _prói, _פרמה_, іноў
  { {0x50cf005d,0xf5310008,0x387f0045,0x66044e05}},	//   _स्पष, ֵ֥י_, şuri_, itik
  { {0xb53b0053,0x69b2005d,0x66040604,0xdc98005e}},	//   אגיש, _इंजी, htik, рвні_
  { {0x61e20020,0x201e01a3,0x60da4e06,0xb09b000a}},	//   osol, _isti_, _hetm, _גיבר
  { {0x4e9600b0,0x539b01ac,0x26d902b9,0xdc18002a}},	//   _اشار, טיטו, _reso_, dłąc
  { {0x35db000b,0x25b9001a,0xa5bb002a,0xda700015}},	//   मीफ़, _rusl_, _zrów, رُّ_
  { {0xad650021,0x26d91f4a,0x6604140c,0xc7970058}},	//   _بانه, _peso_, etik, مشرب
  { {0x6b8d003f,0xd6d82962,0x60da006f,0xdce10045}},	//   _ukag, йту_, _letm, pilă
  { {0x35b4070e,0xf77000e5,0x05bb0067,0x248d003d}},	// [bb30] збур, راف_, ادرت_, _ņem_
  { {0x7e9b000a,0xdc18002a,0x201e16fc,0x15150033}},	//   רסמו, ałąc, _osti_, юдзя
  { {0x66042ef1,0x764d0064,0xf9940008,0xd49b1411}},	//   atik, syay, _מרץ_, ура_
  { {0xdb1900c0,0x425500c3,0x764d0061,0x59d0000b}},	//   _utvä, ينار, pyay, तीकर
  { {0x6d580014,0x614503ad,0x201e4e07,0x92b40015}},	//   _olva, жела, _asti_, أحما
  { {0x91a90015,0xa5040033,0x2b920247,0x41291673}},	//   جهتك_, _нясл, ráci_, роко_
  { {0x1428005e,0xdcee0046,0xa066006b,0x61e20c50}},	//   _літо_, žděj, жаща_, asol
  { {0x60060033,0x6d584e08,0x61e23650,0xf412004f}},	//   іным_, _alva, bsol, _קפן_
  { {0x61e20014,0x9f5c02d5,0xbd390036,0xd167006b}},	//   csol, ctví_, аїні_, _лъжи
  { {0xbc840023,0x8d65005e,0xdc18002a,0x361c000a}},	//   ườn, івне, złąc, רוזד
  { {0xca29011f,0x212a0086,0xdc18005c,0xa0c400c3}},	//   _שם_, _خيلی_, yłąc, _رينو
  { {0x66040a6f,0x7ff40067,0x3e350015,0x8a0614fd}},	//   ytik, _رسما, _وفار, озме
  { {0x8d740086,0xeab200a2,0x60da0061,0xfce507ec}},	//   _کانا, بعد_, _yetm, _доло
  { {0xa3ea005d,0x61e4002d,0xcc89002b,0x31ba004c}},	//   _मिल_, áili, _پنبه_, יזשנ
  { {0x3fe9000a,0x6db2002a,0x61e20030,0xbb4606f4}},	//   יַּ֣, _kłan, zsol, _мекк
  { {0x66040941,0x6f0905ed,0x67244e09,0x917b00a1}},	//   ttik, nfec, udij, hề_
  { {0xb9960015,0x7aa60015,0x9b030033,0x67244e0a}},	// [bb40] _ولعب, _بإغل, _ўзьд, rdij
  { {0x3a200035,0x86750033,0x240a02d9,0xe5a60663}},	//   _isip_, чысц, инзи_, цизи
  { {0x29370008,0xf74613ab,0xc6d60015,0xd38a005e}},	//   _ואין_, _дено, _وتحت, айже_
  { {0x60da0251,0x3d09005d,0xb89b000a,0x93a9002b}},	//   _setm, ़्ते_, _כביש, مانف_
  { {0x11d70015,0xe2160015,0xc1a60004,0x61e24e0b}},	//   قونة_, تباع, ојки, usol
  { {0xdb0b00c0,0xc2970010,0x29184e0c,0xc3ca002b}},	//   _utfö, цкіх_, nera_, _نظرم_
  { {0x6f094e0d,0x291819b3,0x9f5c01b2,0xd8d7004c}},	//   ffec, iera_, ství_, קוקט_
  { {0x27e51754,0xf8b3000a,0x5f940004,0x543b004c}},	//   álni_, ושו_, џиит, _דעלא
  { {0x3f98003d,0xbe970015,0x29184e0e,0xad660058}},	//   ēru_, يضًا_, kera_, قاده
  { {0xa06a0063,0x29184e0f,0x8637000a,0xbd8700c3}},	//   _каза_, jera_, קריב_, ينين_
  { {0x29184e10,0xab95005e,0x63bc4e11,0x9c7c06c0}},	//   dera_, зині, _jurn, kače
  { {0xa5bb005c,0xfbcf0086,0x25eb000b,0x395a4e12}},	//   _krót, کتی_, _चिली_, _alps_
  { {0xad660015,0x5a470033,0xda22000b,0xdb190003}},	//   _واته, цэна, मिगत_, _juvé
  { {0x29182b85,0x63bc0003,0x9e330138,0x0000006a}},	//   gera_, _ourn, _цешч,
  { {0x2d8c4e13,0x36d5009f,0xd6db05a7,0xa8990666}},	//   mode_, зобр, ита_, скву_
  { {0x9c7c00bd,0x27ed4e14,0x6443008c,0x7c3c0123}},	//   gače, čen_, änim, ärru
  { {0xe4cb0225,0x89d70015,0xeb92000a,0x917b0016}},	// [bb50] لبان_, _بتعط, _אָז_, hế_
  { {0x63bc1a8e,0x97c70015,0x27f841db,0x29184e15}},	//   _burn, _وتجم, burn_, cera_
  { {0x9c7c016f,0x2901003f,0xf8b1002b,0x49740484}},	//   bače, _icha_, _سکس_, _ілюс
  { {0xabb50053,0x42e70033,0xdc8b000a,0x7afd4e16}},	//   פּעס_, іцеб, בְדָ, ngst
  { {0x9c7c00bc,0xa1950033,0x7afd19bd,0x2d8c4e17}},	//   načb, падч, igst, kode_
  { {0xe8b9005d,0x55ba0008,0x21780010,0x63bc0939}},	//   _आलोच, _למשו, ойчы_, _furn
  { {0xb4d7021e,0xd12e0015,0xb0a5000b,0xa5bb4e18}},	//   सरी_, طمي_, गेंग, _erót
  { {0xd00e06e4,0x2b920089,0xfe45000d,0xa87c000a}},	//   الي_, náct_, знио, יאור
  { {0x236d00d9,0xb0cf005d,0xee3604ab,0x6f092ee9}},	//   _imej_, _स्थग, зны_, rfec
  { {0x29184e19,0x8288000a,0xe6b8000b,0x16b8000b}},	//   xera_, _וְעֶ, _अल्ज, _अल्ब
  { {0x317a0053,0x29184e1a,0x3156004c,0xab2a135f}},	//   _פרעמ, vera_, _ציען_, бона_
  { {0xe4560053,0x6db2002a,0xb09a000a,0x29183f53}},	//   פירט_, _ułan, _היער, wera_
  { {0x44260092,0x8f9a000a,0xa2f6000a,0x29184e1b}},	//   ̉o_, _פיני, המרה_, tera_
  { {0x27f81e72,0x29184e1c,0x2d8c4e1d,0xfe4400fd}},	//   turn_, uera_, code_, _юніо
  { {0x29184e1e,0x200701a3,0x58950033,0x475a01b0}},	//   rera_, ntni_, дшту, брая_
  { {0x29184e1f,0x20074e20,0xf7430419,0x29014e21}},	//   sera_, itni_, несо, _echa_
  { {0xe4d60029,0x1666006b,0xdce8003d,0x6ef60061}},	// [bb60] كتاب, чвам, lidā, lübü
  { {0x27f8002e,0x20070796,0x63bc4e22,0xa5070a3e}},	//   purn_, ktni_, _purn, зефа_
  { {0xd2520086,0xe9a90087,0xc9850115,0xf993000a}},	//   کنش_, _بدين_, _تشيي, _ארז_
  { {0xc2e90015,0x6369005e,0x2d8c06c0,0xa5bb4e23}},	//   قعهم_, оріг_, zode_, _prót
  { {0x929d002a,0x61ed00bc,0x20074e24,0xd31c0065}},	//   _obłu, šaln, etni_, _नसीब_
  { {0x63bc4e25,0xf8be000b,0x301a0015,0x4a9b000a}},	//   _turn, ्डिय, متعة_, זינג
  { {0x35a30010,0xe4240086,0xb4c8000b,0x2d8c376e}},	//   _чарг, _تکذي, ईडी_, vode_
  { {0x644901e2,0xf8b30008,0x547b0008,0x9f470046}},	//   çmiş, עשה_, _הטלו, trná_
  { {0x8e130033,0x2007003d,0x3086002b,0x2d8c4e26}},	//   едыц, atni_, _کلاف, tode_
  { {0x7c862c2a,0x22930015,0xdb190045,0x2b920d85}},	//   зуме, _ألكس, _cuvî, kács_
  { {0xd00f0074,0xf1b3000a,0x2d8c2ce7,0x1b1908f0}},	//   _ملل_, _נסע_, rode_, ожны_
  { {0x7afd0024,0x2d8c0220,0x5477004c,0x4477000a}},	//   ugst, sode_, לגיע_, לעיל_
  { {0xdb040092,0x9f5c006f,0x69cf2fd7,0x7d0f0030}},	//   _khiê, ctvá_, upce, őcsa
  { {0x4bd7002b,0xd90f002b,0x6db2002a,0x7c3c0123}},	//   _کبود_, چیک_, _kłam, ärrs
  { {0xd90f0086,0x7d230115,0xd138002a,0x7ceb000a}},	//   نیک_, _سفين, _mną_, _הַחֶ
  { {0x95d90063,0x6c7b0008,0x5c7b000a,0x57b4024f}},	//   ждат_, _לאופ, _לאוה, ебст
  { {0x59b7014e,0x66f40033,0xd7740015,0x0000006a}},	// [bb70] _इंटर, эпту, رافع,
  { {0xdb040023,0x89dc0008,0x4a5c0008,0xb4d7021e}},	//   _nhiê, _החזי, _לדחו, सरे_
  { {0x9cd70008,0xa5bb3671,0x0000006a,0x0000006a}},	//   פואה_, _prós,   ,
  { {0x27e5002c,0xfbd30008,0x8c1b000a,0x6d86001a}},	//   álnu_, תתף_, מובי, rðay
  { {0x05770021,0x96340033,0xe28e1c4d,0x7d1a4e27}},	//   _فاسد, _зняц, та_, kets
  { {0xdb040023,0x7d1a044c,0x1a9c004c,0x2007001a}},	//   _chiê, jets, ציגע, ttni_
  { {0x7aed4e28,0xef19002a,0x20070030,0x8fa5012c}},	//   _odat, też_, utni_, ومته
  { {0xa6db002e,0xf838000a,0x3eb90293,0x7aed1703}},	//   _boði, לנות_, øst_, _ndat
  { {0x61e4002f,0x200700bd,0xee390484,0xcee80015}},	//   áilt, stni_, іно_, سرين_
  { {0x7aed1836,0x92b40015,0x6ecd000b,0x61e937bf}},	//   _adat, _أحفا, _ध्रु, _ivel
  { {0xcc89056d,0x61e40091,0x51840138,0x61e90c4e}},	//   юбое_, šilt, _чута, _hvel
  { {0x2b920307,0x61e92628,0xc5ff003d,0xbf670369}},	//   vács_, _kvel, ģēju_, _عداو
  { {0x7aed0176,0x7d1a01d1,0x6db2002a,0x4a430238}},	//   _ddat, bets, _złam, вняв
  { {0x25ee005d,0x6d4a0026,0x6f1b4e29,0xb9b5006b}},	//   ेंसी_, _gofa, leuc, ессъ
  { {0xe71a002b,0xbbe8002b,0x0000006a,0x0000006a}},	//   ييست_, _فريم_,   ,
  { {0xd70a0010,0x2b05000b,0xe7370515,0x61e94e2a}},	//   ўнае_, _वायु_, мес_, _ovel
  { {0x25f5000b,0x67260079,0x44310061,0xe96a02d9}},	// [bb80] एंगी_, _vakj, _arz_, _маил_
  { {0x9c7c10ca,0x44310085,0x3f800091,0xa5bb0077}},	//   lača, _brz_, čiui_, _prór
  { {0x442301c2,0x3957000a,0xa3d3005e,0x67264e2b}},	//   _csj_, _חשים_, воєч, _takj
  { {0x9c7c016f,0x7d1a1b8e,0xd12f002b,0x65c6076f}},	//   nača, zets, یمن_, _обма
  { {0xdb040023,0xa3de005d,0x72360029,0x93430063}},	//   _phiê, _दौर_, براط, ънце
  { {0x3cf9000b,0xdfd00067,0x6f024e2c,0x443102ad}},	//   ्भों_, هيت_, _scoc, _frz_
  { {0x442c0003,0x6f1b0012,0x7d1a4e2d,0xf487002b}},	//   _éd_, feuc, vets, _قافی
  { {0x9c7c016f,0xcdc60054,0x7d1a0079,0x6d4a4e2e}},	//   jača, мљоп, wets, _sofa
  { {0xdb040023,0x8fa30054,0x6db2002a,0x7d1a2e25}},	//   _thiê, њање, _włam, tets
  { {0xab64005c,0x657e002d,0x2056135f,0x902a0058}},	//   óżni, nnph, _отер, _وأضف_
  { {0x6db2002a,0xcf8f0b1e,0x7aed4e2f,0x7d1a4e30}},	//   _ułam, _ај_, _pdat, rets
  { {0xee3a1561,0x9c7c0085,0x61e94e31,0x60270030}},	//   _мне_, gača, _yvel, sémá
  { {0xf2d300b2,0x6d4a000c,0x7d1a4e32,0x8f8b000a}},	//   כער_, _tofa, pets, _וְגֵ
  { {0x9f4e0125,0x5e9b000a,0x0000006a,0x0000006a}},	//   irfí_, _ובדק,   ,
  { {0xeb9b0029,0xacfb000a,0x75270030,0x1d17000a}},	//   _وضعت_, _והוכ, _rajz, _חקור_
  { {0x7aed4e33,0x7c2e30a6,0xfc2f0058,0x998900d4}},	//   _udat, åbru, _ضحى_, _braţ_
  { {0x69cd003f,0x75270030,0x3a3200aa,0xab843aca}},	// [bb90] _utae, _pajz, _gryp_, _шушк
  { {0x7ce90030,0xd49b3629,0xc7c701e1,0x61e90072}},	//   _törő, оре_, _осми, _rvel
  { {0xf4850074,0x2b840061,0xa2f5018d,0xdb1b01c0}},	//   رائی, lıca_, епеч, zptý
  { {0xc2c50015,0x3d0e000b,0x45d500e2,0xf2c50058}},	//   ريتي, त्ते_, _помс, رْتُ
  { {0xeb9200b2,0xe5c40731,0xe4d70015,0xd25b0033}},	//   אָג_, _ассо, _يتسب, ўце_
  { {0xe8e00092,0x25b80b77,0x2a58000a,0xa2d0000b}},	//   _kiều_, _girl_, ובדן_, डुब्
  { {0xd00e0067,0x1fb506a6,0x3cf4000b,0x6f1b183a}},	//   ملو_, нсир, ूलने_, teuc
  { {0xa29502e1,0x2b84007f,0x0000006a,0x0000006a}},	//   _забі, kıca_,   ,
  { {0x61e90796,0x80ca000b,0xe8e00016,0xfce50c68}},	//   _uvel, _स्के, _liều_, нопо
  { {0x653a00b2,0x1c450036,0x7d090001,0xa698000a}},	//   ִערד, еном, чног_, וכחה_
  { {0xa0380015,0x15f3000b,0x9c7c0085,0xab2a0555}},	//   _يأمر_, ेंडर_, tača, пона_
  { {0x0000006a,0x0000006a,0x0000006a,0x0000006a}},	//     ,   ,   ,
  { {0xb69b0045,0x9c7c02d8,0x3a9a00ce,0x9f8a0072}},	//   _scân, rača, ятою_, tööl_
  { {0xdb1904f9,0x395e001a,0x0000006a,0x0000006a}},	//   _cuvâ, óts_,   ,
  { {0x2bc6014e,0x6c790053,0x7b960036,0x9c7c4e34}},	//   _रूपा, _מאַפ, _приї, lačn
  { {0xa5bb03af,0x28d0005d,0xfaa6005e,0x75d60015}},	//   _próp, _त्रि, _пайо, فيرا
  { {0x61ed010b,0x9c7c4e35,0x7ae64e36,0xfaff042f}},	// [bba0] šalj, načn, makt, piër_
  { {0x9986002b,0x7ae64e37,0xa2b5000b,0x448a009b}},	//   _سلجو, lakt, ेशन्, пбзн_
  { {0xed560053,0x3f58001a,0x66e60c7c,0x1957004f}},	//   עבער_, _séum_, _пона, _נבטל_
  { {0x9c7c099c,0x14170015,0x7ae64e38,0xbb3b004c}},	//   kačn, عينة_, nakt, ּעסי
  { {0x799c0034,0x96760033,0x76bb004f,0x0000006a}},	//   olrw, _чыні, _ממכפ,
  { {0x6fc70064,0x21670763,0x9c7c3a0f,0x61434e39}},	//   _sıca, ничи_, dačn, леча
  { {0xdfd00029,0x64a34e3a,0xf9930135,0xc953000a}},	//   جيب_, _бара, ארג_, רמו_
  { {0x63a300aa,0xceb90046,0x7ae63ef4,0x0000006a}},	//   ïnnt, zeře_, jakt,
  { {0x33770008,0xe731000a,0xf2e7002b,0x44440618}},	//   _נתמך_, בֵי_, _سکنه_, lx_
  { {0x91620092,0xc27b000a,0x5d5404ae,0xc0aa012c}},	//   _dự_, _זרמי, ткот, _فاضل_
  { {0x20b90010,0x44444e3b,0x0577000a,0x4af901c6}},	//   _жыць_, nx_, תגים_, меню_
  { {0xdd2f0089,0x44444e3c,0xe453039e,0x547b000a}},	//   _měři, ix_, רֶץ_, לטיו
  { {0xc33301e4,0xa3e7000b,0xceb90046,0x9946006f}},	//   אור_, _मौन_, teře_, _kôň_
  { {0x2b8401e2,0x7e7d002c,0x7ae60079,0xd90f002b}},	//   rıca_, úspe, aakt, حید_
  { {0xe8950080,0x7b0600f2,0x79540015,0x6aa400aa}},	//   тавь, ättö, دَّا, _ezif
  { {0x7ae601e2,0x4c9b0008,0xdc9b000a,0xf047000a}},	//   cakt, _משוע, _מסוכ, עָם֙_
  { {0x0bb8000a,0x6d5a0061,0xceb90046,0x444435ad}},	// [bbb0] _אלהם_, okta, peře_, ex_
  { {0x9c7c0057,0x4a7c000a,0x6d5a4e3d,0xc7bb004a}},	//   načo, _מרחב, nkta, _нём_
  { {0x9c7c0227,0xd7950015,0x94390015,0x6d5a4e3e}},	//   začn, _للدخ, بكاء_, ikta
  { {0x68e70014,0x290305d8,0xf7d6000a,0xd808000a}},	//   lajd, lgja_, _שורש_, _אִשָ
  { {0x2258005f,0x6d5a22af,0x29030030,0x673d0123}},	//   ницы_, kkta, ogja_, _insj
  { {0x672d0005,0x29034e3f,0x865a04dc,0x68e70e23}},	//   ldaj, ngja_, _חדשי, najd
  { {0xe8e00023,0x91620023,0x7ae6003c,0xb4bf000b}},	//   _hiểu_, _sự_, yakt, ीडी_
  { {0xe8e00092,0x672d4e40,0x93970015,0xee3908c9}},	//   _kiểu_, ndaj, _أجسا, дни_
  { {0xe29f002e,0x256400dc,0xc332000a,0x7ae641ce}},	//   _áð_, _föld_, _דון_, vakt
  { {0x41b50074,0x9c7c0156,0xdd8e0015,0x7ae60852}},	//   _شمار, račn, يوي_, wakt
  { {0x63bb000c,0x80ca005d,0x9c7c002c,0x2136004c}},	//   _kiun, _स्टे, sačn, _שטעל_
  { {0x91620023,0x6d5a00df,0x628c005c,0x63bb003f}},	//   _tự_, akta, żnoś, _jiun
  { {0x63a90026,0x1d090001,0x63bb1b2e,0xd24f005e}},	//   _mhen, _жели_, _miun, ицi_
  { {0x290305d8,0x7ae63e98,0xcdf6000a,0x3ea20061}},	//   ggja_, sakt, _ימני_, ükte_
  { {0xcd76000a,0xb7960054,0x67f50033,0x88e3005e}},	//   _בעסק_, враћ, лятф, ржсе
  { {0xe8e00023,0xf71a0015,0x63bb02b9,0xe71a0015}},	//   _biểu_, بيرغ_, _niun, بيرت_
  { {0x7ae40176,0x7e6900b8,0x2913002e,0x660d4e41}},	// [bbc0] _ieit, nzep, únað_, gtak
  { {0xa6db0084,0x69fb011f,0xa96a002b,0x7ae44e42}},	//   _boðs, _קליק, _آمدم_, _heit
  { {0x44440b7a,0x7ae40472,0x130a0892,0xe8d7000a}},	//   ux_, _keit, дней_, _שוטר_
  { {0x7bc34e43,0x69c400dd,0x7ae4016e,0xdd2f0046}},	//   _munu, _kuie, _jeit, _věři
  { {0x63bb013c,0xc4c60015,0xf1aa0015,0x63a9007c}},	//   _diun, _لتزو, واته_, _dhen
  { {0x7ae44e44,0x23a7007c,0x78a90046,0x69c40045}},	//   _leit, võje_, řeve, _muie
  { {0xb0ac000b,0x9c7c006f,0x61eb0034,0x2564001a}},	//   टेंग, vačo, asgl, _völd_
  { {0x63bb04ed,0x7ae44e45,0xa2d3002b,0x2d5b016e}},	//   _giun, _neit, _نيفت, _dêem_
  { {0xf773013a,0xe2970010,0xafb70029,0x9c7c0227}},	//   יקה_, _аат_, خطوط_, tačo
  { {0x7bc34e46,0x672d10a4,0x6d5a1147,0x63a92f01}},	//   _bunu, zdaj, ukta, _zhen
  { {0xa4fb0008,0xfc660063,0xb4fb01d8,0x9c7c0264}},	//   וליט, тъпн, ופיי, račo
  { {0xa3e4005d,0x3f800007,0xa6e2002e,0x7ae4002d}},	//   पीय_, čius_, áðla, _ceit
  { {0x3ea0002f,0xbef70008,0x7e69005c,0xd337000a}},	//   _áit_, _יצאו_, czep, דרכה_
  { {0xbea30001,0x6c340029,0x7bc30026,0x7c6600c3}},	//   _тачк, _مفتا, _funu, _لابل
  { {0x6db2005c,0x7ae44e47,0x7bc3013c,0x3707006b}},	//   _sław, _feit, _gunu, кчав
  { {0x61ed00df,0x2d9e1556,0xba550086,0x68e71e8c}},	//   šali, llte_, _منبع, sajd
  { {0xba740086,0x96350010,0x7b740029,0x63bb04ed}},	// [bbd0] _پايت, ынац, _خطوا, _riun
  { {0x63bb00df,0x7ae44872,0xc4dd000b,0xb4d4004a}},	//   _siun, _zeit, यरेख, ижущ
  { {0x2d9e0a11,0x63a90495,0x660d074e,0x9cd7000a}},	//   ilte_, _phen, stak, דובה_
  { {0xe8e00092,0x2d9e00b8,0x660d13ba,0xd347002b}},	//   _tiểu_, hlte_, ptak, خیره_
  { {0x63bb000c,0x92670029,0x61eb0012,0x9f650030}},	//   _viun, خدام, usgl, _ítés_
  { {0x63a9003e,0x4a5c000a,0x2d820030,0xa4d4005e}},	//   _when, ודדו, ékel_, _ворі
  { {0x10150029,0x63a94e48,0xc918000a,0x41740015}},	//   ابتد, _then, דחות_, جانس
  { {0x68e500f2,0xdfce0015,0x2d5b016e,0x2d9e4e49}},	//   _lehd, أيي_, _vêem_, elte_
  { {0x7bc301e2,0xa3e7014e,0xa3e4000b,0x7ae44e4a}},	//   _sunu, _मौत_, पीठ_, _reit
  { {0xcda90086,0x7e69005c,0x7ae44e4b,0x7bc3042c}},	//   عهده_, rzep, _seit, _punu
  { {0x7995005c,0x64e1000b,0xd301005e,0x7ae44e4c}},	//   dozw, _फ़ैश, _вiдс, _peit
  { {0xa2aa000b,0x69c4007c,0xbb860015,0x3a29002a}},	//   जेक्, _puie, الحي, _bsap_
  { {0x7ae4002e,0x69c40c07,0xe8e00016,0x9e080015}},	//   _veit, _quie, _liễu_, _لينك_
  { {0xdb1900fb,0x7ae405cf,0xceb2000a,0xa3e40157}},	//   _nuvæ, _weit, _היד_, पीड_
  { {0x7ae40176,0x3a290061,0xbbf50015,0xfbd10058}},	//   _teit, _esap_, _إستث, _اتت_
  { {0xfbd20008,0xfc56000a,0x8c1a000a,0xeb06009b}},	//   _פתח_, _תבקש_, _נופי, _спип
  { {0x36674e4d,0x44fa0015,0x05aa0033,0xe61a01b0}},	// [bbe0] гато_, فراج_, евай_, эда_
  { {0x04460df0,0x0000006a,0x0000006a,0x0000006a}},	//   лезн,   ,   ,
  { {0x0000006a,0x0000006a,0x0000006a,0x0000006a}},	//     ,   ,   ,
  { {0xb827034e,0x25e8000b,0xe8e00016,0xf6d5005e}},	//   _союз_, _चौथी_, _diễu_, _віря
  { {0x5b7b0053,0xcb13000a,0x2d9e00cb,0x9c7c006f}},	//   ערנא, מלא_, ylte_, vačm
  { {0x183601d8,0x2936004c,0x313413d9,0x20ca0015}},	//   ָאֵל_, ראַן_, рекр, ربتي_
  { {0xe0860015,0x61430054,0x6ff30015,0x9c7c0816}},	//   دجشي, сеја, مسيط, tačm
  { {0xcf260015,0xdd2f0046,0x2d9e0012,0x752e0085}},	//   ارثي, měřu, wlte_, _habz
  { {0x5ce60010,0xdb040077,0x9989006f,0x73990054}},	//   люна, _chií, _hrať_, _ртрс_
  { {0x2d9e0011,0xc237000a,0xdd740054,0x1e170015}},	//   ulte_, _גרמו_, ргоњ, اغية_
  { {0x9c7c010b,0xc3340008,0x2cb800c0,0xdfcf00e6}},	//   mačk, ֑וֹ_, ärd_, _فيل_
  { {0xa4b70008,0x4fa30063,0xab950036,0xda350892}},	//   טליה_, _лихв, римі, аемы
  { {0x629e005c,0x5d830086,0xff7b0053,0x6f930015}},	//   ępow, _گلول, _אטאמ, _النض
  { {0xceb30053,0x28d0000b,0xd00600c3,0x9c7c03f2}},	//   _פיס_, तुलि, يل_, načk
  { {0x3cf70087,0x7995002a,0x58d410ff,0x37ab0515}},	//   _صعود_, rozw, сост, етан_
  { {0xcb990086,0xa09b004c,0x387e006f,0x9c7c00b3}},	//   _جنبش_, גילט, útra_, hačk
  { {0x25ee005d,0x442a4e4e,0x3a294e4f,0x6458003c}},	// [bbf0] ेंगी_, _asb_, _usap_, øvin
  { {0x9c7c016f,0x9989006f,0x0000006a,0x0000006a}},	//   jačk, _brať_,   ,
  { {0xa2d50002,0x19ba000a,0x824b002b,0x63a30045}},	//   ليات, _שמתב, کشاف_, înno
  { {0x91d50010,0x92590080,0xe759005e,0xb7da000a}},	//   ацкі, кает_, _римі_, _שקרי
  { {0x81c703eb,0x442a0fab,0x44384e50,0x0000006a}},	//   klēš, _esb_, _err_,
  { {0x9c7c036d,0x45fa000a,0xc5fa000a,0xd184008b}},	//   gačk, _בהשג, _בפשט, блій
  { {0xa1560124,0x0429000a,0x2166004a,0xf958000a}},	//   рају_, _בֵּֽ, рищи_, רסות_
  { {0xbe390036,0xff51002b,0x2ba50065,0x0000006a}},	//   вчої_, تخت_, _गीला,
  { {0x3eb900c0,0xf6520053,0x9c7c0085,0xa107012c}},	//   äst_, ַצט_, bačk, _مذاه
  { {0x8d5505b3,0xf532000a,0x8d920015,0xa282002b}},	//   ртич, ַ֥ת_, يليش, _بیهو
  { {0xe8e00023,0xcb6a4e51,0x55760053,0x9b760015}},	//   _hiệu_, ване_, שעתן_, لاحص
  { {0x672f002a,0x661d4e52,0x2564007c,0xde95011e}},	//   _nacj, _opsk, _möla_, _каењ
  { {0x6db20050,0xe7e8000b,0x7c2a016e,0x81c7003d}},	//   _płat, टीना_, _esfr, blēš
  { {0xa2aa005d,0x2bc60065,0xa2b6004f,0xdb190072}},	//   जेट्, _रूवा, יפרד_, _auvä
  { {0xe8e00023,0xb8ce005d,0x661d1cdb,0x1089000a}},	//   _liệu_, _और_, _apsk, דָּֽ
  { {0x2b400011,0x9b930015,0xdd2f0046,0x9c7c0085}},	//   _unic_, _ولوت, věřu, začk

  { {0xc4e60080,0xe4d60015,0xdb9b000a,0x44381835}},	// [bc00] ижай, لتاب, _בסקר, _srr_
  { {0x6db2005c,0x9990002a,0x845a0848,0x9a3b000a}},	//   _ułat, żało_, крет_, _יתפק
  { {0x9c7c010b,0xb4d6005d,0x72c60036,0xc917000a}},	//   vačk, _सभी_, абез, _דחית_
  { {0x25fe0065,0x0000006a,0x0000006a,0x0000006a}},	//   _लिपी_,   ,   ,
  { {0x78c50014,0x672400f2,0x2d8200dc,0x93130015}},	//   _átvá, meij, ékek_, تونش
  { {0xca37000a,0xd0100015,0xe8e00016,0x99890247}},	//   יננה_, كلت_, _diệu_, _trať_
  { {0xa1270029,0x9c7c016f,0xa5050010,0x6604008c}},	//   شكيل_, račk, _уяўл, luik
  { {0x03d70008,0xd138005c,0xf7d7000a,0x65ab0012}},	//   _כולם_, _skąd_, בוקש_, rühe
  { {0xf11a003b,0x5f730086,0x42fb000a,0x65ab007c}},	//   _لغات_, تاور, _שהמס, sühe
  { {0x4096057e,0x9c7c18f1,0xd8430046,0x63a24e53}},	//   _крет, lači, ličů_, llon
  { {0xc3340008,0xf19b000a,0xdcfa0045,0x9f5c0046}},	//   ֖וֹ_, _ישמש, entă, luví_
  { {0x6db2005c,0x3d17000b,0x5e260015,0x9c7c09cb}},	//   _płas, ब्बे_, _نعتق, nači
  { {0xd2460029,0x672f002a,0xbea301f3,0x6dd400c3}},	//   أن_, _racj, _дацк, _اقتض
  { {0x7af60050,0x6e97005e,0x6e3b000a,0x63a23be3}},	//   _edyt, _твір_, _שתגד, hlon
  { {0x6db20050,0x672f002a,0xd7c90067,0x67d5045f}},	//   _włas, _pacj, اوره_, собу
  { {0x1cbb0008,0x501b0008,0x4cbb000a,0xd6d81eaf}},	//   _במוע, כולו, _בזוו, иту_
  { {0x79a70004,0xd8430046,0x7bda1d6e,0x63a20226}},	// [bc10] _врне, dičů_, lptu, dlon
  { {0x63a24e54,0xdce80046,0x8e20005e,0x201e013b}},	//   elon, vidě, _нiж_, _opti_
  { {0xba74002b,0xd370002b,0xb90b000b,0xf3150033}},	//   _هایت, ژهٔ_, मर_, йджэ
  { {0x33840063,0x9c7c016f,0x27fe002c,0x2607000b}},	//   оучв, gači, átne_, िंदी_
  { {0x56940191,0x96470010,0xa1594adb,0xe7b4000b}},	//   _мают, _тэнд, ладу_, ंगरप
  { {0x1a9a0053,0x27fe1ea3,0x63a24e55,0x38d7004f}},	//   ניװע, štne_, alon, בֵ֗ל_
  { {0x62960064,0x9f050015,0x63a24e56,0x9c7c0091}},	//   üyor, موثو, blon, bači
  { {0x43850029,0x645800f2,0xcf45004a,0x2d9c0085}},	//   _الرق, ävie, сний, _akve_
  { {0x0d950033,0xf99f48d6,0x0000006a,0x0000006a}},	//   йшоў, ntès_,   ,
  { {0xdce1003d,0xfd49004a,0x4d650a13,0x8d653d4c}},	//   vilē, узок_, сков, свое
  { {0xca29000a,0x9b460015,0x3f58016e,0xac090033}},	//   _רם_, مندو, _céus_, ынна_
  { {0xd37a004c,0x99840046,0x3f580144,0x6e390034}},	//   ָרשט, ímž_, _déus_, _trwb
  { {0xdce80064,0xed4e006b,0x7bda11ff,0xdcfa0091}},	//   aldı, _ео_, aptu, jotė
  { {0x2bcf014e,0x290c007c,0x929a000a,0xb5190065}},	//   _संपा, üda_, רישת, न्मय_
  { {0x6d433029,0x67a60015,0x3c440015,0x63a2157b}},	//   _inna, محرق, _وَهِ, ylon
  { {0x290c005c,0x6f090049,0x7c3c02de,0x660401be}},	//   żda_, ngec, ærre, tuik
  { {0xf1a7005d,0x9c7c39b0,0xda660015,0xe5ca0067}},	// [bc20] गतान, vači, _داغي, اظره_
  { {0x66040384,0xca37000a,0x3a37000a,0x0000006a}},	//   ruik, _פניה_, _פרים_,
  { {0x63a24e57,0x2d8200dc,0xc2c6002b,0x6e290012}},	//   tlon, ékei_, مياي, hweb
  { {0xd24f002b,0xa4f8002b,0x68ee4983,0x826a0195}},	//   کنه_, _چکار_, labd, лаев_
  { {0x290500dc,0x82330015,0x7d080123,0x6d431086}},	//   ólag_, كروا, ygds, _onna
  { {0x2abb0053,0x63a202c6,0x7bda001a,0xd8430046}},	//   אמנא, slon, yptu, sičů_
  { {0xcf9a0004,0x9c7c0091,0x8ff70015,0xd46a0099}},	//   лји_, pači, مرير_, _сиве_
  { {0x4f670010,0x984c0024,0x7ff30015,0x232a005e}},	//   йшым_, dēļa_, أسوا, _щоби_
  { {0x2cea0a7f,0x667b0053,0xa5bb0e57,0xc6930008}},	//   льно_, ָטיק, _próx, ּאת_
  { {0xd6570008,0x71d7000a,0xa50b004f,0x0000006a}},	//   ציית_, _לומד_, ְּיִ,
  { {0x459b00b2,0xaf0a00b0,0x40960029,0x60d7000a}},	//   רסיע, _مقام_, _الضر, _הובא_
  { {0xdfcf0029,0x65b000f2,0x7b670ea6,0xeb4b19bf}},	//   _أين_, lähd, стое, учок_
  { {0xbc670086,0x291800c0,0x5dda2fa0,0x5e5a0040}},	//   لمین_, ffra_, _сфер_, _حجاج_
  { {0xfbcf0086,0xdd8f0029,0x7bda007c,0x7db40015}},	//   بتی_, _كون_, pptu, _بمتص
  { {0x115b0053,0x4d7b000a,0x4ff8000a,0x98480daf}},	//   נדלע, _תרוע, יִּנ, бята_
  { {0x28d9014e,0xf7730086,0x78a90046,0x6db2002a}},	//   _ब्रि, ساز_, řevo, _złap
  { {0xe6100015,0x7bca0573,0x15150033,0xd31402a3}},	// [bc30] فشل_, _hufu, ждзя, _вiкт
  { {0x7bca4e58,0x65b0008c,0xe9d8002b,0x6f090061}},	//   _kufu, jähd, _اذيت_, zgec
  { {0x69dd108a,0xb8df000b,0x9d1b004f,0x752502ad}},	//   lpse, ेश_, רובט, rehz
  { {0x1dc8005d,0x256401af,0xdc9b000a,0x69dd007c}},	//   रदात, _höll_, ניאל, opse
  { {0x2bcf4e59,0xe29900d7,0x9b18000a,0xdd99006f}},	//   _संभा, јал_, מחאה_, hrňa_
  { {0x61420124,0xc1e80010,0xa0090015,0x657e00da}},	//   деша, сьце_, لقتل_, ciph
  { {0xb4e5000b,0x7aef0079,0xf994000a,0xd00e0067}},	//   नरी_, kact, הרס_, نلو_
  { {0x987c00b2,0x27e5002c,0x7fe80029,0x81170086}},	//   טרוק, álny_, حروف_, _گذرا
  { {0x97580008,0x8d750021,0xa2c6000b,0x6f090061}},	//   מיהו_, قادا, िशर्, rgec
  { {0x28d9000b,0x6b8d007c,0x8d59004a,0x7aef4e5a}},	//   _ब्लि, _ajag, ршит_, eact
  { {0x6e3c0024,0xfb8a0a61,0x7aef1915,0xbca50015}},	//   ārba, ибок_, fact, تمدي
  { {0x920d021e,0x9368000a,0x20074e5b,0xdce90061}},	//   _समाज_, ֶ֣רֶ, muni_, ının
  { {0x539a0008,0x645e005c,0xc9aa000d,0xd7f10092}},	//   שירו, zypi, ивме_, ẫn_
  { {0x645e00f2,0x6d434e5c,0x0000006a,0x0000006a}},	//   yypi, _unna,   ,
  { {0x5b360010,0x2007003f,0x65b000b8,0x29180293}},	//   _дэпу, nuni_, nähe, rfra_
  { {0x27c30058,0x49ca04c5,0x0000006a,0x0000006a}},	//   ِيِّ, _клин_,   ,
  { {0x64430123,0xe0df0016,0x63ba0144,0x20070509}},	// [bc40] ånin, _đòn_, _ètni, huni_
  { {0xc6030080,0xe5060015,0xb5060015,0x7bc4007c}},	//   ьзуй, تبري, تظرو, _hiiu
  { {0x20070085,0x799c0034,0x657e4e5d,0x42ca1411}},	//   juni_, morw, riph, аген_
  { {0xe73a0ac7,0x9f5c0089,0x2007003f,0xa8030010}},	//   _тем_, prvé_, duni_, _ўзял
  { {0x27ed016f,0x9c7c002c,0x93a90015,0x914a18a7}},	//   ćene_, lačt, حالف_, ичка_
  { {0x7aef04f9,0x799c003f,0x66160293,0x65ab007c}},	//   zact, norw, mtyk, püha
  { {0xa0670001,0x9c7c0264,0x20070019,0xdb0f0057}},	//   жаја_, načt, guni_, ždéh
  { {0x799c0026,0x6f230015,0x65b0008c,0xc3230088}},	//   horw, ِّين, sähd, _омск
  { {0xc7b304dc,0x3ea2002e,0x66160870,0xed8a3aa0}},	//   ובה_, ækt_, ntyk, исок_
  { {0x2007000c,0xdb0d0152,0x66160007,0x71660015}},	//   buni_, _chaî, ityk, _بارك
  { {0x200702d7,0x1ee80086,0xc4d30008,0x30860086}},	//   cuni_, _هوای_, וגת_, _بلاف
  { {0x66163f69,0x0a6b005e,0xb09b000a,0xdce10091}},	//   ktyk, арги_, _דיבר, kilė
  { {0xcaa70029,0xd5c50010,0x69dd008c,0x6736002a}},	//   تصدي, вiнн, upse, ddyj
  { {0x314a000a,0x7aef4e5e,0xbda60015,0x799c0034}},	//   ׁתָּ, sact, _بحصو, gorw
  { {0xf7700086,0xef19002a,0xac17005e,0x7aef1a2a}},	//   چاق_, liża_, _дощу_, pact
  { {0x2bcf000b,0x27fe04b2,0x1b780015,0x69dd4e5f}},	//   _संता, átna_, _وصية_, ppse
  { {0x9c7c065d,0xa6e2002e,0xe667005e,0xef19002a}},	// [bc50] raču, óðan, цтво, niża_
  { {0x27fe00bd,0x6d58016f,0x2bcf000b,0xb467002b}},	//   štna_, _jova, _सूडा, يداه
  { {0x49b80074,0xd8380033,0x7aed1ea2,0x6d584e60}},	//   _بايد_, _дэя_, _keat, _mova
  { {0x8c1b000f,0xe3b0002b,0x889a000a,0x6d584e61}},	//   שואי, پرم_, _לבתי, _lova
  { {0x32f20029,0x7aed0541,0x61452c2a,0xeb92000a}},	//   ركوز, _meat, зела, עָב_
  { {0x2d5b020a,0x26c70089,0x6d583a94,0x7aed0541}},	//   _lêer_, ěnou_, _nova, _leat
  { {0x2bc6000b,0xe04200f4,0xfbc6000b,0x2007007c}},	//   _रंगा, енщи, _रंगम, uuni_
  { {0xd3430086,0x7aed2fef,0x6e220125,0x87e30065}},	//   _تفری, _neat, _bpob, टीएफ़_
  { {0xc33200b4,0xf2d200b2,0x4095002b,0x7bc4007c}},	//   _און_, _װעב_, _کلار, _riiu
  { {0x1d090001,0xce180010,0x2007435a,0xceb90046}},	//   љени_, іцыі_, puni_, neři_
  { {0xf456004c,0x6d5c007c,0x442301c2,0x13b5000a}},	//   ִישר_, öraa, _jpj_, ּהָל_
  { {0x69c5022d,0x10360008,0x7aed01b5,0x66164e62}},	//   _aihe, _מטעם_, _ceat, ytyk
  { {0x7aed0041,0x256400c0,0x5e440015,0xa3be000b}},	//   _deat, _dölj_, _يَمْ, ुआत_
  { {0x2d8200dc,0x82760053,0x61e926cc,0x8e56000a}},	//   éket_, לערע_, _mwel, _מינג_
  { {0x256400c0,0x7aed19d4,0x99840030,0x44310bba}},	//   _följ_, _feat, ímű_, _nsz_
  { {0xfe650086,0x97c301c5,0xabfa000a,0xdce10091}},	//   نگ_, ейсе, _ההקר, tilė
  { {0x05660063,0xd7ca002b,0xb69b0045,0x67361e7f}},	// [bc60] пван, _گوجه_, _scâr, rdyj
  { {0x1c1f005d,0xaa3b0008,0x66161316,0xca97000a}},	//   _बहाल_, _פתיח, rtyk, _מדפי_
  { {0x65ab0012,0x66164e63,0x741300c3,0x753501b6}},	//   mühl, styk, فولا, _dazz
  { {0xd3790036,0xf74a0015,0xd7760015,0x160c000b}},	//   очі_, _الحي_, _راجع, िंदर_
  { {0xebad0053,0x71a60010,0x1956000a,0x463a005e}},	//   בסאָ, падз, ּבֶל_, _учня_
  { {0xdcfa0024,0x75350567,0x61e9014c,0xe1330033}},	//   rotī, _gazz, _dwel, еншы
  { {0x80b8000b,0x40340b9b,0x6d584115,0x660449de}},	//   ेखें, фейс, _rova, lrik
  { {0x78a10980,0x66040601,0xd2520058,0x0000006a}},	//   ülvi, orik, _كنز_,
  { {0x61e90176,0xe8e00023,0x7aed4e64,0x66044e65}},	//   _gwel, _chịu_, _reat, nrik
  { {0x20560036,0x63ae0007,0x7aed4e66,0x24f6000a}},	//   _нтер, šinė, _seat, הֶ֛ם_
  { {0x7aed0005,0x9b954e67,0x66044e68,0x7e600502}},	//   _peat, динц, hrik, symp
  { {0xa3e4005d,0x80250015,0x343b004c,0x66044e69}},	//   पीए_, _تركم, צײכע, krik
  { {0x09e4008f,0x5a440010,0x8aa70010,0x65ab00b8}},	//   ноўн, нэра, ярод, fühl
  { {0x395a2efb,0x7aed2299,0xa9c4004a,0xdebb000a}},	//   _cops_, _weat, есск, _המדל
  { {0xad1b009d,0x98c10024,0x7aed4e6a,0x75354e6b}},	//   _הוור, _āpēc_, _teat, _razz
  { {0x27ff065d,0x2d8c0012,0x753501c2,0x66044e6c}},	//   čun_, lnde_, _sazz, frik
  { {0x5afc0008,0x4b7c000a,0xe6130015,0x38c9002b}},	// [bc70] _הלחצ, _לאהו, عشر_, _وادی_
  { {0x2d9e25a1,0x6a140015,0xdb0d0125,0x5d78004f}},	//   note_, _أبير, _mhaí, קָּנ
  { {0x61e90f21,0x95c4006e,0xd3d80015,0xdce8003d}},	//   _swel, ريمه, كبنا_, lidē
  { {0x2bcf005d,0xe1f10086,0x25ba0026,0x25e8000b}},	//   _संसा, نست_, ampl_, _चौकी_
  { {0xb90a0023,0x2d9e0007,0x45d40361,0x73b80015}},	//   _nghệ_, kote_, _пояс, أطلس_
  { {0x1a9c0053,0x2d9e4e6d,0x2d8c0111,0x10a5006b}},	//   זידע, jote_, jnde_, милн
  { {0xd4040080,0xd12e0015,0x2d9e4e6e,0x2fd6002b}},	//   _пяти, شمي_, dote_, ووود_
  { {0x61e9003e,0xfe45000d,0x6d5c012d,0x387e002c}},	//   _twel, днио, öran, útri_
  { {0xee3602bf,0xef160088,0xfce51208,0x14d5004f}},	//   дны_, фмы_, мопо, ֽוֹל_
  { {0xe81e005d,0x9e640029,0x3c650121,0xbc6520b9}},	//   _पहला_, عاين, дког, двок
  { {0xa156000a,0x61fc003d,0x236d0535,0x0000006a}},	//   _קבעה_, _ārli, _klej_,
  { {0x109a000a,0x7ff40015,0x2d8c4e6f,0x25fe000b}},	//   _ובעב, _أسلا, ande_, _लिली_
  { {0x2bcf005d,0xa2f6000a,0xfe4500fd,0x993a005e}},	//   _संवा, ומרה_, _інко, ояву_
  { {0x2d9e402c,0xbbe8002b,0xa3cd000b,0x66044e70}},	//   cote_, _کروم_, रदा_, vrik
  { {0x3f8d08e0,0xa3bf005d,0x475a0892,0xb895006b}},	//   oneu_, ीदा_, орая_, ертъ
  { {0x290401e2,0x8b950010,0x27fe00bd,0x68e10061}},	//   şma_, _прыч, štno_, ılda
  { {0x80a4014e,0xdcfa0048,0x27ed016f,0x69d5005d}},	// [bc80] _चुने, litā, ćena_, _यूपी
  { {0x59830f54,0x0585005e,0xb9c60015,0x66044e71}},	//   _альб, нуєм, _تتعه, rrik
  { {0xdcfa0024,0xdb060d46,0xf993000a,0x66044e72}},	//   nitā, elké, _ברז_, srik
  { {0x2d9e000c,0x2ca74e73,0xdb160003,0xa857000a}},	//   zote_, _mynd_, écèd, _חיטה_
  { {0x2d9e0705,0x2d8c4715,0x24f600af,0x0000006a}},	//   yote_, ynde_, _очвр,
  { {0x2366016f,0xba9b000a,0x98a3003d,0xc1040067}},	//   skoj_, חסני, lejā_, روعي
  { {0x2d9e1aa1,0x69d5000b,0xdb040125,0x7ff30015}},	//   vote_, _यूनी, _dhiú, نسيا
  { {0x2d9e000c,0x236d00bd,0x934307c1,0x547b000a}},	//   wote_, _glej_, _инсе, _וטלו
  { {0x2d9e0007,0xdce1003d,0x62660058,0x0000006a}},	//   tote_, cilī, _غارق,
  { {0xe16a0018,0xdce8003d,0x61e22490,0xdb040125}},	//   _بصره_, vidē, mpol, _ghiú
  { {0x2d8c0012,0xdcfa003d,0x20330015,0x61e24e74}},	//   rnde_, gitā, _لفلس, lpol
  { {0x3dc70012,0x61e24e75,0x2d9e4e76,0x0000006a}},	//   _einw_, opol, sote_,
  { {0x7e9a0029,0x2d9e40d5,0x0a6b005e,0x61e24e77}},	//   _بنشر_, pote_, ірми_, npol
  { {0x2ca70176,0x3f840962,0x61e24e78,0xd90f002b}},	//   _fynd_, limu_, ipol, جید_
  { {0x58d40e37,0x6d4a0e81,0x6458008c,0xdce8003d}},	//   тост, _infa, ävil, sidē
  { {0x4bfb0008,0x3f844e79,0x65ab2e2d,0x1bfb000a}},	//   _ולהס, nimu_, rühm, _ולהב
  { {0x35b50083,0x60da00b8,0xa3e7000b,0xd7c4004a}},	// [bc90] ебар, _oftm, _मौज_, тёро
  { {0x3f84000c,0x9999002a,0x65b0008c,0x61e24e7a}},	//   himu_, żyło_, täha, dpol
  { {0x3f84084b,0x6db2002a,0x236d4e7b,0x68f54e7c}},	//   kimu_, _błaz, _plej_, mazd
  { {0x14df014e,0x66020007,0x3f840007,0x92950010}},	//   _प्रण, šoka, jimu_, наец
  { {0xdb160152,0xdcfa003d,0x2d8b0030,0x3f841c4e}},	//   écéd, zitā, écek_, dimu_
  { {0xe3d70015,0x6d5c0123,0x80c9000b,0x50d5002b}},	//   _يتزع, öral, िखें, رزتر
  { {0x25a10089,0x10a20f5c,0x4fa5006b,0x61e24e7d}},	//   mohl_, лишн, никв, apol
  { {0xdcfa0048,0x6d4a37a0,0x65b00012,0x95fb000a}},	//   vitā, _anfa, nähn, ַּ֖ח
  { {0x3f8d08e0,0x61e2005c,0xee39005e,0xf2cb000b}},	//   rneu_, cpol, їно_, िशीघ
  { {0x128a0086,0x68f50d55,0x672d007c,0x3f840072}},	//   _عملی_, jazd, heaj, aimu_
  { {0x672d003f,0x0000006a,0x0000006a,0x0000006a}},	//   keaj,   ,   ,
  { {0xdcfa0024,0x6d4a4e7e,0x5319000a,0x798e0034}},	//   ritā, _enfa, הוֹצ, wnbw
  { {0x8b950033,0xeef6000a,0xda07000b,0x672d00d4}},	//   трэч, _נמסר_, वंगत_, deaj
  { {0x317900b2,0x68f500dc,0x127a0053,0xdcfa0024}},	//   לאָד, gazd, לארע, pitā
  { {0xa3bf005d,0x61e20844,0x2d854e7f,0xf8bc0065}},	//   ँगा_, zpol, mile_, ोखेप
  { {0xc7a30004,0xc052004c,0x645801be,0x2d854e80}},	//   гиск, נזן_, ävim, lile_
  { {0x9aeb000a,0x060a0033,0x66e00046,0xa6aa0015}},	// [bca0] _מַיִ, янак_, jáků, سارق_
  { {0xba9b000f,0x2d854e81,0xdcfa0045,0x8936000a}},	//   _מספי, nile_, mită, _נָ֥א_
  { {0x61fb022d,0x13060083,0xdcfa04f9,0xf917000a}},	//   _avul, езем, lită, _אחיך_
  { {0x2d85390a,0xb7db000a,0x61e22e14,0x73360058}},	//   hile_, _מקטי, tpol, عرائ
  { {0xdcfa04f9,0x3f840007,0x61d70036,0x8b080089}},	//   nită, vimu_, емія_, _zpří
  { {0x61e404f9,0x7243002b,0x916c0016,0x63ab007c}},	//   ţilo, اپول, _bốn_, algn
  { {0x3f842254,0x877a000a,0x6d5c007c,0x2d854771}},	//   timu_, ּאִי, öram, dile_
  { {0x7c3e00dc,0x26ee005d,0x2d851804,0xa3cd000b}},	//   _ápri, _ज़ोर_, eile_, रदर_
  { {0x916c0092,0x63a2253c,0x2d854618,0xc246006b}},	//   _tồn_, moon, file_, _янак
  { {0x867b000a,0x51fb000a,0x2d854e82,0xdcfa0045}},	//   פריו, _מהמצ, gile_, dită
  { {0x0577000a,0xfe6f002b,0x201a0144,0x4c94016a}},	//   גגים_, لدی_, àpid_, тинс
  { {0xe0df0092,0x63a20035,0x2d85002d,0x2057000a}},	//   _đòi_, noon, aile_, _ריאל_
  { {0x645800f2,0x2d8530c5,0x8b080046,0x9d180004}},	//   ävij, bile_, _spří, _жолт_
  { {0x4aa5005d,0x65b000b8,0x9e77000a,0xce37000a}},	//   _गुणव, wähn, _אגדה_, _נאות_
  { {0x27ed016f,0x63ab002e,0x9cd7000a,0xb8e9000b}},	//   ćeno_, ylgn, _אווה_, _ऋण_
  { {0x25a1018b,0x2cb10064,0x63a20e95,0x61f90034}},	//   wohl_, üzde_, joon, yswl
  { {0xdcfa0011,0xb9990001,0xfb38004c,0x63a2007c}},	// [bcb0] cită, _ових_, _טאהש_, doon
  { {0xd251002b,0x6d9c0061,0x96340033,0x96570033}},	//   ینا_, _uçağ, ынуц, лiвы_
  { {0x63a2016b,0x51f5002b,0x8b080046,0x3387006b}},	//   foon, چستر, _upří, нудв
  { {0x200700bd,0x7bdb000a,0x9962003d,0xfa6b000a}},	//   vrni_, פקדו, _cīņu_, ּכַּ
  { {0xe0ce04ae,0xcad8000a,0xdb040546,0x68e30072}},	//   ив_, גודת_, _skië, _õnds
  { {0x91020054,0xdce80091,0x2d850072,0x659544db}},	//   апше, midė, xile_, _рагу
  { {0xdcfa0045,0x4174006e,0x2d854e83,0xd0160058}},	//   zită, دانس, vile_, نقوش_
  { {0x2d85002a,0x916c0016,0xc01c0016,0x9f5c0069}},	//   wile_, _vốn_, _hước_, trvá_
  { {0xdce10048,0xe3b00225,0x32190002,0x81d5005e}},	//   eklā, _طرف_, _زياد_, _розх
  { {0xdcfa0011,0x4d654e84,0x1c450511,0xa5bb002a}},	//   vită, тков, вном, _spój
  { {0x2d854e85,0xc4d20008,0xfc05006b,0x3b0a1797}},	//   rile_, יגי_, ъпно, мено_
  { {0x3d13005d,0x005600a3,0x6ee70015,0xdcfa0045}},	//   _दावे_, _בשעת_, _أسال, tită
  { {0x3f7a0053,0xff500029,0xeaf2000b,0xbb86002b}},	//   _קאנס, _دخل_, _अजीत_, فلگي
  { {0xc01c00a7,0xdcfa0011,0xdce80007,0x63a2003f}},	//   _nước_, rită, didė, zoon
  { {0x63a2003f,0x3c440015,0xdcfa0045,0xdce80091}},	//   yoon, _مضيف, sită, eidė
  { {0x9a6a0029,0xca740086,0xab9a0015,0x8a960015}},	//   _يمثل_, _منعک, _تختر_, _لشخص
  { {0xc01c0023,0xfaa6000d,0x24f6000d,0x7c240085}},	// [bcc0] _bước_, _јапо, вчер, _ćiri
  { {0xf5070080,0xc01c0092,0x63a20150,0x09f7000a}},	//   кнул_, _cước_, woon, _שמים_
  { {0x1c09005d,0xdce80091,0xf3d70015,0x65634e86}},	//   _विफल_, aidė, نولث_, önha
  { {0xc2c60086,0x91e6030e,0x2897000a,0xf2060033}},	//   نياي, воде, _ידין_, вяко
  { {0x2564002e,0x63a24e87,0x82330015,0x7053002b}},	//   _sölu_, roon, لروا, ینها
  { {0x04ca0015,0x63a213c8,0x8a7b000a,0xa0b800af}},	//   _يوحي_, soon, ואנת, нглу_
  { {0xf9930008,0x63a2003f,0xf1a90067,0xa989004f}},	//   ברג_, poon, راهه_, עָנִ
  { {0x200e000c,0x65b000b8,0xc692000a,0x442a3ca3}},	//   rufi_, zähl, ֹא֙_, _ipb_
  { {0xab5b0012,0x6ce602a3,0x201c00bc,0xd2a7098b}},	//   hmüc, кіне, stvi_, _акте_
  { {0x2564002e,0x6b8406d4,0xd24f0015,0x114a0015}},	//   _tölu_, _amig, _بنك_, _تجرى_
  { {0x217520ed,0xd00f0015,0xa177000a,0x753c4e88}},	//   _сутр, _ولك_, _שעבד_, _marz
  { {0xf413013a,0x65b000b8,0xdce10024,0xdb0f0064}},	//   ספר_, wähl, rklā, _ödül
  { {0xc33304dc,0xd2460029,0xed5a0063,0x65ab0020}},	//   בור_, حن_, _оод_, sühi
  { {0x753c0050,0x2bd9002b,0xc98703ae,0x6b844e89}},	//   _narz, بایک_, туми, _emig
  { {0x97a70080,0xc01c0092,0xd7f80848,0x9b450015}},	//   врал, _rước_, кут_, _منغو
  { {0x25fe000b,0xdce80091,0x753c0079,0x5b1549eb}},	//   _लिखी_, tidė, _aarz, _смит
  { {0xc7c80080,0x46150029,0xa3be000b,0xc6a70054}},	// [bcd0] тыре_, طوار, ुआई_, трви
  { {0xe6100029,0xdce80007,0x6aad00dd,0x9e77000a}},	//   تشف_, ridė, _iyaf, דגמה_
  { {0xdce80007,0x97c70015,0x7bcd0091,0x4438050b}},	//   sidė, _لتحم, _kiau, _csr_
  { {0x20130251,0xd7f10092,0x9888000a,0x76eb0015}},	//   àxim_, ẫu_, _יָרֵ, _تعدّ_
  { {0xc01c0092,0x6b7c015b,0xd5c500ce,0x0000006a}},	//   _tước_, וראנ, вiдн,
  { {0x7bcd0007,0x7c380085,0x753c36c5,0x321d0535}},	//   _liau, _osvr, _garz, rtwy_
  { {0xc95400a3,0x491b000b,0x321d002a,0x90450040}},	//   ימס_, _बानो_, stwy_, انبه
  { {0x753c0050,0xb4c1000b,0x27fe0030,0xee390317}},	//   _zarz, ुशी_, átni_, ени_
  { {0xa6e2002e,0x5cf50839,0xa5bb016e,0x673d2da4}},	//   óðin, ляну, _apói, _masj
  { {0x25761946,0x27fe00bd,0xdfd50033,0x673d00bc}},	//   _vælg_, štni_, _божы, _lasj
  { {0x9f0504c9,0x63bb0092,0xa0c40015,0xc4b1000b}},	//   _موضو, _khun, _نيكو, _झरोख
  { {0x2bba003b,0x673d003c,0xb4360008,0x65ab0012}},	//   عادة_, _nasj, נָיו_, mühu
  { {0x239800bc,0xde051764,0x0000006a,0x0000006a}},	//   nčja_, _спли,   ,
  { {0xd9460054,0x64472441,0xc27a000a,0xfce20763}},	//   ћеви, _orji, גרשי, _лошо
  { {0x63a900bd,0x3104000b,0x9d1a000a,0xef26007c}},	//   _oken, रणतः_, _נוקט, üügi_
  { {0xe7370180,0xb6a6034e,0xa6ca0004,0x63bb0016}},	//   лес_, гибл, елба_, _nhun
  { {0x7a85002b,0x644302de,0x753c4e8a,0x673d0012}},	// [bce0] _پشيم, ænin, _parz, _dasj
  { {0x63a911c5,0x201801ee,0x442a4e8b,0x649a0979}},	//   _aken, _årig_, _ppb_, нтер_
  { {0x63bb002d,0xd91b000a,0x69d6492b,0x649a027a}},	//   _bhun, _אויל, _huye, хтар_
  { {0xe29a4e8c,0x63bb1323,0x69d60573,0x753c0b65}},	//   нае_, _chun, _kuye, _warz
  { {0x5186000d,0x2377002b,0xa6830c6e,0x27f60046}},	//   лука, دمند_, _гляд, šeně_
  { {0x64a64e8d,0xc4c60015,0x673d0085,0x29f2003d}},	//   _бага, _متزو, _zasj, iņa_
  { {0x629c0050,0x8026002b,0xb0260015,0x7644008c}},	//   _środ, ارتم, اءته, lviy
  { {0xb4c0005d,0x7af6002e,0x04930029,0x33b60058}},	//   ँधी_, _neyt, _الفح, _إمرأ
  { {0xe731000a,0x8fa30054,0x6e030015,0xa5bb0125}},	//   חֵי_, љање, مِين, _spói
  { {0x90d50023,0xa3d3005d,0x71d70008,0x7bcd0007}},	//   _hàn, _हूँ_, _עובד_, _siau
  { {0xdb55005f,0x6aad0375,0xf5400033,0x65ab0012}},	//   авны, _syaf, скiм_, müht
  { {0x213e003e,0x44444e8e,0x69d608b8,0xb09b000f}},	//   _hath_, iv_, _buye, _איבר
  { {0xc333013a,0x44440020,0xb69b0011,0x7e7b002a}},	//   זור_, hv_, _adân, czup
  { {0x2018007c,0x2d8b0030,0x90d50016,0x6d4b0061}},	//   _äris_, écet_, _làn, ğlaç
  { {0xa3d3005d,0x213e0495,0x8cdb000a,0xe0ce005e}},	//   _हूं_, _math_, _אחות, овi_
  { {0x17f80015,0x8c1b000a,0x44444e8f,0x69d00073}},	//   طرفة_, _נוחי, dv_, _žiež
  { {0xa3da000b,0x213e00da,0x929d002a,0xd50b0067}},	// [bcf0] _डूब_, _oath_, _odła, فغان_
  { {0x63a946cd,0x7af60405,0xd49b09c3,0x8e2000e2}},	//   _sken, _zeyt, нре_, _мiж_
  { {0xd6d1003b,0x3d1c005d,0xc952000a,0x2cfb004c}},	//   _وقد_, _माने_, _ומי_, גלבא
  { {0x90d50092,0x0000006a,0x0000006a,0x0000006a}},	//   _càn,   ,   ,
  { {0x44440048,0x90d50092,0xab7c004c,0x5b7c004c}},	//   av_, _dàn, עװדי, ערדא
  { {0xa5930086,0xa4d40036,0x213e130f,0x614503a8}},	//   _اگرچ, _горі, _cath_, река
  { {0x70520029,0x63bb4d94,0x213e0125,0xdce8003d}},	//   قنوا, _thun, _dath_, aidī
  { {0xe7b5005d,0x63a901f0,0x6f65097d,0x660d4e90}},	//   ंतिप, _uken, рвиз, orak
  { {0x7af6002e,0x44210b00,0x213e0112,0x660d4e91}},	//   _reyt, lth_, _fath_, nrak
  { {0x44214216,0x213e0f4a,0x4d14004a,0x0c252f6a}},	//   oth_, _gath_, бьют, амон
  { {0x44210b00,0xdcfa003d,0x644a0012,0x7af64855}},	//   nth_, entē, äfix, _peyt
  { {0x1ee70086,0x660d192b,0x44211d43,0xcd28002b}},	//   _صوتی_, krak, ith_, پسین_
  { {0xeb970404,0x386a0026,0xeab200e6,0x333f0003}},	//   рия_, wybr_, تعد_, _maux_
  { {0xfce50124,0x1d09009f,0x9e7a000a,0x4e7a000a}},	//   _токо, _реки_, _שנספ, _באנצ
  { {0xdd34002b,0x65b0008c,0x02b2000b,0x660d4e92}},	//   _درنظ, sähk, _जर्न, erak
  { {0x8c1a0008,0xd62a0054,0xdc9a000a,0x6d414e93}},	//   _סופי, кобе_, _שיקל, ldla
  { {0x44210b7c,0x67240111,0xe73703a9,0xf99f0251}},	// [bd00] eth_, rfij, шет_, guès_
  { {0x79fb0008,0x7abb0008,0x4421003e,0x90d50092}},	//   _שליח, _בצפו, fth_, _sàn
  { {0x6d410bc8,0x74130021,0x84560099,0x213e4e94}},	//   idla, قولا, шњач, _rath_
  { {0x779404b6,0x68fc01e2,0xdc8c0053,0x6d4101d7}},	//   _ایرا, lard, עװאָ, hdla
  { {0x98b30011,0x44211c43,0x213e2390,0xab5b0061}},	//   _taxă_, ath_, _path_, kmün
  { {0x333f0152,0xd24f0021,0x68fc4e95,0x29184e96}},	//   _eaux_, بنه_, nard, ngra_
  { {0x21670001,0x333f1151,0xb97b000a,0xcfe800c3}},	//   рији_, _faux_, כנסי, دفعه_
  { {0x93160086,0x543b0053,0x68fc4e97,0xc7d7000a}},	//   _خورش, _בעלא, hard, סופי_
  { {0x27ed016f,0xad6600c3,0x68fc4e98,0x22290015}},	//   ćeni_, لاده, kard, _مثلي_
  { {0xe2a60084,0x65b000b8,0x91bf0016,0x213e0125}},	//   íðum_, fähi, _trú_, _uath_
  { {0x10a60036,0xd3140036,0xdcba0063,0x660d0ca3}},	//   _тижн, _вiдт, ъщи_, zrak
  { {0xdfcf0029,0xbb940080,0x3182005c,0x2d8701f0}},	//   _قيل_, жающ, ższą_, _emne_
  { {0xdb0a0030,0x68fc4e99,0x0f7b004f,0x0000006a}},	//   ónál, fard, _בראל,
  { {0x9e650086,0x3af50092,0xac18022a,0xae7b000f}},	//   _دامن, ấp_, _боку_, _שְׁת
  { {0xb8680292,0x2bd0005d,0x4421003e,0x2b40002d}},	//   ајте_, _संचा, xth_, _faic_
  { {0x2918002f,0x8b6700b0,0x36d50063,0x68fc2ba3}},	//   agra_, _خاتم, соар, aard
  { {0x7bd801d1,0x3bbc0008,0x4421003e,0x76b9023e}},	// [bd10] _huvu, _במהד, wth_, улар_
  { {0x2d8c0005,0xe4e70036,0x7bd8003f,0x05770029}},	//   nide_, ріан, _kuvu, جارد
  { {0x65ab018b,0x7afd1213,0xb5a40033,0x44210220}},	//   führ, oast, іруй, uth_
  { {0xa3b40191,0x2d8c0422,0xa5bb002e,0x44210495}},	//   обхі, hide_, _apót, rth_
  { {0x2d8c0005,0x7bd8022d,0x07560008,0x13080036}},	//   kide_, _luvu, _הסרט_, рній_
  { {0x463a00b2,0x4421003e,0xd1310029,0x7afd4e9a}},	//   _געשע, pth_, سمع_, hast
  { {0x333f0152,0x65ab00b8,0xdb0e0030,0x2d8c4e9b}},	//   _taux_, bühr, őjéb, dide_
  { {0xdfa40029,0x2d8c0f55,0x2898000a,0xc898000a}},	//   يحيي, eide_, ידון_, יכוז_
  { {0x52850029,0x68fc0d51,0x7afd4e9c,0x2d8c4e9d}},	//   _الذك, yard, dast, fide_
  { {0x7bd80007,0x26b6000f,0x30a7387e,0x2d8c4e9e}},	//   _buvu, מִים_, _крев, gide_
  { {0xbb460a61,0xcb6a2246,0x68fc46d3,0x9e64002b}},	//   бенк, гане_, vard, ماین
  { {0xe45600b2,0x2576002e,0x316500b8,0x68fc11a3}},	//   צירט_, _mæla_, _holz_, ward
  { {0x139a0053,0x9d450080,0x68fc052a,0x539a00a3}},	//   רברע, _гелд, tard, רירו
  { {0x68fc002f,0x0fd6005d,0x6d5c0020,0x3f8d4363}},	//   uard, _ढूँढ, örat, lieu_
  { {0x4807006b,0x46c5000b,0x66e6005e,0x2918001a}},	//   йерн_, लेसह, йова, rgra_
  { {0xea5a03f1,0xd6d20015,0x7c940015,0x2246006f}},	//   _број_, سقط_, _بشها, yvok_
  { {0xe4d60029,0x96f90010,0x3eda004c,0x4df9004c}},	// [bd20] متاب, рэсу_, אַבא, טפּא
  { {0xceb2039e,0x4a5b015b,0xed15000a,0x3f8d1193}},	//   לין_, _עדיו, מַ֣ת_, hieu_
  { {0xd8d700b2,0x0fd6000b,0x6cfa004c,0x07a60418}},	//   _לויט_, _ढूंढ, רפעס, _ганн
  { {0x8bd6000a,0xdce30046,0x2d8c4e9f,0xd46700af}},	//   צונו_, _plně, zide_, љице_
  { {0x65ab00b8,0x2369007c,0xe2970054,0x22d50033}},	//   rühr, öaja_, бац_, іццё
  { {0x6458022d,0x7afd099c,0xdb0608e9,0x89e9000a}},	//   ävis, zast, llkä, בַקֵ
  { {0x55770053,0x7109005e,0x2d8c4ea0,0xa81a000a}},	//   _פעלן_, рхів_, vide_, אֵ֥י
  { {0x2d9900dc,0x33960015,0x2d8c00da,0x6d450030}},	//   ésen_, _الرز, wide_, _óhaj
  { {0x2d8c0020,0x7afd4ea1,0x9046002b,0xed14004a}},	//   tide_, vast, _گناه, омпь
  { {0x71650029,0x867b0008,0xf653000a,0x38c30003}},	//   _والك, טרפו, פצת_, néré_
  { {0xb09a0036,0xc334000a,0xcb99005e,0xa6db001a}},	//   _стає_, ֗וֹ_, ивої_, _laða
  { {0xd366003b,0xdced0024,0x3f8d0251,0x0057000a}},	//   ذه_, ējād, cieu_, _לשבת_
  { {0x256f0064,0x7afd4ea2,0x2d8c4ea3,0x2b1a0065}},	//   _yılı_, rast, pide_, _भारु_
  { {0x7afd33fc,0x0c7a0021,0xcebf0046,0x7bd8003d}},	//   sast, _مصعب_, ářem_, _tuvu
  { {0x38c30152,0x8078000a,0x7ae40034,0x2cfb000a}},	//   déré_, בְּה, _ffit, _גלוא
  { {0xe8940010,0xc6a70004,0x89d9002b,0x35f51ece}},	//   чась, брзи, _پودر_, жпар
  { {0x38c30003,0x07080015,0x45d4004a,0xf1a8000b}},	// [bd30] féré_, صيلي_, зоус, गवान
  { {0x67d50007,0xd371002b,0x99f8000a,0x7d1a1dbf}},	//   _sąju, ژها_, _הזזה_, ngts
  { {0xe4350074,0x66d5002b,0x36d51068,0x0000006a}},	//   تفاد, _ويدئ, _монр,
  { {0x8c1b000a,0xdfc60015,0xdb060030,0x69c70030}},	//   רואי, _زي_, toké, lmje
  { {0x3f8d08e0,0x38c90086,0x645800f2,0xa204005e}},	//   vieu_, _حاکی_, ävir, зпід
  { {0x11d40029,0x9f910046,0xdb060069,0xa0690195}},	//   ستهد, _vší_, roké, иала_
  { {0x80240015,0xd91c000a,0x8fa500c3,0x55ba000a}},	//   كريم, טוגל, يمته, _כמשו
  { {0xce590015,0x8e0901c5,0x984c01ec,0x0000006a}},	//   لشخص_, анив_, lēģa_,
  { {0xfd110029,0x63ab3bdc,0xab5b068c,0xdde8002b}},	//   وجد_, mogn, rmül, یریه_
  { {0x98ba0048,0xfc290080,0x1d090001,0x4d14004a}},	//   _lapā_, ажок_, јени_, пьют
  { {0x3f8d0251,0x4095002b,0xf1c80015,0xdb06008c}},	//   pieu_, _بلار, _اولى_, ylkä
  { {0x98b80007,0x65b00f7a,0x9f35005e,0x6d5c0123}},	//   ndrą_, läht, _феді, örar
  { {0x433a0053,0xa2dc000b,0xdaba0033,0xed591c80}},	//   בערב, _फलस्, рыні_, _вол_
  { {0x65b00005,0xa6db002e,0x2eff00b8,0xfe9a0008}},	//   näht, _raða, lauf_, _דינמ
  { {0x3855006b,0x68430046,0x38cb002b,0x18670663}},	//   пътс, vídá, لافی_, оари_
  { {0x6d434ea4,0xdc880008,0x7ae4003f,0x6f1b0049}},	//   _hana, _לְפָ, _ufit, nguc
  { {0xd5e90029,0x05663433,0xef19002a,0x6736001a}},	// [bd40] معلن_, ован, chże_, reyj
  { {0xa5bb3705,0x65b0008c,0x6736001a,0xa50a10a1}},	//   _spór, jäht, seyj, режа_
  { {0x63060015,0x61e94ea5,0x224d01d7,0x37c60015}},	//   قوال, _atel, _arek_, _ويخف
  { {0xfe67003b,0x443a0034,0x38c30003,0x224d01c2}},	//   _قد_, rwp_, séré_, _brek_
  { {0x1154006b,0x38c30003,0xdce1002a,0x31c61560}},	//   зклю, péré_, sklę, оскв
  { {0x7bcf0227,0x6d434ea6,0x6536002b,0x6a710030}},	//   íbuz, _nana, _برحذ, _hófú
  { {0x657e017e,0x61e900f2,0x91350033,0x660400cb}},	//   mhph, _etel, яхці, lsik
  { {0x63ab4ea7,0x69c7016f,0x6d4316ad,0x2453006e}},	//   cogn, zmje, _aana, _تنفس
  { {0xddea0067,0x877b000a,0x71ea0015,0x6d434ea8}},	//   جربه_, יאקי, _ضفاف_, _bana
  { {0xa2a3005d,0x8178000a,0x6d430c5a,0xfbe90016}},	//   _छुट्, _פְּק, _cana, _tuệ_
  { {0xdd97008f,0x55bb000a,0x3ce9000b,0x6d434ea9}},	//   ўшы_, שמיו, छड़े_, _dana
  { {0x61e9003c,0x9e6600e5,0x6fb60015,0x660441fd}},	//   _ytel, _واشن, _بمصا, ksik
  { {0x09e40010,0x539b000a,0x6d43283c,0x4e9600c3}},	//   моўн, שיכו, _fana, _بشار
  { {0x27350023,0x6f000064,0x644e0901,0xaac7000b}},	//   _ấn_, lamc, _orbi, रेषक
  { {0x98480063,0xf77303c4,0x8bb70029,0x9f580030}},	//   оята_, وار_, _وإعا, _író_
  { {0x69c70085,0x907b000a,0x660b0030,0x6d434eaa}},	//   smje, בטלי, ágko, _zana
  { {0x6d43000c,0x7ada0008,0xc4db0001,0x85750063}},	// [bd50] _yana, _לַיה, ађе_, плах
  { {0x344b4eab,0x6f000125,0xd5b100c3,0xc517012c}},	//   ичен_, hamc, رفا_, تبرت
  { {0x917b0092,0x34b50015,0x66044eac,0x04880054}},	//   hệ_, أماز, asik, ољци_
  { {0x224d018c,0x883a0008,0xb866002b,0xca48009a}},	//   _prek_, _פתרו, _راپو, _الیه_
  { {0x65b00209,0xc0e502bf,0x41e40015,0x66040030}},	//   täht, полк, وسوف, csik
  { {0xc244008f,0x63ab151c,0x2a3c004c,0xd24e0040}},	//   ьнік, sogn, יעדמ, انو_
  { {0xddc9005c,0x66020007,0xf994000a,0x2d990030}},	//   rzeż, šokt, ורס_, ésem_
  { {0x889c000a,0xb89c000a,0x6d434ead,0x65b0008c}},	//   יבוי, יבוש, _sana, säht
  { {0x2eff018b,0x61e902df,0x6d434eae,0xe3b00040}},	//   rauf_, _utel, _pana, _شرف_
  { {0x0d824eaf,0x6b8d4eb0,0x41770002,0xac851591}},	//   ельн, _amag, _بارس, згол
  { {0x3d1c014e,0xc1720008,0x6d431c00,0xff530015}},	//   _मारे_, _רחב_, _vana, _يخص_
  { {0x6d43000c,0x65b000b8,0x60ba0008,0x00ba000a}},	//   _wana, nähr, _הצעד, _המעמ
  { {0x433a0053,0x6d430375,0x34b8000b,0xee2e1006}},	//   זערב, _tana, _अर्द, _ян_
  { {0x6d43003f,0xdce30ea5,0xfe790046,0x66040123}},	//   _uana, _konč, ncům_, vsik
  { {0xb0b50053,0x764f005c,0x08c30001,0xd5c5005e}},	//   לפֿס_, _arcy, ебрн, гiон
  { {0xab660036,0xb7590036,0x65b000b8,0x68430010}},	//   _хвил, ошує_, jähr, энса
  { {0xfbd3013a,0x644e1007,0xcbc50029,0xf99f0999}},	// [bd60] _אתה_, _srbi, _تزوي, grès_
  { {0x6b8d03df,0x0585005e,0xaaa5000b,0x66044eb1}},	//   _zmag, муєм, _गुटक, rsik
  { {0xc6890008,0x65b000b8,0xf8db0008,0x66044299}},	//   נא_, fähr, _לחימ, ssik
  { {0xfa76000a,0x62820079,0xe3b20040,0x7bd601d7}},	//   ּעַת_, tzoo, ررا_, _jiyu
  { {0x4b4d00b2,0xd4f60033,0xe2970054,0xc3270015}},	//   יגאַ, _нявы, пац_, سكون_
  { {0x7d0100bd,0x40342c7f,0x76bb000a,0xdb0601d3}},	//   jals, декс, _למכפ, dokí
  { {0x9479005e,0xc953000a,0xe3660515,0x64a30ef5}},	//   _дсту_, תמו_, _екви, _зара
  { {0x749b004c,0x7bd602f2,0x232706a6,0x0000006a}},	//   _הילפ, _niyu, _носи_,
  { {0x80a6002b,0x12eb000a,0x8e230138,0x63a301d3}},	//   _کمان, _הַבּ, нфэд, énne
  { {0xc24312ba,0xc5f3000a,0x427b000a,0xc27b000a}},	//   _янук, עדת_, _האמג, _הרמי
  { {0x6b9d0030,0x239800bc,0x6f060030,0x16b90065}},	//   érgo, ečji_, ókcs, _आर्ब
  { {0x7bc404ed,0x7d010020,0xdce80064,0x1f55004a}},	//   _chiu, aals, ğlıy, _отчё
  { {0x59da014e,0x7d014eb2,0xdce80064,0x2aab03ad}},	//   _यूआर, bals, şlıy, стно_
  { {0x5e57013a,0x827700b2,0xd90f0074,0x5e430015}},	//   _מידע_, לעכע_, دید_, _أَوْ
  { {0x68fe00e8,0x6d583206,0x6d480034,0x0000006a}},	//   _depd, _inva, mdda,
  { {0x5ba4008f,0x6b8d4404,0xdc9b0447,0xf99f0144}},	//   _прыз, _umag, _לסוכ, très_
  { {0x98ba0045,0x1634030c,0x6d480535,0x0000006a}},	// [bd70] _papă_, нетя, odda,
  { {0x65b000b8,0xf9fc0008,0x6d484eb3,0x35b409ba}},	//   währ, _ההזמ, ndda, ебур
  { {0x6d480f3c,0xf8c1000b,0x84390015,0xfe790046}},	//   idda, _एरिय, تكار_, vcům_
  { {0x92950010,0xf99f0291,0xf4100015,0x33750323}},	//   маец, près_, اؤل_, ьгер
  { {0x2d990014,0x6d584aec,0xdce300bd,0x21691e64}},	//   ések_, _onva, _sonč, жили_
  { {0x20d5005e,0x29034eb4,0x265a004f,0x365a004f}},	//   мійс, naja_, _וכשא, _וכשנ
  { {0x7d01018c,0x69d7003e,0x7ae60123,0x8fa50b1e}},	//   vals, _mixe, yckt, маке
  { {0x08580008,0x6d480026,0x29031e1f,0xe7bf000b}},	//   לבום_, edda, haja_, ्षिप
  { {0x7e960086,0x3f830091,0xc332000a,0x7d014eb5}},	//   وچهر_, ėju_, _בון_, tals
  { {0x72040029,0x63b90026,0x7bd60035,0xb609003d}},	//   _أولم, llwn, _siyu, _izšķ
  { {0x7d014eb6,0x29034eb7,0xc10400c3,0x0000006a}},	//   rals, daja_, _سوني,
  { {0x69d70251,0x9bca0015,0x3e350015,0x799c0034}},	//   _aixe, توجك_, _يفار, wnrw
  { {0x7e280029,0x1d090684,0x98ba002a,0x89f6056d}},	//   _فسوف_, _дели_, _mapą_, ьянц
  { {0x3afc0092,0x98ba0091,0x29034eb8,0x4dda004f}},	//   ập_, _lapą_, gaja_, _וחסו
  { {0xb906000b,0x66e64eb9,0x99820046,0x6da20bbb}},	//   _फल_, доба, stků_, _шиша
  { {0x69c50014,0x1bfa0008,0xabfa000a,0x635e0045}},	//   _ehhe, _ולקב, _והקר, _mănâ
  { {0x6fea005c,0xd6250029,0x1b290015,0x69d70287}},	// [bd80] _ięce, فعلي, _رأيي_, _fixe
  { {0xf1e1005d,0x29034eba,0x98aa002a,0x9a250015}},	//   _पढ़न, caja_, zebę_, _أعين
  { {0x53e50191,0x7c28000a,0x47c6005e,0x03260342}},	//   еціа, ּ֥עַ, _обов, дден
  { {0x6e2943ce,0x0000006a,0x0000006a,0x0000006a}},	//   kteb,   ,   ,
  { {0x6d484ebb,0xf1aa0015,0x66350033,0x7afb001a}},	//   ydda, ياته_, _пэрф, ðuti
  { {0xc69300b2,0xf917000b,0x61fb002a,0x6e290030}},	//   _יאר_, _ताज़ा_, _dwul, dteb
  { {0x98b10045,0x0000006a,0x0000006a,0x0000006a}},	//   meză_,   ,   ,
  { {0x33660010,0x98b10045,0x6d480034,0x29030e2a}},	//   _ўваг, leză_, wdda, zaja_
  { {0xc7b30008,0x2903003f,0x2dd401c5,0x66a9000a}},	//   כבה_, yaja_, нжир, ּיתֶ
  { {0x98b10011,0xa1c30033,0x3eb8003d,0xdb0f016e}},	//   neză_, _абуд, ārt_, cocê
  { {0x29030796,0x6d484ebb,0xe06a0015,0x7db30015}},	//   vaja_, rdda, _بإذن_, خصيا
  { {0x23660085,0x2c4c0046,0xeef60033,0x26c200bc}},	//   njoj_, _věd_, _цяжэ, _ozko_
  { {0x29034ebc,0xda7b0127,0x7d7a0015,0x61e00fa0}},	//   taja_, іям_, _ومصر_, _juml
  { {0x6d580f0a,0x66164ebd,0xdebb004f,0xb4dd0065}},	//   _unva, dryk, _ומדל, _डले_
  { {0x5ba70ea6,0x98b10045,0x29034ebe,0x69d701f9}},	//   _ориз, deză_, raja_, _vixe
  { {0x6616002a,0x36d508d7,0x29034ebf,0x804b004f}},	//   fryk, еобр, saja_, חֲמֶ
  { {0xc50b0029,0x8afc000a,0xbafc000a,0x5afc000a}},	// [bd90] قتال_, _והחי, _והחש, _ולחצ
  { {0x2d9e4ec0,0x99d70029,0x7d7b004c,0xd5bb00e2}},	//   nnte_, _تتعا, ֿראג, іса_
  { {0x2d9900dc,0x94750086,0x2d9e4ec1,0x61e0007c}},	//   ései_, رگسا, inte_, _auml
  { {0x2d9e00b8,0x7995003f,0x6616002a,0x6e2900cb}},	//   hnte_, lizw, bryk, yteb
  { {0x29010020,0x63c80015,0xc6a701ca,0x0cbb000b}},	//   _keha_, ذِهِ_, _црни, _उर्म
  { {0xc1050029,0x42520086,0xea78000a,0xfa78000a}},	//   روبي, انور, וגדר_, ועדת_
  { {0xe0570086,0xdce30024,0x25e5000b,0x78fc000a}},	//   بیات_, _nonā, _झंडी_, חלופ
  { {0xfe45000d,0x2d9e4ec2,0x53470033,0x2032002b}},	//   енио, ente_, _ўхва, افيس
  { {0xee361561,0xe732000f,0x6e29016e,0xdea1002b}},	//   ены_, אֵת_, uteb, دیشی
  { {0xdb060107,0x316c002a,0xaec20033,0xdcfa003d}},	//   doká, _godz_, ыбыл, ditē
  { {0x6e2930cc,0x71d6000a,0xa508000a,0xab64002a}},	//   steb, _נועד_, וּרִ, óżow
  { {0x547a000a,0xc4d2000a,0x66ca0030,0x2d9e4ec3}},	//   פטרו, טגי_, nöké, ante_
  { {0x09e3006b,0x8f9a004f,0x29010546,0x9f5c0052}},	//   лоян, _ציני, _beha_, fsvæ_
  { {0x644a0134,0xdca50361,0xf99f03a0,0x0000006a}},	//   æfik, _пали, ssèn_,
  { {0x0d16013a,0x3c450029,0x5d7a015b,0x2c720015}},	//   _טקסט_, _أَبِ, _מאסק, _مُوس
  { {0x61330064,0x4c340033,0xdc36004c,0xdcfa003d}},	//   lılı, _рэшт, _נאפט_, bitē
  { {0x7dec0053,0x98b10045,0x65c60e7c,0xe61a0af4}},	// [bda0] ַקאַ, teză_, ебаа, яда_
  { {0x61330064,0xf202000b,0x89eb000a,0xb5a90015}},	//   nılı, रीफ़_, _מַטֵ, والك_
  { {0xe9a90015,0x61e000bc,0x25e5000b,0x69ce2059}},	//   _تدين_, _suml, _झूठी_, mmbe
  { {0x1ddf005d,0x237f0011,0x2576002e,0x02060195}},	//   नदात, _cluj_, _mæli_, ездн
  { {0x32ba0029,0x61330064,0xcb130135,0xf7d7000a}},	//   أداة_, kılı, רלד_, _רוכש_
  { {0x889a0008,0x90e6002b,0x2fcd0034,0xb2730033}},	//   ּבֵי, رستن, emeg_, ыліш
  { {0xc0e70029,0x638602e1,0x2d9e0293,0xdb060030}},	//   رفين_, _згва, vnte_, zoká
  { {0x7bde0152,0xe3b70033,0xc692000a,0xdb0f0144}},	//   _épui, _збс_, ָא֙_, cocè
  { {0x61ba0029,0x929d002a,0xdbde001a,0x61e0007c}},	//   _فهرس_, _pełe, díán, _uuml
  { {0x44380cc1,0xdb0601c0,0x2d9e4ec4,0x59b40065}},	//   _kpr_, voká, unte_, ंकफर
  { {0x2d9e00b8,0x23ca000a,0x2cb802de,0xb47a000a}},	//   rnte_, ּצָּ, ærd_, לָ֛י
  { {0xab950036,0xd0060086,0xa3c0000b,0x443801d7}},	//   тимі, یل_, ँति_, _mpr_
  { {0x7995003f,0xfe720015,0x4438002a,0xdb0f0140}},	//   tizw, _حدا_, _lpr_, nocé
  { {0x61330064,0x6fc5002a,0xdcfa003d,0x6f020125}},	//   cılı, róce, ritē, _heoc
  { {0x44380198,0xd8380033,0x1dc60065,0x161e0065}},	//   _npr_, нэт_, _रीयत, यूसर_
  { {0x6d4a4ec5,0x1cbb000a,0xccf80046,0x8cbb000a}},	//   _hafa, _ממוע, lbě_, _מצוק
  { {0xc8f5010f,0x29010005,0xccf80089,0x98ba002a}},	// [bdb0] _изпъ, _teha_, obě_, _mapę_
  { {0x443800d9,0xab5b0012,0x656e4b3d,0x290c0030}},	//   _bpr_, flüg, _cobh, ódat_
  { {0x6d4a003f,0x44380fc1,0x656e0030,0x76463b6e}},	//   _mafa, _cpr_, _dobh, _esky
  { {0x61330064,0x443800e8,0x8c1b0008,0xa2d500c3}},	//   zılı, _dpr_, לובי, نيات
  { {0x61330064,0x291e0030,0xd3d80015,0x56580033}},	//   yılı, ótag_, ربما_, _заяў_
  { {0x7c380111,0x6d4a0553,0x22b7002a,0xa696004f}},	//   _opvr, _nafa, _ręką_, _יכרה_
  { {0xa3b50010,0xa1560001,0xe588000a,0x929d002a}},	//   _абві, тају_, _נָשָ, _bełc
  { {0x6455003d,0xb7dc004f,0x0000006a,0x0000006a}},	//   _irzi, הקהי,   ,
  { {0x0ea90191,0x61330064,0x6f024ec6,0x3eb9290f}},	//   ький_, tılı, _deoc, æst_
  { {0x645a16ee,0xec7900ce,0x6d4a187e,0x0000006a}},	//   _átic, дпо_, _cafa,
  { {0x51840010,0x61330064,0x6d4a0026,0xa156000f}},	//   _сута, rılı, _dafa, _שבעה_
  { {0x7ff40029,0x1eea0086,0x61330064,0x6e92002b}},	//   _إسلا, _قومی_, sılı, الیا
  { {0x4a430063,0x61330064,0xa6db001a,0xab290015}},	//   аняв, pılı, _faði, رسَل_
  { {0x6d4a33e8,0x69ce4ec7,0xd94603ae,0xdb060353}},	//   _gafa, umbe, њеви, llkü
  { {0x7aed0026,0xbbe80015,0x2d850046,0x5dc8000a}},	//   _ffat, _كريم_, mhle_, _אֶקְ
  { {0x8c1a0008,0x6d21005d,0x7d030293,0xaa960015}},	//   _חוקי, _माँग_, _hens, _للعث
  { {0xc9aa0083,0x443800d9,0x3cf80030,0xab5b0012}},	// [bdc0] _овие_, _spr_, űrve_, rmüt
  { {0x6455016f,0x225800bd,0x45830036,0x2d850046}},	//   _brzi, _črk_, агув, nhle_
  { {0x7d034ec8,0xa7d60015,0x13060923,0xb97b004f}},	//   _mens, _لتحص, взем, _חריז
  { {0xe29a0010,0x59bc005d,0xd379005e,0xccf80046}},	//   мае_, ोगकर, нчі_, zbě_
  { {0x6d21005d,0xccf80089,0x46a30010,0x64554ec9}},	//   _मांग_, ybě_, _ваяв, _erzi
  { {0xd0100029,0xdb0f0f24,0x67244eca,0x25fb0065}},	//   ملت_, rocé, lgij, _लौटी_
  { {0xccf80089,0x705400e6,0xa6db001a,0x44380cc1}},	//   vbě_, انبا, _raði, _upr_
  { {0x6d4a330e,0x27fe006f,0x67244ecb,0x98ac0091}},	//   _safa, átny_, ngij, ždė_
  { {0x4ea60063,0xccf80089,0x8ed7002b,0x8fa30054}},	//   ърка, tbě_, پذير_, јање
  { {0x44442630,0x7aed0011,0xe7e5000b,0x7d0303b8}},	//   ow_, _sfat, कदमा_, _cens
  { {0xfe6f0074,0xdce10048,0x351b0632,0x5d630010}},	//   مدی_, eklē, ווינ, ртыз
  { {0x6d4a363d,0x4095006b,0x63a24ecc,0x2d8504b2}},	//   _wafa, _срут, nnon, ahle_
  { {0x6d4a0f4d,0x44440026,0x7d034ecd,0xa9970021}},	//   _tafa, hw_, _fens, نشست
  { {0xf2d300b2,0x2d850107,0x6e202c3c,0x7d0332fd}},	//   יער_, chle_, mumb, _gens
  { {0x6d3b0135,0x6e204ece,0x8bc749eb,0x7d084ecf}},	//   _חתונ, lumb, _исид, mads
  { {0x7d08020a,0x44440026,0x0aeb0021,0x9f91006f}},	//   lads, dw_, _غربي_, _sšú_
  { {0x44444ed0,0x8704004a,0x6e2041ca,0x67d40137}},	// [bdd0] ew_, рясе, numb, роту
  { {0x27130023,0x44f40036,0x7d084ed1,0xe7c3000b}},	//   ện_, ипус, nads, _वीरप
  { {0x98ba0089,0xf7950033,0xaba8002b,0x442b056d}},	//   _mapě_, _банэ, _سهیم_, ьцам_
  { {0x6e20000c,0xddc2005c,0xbc79004c,0x63a24ed2}},	//   kumb, _proś, עװײט, gnon
  { {0x6e20000c,0x471a0008,0xb6040010,0x97a8000a}},	//   jumb, _אורג, _вяск, _יֹשֵ
  { {0xdca60029,0x6e200077,0x63a24ed3,0xdcfa0091}},	//   _هى_, dumb, anon, mitė
  { {0xb938000a,0x7d034ed4,0x660d4ed5,0x1fb54bb9}},	//   דרוג_, _rens, lsak, лсир
  { {0x2f54005f,0x7d033873,0x660c008c,0x1f54004a}},	//   атьс, _sens, _älkä, атьё
  { {0x44210049,0x0d9901b0,0x1ea90015,0x7d034ed6}},	//   luh_, етны_, عاعي_, _pens
  { {0x660d0020,0x4d651cd1,0xfd110015,0xbc190033}},	//   isak, уков, حجة_, німі_
  { {0x6445003e,0xa3c7005d,0x44210d25,0x7c640015}},	//   nwhi, _उठा_, nuh_, لاَل
  { {0x4fa40191,0xdcfa0007,0x83350053,0x7d030111}},	//   _києв, kitė, נאָס_, _wens
  { {0x2d8b0152,0x7d0800dc,0x2d9900dc,0x44441cb7}},	//   èces_, bads, éses_, zw_
  { {0xfe9a0053,0x44440026,0x44210375,0x0d84042b}},	//   _אינמ, yw_, kuh_, _клін
  { {0x2576002e,0xef19005c,0xa6db002e,0x44210509}},	//   _mælt_, akże_, _maðu, juh_
  { {0x8a960086,0x1cba0008,0x44210509,0x7c3a000a}},	//   _مشخص, _אמצע, duh_, _נתפס
  { {0x6d4100aa,0x07b70015,0x4b2500c3,0x35ca0054}},	// [bde0] oela, اهقة_, _ضعيف, егао_
  { {0x85060086,0x6d414ed7,0x86750033,0x4444002a}},	//   اوان, nela, шысц, tw_
  { {0x44440298,0x04b50010,0x44210375,0x290a4ed8}},	//   uw_, асця, guh_, maba_
  { {0x76f50010,0x7dc6002e,0x6e2002e8,0x91e64ed9}},	//   _вярх, iðsa, yumb, годе
  { {0x69de000c,0x442101d7,0x44440eb3,0x7c210012}},	//   _kipe, auh_, sw_, hulr
  { {0x6b840251,0x290a02c1,0x44210375,0xca37000a}},	//   _llig, naba_, buh_, רנסה_
  { {0x628b016f,0x58f7000a,0x10130015,0x6d414eda}},	//   azgo, אמצע_, مبيد, dela
  { {0xa8570008,0x6d410020,0xf3ca002b,0x290a11da}},	//   ריקה_, eela, _سبزه_, haba_
  { {0x6d410026,0x539b000a,0x7d0828e4,0x41aa1923}},	//   fela, _נימו, tads, _зван_
  { {0x01d70196,0xc0460087,0x290a4edb,0x2619000b}},	//   _موقع_, _مخصو, jaba_, यूटी_
  { {0x759b0008,0x290a4edc,0x80290015,0x2175006b}},	//   תייח, daba_, _لأنّ_, _тутр
  { {0x2b82002f,0x501b0008,0x600b000a,0xbefa0015}},	//   _póca_, _טובו, _נִבְ, _أراض_
  { {0x7d08192b,0x6d414edd,0x69de4ede,0x6fb3009a}},	//   pads, bela, _bipe, _امنا
  { {0x2905002f,0x9e650087,0x69de044c,0x290a4edf}},	//   úla_, _خامن, _cipe, gaba_
  { {0x6b84003e,0xab5b00b8,0x4d7b0053,0x69de4ee0}},	//   _flig, glüc, _ארגע, _dipe
  { {0xb7940015,0x660d42a0,0x4c130067,0x9f4700cb}},	//   مؤقت, tsak, _ابوس, ppnå_
  { {0x290a00b6,0x15f40029,0x98a50064,0x461500e6}},	// [bdf0] baba_, مسلح, ılı_, شوار
  { {0x7afd00b8,0x290a0896,0x44210049,0x628b00bc}},	//   lbst, caba_, tuh_, vzgo
  { {0xe5c40080,0x660d4ee1,0xdcfa0091,0x97c70067}},	//   ссто, ssak, sitė, _متحم
  { {0x44210849,0x02d90029,0x3943003d,0x6d414ee2}},	//   ruh_, نواب_, lejs_, zela
  { {0x44210509,0x2258004a,0x8268005e,0x7afd0012}},	//   suh_, лицы_, лаїв_, ibst
  { {0x6edb0048,0x3a38000a,0x6d414ee3,0x7bdf0aff}},	//   _jābū, טרדם_, xela, _liqu
  { {0xddcb00df,0xa3d5005e,0x98b80045,0x51840054}},	//   žiūr, _вовч, meră_, ључа
  { {0x290a02c1,0xcf8e002b,0xee390718,0x6d414ee4}},	//   zaba_, وژن_, вни_, wela
  { {0x52380087,0x63bb0b63,0x6d41034c,0x8d750015}},	//   _مسلح_, _ikun, tela, لادا
  { {0x6b84003e,0x6b964ee5,0x7afd4ee6,0xad5937e5}},	//   _slig, _smyg, ebst, трих_
  { {0x63a906f5,0x8d540010,0x69de1f30,0x30a709ef}},	//   _kjen, стыч, _ripe, _срав
  { {0xa4b60008,0xeb9a1b04,0x6d414ee7,0x7bcd0252}},	//   ילתה_, тим_, sela, _chau
  { {0x3f7a0053,0x63a9016f,0x290a4ee8,0x8f7a000a}},	//   _שאנס, _mjen, taba_, _שננק
  { {0xc27a000a,0x3943003d,0xd7f80045,0x4e8a000a}},	//   דרשי, gejs_, ţăm_, _שָׁ֣
  { {0x98b80011,0x7bdf001c,0x7afd00c0,0x69de0705}},	//   deră_, _fiqu, bbst, _vipe
  { {0x290a4ee9,0x69de0f21,0x63a94eea,0x70e2000b}},	//   saba_, _wipe, _njen, _पल्ल
  { {0x98b80011,0xaa46006d,0x3bbb000a,0x290a0077}},	// [be00] feră_, _тепл, _במקד, paba_
  { {0x929d0050,0xb9930015,0x7bdf0003,0x63bb4eeb}},	//   _pełn, _وليب, _épur, _akun
  { {0xa6db002e,0x2937000a,0x130a004a,0x9986002b}},	//   _baðs, _דאין_, вней_, _ملکو
  { {0x5c360053,0x83170015,0x7bdf0144,0x63a90085}},	//   ירען_, لقمر_, _xiqu, _cjen
  { {0x42540029,0xf2030c55,0x9b17004c,0x98b80045}},	//   إنتر, оящо, בֿוד_, beră_
  { {0x63a90134,0x33f6005e,0x91030054,0x63bb2d04}},	//   _ejen, _вчас, опље, _ekun
  { {0x64a31c64,0xe3ba006b,0xd4670004,0x63a902de}},	//   _дара, _абв_, _кире_, _fjen
  { {0x63a913e1,0xa0670054,0x5f760015,0x7ae402f2}},	//   _gjen, раћа_, شاعر, _ngit
  { {0x3da60036,0xe731000f,0x7bdf4eec,0x5e430058}},	//   ироб, הֵי_, _riqu, قَيْ
  { {0xd24f002b,0x7bcd4eed,0x7ae40aff,0xdcfa003d}},	//   _زنم_, _shau, _agit, mitī
  { {0xdeef1561,0xfe18005d,0xa3cb0157,0xac98006e}},	//   _мы_, _दिवस_, _रीड_, انجا_
  { {0x5c730127,0x600b000a,0x7afd4eee,0x0000006a}},	//   ілят, _יִדְ, ubst,
  { {0x7bdf08e0,0xc333013a,0x7afd2ac7,0x6da608e8}},	//   _viqu, חור_, rbst, _кида
  { {0x6c340086,0x7c6600e6,0x7db30015,0x7ae44eef}},	//   _هفتا, _نابل, _وصوا, _egit
  { {0x37070063,0x87d70015,0x7bdf24d7,0x7793009a}},	//   ичав, لغرا, _tiqu, قیدا
  { {0x386d0085,0x9cdb000a,0xb467002b,0x8cdb004f}},	//   ćer_, _בקופ, یداه, _בחות
  { {0x6b870074,0x85150036,0x6b9d007c,0x98b80045}},	// [be10] _مشکل, ймає, misg, teră_
  { {0x3abc0008,0x63bb0472,0xe5c40a61,0x63a90085}},	//   _במחנ, _skun, осхо, _sjen
  { {0xaab80086,0x0467226a,0x59d40015,0x69d50012}},	//   _مدیر_, штам, _بغير, mmze
  { {0x6cd90053,0x98b80011,0x9cd9004c,0x0394005e}},	//   אַנצ, seră_, אַנז, орія
  { {0x926b0063,0x63a90085,0x98b80045,0xd7c30065}},	//   ържа_, _vjen, peră_, _वीएच
  { {0x80f8006b,0x61450f78,0x0000006a,0x0000006a}},	//   ахът_, сека,   ,
  { {0xe0550029,0x3f8600dd,0x63a90293,0xa1120015}},	//   إختب, _blou_, _tjen, سويت
  { {0x1f650080,0x657500dc,0x63a9003f,0x6fc5005c}},	//   ским, _hozh, _ujen, róco
  { {0xa3c6000b,0x63b9002a,0x6b9d4ef0,0x02440058}},	//   ॉगर_, mown, disg, _وَفَ
  { {0x5174003b,0x4174003b,0xbd890086,0x25760134}},	//   _والأ, _والس, اندن_, _jælp_
  { {0xe7c7005d,0x61e94ef1,0xdd2f0046,0x3b0a0840}},	//   लताप, _huel, _těži, лено_
  { {0x3fc90074,0xdce100df,0x63b94ef2,0x61e9003f}},	//   _صدای_, yklė, nown, _kuel
  { {0xeb97250c,0x61e14216,0x99860058,0x3a9a00ce}},	//   сия_, _kill, ملحو, утню_
  { {0xf2d2000a,0xad58006b,0x60c1008c,0x61e94ef3}},	//   פעם_, _връх_, _kylm, _muel
  { {0x7dc609f0,0x63b90050,0x7ae944ec,0xbbf50115}},	//   iðsl, kown, žeta, _استث
  { {0x63b9002a,0x61e14ef4,0x98a300ce,0x0000006a}},	//   jown, _lill, чисе,
  { {0x06ca0033,0x3c311945,0x63b94ef5,0x05aa0d3c}},	// [be20] угай_, láv_, down, гвай_
  { {0xd9100074,0xca97000a,0xd6cf0015,0xd46a098b}},	//   _زیر_, _לדפי_, رقل_, лизе_
  { {0x89db000a,0x74130015,0xf977000a,0x224d002a}},	//   _תחיי, كولا, _הגיש_, _asek_
  { {0x61e14ef6,0x083b004c,0x96ba00ce,0x63b90535}},	//   _aill, _געטל, _бугу_, gown
  { {0xd9fa000b,0x61e11a8d,0x61e90077,0x52730054}},	//   ्ठित_, _bill, _cuel, зују
  { {0x11d70015,0x20050034,0x61e14ef7,0xa158140a}},	//   مونة_, _bwli_, _cill, раку_
  { {0x0133003b,0x987a00b2,0x21670001,0xa87a0053}},	//   سعود, טאַט, сији_, טאַר
  { {0x63b9005c,0x60c50020,0xc0a90015,0xadf40004}},	//   cown, ühma, جاهل_, опиш
  { {0x61e14614,0x61e930da,0x0000006a,0x0000006a}},	//   _fill, _guel,   ,
  { {0x61ef0152,0x11190010,0x5d6607c1,0x4d98005e}},	//   _écla, _віцэ_, стиз, ркою_
  { {0xb5fb047e,0xe0850015,0x55bb000a,0xd5bb000a}},	//   _gráf, _وجمي, רמיו, רזיל
  { {0x60db0053,0xdfcf0015,0xdce3005a,0x61e14ef8}},	//   _עקאנ, _كيل_, _koně, _zill
  { {0x753c005c,0x3eab006f,0x539b05bd,0x93b7000a}},	//   _obrz, čitú_, ריכו, מלטו_
  { {0x7dc6001a,0x63b9002a,0x3c31006f,0x645c4ef9}},	//   oðsm, zown, báv_, _orri
  { {0x65750156,0x39340010,0x2d8c0125,0xa6e2001a}},	//   _rozh, чэўс, mhde_, íðna
  { {0x47350010,0xd7940063,0x7d0a002e,0x2d9e4efa}},	//   ўнас, писъ, _hefs, lite_
  { {0x7dc6002e,0x65750001,0x5eeb000a,0xf599006b}},	// [be30] yðsl, огађ, אַבְ, аващ_
  { {0xe4cb0086,0x09070004,0x2d9e1a5f,0x994d0091}},	//   هبان_, _учим, nite_, ržų_
  { {0x61e902c1,0xc9f4002b,0x98b8002a,0x2d8c008c}},	//   _suel, _وسیع, terą_, ihde_
  { {0x61e14efb,0xfbc9000b,0x2d9e05ef,0xab5b0030}},	//   _sill, रतिम, hite_, zlün
  { {0x2d9e0780,0x645c00b8,0x63b9005c,0x13080036}},	//   kite_, _erri, rown, сній_
  { {0x61e90467,0x1a9c0053,0x63b9005c,0x2d9e116e}},	//   _vuel, ניגע, sown, jite_
  { {0x94750086,0x2d9e4efc,0x297c000a,0x397c000a}},	//   _بگذا, dite_, רטוא, רטונ
  { {0x10080029,0x224d0035,0x2d9e177b,0xa6fb000a}},	//   حتوى_, _tsek_, eite_, נִ֔י
  { {0x61e10613,0x61e9007c,0x11450015,0x9e650033}},	//   _till, _uuel, _وَرُ, івод
  { {0x2d9e03af,0x161e005d,0x2d8c002d,0x7d090001}},	//   gite_, यूटर_, ghde_, шног_
  { {0x7f190086,0x04680008,0x2ef50839,0x5baa3ed3}},	//   _نياز_, ֶיךָ_, _дзер, иком_
  { {0xdb960036,0x2c570011,0x7c940010,0xf412000f}},	//   ішнь, _văd_, ярыц, ופט_
  { {0x2d9e116e,0x19f70015,0x34c6000b,0x6ec7002b}},	//   bite_, يَّد_, _वर्द, _اتاق
  { {0xedf50086,0x3f8d001c,0xf8660342,0x2d9e4efd}},	//   _هيچگ, lheu_, овго, cite_
  { {0x1089000a,0xcbc60015,0x48e3004a,0x6d88000a}},	//   בָּֽ, _وزعي, дорв, _לָקְ
  { {0xfbc30063,0xc052000a,0xdb060030,0x4fac000a}},	//   _общо, וזל_, knké, ָׁמְ
  { {0x6f0b00dc,0xb6a60404,0xd62a02bf,0x07a30165}},	// [be40] _megc, циал, розе_, фатн
  { {0x26c20091,0x6f0b0030,0x44fa0033,0x7bc60dca}},	//   _vyko_, _legc, рхаў_, llku
  { {0x2db60053,0xd2a6005e,0xe73a4efe,0xc953000a}},	//   קלען_, _кiль, _кен_, _חמת_
  { {0xd62a0001,0xb8fd005d,0xdcfa003d,0xc2e90015}},	//   _коме_, ते_, iktā, معهم_
  { {0x36360086,0xbb3b0053,0xf7730008,0xdce30089}},	//   _برجس, שעני, _חקר_, _poně
  { {0x753c016f,0xab5b00dc,0x113a004a,0x41e3005e}},	//   _ubrz, elül, ряды_, міща
  { {0x2d9e1a5f,0xa81a000a,0xe0d30054,0xb5fb0030}},	//   vite_, בֵ֥י, мошњ, _prág
  { {0x93fb0008,0xdfda006b,0x2d9e002a,0x7dc6001a}},	//   _כללי, шъл_, wite_, rðsm
  { {0xe29a0083,0xdcfa0089,0xbd6a017c,0x2d9e4eff}},	//   _таа_, chtě, арне_, tite_
  { {0x66090064,0x2d9e3154,0xa63b004f,0x0000006a}},	//   _çeke, uite_, סגיר,
  { {0x7d0a09f0,0x80a60086,0xc3340008,0x98ba003d}},	//   _vefs, _بمان, ֔וֹ_, _mapē_
  { {0xbe660029,0xd3660086,0x7dc6001a,0x2d9e09d4}},	//   _وهاي, ره_, oðsk, site_
  { {0x7fd700b4,0x2d9e4f00,0xe8e30065,0x0dca04c5}},	//   _וואס_, pite_, पश्च, _куки_
  { {0x7dc60084,0xf807005e,0x6fea002a,0x61ed0125}},	//   iðsk, жчан, _pęch, íali
  { {0x4ff8000a,0x6cfb000a,0x67d512ba,0xd763002b}},	//   מִּנ, _דפוס, зову, ونسی
  { {0x7c2800e8,0x501b0008,0x44210107,0x6d481422}},	//   mudr, יולו, vrh_, leda
  { {0x960b0010,0xd6db006d,0x163401b7,0x07080058}},	// [be50] рэба_, ртв_, метя, زيلي_
  { {0x6d484f01,0x7c281112,0x45d40a1f,0xa48700c3}},	//   neda, oudr, доус, يجان
  { {0x88830086,0x69c7060b,0xd5b80484,0xab5b0061}},	//   _غیرن, mlje, ісу_, ylül
  { {0xdfc6003b,0x29110467,0x6d480020,0x87270029}},	//   _سي_, laza_, heda, _بعدم
  { {0x0204008f,0xd1790010,0x0165006b,0x6d482276}},	//   дзін, йскі_, зкло, keda
  { {0x867a0008,0x6fc500dc,0x6d480b6c,0x29111e06}},	//   _הרשו, móci, jeda, naza_
  { {0x24180010,0x6d484f02,0x764d04d0,0xc0e20345}},	//   _моры_, deda, lway, ношк
  { {0xb5fb002d,0x6235022a,0x672d35a6,0xce59002b}},	//   _trád, _небу, ngaj, مشخص_
  { {0x29114f03,0x764d00c7,0xada5027a,0x0000006a}},	//   kaza_, nway, запл,
  { {0x2911003f,0xbd450015,0x61fb015a,0x3c15003d}},	//   jaza_, أندي, _itul, tāv_
  { {0xca29000a,0x7c28003d,0xd6220033,0xab5b007f}},	//   _תם_, gudr, зiла, lmüy
  { {0x764d003f,0xeb97004a,0x29110045,0x69c74f04}},	//   kway, зию_, eaza_, elje
  { {0xab5b0064,0x29110061,0xbfb80015,0xdb1f0030}},	//   nmüy, faza_, _بطلا_, óvál
  { {0x2911003f,0x8dfa000a,0x5dfa000a,0x672d002a}},	//   gaza_, _ההסת, _הפסנ, egaj
  { {0x59370033,0x764d01f9,0x0000006a,0x0000006a}},	//   язёў_, eway,   ,
  { {0xc0520053,0x69c70085,0xb7e30088,0x61fb002a}},	//   עזן_, alje, ежск, _otul
  { {0x69c70198,0x6fc54f05,0x4df90053,0x80a2000b}},	// [be60] blje, góci, מפּא, _केने
  { {0xd6cf0029,0xe61706b4,0xd5b20029,0xba9b0008}},	//   اقك_, яду_, رفض_, _לספי
  { {0xb97b0008,0xa97b0008,0x98160225,0xe97b000a}},	//   _הניי, _האיכ, _عبدا, _הניש
  { {0x12880086,0x6d48005c,0x225f13e1,0x394a0034}},	//   يمای_, zeda, _bruk_, lebs_
  { {0x115408fc,0x6fc5016e,0x6d482755,0xb7db000a}},	//   дклю, cóci, yeda, _לקטי
  { {0x15f1005d,0x8a170008,0x225f049c,0xb5fb002e}},	//   _अंतर_, לחנו_, _druk_, _fráb
  { {0x61fb00f2,0xc953000a,0x6d484f06,0x3958003d}},	//   _etul, גמו_, veda, idrs_
  { {0x645b005c,0x1777000a,0xdb090061,0xafe303ae}},	//   śció, ִׂים_, ülüy, нојл
  { {0xb5fb0089,0xf202005d,0x63a24f07,0x923b0046}},	//   _irác, रीख़_, mion, ěřít
  { {0x667b0053,0x71a30001,0x51fb000a,0x63a24f08}},	//   צטיק, _зауз, _להמצ, lion
  { {0xfe6f0074,0x69c7065d,0xab5b0064,0x6fc500dc}},	//   ندی_, vlje, slüm, zóci
  { {0x2911003f,0x6d484f09,0x6616002a,0x63a24f0a}},	//   waza_, seda, ksyk, nion
  { {0x2911003f,0xf77f0144,0x2a6000da,0x69c70b28}},	//   taza_, _niça_, _crib_, tlje
  { {0xed570010,0x69c7008c,0x2d854f0b,0x661607ba}},	//   _ноч_, ulje, ckle_, dsyk
  { {0x5d3b0008,0x63a2055a,0x0d3b000a,0xf7490015}},	//   _התוא, kion, _הגוב, يلسي_
  { {0x69c7010b,0xf77303c4,0x15f1005d,0x764d003f}},	//   slje, راز_, _अंदर_, tway
  { {0x6b8d00b6,0xbbc9005d,0xfb380029,0x15150010}},	// [be70] _ilag, रतीक, _رأيت_, ддзя
  { {0x6fc5005c,0x5d98000a,0x26c7003d,0xab5b0061}},	//   róci, קֹּד, āno_, klük
  { {0x61fb0870,0x5335033d,0xc8fb000b,0x63a24067}},	//   _stul, деет, ्रीम_, fion
  { {0xd808000a,0xf8b2000a,0xe4d40015,0xf65f063b}},	//   _מִשָ, _ישי_, رتلب, _træ_
  { {0x2d854f0c,0xe3c40015,0x68ec0030,0xa22902a3}},	//   ykle_, رْهَ, _áldá, іжка_
  { {0xa0690054,0xf194004a,0xab5b0061,0x21660004}},	//   жака_, ничь, rmüy, диши_
  { {0x63a2005c,0x6b8d00c0,0xd91c000a,0xdb06007c}},	//   bion, _olag, זוול, tokü
  { {0x225f4f0d,0x0e650248,0x63a22b8e,0x9e651d8a}},	//   _truk_, дкин, cion, двид
  { {0xe3b00002,0x9758000a,0xf1f80015,0x41250015}},	//   _صرف_, ליהו_, _فعلت_, _يفرق
  { {0x6e2902c1,0xf2d2000a,0x6b8d4f0e,0x02440015}},	//   rueb, _יען_, _alag, _سَمَ
  { {0x6b8d4f0f,0x1b4a0c96,0x5f450015,0x2d85118e}},	//   _blag, озни_, _ينطل, rkle_
  { {0xe2870029,0xf989000a,0x00ba000a,0x4c82005e}},	//   نذ_, _דר_, _ומעמ, тлюв
  { {0xcf92000a,0x6e2912cd,0x4f88004f,0x0000006a}},	//   _בטא_, queb, _צָעֲ,
  { {0x63a20ede,0xdb06002a,0xa3d4000b,0x6b8d4f10}},	//   zion, tokó, _सीन_, _elag
  { {0x7c920029,0xc8b50033,0x6b8d115b,0x394a0012}},	//   _للوص, есты, _flag, rebs_
  { {0x2905002e,0xdb061ed5,0x6b8d06c0,0x63a206c9}},	//   ðlar_, rokó, _glag, xion
  { {0xbbd7000a,0xab5b0061,0x46a30033,0xfbd3000a}},	// [be80] _קופץ_, zlük, ватв, _בתה_
  { {0x63a20050,0x75d3002b,0x62820573,0xdb06002a}},	//   wion, پيما, vyoo, pokó
  { {0x661600cb,0xb5fb4f11,0x63a21f6b,0x69dc0b14}},	//   ssyk, _prác, tion, mmre
  { {0x7dc6002e,0x27f70264,0xcc76000a,0xe2ca0923}},	//   rðsi, žené_, וגעת_, олед_
  { {0xb5fb0089,0x63a2187c,0x8233002b,0x2216131f}},	//   _vrác, rion, نروا, ффер
  { {0x69dc016f,0x75d6002b,0x63a24f12,0x6909004f}},	//   nmre, _آيسا, sion, ִּצְ
  { {0xf202005d,0xb5fb4f13,0x63a24f14,0xa0670054}},	//   रीज़_, _trác, pion, даја_
  { {0xab5b19a2,0x649b000a,0x22690046,0x044301ca}},	//   rlük, _וילה, átký_, _шесн
  { {0x113a0010,0x7ae9016f,0xf3f90045,0x657c030a}},	//   _мяжы_, žetk, _ăţi_, _korh
  { {0xfe6f0029,0xe16600e5,0x9cca0033,0xdd9000c3}},	//   ؤدي_, _تدري, жыма_, اود_
  { {0xe0460036,0xec6a005e,0x20560033,0x69dc00bc}},	//   _інди, ірок_, _ютар, dmre
  { {0x61e80026,0x0a6b0661,0xa3c0000b,0x764600aa}},	//   _hidl, орги_, ुति_, _opky
  { {0x657c00dd,0xd2460087,0xfe7200e5,0xcf250015}},	//   _oorh, دن_, _جدا_, _أرمي
  { {0xc8fb005d,0x7dcf01f0,0x657c01c2,0x0000006a}},	//   ्रेम_, løsn, _norh,
  { {0x61e84f15,0xa3c0000b,0xcd330015,0x2d8e0012}},	//   _midl, ुता_, _شروب, _ilfe_
  { {0x6b8d4f16,0x0057000a,0xab65002a,0x6d584f17}},	//   _ulag, ושלת_, ęższ, _hava
  { {0x7aed0020,0x6d584f18,0x6d5a0595,0xe699006b}},	// [be90] _igat, _kava, odta, чваш_
  { {0xca480086,0xf9fc000a,0xe57300c3,0x6d5a4f19}},	//   _کلیه_, _והזמ, خطر_, ndta
  { {0x3c3800dc,0x7b5f004c,0x0cd4000a,0x6d582acd}},	//   név_, אָריר, תֵּר_, _mava
  { {0x43080015,0x6c190643,0x7c3a086c,0x6d584f1a}},	//   ِينَ_, לֵנו, ittr, _lava
  { {0x645a016f,0x824b0115,0x657c0cbb,0x2169025f}},	//   _štit, تشاف_, _forh, зили_
  { {0x30550054,0x6d584f1b,0xdb1d0400,0x20550719}},	//   еђит, _nava, llsä, етир
  { {0x33950010,0x2089006b,0x44254f1c,0xdb1d0003}},	//   _завё, яйки_, _íl_, posè
  { {0xa4d40191,0xef1941f8,0x6d5a063b,0x9980002a}},	//   _росі, чми_, edta, _zwiń_
  { {0x7e620495,0x7c3a0003,0x69dc0034,0xe4e3000b}},	//   _crop, ettr, ymre, _कृति_
  { {0x8c950036,0x7e623bbd,0xc1040015,0x61e82c7e}},	//   ермі, _drop, _لوكي, _gidl
  { {0x7e620049,0xbebd003d,0x6d584f1d,0x0000006a}},	//   _erop, egūt, _dava,
  { {0xab770015,0x6d580079,0xe452000a,0x4bc50058}},	//   ّمَا_, _eava, רֶז_, َتَّ
  { {0x6e45000d,0xbe8700e5,0x3ec70033,0x3e870015}},	//   _челз, _تجاو, _ўсеб, _تشاف
  { {0xfe700029,0x64550012,0x9f4c0046,0x69dc0123}},	//   _خدم_, _oszi, _rudé_, umre
  { {0x186718a7,0xf746007a,0xd7f20015,0x69dc0651}},	//   нари_, нево, اكر_, rmre
  { {0x9f4604ed,0x7bc4003f,0x657c0030,0x6d584f1e}},	//   _cioè_, _ukiu, _sorh, _zava
  { {0xcf9200b2,0x3ea00084,0x6d580064,0x056612ae}},	// [bea0] אטן_, _þitt_, _yava, нван
  { {0x7abb0008,0x090610b7,0xd910002b,0x443a4f1f}},	//   _מצפו, _япон, _خیس_, ttp_
  { {0x657c018b,0x3f8f2c37,0x399b0135,0x98a6012e}},	//   _vorh, _olgu_, _זייד, _чине
  { {0x8cb60053,0x2b5b0008,0x61e800c0,0xb5fb1754}},	//   תּמא_, ּ֣אמ, _sidl, _irán
  { {0x71a60c1d,0xb97a000a,0x4b4d004c,0x0cac000b}},	//   надз, ּנֶי, ןגאַ, _चश्म
  { {0x7c3a002e,0x64a64f20,0x66044f21,0x6d47007c}},	//   yttr, _зага, mpik, õjal
  { {0xb0da005d,0x61e8016f,0x201a0030,0xdce3003d}},	//   येंग, _vidl, épi_, _monē
  { {0xdefa008f,0xdb1d0152,0xae21005d,0x395a0a54}},	//   чык_, posé, _मिशन_, _laps_
  { {0x6d5800df,0x61e80cd8,0xe2970127,0x29060092}},	//   _pava, _tidl, _зат_, _đoan_
  { {0x409625ca,0x721b0008,0x50960001,0xb637004c}},	//   _прет, _מומח, _пређ, עריס_
  { {0x0caa004a,0x320d0012,0x6fc50533,0xb53b000a}},	//   ятии_, _zwey_, tóct, הגיש
  { {0x60c40061,0x648b000a,0x6d580573,0xd5be000b}},	//   ğimd, לְכְ, _wava, ्तुओ
  { {0x6d580cd1,0x722a000a,0x539b000a,0x60c40061}},	//   _tava, הוָ֗, ליטו, şimd
  { {0xf2d300b4,0xa024018b,0x09e4008f,0x5dfb0008}},	//   טער_, _größ, лоўн, _צפונ
  { {0x8d5b013a,0x6fc502c1,0xd7f10016,0xb5fb0077}},	//   _זכוי, mócr, ễ_, _crán
  { {0x0aeb0029,0x7dc64be8,0x7c280034,0x60c50353}},	//   _عربي_, rðsu, mrdr, ühmi
  { {0x8aa40174,0x569400ce,0x7ac70138,0x0000006a}},	// [beb0] _брэд, гатт, _яске,
  { {0x57f500a4,0x61ef0003,0x395a00da,0x64550030}},	//   _ипот, _écli, _gaps_, _pszi
  { {0x645a00bd,0xf9900029,0xdcf8016f,0xe8950892}},	//   _štir, _دبي_, _novč, _рань
  { {0x9358005e,0x94040015,0xa3f4005e,0xae21000b}},	//   ершу_, اونه, упці, _मिलन_
  { {0x4209005e,0x63c80015,0x2bb6003d,0x6fc50030}},	//   єнко_, رِهِ_, nāca_, zócs
  { {0x25a50084,0x7dc6002e,0x6145153d,0x0000006a}},	//   _öll_, iðss, тека,
  { {0x7bc6002e,0x70520015,0x1958000a,0x1fb52372}},	//   _íhug, لنوا, גבול_, ксир
  { {0xfe450083,0x883c0008,0xd00e0029,0xaf02006b}},	//   внио, פתחו, آلي_, апъл
  { {0x236d002c,0x92b70015,0x3e320015,0xee36004a}},	//   _inej_, _أحزا, لفير, вны_
  { {0x6e3b0213,0xc694004c,0x39940012,0x5c89005e}},	//   rtub, טאפ_, _käse_, дйом_
  { {0xa1280015,0xb4fa000a,0xdbdf001a,0xdb06006f}},	//   _أكمل_, ופתי, tíðn, enká
  { {0x6299002a,0x6604008c,0x6ff1003d,0x395a1e0b}},	//   ozwo, ypik, _nāci, _saps_
  { {0xeb970404,0xdfd40010,0x2d990003,0xd6220033}},	//   тия_, _соцы, èses_, зiна
  { {0xc2120008,0xdbdf001a,0x2d8b003d,0x41c10065}},	//   שהם_, síðn, īces_, शकिस
  { {0x661d0cbf,0x6f093301,0x7c640067,0x260f002a}},	//   _avsk, obec, _مايل, eżo_
  { {0x6ce40036,0x2fcd3ead,0xeafa0067,0x6e29035f}},	//   _січе, nleg_, _غربت_, oreb
  { {0x66090064,0x395a4f22,0x85ea005e,0xa922001a}},	// [bec0] _çekl, _taps_, ддав_, _óþol
  { {0x66044f23,0xb5fb4f24,0x6299002a,0x6e290061}},	//   rpik, _trán, dzwo, ireb
  { {0x741300e6,0xb5fb4f25,0xd91b000a,0x2fcd001a}},	//   لولا, _hrál, _קוטל, kleg_
  { {0xb5fb01b2,0x291839ca,0x9cd6000a,0x6c7a004c}},	//   _král, lara_, דועה_, ורעד
  { {0x27e0022d,0x2fcd05d8,0x6f090123,0x7dc6001a}},	//   mmin_, dleg_, dbec, iðsr
  { {0xf5030080,0x1a9b0053,0xba9b000a,0x11d70015}},	//   _взро, וינע, וסני, نونة_
  { {0xf9930008,0x64a6070e,0x21670001,0x69ce4f26}},	//   שרו_, _рава, тији_, ilbe
  { {0x2fcd05d8,0x82360015,0xf8b3000a,0xa0670054}},	//   gleg_, _لرئا, ישו_, ђања_
  { {0x8e130010,0x32460054,0x6e294f27,0x27e012a5}},	//   адыц, _језг, greb, imin_
  { {0x27e04f28,0x4237000a,0xddc90045,0xa06a03ae}},	//   hmin_, _בנמל_, rveş, _оаза_
  { {0x6e294f29,0x0197000a,0x27e031c7,0x29184f2a}},	//   areb, _שכבש_, kmin_, dara_
  { {0x29180125,0x69ce4f2b,0x0000006a,0x0000006a}},	//   eara_, elbe,   ,
  { {0x7e9a0015,0x8d760015,0xdb060030,0xaa5406eb}},	//   _تنشر_, _لاغا, unká, авяш
  { {0x9f810084,0x6ff10024,0x7dc6002e,0x29180375}},	//   lóð_, _sāci, rðss, gara_
  { {0x28f80a2c,0x6d8b000a,0x9dd7004f,0x4139004f}},	//   тесь_, _קָדְ, _שווק_, עֲשׁ
  { {0xe4e3005d,0xf7730015,0x3c77000a,0x57b40033}},	//   _कृषि_, جاس_, _יתום_, абст
  { {0xdb1d0014,0x6ff10024,0x95d909dd,0x29184f2c}},	// [bed0] nosí, _vāci, едат_, bara_
  { {0x66090064,0x27e00035,0x1e3b000a,0x2e3b000a}},	//   _çekm, amin_, וגמא, וגמנ
  { {0x2fcd0034,0x95c40015,0xab5b0012,0xdb0f0003}},	//   yleg_, جيله, blüt, encé
  { {0x9f81002e,0xd8b80015,0x2bf7004c,0x92950033}},	//   jóð_, _جدًا_, דמאן_, лаец
  { {0x13080036,0x26c90086,0x32450015,0xe5c70033}},	//   тній_, _سطحی_, انتف, _асво
  { {0xdb1d0014,0x32b8003b,0x6e2904ed,0xd6560008}},	//   dosí, خدمة_, vreb, _גישת_
  { {0x14c70086,0x34950001,0x2fd60086,0x2fcd4f2d}},	//   _شهری_, _савр, گويد_, tleg_
  { {0x6e2936b4,0x21290061,0x95fb000a,0xffd50033}},	//   treb, şah_, ֵּ֖ח, ыўля
  { {0xab5b00b8,0xfe710015,0x2fcd4f2e,0xe732000a}},	//   hlüs, صدة_, rleg_, צֵה_
  { {0x6e2600dc,0x91e40001,0x84f5000b,0xdb0d001a}},	//   ákba, _вође, ेडिट_, _skað
  { {0x2d990007,0x7de40015,0xdb060046,0x29184f2f}},	//   ėse_, جسيم, liké, vara_
  { {0x709a000a,0x6e2903cd,0x60c40061,0x9f050015}},	//   _אֱדו, preb, şimc, _صوتو
  { {0x29050064,0x6d4100b8,0x2918119a,0x9d450033}},	//   ılan_, pfla, tara_, _белд
  { {0x99d60086,0xceb2000a,0x8d74002b,0xab5b0012}},	//   اقست, _פיג_, _پاها, flüs
  { {0xe61f016e,0x6fc7000b,0xb5fb4f30,0x27e04f31}},	//   _avô_, ावपू, _drám, tmin_
  { {0x7c3c0251,0x18670001,0x3f8d00e8,0x0676005e}},	//   àrre, ћати_, nkeu_, лузя
  { {0xb5fb002d,0xb50f000b,0x7ba5012c,0x7ae9001a}},	// [bee0] _frám, िरूप_, _خصوم, þett
  { {0xc88501e2,0x1a9b0053,0x5a9b0008,0xaa77000a}},	//   _başı_, _נייע, _נשיא, _עתיד_
  { {0xef19005c,0x54360018,0x0d160053,0xc953000a}},	//   każ_, طرار, רקעט_, _המת_
  { {0x442612d7,0xc3d50033,0xdc88000a,0x7bc64f32}},	//   čo_, аўчы, כְנָ, noku
  { {0xef19005c,0x925802e1,0xeab6000a,0xcb37000a}},	//   daż_, талт_, נִ֣י_, ראני_
  { {0x645801d0,0xe5a60766,0x0000006a,0x0000006a}},	//   ævis, _сиги,   ,
  { {0x853b0008,0x7bc64f33,0xdcf8003d,0x33d600ce}},	//   _רגלי, koku, _novā, _біат
  { {0x083b0053,0x2d8300f2,0xdb1d4f34,0xdfd00015}},	//   געקל, öjen_, tosí, غية_
  { {0x01360031,0xc291002b,0x20070030,0x7bc64f35}},	//   _معاد, _ویمب, apni_, doku
  { {0xdd900029,0xd6570008,0x6f1d002d,0x22930029}},	//   زوج_, ניית_, óscr, _الكس
  { {0xed500086,0xd59b000a,0x7bc64f36,0xc006307f}},	//   مپک_, גביל, foku, _спек
  { {0xdb1d0046,0xd00f002b,0x5f76006e,0x0000006a}},	//   posí, _رله_, _حائر,
  { {0x4f650015,0xdb1d0c4e,0x0000006a,0x0000006a}},	//   _خالف, ilsø,   ,
  { {0xdb06008c,0x3ea2001a,0xdc55002b,0x9ed7005e}},	//   enkä, úktu_, _چريک, _сміт_
  { {0x7d1a052c,0x3cfb000a,0xb5fb006f,0x6cfb004f}},	//   mats, _אלונ, _vrám, _אפוס
  { {0x291e002e,0xa3d4000b,0x7d1a2c29,0x9f4c0144}},	//   ótar_, _सील_, lats, _judà_
  { {0xb5fb4f37,0x8515005e,0x7a570015,0x7d1a01ec}},	// [bef0] _irák, имає, _إضعا, oats
  { {0x86e80015,0x3e7a0091,0x7d1a4f38,0x88c7009a}},	//   اعِف_, mštą_, nats, _متجل
  { {0x54554f39,0xdcb10016,0x79ac000a,0x7d1a007c}},	//   рвет, hản_, _רֹחַ, iats
  { {0xdfc60029,0x987a01ac,0x69c74f3a,0x387a004c}},	//   _ذي_, _סארט, loje, _סטרױ
  { {0x7d1a4f3b,0x471a000a,0x35be000b,0xe28e1886}},	//   kats, _בורג, ्तख़, ца_
  { {0x7bc6000c,0x69c7022d,0xef190050,0xe1f00086}},	//   zoku, noje, waż_, سسه_
  { {0x7bc6000c,0x99590069,0xe1880058,0xef190535}},	//   yoku, kážu_, طئون_, taż_
  { {0x82f8003b,0xd3460086,0x3e7a0091,0x69c7008c}},	//   _مركز_, _نیمه_, kštą_, hoje
  { {0x399401d1,0x7db50004,0xef19002a,0x69c74f3c}},	//   _läsa_, исоц, raż_, koje
  { {0x2007002e,0x1c450484,0x21580002,0x69c7008c}},	//   ppni_, аном, _مجمع_, joje
  { {0x8f750010,0x3f8d00e8,0x9f55005e,0x5f74002b}},	//   _вулі, pkeu_, _ввеч, _گالر
  { {0x7d1a0234,0x907a000a,0xd436000a,0x4c8201f3}},	//   aats, _בטעי, סטרי_, іляв
  { {0x7d1a0abb,0x61ee0061,0x628b0091,0x2a69055e}},	//   bats, _ünlü, nygo, _crab_
  { {0xf1b20053,0x69c70844,0xcda90015,0x91f6000a}},	//   ַסן_, goje, _جهته_, ימשו_
  { {0xa3d5005d,0x7bc6003f,0x628b0026,0x98b70010}},	//   हता_, poku, hygo, алёт_
  { {0xcc3a0053,0x1cba000a,0x67a50015,0x6f1b002a}},	//   _סעפט, _במצע, محقق, nauc
  { {0x44330152,0x89d60010,0x63ab424b,0x2a694f3d}},	// [bf00] eux_, _вінш, dign, _grab_
  { {0x75d30002,0xf623005e,0xf507004a,0x628b0542}},	//   قيقا, ідхо, инул_, dygo
  { {0x14170029,0x224d00d9,0xb97b000a,0xdb040030}},	//   ليلة_, _apek_, _סנטי, _amié
  { {0x6266000d,0x6b840003,0xd7fb000a,0xf2060033}},	//   ивеа, _joig, _שהכל, аяко
  { {0x44331fca,0x3f82002e,0xdb1d0030,0x6f1b0034}},	//   aux_, ökum_, nosá, dauc
  { {0xfad7013a,0x6b960026,0xab5b0012,0xe1380033}},	//   בונך_, _llyg, hlüp, узкі_
  { {0x7d1a4f3e,0x754700dc,0x6b960026,0xdb1d00dc}},	//   vats, észő, _olyg, őzés
  { {0x9fae0089,0x628b0026,0xb3e90015,0xdb1d0d46}},	//   _tří_, bygo, _معقل_, kosá
  { {0x539b0008,0x7d1a4f3f,0x3f670004,0xdcb10016}},	//   _סימו, tats, рињо_, uản_
  { {0xeb8800b2,0xddc20050,0xb5fb0264,0x71ea006e}},	//   _אָ_, _społ, _dráh, _شفاف_
  { {0x1b19005f,0x7d1a357b,0xf4f70053,0xd12f0029}},	//   лжны_, rats, יזיש_, _زمن_
  { {0x7d1a4f40,0x69c7005c,0x0ba70036,0xd00f002b}},	//   sats, woje, ршом, _آلن_
  { {0x69c74f41,0xa3c70008,0x6b844f42,0x9f7b000a}},	//   toje, יִךְ_, _doig, _שנדח
  { {0x660901e2,0x88c70029,0xe3be0064,0x63ab01b2}},	//   _çeki, لتأل, ğıya_, zign
  { {0x628b005c,0xf7730806,0x6b9616a9,0x69c74f43}},	//   zygo, يار_, _flyg, roje
  { {0x27ef002e,0x5bc40015,0x56f50004,0x6c7b000a}},	//   ögn_, _وقول, спаѓ, _ירוד
  { {0xa9350010,0x69c704af,0x46150015,0x645c326e}},	// [bf10] _лепш, poje, صوار, _asri
  { {0xca36000a,0x63ab002a,0x55742b16,0x0000006a}},	//   _פנתה_, wign, огут,
  { {0xf487000d,0x5ca9000a,0x55640015,0x7d180061}},	//   јузн, ְׁנַ, تهلك, _mevs
  { {0x628b002a,0xa2c30065,0x7d18013b,0x7dcf0c4e}},	//   tygo, िअल्, _levs, røsi
  { {0xd6db4f44,0xb7da000a,0xf776004c,0x6f1b0003}},	//   _што_, _תקרי, _הערי_, vauc
  { {0x628b3679,0xd1bb0015,0x5437002b,0x63ab0d65}},	//   rygo, خاصا_, _پرسر, sign
  { {0x0495003b,0xe9df0077,0x6f1b0012,0x60090054}},	//   _الأح, ctúe_, tauc, ћним_
  { {0x28b8013a,0x6717005d,0xf8b8000a,0x6f62006b}},	//   יפוש_, तरिक_, יפוי_, звъз
  { {0xdfa4003b,0x22940036,0x63a9065d,0x6f1b1555}},	//   تحوي, _дитя, _imen, rauc
  { {0x6f1b0024,0x7bcd0553,0x6b844f45,0xb5fb0125}},	//   sauc, _akau, _soig, _crái
  { {0x6b960026,0x30a704f0,0x63a901b2,0xdde8002b}},	//   _plyg, _трав, _kmen, جريه_
  { {0x63a90089,0x4421003e,0xf98900a3,0x8b9603fc}},	//   _jmen, ish_, _אר_, сроч
  { {0xdef80010,0x0a3a0010,0x63a9003f,0x8a3a0033}},	//   _тых_, ычны_, _mmen, ыянт_
  { {0xc27a0053,0x99d60029,0xd9460001,0xdb1d00dc}},	//   ארשי, إتحا, љеви, rosá
  { {0xcd760008,0xb7960001,0xb900021e,0x1d16000a}},	//   _לעסק_, браћ, _तर_, _הקצר_
  { {0x07a31319,0x63bb00bc,0x5a960099,0xe76a002b}},	//   пасн, _njun, _гроф, دحسن_
  { {0x75d60021,0xdcb10016,0xdb37000a,0x44f6009a}},	// [bf20] ميرا, iảm_, _הנפח_, مساز
  { {0x63bb4f46,0x24f60033,0x63a9164a,0x649a0684}},	//   _ajun, счар, _amen, лтер_
  { {0xab5b0020,0xe4e30065,0x7ddd01f6,0x0000006a}},	//   foüh, केलि_, cèse,
  { {0x63a9005c,0xe29a0afb,0x031a00a2,0xc5e9000a}},	//   _cmen, лае_, اتات_, גד_
  { {0x2327017a,0x27030016,0x63bb4f47,0x291a172e}},	//   сочи_, _ổng_, _djun, _kepa_
  { {0xf5960029,0x55e30080,0x9326002b,0x6f0202b9}},	//   _السج, _нояб, _گرسن, _sfoc
  { {0xe04a0074,0x6e220820,0xf993000a,0x5478000a}},	//   اشته_, _svob, הרג_, _דְּנ
  { {0x6f190176,0x33b60029,0xb5fb002d,0x42b60033}},	//   _cewc, _امرأ, _srái, _лёзу
  { {0xa3d5014e,0x877b0053,0x6f190026,0xb5fb002d}},	//   हतर_, ראפי, _dewc, _prái
  { {0x63a9002c,0x865b000a,0x444415fc,0xb65b004c}},	//   _zmen, נדיי, ot_, נדיש
  { {0xdb550080,0xe6d5005d,0x757b0053,0x6cd40002}},	//   овны, _दर्ज, אטיפ, تقدا
  { {0x6f190026,0x4444010c,0x4f650015,0xcb0b0174}},	//   _gewc, it_, _وانف, ыход_
  { {0x2aab0124,0x44443285,0xc333000a,0xb5fb4f48}},	//   утно_, ht_, הור_, _trái
  { {0x398f0020,0xd2b7000a,0x44444f49,0x1e57000a}},	//   _küsi_, מלכת_, kt_, _לשדר_
  { {0x6f0d04f9,0xbc67002b,0x7c060015,0x4da50015}},	//   _încâ, _همون_, _ابتك, _بإنف
  { {0xceb90089,0x06150a61,0x501b000a,0x5a3507be}},	//   saře_, ждаю, טולו, _днит
  { {0xaa590511,0x764402f2,0xa3be000b,0x44444f4a}},	// [bf30] _типу_, gtiy, ीकन_, et_
  { {0x63bb00c0,0x44441fb7,0x05180015,0xa2bc000b}},	//   _sjun, ft_, مزمع_, _शख़्
  { {0xe46b004a,0x28080046,0xc4550015,0x44442a8a}},	//   ышал_, ětné_, تَاب, gt_
  { {0x44214f4b,0x69d50012,0x05d9000b,0x7dcf04d1}},	//   rsh_, llze, _बीरब, løst
  { {0x60c40064,0x444415fc,0x59fc000a,0x97420033}},	//   şiml, at_, ָּׂד, зiць_
  { {0x2903005c,0x44440334,0xcad8000a,0x851d000b}},	//   ncja_, bt_, צוגת_, _फ़िट_
  { {0x93e90029,0xaf9914f4,0xf4340033,0x64430144}},	//   _نفسك_, итих_, _нерэ, ànid
  { {0xdfd10029,0x6fb50029,0x63bb00e8,0x63a9002c}},	//   بيع_, تمعا, _ujun, _umen
  { {0x2903005c,0x64454f4c,0xaec2006b,0xed59005e}},	//   kcja_, lthi, мбъл, аоп_
  { {0xb65c004c,0x61fb02f2,0x22b80015,0x660d1839}},	//   רדזש, _iuul, _ادفع_, ipak
  { {0x61fb48b6,0xb5fb016e,0xc1040021,0xdb1d008c}},	//   _huul, _gráv, _روني, kosä
  { {0x64454f4d,0x61fb09e7,0x743a004c,0x69d50012}},	//   ithi, _kuul, סערװ, elze
  { {0x61fb0020,0xb69b0011,0x44440c19,0xdb1d0123}},	//   _juul, _sfân, zt_, dosä
  { {0x61fb0201,0x01fa004c,0xdb0f0144,0x44444f4e}},	//   _muul, יפשל, ancà, yt_
  { {0x6fea005c,0x61fb0201,0xc172000a,0x44440380}},	//   _ręcz, _luul, וחם_, xt_
  { {0xd70a0010,0x6b9d0012,0x2903002a,0x4444153c}},	//   рнае_, chsg, acja_, vt_
  { {0x660d0035,0x05aa0afb,0xddc200bc,0x291a01d7}},	// [bf40] gpak, авай_, _hroš, _tepa_
  { {0x76440064,0x22420020,0xd910002b,0xe617056d}},	//   rtiy, _äkki_, _سیر_, юду_
  { {0x44444f4f,0x14c8002b,0xf3f4002b,0x660d4f50}},	//   ut_, حهای_, ستاک, apak
  { {0xa3d4000b,0x59b2000b,0x94d30015,0x2d874f51}},	//   _सीख_, ँचकर, ذينش, _lone_
  { {0x64450705,0x6fea002a,0x9757000a,0xdd1c0069}},	//   athi, _tęcz, _ויכו_, váži
  { {0x02190010,0x64a60010,0xb5fb0156,0xdd020024}},	//   сіць_, _дага, _práv, ārīg
  { {0xcf9a0124,0x39584362,0xb97b004f,0x403400ce}},	//   ији_, iers_, ינסי, чейс
  { {0x39580041,0x64430144,0x9f440003,0x2611000b}},	//   hers_, ànie, ommé_, दीकी_
  { {0xe3be0064,0x2903005c,0x66090064,0x2d874f52}},	//   ğıda_, ycja_, _çekt, _bone_
  { {0x2d9809f9,0x67ce0091,0xdff60248,0xddc20085}},	//   óre_, lėję, _дядь, _broš
  { {0xe4fb00b2,0x2d87003e,0xb4fb009d,0x395800ed}},	//   יפיש, _done_, יפיי, ders_
  { {0xddc20048,0xbb940080,0xd9e3005d,0xb5fb0057}},	//   _droš, дающ, पष्ट, _krát
  { {0x290c0064,0x39581669,0x22461e2a,0x2d874f53}},	//   ıdan_, fers_, ntok_, _fone_
  { {0x2d87003e,0x60cd0011,0x644500ea,0x41ca000b}},	//   _gone_, şame, ythi, ाकिस
  { {0x6ca30063,0x6bd70015,0x79540015,0xdb0f016e}},	//   _оръж, _وتعر, بَّا, ancá
  { {0x224609cf,0xc6f90239,0x660d4f54,0x5b15004a}},	//   ktok_, снах_, tpak, _эмит
  { {0x2b590011,0x1a65002b,0x2903002a,0x69c00046}},	// [bf50] mesc_, _عیسی_, pcja_, émec
  { {0x3958003e,0xeaaa0053,0xe46b0080,0x660d0375}},	//   cers_, _לױפֿ, ишел_, rpak
  { {0xdb064f55,0x61fb0209,0x24f80033,0x43753589}},	//   liká, _suul, інцы_, зулт
  { {0x2b590011,0x64454f56,0xb5fb4f57,0xe3c40015}},	//   nesc_, rthi, _brát, وْلَ
  { {0x27e92691,0x877a0008,0x8bd8000a,0xf628005e}},	//   mman_, _הארי, קודו_, _міри_
  { {0x27e94f58,0x45fa000a,0x15fa000a,0xf616000a}},	//   lman_, _להשג, _להשע, _מחשש_
  { {0xa99c01ac,0x27e9459a,0x2246006f,0x7dd403a0}},	//   שבור, oman_, atok_, càsi
  { {0x27e900b6,0xb5fb001a,0x39584f59,0x61fb4f5a}},	//   nman_, _frát, zers_, _tuul
  { {0x28d2014e,0x39580bf5,0xa3d4000b,0x2d874f5b}},	//   _दुनि, yers_, _सीट_, _pone_
  { {0xf2d20008,0x2d9e002d,0x26b60008,0xdbd70209}},	//   _טען_, ghte_, לִים_, hääl
  { {0xfbd20029,0x2ef50254,0xb5fb0057,0x39580f43}},	//   فتح_, _езер, _krás, vers_
  { {0xdb064f5c,0x39582903,0x27e94f5d,0x0000006a}},	//   fiká, wers_, jman_,
  { {0x99160010,0x395800ed,0x2d9e0125,0x2d8702d0}},	//   зьбі, ters_, bhte_, _tone_
  { {0x2d87003f,0xdcb10092,0xda790010,0xddc24f5e}},	//   _uone_, hải_, іяў_, _troš
  { {0x7d7a0008,0x395824ed,0x11da000a,0x2b590045}},	//   _לנסו, rers_, מחשב, besc_
  { {0xab9a0086,0x2fcd0150,0x2b590045,0x2246006f}},	//   _دختر_, noeg_, cesc_, ytok_
  { {0x41cb000b,0xbb3b000a,0x39584f5f,0x8b3b000a}},	// [bf60] िवास, _העפי, pers_, _התפצ
  { {0x27e90a58,0x78c70030,0xa3a90065,0xed15004f}},	//   aman_, érvé, गोस_, לַ֣ת_
  { {0x39c50015,0x27e94158,0x67ce0091,0xdb0f0144}},	//   _تغيّ, bman_, tėję, ficè
  { {0xb5fb001c,0x2246020e,0x7dd40144,0xa87b000a}},	//   _prát, ttok_, ràsi, _האטר
  { {0x67ce0091,0x23690015,0x96b90054,0x31650012}},	//   rėję, تحلي_, _дуру_, _balz_
  { {0x47360074,0x22460014,0xb5fb0264,0x159a0015}},	//   _برگز, rtok_, _vrát, _انسخ_
  { {0x987a0053,0x55770053,0x34a718dc,0x2937004c}},	//   מאַט, _צעלן_, _евро_, לאסן_
  { {0x69ce00b8,0xb5fb0125,0xa857000a,0x22460030}},	//   hobe, _trát, פיפה_, ptok_
  { {0xed58002c,0x2b590011,0xd37b0008,0x9757000a}},	//   teľ_, vesc_, _פרמט, ליקו_
  { {0xe29b000a,0xad25002b,0xd29b000a,0x4e930015}},	//   _השמר, ورپو, _השמט, عشير
  { {0x2b590045,0x6441008c,0x40960033,0xd366002b}},	//   tesc_, _älit, _эрат, په_
  { {0xbe4a0086,0x34b70008,0xdb064f60,0x907b000a}},	//   _هشتم_, לפים_, tiká, _לטבי
  { {0x2b590011,0xdef40010,0xdfa50031,0x99d70015}},	//   resc_, _ўплы, _تحلي, كتسا
  { {0x2b590011,0x3eb9002c,0x443a4f61,0xdd2f0046}},	//   sesc_, úste_, kup_, _těši
  { {0xa3be005d,0xfce30001,0x6d5a4f62,0x71d7000a}},	//   ीका_, _пољо, meta, פולד_
  { {0x1cbb0008,0xdb1d002d,0x443a0375,0x27e94f63}},	//   _למוע, hosú, dup_, uman_
  { {0x9f4c002c,0xd6db0a7f,0x35f50010,0x6d5a0020}},	// [bf70] _budú_, ств_, дпар, oeta
  { {0xf8ae0086,0x7bcf0011,0x5eeb000a,0x27e94f64}},	//   اکی_, locu, זַבְ, sman_
  { {0x44270782,0xdbd700f2,0x443a0375,0x6d5a3a76}},	//   én_, pääl, gup_, ieta
  { {0x14740029,0x6d5a06ef,0x245e0089,0x94740015}},	//   عالج, heta, _dům_, عدلا
  { {0x41740074,0x2fcd020a,0xa2940036,0x92940010}},	//   کانس, voeg_, наці, нацц
  { {0x7c3a262d,0x067a000a,0x2d8a04d2,0x867a000a}},	//   kutr, _ונשל, öbel_, _ורשו
  { {0x6d5a4f65,0xe3b30015,0x2054004a,0xd148002b}},	//   deta, _كرر_, етыр, سشون_
  { {0x389c00a3,0x6d5a007c,0x69ce4f66,0x91f70058}},	//   מיונ, eeta, zobe, _فأطا
  { {0x7e620014,0xdb060061,0x7bcf4f67,0x2fcd4f68}},	//   _csop, likç, docu, roeg_
  { {0xdc120064,0xd658000a,0xe1f30015,0xa3a9000b}},	//   _ağın, ליחת_, _أسر_, गोर_
  { {0x656700bd,0x1bea006b,0x2fcd0fd8,0xdcf80046}},	//   _majh, ждни_, poeg_, _hově
  { {0xeb97004a,0x6d8d0125,0x6d5a01be,0xf092000a}},	//   дию_, _cúar, aeta, _שנא_
  { {0x65a0018b,0x6d5a28ac,0x69ce389c,0x7ed40033}},	//   _höhe, beta, tobe, _пішч
  { {0x9f5e0945,0x64554f69,0x8dfa000a,0xc236000a}},	//   _että_, _opzi, _והסת, ורשו_
  { {0x69ce0eb6,0x65a00030,0x18671adc,0xe9df35b3}},	//   robe, _jöhe, мари_, ptún_
  { {0xe61a4f6a,0xdb060061,0xab5b0061,0x99820091}},	//   жда_, dikç, klüy, tukų_
  { {0x60c401e2,0xdcf80089,0x64550024,0x558a042b}},	// [bf80] ğimi, _nově, _apzi, обам_
  { {0x60c40064,0xe6de000b,0xca37000a,0x3a37000a}},	//   şimi, _मरीज, _קניה_, _קרים_
  { {0xa97b000a,0xba76002b,0xb97b000a,0x934601b0}},	//   _ואיכ, _راکت, _וניי, днее
  { {0x645e0026,0xa3a9005d,0x99820007,0x64430144}},	//   rwpi, गोल_, pukų_, ània
  { {0xd2500070,0x71a60010,0x925a0225,0x7c3a00b8}},	//   انت_, мадз, تشار_, zutr
  { {0x6724008c,0x7dd40144,0x4ac6000b,0xdb060601}},	//   laij, nàst, _लखनव, likä
  { {0xa3d9005d,0xc9530008,0x6d5a4f6b,0x154305ab}},	//   _ठीक_, דמו_, veta, _шерм
  { {0x57fb000a,0xdb064f6c,0x6d5a01d7,0xdb1d15ca}},	//   חלקו, inkó, weta, llsö
  { {0x3df400d0,0x6d5a0b79,0xe2460015,0xc7d7000a}},	//   нзис, teta, _تخزي, ווקי_
  { {0x60cd0064,0xaad2005d,0x867b000a,0xa3e2000b}},	//   şama, _सड़क, קריו, _नीत_
  { {0xfe6f0086,0xf537000a,0x66ee000b,0x6d5a2731}},	//   هدی_, וניי_, चेतक_, reta
  { {0x69c0038d,0x7c3a4f6d,0x6d5a4f6e,0x63a24f6f}},	//   émen, rutr, seta, nhon
  { {0x4e960029,0x7c3a00c0,0x6d5a4f70,0x5d660015}},	//   _تشار, sutr, peta, _يُؤْ
  { {0x6d43002f,0x09e40033,0x7c3a0a3d,0xb9e4005e}},	//   _gcna, коўн, putr, віси
  { {0x4bdb0029,0x98480063,0x478b0afa,0x0d3b000a}},	//   _وبعد_, мята_, осам_, _וגוב
  { {0xab5b0064,0xdb1d0123,0xb6f50054,0x87980058}},	//   ylüy, elsö, езбј, وَّر_
  { {0x15150010,0xd64b005e,0x55750597,0x7c2808d9}},	// [bf90] едзя, дiсл, нгат, lsdr
  { {0x9954002c,0xc4db0001,0xd9e3000b,0xdb060061}},	//   _päť_, ође_, _गठित_, tikç
  { {0x6724003f,0xddc2005c,0x7bc80003,0xf3f94ccf}},	//   baij, _spoś, éjug, чнеш_
  { {0xa3a9005d,0xdcf80089,0x17190008,0xa5f91a4d}},	//   गों_, _sově, _מוֹע, _нему_
  { {0xdcf80089,0x7d0a27fc,0x91d50033,0xd6270015}},	//   _pově, _offs, нцкі, _تعجي
  { {0xe045312e,0x6b8d007c,0x7c282d55,0xa0690a3f}},	//   енки, _loag, ksdr, зака_
  { {0x74150067,0x03190054,0xd0110015,0xd12e0015}},	//   _سوءا, _новј_, دلع_, حمى_
  { {0x70520087,0x0e6500d7,0xab5b0012,0x9972003d}},	//   انيا, екин, hnüb, iņš_
  { {0xa3cc005d,0xfe710015,0xddc2002a,0x8db502a3}},	//   रकर_, ادب_, _upoś, есні
  { {0x3f82002e,0x519b002b,0x4c851206,0xac850a86}},	//   ökur_, _بخرد_, елов, егол
  { {0xe5724f71,0x3f15005f,0x80140010,0xbb460839}},	//   אַר_, _здес, _афіц, ненк
  { {0xfe710074,0x4c820036,0x8f680029,0xc949000a}},	//   _مدت_, улюв, _يملك_, _למ_
  { {0xdd950010,0x99840089,0xaae50029,0xc332039e}},	//   _пады, émů_, َسُو, נוך_
  { {0xc21200f3,0x6e2900aa,0xb5fb0046,0x63a24f72}},	//   רהם_, mseb, _psán, zhon
  { {0xe0c70087,0x02dc000b,0xa3c1000b,0x8d740067}},	//   از_, _बर्न, ुवा_, _جانا
  { {0x2a72005c,0x6f0900d9,0x6e290796,0xcc56000a}},	//   _tryb_, ncec, oseb, _נספק_
  { {0x290501e2,0x97c3034e,0x6e294f73,0xa6c722d7}},	// [bfa0] ılar_, уйте, nseb, елта_
  { {0x05850036,0xdb060604,0x7ae44f74,0x6d414f75}},	//   куєм, sikä, _izit, ngla
  { {0x98b800df,0x63a23dd1,0x13a8002b,0x29184f76}},	//   merį_, thon, ونئی_, mbra_
  { {0x8c1a0008,0x2486016f,0x68e11099,0x74130067}},	//   פוני, ćom_, ülde, اونا
  { {0xe2970001,0xc6d60029,0xc3270015,0x96fb000a}},	//   нац_, _ستحت, ركون_, _מלכת
  { {0x20660001,0x6e2900bc,0x98b80091,0x67c50091}},	//   еђив, dseb, nerį_, mėja
  { {0xdce3018c,0xb8820089,0x84e30286,0xf993000a}},	//   _banč, _říjn, _борж, ררו_
  { {0xdd2500df,0xa8570008,0x69dc00b8,0xbfa7004a}},	//   _rūši, תיקה_, hlre, етье_
  { {0xd3450086,0x63a00020,0x67c50007,0x7ae4003f}},	//   _شیوه_, _ilmn, nėja, _nzit
  { {0x6d410123,0x3994007c,0xd257000a,0x01690015}},	//   ggla, _käsu_, _אשמה_, _يحلو_
  { {0xdcba0063,0x80a60029,0x859b000a,0x2537004c}},	//   ящи_, _ثمان, פשטו, ענטש_
  { {0x67c50007,0x1ee8002b,0x6d414f77,0x501b000a}},	//   kėja, _قوای_, agla, _זואו
  { {0xdfcf04b6,0x61fa0064,0x4e930067,0xbfb7000a}},	//   _اين_, _kitl, _مشور, _אפאצ_
  { {0x17fb0029,0x67c50007,0x6c5401c5,0xdb0f4f78}},	//   كررة_, dėja, _акку, micí
  { {0xdb0f02c1,0xadd70008,0xb909000b,0x9d430004}},	//   licí, _רווח_, _बर_, _сејд
  { {0xca490086,0x657c0026,0x61fa05d8,0x9c0b000a}},	//   _قلعه_, _anrh, _litl, _צִוִ
  { {0x29180014,0xdb0f4f79,0xfc450057,0x67c50091}},	// [bfb0] bbra_, nicí, žíte_, gėja
  { {0x95d8004a,0xa3a9000b,0x3abc004f,0x28d20065}},	//   едут_, गोई_, _ממחנ, _दुवि
  { {0xe3be0064,0xc9520008,0x95c40015,0x47d50015}},	//   ğına_, _דמי_, ديله, _ليدر
  { {0x04c8003b,0xe3be01e2,0x6e290176,0x92950010}},	//   روني_, şına_, yseb, каец
  { {0x6d410757,0xc1050015,0x2169227a,0x61fa4f7a}},	//   ygla, نوشي, дили_, _bitl
  { {0xd838018c,0x23690a00,0x66640063,0x018b004a}},	//   šče_, žaj_, _съюз, ящей_
  { {0xa0660063,0xb0680015,0xa493002b,0xe0420342}},	//   ваща_, فصيل_, _حیات, анщи
  { {0x8cca005d,0xf412000a,0xddc2002a,0x99990046}},	//   _सँजो, _כפל_, _groź, kusů_
  { {0x764d00b6,0xbea50004,0x8d750067,0x657c0034}},	//   ntay, тапк, نادا, _ynrh
  { {0xfe420036,0x6e290849,0xd2280015,0xf42a008c}},	//   шньо, rseb, _أكله_, _äää_
  { {0x8f550015,0xdb0f0045,0xe6de000b,0x6e290f77}},	//   _لناش, dicâ, _मर्ज, sseb
  { {0x764d0064,0x399400c0,0x7b96005e,0x8b960a31}},	//   ktay, _läst_, трої, троч
  { {0x21270092,0xdb0f0011,0x98b80091,0x0000006a}},	//   oanh_, ficâ, terį_,
  { {0x67c50007,0x7bdd138c,0x7de8005e,0x6c850015}},	//   vėja, alsu, _зміг_, _للتم
  { {0x3f8f0005,0xaba60015,0x764d0061,0x290a0030}},	//   _kogu_, _لإظه, etay, rcba_
  { {0x21270092,0x18670001,0x6c56000a,0x764d0061}},	//   hanh_, њати_, _ייצא_, ftay
  { {0x3f8f010b,0x399400c0,0x764d0035,0x7ae44f7b}},	// [bfc0] _mogu_, _bäst_, gtay, _uzit
  { {0x67c50007,0x3f8f4f7c,0xa806080e,0xb9060058}},	//   rėja, _logu_, _изол, _جِدً
  { {0x03260036,0x499b0008,0xb9370008,0x299b000a}},	//   вден, _חשיב, _בניו_, _חסימ
  { {0x61ca005d,0x3f8f0085,0x78a30061,0x67c50091}},	//   ाक्ष, _nogu_, _ünva, pėja
  { {0x15ba0010,0xa1ea0029,0x42540115,0x127a0015}},	//   _жывы_, ورتك_, انتر, بحاث_
  { {0x657c0176,0xe2970001,0x68e90089,0x7f95047e}},	//   _unrh, ђај_, řede, _máqu
  { {0xe4230086,0x61fa05d7,0x60630015,0x66160091}},	//   _نکني, _vitl, لهول, lpyk
  { {0x61fa00dd,0xe0cf0029,0x25e6000b,0x3849000a}},	//   _witl, غزو_, _जीती_, ׂאוּ_
  { {0x5e430029,0xc7b304dc,0xc693000a,0x6fc7000b}},	//   لَيْ, יבה_, ֹאת_, ावजू
  { {0x2ca90089,0x70560029,0x61fa0150,0x54e6000b}},	//   _řada_, _لنطا, _uitl, _कराए_
  { {0x853b0008,0x653b000a,0xbb95005e,0xe53b000a}},	//   וגיי, ועיד, ганщ, ותיר
  { {0x7e670024,0xc4d3000a,0x0000006a,0x0000006a}},	//   ājpr, יגת_,   ,
  { {0xee940086,0x4e1b005d,0x41b6000b,0xa5bb4f7d}},	//   _حداک, पीआई_, _अगास, _kvót
  { {0xdd93008f,0x5e570008,0xa9c4004a,0xfe090015}},	//   _вашы, _סיוע_, асск, _أغنى_
  { {0x7793002b,0x60e60046,0xf8b40033,0xdb0f1358}},	//   لیدا, _úsmě, абрэ, ricâ
  { {0xe8940010,0x394d0089,0xb8db000b,0xa3e2000b}},	//   шась, řes_, _आइ_, _नील_
  { {0x8bb40002,0xeb1f000b,0x443a0079,0xd7f808f7}},	// [bfd0] _خصوص, परीत_, erp_, тур_
  { {0x8514005e,0x9f9a007c,0x95c40015,0x764d29f8}},	//   имує, _hääl_, ليقه, rtay
  { {0xf7eb003b,0xdce30048,0xf9920008,0x764d0064}},	//   _يرجى_, _kanā, _הרי_, stay
  { {0x67c50007,0x389a000a,0x764d0061,0xa4d4005e}},	//   mėjo, _נירנ, ptay, шохі
  { {0x67c50007,0xdce30024,0x6b9d0079,0x443a0091}},	//   lėjo, _manā, iksg, arp_
  { {0xa5bb005c,0x644a0251,0xe1f8005e,0x1a9c004c}},	//   _dwóc, àfic, вгі_, וידע
  { {0xe0550029,0xdb1d0020,0x3f8f0024,0x21270092}},	//   اختب, fosü, _pogu_, ranh_
  { {0x6d5c0020,0xf0620063,0x439401c5,0x69d54f7e}},	//   õran, скъп, _касс, hoze
  { {0x69d54f7f,0xbe850015,0x7c3a4f80,0x02b70065}},	//   koze, اجعو, ertr, _अधिभ
  { {0xc6920008,0x67c50091,0x5c15027a,0x65a00012}},	//   צאי_, kėjo, льму, _löhn
  { {0x62990026,0x75eb0064,0x41df000b,0x7c950015}},	//   lywo, müzd, _पीएस, اشخا
  { {0x29cd002c,0x67c50007,0xe456004c,0x03d5004f}},	//   hľad_, dėjo, נירט_, רוֹם_
  { {0x539a00b2,0xff040063,0x20050035,0xdce10064}},	//   גירו, _тяхн, _huli_, rklı
  { {0x186a010f,0x75eb0064,0x52d6004c,0x20051779}},	//   наги_, nüzd, רושע_, _kuli_
  { {0x589505d1,0xf1b2000a,0xcc350033,0x9c96002b}},	//   ашту, מסך_, _схлы, _منوط_
  { {0x200500b6,0x6825004a,0x6f1b0012,0xe8f701cf}},	//   _muli_, рьёз, nbuc, улс_
  { {0xe57a0e44,0x69d54f81,0xe707002b,0xd6250015}},	// [bfe0] нза_, boze, اسفی, لعلي
  { {0x67c50007,0x2fdf00b8,0x5ee8000a,0x6f1b0012}},	//   bėjo, hlug_, דַעְ, hbuc
  { {0xe3be0064,0x26cb00d9,0x62994f82,0x97c60002}},	//   şıma_, _exco_, eywo, _مقدو
  { {0x1417003b,0xa22a00a4,0x5345005e,0xc3da0015}},	//   اينة_, ежда_, ихіа, رباط_
  { {0x75840074,0x8bd7000a,0xdb0f0077,0x27e04f83}},	//   _پیام, נונו_, nicá, mlin_
  { {0x0f1c005d,0xc6930008,0xb4260031,0x27e048bc}},	//   नर्स_, _האש_, _معرو, llin_
  { {0xdd3a0011,0x66060e95,0x6e3b0375,0x2fdf0012}},	//   _lăţi, _hukk, erub, flug_
  { {0x63b9005c,0x27eb0092,0x5f940254,0xb355002b}},	//   ciwn, _xhcn_, риит, _نیما_
  { {0xdd900029,0xad660086,0x27e000f2,0x244e0057}},	//   قوة_, هاده, ilin_, lým_
  { {0xa3b0005d,0x4d98005e,0xaa7d008c,0xcc54006b}},	//   टोर_, ткою_, _käöä_, авоъ
  { {0xdce30024,0x244e0107,0x66060293,0x3cf8012d}},	//   _panā, ným_, _lukk, ärv_
  { {0x656e002d,0x6ab2000b,0x672600bc,0xdb0f0e51}},	//   _labh, ीपूर, _nekj, ficá
  { {0x6b9d002e,0x244e0107,0x539b000a,0x66060601}},	//   rksg, hým_, תיכו, _nukk
  { {0xf2d300b2,0x9989005c,0x244e0264,0x65a00012}},	//   מער_, _stał_, kým_, _söhn
  { {0x6299005c,0xddc200bd,0x67260af5,0x58840033}},	//   zywo, _krož, _bekj, быта
  { {0x67c50007,0x2d8c00c0,0xd838006f,0x7ceb000a}},	//   rėjo, ljde_, áča_, _אַחֶ
  { {0xdb0f0020,0x35b5017d,0xa9c700c3,0x2d8c0046}},	// [bff0] öjõu, абар, _مزدو, ojde_
  { {0x656e002f,0xd838018c,0xdb1d005c,0x66060293}},	//   _cabh, šča_, posó, _dukk
  { {0xddc200bd,0x2d9e016b,0xf9fa000a,0x6f1b002a}},	//   _orož, ikte_, _שהתמ, ybuc
  { {0xae04014e,0xb7671660,0x6299005c,0x656e002d}},	//   रदान_, _стой, tywo, _eabh
  { {0x656e002d,0xceb90046,0x9207003d,0x2fdf00aa}},	//   _fabh, obře_, klāš, vlug_
  { {0x05870080,0x656e002d,0x5059006b,0x2278002b}},	//   _сумм, _gabh, вшия_, الوگ_
  { {0xe588000f,0x10a52003,0xddc204b2,0x34950248}},	//   _עָשָ, рийн, _brož, _тавр
  { {0xa295192f,0x7ff50086,0xe3b30086,0xe3b000e5}},	//   _кабі, جستا, _طرز_, _فرق_
  { {0xcee9006b,0x6f1b4f84,0xa6fb000a,0xab5b0030}},	//   ъдие_, rbuc, עִ֔י, tnün
  { {0xdcf80048,0x463c0053,0x32940015,0xbd450015}},	//   _novē, געזע, _الْأ, جندي
  { {0xb17a0053,0xa17a0053,0x417a000a,0xab5b0012}},	//   _שטער, _שטעט, _שנעב, rnün
  { {0x765d0035,0x6e3b0035,0xaed50004,0xddc22ae7}},	//   _opsy, prub, _коеш, _grož
  { {0x7ff40074,0x6e220026,0x8f9a0008,0x6726002e}},	//   _اسلا, _gwob, _שיני, _rekj
  { {0xdb0400dd,0x75270089,0x66061c37,0xd94607c1}},	//   _klië, _nejz, _rukk, јеви
  { {0xa3d5005d,0x656e002d,0xd7060254,0xb5fb0227}},	//   सका_, _rabh, изви, _fráz
  { {0x656e0c0b,0xc7a305c4,0x244e0264,0xe73707f7}},	//   _sabh, оиск, vým_, иес_

  { {0xb69b0011,0xa50a0001,0x27f24f85,0x27e02395}},	// [c000] _sfâr, веза_, rmyn_, rlin_
  { {0x27f20026,0x1a9b0135,0x244e0227,0x3ead0030}},	//   smyn_, _סייע, tým_, izet_
  { {0x6726002e,0xc953000a,0x3f9f008c,0xd36f008b}},	//   _tekj, _ומת_, kkuu_, оч_
  { {0xa3b0014e,0xe29a008f,0x244e0107,0x7413002b}},	//   टों_, кае_, rým_, زوها
  { {0x656e002f,0x98a30024,0xf1a90086,0x2d9e0293}},	//   _tabh, majā_, گانه_, ykte_
  { {0xfe080023,0x77640251,0x98a30024,0x7644003f}},	//   _nữa_, leix, lajā_, muiy
  { {0x6e22005c,0xf1a9002b,0xf836000a,0x645c2d24}},	//   _swob, دانه_, ׁנַת_, _upri
  { {0x77640251,0x98a30024,0x4fc6000d,0x9326002b}},	//   neix, najā_, јска, _خرسن
  { {0x61460124,0xfe080016,0x44444f86,0x3ead1086}},	//   _веза, _bữa_, lu_, gzet_
  { {0xd6570008,0x44444f87,0xf653000a,0xdd900067}},	//   סיית_, ou_, קצת_, سوج_
  { {0xc57900b2,0x98a30024,0xb5fb0057,0x6f660342}},	//   אָרט, kajā_, _práz, _ввез
  { {0x9ffa0029,0xa3cc005d,0x4f660015,0xddc901a3}},	//   _شراء_, रकट_, _خاطف, rveš
  { {0x7e790176,0x77640251,0x5fb30015,0x99d70015}},	//   _grwp, deix, _بمنط, لتسا
  { {0x6b5c0134,0x1cba0029,0xeb9f00cb,0x4dd30021}},	//   _pågæ, _لاعب_, skø_, _وتوس
  { {0xb5fb002d,0xada3009c,0x44444f88,0xdb060046}},	//   _usái, _фајл, ju_, liký
  { {0x77640251,0xf7700029,0x98a30024,0x3cfb000a}},	//   geix, واق_, gajā_, _בלונ
  { {0x44444f89,0xe6670180,0x929d002a,0xa5350033}},	// [c010] eu_, штво, _ogła, йнач
  { {0x443100df,0x6d484f8a,0x44444f8b,0xd4370058}},	//   _pvz_, ngda, fu_, لعصب
  { {0x98a30024,0x7ddd0251,0xad1b000a,0x44444f8c}},	//   bajā_, mèst, דובר, gu_
  { {0x69c700bd,0x7ddd0251,0xe3b000e6,0x98a3003d}},	//   lnje, lèst, ورن_, cajā_
  { {0xc2440010,0x4df6005d,0x44444f8d,0xe28e0033}},	//   жнік, ँगाई_, au_, ча_
  { {0xdca60029,0x672d00f2,0xcad8000a,0x25570046}},	//   _فى_, laaj, בודת_, _dělí_
  { {0x44444f8e,0x04c90015,0x3f9f008c,0xddc2002a}},	//   cu_, _صوري_, tkuu_, _droż
  { {0xc7b2000a,0xaf98004a,0xfe080016,0x6445042c}},	//   ּ֑ה_, итых_, _sữa_, muhi
  { {0x69c700bd,0x64451437,0xc8e4000b,0x92680054}},	//   knje, luhi, _गर्म_, _врха_
  { {0xcda90074,0x3f9f00f2,0x31580015,0x21580015}},	//   اهده_, skuu_, _نجمة_, _نجمع_
  { {0x672d0020,0x3ead00dc,0x69c70198,0x64453310}},	//   kaaj, szet_, dnje, nuhi
  { {0x929d005c,0x6d480035,0x672d0209,0x2911002a}},	//   _zgła, agda, jaaj, ecza_
  { {0x98a30024,0x44444f8f,0xed590788,0xdb060072}},	//   vajā_, zu_, _бол_, mikü
  { {0x644511c6,0x44444f90,0x69c707c4,0x6d5d0030}},	//   kuhi, yu_, gnje, ősab
  { {0x776408e0,0x68e90089,0x98a30024,0x64450020}},	//   teix, ředn, tajā_, juhi
  { {0x644500b6,0x07a6006b,0xd83800bc,0x8c36000a}},	//   duhi, щабн, ščo_, _הטקס_
  { {0x776408e0,0x98a30024,0xfbd3000a,0x80be000b}},	// [c020] reix, rajā_, _מתה_, _वेने
  { {0x12880086,0xdb06007c,0x75d60015,0x98a3003d}},	//   یمای_, hikü, حيطا, sajā_
  { {0x644500b6,0x44440c60,0x63060029,0x6b844f91}},	//   guhi, uu_, موال, _knig
  { {0x7e69003f,0xf7860015,0xf2060033,0xab5b0030}},	//   kwep, _الحَ, бяко, enüj
  { {0xdb064f92,0x234b002b,0xc8b5002b,0x44444f93}},	//   likó, اسمی_, _هلیک, su_
  { {0xa97a00b2,0xe9df002d,0x25b800bd,0x44444f94}},	//   ראַכ, ltúr_, _umrl_, pu_
  { {0x443e0023,0xdb060050,0x55bb000a,0x04960021}},	//   _ít_, nikó, _עמלו, _الزح
  { {0x69c700bd,0x987b00a3,0xdfd00021,0x2911002a}},	//   znje, ראקט, بيب_, zcza_
  { {0xf7730008,0x628600bd,0x539b000a,0xa3d5000b}},	//   לקה_, _škof, _עימו, सकर_
  { {0xa281002b,0x6db40033,0xd00a0054,0x63a20ef2}},	//   _آیوو, ійну, _беже_, lkon
  { {0xb7fa005d,0xe9df002c,0xcb04005d,0xd138002a}},	//   ्दाम_, ktúr_, रखंड_, _idą_
  { {0xd90f0086,0x2911002a,0x447b004c,0x600b000a}},	//   کید_, wcza_, אנטע, _עִבְ
  { {0xddc20048,0x672d008c,0xbe850015,0x6d3418fc}},	//   _esoš, vaaj, _وجهو, _делф
  { {0x67c50007,0xfe370053,0x6b8429e2,0x6df40015}},	//   mėji, _פרוי_, _enig, _بكتا
  { {0x67c500df,0x2911005c,0x58840139,0x69c702c6}},	//   lėji, rcza_, пыта, rnje
  { {0x8aa70010,0x68e90089,0x69c70844,0x5c73006b}},	//   _грод, ředo, snje, _хлът
  { {0xdb0d0064,0x67c50007,0xaba80086,0x672d00f2}},	// [c030] _amaç, nėji, _دهيم_, raaj
  { {0x672d0e95,0xec090016,0x38c9002b,0x69c00030}},	//   saaj, _mến_, _ناجی_, émet
  { {0x93190029,0xa988000a,0x8d5b000a,0xb5fb0030}},	//   لقاء_, _הָרִ, רכבי, _apác
  { {0x67c500df,0x64454f95,0x63a24f96,0x0000006a}},	//   kėji, ruhi, gkon,
  { {0xe1f10086,0x7a7c0053,0x6445442e,0xc8c8002b}},	//   وست_, ָרוס, suhi, _نوین_
  { {0x67c50007,0x3f750016,0xf2d000c3,0x801515ee}},	//   dėji, _ều_, رآن_, офиц
  { {0x299c0008,0xa99c000a,0x999c000a,0x63a24f97}},	//   רסומ, רבור, רבוט, bkon
  { {0xec090092,0x53a50015,0xee390718,0x2d983caa}},	//   _bến_, _بمرك, ани_, ören_
  { {0x68e100dc,0x1e85005e,0x22ab006b,0xdb06007c}},	//   üldj, ілом, _съвп_, rikü
  { {0x02440015,0x7bcd008c,0x7bdf0012,0x4d650350}},	//   _رَمَ, _ajau, _akqu, цков
  { {0xa0c40029,0xdbca005e,0x30a73162,0xdb1d001a}},	//   _فيكو, игод_, _урав, insæ
  { {0x67c500df,0x06fb014e,0x9ed90063,0x7d1c0064}},	//   bėji, ्शाव_, _кмет_, ırsa
  { {0x7aed005c,0x7fe8005e,0x68e90046,0x6ee700c3}},	//   _czat, _уєфа_, ředl, _اسال
  { {0x3ea2003c,0x63a94f98,0x28db000b,0x31670012}},	//   økte_, _llen, _मुहि, nenz_
  { {0x929d005c,0x2dd80015,0x7bcf0003,0x63a94f99}},	//   _ogło, _ابنة_, ébuc, _olen
  { {0x6b840026,0x9f460092,0xec090016,0xa6ca07be}},	//   _unig, _khoá_, _yến_, алба_
  { {0xe6170404,0x63a2078a,0xdb37004f,0xf1a90065}},	// [c040] жду_, vkon, _ונפח_, कसान
  { {0xba9b0008,0x04460036,0xdb1d145c,0xd5af0015}},	//   _כספי, жежн, gnsæ, نفق_
  { {0x05770029,0x31670012,0x63a904dd,0x04ca0015}},	//   تملة_, denz_, _blen, جواي_
  { {0x69dc03b8,0x14170015,0xab0d000a,0x9f4c016e}},	//   lore, زيهة_, ְהוֹ, _judô_
  { {0xb5fb00dc,0x69dc4f9a,0x7f9c0144,0x63a205a9}},	//   _csás, oore, _xéqu, rkon
  { {0x63a94f9b,0xca7b000a,0x71f70021,0x31670028}},	//   _elen, יננט, يروس_, genz_
  { {0xe57100b2,0x11390010,0xbfaa4f9c,0xf99300f3}},	//   _אַן_, сячы_, итие_, ורג_
  { {0xe29a008f,0xdfd0003b,0x02460029,0x69dc4f9d}},	//   _каб_, عية_, _وَأَ, hore
  { {0x765600f2,0x69dc4f9e,0x98a3002a,0x0000006a}},	//   ntyy, kore, mają_,
  { {0x929d0050,0x161f005d,0x5d54000d,0x98a3005c}},	//   _zgło, मीटर_, чкот, lają_
  { {0x63bb0176,0xdb1d038d,0x69dc06d4,0xa0c60086}},	//   _ymun, lisé, dore, _بياو
  { {0x67c50007,0x5457000a,0x98a3002a,0x9a87007e}},	//   pėji, חסטן_, nają_, оугл
  { {0xdb1d0152,0xc3330008,0xa5bb002a,0x93fb015b}},	//   nisé, וור_, _dwój, ילטי
  { {0xad660015,0x418a000a,0x68e90046,0xdb040030}},	//   _ذاته, ׁנָ֑, ředm, _amió
  { {0x98a3005c,0x7bcd003d,0xdd0f006f,0x200c4f9f}},	//   kają_, _tjau, _užšo, _judi_
  { {0xd7740029,0x316700b8,0x9615005e,0x98a3002a}},	//   واقع, zenz_, змаї, jają_
  { {0x1ab41e88,0x98a3005c,0x9a590029,0x69dc4fa0}},	// [c050] _объя, dają_, _الخط_, bore
  { {0x69dc1213,0x356b000d,0x63a94fa1,0x98a10045}},	//   core, јран_, _slen, _cehă_
  { {0xc952000a,0x59d40021,0xfe790046,0x200c1fe2}},	//   _אמי_, _تغير, zvů_, _nudi_
  { {0x98a3005c,0xe51b000b,0xb51b000b,0x7bdd4fa2}},	//   gają_, _प्रि_, _प्रय_, nosu
  { {0xa2940036,0xdb7c0053,0xb2240010,0xc2cb0015}},	//   маці, ינאכ, дміл, جبال_
  { {0xd49b0fea,0x200c4fa3,0x409504e5,0x21690248}},	//   _крб_, _budi_, зрит, сики_
  { {0x316700b8,0x98ba0064,0xa1120015,0xc1e80033}},	//   renz_, _yapı_, رويت, цьце_
  { {0x69dc0f2e,0xc4d2000a,0x98a3002a,0x31670012}},	//   zore, _נגן_, cają_, senz_
  { {0x69dc02c1,0x7bdd00dc,0x4277002b,0xed59006b}},	//   yore, dosu, _بازآ, боп_
  { {0xc05b129a,0x661b0061,0x67c50091,0xdc120061}},	//   _від_, _çuku, mėju, _aşın
  { {0x67c50007,0x459c004c,0x7ae4008c,0x657501c2}},	//   lėju, יסזע, _syit, _mazh
  { {0x7bdd0548,0xbf58005e,0x78750046,0xa0c40040}},	//   gosu, _мрії_, zývá, _تيمو
  { {0xde580010,0x7c950086,0x69dc4fa4,0x67c50091}},	//   _маці_, زشگا, tore, nėju
  { {0xceb20053,0x98a3005c,0x69dc00f2,0x7c6500a2}},	//   _איד_, zają_, uore, _فاعل
  { {0x7e7b0084,0x69dc4fa5,0x2d874fa6,0x2adc000b}},	//   lvup, rore, _inne_, _गुरु_
  { {0x4c3a0008,0xd70a0010,0x765600f2,0xdc3a000a}},	//   _התקב, снае_, ttyy, _העקר
  { {0x69dc4fa7,0x320501f9,0x0000006a,0x0000006a}},	// [c060] pore, _oily_,   ,
  { {0x7abb0008,0x98a3005c,0x67c50007,0xdb1d4fa8}},	//   _לצפו, wają_, dėju, visé
  { {0x999b0008,0x299b0008,0x765600f2,0xa99b0008}},	//   _הביט, _הסימ, styy, _הביר
  { {0x200c000c,0xb6a30023,0x9a57002b,0xdb1d435c}},	//   _rudi_, _khẩ, _بلیط_, tisé
  { {0x52130036,0x98a3005c,0xba3a004c,0xf2da0021}},	//   едіт, rają_, צײַט, حظات_
  { {0xdb1d1f0d,0x98a31ed6,0x75eb0061,0x75d6009a}},	//   risé, sają_, nüzl, _ريزا
  { {0xf957000a,0x67240085,0x7e624fa9,0x0000006a}},	//   פסקת_, obij, _spop,
  { {0xf457000a,0x80370015,0xa857000a,0x68e1007c}},	//   _מילר_, أسوأ_, ליצה_, üldi
  { {0x442a0026,0xe731000a,0x1f130015,0x7bdd0085}},	//   _hwb_, כֵי_, ربيج, vosu
  { {0x200c0e6d,0x64430048,0xa1c3042b,0x7e760091}},	//   _tudi_, šnie, _збуд, _šyps
  { {0x7bdd4faa,0x6557000a,0x8557000a,0x3a29462f}},	//   tosu, הביא_, השיב_, _swap_
  { {0x68e90089,0x92020024,0x2d874fab,0x44440541}},	//   ředk, žāda, _enne_, ir_
  { {0x753c0050,0x2f970008,0xb6a30092,0x44440746}},	//   _odrz, _מכאן_, _chẩ, hr_
  { {0x6dd40015,0x4444326e,0x76440bc7,0xb606003d}},	//   _تقتض, kr_, driy, nošā
  { {0x657500bc,0x444430d2,0xbd5b000a,0x7bdd4fac}},	//   _razh, jr_, _הכוש, posu
  { {0x501b000a,0x62804fad,0x44444fae,0x6724003d}},	//   מולו, _ormo, dr_, gbij
  { {0x3bbc000a,0xbb3c000a,0xd50b002b,0x2ad5002b}},	// [c070] _למהד, _התחז, مغان_, _زيدآ
  { {0xb6060024,0x67c50007,0x69da0046,0x44440034}},	//   jošā, vėju, čtec, fr_
  { {0xf9920008,0x444406bd,0x62800738,0xb606003d}},	//   _סרט_, gr_, _armo, došā
  { {0x1836000a,0x3205006f,0x9cd7000a,0xfc17000a}},	//   _קארל_, _sily_, הובה_, פקדי_
  { {0xdce10024,0xd25b042b,0x877a000a,0xf990002b}},	//   ielā, сце_, _וארי, _شبی_
  { {0xfa78013a,0x22a30024,0x44443186,0x27e94faf}},	//   פעות_, _rīkā_, br_, llan_
  { {0xa4d4005e,0xd0110015,0x67c50091,0x62804fb0}},	//   _зорі, خلع_, sėju, _ermo
  { {0x27e94fb1,0xdce9006f,0xbe39005e,0x0ea90342}},	//   nlan_, ínča, очої_, жкий_
  { {0xc2c40029,0x66070111,0xa3da000b,0x3e320015}},	//   _كيفي, _kijk, ठकर_, نفير
  { {0xd83800bd,0xa5bb0125,0xfaff00aa,0x6724136b}},	//   šči_, _dtóg, reël_, zbij
  { {0xbb461006,0x673d0085,0x27e94fb2,0x660f0691}},	//   менк, _odsj, klan_, _luck
  { {0xb6a30023,0x547a0008,0x66070111,0xfc3f0264}},	//   _phẩ, קטרו, _lijk, čí_
  { {0xeb97250c,0x8db50036,0x9f040015,0xd336000a}},	//   фия_, _оскі, _كومو, וררה_
  { {0xdd940010,0x2ca90089,0x0d730086,0x4efa0447}},	//   _пачы, _řadu_, _سختگ, _והנו
  { {0x661d4fb3,0x37e6005e,0x38c8002b,0x48e30033}},	//   _atsk, довг, ساسی_, ворв
  { {0x660f18b4,0x2fcd4fb4,0x752e0061,0x75eb0061}},	//   _buck, nneg_, _sebz, süzl
  { {0x44440176,0x67244fb5,0xcb8b000a,0x66070079}},	// [c080] wr_, rbij, _וְיֹ, _bijk
  { {0x272c00a7,0x27e9064e,0x4444037f,0xddc9003d}},	//   ến_, alan_, tr_, steņ
  { {0x44444fb6,0xdce30046,0x6607198a,0x27e94fb7}},	//   ur_, _raně, _dijk, blan_
  { {0x44444fb8,0x23270b1e,0x291801c2,0x96ba007e}},	//   rr_, доци_, lcra_, _дугу_
  { {0xb0c3005d,0xb6060024,0x27e00df1,0x9f4d008c}},	//   _वेबग, tošā, moin_, imeä_
  { {0x27e000f2,0x644302c1,0x2fcd0026,0x69ce0f3e}},	//   loin_, ánic, eneg_, nnbe
  { {0x21670054,0x2ea6000b,0xb606003d,0x7416002b}},	//   фији_, गन्त, rošā, _آورا
  { {0x66070079,0x27e0008c,0x69ce0012,0xab5b0012}},	//   _zijk, noin_, hnbe, nnüt
  { {0x23890089,0x8d6a0180,0x6ac8000b,0xbd6a219d}},	//   šují_, ојна_, रपोर, орне_
  { {0xf1aa0086,0x69ce0111,0x68e90089,0x33260b00}},	//   _باره_, jnbe, ředi, lbox_
  { {0x27e0008c,0xdb04001a,0x27e94fb9,0x0000006a}},	//   koin_, _smið, ylan_,
  { {0xf0b70053,0x0465000a,0xdfa60015,0x6f770015}},	//   _קלאר_, ׂיתָ_, _تحطي, _يملأ_
  { {0x6ffb000a,0x8d73002b,0x6d5c007c,0xdce1003d}},	//   _והאפ, رایا, õras, relā
  { {0xddc90089,0x5964006b,0x0cd40c71,0x332600da}},	//   kteř, къса, _полю, hbox_
  { {0x27e900dc,0x66070111,0xf8074fba,0xdb1d001a}},	//   tlan_, _rijk, дчан, lisí
  { {0x27e9013c,0xba550054,0x69ce2fbd,0x5fde000b}},	//   ulan_, _звиј, anbe, मविल
  { {0x35f50840,0x3326019f,0x3ea40d3d,0x27e94fbb}},	// [c090] епар, dbox_, nymt_, rlan_
  { {0x201e00f2,0x27e0002d,0x34ab00a2,0x2d9c2efb}},	//   _otti_, aoin_, يداً_, _jove_
  { {0x2d9c003e,0x2246006f,0x78a10123,0x27e94fbc}},	//   _move_, erok_, älvd, plan_
  { {0x2d9c1d40,0x66070079,0x660f4fbd,0xe3b30015}},	//   _love_, _wijk, _tuck, خرط_
  { {0xdb060604,0x201e04ed,0x661d0971,0x471a000a}},	//   sikö, _atti_, _utsk, _מורג
  { {0x018b0080,0x2d9c4fbe,0x0000006a,0x0000006a}},	//   ющей_, _nove_,   ,
  { {0xc0e2049d,0x6474004a,0x89ec000a,0xe4140033}},	//   лошк, _игру, קַדֵ, _адсь
  { {0x6815005c,0xd00e0015,0xf772000a,0xe0d0006e}},	//   _lądo, حلي_, ָ֧ה_, جزه_
  { {0x201e0064,0xa0220e95,0x63a4008c,0x4e050bb1}},	//   _etti_, ööri, öine, нзиб
  { {0x2fcd0176,0x2d9c0f21,0xa5bb0030,0x0c25005e}},	//   sneg_, _cove_, _utód, нмон
  { {0x81760053,0x6ac8005d,0xdb1d002d,0x2d9c052a}},	//   _רגעס_, रप्र, aisí, _dove_
  { {0x7f840029,0xc4d2004c,0xdb04016e,0x907a000a}},	//   _للمن, רגט_, _aliá, _מטעי
  { {0x27e000f2,0xab5b0061,0x0000006a,0x0000006a}},	//   voin_, enüs,   ,
  { {0xe9df002e,0xed56005e,0x89f50033,0xfe9a000a}},	//   trúa_, _зош_, вясц, _מינמ
  { {0x27e0008c,0x7d7600c3,0x69ce4fbf,0xddc9036d}},	//   toin_, _سمير_, rnbe, ovež
  { {0x2d9c016f,0xd7060054,0xb903056d,0xdb04191d}},	//   _zove_, езби, узск, _eliá
  { {0x39360010,0x464a0080,0x09e605e6,0x764d4fc0}},	// [c0a0] _пэнс, язан_, _поин, guay
  { {0x27e00152,0x7bc64fc1,0xab5b007c,0x7dea004c}},	//   soin_, liku, hiül, ִקײַ
  { {0x75d30029,0x5b7a000a,0x68e10030,0x6b7a000a}},	//   ديلا, ּרְא, üldt, ּרְנ
  { {0x7bc64fc2,0xf487002b,0x64430030,0x799e00e7}},	//   niku, عالی, ánia, _hopw
  { {0x41e6078f,0x599a0008,0x46a30010,0xd2a70033}},	//   ніка, ּשֶׁ, _баяв, нкце_
  { {0xd83800bd,0x21770033,0xdb1d0794,0x7bc64fc3}},	//   šču_, ейшы_, visí, hiku
  { {0x68e90046,0xc953000a,0x7bc64fc4,0x232a20f1}},	//   ředv, אמו_, kiku, _нови_
  { {0xa857000a,0xab5b0012,0x1013002b,0xedc8000b}},	//   גיקה_, hnür, دبود, िच्छ
  { {0x2d9c00bd,0xefb3002b,0x3d94005e,0x7bc64fc5}},	//   _pove_, دینگ, випр, diku
  { {0x2ca50134,0xb6bb000a,0xd657000a,0x50b60054}},	//   fyld_, פציי, עיית_, _псеу
  { {0xaf0a0015,0xc334000a,0x4f260a23,0x1eda002b}},	//   _فقام_, ֛וֹ_, _здеб, _کباب_
  { {0x6815005c,0xc334000a,0x7bcf0273,0xa08b000a}},	//   _sądo, כוֹ_, uncu, _מְדִ
  { {0xada60010,0x69da0089,0xb5fb001a,0x75f0006f}},	//   _падл, čten, _spám, väzn
  { {0x5e770008,0x7c940015,0x5d640015,0x7bc64fc6}},	//   _נתון_, _للتص, _شُعْ, aiku
  { {0xbd170008,0x4d7b000a,0x28db000b,0xd789006e}},	//   _אחוז_, _זרוע, _मुखि, ونسو_
  { {0x17f80029,0x7c3a4fc7,0xfca90058,0x0577009a}},	//   فرقة_, mstr, _تاهو_, کارد
  { {0xe6130029,0x65a00012,0x78a10123,0x6b8d2c36}},	// [c0b0] اشر_, _röhr, älvb, _inag
  { {0x68e1007c,0xe61f0034,0x7c3a4fc8,0x0000006a}},	//   ülds, _prôb_, ostr,
  { {0x69c7010b,0xdb1d001c,0x54550457,0x4ddb000a}},	//   mije, cisã, твет, לחמו
  { {0x69c74fc9,0x7c3a4fca,0x8c1b000a,0x0000006a}},	//   lije, istr, פודי,
  { {0xfe080023,0x7c3a0012,0x71f90015,0xdb0f026a}},	//   _hữu_, hstr, ورتس_, licó
  { {0xb6040010,0x7bc60eca,0x69c7136b,0x21660461}},	//   _бяск, ziku, nije, виши_
  { {0xa8cc000a,0xab5b007c,0x7c3a4fcb,0x6b8d4fcc}},	//   ּ֖וֹ, tiül, jstr, _onag
  { {0xa5bb00dc,0xf1a40036,0x53140015,0xd1bb002b}},	//   _utób, _ґрун, _مذكر, _کارا_
  { {0x7bc6069a,0x3eab0089,0xab5b007c,0x51870033}},	//   viku, áct_, riül, _пужа
  { {0xb5fb002c,0xaea800a2,0x0d82156c,0x69c70085}},	//   _spáj, عطيل_, альн, jije
  { {0xe5720008,0x69c7044c,0x7bc64fcd,0x403501c5}},	//   בַר_, dije, tiku, _реес
  { {0xdb1d001c,0x6b8d0125,0x61e32441,0x7bc60091}},	//   visã, _cnag, lonl, uiku
  { {0x7c3a0440,0x733a0053,0x433a0053,0xc3320008}},	//   astr, וערס, וערב, סוך_
  { {0x7c3a032c,0x0ea80036,0x999e0089,0x2ead000b}},	//   bstr, _якій_, čtů_, टनीत
  { {0x7d56000a,0x6e3b0012,0x61e30125,0xc0ac000a}},	//   _ייסד_, lsub, ionl, ִימָ
  { {0xca4a0015,0x6a860aed,0x2d980061,0x6f1b0375}},	//   _قلبه_, _алиа, örev_, ncuc
  { {0x64430084,0x69c7016f,0x61e3008c,0x799e0ffd}},	// [c0c0] ánin, bije, konl, _topw
  { {0x75d30029,0xaa370053,0x69c7044c,0x3a37000a}},	//   ليقا, _שטיק_, cije, _שרים_
  { {0x07fa0029,0xb5a90015,0x443c0030,0xdb1d0307}},	//   _يرجع_, راكك_, év_, lisá
  { {0xe71a0086,0x07a6000d,0x4c9a000a,0x07fa0033}},	//   _زيست_, _рамн, ובעו, _іхны_
  { {0xa116002b,0xdce8006f,0xd132002b,0x68e90046}},	//   نوشت, vedč, لمش_, ředt
  { {0x41530036,0x201a001c,0x7c3a4fce,0xe2970099}},	//   ивіс, ípio_, ystr, таљ_
  { {0x2eca005d,0xddc9005c,0xa0670001,0x25d7000a}},	//   ाप्त, steś, ваја_, _סולן_
  { {0x245c01b2,0x657c4fcf,0x69c706c0,0x7c3a4fd0}},	//   mím_, _harh, zije, vstr
  { {0x6e3b00b6,0x245c0057,0xa2060033,0x9757000a}},	//   gsub, lím_, _апад, דיפו_
  { {0x6b8d010b,0xa2bb000b,0x7c3a2a9a,0x645e0085}},	//   _snag, _शेट्, tstr, otpi
  { {0x69c7010b,0x245c04af,0x62820150,0xf537000a}},	//   vije, ním_, lvoo, כריז_
  { {0xa3d5005d,0xfe462cd9,0x5ba70973,0x7c3a4fd1}},	//   िचय_, _андо, троз, rstr
  { {0xec0a00a7,0xf7730086,0xfe720086,0x7af6005c}},	//   _nếu_, یار_, _خدا_, _czyt
  { {0x6e2d0064,0x7c3a4fd2,0x6d4e016e,0x63a04fd3}},	//   _çaba, pstr, óbad, _lomn
  { {0x245c0057,0x69c74fd4,0x2d0e000b,0x0c73002b}},	//   jím_, rije, सशील_, _نديد
  { {0x907b000a,0xdb0f09ae,0x69c74fd5,0x245c3b68}},	//   וטלי, ricó, sije, dím_
  { {0x62820298,0x61fa0020,0x657c0026,0x61e30064}},	// [c0d0] jvoo, _ohtl, _barh, yonl
  { {0xdc420046,0x6282042f,0x8895105a,0x657c01f6}},	//   _léče, dvoo, _биох, _carh
  { {0x7cf8000a,0x61e3008c,0x62820079,0xddc2006f}},	//   תִּק, vonl, evoo, _osož
  { {0x68e90089,0x6e220061,0x82d90350,0x63a04fd6}},	//   ředs, _otob, ндес_, _comn
  { {0x56b50053,0x61e30064,0x63a04fd7,0x657c01f9}},	//   _עפֿן_, tonl, _domn, _farh
  { {0xec0a0023,0xc0a90015,0x11e4005e,0x7ff5002b}},	//   _hết_, فاعل_, ажім, گستا
  { {0xec0a00a7,0x245c4fd8,0xf994000a,0x40950015}},	//   _kết_, cím_, ירס_, العر
  { {0xdff5008f,0xec0a0023,0x7ff50002,0x61e34fd9}},	//   ыяль, _yếu_, دستا, sonl
  { {0x8d750087,0x7aed0049,0xb69b0045,0x6f1b0799}},	//   هادا, _nyat, _zgâr, rcuc
  { {0xb5fb002d,0xdb0d0003,0xbd450015,0x6f1b0077}},	//   _bpái, _plaî, دندي, scuc
  { {0x753504ed,0x6cc50033,0x0d940033,0x8f550015}},	//   _mezz, уйна, ршыў, _مناش
  { {0x69c50335,0xfeb905e6,0xab5b007c,0x69da0046}},	//   _amhe, _плеј_, niüh, čtem
  { {0x245c0089,0x0a3a0033,0x6e450054,0x03d6004f}},	//   zím_, эчны_, _селз, רורם_
  { {0x99d6003b,0x9d550087,0x19d50033,0xdb1d10e5}},	//   اتحا, _صنعت, аўсё, risá
  { {0xa3e3005d,0x4dda0008,0x18670f2c,0xf7460a61}},	//   नका_, _אחסו, лари_, лево
  { {0x245c01b2,0x5b360033,0x628200aa,0xe507000b}},	//   vím_, _сэку, yvoo, _वृधि_
  { {0x657c4fda,0xa6860010,0x05660785,0x7af6002a}},	// [c0e0] _parh, ылад, лван, _uzyt
  { {0x245c0107,0xb9560054,0x63a04fdb,0x2bc00065}},	//   tím_, _стић, _somn, शोरा
  { {0x03260083,0x657c0a5e,0x63a0341d,0x136a0054}},	//   гден, _varh, _pomn, ешли_
  { {0x245c4fdc,0x62820079,0x644a0144,0x833600c3}},	//   rím_, tvoo, àfiq, اراض
  { {0x71a6008f,0x6d43005c,0xdce80024,0x69c50026}},	//   ладз, _odna, iedā, _ymhe
  { {0x5a170053,0x91e30080,0x62820384,0xd12f0015}},	//   אקסן_, боче, rvoo, كمه_
  { {0x5478013a,0xf1a90086,0xc9530008,0xa5bb005c}},	//   _בְּנ, خانه_, צמה_, _twór
  { {0xf8b30008,0x6d4302e4,0xab5b007c,0x53b8000b}},	//   משו_, _adna, riük, _आतिश
  { {0xb5fb002d,0xae430086,0xd0070001,0x5e430015}},	//   _spái, مپيو, ћење_, مَيْ
  { {0xd5b30008,0x3f8f002e,0xc536000a,0x865b004f}},	//   ֶׁר_, _engu_, נָ֥ה_, עדיי
  { {0xdfcf002b,0xbdf70015,0x0000006a,0x0000006a}},	//   _کين_, دريا_,   ,
  { {0x6d4e00dc,0xce35002b,0x0000006a,0x0000006a}},	//   óbab, _چونک,   ,
  { {0x9e95002b,0xdd940033,0x7ac701b7,0x6e2200aa}},	//   _ناوچ, _валы, усне, _utob
  { {0xdd90002b,0x2d9a007c,0xdee30054,0x1e57000a}},	//   _ذوب_, _õpe_, _уочи, _עשור_
  { {0x98480063,0xa8350001,0xad1b000a,0xad65002b}},	//   лята_, ребљ, _אוור, _خانه
  { {0x36d50001,0x4423007c,0x5c5b000a,0x64434fdd}},	//   аобр, _rtj_, _נדחק, ánim
  { {0x753504ed,0xec0a0092,0xe6670010,0x260d0085}},	// [c0f0] _pezz, _vết_, ытво, _džon_
  { {0x6701000b,0x69c50012,0x99990091,0x6443036d}},	//   लेषक_, _umhe, rusų_, šnim
  { {0xab5b0020,0xec0a0092,0xf992000a,0xe31503ae}},	//   tiüh, _tết_, _ורי_, амењ
  { {0xf1ed000b,0x889a004f,0x0000006a,0x0000006a}},	//   _चीज़_, _סברי,   ,
  { {0xab5b0020,0x6bec0053,0xc73a000a,0xd2510015}},	//   riüh, ײַאַ, _שתשת, زنغ_
  { {0x69d500b8,0x644a0e75,0x2169384f,0x60250baf}},	//   nnze, áfic, тики_, адка
  { {0x11280036,0xf77f0064,0xdb1d002e,0x69d500b8}},	//   уючи_, _kaç_, nnsó, inze
  { {0xfe4500d0,0xaa7d008c,0xdb1d008c,0xe3b30067}},	//   анио, _käää_, nisä, _ارس_
  { {0xee3603be,0x764d00d9,0xdcf800bd,0xaf020063}},	//   аны_, nray, _davč, опъл
  { {0xc6920008,0xbc190010,0x0e680029,0x1636000a}},	//   קאי_, кімі_, اصيي_, סנתר_
  { {0xab2a28e1,0x72040031,0x764d01c2,0xdb1d008c}},	//   кона_, _اولم, hray, kisä
  { {0x2d9800c0,0xe4560053,0xebe6005e,0xe0d00040}},	//   örer_, סירט_, ромп, _عزل_
  { {0x539a0008,0x6d4e002a,0x3af60296,0xef0e41f2}},	//   דירו, óbac, рянс, _фм_
  { {0x9f5e0030,0x672d4fde,0x200f042c,0x78d60138}},	//   _futó_, ebaj, _higi_, аўбц
  { {0xac160124,0x6c790053,0x475a0063,0x6443016f}},	//   _коју_, _יאַפ, края_, šnij
  { {0xc7a60080,0x764d0003,0xe8530015,0x672d0030}},	//   шибк, fray, تنفد, gbaj
  { {0xd70a0010,0x14c80086,0x68e90046,0xe617004a}},	// [c100] тнае_, گهای_, ředp, идт_
  { {0x9a3b000a,0xc96612ae,0x200f4fdf,0x672d003d}},	//   _שתיק, _твой, _ligi_, abaj
  { {0x14c80074,0x764d0064,0xe45a005e,0xddcb003d}},	//   دهای_, aray, тже_, _apgū
  { {0x82a60063,0x317e00b8,0x3cfa0053,0x9cd6000a}},	//   ишле, _satz_, דלענ, בועה_
  { {0x02060080,0x22ba0015,0x20f50016,0x628917c8}},	//   аздн, خداع_, _ái_, _creo
  { {0x25080086,0x68e91d56,0x3958003d,0x27f24fe0}},	//   _مرزی_, şede, ngrs_, llyn_
  { {0x64a60afb,0x03960baf,0x4034004a,0x637a0004}},	//   _тава, _края, щейс, _исар_
  { {0x2249016f,0x27f21dc6,0xb4b2000b,0x547b000a}},	//   šaka_, nlyn_, टनी_, _בטלו
  { {0x62330083,0xa3e3005d,0xbda60015,0x200f4fe1}},	//   _меѓу, नकर_, لحدو, _digi_
  { {0x200f0084,0x50460180,0x5d980033,0xcd0631d5}},	//   _eigi_, _вежб, укоў_, ични
  { {0x9df7008f,0xdd97008f,0x91bb000a,0xd5b80033}},	//   рнэт_, ршы_, _שמבי, нiко
  { {0xee860010,0x00770008,0xdb24002e,0xd00f0015}},	//   _выко, _כתבי_, örðu, _قلل_
  { {0x27f219c4,0x49a7012e,0xde760058,0x8d760058}},	//   dlyn_, ајва, _خداع, _ناغا
  { {0x9d170010,0x394d00b8,0x261a005d,0xf77f0061}},	//   _кошт_, ßes_, _बढ़ी_, _saç_
  { {0x8dfb000a,0xd90f002b,0x0c770040,0x69d50012}},	//   _שהות, بید_, _نصيب_, rnze
  { {0x27f20026,0x98b10011,0x1cb70008,0x64430844}},	//   glyn_, ează_, _כלול_, šnik
  { {0x2cac0176,0x60150007,0x16380015,0x764d0061}},	// [c110] lydd_, _išme, لسلة_, uray
  { {0xdb1d00f2,0x3ebb000a,0xdce80045,0xdb26002b}},	//   sisä, דצמב, cedă, _پویی
  { {0x2cac0176,0x89da0008,0x89dc000a,0x96080033}},	//   nydd_, _תחתי, _בחזי, рэта_
  { {0x77b81eeb,0x644a0030,0xe3c40015,0xb5fb3c87}},	//   _píxe, áfia, يْلَ, _apát
  { {0x59bb005d,0x2cac0026,0x9f4a0046,0xb796000a}},	//   _उतार, hydd_, ámým_, _הכרח_
  { {0xc6920053,0x867a00a3,0x90450015,0x62890045}},	//   _זאך_, _גרשו, منته, _vreo
  { {0xa4d40036,0xc9b80008,0x89ec004f,0x09b8004f}},	//   _дорі, שהות_, כַהֵ, שפוט_
  { {0xd8d8013a,0x63ad0005,0x2cac0176,0x62891f22}},	//   יווט_, öand, dydd_, _treo
  { {0xddc200bd,0xa2b5070e,0x6ad1000b,0xfe710015}},	//   _spoš, _убач, सपोर, سدة_
  { {0x2cac0176,0xa4b5000a,0x91f90015,0x1ad10065}},	//   fydd_, ֶלָה_, _صفاء_, सपैठ
  { {0x2cac0026,0xec0a0016,0xcb09000a,0xc05800e2}},	//   gydd_, _bếp_, _נל_, _віч_
  { {0x5f770086,0xb5fb0046,0xc4d2000a,0x2d9e006f}},	//   _خاطر, _zpát, לגי_, ajte_
  { {0xfe700029,0xa5bb4fe2,0x2ef51923,0x26170065}},	//   _يده_, _atóm, _уздр, _भूली_
  { {0x2cac0026,0x09fa0029,0x6fde0024,0xbea20180}},	//   bydd_, افسة_, rīce, _хашк
  { {0xddc2018c,0x290c038a,0x6ff9004c,0x3cea013f}},	//   _upoš, äda_, ָפּג, čivé_
  { {0x18670001,0x2fcd0034,0x7bcf0003,0x279504d7}},	//   љати_, nieg_, ébut, ошур
  { {0x9bb7000a,0x3ead4fe3,0x07a312bd,0x75460033}},	// [c120] _להקה_, nyet_, чатн, йназ
  { {0x8b08005c,0xa5bb00dc,0x27f20728,0xd7070033}},	//   _cięż, _utól, slyn_, снуе_
  { {0x3d3a0053,0xb4b2005d,0x0d3a0053,0x04ca0015}},	//   רגעס, टने_, רגעב, دواي_
  { {0xec0a0023,0xd36f0029,0xa3ba0015,0xc3d50033}},	//   _xếp_, فهم_, دائر_, оўчы
  { {0xebad0053,0x2fcd0034,0xcb13000a,0x61140099}},	//   כסאָ, dieg_, פלג_, одлу
  { {0x3ead00b6,0xe9df002e,0x6443001c,0x201800dc}},	//   dyet_, trúi_, ânic, _érik_
  { {0xe4da0074,0x853b000a,0xb97b000a,0x877a000a}},	//   _صورت_, _תגלי, רנצי, ָאִי
  { {0xdbf10089,0xdce1003d,0xdfd00015,0x69ce4fe4}},	//   _příb, adlī, ظية_, hibe
  { {0x2cac0b7c,0x26c04fe5,0xe7fb000b,0xfdb8030c}},	//   wydd_, nzio_, ्षता_, илищ_
  { {0x667b0135,0xc693000a,0xec0a0016,0x2cac2c07}},	//   נטיק, פאת_, _sếp_, tydd_
  { {0x6ad1005d,0x2fcd002a,0xd59b004c,0x459b004c}},	//   सप्र, bieg_, אביל, אסיע
  { {0x2cac0176,0x788300dc,0x5f7600e6,0x78a10123}},	//   rydd_, hívá, _دائر, älvm
  { {0x9b580063,0x2cac0026,0x99d70015,0x6e960067}},	//   щият_, sydd_, متسا, _دلشا
  { {0x8b080089,0xd910002b,0x2cac0034,0xaa1c0030}},	//   _stří, کیپ_, pydd_, ótáá_
  { {0xfdf70008,0x78830089,0x27e91418,0x6da303ae}},	//   _הצגת_, dívá, toan_, _хија
  { {0xba190086,0x58d40036,0x17fb0029,0xba550054}},	//   _پيدا_, чост, ارسة_, _двиј
  { {0x95390063,0x5694005e,0x27e901d7,0x2cc80091}},	// [c130] изат_, патт, roan_, žudė_
  { {0x27370092,0x6d5a4fe6,0x3a290061,0x69ce1342}},	//   ần_, ngta, _itap_, cibe
  { {0x44270298,0x9d1b000a,0x6d5a0091,0x74280015}},	//   ën_, אובט, igta, مكلف_
  { {0x7bcf4fe7,0xd5a3009a,0xa2f504c5,0x0000006a}},	//   nicu, _کلسی, опеч,
  { {0x6b7c0053,0x326718fe,0xc24401f3,0xc2cb002b}},	//   טראנ, стев, знік, دبال_
  { {0x3ead0061,0xd5b10016,0x7bcf3f56,0x343b0058}},	//   vyet_, _ố_, hicu, _مسرد_
  { {0x2fcd00b8,0xe1f00087,0xa1560054,0xc954000a}},	//   tieg_, رسه_, цају_, למס_
  { {0x6d5a1de7,0xce49024f,0x02450015,0xef190923}},	//   egta, азие_, _وَزَ, шми_
  { {0x2fcd00b8,0x0d990033,0x7bcf04a8,0x69ce0030}},	//   rieg_, атны_, dicu, yibe
  { {0xdcf80024,0xddc50036,0xfc450057,0x2fcd0313}},	//   _savā, ібни, žíme_, sieg_
  { {0xc0d50086,0x7bcf4fe8,0xffe702bb,0xe58c000a}},	//   _بياب, ficu, _людн, רָחָ
  { {0x6d5a0035,0xda66005e,0x3b0a0004,0x3f83003d}},	//   agta, овми, иено_, ējus_
  { {0xaffc005e,0x29cd0085,0x7ed40033,0x69ce4fe9}},	//   _соцi, ržan_, _нішч, tibe
  { {0x63b8003d,0x395e007c,0x1d0901cf,0x9e070bb1}},	//   īvni, üts_, _кели_, _учел
  { {0x5bc60015,0x69ce4fea,0x7d7a000a,0x6c350015}},	//   _وقتل, ribe, _כנסו, _بفعا
  { {0xa6db002e,0x61ea0061,0x69ce4feb,0xb8f20065}},	//   _meðf, zofl, sibe, _वध_
  { {0xd5b20029,0x2d850089,0x64570003,0x6fde003d}},	// [c140] وفر_, odle_, euxi, nīca
  { {0x2ca90089,0x6b844fec,0x26c002b9,0x2d850223}},	//   _řady_, _haig, rzio_, ndle_
  { {0x6b9600df,0x07a60229,0xab5b0061,0xc7a61adc}},	//   _knyg, _данн, enüy, _динк
  { {0x61fd0024,0x75f0006f,0x7afb002a,0xdddb0535}},	//   _īsla, väzu, żute, ntuł
  { {0x6b844fed,0x7bdb000a,0x420a1411,0xf19400ce}},	//   _maig, סקנו, андо_, зиль
  { {0x672406c0,0x6b844fee,0x28cf0065,0x7bcf00d4}},	//   lcij, _laig, _हेडि, zicu
  { {0x999b0135,0x2d8508b8,0x399b000a,0xdb06008c}},	//   יבסט, ddle_, ייסד, lkkä
  { {0x4fc6008f,0x67244fef,0xa0070015,0xdfa60015}},	//   ўска, ncij, يقول_, تحتي
  { {0x6815005c,0x76444ff0,0x8fa30004,0xdb0d0061}},	//   _jądr, nsiy, ќање, _ilaç
  { {0x06970008,0x753c005c,0x3f820264,0x6815002a}},	//   קדים_, _jerz, žku_, _mądr
  { {0x6b8400df,0x3a290161,0x4c94135d,0xb5fb0643}},	//   _baig, _stap_, чинс, שליכ
  { {0x6b844ff1,0x764422ce,0xcd2a002b,0xc0d30015}},	//   _caig, ksiy, دسکن_, _تيمب
  { {0x69c00024,0xaac5000b,0x7dc60015,0x60150091}},	//   īmen, _लेखक, _وتتك, _išma
  { {0x7bcf1b98,0x44444ff2,0x29cd0085,0xbebd003d}},	//   sicu, ks_, ržao_, rbūt
  { {0x6b84002f,0xd90f0086,0x5cc30063,0xab870608}},	//   _faig, ضیح_, _осъз, _дупк
  { {0x5bc40029,0x1cbb000a,0xd794006b,0x7b06001a}},	//   _يقول, _כמוע, мисъ, áttö
  { {0x44380176,0xf1db005d,0xa5bb0030,0x4dfe000b}},	// [c150] _awr_, _बदलन, _utók, _उठाई_
  { {0x9f4401b2,0x44444ff3,0x9557012c,0x78ae0030}},	//   domí_, fs_, تخرا, ínvá
  { {0x753c00b8,0x44442d92,0xb97a000a,0x69da0046}},	//   _derz, gs_, _הנתי, čtet
  { {0x987a00b2,0x44380026,0xa87a004c,0x187a000a}},	//   _פארט, _dwr_, _פארר, _פטרב
  { {0x798500d9,0x444408aa,0x44380012,0x2d85002a}},	//   _kahw, as_, _ewr_, ydle_
  { {0x1a7c0008,0x81c8005e,0x9a7c000a,0x444424ed}},	//   שְׁמ, огів_, שָׁח, bs_
  { {0x661d0293,0x44380e18,0x44444ff4,0xc5f2000a}},	//   _husk, _gwr_, cs_, _נדל_
  { {0x63a2005c,0xd8dc0008,0xb4d7005d,0x661d2a52}},	//   cjon, יקור, ापी_, _kusk
  { {0xd14b0074,0xd2510087,0x673d4ff5,0x63bb01d7}},	//   _نشان_, _سنا_, _mesj, _ilun
  { {0xd1310029,0x6b844ff6,0x22b80015,0x4d651305}},	//   _أما_, _saig, _بدفع_, чков
  { {0x64454ff7,0x6b840020,0x752500b8,0x98b80024}},	//   nshi, _paig, ichz, karā_
  { {0x2d83116e,0x6ff40015,0xcb6a006b,0x64454ff8}},	//   žje_, _قسنط, щаме_, ishi
  { {0x42790053,0x798500e8,0x661d0007,0x44440024}},	//   זאָג, _bahw, _nusk, zs_
  { {0x764401e2,0x63bb4ff9,0x63a90020,0x661500bd}},	//   vsiy, _llun, _loen, _nizk
  { {0x63bb200b,0x6b844ffa,0x6d414ffb,0x661d4ffc}},	//   _olun, _taig, mala, _ausk
  { {0x66150024,0x44444ffd,0x6d414ffe,0x64454fff}},	//   _aizk, vs_, lala, dshi
  { {0xe737005f,0x6445003f,0xeab20029,0x442a0f49}},	// [c160] яет_, eshi, _سعة_, _stb_
  { {0xadfd000b,0x6d415000,0x76445001,0x649a1045}},	//   ॉगिन_, nala, rsiy, йтер_
  { {0xdb0d1352,0xd4c60015,0x64451ba1,0x2937000a}},	//   _plaç, أغذي, gshi, _מאין_
  { {0x8c1a013a,0x77940086,0x6d411636,0x889b000a}},	//   צוני, _تیرا, hala, _הבטי
  { {0x753c04ed,0x63a95002,0x6ecb000b,0x79850f21}},	//   _terz, _doen, _तेलु, _yahw
  { {0x63a25003,0xa5d80008,0x7af600f2,0x69dc22af}},	//   sjon, _וַֽי, _myyt, nnre
  { {0xf9930008,0x6443006f,0x6d415004,0xb97b000a}},	//   תרו_, ánit, dala, מנסי
  { {0xd0950033,0x63bb0123,0x63a901d7,0x6d415005}},	//   ьшчы, _glun, _goen, eala
  { {0x6d415006,0x6e630033,0x31160a3e,0xf1b90160}},	//   fala, нтэж, _ефес, _suše_
  { {0x6ce60010,0xfe6f00e6,0xdd9a0063,0x41c60015}},	//   зіме, ادي_, сши_, _عقاق
  { {0x718b0008,0xe1650015,0xcf260067,0x29cd003d}},	//   _לְאַ, _تدقي, _فرشي, užam_
  { {0xb09b0008,0xb4fb00a3,0x6d413017,0x224601d7}},	//   _ליבר, מפיי, aala, osok_
  { {0xbf130015,0xe61f0016,0x98b8003d,0x6d415007}},	//   _كومب, _trôi_, varā_, bala
  { {0x6d4a02de,0x673d5008,0x4a040015,0xceb3000a}},	//   _udfa, _sesj, ّبِّ, _ריס_
  { {0xd7f50010,0x661d5009,0x18a40010,0x5dfb000a}},	//   дзвы, _susk, наём, _הפגנ
  { {0xb8140001,0xdb1d001a,0x661d500a,0x8cdb004f}},	//   едсј, lisþ, _pusk, _לחות
  { {0x25aa0176,0xaa540033,0x6935002b,0x061513d6}},	// [c170] _bobl_, _звыш, _يکسر, ддаю
  { {0x63bb500b,0x3abc000a,0xdb0f0046,0x98b8003d}},	//   _slun, _למחנ, nkcí, sarā_
  { {0x752500b8,0x254f0024,0xc952000a,0xb4d7000b}},	//   rchz, vēlē_, _במי_, ापे_
  { {0x213e0026,0x644504d0,0x6d41500c,0xa2d50015}},	//   _aeth_, rshi, zala, ويات
  { {0x213e0176,0x026b004a,0x20fc0016,0x6d41500d}},	//   _beth_, сшей_, _ải_, yala
  { {0x64430089,0x63a90079,0x7bdd0012,0x40950ffe}},	//   ánis, _woen, hnsu, дрит
  { {0x63a9016b,0x201e0375,0x98b80045,0x224602f2}},	//   _toen, _cuti_, mară_, asok_
  { {0x98b80011,0xc4d20008,0x6d411636,0x58bc000a}},	//   lară_, _סגן_, wala, ממוצ
  { {0x29cd016f,0xd00e0015,0xe81f000b,0x22460030}},	//   ržaj_, جلي_, _मूसा_, csok_
  { {0xe29004c9,0x98b80011,0x929d002a,0x02440015}},	//   _حذف_, nară_, _człe, _أَلَ
  { {0x7af600f2,0x6d41500e,0x8cb40256,0x6ee7009a}},	//   _syyt, rala, есяч, _کسال
  { {0x333f0152,0x7af600f2,0xceb50001,0x60150007}},	//   _jeux_, _pyyt, _обећ, _išmo
  { {0x6d41331e,0x539a0008,0x7fb60015,0x0000006a}},	//   pala, קישו, _زهور_,
  { {0x8c650074,0xceb2000f,0xe81f000b,0xe61f006f}},	//   _قطعن, _ביד_, _मंशा_, _osôb_
  { {0x64430045,0x5fd1000b,0x69dc2d66,0x7e69500f}},	//   ânil, _तगाल, rnre, ltep
  { {0x7af600f2,0x9b460086,0x4c3a000a,0x7e69001a}},	//   _tyyt, _کنکو, _ותקב, otep
  { {0x25aa0176,0x99e60080,0x05aa0010,0x98b80045}},	// [c180] _pobl_, _ожид, овай_, fară_
  { {0x6e2d0061,0xe5770054,0x2d871741,0x98b80045}},	//   _çabu, мзу_, _jane_, gară_
  { {0x2d873e5c,0x999b000a,0x299b000a,0xa99b000a}},	//   _mane_, _וביט, _וסימ, _וביר
  { {0x333f038d,0xf6260180,0x2d873fdf,0x7e695010}},	//   _ceux_, _одмо, _lane_, ktep
  { {0x333f038d,0x213e0026,0x2b400034,0x41e601c6}},	//   _deux_, _peth_, _meic_, міка
  { {0x27ed0198,0xe2a90015,0xa5760015,0x159a0015}},	//   čene_, ثامن_, _تُست, _بنسخ_
  { {0x232a0036,0x5066005e,0x333f0003,0x0000006a}},	//   _мови_, фтла, _feux_,
  { {0x260d0091,0x60050052,0x0000006a,0x0000006a}},	//   _džou_, jómd,   ,
  { {0x2d875011,0x5e430015,0x7c2d06c0,0x7e6908cf}},	//   _bane_, نَيْ, _čara, gtep
  { {0x201e01d7,0x8146002b,0x2d87481c,0x2dda0058}},	//   _tuti_, _آنان, _cane_, تبعة_
  { {0x333f0152,0x2d8707e9,0x2b400034,0xdce1003d}},	//   _yeux_, _dane_, _beic_, delē
  { {0xbb940080,0x6f930015,0x2d980030,0xebf40015}},	//   вающ, _للمض, űre_, َأَة
  { {0xc3330008,0xbda60029,0xd3370008,0x2d870bfa}},	//   כור_, _يحتو, ורכה_, _fane_
  { {0xdb1d007c,0x4efb000a,0x29cd0091,0x1efb000a}},	//   lisü, _והדו, ožai_, _ולדע
  { {0x9cf40036,0x6bd70029,0x2b40130f,0x4d77000a}},	//   _язкі, _يتعر, _feic_, _חתול_
  { {0xdb1d007c,0xfce30004,0x31db000b,0x6443016e}},	//   nisü, _шојо, _बद्ध, ânim
  { {0x98b80011,0x443f002c,0x19952ac6,0xd567005e}},	// [c190] tară_, _ňu_, _запя, дтеп
  { {0x057700c3,0xde880016,0x6d4e0030,0x600501d3}},	//   بارد, _mị_, óbah, móme
  { {0xdb043aff,0x98b80011,0x333f0003,0x60055012}},	//   _hlið, rară_, _peux_, lóme
  { {0x98b80011,0x69d55013,0x9f4d00aa,0x9405009a}},	//   sară_, lize, roeë_, روشه
  { {0x333f0152,0x60050896,0xdb1d007c,0x98b80045}},	//   _veux_, nóme, disü, pară_
  { {0x69d55014,0xf1b90085,0xdcef006f,0x7204002b}},	//   nize, _buša_, _čeľa, نونم
  { {0x6ed4000b,0x2d870c6f,0x1fb50128,0x0000006a}},	//   _बेबु, _rane_, еспр,
  { {0xde8800a7,0xc918013a,0x7e690020,0x4918000a}},	//   _bị_, וחות_, ttep, וקול_
  { {0xc175010f,0x3eb95015,0x28d6021e,0xe732000a}},	//   _плащ, ást_, _डेनि, נֵה_
  { {0x69c00024,0x2b40002d,0x62340001,0xde880092}},	//   īmek, _seic_, _рефу, _dị_
  { {0xc5f2000f,0x28cf000b,0xf1c80015,0xdc030069}},	//   רדי_, _हेलि, _تولى_, ačín
  { {0x1eea002b,0x69d55016,0xe452004f,0x7656005b}},	//   _کوهی_, eize, נֶת_, yryy
  { {0x69d50014,0x2d870064,0x2b400024,0xeb9700a4}},	//   fize, _tane_, _veic_, хия_
  { {0xbed600b2,0xdd88005e,0x69d50b09,0xfce501eb}},	//   _אונז_, _обід_, gize, _поло
  { {0x25f5005d,0xa2d6000b,0x98b80091,0x0000006a}},	//   ्तनी_, _मेन्, karą_,
  { {0xc7b20029,0x8c1a00a3,0x0000006a,0x0000006a}},	//   دّر_, _צופי,   ,
  { {0xaffa0053,0x98b80091,0x46350058,0xb6350058}},	// [c1a0] פּלי, darą_, َرْأ, َعْت
  { {0x4ea8000a,0x273e0016,0x69d55017,0x1426027a}},	//   וֹעֲ, ắn_, cize, еджм
  { {0x2db60053,0x19b700f3,0x7c2b0045,0xf74607d9}},	//   עלען_, _נפטר_, _înră, _пено
  { {0xd8d70053,0x32660004,0xe61a0004,0xe7320015}},	//   _טויט_, еткв, _ндм_, _حصد_
  { {0x20060176,0xa3b1005d,0xf126005e,0xf1b90085}},	//   _rhoi_, _ओवर_, ньйо, _suša_
  { {0x2fdf0012,0x27e0005b,0x0000006a,0x0000006a}},	//   enug_, lnin_,   ,
  { {0x63a40020,0xf8b2005d,0x6f0200dc,0x21670054}},	//   öins, ीनिय, _szoc, хији_
  { {0x27e05018,0xdfd00029,0x74160029,0x657e0556}},	//   nnin_, ؤية_, _أورا, leph
  { {0x171b000a,0x8b03002a,0xdb1d007c,0xdddb0046}},	//   הופע, łęzi, risü, ltuř
  { {0xde880023,0xa5bb0030,0x70f60015,0xcce60015}},	//   _vị_, _utót, _كسائ, فسجي
  { {0xa5bb0f9a,0xa6db0084,0x62822514,0xb5820010}},	//   _któr, _meða, lwoo, тнiк
  { {0xde880092,0xcf260015,0xdb1d016e,0x20552b7c}},	//   _tị_, _أرضي, visó, _штур
  { {0x28d6005d,0x69d50c0a,0x62825019,0xfbdf016e}},	//   _डेबि, tize, nwoo, rnê_
  { {0xa6db0084,0xdddb0046,0x69d50079,0x3eb901de}},	//   _neða, ktuř, uize, øste_
  { {0x645e0048,0x8d630001,0xfdf7000a,0xa3b1000b}},	//   jupi, _свје, _רצות_, _ओवल_
  { {0x62820384,0xbc670029,0x3cfb000a,0x69d53bbd}},	//   kwoo, _أمين_, _מלונ, size
  { {0x8bd8000a,0x7d7a000a,0x6be40015,0x2d8c501a}},	// [c1b0] _רוחו_, ּנ֣ו, _حكيم, odde_
  { {0x645e003f,0x78a100c0,0xdb1d501b,0x2d8c0079}},	//   fupi, älvs, pisó, ndde_
  { {0x645e0020,0x2d8c0079,0xddc20046,0x6722003d}},	//   gupi, idde_, _opož, žoja
  { {0x62350ac6,0x1836000a,0xccf3004c,0x628208cf}},	//   веду, _שארל_, אכע_, fwoo
  { {0x6282020a,0x2294005e,0xaab3000b,0xa29402a3}},	//   gwoo, лиця, ुनिक, лаці
  { {0x26c9003f,0x98b80091,0x8234006e,0xe2960763}},	//   mzao_, sarą_, ارنا, таш_
  { {0x442504f9,0x645e003e,0xf994000a,0xdcf80091}},	//   _îl_, cupi, טרס_, _tavę
  { {0x389c0008,0x889c0053,0x201900f2,0x7ff50015}},	//   ליונ, לבוי, ösi_, خستا
  { {0x200d0011,0x52740086,0xaf050063,0xc7b4004f}},	//   rmei_, _مالز, ъпил, טבק_
  { {0x64580007,0xb51d0033,0x6e221284,0x2d9520e6}},	//   švie, блiя, _duob, трис
  { {0xd6220033,0xd35f005e,0xfce501eb,0x27e0501c}},	//   вiла, _вiдч, тоно, ynin_
  { {0x2d8c20df,0xab2a005e,0xeb97004a,0xdb1d0125}},	//   adde_, ьома_, вию_, bhsí
  { {0xf41200b2,0x8d950029,0x44230085,0x89d600ce}},	//   יפט_, _للإش, _luj_, вівш
  { {0xaf040191,0xddc20089,0x27e0501d,0x0000006a}},	//   _спіл, _zpož, wnin_,
  { {0x3f8d0251,0xabaa0015,0x27e044d5,0xd9430719}},	//   odeu_, _يهتم_, tnin_, реси
  { {0x3f8d001c,0xf092000a,0x27e0501e,0xab5b0012}},	//   ndeu_, סנן_, unin_, nhül
  { {0x0566010f,0x6d430375,0x7b650099,0xe61a01c5}},	// [c1c0] кван, _kena, _стје, дда_
  { {0xc5160029,0x6d431438,0x645e501f,0xa5bb0976}},	//   نبات, _jena, tupi, _stór
  { {0x6d434d1a,0xa9bb000a,0x64c60015,0x657e1351}},	//   _mena, _חזיר, خيال, reph
  { {0x628209f2,0xd36f0029,0xd2520015,0x7c2d0085}},	//   twoo, قهم_, لنص_, _čarl
  { {0x4b4d0053,0xd36f0015,0x02d2000b,0x29cd00bc}},	//   לגאַ, تهن_, _देशभ, ržav_
  { {0xa5bb002a,0xddc2003d,0xf1b907c4,0x6d435020}},	//   _wtór, _spož, _dušo_, _nena
  { {0x04435021,0x40940015,0xdce10091,0xc0340054}},	//   _весн, البر, melė, ћниј
  { {0xfff80074,0xa8570008,0x62825022,0x387a01c2}},	//   رکات_, דיקה_, pwoo, _mppr_
  { {0x03570008,0x6fde0024,0xd0070001,0x57fb000a}},	//   _שימש_, nīci, њење_, ולקו
  { {0x68e904f9,0x7c23002d,0x6d435023,0xdce10091}},	//   şedi, _bunr, _cena, nelė
  { {0x6d431c54,0x23b6000b,0x2d8a006f,0xa5b7000a}},	//   _dena, _अकाद, ľbe_, דליק_
  { {0x60d9004c,0xab5b0012,0xdcf80046,0x6e960015}},	//   _אַנג, chül, _zavě, _للصا
  { {0xdfcf0806,0xb9080016,0xdce10091,0x6d435024}},	//   _بين_, _thiị_, kelė, _fena
  { {0x7e6003f6,0x6d435025,0xc211000a,0xda34004a}},	//   mump, _gena, ֶ֔ם_, реры
  { {0xdce10007,0x4bdb0015,0xacf801f3,0xf8690015}},	//   delė, _يبعد_, _янку_, عمري_
  { {0x80f5000a,0xf7700015,0x7bc60dca,0x661c01d7}},	//   רֶשׁ_, ياق_, chku, _airk
  { {0x661c0e0d,0x644e0804,0x7e600260,0xd6b4006b}},	// [c1d0] _birk, _avbi, nump, айтъ
  { {0x27460091,0x6d485026,0x661c0d3d,0x6b8d5027}},	//   vūnų_, nada, _cirk, _haag
  { {0x6b8d00b6,0x661c00bd,0x6d485028,0x67d50137}},	//   _kaag, _dirk, iada, _бону
  { {0xa3cd005d,0x6d485029,0x58ba000a,0x7e60502a}},	//   षों_, hada, _נמרצ, kump
  { {0x69c700f2,0x98b80007,0x03180015,0x4374005e}},	//   ohje, darę_, نتهت_, руєт
  { {0x60150091,0x7abc000a,0x764d0061,0x3abc000a}},	//   _išmi, וצדו, msay, ומדנ
  { {0xc5f20008,0xd164006b,0x6d48502b,0xab5b0012}},	//   _הדם_, ръчи, dada, thül
  { {0x6d43502c,0xcfa40054,0x62670015,0x29cd0091}},	//   _sena, ишњи, _لائق, ožas_
  { {0x7e6000b6,0x224d016f,0x3f8d12b3,0x7c231234}},	//   gump, _uvek_, rdeu_, _sunr
  { {0x4174002b,0x4c85502d,0x6d48502e,0xa19402da}},	//   _نامس, глов, gada, _кауч
  { {0x6fde0024,0x6d43502f,0xbb465030,0xd5c50033}},	//   zīci, _vena, ленк, нiкн
  { {0x4e9503c4,0xf9890008,0x6adf000b,0x210f000b}},	//   _مشتر, _מר_, नपूर, ाधीश_
  { {0x6b8d0409,0xee38042b,0x6d435031,0x7e605032}},	//   _daag, _ані_, _tena, cump
  { {0x6d485033,0x2d94006b,0x29cd1cfa,0x672d0535}},	//   cada, _връс, džas_, ecaj
  { {0xbca8003b,0xc8b502bf,0x8d740015,0xccb6002b}},	//   _لديك_, асты, _خانا, _مهوش_
  { {0xb8060015,0x661c5034,0xab661411,0xfe65009a}},	//   ابسه, _sirk, _свил, يگ_
  { {0x67220048,0xdce10007,0x661c2233,0xd7e70004}},	// [c1e0] žojo, telė, _pirk, умте_
  { {0x598628d2,0x75d30015,0x64a60fd2,0xaa3b004f}},	//   _слоб, ميقا, лаза, _רתיח
  { {0x5a170008,0xb4250029,0x764d0e8a,0x14c8002b}},	//   _תקין_, لعنو, asay, خهای_
  { {0x929d0050,0x661c018b,0x61e3003c,0x6d485035}},	//   _czło, _wirk, ennl, zada
  { {0xe297335c,0xbb3b015b,0xf6b60033,0x6d485036}},	//   лац_, געני, _сёня, yada
  { {0x7bc40251,0xa6db002e,0x6d4800e1,0x0000006a}},	//   _lliu, _meðl, xada,
  { {0x4034004a,0x65c35037,0x6d483e42,0xa0670054}},	//   шейс, _убра, vada, гаја_
  { {0xa3b8014e,0xa8e20092,0x6815005c,0xdfd00031}},	//   _छवि_, _đồn, _sądz, تيب_
  { {0x9ed7006b,0xc7b3000a,0x394a02de,0x69c7008c}},	//   лмът_, מבה_, kabs_, yhje
  { {0x6b8d0fb2,0x7bc4055a,0xc27b00a3,0x067b004c}},	//   _saag, _aliu, _ארמי, ײנטל
  { {0x7e603b90,0x6f660015,0xb09a005e,0x6ed4000b}},	//   sump, _مهام, _ятає_, _बेरु
  { {0x764d00b6,0x6e93002b,0x7e605038,0x6d485039}},	//   ysay, _گلها, pump, sada
  { {0x6d48503a,0xda781a71,0x6b8d0ed4,0x0000006a}},	//   pada, ляр_, _vaag,
  { {0xc2140008,0x283b0015,0x2c4e002a,0x6b8d02f7}},	//   יהָ_, فأرة_, pęd_, _waag
  { {0x4dfb000f,0xac73002b,0xd80b004a,0xdca30054}},	//   _רפוא, _هايش, ехал_, _гаји
  { {0x4735008f,0x2bbb0029,0xddc9005c,0xdc9b000a}},	//   рнас, _ساعة_, kreś, _טיול
  { {0xdb1d002f,0x672d2999,0x8c1c000a,0xb4bd000b}},	// [c1f0] bhsá, rcaj, _אוהי, इन्_
  { {0x764d40a7,0x28d6005d,0x61e4002d,0x29cd003d}},	//   rsay, _डेवि, éill, ržas_
  { {0x764d0152,0xa022007c,0xb604503b,0xe6040015}},	//   ssay, ööli, сятк, حِلَ
  { {0xdc3b0053,0x764d0064,0x94740015,0xd795006b}},	//   געאר, psay, إدلا, _тимъ
  { {0xe1f103c4,0x27ec0046,0xe2990054,0x321e2dce}},	//   يست_, édne_, ђак_, _bity_
  { {0x321e003e,0x30550001,0x11d90015,0xdce8003d}},	//   _city_, ађит, ضوعة_, nedē
  { {0xdb1d0020,0xa6db002e,0x499c000a,0xe0420121}},	//   misõ, _meðm, תשוב, онщи
  { {0x6289002d,0x63050015,0xdb1d503c,0x0000006a}},	//   _tseo, _نوزل, lisõ,
  { {0x0018008f,0x20030024,0xe3b00115,0x7db50015}},	//   ыўшы_, ēji_, _عرف_, لصدا
  { {0x7bc80048,0x8c950210,0xe807000b,0x32b80015}},	//   ījum, армі, _वीसा_, _صدقة_
  { {0xe572000a,0x6bd60015,0xdb06007c,0x7bc44327}},	//   חַר_, لتحر, skkü, _pliu
  { {0xdb1d007c,0x69c5494a,0x4093002b,0x351a000a}},	//   hisõ, _alhe, _پلچر, כותנ
  { {0x7f3a0053,0x2ba8005d,0xdb1d0125,0xada5030c}},	//   _סעסו, गाबा, thsá, _валл
  { {0x8cb5010f,0x3eca000a,0x3f8f2acd,0xba1a0015}},	//   _всич, _שֶׁ֣, _hagu_, ئيسا_
  { {0x7aed001c,0x4dda000a,0x7c940033,0x6005006f}},	//   _exat, _בחסו, _грыц, nómo
  { {0x3f8f0020,0x69c500dc,0x18670054,0xdb1d0072}},	//   _jagu_, _elhe, јати_, visö
  { {0x3f8f0026,0xabfb0447,0x4bfb000a,0xdcfa003d}},	// [c200] _magu_, _שהפר, _בלקס, metā
  { {0x399a0053,0x3ea0002d,0x051a0029,0x3f8f0375}},	//   _ייִד, _áite_, نزاع_, _lagu_
  { {0xbb1b0045,0x69dc503d,0x0326237f,0x546a503e}},	//   neîn, mire, аден, таем_
  { {0x3f8f0005,0x78a8007c,0xdb1d0123,0x69dc503f}},	//   _nagu_, ädvu, risö, lire
  { {0x69dc10e0,0x321e00da,0xdcfa003d,0x75410030}},	//   oire, _pity_, ietā, ézzü
  { {0x60860029,0x61f70010,0xf50a007a,0xdb1d001c}},	//   لشبك, аніў_, _англ_, cisõ
  { {0x25f5005d,0xc9530008,0x7416002b,0x9fc6005e}},	//   ्तरी_, קמה_, _نوسا, ищил
  { {0x2d8e2305,0x225a0015,0x7ff30021,0x69dc5040}},	//   _safe_, _للرد_, يسيا, hire
  { {0x317a0086,0x69dc5041,0x9df8004a,0xeda62aa8}},	//   _لحاظ_, kire, лнит_, ашно
  { {0x69dc0045,0x443a0795,0x0000006a,0x0000006a}},	//   jire, opp_,   ,
  { {0x30860115,0x55bb000a,0x3f8f0034,0x6adf000b}},	//   _خلاف, דמיו, _fagu_, नप्र
  { {0x69dc002d,0x98a32aad,0x6fb30015,0x62080091}},	//   eire, ncją_, _وملا, šplė
  { {0xcff50074,0x9b580063,0x3e3400a2,0x501b000a}},	//   _اينک, шият_, _افتر, _סודו
  { {0xda090086,0x61f802c6,0xdebb000a,0xa9c4004a}},	//   ايسه_, novl, _במדל, осск
  { {0xed570cb9,0xdb1d001c,0xe7590036,0x98a3005c}},	//   _тој_, visõ, ливі_, kcją_
  { {0x9057000a,0xad1b000a,0x6bd40015,0xdddb0045}},	//   יבלו_, _בוור, _وتير, otuş
  { {0x8b03002a,0xdb1d007c,0x2fc60034,0xd7e40033}},	// [c210] łębi, tisõ, _mlog_, ціро
  { {0x3f84000c,0x2707005d,0x3db80053,0x7bdd0209}},	//   hemu_, _शरीर_, נֶּא, lisu
  { {0x44270023,0xe4d90029,0xe475000d,0xb8950015}},	//   ên_, دوات_, слењ, _الجع
  { {0x2458008f,0x289a0008,0xdb1d0020,0x889a00f3}},	//   раць_, _עירא, sisõ, _עברי
  { {0xddc904f9,0x2ba8000b,0x2bba000b,0xd2280015}},	//   nteţ, गाता, _उकसा, لكنه_
  { {0xe1f80010,0x61421923,0x7bdd014b,0x98a3002a}},	//   агі_, пеша, hisu, acją_
  { {0xb3670063,0x7bdd5042,0x2fc65043,0xd12e0021}},	//   _възк, kisu, _blog_, رمي_
  { {0xdce10024,0xfe450004,0x3f8400bc,0x6d5c001a}},	//   selī, бнио, gemu_, óran
  { {0xef19005f,0x5fa9005d,0x929d005c,0xee3602bf}},	//   ыми_, काबल, _byłe, бны_
  { {0x7bdd007c,0x0000006a,0x0000006a,0x0000006a}},	//   eisu,   ,   ,
  { {0x40950086,0x3f8f5044,0xe588000a,0xc0c80033}},	//   _دلار, _tagu_, בָרָ, _куце_
  { {0x30150080,0xeb9f02de,0x629b0091,0x547a000a}},	//   _удер, eløb_, _kruo, נטרו
  { {0x539a0008,0x501a000a,0x69dc20e8,0xd6220033}},	//   אירו, _עונו, tire, вiна
  { {0xfe700086,0x6e3b11ac,0x69dc0125,0x7bdd433c}},	//   _زده_, mpub, uire, aisu
  { {0x2d850440,0x69dc5045,0xc7a60345,0x6c350015}},	//   mele_, rire, бивк, _اعتذ
  { {0x2cb800c0,0x2d855046,0x69dc5047,0xd6260015}},	//   ärde_, lele_, sire, معطي
  { {0xb8ff014e,0xbb3b00b2,0x2c7100dc,0xe57a0608}},	// [c220] _दे_, _געפי, lád_, лза_
  { {0x9986003b,0x3f84002a,0xa6650015,0x2d855048}},	//   _الدو, zemu_, تطفو, nele_
  { {0xdb0d0084,0x645e0024,0xe45a4575,0x2d855049}},	//   _hlað, urpi, уже_, iele_
  { {0x63a40048,0x6cfa0053,0x629b0007,0x2d85504a}},	//   ķino, אפעס, _bruo, hele_
  { {0xa3d7014e,0x02d2000b,0x2d85487f,0xaaba000b}},	//   ाफ़_, _देखभ, kele_, ॉनिक
  { {0xd9f8005d,0x3f84005c,0x2d85504b,0x2a77004c}},	//   ंकित_, wemu_, jele_, מענך_
  { {0x2d85504c,0xd0100031,0x3ff40015,0x301401b7}},	//   dele_, ولت_, يكتر, одкр
  { {0x389b0008,0xb0270029,0x289b039e,0x2d852fa3}},	//   ריקנ, حكيم_, ריקא, eele_
  { {0x629b0007,0x25ef005d,0xd36f0115,0xfe6d002b}},	//   _gruo, _आदमी_, _سهل_, نگو_
  { {0x4237000a,0x2486002a,0x2d85504d,0x0000006a}},	//   _לנמל_, łomu_, gele_,
  { {0xfe6f0074,0xb5fb0053,0xc1060086,0x5f460029}},	//   ودی_, רליכ, _اواي, _هنال
  { {0xdb0d002e,0xfbab004a,0x6abd002a,0x2fc60085}},	//   _blað, утой_, tysf, _ulog_
  { {0x442a0f9a,0x2f97013a,0xddc90011,0x15fa005d}},	//   _lub_, _לכאן_, uteţ, ्तार_
  { {0xf2d300b2,0x0e57000f,0xceb30135,0x6ca60254}},	//   לער_, _פשוט_, _מינ_, _гриж
  { {0xe9190036,0x0bd50015,0xaab6002b,0xeb9f02de}},	//   рові_, _ويتح, مگیر_, rløb_
  { {0x60310024,0xdc6b000a,0xa037004f,0x0000006a}},	//   _jāma, _ע֣וֹ, מאלה_,
  { {0x8f9b0008,0x95d90254,0x8b58000a,0xf7700015}},	// [c230] נימי, адат_, _היחס_, عاف_
  { {0x85bb0015,0x6d4a0077,0xdcfa0045,0x6f020326}},	//   دارس_, _jefa, cetă, _myoc
  { {0x628000df,0xd49b0010,0xf1ac005d,0x980b0015}},	//   _apmo, ыра_, चानन, _متحف_
  { {0x78ba00c0,0x2d85504e,0xd8380046,0x6d4a0034}},	//   ätve, zele_, íče_, _lefa
  { {0xdcf80024,0x6d58504f,0x6265005e,0x51f50021}},	//   _kavē, _odva, івка, يستر
  { {0xfa78013a,0xddc20089,0xda7c0008,0x2d850011}},	//   צעות_, _tvoř, טנדר, xele_
  { {0x7dcd001a,0x2d855050,0x27e95051,0x978b000a}},	//   _húsg, vele_, onan_, ָרִ֔
  { {0xdbf20089,0x60090001,0x27e95052,0x6d580aa0}},	//   _přís, јним_, nnan_, _adva
  { {0x92b70086,0x7c2a00b8,0xa6db002e,0x6d4a5053}},	//   _احزا, _aufr, _beði, _befa
  { {0x7c2a003c,0xa2b8000b,0x6d4a5054,0xed5903ae}},	//   _bufr, ्नर्, _cefa, јон_
  { {0x6e3b0007,0x2d855055,0xcb09000a,0x6cc5005e}},	//   spub, rele_, _סל_, ійма
  { {0x2d855056,0x6722003d,0xdbf20046,0x2c7103bc}},	//   sele_, žoji, _třís, rád_
  { {0xeb970404,0xff500086,0x0376000a,0xdd950033}},	//   ция_, _سخن_, חתרת_, _мады
  { {0x7b3e005c,0x8c45017a,0x6d4a1a2b,0xfeb80015}},	//   dłuż, _деке, _gefa, _دامت_
  { {0x6e2b002e,0xab5b0064,0x61e4002d,0x291e0123}},	//   _hugb, mkün, éili, äta_
  { {0x29040048,0x27e95057,0x07a30010,0x98a3005c}},	//   āma_, gnan_, масн, ncję_
  { {0x9989002c,0x7c2a00b8,0x442a5058,0x8c170015}},	// [c240] _stať_, _zufr, _sub_, _بيير_
  { {0x6abb00b8,0x7c240201,0xab5b0012,0x49c70033}},	//   äufe, _hiir, nkün, _млын_
  { {0x7c24267f,0x98a3005c,0x6e23003c,0x27e90915}},	//   _kiir, kcję_, _minb, bnan_
  { {0x99860086,0x1306059c,0xab5b0020,0x98050033}},	//   _الگو, озем, shüv, _няўд
  { {0xc7b301e4,0x27e000f2,0xfbd3000a,0x69ce0061}},	//   _חבר_, miin_, ותא_, ohbe
  { {0x4a9b00b2,0x27e02aa7,0x1a9b0053,0xea9b0053}},	//   יינג, liin_, יינע, יסנש
  { {0x21670124,0x316001e2,0x70540029,0x61ed12bf}},	//   цији_, ğiz_, أنبا, éala
  { {0x88bb0008,0x27e000f2,0xb6020089,0xa857000a}},	//   יזצי, niin_, řáda, קיפה_
  { {0x3f980089,0x7c2a04f3,0x6d41108a,0x7c380046}},	//   ěru_, _sufr, fbla, _stvr
  { {0x4424003e,0x27e900bd,0x667b000f,0x27ed1422}},	//   _him_, znan_, סטיק, čeni_
  { {0x27e000f2,0x659b0008,0x6d4a1736,0xfeb7002b}},	//   kiin_, בייק, _vefa, مایت_
  { {0x6d4a0176,0xb4fb0008,0xddc90011,0x6e231611}},	//   _wefa, שפטי, preş, _einb
  { {0x6d411786,0x27e000f2,0x44245059,0xdcf8003d}},	//   bbla, diin_, _mim_, _pavē
  { {0x6d5500dc,0x6d58505a,0x4424505b,0x4dd30015}},	//   ózat, _udva, _lim_, _يتوس
  { {0x61ea00b8,0x61fd002e,0x7c380d98,0x7c580015}},	//   infl, _ísle, _utvr, _البر_
  { {0x4424145b,0x9635011c,0x27e01547,0x34ab002b}},	//   _nim_, знац, giin_, یداً_
  { {0x9742005e,0x9f440f01,0x27e9505c,0x06090058}},	// [c250] вiть_, lomó_, rnan_, مْرٌ_
  { {0x69ce2c21,0xe8eb0015,0xd49b0164,0x44243dbb}},	//   chbe, _نرجو_, ире_, _aim_
  { {0x7aeb0024,0x98a3005c,0x7b3e005c,0xa4d4005e}},	//   ņotā, ycję_, służ, мофі
  { {0x78fa0008,0xab5b00b8,0xd0060067,0x4424505d}},	//   _לפתו, chüt, _سل_, _cim_
  { {0x80d3014e,0x442431b4,0xc2440010,0xd7360008}},	//   _भेजे, _dim_, днік, _מטרת_
  { {0x76ba01e4,0x30790015,0x44240012,0x6e2b505e}},	//   _המשפ, محبة_, _eim_, _rugb
  { {0x4424505f,0x671f000b,0xa1560054,0x98b80045}},	//   _fim_, _मृतक_, чају_, mbră_
  { {0xffd50010,0xa2d6000b,0xfe450004,0x98b40085}},	//   яўля, _मेक्, пнио, žeću_
  { {0xee390001,0xa159017f,0x60055060,0xd00e0015}},	//   љно_, _газу_, nómi, دلي_
  { {0x7c240c8d,0x6d415061,0x90a70015,0xf1b91253}},	//   _siir, ubla, _وحام, _pušu_
  { {0x7c240458,0xdca54912,0xab5b00b8,0xf045002b}},	//   _piir, чани, rkün, _رعای
  { {0x6d41020a,0x907a000a,0x6488000a,0x2cb80123}},	//   sbla, _לטעי, חְשְ, ärda_
  { {0x27e0022d,0x7c240020,0x9b46002b,0x80b1000b}},	//   viin_, _viir, ينگو, _अपडे
  { {0x8e080036,0xab5b00dc,0x6e920029,0x27e002f2}},	//   _днів_, lkül, _ألوا, wiin_
  { {0x27e01c3e,0x00c9000a,0xf1b2004c,0xa6db001a}},	//   tiin_, זֶּֽ, ײסן_, _meðu
  { {0xd6da0086,0xccf2000a,0xf09205bd,0x273c0046}},	//   موزش_, _רכה_, ענן_, kánů_
  { {0x27e02aa7,0x166615f1,0xab5b43aa,0xa3c5000b}},	// [c260] riin_, явам, rhüt, एसई_
  { {0x27e0022d,0x1a9b0053,0x4a9b0053,0x44245062}},	//   siin_, _פייע, _פייג, _sim_
  { {0xc32a0029,0x487a0063,0x6b96117f,0x49bb000a}},	//   مكان_, _успя_, _kayg, _המיס
  { {0x61ea0026,0x7c2e016e,0x32070244,0x7bc65063}},	//   wnfl, íbri, elny_, nkku
  { {0x56930010,0x6d5c00dc,0xd323004a,0x79b6000a}},	//   _заўт, órak, ньши, ּלֶד_
  { {0x1df7000b,0xd6eb000a,0x3ea00091,0xab5b0030}},	//   ुतोष_, _הַלָ, _šito_, ekül
  { {0xf993000a,0xc5fa000b,0x44245064,0xc7d6000a}},	//   גרו_, ्तीय_, _tim_, ּוִי_
  { {0x6736005c,0x67220024,0x3207005c,0x929d002a}},	//   ncyj, žoju, alny_, _wyła
  { {0x9f5f016e,0xe2ca0033,0xb30a009a,0x929d0535}},	//   cluí_, _улад_, _طغرل_, _tyła
  { {0x60e7002e,0x3eb90f3a,0x7656008c,0x01d70015}},	//   ármá, ästa_, isyy, _فوقع_
  { {0x6736005c,0x057700f3,0x113b000a,0x3157004c}},	//   kcyj, הגים_, _התבל, _זיבן_
  { {0x7656008c,0x69de5065,0x6ff300d4,0x0000006a}},	//   ksyy, _ampe, tăce,
  { {0xcfb7000a,0xada61a9d,0x600b000a,0x5fa90065}},	//   _מלאי_, _надл, _הִגְ, कारल
  { {0x7bc60fb2,0xf773002b,0xdee50115,0x64b50046}},	//   akku, کاس_, _تأمي, _hřiš
  { {0x5d7b0008,0x7d7b0447,0x2905001a,0x4d7b000a}},	//   _האוק, _הרוג, æla_, _הרוע
  { {0xab5b0061,0x69de5066,0x248301d7,0x60055067}},	//   oküm, _empe, _rpjm_, tómi
  { {0x05870080,0xe6640e88,0xe7300015,0x55b90033}},	// [c270] зуем, етхо, اصف_, огаў_
  { {0x7bcd002e,0xd7bf000b,0x6736002a,0x68f9004f}},	//   _hlau, _एकवच, acyj, _ֽלֹה
  { {0x7bcd5068,0x6b960064,0x6fe80089,0xe919005e}},	//   _klau, _yayg, pěch, _фоні_
  { {0x69c70789,0xdfc60015,0xb8f1000b,0x28d60065}},	//   lkje, _شي_, वन_, _डेटि
  { {0x9404002b,0xdb0d016e,0xd6840e64,0xf79a004f}},	//   روهه, _doaç, _пурп, _וברמ
  { {0xc6920008,0x69c725cc,0x8a7c000a,0x27ed0085}},	//   _שאם_, nkje, צאות, čenu_
  { {0x84640063,0xab5b17f7,0x7bc6001a,0xdce1002a}},	//   _пъте, tkül, ykku, oglą
  { {0x43940080,0x33940033,0xee3944e7,0xd6220033}},	//   _пасс, _пасё, они_, вiза
  { {0x69c73adb,0x63a900aa,0xdce8003d,0xab5b080d}},	//   kkje, _inen, bedī, rkül
  { {0xf1a4014e,0xde160029,0x6b960064,0xa2b2005d}},	//   _गोपन, وقيت_, _sayg, _आपत्
  { {0x69c7003c,0x91640015,0xaf37002b,0x6736002a}},	//   dkje, _أهمه, _فرشت, ycyj
  { {0x63bb00dd,0x3b0a226a,0x30180015,0x98b8003d}},	//   _joun, жемо_, _فتنة_, zarē_
  { {0xdce1005c,0x7bc600f2,0x63a95069,0x63bb1d40}},	//   dglą, rkku, _mnen, _moun
  { {0x63a403eb,0x7bcd00d9,0x63bb4569,0x61e3506a}},	//   ķini, _elau, _loun, ninl
  { {0x6cd20029,0xabf6006d,0xd7c9000b,0x0ec8000b}},	//   _لقوا, _очищ, रसंच, ाईअड
  { {0xa6db002e,0x7bcd506b,0xbbf60015,0x63bb10d1}},	//   _neðs, _glau, _تستث, _noun
  { {0x61e301e2,0xfe790089,0x8cc5005d,0xe6120029}},	// [c280] kinl, ntů_, ानको, نشئ_
  { {0xc7a90053,0x04462a44,0x60c3006f,0x69de008c}},	//   ױב_, дежн, kynm, _umpe
  { {0x63bb003e,0x6d5c002d,0xdce80024,0x929d002a}},	//   _boun, órai, vedī, _było
  { {0xfe790089,0x83830080,0x63bb19d4,0xd78a0015}},	//   ktů_, выше, _coun, _بنحو_
  { {0x61e3003f,0x8c1b000a,0xfe790046,0xb425002b}},	//   finl, קוני, jtů_, رعمو
  { {0xcad70008,0xdcf80007,0x61e329fc,0xc0aa0031}},	//   וונת_, _gavė, ginl, قابل_
  { {0x63bb003e,0x64b50089,0xdce80024,0x0000006a}},	//   _foun, _přiš, redī,
  { {0x30170015,0xab5b007c,0xa6db001a,0x3ec605b5}},	//   وتية_, tküm, _geðs, дсоб
  { {0x61e30061,0xd29b0033,0x41760369,0x0000006a}},	//   binl, _нiбы, _يائس,
  { {0x6005001a,0x63a900bf,0xdce1002a,0xd1ca002b}},	//   dómu, _znen, zglą, _ببرم_
  { {0x659b013a,0x63bb003e,0x61fd002e,0xd12f0070}},	//   קיטק, _youn, _ísla, _ضمن_
  { {0x2014005c,0xaec60925,0x5457015b,0x3f9801ec}},	//   ócić_, _обел, וסטן_, ērus_
  { {0x501b00b2,0xbf650015,0x9f4d0012,0x5f16000b}},	//   _וואו, _أدمو, ließ_, _पृच्_
  { {0x7c660031,0x7c580015,0xc9840719,0x0000006a}},	//   _قابل, _فلتر_, куси,
  { {0x91d90053,0x69c713e1,0xd7f50afa,0x2d8c506c}},	//   פֿשפ, rkje, езвы, mede_
  { {0x69c706f5,0x61e30064,0x7c830099,0x2d8c506d}},	//   skje, zinl, _руше, lede_
  { {0x63bb0041,0xc20e005d,0x61e30464,0xa61514b7}},	// [c290] _roun, िताब_, yinl, емач
  { {0x9e77013a,0xaa880086,0x63bb26e3,0xc6a4006b}},	//   וגמה_, _کنیم_, _soun, ърси
  { {0x63bb506e,0xa439005e,0xf992000a,0x2d8c01e0}},	//   _poun, їзду_, _גרי_, iede_
  { {0xe667010f,0x07350053,0x67d5005e,0x2d8c506f}},	//   _отго, _ראָם_, _чому, hede_
  { {0xa2940036,0x07a40010,0xfe790089,0x92940033}},	//   каці, _раўн, xtů_, кацц
  { {0x63bb003e,0xb224005e,0x409515f7,0x929d002a}},	//   _woun, вміл, ерит, _wyło
  { {0x70550086,0x2d8c5070,0xdbc70061,0x61e35071}},	//   رنظا, dede_, _göçl, rinl
  { {0x63a90334,0x61e35072,0xa2950033,0xef19002a}},	//   _unen, sinl, _пабі, zeżu_
  { {0x2ec9005d,0xa3be000b,0x997d003d,0x2d8c4d3f}},	//   िनेत, ेसर_, māņu_, fede_
  { {0xc6920008,0xd1310029,0x1c45034e,0x2d8c5073}},	//   נאי_, _إما_, нном, gede_
  { {0xfe790089,0x1d940033,0x2d940033,0xc0d50015}},	//   stů_, трыё, трыс, _ثياب
  { {0xf0440010,0xdcfa0046,0xfe790046,0xf092000a}},	//   _рэфо, letě, ptů_, _תנא_
  { {0xaae0005d,0x44310656,0x5ac7058f,0x4ae00157}},	//   _पेशक, _luz_, елям_, _पेशव
  { {0xf2d24a20,0x60310024,0x395e0152,0x7e960015}},	//   נעם_, _rāmj, ûts_, _أنور_
  { {0x4d760008,0xdca2006b,0x3eb50045,0x997d003d}},	//   _נתקל_, _бащи, ţetă_, kāņu_
  { {0xed16004c,0x9f910030,0xad1a004f,0xb8650058}},	//   _אַחת_, _báé_, _צוקר, ضافو
  { {0x6b840035,0xd6a90058,0x7e7b5074,0x443100d4}},	// [c2a0] _ibig, ودكم_, ntup, _auz_
  { {0xe4d7002b,0x44310061,0xddc2002a,0x3946005e}},	//   کومت_, _buz_, _zwoł, _яног
  { {0x8ca2005d,0x2937004c,0x7e7b007c,0x290e0030}},	//   गियो, _ראטן_, htup, _áfa_
  { {0xe9f90023,0x78ad0089,0xe3ba0010,0x2d8c5075}},	//   _trả_, ňová, ябе_, zede_
  { {0x3d06005d,0x2d8c2701,0x07a304f7,0xa294022a}},	//   _सुने_, yede_, _саян, талі
  { {0xcb1300b2,0x27ff02c6,0x7644117f,0x798e0034}},	//   אלד_, čune_, mpiy, nebw
  { {0x21570029,0x6b840012,0x6fde003d,0xc7cb0016}},	//   رجوع_, _obig, lūci, _hiêị
  { {0xf8b30008,0x2d8c0035,0xdfd000e6,0x44441650}},	//   רשה_, wede_, شيخ_, mp_
  { {0x44445076,0x3ea2002e,0x5e430015,0x2f370015}},	//   lp_, íkt_, هَيْ, رثية_
  { {0x2d8c02c1,0x81a50029,0x63a40024,0xd6770008}},	//   uede_, _لحمل, ķinu, עתיק_
  { {0x9bd50036,0x2d8c0293,0xee77002b,0xd179005e}},	//   вжні, rede_, وصیت_, _юсті_
  { {0x2d8c018c,0x6aa40176,0xbb94004a,0x44445077}},	//   sede_, _brif, гающ, ip_
  { {0x5fbb0008,0x5a3405c4,0x2d8c5078,0x636b0030}},	//   _מצאנ, лнят, pede_, lönü
  { {0x2a640030,0x6da30099,0x7dcd001a,0x6aa43e55}},	//   ámba_, _биља, _húsn, _drif
  { {0x0db70015,0x44440079,0x6aa45079,0x7793009a}},	//   _ساوث_, jp_, _erif, هیدا
  { {0xf7940033,0x6d480091,0x44442785,0xa8180058}},	//   ласэ, lbda, dp_, فتقر_
  { {0xb908005d,0x645c0152,0x44442903,0x501b000a}},	// [c2b0] _मे_, _avri, ep_, לולו
  { {0xd5380015,0x6b84002a,0xd64d005e,0x383502ed}},	//   ّثنا_, _zbig, дiве, _инор
  { {0x99640010,0x89dc0008,0xb4bd005d,0x98b80007}},	//   _стыл, _מחזי, ेने_, darė_
  { {0xf8b6000f,0x6b9d507a,0x91a60065,0x85040058}},	//   _ספרי_, ndsg, _टोबै, دومن
  { {0x07560008,0x7d0a002e,0x4444507b,0xab5b0012}},	//   _בסרט_, _lyfs, ap_, rküh
  { {0xc0e5066c,0x81c8005e,0x3a38000a,0x444401c2}},	//   колк, нгів_, תרגם_, bp_
  { {0xe1f000e6,0x997d0024,0x4444507c,0x40920058}},	//   حسن_, pāņu_, cp_, للور
  { {0xe4250086,0x7e7b507d,0x6b9d3ba0,0xbe39005e}},	//   _شکاي, ttup, jdsg, мчої_
  { {0x64451650,0xd2bb00c3,0xd80c000a,0x3f8d0144}},	//   lphi, _عارض_, הִזָ, reeu_
  { {0x30850015,0x6445343d,0x6b8401e0,0x0000006a}},	//   _للطف, ophi, _sbig,
  { {0xbebd0007,0x9f5f0003,0xcb6a0af4,0x7e7b507e}},	//   ncūz, houé_, мане_, stup
  { {0x6aa40026,0x5ea50015,0x5f74006e,0x6d48507f}},	//   _prif, _لمصل, _ماهر, abda
  { {0x6ec40031,0x798e0034,0x3af6005e,0xbe640058}},	//   _متوق, tebw, тянс, _مهني
  { {0xdce1005c,0x6d5c116b,0x201f0091,0x27e201d7}},	//   zglę, órat, lmui_, _smkn_
  { {0x38c80086,0xdd8e0029,0x7e690c2e,0xe9a302d9}},	//   راسی_, _ذوي_, lrep, јасп
  { {0x6fde0024,0x38650030,0x6aa45080,0x798e0034}},	//   tūci, álra_, _trif, sebw
  { {0x78a50134,0x8c1b000a,0x200d0045,0x636b0061}},	// [c2c0] _erhv, _קופי, ilei_, zönü
  { {0x2a570008,0x08c617bd,0x69d50596,0xc7cb0016}},	//   _שבין_, _абон, chze, _viêị
  { {0x44441bed,0x05770015,0x250b002b,0x200d1ed6}},	//   up_, ضمنة_, ورمی_, klei_
  { {0x44442903,0x39585081,0x9ada000a,0xb4650015}},	//   rp_, lars_, ֽחַט, ادله
  { {0x98b80091,0x44443163,0xf773000a,0xa2ec0065}},	//   tarė_, sp_, _דקר_, जपेज_
  { {0xdddb0024,0x7e695082,0xa576002b,0x44441b28}},	//   lruņ, drep, _جُست, pp_
  { {0xb0570029,0x5f760015,0xd01a0bb1,0x645c5083}},	//   نشيط_, ناظر, мфи_, _uvri
  { {0x78fb000a,0x28ba000b,0xb4250040,0x4ab4000b}},	//   ופצו, _उपनि, _معقو, ुहाव
  { {0xb22604c2,0x8fa300d7,0x7e695084,0x9f4401f6}},	//   _амал, рање, grep, nimé_
  { {0x22465085,0x27010016,0x64430125,0x2cea005e}},	//   mpok_, ỗng_, ínig, дьмо_
  { {0x7f860029,0x00360033,0xcf8f0054,0x6d480091}},	//   _للان, _рэзю, _кј_, rbda
  { {0x3958003e,0x7e695086,0x200d5087,0x7f46110d}},	//   ears_, brep, clei_, _редж
  { {0x4ae40010,0x7d960015,0x6031003d,0x6b9d2035}},	//   аўра, _للشؤ, _rāmi, rdsg
  { {0x3cfd000b,0x5e57000a,0x9c9a0015,0x9f5f0003}},	//   _रुके_, _יידע_, _ينشط_, voué_
  { {0xd90f0074,0x61ed0152,0xf8071b07,0x98c4093c}},	//   تید_, éali, вчан, астл
  { {0x2d9c5088,0x309b0008,0x20045089,0xb09b000a}},	//   _have_, ושלמ, nomi_, וילר
  { {0xa3b6000b,0xb4bd000b,0x97154747,0x2b593551}},	// [c2d0] जान_, ेन्_, умац, masc_
  { {0x7c2d2f1b,0x68ee002d,0x2d9e2a94,0xb5d40054}},	//   _hiar, ándá, ndte_, ажуј
  { {0x9608008f,0x7c2d003f,0x201f0007,0xf9920008}},	//   тэта_, _kiar, ymui_, _פרט_
  { {0xdb04001c,0x2b59002d,0x2d9c508a,0x2004002a}},	//   _uniã, nasc_, _lave_, jomi_
  { {0x200418a6,0x96470010,0x7c2d005c,0x69a7000b}},	//   domi_, _шэнд, _miar, टएपी
  { {0x067a015b,0x27e91830,0x6ff30045,0x2d9e508b}},	//   _אנשל, lian_, tăco, jdte_
  { {0xa4d5005e,0x205401b0,0x7dcd006f,0x22460030}},	//   _сові, атыр, _súso, apok_
  { {0xc0c80001,0x20040007,0x2d9e016b,0x7e69508c}},	//   ђује_, gomi_, edte_, trep
  { {0xa2f50010,0xe3b00087,0x51f903e7,0x91870015}},	//   _спач, _ظرف_, _знаю_, _لجام
  { {0x7bd60024,0xb5fb0057,0xbbcc000b,0x808b0015}},	//   īzum, _uvád, ास्क, _يضاف_
  { {0x27e90849,0x7c2d0375,0xc19a000a,0x1bea08c9}},	//   kian_, _biar, _רשעי, едни_
  { {0x442d00df,0x27e908c0,0xeb97004a,0xa3b6000b}},	//   _jie_, jian_, гию_, जाय_
  { {0xd37a00b2,0x7c2d508d,0x2f96000a,0x4e79004c}},	//   ערשט, _diar, _תכנן_, _נאַצ
  { {0x2d9c0041,0xe29f002e,0x4d880029,0x442d508e}},	//   _gave_, _áðu_, _لَهُ_, _lie_
  { {0xb5fb00dc,0xa3b6000b,0x660501c2,0x4109000a}},	//   _ováb, जाम_, dohk, גִּ֣
  { {0xb8dc005d,0xeb9a000d,0x7c2d04ed,0x27e9013c}},	//   _आप_, _чии_, _giar, gian_
  { {0x8c1b000a,0xd7ef0015,0xe61a05b1,0xfaa61114}},	// [c2e0] _אוקי, سكك_, еда_, _сапо
  { {0x9f44038d,0x27ff065d,0x160a0015,0x7c2d508f}},	//   rimé_, čuna_, رياً_, _ziar
  { {0xdd5600b2,0xdce30064,0xb97b0447,0x27e95090}},	//   רבעט_, _kanı, _אריז, bian_
  { {0x28970008,0x7c3e0152,0x2d9e00dc,0xd36f0015}},	//   _עדכן_, _épre, zdte_, كهم_
  { {0x41e6078f,0xa3b6005d,0x442d5091,0xb7db000a}},	//   ліка, जाब_, _die_, _טקטי
  { {0x442d020a,0xab5b1ca8,0x69ce47fa,0xe43602be}},	//   _eie_, lküt, nkbe, _مفسد
  { {0x442d1d7a,0x94790001,0xd1750033,0x20045092}},	//   _fie_, _исту_, рычы, tomi_
  { {0x09d1005d,0x5ea40029,0xaa8604af,0x2d9c5093}},	//   _हत्य, لمعل, _zvýš, _save_
  { {0x733b00b2,0x141b00b2,0x7c2d002d,0xd337000a}},	//   _װעבס, _טולב, _riar, _תרמה_
  { {0x442d0298,0xc6930008,0x5d540254,0x0697000a}},	//   _zie_, צאת_, шкот, נדים_
  { {0xa5b7000a,0x645e4054,0xdd90002b,0x7c2d5094}},	//   אליק_, nspi, موک_, _piar
  { {0x2d9c1350,0x69ce3c66,0xa3ba000b,0xc334000a}},	//   _wave_, ekbe, आउट_, יוֹ_
  { {0xdce30064,0xdee30180,0x2d9c0091,0x27e90cee}},	//   _danı, _лоци, _tave_, vian_
  { {0x7c2d005c,0x26c9003f,0x64410003,0xfe9b000a}},	//   _wiar, vyao_, _élig, _ניומ
  { {0x248d010b,0x6d3b000a,0x27e93eb4,0x28f8004a}},	//   _ćemo_, _אתונ, tian_, герь_
  { {0xab5b007c,0x98170021,0x645e5095,0x6d5a478b}},	//   gküt, ابسا, dspi, lata
  { {0x81c7003d,0x27e95096,0x98b1002a,0x356b04b9}},	// [c2f0] ldēš, rian_, dczą_, ерен_
  { {0x442d0bcf,0x1515008f,0x3eb90197,0x260f000b}},	//   _sie_, адзя, ästi_, _तीखी_
  { {0xdce301e2,0x442d2e0f,0x6605007c,0x2915002b}},	//   _yanı, _pie_, rohk, _خودآ
  { {0xa3df005d,0x13a70086,0x7bcf00aa,0x6d5a21f7}},	//   धों_, طنتی_, nkcu, hata
  { {0x49b80086,0x93940029,0x12870086,0x442d5097}},	//   _شاید_, إجما, امتی_, _vie_
  { {0x6a6c002e,0x442d11a6,0x90c50342,0xa06925d6}},	//   _höfð, _wie_, ибле, вака_
  { {0x7d1c0084,0x31580029,0x442d5098,0xa99c000a}},	//   ýrsl, اجهة_, _tie_, גבור
  { {0x6d5a1641,0xbfc5045f,0x9e654a84,0x0e652493}},	//   eata, рбик, авид, акин
  { {0x8db5017f,0x6d5a5099,0x6e920058,0x4ed500ce}},	//   асні, fata, قليا, рюйт
  { {0xdce30064,0x0d82251e,0xa698000a,0xde880015}},	//   _sanı, ольн, רכזה_, اضيه_
  { {0x3207003e,0x5f950477,0xb47b004f,0x7dcd0052}},	//   mony_, _виет, תָ֖י, _húsk
  { {0x320707e9,0x00ba000a,0x60ba000a,0x6d5a0201}},	//   lony_, _במעמ, _בצעד, aata
  { {0xbf34002b,0x6d5a0332,0x4afa0033,0xa3b6000b}},	//   _ارمغ, bata, тэня_, जात_
  { {0xef180010,0x3236004c,0xc236000a,0x6d5a3745}},	//   _смі_, יטשן_, ירשו_, cata
  { {0xdce301e2,0xfca80029,0x98360010,0x1089000a}},	//   _tanı, _مايو_, рэгі, כָּֽ
  { {0x3207509a,0x645e509b,0x57460993,0x0000006a}},	//   hony_, vspi, рнаб,
  { {0xd6cf0031,0xab5b0061,0x320714b9,0xe737096d}},	// [c300] وقف_, rküt, kony_, реу_
  { {0x7bc40020,0xd9460001,0x4a5b000a,0x3207002a}},	//   _hoiu, _њени, _שדיו, jony_
  { {0x645e509c,0xab5b007f,0x0000006a,0x0000006a}},	//   uspi, mkür,   ,
  { {0x6d5a00dc,0xf7720086,0x07a60001,0xb4250015}},	//   zata, _باد_, _тамн, معنو
  { {0x61ea0064,0xbb3b000a,0x98b1002a,0xeaa9000a}},	//   tifl, דעני, rczą_, ָדוֹ_
  { {0x20660001,0x6abb00b8,0xf8ba005d,0x9b17000a}},	//   ађив, äufi, _उपाय, בחנה_
  { {0xc953000a,0xd13901f3,0x30770015,0x1c06000b}},	//   חמו_, ухі_, لحية_, रवाल_
  { {0xbfa70080,0x201d0026,0x6d5a509d,0x62660015}},	//   атье_, _chwi_, wata, _ناطق
  { {0x443801d1,0xab5b0064,0x6d5a509e,0xe29709e5}},	//   _hur_, kkür, tata, _кат_
  { {0xf5310008,0x61ed002d,0x3207005c,0x127b0053}},	//   ּ֥י_, éalt, cony_, _באמע
  { {0xf1c200df,0x4c940063,0x25370053,0x63a000bd}},	//   rašą_, щинс, יניש_, _kamn
  { {0x2d850026,0x6d5a2169,0xceea004a,0x4438509f}},	//   afle_, sata, _идее_, _mur_
  { {0x0a6b0063,0x3a740142,0x63a250a0,0x6d5a1c4f}},	//   ърни_, оляр, idon, pata
  { {0xa2a7005d,0x44380bf5,0xc171000a,0x63a050a1}},	//   चित्, _our_, ּ֗ם_, _lamn
  { {0x6d580048,0x443850a2,0xa8a40a31,0x19580033}},	//   _ieva, _nur_, ортк, расы_
  { {0x63a20014,0x3207005c,0x48150010,0x47350010}},	//   jdon, zony_, ёмас, снас
  { {0x6d580020,0x63a20026,0xceb3004c,0xab5b04d2}},	// [c310] _keva, ddon, ֿיע_, sküs
  { {0xb9950029,0x63a204ed,0x95d8004a,0x6d580085}},	//   _الدب, edon, адут_, _jeva
  { {0x4438002f,0xd49b010f,0x8ca9005d,0x5996000a}},	//   _cur_, ъра_, टियो, _הכתב_
  { {0xb3670063,0x69c550a3,0x6d5850a4,0xdcfa003d}},	//   ръжк, _hohe, _leva, letē
  { {0x6145207f,0x2d850026,0x69c54cf8,0x6664006b}},	//   бела, yfle_, _kohe, _мърз
  { {0x7c38038d,0x7995003f,0xa2240086,0x6d5833d6}},	//   _ouvr, nezw, يروه, _neva
  { {0x32070050,0x4438002f,0xd0580010,0xdcfa0024}},	//   rony_, _gur_, арыі_, ietē
  { {0x284a0053,0x6305002b,0xe3b300c3,0x58f8000a}},	//   נעפּ, _هوزل, _برس_, יצון_
  { {0x4438018b,0x8e09005f,0x7995003f,0xdee5226a}},	//   _zur_, лнив_, kezw, сопи
  { {0x6d5801e2,0x5de501b0,0x7e6200bc,0x32190369}},	//   _ceva, ёжна, _dvop, _صياد_
  { {0x6d5850a5,0x5f770031,0xe572000a,0x6bd60015}},	//   _deva, _ناشر, הַר_, متحر
  { {0xe9f90023,0x929d002a,0x7dcd31fc,0xeb9f0013}},	//   _trẻ_, _wyłu, _músi, dløs_
  { {0x6e450015,0xed4e50a6,0xada50888,0x69c550a7}},	//   _انتم, _но_, _галл, _bohe
  { {0xceb20008,0x6d580384,0x79950586,0x6ff30011}},	//   _מיד_, _geva, gezw, dăci
  { {0xab5b0475,0xa3d70157,0x09e300fd,0x63a24aa4}},	//   rkür, िसा_, чорн, ydon
  { {0xdc3a0053,0xddc2002a,0xdc28003d,0xab5b0061}},	//   _געקר, _owoś, rķēj, skür
  { {0x443850a8,0xdcfa0024,0x7bdb000a,0x6ff30045}},	// [c320] _sur_, betē, _תקפו, găci
  { {0x63a050a9,0x7abb000a,0x96630033,0x69c50034}},	//   _samn, _עציו, якуе, _gohe
  { {0x69dc002d,0x36360086,0x9a250029,0x443800da}},	//   mhre, _گرجس, _بعين, _qur_
  { {0x53e50036,0xcc7a0053,0xd3790036,0x62820ae5}},	//   оціа, טװער, ичі_, ttoo
  { {0x6d430026,0x3239002b,0x6ff30045,0xb97a000a}},	//   _ofna, لينگ_, căci, ָנֶי
  { {0x9f44002d,0x6282014c,0x80a4000b,0xd4d60033}},	//   rimí_, rtoo, किले, _лібэ
  { {0xf9930008,0x63a004c6,0x44380161,0x628250aa}},	//   פרה_, _tamn, _uur_, stoo
  { {0x6d4104f9,0x7995002a,0x6d5850ab,0x9f040015}},	//   ecla, zezw, _seva, يوغو
  { {0x20d30023,0x66f8014e,0xd0070001,0x63b30107}},	//   ại_, ंपिक_, љење_, šení
  { {0x442650ac,0xdd9a1411,0x9f910052,0x0000006a}},	//   lmo_, уши_, _náæ_,
  { {0x69c50dfa,0x5bb9006b,0x69dc0125,0x6ce60033}},	//   _rohe, алня_, dhre, сіпе
  { {0xa09b0008,0x7995003f,0xddc90011,0x611b000a}},	//   _תיאט, wezw, pseş, _גובה
  { {0x7bdd0007,0x539b000a,0xddc0003d,0x997d003d}},	//   ūruo, איכו, nsmū, rāžu_
  { {0x2fc60161,0x69dc50ad,0x44260696,0x0cd400ce}},	//   _hoog_, ghre, hmo_, _молю
  { {0x999a00dc,0x30d8000a,0xb809002b,0x70b6000b}},	//   _cipő_, בַּע, ليسم_, _अपोल
  { {0x69dc00b8,0x69c50012,0xd8380033,0x6ff30045}},	//   ahre, _wohe, сэр_, tăci
  { {0xa3ac014e,0x98a30061,0x6b8d02f2,0x163b0015}},	// [c330] _औफ़_, rajı_, _ibag, اسرة_
  { {0x98a30064,0x6ff30045,0x44262ac9,0xa3ae0091}},	//   sajı_, răci, emo_, _rūšį_
  { {0x07350063,0x73390138,0x6aad0052,0x0000006a}},	//   _меню, азер_, _hraf,
  { {0xe3150124,0xedb5005d,0x24580010,0x6d410077}},	//   омењ, _अच्छ, саць_, zcla
  { {0xabfc000a,0x290c007c,0x877a004f,0x5727009a}},	//   נהדר, üdav_, _דארי, _دردق
  { {0xd5bb000d,0x442650ae,0xd65c0033,0x7dcd0030}},	//   _ссм_, amo_, вiцк, _húsv
  { {0x60250010,0xff510015,0xe97c000a,0xa2a7000b}},	//   одка, وخة_, אנוש, चिह्
  { {0x7a2000c0,0xfe450b1e,0x9f4d00aa,0xe3d70058}},	//   möte, онио, mieë_, _اتسع
  { {0xee360802,0xd00e00e6,0xa3b6000b,0xee3900d7}},	//   оны_, خلي_, जार_, јно_
  { {0x27080023,0x27ed0089,0xb54702e1,0x5de5022a}},	//   ởng_, čeny_, алiс, іжна
  { {0x6d4150af,0xfd110015,0x9f4d00aa,0x6aad50b0}},	//   rcla, بجة_, nieë_, _araf
  { {0x547a0008,0xab2a08df,0x395a008c,0x6d4150b1}},	//   סטרו, иона_, _seps_, scla
  { {0x539a0008,0x6aad0495,0x69dc1d43,0xc7b80016}},	//   בירו, _craf, thre, _đđ_
  { {0xfe700086,0x6aad50b2,0x7bdd1f9a,0x442650b3}},	//   _سده_, _draf, ahsu, zmo_
  { {0x4426212e,0xf1b2000a,0x7c64002b,0x98a300d8}},	//   ymo_, וסם_, _فايل, мире
  { {0xe737005f,0x7bdd50b4,0x98b80091,0xb7da0015}},	//   жет_, chsu, sarį_, جورا_
  { {0x764d0035,0x85ea005e,0xcf9205bd,0x6aad50b5}},	// [c340] gpay, адав_, וטן_, _graf
  { {0x05660484,0x9f4d00aa,0x2b450046,0xeb9f0c4e}},	//   івен, fieë_, ělce_, lløp_
  { {0x24560086,0xa3b6000b,0x9f4d00aa,0x0555005e}},	//   زنشس, जाल_, gieë_, яття
  { {0xccf20008,0xe7320029,0xdc88000a,0x69c1007c}},	//   וכב_, _يصح_, מְנָ, ölev
  { {0xa22a085d,0x25a30085,0x3253005e,0x0206004a}},	//   ажда_, _fajl_, двір, оздн
  { {0x7d060050,0x442650b6,0x244a0015,0x6fe8002a}},	//   ększ, smo_, _نجري_, mści
  { {0xd4670080,0x2fc600dd,0x99bb0643,0x30a3055f}},	//   _мире_, _poog_, יזסט, дрыв
  { {0xef190050,0x6fe8005c,0xb4d6000b,0x6e66005e}},	//   leży_, ości, िनी_, отож
  { {0x6fdc038d,0x2fc6187b,0xa3d7000b,0xc3d50033}},	//   _néce, _voog_, िसर_, _эўры
  { {0x69c80f38,0x6b8d02b9,0x6fe8002a,0x2372002a}},	//   ödel, _sbag, iści, łają_
  { {0x9d140080,0x853b000a,0x6fb60015,0xe163002b}},	//   ядоч, יגיי, _ومطا, _آگهي
  { {0x6fe8005c,0x6ff30045,0xcbe7005e,0x6aad50b7}},	//   kści, făcu, іцни, _praf
  { {0x6fe80050,0x64480152,0x764d0c87,0x7de60015}},	//   jści, _édif, xpay, _وستم
  { {0x6fdc0152,0x1e330010,0x3eb900c0,0x7c3e0152}},	//   _déce, _жніў, åste_, _épro
  { {0x6fe8005c,0xe9190036,0x91bb000a,0x88b1002b}},	//   eści, сові_, סמלי, ریحچ
  { {0xf7730115,0xd7e70033,0xdddb0061,0x7dcd001a}},	//   باس_, ціго, oruş, _dúsu
  { {0xa3ab005d,0xf4020011,0x8f9b000a,0x8c19002b}},	// [c350] _कोष_, inţă_, סימי, _پيکر_
  { {0x7a200435,0xdcea0061,0x6443016e,0x764d050b}},	//   töte, _hafı, ínio, rpay
  { {0xd37100e6,0x299a000a,0xd3550015,0x65150015}},	//   فها_, _הסתמ, كَاة, أوائ
  { {0xf3670036,0x9f4d00dd,0x3cfb0053,0x389a000a}},	//   ітен, rieë_, סלאנ, _פירנ
  { {0xfbd40008,0xd3460086,0x77ba0008,0x61451c55}},	//   ותף_, سیله_, _המרח, пела
  { {0x1a9c0053,0xfa78000a,0xe5700067,0xf4020045}},	//   יידע, קעות_, _لطف_, enţă_
  { {0xdd1c002c,0xf9580008,0xdcfa0091,0x93970015}},	//   yšši, חסות_, metė, _وجرا
  { {0x78fc0008,0xdcfa0091,0x403203ae,0xaec51dd4}},	//   ילופ, letė, нејс, збил
  { {0xfe710029,0x51870323,0xaf35002b,0x0000006a}},	//   ردة_, _мужа, يرکت,
  { {0x6fdc038d,0xf256000a,0x11440015,0xf4020045}},	//   _réce, _זֹאת_, _يَقُ, anţă_
  { {0xcb0901c8,0x6fdc0003,0x3136000a,0x1d09121e}},	//   _על_, _séce, _זרעך_, сени_
  { {0x29040064,0x6fe8005c,0x7ff7006e,0xef19002a}},	//   şmak_, yści, _بسطا, zeży_
  { {0x7f3a009d,0xdcfa0007,0x7d18002c,0x7dcd0251}},	//   _התנג, ketė, _časť, _búst
  { {0xaec40010,0xbea21068,0x0000006a,0x0000006a}},	//   _юбіл, _чашк,   ,
  { {0x291e00c0,0x64430046,0xd8262c63,0xa3e60065}},	//   åta_, ínil, здви, योँ_
  { {0xe89b0064,0x2d8200dc,0x75e00030,0xe73a012e}},	//   şağı, őket_, _közg, сеа_
  { {0x75d30086,0x4b7b000a,0xddc90045,0x5b7b004f}},	// [c360] کيلا, _האפו, creţ, _הרפא
  { {0x690700dc,0x6fe8005c,0xf5e5005e,0x36030015}},	//   érdé, rści, мієм, ّوْف
  { {0x23b30086,0xd9100086,0xc953039e,0xa957000a}},	//   کمنس, _شیر_, _אמת_, _מייק_
  { {0xa3e6005d,0xcc3a004c,0x93432c75,0xe8d7004f}},	//   यों_, צענט, енце, _זוטר_
  { {0x74130074,0x6fd501b2,0x1ddb000b,0x0000006a}},	//   روها, _václ, मघात,
  { {0xc2970010,0x27e00035,0xf044002b,0xe0d20015}},	//   якіх_, lhin_, وعبی, فزع_
  { {0x0219008f,0x7c240026,0x76490061,0x81430015}},	//   ціць_, _ohir, _çeyr, رنين
  { {0xdfd0003b,0x28970008,0x27e0200d,0xb4fb0008}},	//   ئية_, פדפן_, nhin_, _הפלי
  { {0x27e0022d,0x4424018b,0xa136012c,0xa3e60065}},	//   ihin_, _ihm_, _فراش, योः_
  { {0xf6530008,0x27ff02c6,0x7c241f9a,0x3f5a0016}},	//   עצת_, čuni_, _ahir, ẫu_
  { {0x40560029,0x26f8000b,0x1c380033,0x7dcd072a}},	//   _رئاس, ंपुर_, юзны_, _rúst
  { {0x7dcd002c,0xddc90011,0x60d7000a,0x44240012}},	//   _súst, treţ, _מובא_, _jhm_
  { {0x9b24000d,0xbae50015,0x5af80033,0x6e94009a}},	//   ефрл, ذكسي, зеяў_, _آلتا
  { {0x3ea2002e,0xadb80058,0x0000006a,0x0000006a}},	//   æktu_, _ذهبا_,   ,
  { {0x27e000b8,0x69d500b8,0xa8490115,0xb4d6000b}},	//   fhin_, rkze, تلزم_, िनो_
  { {0x1d1705af,0xbd170008,0x2d8c09f2,0xacfb000a}},	//   _מקור_, _מחוז_, lfde_, _להוכ
  { {0x69c1007c,0x2d8c0546,0x9635493d,0x0000006a}},	// [c370] öles, ofde_, днац,
  { {0x0614005f,0xf628005e,0x442401d7,0xbadc000a}},	//   едую, піхи_, _ahm_, _לקחת
  { {0xf8d1005d,0x24990067,0xb8670015,0xd918043d}},	//   _हथिय, تناد_, _عادو, _нью_
  { {0x4c9b000a,0x23d40033,0xd82800e2,0x27e04fe9}},	//   מבבו, нцір, _ніяк_, chin_
  { {0x46a40010,0x59d1005d,0x82370015,0xa2e400ce}},	//   _заўв, _सकार, أرصا, ноїд
  { {0x13080036,0xe7d50064,0x76ba0008,0x2d8c0079}},	//   чній_, _yığı, _ומשפ, jfde_
  { {0xd5c5005e,0x10a2058c,0x0000006a,0x0000006a}},	//   мiжн, вищн,   ,
  { {0xd8dc000a,0xb0680015,0xe534005e,0x7ed5005e}},	//   מקור, أصول_, _чесь, діоч
  { {0xc91a005d,0x5215004a,0xa282002b,0x0d990033}},	//   _धर्म_, _ждат, _لینو, отны_
  { {0x75e001e2,0x7c240705,0xb5fb0030,0x7dcd50b8}},	//   _gözd, _shir, _sváj, _rúss
  { {0xddc9016f,0x2a690020,0x44240012,0x2baf000b}},	//   greš, _avab_, _yhm_, _जोहा
  { {0x30780015,0xf4f300ce,0x0000006a,0x0000006a}},	//   _رحمة_, ькiй_,   ,
  { {0xbea50010,0xe7d50061,0xef1f007c,0x0a3a0033}},	//   _цалк, _sığı, üüd_, ючны_
  { {0x75e00014,0xdb0600dc,0x31ad00dc,0x7c2400da}},	//   _köze, ndké, böző_, _whir
  { {0x27e00041,0x7e7b002e,0x7dc40029,0x7c2450b9}},	//   thin_, luup, _ستوك, _thir
  { {0x6ca40015,0x6d08004f,0x69c10072,0x0000006a}},	//   _أصول, _מִפַ, öler,
  { {0x27e000b8,0xa3ab005d,0x7e7b001a,0x35ca0054}},	// [c380] rhin_, _कोइ_, nuup, огао_
  { {0x6fdc0152,0x44f6002b,0x461a0033,0x27f20034}},	//   _méca, وساز, іцаў_, siyn_
  { {0xe73a2cd4,0x799c0026,0x2fdd0026,0xd2a601f3}},	//   _мен_, merw, _olwg_, _мiль
  { {0xd36f0029,0x799c00b8,0x7e7b007c,0x75e00061}},	//   لهم_, lerw, kuup, _sözd
  { {0xfbd30135,0xddc90844,0x91780016,0x91e6107c}},	//   כתא_, zreš, _hởi_, моде
  { {0xb865002b,0x9f460012,0xdd050046,0x0576002b}},	//   _تایو, _bloß_, ápět, _تاحد
  { {0xe3660001,0x799c005c,0xf993000f,0xa491002b}},	//   _окви, ierw, דרו_, _میلت
  { {0x77640144,0x799c475f,0x7e7b001a,0x645c0034}},	//   naix, herw, fuup, _iwri
  { {0xe2460031,0x24630030,0x799c0651,0xe6a8005a}},	//   _آخري, _témá_, kerw, _oříš
  { {0x7dcd0467,0xddc2005c,0x3f82002a,0xb6bb000a}},	//   _búsq, _stoł, żku_, קציי
  { {0x75e01e0e,0x05770008,0xd5770008,0xdb0a0264}},	//   _közb, וגים_, ותיה_, čným
  { {0x50650029,0x6fb30015,0x9985002b,0x6fd5013f}},	//   _أطلق, _لمما, کلسو, _nách
  { {0x4f650067,0x753c002a,0x799c233f,0x44440016}},	//   _سانف, _ogrz, ferw, hq_
  { {0x20140050,0x91780023,0xa3ab005d,0x9f5f002e}},	//   ścią_, _bởi_, _कोई_, lluð_
  { {0xfe37000a,0x5d7b000a,0x29050061,0x7d7b000a}},	//   _קרוי_, _ואוק, çla_, _ונוו
  { {0xdc2b0086,0xf773012c,0x69de0a44,0x0000006a}},	//   _بسته_, ضار_, _elpe,
  { {0x644e0048,0x8cc6000b,0xd6db00fd,0x799c0012}},	// [c390] _atbi, ाहको, цтв_, berw
  { {0x645c0026,0x4615002b,0xe3b0002b,0x6b9d0034}},	//   _bwri, روار, یرن_, lesg
  { {0x77640341,0xd8e40033,0x645c0034,0x224d0079}},	//   baix, _ацяп, _cwri, _stek_
  { {0x94bf005d,0x64410152,0x645c0034,0xad1b000a}},	//   _एपीआ, _élim, _dwri, חובר
  { {0x53340010,0x43740036,0x8c1c000a,0x9f4a0046}},	//   вецт, туєт, קודי, ímým_
  { {0x7ff504b6,0x27ff065d,0x645c0026,0x6fdc0152}},	//   کستا, čunu_, _fwri, _réca
  { {0x79850034,0xcfa90015,0x645c0034,0x7a200030}},	//   _mchw, كاظم_, _gwri, kötn
  { {0x7e7b0084,0x799c005c,0x6d4a0376,0x753c002a}},	//   tuup, zerw, _affa, _zgrz
  { {0xcdf50256,0xf3140033,0x63bb50ba,0x8319004f}},	//   ечны, _адтэ, _inun, _זוּז
  { {0x22b80029,0xd6fa000a,0xf1b9000a,0x7e7b0123}},	//   _تدفع_, לִיש, _מֶ֣ל, ruup
  { {0x3ead00bd,0x63a90c59,0x3236000a,0xddc00033}},	//   svet_, _kaen, _נטען_, ртыi_
  { {0x6d4a50bb,0xff5300e5,0x9056000a,0xd9d8000b}},	//   _effa, _شخص_, _נבנו_, डस्ट
  { {0x4a430063,0xe6a80089,0x63a93365,0xdaba0010}},	//   лняв, _příš, _maen, чыні_
  { {0x63a90005,0x69c10020,0xdb0f00dc,0x19b90036}},	//   _laen, ölep, ájáv, мусь_
  { {0x98aa0064,0x4dda000a,0x63bb0061,0x8b660015}},	//   tabı_, _מחסו, _onun, _كاظم
  { {0x63a900bd,0x799c50bc,0xc7a3201e,0x07a350bd}},	//   _naen, serw, лиск, ласн
  { {0xd7070175,0xabfb000a,0xf6260054,0x80a1000b}},	// [c3a0] енте_, _מהקר, едао, _कैसे
  { {0x98aa01e2,0x63bb50be,0x2a5700f3,0xf0a50016}},	//   sabı_, _anun, _רבין_, _đàng_
  { {0xaa090015,0x63a950bf,0x04960033,0xddc9002a}},	//   _تزيل_, _baen, эраў, opeł
  { {0xd3a50036,0xd3720086,0xf8b3000f,0x6fd50656}},	//   кріп, اهش_, _עשר_, _fáci
  { {0x79850176,0xdbc70005,0xa3e6005d,0x91be000b}},	//   _ychw, _tööl, योग_, _एचआई
  { {0x645c0026,0x68050091,0xe8fa000a,0x59c3000b}},	//   _twri, mėda, ּהֵן, शायर
  { {0x644e00c0,0x68050007,0x03960010,0x63a950c0}},	//   _utbi, lėda, _прая, _faen
  { {0x28b3000b,0x7c3e0003,0x0704000b,0xa4b7000a}},	//   ुमति, _épri, _रखाव_, _אללה_
  { {0x68050091,0xc73b000a,0x43750099,0xf1ab000b}},	//   nėda, התפת, _јуст, _टोकन
  { {0x63a900bd,0x8297000a,0x71ea009a,0x216a009b}},	//   _zaen, _אדמס_, _عفاف_, _хижи_
  { {0x67fb00f2,0x6d480024,0x7fd60036,0x63a9003f}},	//   näjä, rcda, _піді, _yaen
  { {0x7985018b,0xb4fb000a,0x68050091,0x7d180046}},	//   _schw, לפיי, kėda, _vyvs
  { {0xdd92002b,0x03d7000a,0x9e730015,0xd00f006e}},	//   _موش_, תוכם_, _مهنت, _الن_
  { {0x68050007,0x3ea6008c,0xec6a1411,0xbea70058}},	//   dėda, _isot_, _ерик_, _أهون_
  { {0x4e170008,0x2d9e4771,0x0dc90015,0xe0ce005e}},	//   _רחוב_, mete_, _تبنى_, ивi_
  { {0x2d9e50c1,0x6bd70015,0x6fdc0003,0x7c830302}},	//   lete_, _ستعر, _méco, _суше
  { {0x47350010,0x788a016e,0x600b004f,0x061500ce}},	// [c3b0] тнас, têvã, לִמְ, вдаю
  { {0xaa640063,0x7985005c,0x395401b2,0x8afc000a}},	//   _стък, _uchw, časí_, _מהחי
  { {0x75e001e2,0xe1f10086,0xf1bf0092,0x2d9e50c2}},	//   _sözc, یست_, _đá_, iete_
  { {0xe8d6013a,0xa8560008,0x94740002,0xe5080015}},	//   _יותר_, _שירה_, ادلا, رينو_
  { {0x63a90020,0x36d40121,0x07a40033,0x2d9e50c3}},	//   _vaen, _бояр, _саўн, kete_
  { {0x22890030,0x2d9e0dd9,0xddc00091,0x40951d8a}},	//   rúk_, jete_, irmų, врит
  { {0x2d9e3547,0x91e2006d,0x79ac000a,0xddc9002a}},	//   dete_, роще, לֹהַ, ypeł
  { {0x6fdc038d,0x7e690020,0xc7b2000a,0x63bb50c4}},	//   _déco, tsep, ֹ֑ה_, _unun
  { {0x6fdc0656,0x1ef90015,0xed59006b,0x80a1000b}},	//   _técn, بعثة_, моп_, _कैरे
  { {0xc692000a,0x6fdc0003,0x81f9002b,0x7e6950c5}},	//   סאי_, _féco, _غفار_, rsep
  { {0x2d8b002a,0xeb9a0015,0x3ea6003d,0x2d940033}},	//   ęce_, وضحت_, _esot_, урыс
  { {0x2056000a,0x03d5000a,0x7e69007c,0x31670012}},	//   _ייעל_, דוֹם_, psep, lanz_
  { {0x9f91002e,0x2d9e50c6,0x7f180033,0xd356000a}},	//   _káþ_, bete_, _пішу_, כירי_
  { {0x2d9e3593,0xc27a0008,0xddc9002a,0x316704ef}},	//   cete_, ורשי, speł, nanz_
  { {0x98b80024,0x7c840054,0xfce517bd,0x7188000a}},	//   mbrī_, _буње, _шоко, עְשַ
  { {0xbc7a004f,0x9d1a004f,0xa803009b,0x9f4a007f}},	//   _חנקת, _קוקט, азсл, şköy_
  { {0x3667010f,0x14c80086,0x3a3a50c7,0xadf8000b}},	// [c3c0] като_, کهای_, _tipp_, ुवचन_
  { {0x67fb022d,0x680500df,0x2fcf50c8,0xdb0600dc}},	//   täjä, rėda, _logg_, ndkí
  { {0x80a1005d,0xd5af0029,0xdce100bc,0x69dc50c9}},	//   _कैले, تفل_, kalč, mkre
  { {0xc5e90008,0xdb041772,0x6fdc15ac,0xe424002b}},	//   חד_, _unió, _réco, اکسي
  { {0x6fdc0152,0x2d9e0064,0x32940015,0x25aa4aa4}},	//   _décl, yete_, التأ, _tabl_
  { {0xcad70008,0x159a0015,0x2228002b,0x7656008c}},	//   כונת_, _تنسخ_, رزشی_, mpyy
  { {0x75e00064,0x80a300c3,0x2d9e50ca,0xf993004f}},	//   _göza, لمون, vete_, ירג_
  { {0x08770053,0xdce1006f,0x27e201c2,0x69dc0012}},	//   דעקט_, galč, _jlkn_, hkre
  { {0xa3ab000b,0x8e140054,0x2d9e50cb,0xc243412a}},	//   _कोट_, лдиц, tete_, _внук
  { {0xdcfa0024,0xf77f0064,0x40960015,0xdd900015}},	//   egtā, _ilçe_, _للطر, حود_
  { {0xdfd20074,0x11d70029,0x69dc50cc,0x2d9e50cd}},	//   _پيش_, _جولة_, dkre, rete_
  { {0x40ab0086,0x8fa6000d,0x8ffa0015,0x2d9e50ce}},	//   _زخمی_, _јаде, _غرار_, sete_
  { {0x6ab60026,0xf413000a,0x929d002a,0x4b540015}},	//   _cryf, שפר_, _były, شَّر
  { {0xc3330008,0x6ab643b5,0xbce60058,0xacf3009a}},	//   יור_, _dryf, _لأبو, اسیت
  { {0xd83b0010,0xab5d0053,0xe918005e,0x39e8004a}},	//   дэа_, ראַכן_, ворі_, тьян_
  { {0x58d40036,0x69dc002a,0xdce1003d,0x6d5a1db1}},	//   шост, akre, zglī, lbta
  { {0x6fdc0152,0x66e4000d,0x02be000b,0xd8380033}},	// [c3d0] _récl, аоѓа, ्होन, тэр_
  { {0xa3e5000b,0x69dc50cf,0x06090058,0x05740058}},	//   _फतह_, ckre, رْضٌ_, لامد
  { {0xdb1d0020,0x316700b8,0x937932b1,0x7bdd50d0}},	//   rksõ, vanz_, ебет_, oksu
  { {0x24580010,0x31670012,0x4414004e,0x0000006a}},	//   таць_, wanz_, афіт,
  { {0xe3b00086,0x316700b8,0xd808000a,0xdce100bc}},	//   ترل_, tanz_, _יִשָ, valč
  { {0x94770015,0x2006008c,0x208904e7,0x85470033}},	//   _لدرا, _ajoi_, ейки_, _шэме
  { {0x2edb005d,0x31670012,0x51840839,0x75e00030}},	//   यन्त, ranz_, руча, _közn
  { {0xfe790089,0xa3ab005d,0x8265002b,0x493c000a}},	//   trů_, _कोच_, _مهرن, וגוו
  { {0xee39010f,0xa3d4004a,0x69dc002a,0x2ca702f2}},	//   нни_, _тотч, ykre, _ssnd_
  { {0x2b9e0016,0xd1b8006e,0x7bdd1980,0x0000006a}},	//   _ắc_, _لاما_, eksu,
  { {0xd0840080,0x9055070e,0x9f91013f,0x9596004f}},	//   _вычи, _свец, _záý_, אכתו_
  { {0x50da0053,0x61e60007,0x6ab60034,0x305a000a}},	//   _אקעא, _įkli, _pryf, _נדנד
  { {0xf4120053,0x6ec40015,0xadbd005e,0x69dc50d1}},	//   מפט_, _نتوق, _надi, tkre
  { {0x7eb60008,0x69dc0007,0x7bdd50d2,0x6fd5016e}},	//   _תהסס_, ukre, aksu, _vácu
  { {0xdd8e0031,0x27e201c2,0x77960004,0xdc750033}},	//   _روي_, _plkn_, лјац, _сыль
  { {0x69dc07ae,0xad1a0643,0x6ab6028a,0x7e7b50d3}},	//   skre, _אוצר, _tryf, orup
  { {0x25a100b8,0x562a01c5,0xaa46005e,0x2d8550d4}},	// [c3e0] fehl_, ежам_, _щепл, ogle_
  { {0xe9a60001,0x2d8520ea,0x4a5b000a,0xb0b3000b}},	//   _саоп, ngle_, _רדיו, ंटाग
  { {0x765600f2,0x629b00f2,0x201f0091,0x8d29000a}},	//   spyy, _apuo, klui_, תֵּ֤
  { {0xb5fb0046,0x1d16004c,0x130a0088,0x43860015}},	//   _svát, אקער_, нней_, الإق
  { {0xf6d60033,0x61f850d5,0x232700af,0xddc901ec}},	//   _сіня, tivl, гоци_, mpeņ
  { {0xf1260036,0xd9f6005d,0x201f50d6,0x15431068}},	//   льйо, ुचित_, elui_, _герм
  { {0x361b0008,0x660b00dc,0xc4540008,0x7e7b0049}},	//   _נולד, égke, _כֹּה_, erup
  { {0x3eca0054,0xdfa60015,0x4fd4058f,0x0000006a}},	//   ећом_, احثي, ржит,
  { {0x73060617,0x63a20705,0x420a0054,0x8fa303ae}},	//   _спаз, meon, _знао_, сање
  { {0x211a0029,0x27130092,0x2d8550d7,0x929b000a}},	//   _كتاب_, ệng_, ggle_, _אימת
  { {0xdb040084,0x7c660029,0xfe6f0086,0x4c941206}},	//   _snið, داخل, يدی_, шинс
  { {0x201f001c,0x2d85051e,0xee86056d,0x917800a1}},	//   clui_, agle_, _быко, _hời_
  { {0x7bdd0843,0x7e560098,0xd246002b,0x7dd60045}},	//   rksu, _стец, تن_, _bâst
  { {0x3da3006b,0x1ef9004c,0x3eb902de,0xf4020045}},	//   _гръб, _בלױע, æste_, liţă_
  { {0x91780023,0xe9190036,0x71d7000a,0xa935004a}},	//   _mời_, тові_, נולד_, ревш
  { {0x91780023,0x0ea8005d,0xb886001c,0xf4020045}},	//   _lời_, _कनाड, _suíç, niţă_
  { {0x311b014e,0xdab90029,0x7c2d02f2,0x35f54bc3}},	// [c3f0] _पुनः_, _شهدت_, _ihar, апар
  { {0x1efb004c,0xf4020045,0xae140065,0xe4e70138}},	//   גלמע, hiţă_, डविन_, ліен
  { {0xd37100a2,0xd49b04ab,0xaa3a000a,0x9a3a000a}},	//   قها_, эра_, _שתתח, _שתתק
  { {0xa85a000a,0x485a000a,0x8367006e,0x63a250d8}},	//   _שדרכ, _שכרג, ادال, geon
  { {0x27e9002d,0x75e000dc,0xd235006b,0x7c2d50d9}},	//   mhan_, _közl, андъ, _mhar
  { {0x27e900b6,0x867a0008,0x7e7b0064,0x2be2000b}},	//   lhan_, _ברשו, vrup, _पत्थ
  { {0xc0e50229,0x225800bd,0x91780016,0xf1c70065}},	//   ройк, _črke_, _dời_, लाबन
  { {0x201f0011,0x5ea50015,0x27e950da,0x7c2d0034}},	//   ului_, لمبل, nhan_, _nhar
  { {0x6fdc0152,0xdce1003d,0x9187012c,0x9b46002b}},	//   _méch, dalā, _مجام, یندو
  { {0x6447000c,0xfaff50db,0x2d850003,0x023b0015}},	//   _kuji, raël_, ugle_, _أثرت_
  { {0x7c2d2533,0x7e7b00da,0x91ba000a,0x30780015}},	//   _bhar, srup, _שמעי, _محنة_
  { {0x7f840087,0x64470ef3,0x7c2d0d74,0xca29000a}},	//   _هلمن, _muji, _char, _חם_
  { {0x27e900e8,0xfc490092,0xaa46224d,0x2c4c0089}},	//   dhan_, _bậc_, регл, _věda_
  { {0x442d03af,0x35c9005d,0x65670089,0xbd880015}},	//   _lhe_, राफ़, _nejh, _منهن_
  { {0x7a2000b8,0x67e30020,0x291e002e,0xdc53002b}},	//   nöti, _sõja, æta_, _ارتک
  { {0x91780023,0x38a70026,0xec130015,0x2fcd0085}},	//   _mới_, _dŵr_, _ووود, njeg_

  { {0x6fdc0152,0xa3e9000b,0x6455003d,0x64470091}},	// [c400] _déch, यसन_, _atzi, _auji
  { {0x75e00064,0xd5af0067,0x7794002b,0x27e90fec}},	//   _gözl, وفق_, _گیرا, ahan_
  { {0xb97b0c44,0x76630089,0x27e90035,0x38a70026}},	//   _בניי, _čtyř, bhan_, _gŵr_
  { {0x442d0ede,0x6b490008,0x27e950dc,0x64480003}},	//   _che_, ְרוּ_, chan_, _édim
  { {0x31c6010f,0x443f0251,0xd2500015,0xc7b3000a}},	//   искв, _diu_, أنت_, _ובר_
  { {0x27e0022d,0x442d00b8,0xc5690067,0x11d80015}},	//   lkin_, _ehe_, _محفل_, طوبة_
  { {0x1876000a,0x91780016,0x27e0008c,0x443f0978}},	//   ׁעַר_, _vời_, okin_, _fiu_
  { {0x27e0022d,0x10130029,0x987b0053,0xa857000a}},	//   nkin_, يبيد, דאקט, ביקה_
  { {0xdcea0061,0xd0070054,0xf4020045,0x41aa0b44}},	//   _ınız, јење_, riţă_, _иван_
  { {0xa3b6005d,0x7c2d10df,0x0697000a,0xbbaf000b}},	//   ड़ाव_, _shar, סדים_, _जोड़क
  { {0xa5b70053,0x10f50033,0xdce1003d,0x2702000b}},	//   בליק_, _ляця, talā, लपुर_
  { {0x75e00064,0x4ae70033,0x644050dd,0x90e50015}},	//   _sözl, аўга, _jimi, _اسكن
  { {0x6d5c0064,0x7e540031,0x6fdc0003,0x64403929}},	//   ırab, _انتص, _réch, _mimi
  { {0xfe9b000a,0x6fdc0003,0x7c2d0a1c,0x9f91001a}},	//   _סיומ, _séch, _whar, _háð_
  { {0x6c84003b,0x9848010f,0x7c2d11d8,0x5a3402e1}},	//   _العم, ията_, _thar, інст
  { {0x7c2d003f,0x0d3b0008,0xf7730031,0x5d3b000a}},	//   _uhar, _בגוב, غاز_, _בתוא
  { {0x443f0251,0xa3d5000b,0x6fdc0f1c,0xdce30046}},	// [c410] _riu_, ाउस_, _céci, _odně
  { {0x442d03c2,0xef110053,0x915e0092,0x6fdc1fec}},	//   _she_, פּן_, _nằm_, _déci
  { {0xf8b10074,0x14190029,0xfa3400e6,0x442d0e36}},	//   _عکس_, هيئة_, _بريد, _phe_
  { {0x98a10023,0x9f91002e,0x88ba000a,0xe3b30015}},	//   _nghĩ_, _náð_, _עזרי, غرض_
  { {0x479a0008,0x443f50de,0x644050df,0x0000006a}},	//   _גירס, _viu_, _dimi,
  { {0x7a2000f2,0x644750e0,0x2a58000a,0xdcef0046}},	//   töti, _tuji, סבון_, _řečn
  { {0x442d003e,0xd1780010,0x7dcd0030,0xa99c004f}},	//   _the_, рсіі_, _túsz, דבור
  { {0x91780023,0x644050e1,0x6aad007c,0x4094005e}},	//   _với_, _gimi, _osaf, юріт
  { {0xfe710015,0x6e920015,0x3eb94c6d,0xa15901eb}},	//   أدب_, كليا, íst_, _базу_
  { {0x91780023,0x3f770092,0xc2c40015,0x7a20008c}},	//   _tới_, ểu_, _بيكي, pöti
  { {0xd4790053,0x644116c3,0xddc70030,0xa3ae000b}},	//   װאָל, _élis, áműz, _कसम_
  { {0xfeb90015,0x4e95002b,0xb0350054,0x1419004f}},	//   _ماتت_, _هشتر, _унеш, רוֹב
  { {0xdfb800e6,0x10140015,0xddc9036d,0x9ad500ce}},	//   _خالص_, _ببلد, mrež, оюрі
  { {0x6d4300b6,0x6fdc0152,0x6d5c0064,0x5fc5005d}},	//   _ugna, _réci, ırac, वावल
  { {0x27e00706,0xc8b5054f,0x48e3006b,0x320726a6}},	//   tkin_, осты, порв, inny_
  { {0x30da00b2,0x999a0089,0x4759004a,0x32072887}},	//   אַמע, _tipů_, ируя_, hnny_
  { {0x7bc40035,0x27e050e2,0xe9da03de,0x27ec0091}},	// [c420] _iniu, rkin_, _бкп_, ūdno_
  { {0xc9aa1eb8,0x27e050e3,0x644050e4,0x0000006a}},	//   _свое_, skin_, _simi,
  { {0x7bd60064,0x3736002b,0x680c0061,0x915e0016}},	//   _koyu, _گردآ, ağda, _nắm_
  { {0x3207005c,0xd4670054,0x9d28000a,0x7a20001a}},	//   enny_, сице_, בֵנִ, götv
  { {0xe296000d,0x8c1b0008,0x9f91002e,0xd5b809a0}},	//   среќ, נוני, _ráð_, лiдо
  { {0xca97000a,0xd46a0040,0xb2370058,0xdb04059d}},	//   מדני_, _محرم_, مكنا_, _uniõ
  { {0x915e0016,0x64402390,0x935a0054,0xb458004f}},	//   _cắm_, _timi, _брзу_, _כֻּת
  { {0xa8570008,0xdb0600c0,0x32460010,0x64400045}},	//   זיקה_, odkä, _геаг, _uimi
  { {0xc7b3000a,0x9e660015,0xdb0604d2,0x23270432}},	//   לבה_, حابن, ndkä, _готи_
  { {0x6b8d002f,0x29f20024,0x2d9900dc,0xd257000a}},	//   _scag, iņas_, ősen_, _לשמה_
  { {0x7bd601e2,0x25f0005d,0x459b0053,0x70530086}},	//   _boyu, _इतनी_, נסטע, _فنلا
  { {0xe6c8005d,0xc4d30008,0x853b000a,0xac1908fc}},	//   रमाङ, לגת_, טגיי, рому_
  { {0x9eda0015,0xa3d0000b,0x1eda009a,0x7bd6007f}},	//   _حذاء_, _वचन_, _حباب_, _doyu
  { {0x2d570080,0x3e340015,0xcf2500c3,0x828b004f}},	//   _лишь_, _بفتر, _برمي, נְכֶ
  { {0x8078000a,0xfc490016,0x05dc000b,0xf078004f}},	//   יְּה, _hận_, _मक़ब, יָּם
  { {0xdc550086,0x0057000a,0x07090015,0xf77000c3}},	//   _بروک, משלת_, ليزي_, ّال_
  { {0x75e000dc,0x6aad0a72,0x320709bf,0x34e1000b}},	// [c430] _közh, _usaf, ynny_, पन्द
  { {0x96ad005d,0x99674b0a,0x0000006a,0x0000006a}},	//   ुटबॉ, _утил,   ,
  { {0xfc490092,0x96260024,0x5996000a,0x69c515fc}},	//   _lận_, diņā, _וכתב_, _inhe
  { {0x78fa0008,0x61fa0012,0xef1f007c,0x321e037c}},	//   _כפתו, _amtl, üük_, _akty_
  { {0x3abc0053,0x4b7c015b,0x915e00a1,0x0000006a}},	//   ָמונ, ראדו, _sắm_,
  { {0x5187005f,0x8afc000a,0x95cb05c8,0xd019002a}},	//   суда, נהגי, _сума_, woń_
  { {0xf994000a,0xddc950e5,0x80b30065,0xc0a90058}},	//   פרק_, trež, ंटें, شاغل_
  { {0xb068003b,0x4032000d,0xfc490016,0x7a200030}},	//   حصول_, мејс, _bận_, lött
  { {0x6006008f,0xfc490092,0xde350010,0x4ec50036}},	//   ўным_, _cận_, жэнь, ійов
  { {0xb65c004c,0x69c5001a,0x3e320015,0x8c9500e2}},	//   אדזש, _nnhe, وفير, ормі
  { {0x75e00061,0x6fb50058,0xfce500ce,0x201d0535}},	//   _sözk, _ومئا, іомо, _tkwi_
  { {0x69c550e6,0xeaba02da,0xfffa005b,0x0000006a}},	//   _anhe, айм_, äätö_,
  { {0xcf270086,0x96e80001,0x8df50015,0x2b17000b}},	//   _اراي, мaну_, _وستص, _धुआँ_
  { {0xfce5087a,0x8f360008,0xbdfb0015,0x7a200030}},	//   _моло, _ואנו_, _حرصا_, jött
  { {0x7a200030,0x186a17b6,0xd943011a,0x2bb20065}},	//   dött, раби_, дери, _जसपा
  { {0x7bc40011,0xb8d2000b,0x69c50a3a,0x9626003d}},	//   _uniu, _टन_, _enhe, ziņā
  { {0x2fc0002d,0xc5760015,0xc7af0015,0x69d700da}},	// [c440] _óige_, قطاع, ضّل_, _foxe
  { {0x75e000dc,0x6fdc50e7,0x78550091,0x7a2050e8}},	//   _közi, _héct, _sąve, gött
  { {0xdd7a00b4,0x136a0001,0xd8760067,0xd5470033}},	//   שטעל, ашли_, _باخب, іпце_
  { {0xdc8c0053,0xdb4d000a,0x7413002b,0x032604d7}},	//   רװאָ, ְעוֹ, وولا, оден
  { {0xdc370053,0x599a000a,0x23b30015,0x7791002b}},	//   קאנט_, ֹשֶׁ, بمنس, _سیلا
  { {0x91e3004a,0x81160015,0x7c260012,0x40940015}},	//   моче, يذغا, hlkr, كلتر
  { {0xe6430033,0x80c4000b,0x614300af,0x962601ec}},	//   _церп, वमें, меља, riņā
  { {0x30170029,0xd0100015,0x7e980015,0x645e008c}},	//   يتية_, علة_, منبر_, mppi
  { {0x44260176,0xdee60015,0xad66006e,0xb7db004f}},	//   mlo_, تأثي, ياده, שקפי
  { {0xfc490023,0x6fdc038d,0xcdda023e,0x44260e35}},	//   _vận_, _récu, рњи_, llo_
  { {0x6fdc1446,0x442650e9,0x55bb000a,0xa3ae0157}},	//   _sécu, olo_, במיו, _कसा_
  { {0xfc490092,0x7a200d9c,0x321c0264,0x442650ea}},	//   _tận_, zött, lovy_, nlo_
  { {0x643b0053,0x7a2000f2,0x442650eb,0x539b004f}},	//   יעטנ, yött, ilo_, ביכו
  { {0x9e650074,0xddc30036,0xadb70015,0x6fdc0003}},	//   _راهن, _обчи, _وهنا_, _vécu
  { {0xdcf80061,0x62820d16,0x442650ec,0x515b004f}},	//   _tavı, hroo, klo_, שכלו
  { {0x2d8c3119,0x907b00f3,0xe4cb002b,0x44260085}},	//   lgde_, יטלי, یبان_, jlo_
  { {0xdce30048,0x7a20262d,0x442650ed,0xa3b6000b}},	// [c450] _ienā, tött, dlo_, ड़ाई_
  { {0x2d8c2831,0x442650ee,0xdb0d0030,0x316c003d}},	//   ngde_, elo_, őkód, _nedz_
  { {0x95c40087,0xf992000a,0x2fc60085,0x2d8c0079}},	//   ظيمه, _ארי_, _onog_, igde_
  { {0x442650ef,0x53350923,0xdce301ec,0x628250f0}},	//   glo_, пеет, _jenā, froo
  { {0xa7560008,0x59df021e,0xc2c80015,0x62822580}},	//   _משרד_, _नकार, قبول_, groo
  { {0xe1f80210,0xda5c000a,0x81c7004a,0x2fc602f2}},	//   огі_, סכול, ющее, _anog_
  { {0x442650f1,0x82340015,0x897c000a,0x6282007c}},	//   blo_, ذرها, שָׂה, aroo
  { {0x6fc5000b,0x2d8c0079,0xa29501c6,0x628202c7}},	//   वाइं, egde_, _набі, broo
  { {0xb4440010,0x6d5c0061,0x628250f2,0x0000006a}},	//   _цэрк, ıran, croo,
  { {0x271a0092,0x6fdc00dc,0x35d6000a,0x2d8c0123}},	//   ỏng_, _bécs, ִ֥ים_, ggde_
  { {0x7c950029,0xc5f2000a,0x29040061,0x1d250121}},	//   أشخا, גדי_, şmaz_, ямом
  { {0xfaa6008f,0xade90086,0xeb9a0a61,0x2d8c0150}},	//   памо, _گفتم_, щим_, agde_
  { {0x67ea0084,0x2cac0034,0x6ff40067,0x1a0a0058}},	//   _nýja, awdd_, _تسلط, مآسي_
  { {0x98560036,0xceb20b7b,0x645e50f3,0x7f3a004c}},	//   зташ, _ניו_, yppi, _פעסו
  { {0x75e000dc,0xdca20404,0x7d1c00b8,0x442650f4}},	//   _közv, _защи, ürst, ylo_
  { {0x628200b6,0xdb04001c,0x3f8d2ea8,0x68430361}},	//   yroo, _maiú, ngeu_, енса
  { {0x9f4a0046,0x225800bc,0x2c0b002b,0x46a30033}},	// [c460] ímém_, _črko_, _دعوی_, натв
  { {0x8afb0008,0x3abb000a,0x0566005e,0xdb060030}},	//   _להפי, _פמינ, ївен, jeké
  { {0xdb0600dc,0x316c0024,0x89db01d8,0xb9db000a}},	//   deké, _redz_, _החיי, _החיש
  { {0x44200023,0xd4690029,0x5398005e,0x628250f5}},	//   ôi_, تحكم_, івля_, troo
  { {0x32530036,0x62820209,0x442650f6,0xc7d7000a}},	//   евір, uroo, rlo_, _זוכי_
  { {0x98b80482,0x1a9b0053,0x244a0015,0x4426053e}},	//   ları_, מינע, _هجري_, slo_
  { {0x30a30080,0x997d003d,0x321c01c0,0xd12f012c}},	//   ерыв, nāšu_, rovy_, همه_
  { {0x644e0011,0x547b000a,0x11390033,0xf8b3000a}},	//   _iubi, _לטלו, цячы_, תשה_
  { {0x644e02c1,0x74130015,0x3ead00aa,0x8266009a}},	//   _hubi, _أوقا, gwet_, _رهان
  { {0x36f70008,0x69da15dc,0x661e02de,0x625c0061}},	//   פצים_, ötel, nopk, rçoğ
  { {0x6fdc0152,0x98b80064,0x2d8c0234,0x515b000a}},	//   _décr, karı_, rgde_, _הכבו
  { {0x656e0012,0x90a50015,0x2fda002b,0x997d003d}},	//   _lebh, _تحكم, _دوصد_, dāšu_
  { {0xdfcf00e6,0x4fd7000a,0x98b80061,0x644e50f7}},	//   _حين_, _מואב_, darı_, _lubi
  { {0x7f3b000a,0x195801b0,0xd5c5005e,0xdd930033}},	//   _העדו, зары_, лiнн, _зашы
  { {0xda670086,0x59f80c30,0xbd9b000a,0x5e430058}},	//   _کابي, черя_, _הסות, _ثَوْ
  { {0xfc150010,0xcce5012c,0xdb060030,0xdb0d0052}},	//   _імпэ, _تسهي, zeké, _fnað
  { {0x4b7c0008,0xdb060030,0x644e50f8,0x35b50cb0}},	// [c470] _האחו, yeké, _aubi, мбар
  { {0x7aef0064,0x3c32002c,0x3f830091,0x46140015}},	//   ıntı, ráve_, ėjui_, ّوْر
  { {0x644e29dc,0x89dc000a,0xa99a000a,0xdb060428}},	//   _cubi, _לחזי, _ובתר, veké
  { {0x224500da,0xdc8b000a,0x645c0125,0x2ca1008c}},	//   _silk_, מְדָ, _dtri, _ähde_
  { {0xdb0600dc,0x2245007c,0x8235002b,0x77ba000a}},	//   teké, _pilk_, ورتا, _ומרח
  { {0x72c40010,0xcb14004c,0x9f5f0061,0xf1c7000b}},	//   эбіз, עלס_, onuç_, लाइन
  { {0x3f8d0251,0x644e12b8,0x50580010,0xf484239c}},	//   tgeu_, _gubi, пшыя_, _путн
  { {0x7ff50074,0x6b9d0079,0xdb060030,0x22451ed5}},	//   بستا, jfsg, seké, _wilk_
  { {0x644e00d9,0xdce8003d,0x799c0034,0xdb060030}},	//   _zubi, vadā, yfrw, peké
  { {0xee390010,0x98b80064,0x628b0035,0xc33200a3}},	//   ўно_, zarı_, mugo, _יון_
  { {0x6448038d,0x98b80064,0xbb860015,0x628b50f9}},	//   _édit, yarı_, ولدي, lugo
  { {0x2734002e,0xcfab0002,0xddc20085,0x63ab50fa}},	//   _júní_, _دائم_, _gvož, negn
  { {0x03760008,0x539a0008,0x75e000dc,0x0f560008}},	//   ותרת_, חירו, _közt, _חינם_
  { {0x997d003d,0x200d003d,0xbea20912,0x7f3a004f}},	//   tāšu_, lnei_, _рашк, _וענו
  { {0x62990111,0x98b80064,0x7e08000a,0xaa43105a}},	//   htwo, tarı_, _מִקֶ, терл
  { {0x5d4400b2,0xe76a0015,0xc7a30e3f,0x07a350fb}},	//   _אָפּ_, تحسن_, киск, касн
  { {0xcf9200b2,0x98b80064,0x644e50fc,0xdb08008c}},	// [c480] כטן_, rarı_, _subi, öläi
  { {0xe57a0010,0xf98a002b,0x9a460015,0x98b80061}},	//   ізе_, _بندي_, _تضعه, sarı_
  { {0xb4e8000b,0xe3ba3402,0xc953000a,0xf74a0015}},	//   यने_, жбе_, _במת_, _ولدي_
  { {0x8cbe014e,0x53e50036,0x63ab19a4,0xf503006b}},	//   षितो, нціа, gegn, ъзхо
  { {0xf773013a,0xa248002b,0x22570015,0x3b09000a}},	//   _בקר_, سیال_, وجوب_, ּמוּ_
  { {0x71740015,0x63b90034,0x63ab007c,0x20c6006b}},	//   رهبا, adwn, aegn, дсиг
  { {0xf65f02de,0x63ab0b28,0x628b13b3,0x645c50fd}},	//   _præg_, begn, augo, _utri
  { {0xdfd0003b,0x4ee6005e,0xa3a60015,0x6d5c0061}},	//   اية_, діоз, _تحسن, ıram
  { {0x30130063,0x75d3002a,0xdd900015,0x42530015}},	//   ъдър, _węzł, هوة_, _لنقر
  { {0x200d0011,0x4d9800fd,0xb5fb0046,0x3cd4006b}},	//   anei_, чкою_, _sváz, ежос
  { {0x4424007c,0xb58202a3,0xcf8f0054,0xbdf700c3}},	//   _kkm_, хнiк, _иј_, بريا_
  { {0x75e000dc,0x375a0053,0x7c360026,0xa2c2000b}},	//   _közs, _כּולל_, _chyr, लिप्
  { {0x6e930029,0x5e930029,0xadbc0033,0x4424007c}},	//   _للنا, _للنط, _галi, _mkm_
  { {0xedd40015,0xbdf70015,0x200450fe,0x35d2000b}},	//   _سيبد, _يروا_, limi_, साफ़
  { {0xa3ae005d,0x2004008c,0x6299002a,0x9c7c006f}},	//   क़ा_, oimi_, ztwo, byča
  { {0x2d9e0303,0x50db000a,0x200450ff,0xb5fb005a}},	//   lfte_, חקלא, nimi_, _uváz
  { {0x98af01e2,0xc6f9006b,0x1ab40033,0x63ab5100}},	// [c490] ınız_, чнах_, _абыя, vegn
  { {0x2d9e0012,0xd5c9000b,0x05c9000b,0x7ae00012}},	//   nfte_, राइज, राइब, ämte
  { {0xe7590036,0x39140010,0x3c3204b2,0x20045101}},	//   _нині_, _амэр, láva_, kimi_
  { {0x200412d7,0x25b81990,0xd370002b,0x27f20034}},	//   jimi_, _earl_, لهٔ_, chyn_
  { {0xe9450086,0x27e908c0,0xd25b04f7,0xb6040046}},	//   _ترکی, mkan_, цце_, _stář
  { {0x34950010,0x9f98002e,0x63ab5102,0x27e90d25}},	//   _пагр, _séð_, segn, lkan_
  { {0x63ab04ed,0x200d0024,0x2bb2000b,0xb594005e}},	//   pegn, tnei_, ज़मा, _ширш
  { {0xc7b20008,0x27e90849,0x04c80029,0x200403df}},	//   ָ֑ה_, nkan_, _توفي_, gimi_
  { {0x52150127,0x2d9e00b8,0xd5c9000b,0x27e95103}},	//   _здат, ffte_, राऊज, ikan_
  { {0x3c32002c,0xee36065e,0x27e90849,0xef1604f7}},	//   dáva_, нны_, hkan_, эмы_
  { {0x20040007,0xdb0a01b2,0x27e90375,0xcb09000a}},	//   bimi_, čním, kkan_, _פל_
  { {0xca29013a,0x3015034e,0x645a04aa,0x20045104}},	//   _הם_, _ядер, _étie, cimi_
  { {0x27e908c0,0x2bb2000b,0x0e6401f3,0xac96002b}},	//   dkan_, ज़बा, _акін, ونیا_
  { {0x67e30005,0xb86600c3,0xe802000b,0x27e9297a}},	//   _mõju, فارو, रोना_, ekan_
  { {0x6e21016f,0xa3c1000b,0x27f20034,0x27e90049}},	//   molb, ्ञा_, thyn_, fkan_
  { {0x27e90509,0x7c240213,0x6449002a,0x1bba0015}},	//   gkan_, _ukir, _niei, _رابع_
  { {0x6fa1000b,0xaa570015,0x0b460a1f,0x6e215105}},	// [c4a0] क्यू, _كليا_, _янин, oolb
  { {0x6e210026,0x4a9b0053,0x3ebf00f2,0x27e90375}},	//   nolb, _צייג, ivut_, akan_
  { {0x27e90d25,0x74690036,0x14c80086,0xf5930015}},	//   bkan_, дрів_, بهای_, المج
  { {0xd5c9014e,0xd36f0029,0x27e900c0,0x2cb80134}},	//   राउज, مهم_, ckan_, ærdi_
  { {0x2ca700e8,0xd3230a2c,0x2d9e0123,0x20045106}},	//   _lpnd_, льши, yfte_, vimi_
  { {0x6d5c0064,0x70bd000b,0xf484002b,0x69da008c}},	//   ırak, ्मूल, _لاری, öteh
  { {0xf9930008,0xd1750010,0x67220024,0x20045107}},	//   ארו_, тычы, ļoju, timi_
  { {0x9f4400f2,0x69de4429,0x44240509,0x80a300c3}},	//   yhmä_, _lope, _ukm_, امين
  { {0x20045108,0x7e2a02a3,0x69de5109,0x26c008f4}},	//   rimi_, зіна_, _oope, nvio_
  { {0x06970008,0x69de1ae1,0xdd900225,0x3c32002c}},	//   עדים_, _nope, جود_, váva_
  { {0xc5f30008,0x2d9e00b8,0x71730015,0x61e50012}},	//   רדת_, rfte_, _إهما, öhle
  { {0x3c32002c,0x78550091,0x0000006a,0x0000006a}},	//   táva_, _sąvo,   ,
  { {0x8f75005e,0x3f67006b,0x2d9e0012,0x69de0034}},	//   _рухі, _чичо_, pfte_, _bope
  { {0xc3330b7b,0x3c320107,0xdce30091,0x69de510a}},	//   טור_, ráva_, _seną, _cope
  { {0x27e9510b,0x58840033,0x660508d6,0x645800bf}},	//   tkan_, лыта, vihk, ívil
  { {0x6fa6005d,0xf77300e5,0x27e90509,0xa3c10065}},	//   _कॉमं, طار_, ukan_, ्फ़ा_
  { {0xf653338e,0x27e9510c,0x9220000b,0xf047000a}},	// [c4b0] ائر_, rkan_, मकाज_, תָם֙_
  { {0x984b510d,0x25090086,0x27e9510e,0x7bdf1e83}},	//   _няма_, ورای_, skan_, _hoqu
  { {0x27e90849,0x225f0159,0x9c7c01c0,0xf9fc004f}},	//   pkan_, _stuk_, zyčn, _מהזמ
  { {0x987a0053,0xe4540010,0xd4980010,0x387e0003}},	//   _קארט, укцы, эру_, âtre_
  { {0x32670124,0x64490d92,0xdb160003,0x6b7c004c}},	//   хтев, _viei, _payé, לראנ
  { {0x1e1a014e,0x3318002b,0x7bdf510f,0x51840054}},	//   नकोष_, رزند_, _loqu, гућа
  { {0x70b2003b,0xd3a7078f,0x70bd005d,0x50b50850}},	//   لموض, _прап, ्मेल, тслу
  { {0xc4d20008,0x35c9000b,0x442b0016,0xfc3f0046}},	//   _דגל_, राक़, _óc_, jmí_
  { {0x0cc9014e,0x75e00014,0x2284071f,0x7ceb0030}},	//   िम्म, _közp, _бухг, körö
  { {0x63bb12e7,0xfc3f0046,0x7ae60091,0x61ea207b}},	//   _haun, emí_, vykt, ckfl
  { {0xa8060064,0x90991206,0x26c00085,0x27130016}},	//   lmış, _цвет_, zvio_, ệnh_
  { {0x63bb03eb,0x3f830007,0x3b0a0809,0x6d5a0125}},	//   _jaun, ėjus_, демо_, acta
  { {0xa8060064,0x637a000a,0x69de5110,0x6ee4002b}},	//   nmış, ונרד, _pope, _مسول
  { {0x63bb0fda,0x26c002b9,0x7ceb0030,0x2d94006b}},	//   _laun, vvio_, görö, _бръс
  { {0x44c10007,0x64c50085,0xb7960054,0xfcd200c3}},	//   _nė_, nčić, краћ, _نيوج
  { {0x9836008f,0xb8da014e,0x63bb5111,0xa8060061}},	//   тэгі, _आई_, _naun, kmış
  { {0x6beb000a,0xbab3002b,0x69de3591,0x7e7b5112}},	// [c4c0] _חַיַ, _نميب, _tope, nsup
  { {0x32070264,0x26c05113,0xb5aa0015,0xd46a0054}},	//   jiny_, rvio_, بارك_, диже_
  { {0x32070264,0x649a0033,0x26c0016e,0x63bb5114}},	//   diny_, ьтар_, svio_, _baun
  { {0xd4670001,0x44c10091,0xb5fb0046,0x130a0088}},	//   тице_, _dė_, _ptác, мней_
  { {0x92b30029,0xab0d000a,0x63bb5115,0x0000006a}},	//   لحوا, ּהוֹ, _daun,
  { {0x53330054,0x8afb000a,0x057a0015,0x32075116}},	//   јешт, והני, _زمرة_, giny_
  { {0xc9530008,0xfc4a0092,0x91e30001,0x7e7b4327}},	//   סמה_, _hậu_, роје, esup
  { {0x63bb5117,0x93aa002b,0xeeb8006b,0xd5c502a3}},	//   _gaun, _تاسف_, елиш_, лiзн
  { {0xef1f0020,0x3207037f,0xfbd6000b,0x4343004a}},	//   üüp_, biny_, धानम, _ветв
  { {0xfc4a0092,0xe802000b,0x63a24918,0xe7310c44}},	//   _mậu_, रोता_, lfon, מֵי_
  { {0xfc4a0016,0x7bdf5118,0xb063008c,0x6146009b}},	//   _lậu_, _poqu, ääty, _режа
  { {0x447b00b2,0x6d5a002d,0x63a25119,0x84a9000a}},	//   ונטע, scta, nfon, ׂיתִ
  { {0xd64d0033,0x7ceb0030,0x80c0000b,0xdd92002b}},	//   вiне, törö, विवे, _نوش_
  { {0x7a3200fb,0xfc3f0089,0x7ae00123,0xc333000a}},	//   sætn, smí_, ämta, שוש_
  { {0x6fb8000b,0x7bcd0091,0xa8060061,0x7bdf202e}},	//   ्यपू, _tnau, zmış, _toqu
  { {0x98140015,0x32070448,0xc8640296,0x7bcd41bb}},	//   لبقا, ziny_, ртри, _unau
  { {0x8aa40010,0x98a40024,0xfc4a0092,0x63bb2438}},	// [c4d0] _крэд, āmā_, _cậu_, _raun
  { {0x7e9b000a,0xdb06002a,0xe5c419a5,0xfc4a0016}},	//   וסמו, adkó, исхо, _dậu_
  { {0x63bb0035,0xc9520008,0x32070057,0xf628005e}},	//   _paun, _למי_, viny_, тіти_
  { {0x63a200dc,0xd2990010,0xc4350086,0xa7743a2d}},	//   gfon, еткі_, اکست, _ключ
  { {0x7bfc004c,0x63bb0f1d,0x3207511a,0x0000006a}},	//   ופאצ, _vaun, tiny_,
  { {0xb2240033,0xa8060061,0xb2840033,0xcad8000a}},	//   аміл, rmış, рыцк, כודת_
  { {0xa4d40036,0x41260004,0xdddb002a,0x27fe003d}},	//   _корі, лошо_, ypuł, ūtne_
  { {0xa8060064,0x94b1000b,0x2938000a,0x7e7b1fa0}},	//   pmış, ीटीआ, כאון_, tsup
  { {0xfc4a0023,0xe3150001,0x32070264,0x62350054}},	//   _mật_, _смањ, piny_, _беау
  { {0x6455000c,0xfc4a0092,0x4d650afa,0x2bd6000b}},	//   _kuzi, _lật_, ыков, धाभा
  { {0xd13103c4,0x7e7b3c2b,0x5f950015,0xa0c4002b}},	//   _اما_, ssup, _ملائ, _پينو
  { {0x1bba00e6,0x61e1345f,0x3c3201c0,0x6455511b}},	//   راجع_, _holl, rávo_, _muzi
  { {0xada50146,0x6da50180,0x442f0125,0x61e1511c}},	//   _балл, _била, ilg_, _koll
  { {0x61e1022d,0xceb20008,0x6575002c,0x3c3900dc}},	//   _joll, _ליד_, _nezh, véve_
  { {0xfc4a0092,0xbca50015,0x2c46003d,0x61e12dd3}},	//   _bật_, _إمبي, _mēdz_, _moll
  { {0x61e10100,0x6d3a000a,0xeb9a0b1e,0x3c390030}},	//   _loll, _אֲחו, _џип_, téve_
  { {0x64550ee0,0x6f7a000a,0x8c1b000a,0xb6020046}},	// [c4e0] _auzi, גְבו, _רופי, _ďábl
  { {0xa2c2005d,0x442f003c,0xed58002c,0x61e1511d}},	//   लिस्, elg_, odľa_, _noll
  { {0x35c9005d,0x299b0008,0x399b0135,0xa99b000a}},	//   राज़, _אסימ, _אייד, _אביר
  { {0x2486122c,0x843a0015,0x7794002b,0x7c264704}},	//   čom_, ركشر_, _خیرا, nokr
  { {0xc69400b2,0x0cb0021e,0x96750033,0x67ea001a}},	//   _דאָ_, _जन्म, _высі, _nýji
  { {0x61e10fb7,0x63a2511e,0x69dc0123,0x7c26013f}},	//   _coll, sfon, njre, hokr
  { {0xf9930008,0x7c262e28,0x90a60015,0xe45a005e}},	//   צרה_, kokr, احتم, _їжа_
  { {0xd2520074,0xdb0b00dc,0xc0340001,0x25f20065}},	//   _هنر_, őnéz, јниј, ंघवी_
  { {0x61e1003e,0xc7d70008,0x629e0045,0x5f38006b}},	//   _foll, רופי_, ăpos, ъпия_
  { {0x644200f2,0x61e10026,0x824a0015,0x44263760}},	//   lmoi, _goll, _أشرف_, loo_
  { {0xc2230074,0xb5fb0053,0xd00f002b,0xab620061}},	//   _اکنو, גליכ, _کلن_, ğünd
  { {0xab620064,0x64420f61,0x44260a8e,0x61430088}},	//   şünd, nmoi, noo_, _уеха
  { {0x6b840176,0x61e10064,0x80370053,0x7e62511f}},	//   _ddig, _yoll, _ענדע_, _utop
  { {0x5a340036,0x8e835120,0xd12600e6,0x44265121}},	//   йнят, _الوه, قم_, hoo_
  { {0xb809002b,0x44265122,0x9817002b,0xe918005e}},	//   نيسم_, koo_, هبرا, горі_
  { {0xb8dd014e,0x6455158f,0x57b50004,0x4993002b}},	//   _इन_, _ruzi, јбат, جیگر
  { {0xfc4a0023,0xda4b0033,0x557505aa,0x64555123}},	// [c4f0] _vật_, _пчол_, игат, _suzi
  { {0x36040015,0x69da2a59,0x60c8156a,0x98750004}},	//   موقف, ötet, _ordm, _клоц
  { {0x764e0026,0x38c90086,0xfc4a0092,0x65150015}},	//   _diby, _شادی_, _tật_, جوائ
  { {0x61e15124,0x7afd002a,0x9a68002b,0x442609cf}},	//   _soll, ozst, _جمیل_, goo_
  { {0x877a00b2,0x645a0003,0x7afd00d5,0x61e15125}},	//   _בארי, _étin, nzst, _poll
  { {0xfa78000a,0x644226a6,0x7c260030,0x7afd003d}},	//   נעות_, amoi, zokr, izst
  { {0xa1560054,0x61e102b3,0x4426185e,0xff510015}},	//   шају_, _voll, boo_, يخة_
  { {0x20c80029,0x61e10334,0x4419000a,0xe8d8004c}},	//   ابوي_, _woll, _סוּס, רוהר_
  { {0x61e15126,0xa0240012,0x4dd50033,0x60c801f1}},	//   _toll, _stöß, аінф, _erdm
  { {0x67ea0089,0x7afd003d,0xdb060061,0xd1b802be}},	//   _výji, dzst, lekç, _ماما_
  { {0x55760053,0xa3bc005d,0xcb6a07de,0xfd110015}},	//   ױערן_, _असम_, кане_, تجة_
  { {0xf0470010,0xdce80046,0xbb460e3f,0x6488004f}},	//   _сэзо, ladě, иенк, נְתְ
  { {0x6e670036,0x63a60123,0x7c262a25,0xfaa60099}},	//   _стеж, _ökne, rokr, јаго
  { {0xfe700074,0x7c2600dc,0x4efa000a,0x3cf90015}},	//   _رده_, sokr, _שהסו, _لعبد_
  { {0x26cf00c0,0xd9460a6c,0x7c26255d,0xddc900bc}},	//   ågon_, реви, pokr, osež
  { {0xb4d6002b,0x764e3e95,0x0000006a,0x0000006a}},	//   یغات, _siby,   ,
  { {0xa66500e6,0x09fa0015,0x44264af5,0xfbd2009a}},	// [c500] مطلو, _لفظة_, voo_, _هتک_
  { {0x63a95127,0x8a7b000a,0x7a20008c,0x672f002a}},	//   _aben, _שאית, yöty, _dycj
  { {0xb5fb3498,0x44265128,0x601e003d,0x07a630db}},	//   _itál, too_, līme, _канн
  { {0x87550063,0xa87b0053,0xb5fb00dc,0xb4890029}},	//   _гърц, _באטר, _után, ائلك_
  { {0xdce30089,0x44260a54,0x23270054,0x64421d61}},	//   _peně, roo_, аоци_, rmoi
  { {0x63a9018b,0x645a0003,0x6d4e0091,0x7a20008c}},	//   _eben, _étio, žbai, töty
  { {0x40a8002b,0xb97b000a,0x34930033,0x44260141}},	//   اختی_, דנצי, _маёр, poo_
  { {0xa857000a,0x0fb80054,0x4fc64a85,0x7afd5129}},	//   סיפה_, улић_, рска, yzst
  { {0x7e6d0061,0x7ae00dca,0x9ed7006b,0x4405004a}},	//   _çapl, ämtl, имът_, _учёб
  { {0x9178000a,0x8178000a,0xa2d30015,0xe29b000a}},	//   _תְּח, _תְּק, _بيكت, _בשמר
  { {0x4906000b,0x0637004c,0x8557004f,0x41e5009a}},	//   _हेलो_, שניט_, ישיב_, _اسقف
  { {0x7afd00b8,0xbea60033,0x9c7c0091,0xc334004f}},	//   tzst, _вадк, nyči, ֞וֹ_
  { {0xc334000a,0x6eb60015,0xd8430046,0xbea3512a}},	//   מוֹ_, _خصائ, načů_, _мацк
  { {0x2efb0008,0x6d5c0064,0x6df40015,0xbe630015}},	//   _שִׁב, ıras, _دكتا, _بهوي
  { {0xfc640086,0x1cb7002b,0x9c7c0091,0xf807512b}},	//   _اختی, _نايب_, kyči, ачан
  { {0x69da0fb2,0x8755005e,0x59d5000b,0x8c250021}},	//   öter, скає, दाहर, _دفعه
  { {0x67ea0084,0xa3da005d,0xcc3c0053,0xcfb7000a}},	// [c510] _nýju, ़ान_, _בעהט, סלמי_
  { {0xd54b0086,0xfc4a0016,0xddc900bc,0x05790015}},	//   نجام_, _hập_, zsež, اماة_
  { {0xd3710029,0xc3550015,0xd4980004,0xdce80046}},	//   كها_, مَاع, ирц_, vadě
  { {0xe3b30015,0x6683002b,0x59d5000b,0x4395135f}},	//   ترط_, _ویزل, दावर, садс
  { {0x6235000d,0xdb060064,0xfc4a0016,0x8388005e}},	//   беду, rekç, _mập_, рбів_
  { {0xfc4a0023,0xa4d50127,0x91e20080,0xeab8000a}},	//   _lập_, _логі, зоше, שִׁי_
  { {0x601e0024,0x490d000b,0x74f90054,0x7c2d0085}},	//   zīme, _डेमो_, _севр_, _okar
  { {0xc9180008,0x43940080,0x4918000a,0xddc2002a}},	//   יחות_, _масс, יקול_, _gwoź
  { {0x1dd2000b,0xef19002a,0xed591971,0x6e2802de}},	//   तांत, każe_, лоп_, fodb
  { {0x7c2d0014,0x07920089,0x6e280796,0x92f40015}},	//   _akar, _čímž_, godb, _بأفض
  { {0x443f0023,0x442d04d1,0xc19a000a,0x0c26013e}},	//   _khu_, _kke_, _תשעי, ймон
  { {0xfc4a0023,0xb5fb0107,0x2fe40015,0x26cb3766}},	//   _cập_, _stál, _وكلف, _orco_
  { {0xeb97010f,0xdce10024,0x0f560008,0x200d0011}},	//   щия_, talē, _הינם_, miei_
  { {0x200d0011,0x8e56000a,0x433a004c,0xaf340015}},	//   liei_, _פיצג_, טערב, _برمت
  { {0x7c950029,0x291e0064,0xa3da000b,0xdce1003d}},	//   _العص, çta_, ़ाम_, ralē
  { {0x200d04f9,0x443f0092,0xab5b00dc,0x4c050031}},	//   niei_, _nhu_, ldün, _وظيف
  { {0xe61a005f,0x85560021,0xe7e9000b,0xf74300c2}},	// [c520] гда_, مخاط, _टकरा_, зето
  { {0x05560010,0xd6cf0029,0xcb13000a,0xd8430046}},	//   стая, عقل_, _מלח_, vačů_
  { {0x75e000dc,0x39570008,0xa9bb000a,0x9c7c20db}},	//   _közz, _לשים_, _גזיר, tyči
  { {0x037a0115,0x443f512c,0x4c9a000a,0xd8430046}},	//   احات_, _chu_, טבעו, tačů_
  { {0x1db7000b,0x200d0045,0x2178055f,0xa3da0065}},	//   _असंत, diei_, айлы_, ़ाब_
  { {0x9265002b,0x3ea0008c,0x27e007e7,0xcb37004f}},	//   زدهم, _äiti_, ljin_, זאני_
  { {0x200d0011,0x2a3b004c,0x14d8000a,0x657e01f9}},	//   fiei_, װעקמ, _דַּמ, maph
  { {0x74160086,0x200d0011,0x5f940254,0xbf660015}},	//   _اورا, giei_, циит, حدثو
  { {0x6440022d,0x92050024,0xfc4a0092,0x260f01ec}},	//   _ihmi, _spāņ, _rập_, pļot_
  { {0xf1a90074,0x22f7013a,0xf2e70086,0xf77f001c}},	//   _نامه_, _הזמן_, _دکمه_, _moça_
  { {0x11d70029,0x6ca30080,0x70560002,0x9cf4005e}},	//   _دولة_, пряж, _انصا, ізмі
  { {0xdfd00015,0x320e00da,0x200d0045,0x7b64006b}},	//   _زيت_, lify_, ciei_, зтре
  { {0x80250029,0x4e17002b,0x6e2800bc,0x6282512d}},	//   _برلم, شتید_, podb, nsoo
  { {0xac730086,0x99830089,0x69da008c,0x7e9b004f}},	//   _کاوش, rojů_, ötep, _תסגו
  { {0xfc4a0023,0x2e37000a,0x16d1000b,0x5a34005e}},	//   _tập_, _הרגש_, सम्ब, їнст
  { {0x7c2d003f,0x207b004c,0xbc67012c,0x383500e2}},	//   _ukar, טאלא, _امين_, інар
  { {0x44c80064,0xfbd00015,0x36d41797,0x6eb1000b}},	// [c530] _ağ_, _أتى_, потр, _अनछु
  { {0x9b950074,0x1515008f,0x2ba5005d,0x200d0011}},	//   _الکت, одзя, ग्रा, ziei_
  { {0x2bdd014e,0xe7c4005d,0x54b904ab,0x320e25ef}},	//   यापा, _लोकप, ргея_, dify_
  { {0x437400d7,0xdc9b000a,0x6440002a,0x200d00d4}},	//   пушт, ריאל, _chmi, xiei_
  { {0x92b70029,0x628200aa,0x200d13e3,0x9327009a}},	//   إحصا, gsoo, viei_, حران
  { {0x20b4005d,0xa1350015,0x5fa6000b,0x6746006f}},	//   ंबंध, يرثش, क्सल, ňujú
  { {0x80c0014e,0x443f0e2d,0x64c50015,0x80880015}},	//   विगे, _thu_, _بيزل, مضيف_
  { {0xa2950010,0x442d003c,0x7cff001a,0x22950015}},	//   _мабі, _uke_, _láré, _ولأس
  { {0x200d0011,0x2bdd000b,0xcee6004a,0xaec20033}},	//   riei_, याना, ждые_, дбыл
  { {0x320e003e,0x200d0011,0x55760053,0xac850055}},	//   cify_, siei_, ֿערן_, огол
  { {0x14d5000a,0x200d0045,0xab5b0405,0x8c461127}},	//   קוֹל_, piei_, rdün, жене
  { {0x2ba5000b,0xeb9a512e,0xdb0f0045,0x1b4a2658}},	//   ग्ला, шим_, decâ, изни_
  { {0xce6b0063,0xa3da005d,0x4a750033,0xdb06006f}},	//   _сред_, ़ात_, зыст, lekú
  { {0x0dcb0124,0xd7f10092,0xc8660015,0xf77f059d}},	//   _људи_, ễn_, قطري, _roça_
  { {0x9c650086,0x1089000a,0x75e00061,0x6dc4009a}},	//   _بهبو, יָּֽ, _gözy, _رزول
  { {0xab5b078e,0x657e00aa,0xd94317b6,0xc7b20058}},	//   ndül, waph, феси, بّر_
  { {0x060a0124,0x75d60196,0x27f200aa,0x601e003d}},	// [c540] анак_, ييرا, rkyn_, nīma
  { {0x67f800dc,0x7bc4003f,0x9990002a,0x95860033}},	//   _díja, _haiu, łała_, ілее
  { {0x2eb6005d,0x78ad0089,0x75d30087,0x657e512f}},	//   _अन्त, čová, ظيما, raph
  { {0xd36f003b,0x2bdd005d,0x999a0007,0xfbdd000b}},	//   نهم_, याया, _tipų_, यायम
  { {0x320e0769,0x8c1b000a,0xc2970033,0xa2260015}},	//   tify_, סוני, жкіх_, يرته
  { {0x057a0029,0x799c0026,0x62820438,0x7bc4007c}},	//   _خمسة_, ngrw, rsoo, _laiu
  { {0xa3da000b,0x89db000a,0x320e26a3,0x9588002a}},	//   ़ाद_, יחסי, rify_, grąż
  { {0xa8570008,0xc953000f,0x657c5130,0xa2a7000b}},	//   חיקה_, ומו_, _herh, _फ़ैक्
  { {0xcf26003b,0xdefa1292,0xdde30011,0x62650015}},	//   غربي, рый_, ârşi, _فالق
  { {0x50d60225,0x645c5131,0x7bc600aa,0x5e430015}},	//   _وزار, _kuri, edku, وَيْ
  { {0x657c0064,0xdb0f02c1,0x26c9016f,0xa2c2005d}},	//   _merh, recí, zvao_, लिक्
  { {0x5c070010,0x2bb2005d,0xd3660015,0x5f2a004a}},	//   іяна, ज़गा, عه_, _коем_
  { {0x61e80064,0x9d9a0015,0x2bdd000b,0x3a740033}},	//   _kodl, _ننشئ_, याबा, мляр
  { {0xb5fb006f,0xba3b0034,0x645c134b,0x1f37004f}},	//   _vták, rtïo, _ouri, _ורדר_
  { {0xf65f0134,0xa954005e,0x6e43002b,0x61e80188}},	//   _træk_, дкрі, _تنوم, _modl
  { {0x9f5f002e,0xcb0b03ad,0xd7770015,0x68e80123}},	//   nnuð_, _вход_, تاسع, ädda
  { {0xba770029,0x657c0d25,0x35f5004a,0x645c0e04}},	// [c550] _باعت, _berh, ппар, _auri
  { {0xdce100df,0x645c0769,0xdb0d0020,0x6b9d0012}},	//   galė, _buri, _maaü, lgsg
  { {0x9f5f002e,0x19ba000a,0x47d50015,0x645c3d41}},	//   knuð_, _המתב, _فيدر, _curi
  { {0x645c003e,0x3c160024,0x670c005d,0x69c71b8e}},	//   _duri, tāvi_, _सेवक_, ldje
  { {0x69c50005,0xa3bc005d,0xb7da0008,0xdce10007}},	//   _kahe, _असर_, _הקרי, balė
  { {0xfa98000a,0x69c75132,0x7a32001a,0x61e85133}},	//   קדוש_, ndje, bætu, _codl
  { {0xd058008f,0x75820086,0x69c7016f,0x74680004}},	//   орыі_, _سینم, idje, _мртв_
  { {0x69c50005,0xb5fb0089,0xe3b30086,0xd91c0135}},	//   _lahe, _stáh, _ترس_, יוול
  { {0x61e80026,0xab5b0a55,0xde350033,0xb4bb000b}},	//   _fodl, rdül, зэнь, _अनु_
  { {0x69c500b8,0xddca0064,0x6555000a,0xc332000a}},	//   _nahe, ğişe, ּבֹא_, _טון_
  { {0xf654000a,0x65650012,0x42040015,0x23601b78}},	//   וצץ_, ichh, _تِلْ, žije_
  { {0xe6720064,0x113a0008,0x7a32002e,0xeb97004a}},	//   _ölçü, _התעל, hætt, пию_
  { {0x75f30064,0x7f490015,0x2903013b,0xdb0601d0}},	//   _kızı, _الشق_, ezja_, nekø
  { {0x7e280029,0x7c2700bd,0xcefd0064,0xee38042b}},	//   _وسوف_, čkra, ığın_, _дні_
  { {0x31af01e2,0x69c5018b,0xf7720029,0x4dda0008}},	//   mızı_, _dahe, فاء_, _לחסו
  { {0xb8e4000b,0x16661ed3,0x6a86006b,0x8c4303fc}},	//   _एन_, звам, _елиа, _пеще
  { {0xa3df014e,0xdb9b0008,0x6beb0008,0xdce10007}},	// [c560] तान_, _הספר, _הַיַ, talė
  { {0x31af0482,0x3c320107,0x2c6140ba,0x645c5134}},	//   nızı_, rávu_, _kód_, _puri
  { {0x5fbd005d,0xf977000a,0x6fbd000b,0x657c5135}},	//   ्याल, _מגיש_, ्यां, _verh
  { {0x2c610f11,0xcc76000a,0xe36324bf,0xd8db004f}},	//   _mód_, פענה_, екци, _הקטר
  { {0x83360029,0x61e85136,0x76550281,0xe7370142}},	//   أراض, _podl, _fizy, _нею_
  { {0x645c5137,0x26c7005c,0xd259017f,0x69c3001a}},	//   _turi, łnoc_, іці_, _ónet
  { {0x645c0005,0xf1a90086,0xc5ff0024,0x31af0061}},	//   _uuri, تانه_, ķēts_, dızı_
  { {0x351b0008,0xf8b30008,0xef19002a,0x69c70d85}},	//   _הולנ, גשה_, waża_, zdje
  { {0xb5fb002f,0x4ea30010,0x877b004c,0x4e960015}},	//   _stái, нрэа, זאפי, أشعر
  { {0xf1aa0087,0x72060002,0xa3da000b,0x11e90015}},	//   _داره_, _عوام, ़ाव_, _وعلي_
  { {0x2c61002f,0xdc3f0089,0xef19002a,0xd00a0054}},	//   _cód_, síčn, raża_, _леже_
  { {0x69c55138,0x6291003d,0x3fa50058,0x2fa50058}},	//   _sahe, ūkoš, _يصنف, _يصنّ
  { {0x90290029,0xab5b0061,0x69c50bb5,0xfe465139}},	//   _بألف_, ldük, _pahe, _ендо
  { {0xa3b3005d,0x765d2286,0x69c72857,0x35e0000b}},	//   _जॉन_, _rusy, udje, नाफ़
  { {0x69c50005,0x28f8005f,0xd90f0086,0x2bdd005d}},	//   _vahe, перь_, ایج_, यादा
  { {0x2d9e0b30,0x984b006b,0x65650034,0x36d51377}},	//   lgte_, сяга_, wchh, мобр
  { {0x6b8d00b6,0x69c5513a,0x656500da,0x7c2f4593}},	// [c570] _idag, _tahe, tchh, mocr
  { {0x8afc0008,0x317e0012,0x5afc000a,0xbafc000a}},	//   _להחי, _netz_, _ללחצ, _להחש
  { {0xd7590015,0xf992000a,0xb5fb016e,0x76550061}},	//   _ولدت_, _ברי_, _otáv, _vizy
  { {0xe3b3003b,0x7a321dfd,0x7655005c,0x656502f7}},	//   عرض_, sætt, _wizy, schh
  { {0xa3df005d,0xb2ab0661,0xc2c80015,0x38c70046}},	//   ताब_, стеж_, كبول_, bírá_
  { {0x7c2f002d,0x2c4d0046,0x045b0067,0x68ec0030}},	//   hocr, _vědy_, _هجرت_, _éldá
  { {0x63b90050,0x90450086,0xc5f2000a,0x89ec000a}},	//   pewn, ونته, _ידך_, מַהֵ
  { {0xa0090029,0xb4d9000b,0x2c61002a,0x7837000a}},	//   تقبل_, ़मी_, _ród_, הָ֖ב_
  { {0xa3da005d,0xfe450004,0x4f640015,0x00180033}},	//   ़ार_, мнио, رايف, яўшы_
  { {0xee360010,0xd251002b,0xcc89004a,0xf2040033}},	//   мны_, _شنا_, обое_, _пяхо
  { {0xdb1d0134,0xc5f2000a,0xcf27002b,0x2d940033}},	//   ndsæ, דדי_, _کراي, хрыс
  { {0x442f513b,0x2ef5007a,0x2d9e19bd,0xf989000a}},	//   nog_, _озер, agte_, _כר_
  { {0xef0e000d,0x2c61002a,0x9f580016,0xee2e07ec}},	//   _рм_, _wód_, đrô_, _ан_
  { {0xc9760029,0x6b8d0007,0x7d2800dc,0x442f513c}},	//   باحث, _edag, épsé, hog_
  { {0x442f010b,0xc8b50010,0xc7a60063,0x98a30063}},	//   kog_, нсты, мивк, кире
  { {0xdb1602c1,0x3c16003d,0x442f0cb8,0x3c460058}},	//   _mayú, tāvu_, jog_, _تَبِ
  { {0xe737005f,0x442f513d,0x5bc50015,0x85ea0248}},	// [c580] дет_, dog_, _ستيف, одав_
  { {0x7a3202de,0x75d60015,0xfa9705bd,0xd5160015}},	//   ræts, بيطا, _קדיש_, وباغ
  { {0xdce10024,0x8cd0005d,0x442f0026,0xddcb0024}},	//   dalī, धियो, fog_, _atgū
  { {0x4420513e,0xb4ae005d,0xf77f0064,0x442f513f}},	//   õi_, _कही_, _geç_, gog_
  { {0xc17a0036,0x38c70046,0xbb1b0003,0x2d9e02de}},	//   оїй_, pírá_, haîn, ygte_
  { {0xbbca005d,0xb5fb0107,0xc693000a,0x660e007c}},	//   ियुक, _stáv, _באש_, _umbk
  { {0xa2c2005d,0xdcfa0024,0xb08a0033,0xb11700c3}},	//   लिङ्, katā, цёле_, وقها_
  { {0xe29a008f,0x8fa30001,0x232a044a,0xc0e70015}},	//   _маб_, ваће, _доби_, ظفين_
  { {0x067b0053,0x6d470052,0x0000006a,0x0000006a}},	//   ֿנטל, ýjan,   ,
  { {0xdd900225,0xdb0f001c,0x2d9e0012,0x3dc70034}},	//   دود_, lecç, ugte_, _canw_
  { {0x559700f3,0x515b000a,0xbdf70015,0x7c2f1b71}},	//   ודיע_, _וכבו, ظرًا_, tocr
  { {0xdddb003d,0xd64d0033,0xdc340058,0x0000006a}},	//   rsuš, гiле, َرَة,
  { {0x6ab9005d,0xb4bb005d,0x7de60029,0x8ef60015}},	//   इबेर, _अन्_, _يستم, _تساؤ
  { {0xf77f0064,0xfd0f0086,0x7f3b000a,0xdd8f002b}},	//   _seç_, اجی_, _ועדו, _نوه_
  { {0xcec80023,0x2db70008,0x1e570008,0xa9345140}},	//   _hộ_, _חלון_, _קשור_, верш
  { {0x3f8441e8,0xeb9f04d1,0xdb0f059d,0x0000006a}},	//   namu_, riøs_, jecç,
  { {0x442f010b,0x4b7c000a,0xe699006b,0x85a70054}},	// [c590] vog_, _ואחו, яваш_, дјед
  { {0x442f0026,0x3f84003f,0xcec80092,0xc8670461}},	//   wog_, hamu_, _mộ_, _отми
  { {0xcec80092,0x75880146,0xdb0f016e,0x62890085}},	//   _lộ_, ьств_, fecç, _sveo
  { {0xdb1d02de,0x442f0034,0xfc4a0016,0x3f845141}},	//   rdsæ, uog_, _bậy_, jamu_
  { {0xfc4a0092,0x442f5142,0x3f845143,0xcec80016}},	//   _cậy_, rog_, damu_, _nộ_
  { {0xfc4a0092,0x442f0a4c,0xc692000a,0x867a000a}},	//   _dậy_, sog_, _תאם_, _מרשו
  { {0x3f84003f,0xb97c000a,0x205505fd,0x33950033}},	//   famu_, חרוז, нтир, _павё
  { {0xcec80023,0xb78c00b2,0x4439002d,0xa2ba000b}},	//   _bộ_, ֿריִ, _ós_, _शैक्
  { {0xef1918a9,0xdb1d08e9,0x15f3021e,0xcec80016}},	//   ями_, ndsä, _आकार_, _cộ_
  { {0x11d70029,0x6e450015,0xc05b005e,0x7d090054}},	//   _تترد, عندم, _дід_, зног_
  { {0x3f84003f,0x67f80030,0x27fe01ec,0x0000006a}},	//   bamu_, _díjj, ūtni_,
  { {0xc4d20053,0x26c00026,0x3f84003d,0xbb1b0003}},	//   אגט_, ywio_, camu_, raîn
  { {0x539a0008,0x501a004c,0x9af60058,0x3b830138}},	//   הירו, _צונו, ركست, ыляг
  { {0xfe700015,0x38c8002b,0x1d09029f,0xbea20fac}},	//   _ضده_, وازی_, _нели_, _сашк
  { {0xba3b0251,0x6e2600dc,0xb4ae000b,0x2d8544cb}},	//   duïd, ékbe, _कहे_, male_
  { {0x6d43016f,0x3cf80002,0x2d852c37,0xbb46006b}},	//   _izna, _تعهد_, lale_, _пейк
  { {0xd70a0010,0x38550063,0xdcf80024,0xdb0600dc}},	// [c5a0] чнае_, търс, _ievā, nekü
  { {0x386100b8,0x2bac000b,0xfbac000b,0x3f84003d}},	//   _fuhr_, ट्रा, ट्रम, zamu_
  { {0xdb060005,0x649a0010,0xb97b000a,0xdb0f016e}},	//   hekü, ятар_, _מניי, tecç
  { {0xb5fb27b8,0x03c50210,0x7d060003,0xdcfa0045}},	//   _stát, ксім, _héré, lată
  { {0x7d060014,0xc7b3000a,0xdb0f016e,0x26cf0123}},	//   _kéré, _גבר_, recç, ågot_
  { {0xfc4a0023,0x64a6070e,0x2d851be7,0x52d70033}},	//   _vậy_, _пага, jale_, эмію_
  { {0xa3ea03fc,0x999b0135,0x2d855144,0x3f845145}},	//   _едва_, לבסט, dale_, tamu_
  { {0x64430079,0x7546003d,0x2d855146,0xf65f063b}},	//   ïnit, ērzē, eale_, _træt_
  { {0x241700b2,0xe2970083,0xfe6f0086,0x4226022a}},	//   _נחמן_, _пат_, یدی_, _здав
  { {0x7c24003f,0xbef70015,0x63a25147,0xc693000a}},	//   _ajir, عريض_, lgon, נאת_
  { {0x1ac9000b,0x60a50015,0x6ab9000b,0xdddb0045}},	//   िट्ठ, _لإنق, इब्र, spuş
  { {0x68f500df,0x63a25148,0xfbab004a,0x351b004c}},	//   vyzd, ngon, чтой_, לוינ
  { {0xdcf8003d,0x63a20091,0x7d062522,0x2d855149}},	//   _devā, igon, _béré, bale_
  { {0xc3330008,0x7d060152,0x2d85514a,0xdc8a009b}},	//   רוש_, _céré, cale_, _есил_
  { {0x6e2b000a,0x7e6d0061,0xddc90045,0xa935004a}},	//   _מֵהַ, _çapr, speţ, тевш
  { {0x91f50023,0x5d3b0008,0xab620061,0x6d3b000a}},	//   _kíc, _מתוא, şürd, _מתונ
  { {0xa3da005d,0xc9870054,0xfaa40054,0xba3b0144}},	// [c5b0] ़ाई_, _пуни, _бањо, tuïd
  { {0xfb1c0008,0x7c3d00c0,0x7d060003,0xdb1d0123}},	//   _מוחמ, llsr, _géré, rdsä
  { {0xd3710070,0x7d7b0053,0x7e62008c,0xba3b0144}},	//   لها_, פראג, _luop, ruïd
  { {0xd3700074,0x23e40010,0x2d85276d,0x3ce8000b}},	//   مهٔ_, лічв, zale_, _छपने_
  { {0xd25b0010,0x2d85514b,0xe1ee011d,0x94040015}},	//   чце_, yale_, аг_, دونه
  { {0xc2440010,0x63a20035,0xa3df000b,0xe1f80033}},	//   гнік, agon, ताह_, нгі_
  { {0x2d851be7,0xc0e502da,0x27e9005b,0x0000006a}},	//   vale_, тойк, ojan_,
  { {0x27e9022d,0xe3b30015,0x2d850647,0x73c50015}},	//   njan_, _حرس_, wale_, _جيرم
  { {0x2d85514c,0x4394006b,0x92b4006e,0x32552850}},	//   tale_, _щатс, _محلا, _авар
  { {0x7c3600df,0xa3df000b,0x4d65006b,0x27e9008c}},	//   _skyr, ताव_, ъков, hjan_
  { {0xd00e0086,0xc537000a,0xdb06007c,0x644901d7}},	//   صلی_, עָ֖ה_, sekü, _khei
  { {0x0f150080,0xa3da000b,0x7f850015,0x2004006f}},	//   _имею, ़ाए_, _شلتن, chmi_
  { {0xa3b3021e,0x64491f22,0x2d85514d,0x6d43002a}},	//   ज्य_, _mhei, pale_, _wzna
  { {0xaa460063,0x22f6004c,0x3ead0030,0x0000006a}},	//   тегл, דזשן_, mtet_,
  { {0x644900f2,0x485a0010,0x6d43095b,0xc212000a}},	//   _ohei, драў_, _uzna, בהם_
  { {0x4c9a000a,0xf092000a,0x64490034,0x2fcd0034}},	//   _חבקו, ינל_, _nhei, ndeg_
  { {0x9f4f0251,0x8c37000a,0xe5720015,0x63a60123}},	// [c5c0] _algú_, _בטקס_, لطا_, _ökni
  { {0x27e900f2,0x3ead0b0f,0x6b8418b4,0xd90d002b}},	//   ajan_, itet_, _heig, _کیف_
  { {0x6449002f,0x26cf01d1,0x74690036,0xd4d50010}},	//   _bhei, ågor_, ерів_, ліцэ
  { {0x6b8400df,0xddc30014,0x6449514e,0xe8d7000a}},	//   _jeig, _minő, _chei, _סוכר_
  { {0x6449002d,0x236000bd,0xfbd30008,0x6b840c24}},	//   _dhei, žijo_, יתא_, _meig
  { {0xf4840086,0x443d0034,0xf65f00cb,0x6b84514f}},	//   _ماری, alw_, _trær_, _leig
  { {0x6449002f,0xf9930008,0x69ce0181,0xf77f0061}},	//   _fhei, ברו_, idbe, _soçi_
  { {0x6449002d,0x6b840472,0x32960015,0x22960015}},	//   _ghei, _neig, _للرأ, _للرس
  { {0x3f9801e2,0xa3df005d,0x3ead0134,0x5ea30015}},	//   ğru_, तार_, gtet_, لميل
  { {0xa3da000b,0xa8060061,0x3f980061,0x26d20573}},	//   ़ाक_, llığ, şru_, ivyo_
  { {0xf1a90074,0x6b841554,0x459b0053,0xd59b0008}},	//   _ساله_, _beig, וסיע, וביל
  { {0xa8060064,0x91f50092,0xdb1d00dc,0x765c002a}},	//   nlığ, _tíc, lesé, _liry
  { {0x7987003f,0x6f09005c,0x2014002a,0x69ce0079}},	//   tajw, czec, ęcią_, fdbe
  { {0x5a342eeb,0x5cd40015,0xaab6002b,0xbef7000a}},	//   инят, _مقتط, اگير_, _בצדו_
  { {0xa8060064,0xd9140010,0x27e90144,0x443d0034}},	//   klığ, адры, tjan_, ylw_
  { {0xf8040001,0xb5fb02c1,0x2baa005d,0x628b0026}},	//   ачун, _cuán, _काया, ysgo
  { {0xd6d00029,0x6449164b,0xc6a7006b,0x27e95150}},	// [c5d0] يقِ_, _rhei, ърви, rjan_
  { {0x6b84018b,0x64492533,0xfc3f5151,0x65940015}},	//   _zeig, _shei, llí_, لجمر
  { {0x290a0050,0xa3df005d,0xdce80007,0x765c0026}},	//   czba_, ताल_, radė, _diry
  { {0x3ead005c,0xe8d6000a,0x7b080061,0x7bcf055e}},	//   ytet_, _עורר_, _örtü, ndcu
  { {0xfc3f002f,0x877a0008,0xdee60015,0x765c0034}},	//   ilí_, _ראשי, _اً_, _firy
  { {0x7d15002c,0xb6da004c,0x785c0085,0x8afc000a}},	//   úzsk, _אַלט, _učvr, והדי
  { {0x644917ce,0xc517002b,0x3519004c,0xc9b8000a}},	//   _thei, _شبست, _װוּנ, דהות_
  { {0xb4c1014e,0x3ead02cd,0x7052002b,0x895c05bd}},	//   ्टी_, ttet_, مچنا, ודות
  { {0xdbdd002e,0xfc3f0089,0x6b840334,0x6e920115}},	//   _ráðs, dlí_, _reig, مليا
  { {0x6b840152,0x6f09005c,0x41c0000b,0x3ead4eb6}},	//   _seig, rzec, _एसएस, rtet_
  { {0xed58032c,0x25a5002e,0x6f090eba,0xdcf80045}},	//   teľa_, _öllu_, szec, _revă
  { {0x7d1c002d,0x2d990064,0x9f4d008c,0x3ead5152}},	//   úrsa, şse_, tkeä_, ptet_
  { {0xa8060064,0xa3ab021e,0xfbaa000b,0xb436000a}},	//   nlış, _खान_, _काठम, רָיו_
  { {0x6e92003b,0x5e92003b,0xca750086,0xbf360053}},	//   _الوا, _الوط, شنفک, _גאנץ_
  { {0x3e690092,0xfc3f0537,0x6b845153,0x63a9341d}},	//   _hút_, blí_, _teig, _ocen
  { {0x69a8000b,0x3c460015,0xb5fb5154,0x9d1a004f}},	//   ञ्जी, _حَبِ, _quán, _רוקט
  { {0x66e3165b,0x464a03ae,0x290a0030,0xda5a004a}},	// [c5e0] бота, езан_, szba_, _прош_
  { {0x46130029,0x8a7b000a,0xfdfc000b,0xb5ca0015}},	//   موقر, _ראית, एसएस_, عوام_
  { {0x53160086,0x5dfa004c,0x66fa003d,0xa8060061}},	//   گذار, עפענ, _sākā, tlığ
  { {0x289b0053,0x389b004c,0x889b004f,0x63a901e0}},	//   _איטא, _איטנ, _אבטי, _ccen
  { {0x3e690023,0xa8060064,0x8c1b0008,0x753c005c}},	//   _nút_, rlığ, עוני, _wyrz
  { {0x057a0015,0x3c390046,0x63a95155,0x7ae90072}},	//   _سمرة_, névr_, _ecen, äeti
  { {0xdb1d0014,0xa8063421,0xab5b0064,0xf9930008}},	//   resé, alış, ndür, זרו_
  { {0x3e695156,0x20023e52,0xcfa62c75,0x94b20065}},	//   _bút_, óki_, ушки, ीबीआ
  { {0x91960054,0xc3260e40,0x0326004a,0x23270204}},	//   _бјеш, _смак, _сдан, _боти_
  { {0x32070089,0x60cd005c,0x91f50016,0x7bcd003d}},	//   chny_, łama, _hín, _saau
  { {0x459b0053,0x7bcd121a,0x23690263,0x91f50016}},	//   עסטע, _paau, žaje_, _kín
  { {0xdb550080,0xac19007a,0xa08b000a,0x4ea60004}},	//   ивны, тому_, _נְבִ, _брка
  { {0xdd92002b,0xdb1d0013,0xfc3f5157,0xab5b02ad}},	//   _هوش_, ndsø, rlí_, edür
  { {0xc333011f,0x2b950092,0xfc3f0107,0x6e180015}},	//   מור_, ục_, slí_, _جيتس_
  { {0x5dfb000a,0x4dfb004c,0xf84b0138,0xfc3f005a}},	//   _אפגנ, _אפגא, ечай_, plí_
  { {0x8ae70036,0x8d4b0008,0x213e219f,0x7bdf183a}},	//   _біол, _אֲחֵ, _myth_, _unqu
  { {0xa3e8005d,0x16150010,0x4fbb000a,0xa7fb0077}},	// [c5f0] बान_, адаў, עצמא, _niñe
  { {0x05960086,0x659501dc,0xf7480015,0xe6130015}},	//   لامگ, ражу, الكي_, حشر_
  { {0xb4c1005d,0xd5b80033,0x213e0034,0x6d5e013f}},	//   ्टे_, ыст_, _nyth_, _úpad
  { {0xc3cb0015,0x9cd7000a,0xd9e3000b,0x487a000a}},	//   عظام_, טובה_, खावत_, _שטרס
  { {0x601e0024,0xc7d8006b,0xb3840033,0x0000006a}},	//   nīmu, _смях_, сліл,
  { {0x3e690092,0x213e0026,0xdce80024,0x40955158}},	//   _rút_, _byth_, gadī, арит
  { {0x3e690016,0x78550091,0x89dc000a,0x6021003d}},	//   _sút_, _sąvy, תחוי, lēmi
  { {0x1f650004,0xb2751b07,0x245e0046,0x63a93681}},	//   шким, _влаш, _tůma_, _ucen
  { {0x9e65009c,0xd00e0015,0x81a70021,0x0e65012e}},	//   јвод, بلي_, _محال, јкон
  { {0xfe420036,0x213e0026,0xed590299,0x63040058}},	//   жньо, _fyth_, коп_, _اوكل
  { {0x61e100aa,0x9c260099,0x03d5000a,0x9d450ae6}},	//   _inll, идод, ֑וֹם_, ренд
  { {0x3f890084,0xf3f2000a,0xf536000a,0x26d95159}},	//   _þau_, ַ֣ר_, ינתי_, _orso_
  { {0xeb97010f,0x99f60010,0xaa460457,0x5ffa000a}},	//   шия_, аяві, иемл, _שהנה
  { {0xada20033,0x6021003d,0xd356000a,0x6da20923}},	//   _дашл, dēmi, יירי_, _диша
  { {0xf7720029,0xc212000a,0xb4c1000b,0xfc320015}},	//   قاء_, קהל_, ्टो_, _وحب_
  { {0xab5b0064,0xa803005e,0x0000006a,0x0000006a}},	//   rdür, озсл,   ,
  { {0x7c3b000a,0x85760015,0x98ab003d,0xdc3b000a}},	// [c600] _שתפס, لدائ, ījāt_, _בעקר
  { {0x2d8700b8,0xd5e0000b,0x8afb000a,0xfe790046}},	//   _jene_, नाइज, _ספיק, ipů_
  { {0xdce80048,0x91780092,0x299b0008,0x399b0135}},	//   vadī, _lợi_, _בסימ, _בייד
  { {0xc5e90008,0xb2a60015,0x3205055e,0x61e10034}},	//   וד_, لحته, _ally_, _anll
  { {0x213e0026,0xe7fb000b,0xcb89000a,0x877b000a}},	//   _syth_, _एकता_, רְעֹ, _באכי
  { {0xdb1d0595,0xfad7000a,0xa5650015,0x2d87515a}},	//   rdsø, יונך_, _هدفن, _nene_
  { {0x91f50023,0xf9930008,0xdce80024,0x4fc6070e}},	//   _tín, קרה_, radī, аспа
  { {0x61e108e0,0x44c801e2,0x289b0053,0xdee60015}},	//   _enll, _iş_, דיקא, لأخي
  { {0x539b013a,0x65690064,0x213e0026,0xa3cf005d}},	//   _שימו, _şehi, _wyth_, _वोट_
  { {0x64424acf,0xc27b0008,0x4426515b,0xdb06007c}},	//   lloi, _סרבי, lno_, nekõ
  { {0xd5d900b2,0xa5d90053,0x6ca3004a,0xb5fb004c}},	//   אַרש, אַרי, оряж, דליכ
  { {0x2d870111,0x4426515c,0xef1a3589,0x2c09002b}},	//   _eene_, nno_, _име_, اعدی_
  { {0x545700f3,0xcb47033d,0x6b960034,0x91780016}},	//   יסטן_, рхни, _ddyg, _gợi_
  { {0xd1260029,0x68fc0026,0xedd30115,0xcce60015}},	//   كم_, fyrd, _ويند, _نسبي
  { {0x7c940029,0xaa5c0036,0xb7fb000b,0x1177000a}},	//   _البص, терi, _एकदम_, שתלט_
  { {0x44260198,0xdb1d00dc,0x2d8c515d,0x4ccb000a}},	//   jno_, lesí, lade_, _יֶחֱ
  { {0x44c815e4,0xac07002b,0x442609cb,0xb4c10065}},	// [c610] _aş_, _مذکو, dno_, ्ट्_
  { {0x7afd00f2,0x7a3b0003,0x6442008c,0xdb1d0b31}},	//   myst, aîtr, eloi, nesí
  { {0x998a0091,0x937903ae,0x7afd28a8,0xd5b800af}},	//   albų_, гбет_, lyst, јсу_
  { {0x2d980050,0x4426515e,0x44240036,0x67f80030}},	//   órej_, gno_, оєча, _díjs
  { {0xf2c7010f,0xdb1d00dc,0x60da0064,0x44c81071}},	//   рсен, kesí, _artm, _eş_
  { {0xfa780008,0x13080036,0xdb1d00dc,0x0756000a}},	//   סעות_, шній_, jesí, _לסרט_
  { {0x2d8c11e0,0xc1980036,0x4426515f,0xdb1d0046}},	//   dade_, ртії_, bno_, desí
  { {0x2d8c007c,0x20060034,0x0ea900f4,0x2d873f01}},	//   eade_, _cloi_, гкий_, _sene_
  { {0x2d8c294e,0x97a8000a,0xee39113a,0xd131002b}},	//   fade_, בֹתֵ, лни_, _کما_
  { {0x41e40010,0x7afd1256,0xdb1d00dc,0x6499000a}},	//   _міха, dyst, gesí, ְיָה
  { {0x2d870020,0x11d40029,0x03d5000a,0xf532000a}},	//   _vene_, _بتقد, ֖וֹם_, ּ֥ת_
  { {0xc0b20092,0x20060034,0x7afd0c84,0x2fd40058}},	//   _lưới_, _gloi_, fyst, _وتنح
  { {0x2d8c0020,0xf41201ac,0xcb02000b,0xdb1d0030}},	//   bade_, לפט_, रैंड_, besí
  { {0x7f3a00b2,0x4999005f,0x5d85003b,0x4426515f}},	//   _גענו, ится_, _الثل, zno_
  { {0x44264013,0x09d50033,0x63bb09f5,0x1089004f}},	//   yno_, ццяў, _obun, טָּֽ
  { {0x7afd01cb,0x6c3600e6,0xfbd20015,0x23600f81}},	//   byst, _دفعا, _رتب_, žiji_
  { {0x7bc60c60,0x44260fdd,0x4b7b004c,0xc052000a}},	// [c620] meku, vno_, _גאפו, לזל_
  { {0x44260050,0x2ca5003e,0x7bc65160,0xc0b20016}},	//   wno_, ould_, leku, _cưới_
  { {0xc0b20023,0x09f70008,0x4426065d,0x78be01af}},	//   _dưới_, _המים_, tno_, _uppv
  { {0x7bc62cf3,0xa3b40484,0x2d8c5161,0xdb1d0f49}},	//   neku, іблі, zade_, zesí
  { {0x321c0089,0x73360015,0x2ca50b8e,0xcc3b004c}},	//   tivy_, حرائ, huld_, נענט
  { {0x3c320156,0x4426060b,0xda5a000a,0xe04a002b}},	//   rávy_, sno_, אכְל, گشته_
  { {0x7afd0050,0xa3e8005d,0x23690263,0xb97b00a3}},	//   zyst, बाद_, žaja_, אנצי
  { {0x4fc6005f,0xe8d7000a,0x7afd008c,0x6e980099}},	//   сска, מוצר_, yyst, авир_
  { {0xdb1d0014,0x2d8c5162,0x7e7b02f2,0xf5aa000a}},	//   tesí, tade_, gpup, ְבֹּ
  { {0x9e140036,0x27370092,0xade60001,0x27250092}},	//   ідні, ủng_, сцик, ặng_
  { {0x7afd0b90,0x2d8c0876,0x915e0016,0xa177000a}},	//   wyst, rade_, _dặm_, _העבד_
  { {0x7afd5163,0x2d8c5164,0x7bc65165,0xbea6116d}},	//   tyst, sade_, geku, _гадк
  { {0xdb1d00dc,0xa3ab005d,0x2baa000b,0xa7fb0077}},	//   pesí, _खास_, _कारा, _niña
  { {0x7afd5166,0x7bc6007c,0x601e003d,0xcee9009a}},	//   ryst, aeku, cīmr, _خرمن_
  { {0x195904f7,0x59f80063,0xddb7000a,0x7bc62ebe}},	//   равы_, щеря_, _הפופ_, beku
  { {0x8c190015,0x57790033,0x96eb02ed,0x0000006a}},	//   _خيبر_, рбаў_, льза_,
  { {0x68e800c0,0x6b7c0053,0xceb30053,0x7c2d003f}},	// [c630] äddr, _ערזנ, ּיע_, _ijar
  { {0xd5675167,0x7c2d001a,0xddca01d3,0x6aa00052}},	//   стап, _hjar, _kifő, ámfe
  { {0x69c700bd,0x7c2d0e05,0x20d80016,0x454b0004}},	//   meje, _kjar, _nĩi_, учам_
  { {0x3d09000b,0x6e3a01d7,0x69d55168,0x69c74704}},	//   ानते_, hotb, ldze, leje
  { {0x68e00048,0xa1890054,0x6d4e006f,0xc0b20016}},	//   āmde, абла_, ýbaj, _tưới_
  { {0x7bc6005c,0xdb04005c,0x6234005e,0x97420033}},	//   zeku, _zbió, печу, пiць_
  { {0xb5fb0264,0xd5b80484,0x2baa000b,0x7bc60573}},	//   _otáz, _уся_, _काला, yeku
  { {0x2ca50111,0xab5b007c,0x63bb5169,0x2911516a}},	//   vuld_, teül, _ubun, izza_
  { {0x442d0962,0xaff60015,0x8e090342,0x40120015}},	//   _ije_, تفيا_, инив_, بِيذ
  { {0x7c2d013c,0x69bb000b,0x442d008c,0xa19405a7}},	//   _ajar, श्मी, _hje_, _науч
  { {0x442d00bd,0x1ee70086,0xab5b007c,0x361a004c}},	//   _kje_, _گوشی_, seül, שותד
  { {0x7e7b008c,0x69d5516b,0x7f840058,0xab5b0072}},	//   ppup, edze, _فلمن, peül
  { {0x69c70014,0xdaba0010,0x02f90008,0x543a004c}},	//   feje, шыні_, ׁלֹמ, שערא
  { {0x201f0007,0x6d47001a,0x7d240030,0x7bc6516c}},	//   liui_, ýjas, átsá, seku
  { {0x7c2d0084,0x7bc6003f,0x798e0012,0x395e516d}},	//   _fjar, peku, rabw, äts_
  { {0xfc320806,0x201f0007,0xac170001,0x442d516e}},	//   _تحت_, niui_, _моју_, _nje_
  { {0x7c570029,0x6d430026,0x69c71e86,0xa3e8000b}},	// [c640] _بلير_, _hyna, beje, बास_
  { {0xbb1b0152,0xdcf80089,0xd8760015,0x7afb0012}},	//   raît, _nevě, _واجب, äute
  { {0xec130086,0x64c60015,0x201f0091,0x200d042f}},	//   _روید, تيال, kiui_, khei_
  { {0xfe670029,0x66e602c4,0x6d43516f,0xd3700058}},	//   _يد_, _дома, _myna, رهت_
  { {0x6e28002e,0xf773002b,0x442d42f6,0xa3df0065}},	//   yndb, _تاپ_, _dje_, ताज_
  { {0x6d430064,0x442d5170,0xa1870054,0x7acb000a}},	//   _oyna, _eje_, обља_, שֶׁ֧
  { {0xdcf80046,0xc0e70015,0x0ef4000b,0xb7da004f}},	//   _devě, قفون_, ेन्स_, ֹקִי
  { {0xdfda0063,0x78fb0053,0x8ca3000b,0x69c738bc}},	//   рък_, יפצו, _कमजो, zeje
  { {0x6d430061,0x66ba004f,0x8dea009b,0x0000006a}},	//   _ayna, ׁמֵה, афна_,
  { {0x22f7000a,0xa3e8000b,0x6d431d3e,0x6e280ffa}},	//   _וזמן_, बाव_, _byna, undb
  { {0xdb1d0089,0xb5820010,0x6d4306bd,0xbdf70015}},	//   desá, чнiк, _cyna, تريا_
  { {0x7ee6003b,0x69d5005c,0xa4b7000a,0x7e630012}},	//   _وكان, wdze, חלטה_, _einp
  { {0xbfa30092,0x6e3a00dc,0x9057000a,0x69c75171}},	//   _miề, potb, _ובאו_, teje
  { {0xd8770015,0x22be003d,0x6d430034,0x9e370015}},	//   قارب, mākā_, _fyna, _وسوء_
  { {0x22be0024,0x63ab2749,0x69c75172,0x29055173}},	//   lākā_, yggn, reje, ála_
  { {0x998300df,0x7c2d234d,0xbfa30016,0x80a20065}},	//   tojų_, _ujar, _niề, _गिने
  { {0x22be003d,0x356b09dd,0x2905427c,0x6d5c0052}},	// [c650] nākā_, арен_, šla_, ýraf
  { {0x6b8d3b2f,0xc4db0054,0x05b80015,0xe5070067}},	//   _heag, иђе_, قدمت_, يباي
  { {0xfa340029,0x6b8d013c,0xe3b10015,0xd370002b}},	//   _تريد, _keag, ّرت_, چهٔ_
  { {0x7c3d022d,0xd370002b,0x60cd002a,0x0000006a}},	//   nosr, نهٔ_, łamk,
  { {0x236900bd,0x8c1c000a,0xa294005e,0x44da006f}},	//   žajo_, סודי, дачі, _eď_
  { {0x7e6b0007,0xbb3c0053,0x6b8d5174,0xe47b0015}},	//   _rugp, בעדי, _leag, _نحرص_
  { {0xc5f201e4,0xa3e8000b,0xd1b80021,0x200d5175}},	//   _אדם_, बाश_, تانا_, thei_
  { {0xd3e30086,0x6b8d0011,0xa3b3000b,0xf41f07c2}},	//   _تقری, _neag, _जॉच_, _öä_
  { {0xa3e8014e,0xe1650086,0x201f0007,0x3ed20015}},	//   बार_, _فضای, riui_, فقير
  { {0x443d0041,0xee360080,0x90e70015,0xc1740021}},	//   low_, знь_, _وسان, _قدمت
  { {0xa7fb02c1,0x6b8d0541,0x201f0091,0x8c462205}},	//   _niño, _beag, piui_, зене
  { {0x00ba000a,0x60ba000a,0x22be003d,0x251a000a}},	//   _למעמ, _לצעד, bākā_, מותא
  { {0x6d43005c,0xcf270002,0x4a750033,0x7c2f0003}},	//   _wyna, _براي, дыст, ébra
  { {0xddc30024,0x433a000a,0x443d5176,0xde58005e}},	//   _minū, מערב, how_, _дачі_
  { {0xdb1d0057,0x69ad000b,0x9f44006f,0x443d2d40}},	//   resá, _जारी, ajmä_, kow_
  { {0x4c9a0008,0xdb1d0134,0x1bba0015,0xab5b007c}},	//   _השקע, desæ, _طابع_, keüh
  { {0x443d1647,0xdb22008c,0x0000006a,0x0000006a}},	// [c660] dow_, ätäy,   ,
  { {0x65690064,0x2baa0065,0xdb37004f,0x0000006a}},	//   _şehr, कलवा, _מנפח_,
  { {0x14c80074,0x69fb000a,0xc689000a,0xf9fb000a}},	//   تهای_, _הליק, רא_, _ההימ
  { {0x68e10134,0xddc2002a,0xd36f0015,0xf789016e}},	//   ælde, _stoż, ههم_, _voçê_
  { {0xc2970033,0xbfa30016,0xb2730033,0x7bd65177}},	//   зкіх_, _viề, еліш, _mayu
  { {0x7bd60035,0x7416002b,0x026900ce,0x0000006a}},	//   _layu, _کورا, ішій_,
  { {0xbfa30023,0x3d05005d,0xddc20007,0x443d2239}},	//   _tiề, शनों_, _nuoš, bow_
  { {0x22be0024,0xdb060030,0xde78005e,0x0000006a}},	//   tākā_, egkí, обич_,
  { {0x28ce000b,0xa0070015,0x7c3d00bc,0x62890034}},	//   _हैसि, ثقيل_, vosr, _gweo
  { {0xddcb01e2,0xab5b00dc,0xdd900067,0xddc2002a}},	//   ğişt, lfüg, خود_, _utoż
  { {0x61e800fb,0x25ed005d,0x8eda0086,0x6b8d0020}},	//   _indl, घाती_, _گذار_, _peag
  { {0x10160002,0xab5b04de,0x6e210030,0x61fa5178}},	//   _عباد, nfüg, ailb, _hotl
  { {0xcff7000a,0x319f003d,0x7c3d0030,0x3e06006b}},	//   _מצאה_, bāzē_, rosr, _някв
  { {0xaa645179,0xe805000b,0xcf250040,0x3e340015}},	//   етск, रस्थ_, _ترمي, _تفتر
  { {0x6b8d002f,0x7c3d0796,0x5dbb000a,0xf8070788}},	//   _teag, posr, _הזוה, пчан
  { {0x7bd600b6,0x99980089,0x2ca3006f,0xbd290015}},	//   _gayu, borů_, ájde_, _بأهل_
  { {0x6bd40015,0x2bb80015,0xc56b0040,0xbbc9000b}},	// [c670] _ستير, _راية_, محال_, िजीक
  { {0xf8ae0086,0x2d8e02c1,0x61fa08f5,0xfc3f0125}},	//   دکی_, _jefe_, _notl, loí_
  { {0xf9fc0008,0x7bd601d7,0x443d517a,0x19ba004f}},	//   _להזמ, _yayu, tow_, _ומתב
  { {0x4ab1000b,0x9f4f006f,0x6d39000a,0x9554002b}},	//   _जमाव, _logá_, חֲנו, رخلا
  { {0xe3b00086,0x63a400dc,0x443d1a0b,0xb7da000a}},	//   ارم_, óina, row_, _וקרי
  { {0xa925006f,0x746b279e,0x61450082,0x02040033}},	//   poľč, _грав_, мела, нзін
  { {0x99980046,0x61fe007c,0xdce1003d,0xdb1d0123}},	//   zorů_, öpla, rblī, lesä
  { {0xddc20007,0x61e80334,0xa3d4004a,0x200b002a}},	//   _ruoš, _endl, _посч, óci_
  { {0x3e7204f9,0x7bd6517b,0x6e212315,0xef191ebd}},	//   _cât_, _rayu, tilb, юми_
  { {0x7bd60509,0x99980046,0xddc20091,0xd1bb006e}},	//   _sayu, vorů_, _puoš, _دارا_
  { {0x82340029,0x7bd6088a,0x0576004f,0xb5fb039f}},	//   _أرقا, _payu, וגתם_, _huás
  { {0xea010023,0x3c1a0010,0x99980089,0x6e21517c}},	//   _đạt_, іўня_, torů_, silb
  { {0xa3ab000b,0x6008000a,0x61e8063b,0xdb1d008c}},	//   _खाई_, _מִסְ, _yndl, jesä
  { {0x69d7016e,0x186a16e7,0x99f50033,0x0000006a}},	//   _caxe, жави_, нясі,
  { {0x2d850493,0x7d7a000a,0xd138002a,0xd9432de6}},	//   mble_, _ונצו, _idąc_, вери
  { {0x7b070014,0x2be4000b,0x6c360058,0xc84a004e}},	//   örté, गाओं_, _تعتذ, іпаж_
  { {0x6beb011f,0xdb9b000a,0x4b26005e,0x1666006b}},	// [c680] _וַיַ, _וספר, _імов, двам
  { {0x2ca50388,0x4d7a004c,0xeb9f02de,0xd65c0033}},	//   orld_, ַרנע, nkøn_, пiск
  { {0xf2410010,0x2e3a0053,0xfc17002b,0x136a517d}},	//   _якiя_, קגענ, _رقیب_, ошли_
  { {0x730a0029,0x3f8f0007,0x2bc1000b,0xf7720015}},	//   يقاف_, _negu_, ष्पा, _جاد_
  { {0x69bb014e,0xab5b018b,0x61fa517e,0xe2970822}},	//   श्वी, rfüg, _potl, дач_
  { {0xc5d50010,0xd2500087,0x3217002b,0x35f4000a}},	//   _пісь, دنت_, ويند_, _אֶֽל_
  { {0x6d47007c,0x91e30054,0x61fa517f,0xab5b0030}},	//   üjal, тоје, _votl, pfüg
  { {0xf8b30008,0x4422379f,0xc953000a,0xa3ab000b}},	//   דשה_, _ök_, כמו_, _खाए_
  { {0xf65f0bfa,0xdb1d2749,0xa2d5000b,0x28d5000b}},	//   _især_, ldsö, _मैप्, _डैनि
  { {0x61e80134,0x42fb000a,0x12fb000a,0x6d4f002a}},	//   _undl, _והמס, _והמב, ęcan
  { {0x62820020,0xe0d20115,0x6aa6001a,0xdb1d0a88}},	//   lpoo, _جزء_, erkf, ndsö
  { {0x2fd70015,0x6c080015,0x2d851915,0xb5fb20aa}},	//   _يولد_, ِيَّ_, able_, _juár
  { {0x2d855180,0x1b4b0015,0xfc3f0125,0x8eb30058}},	//   bble_, تؤدي_, roí_, _لمنش
  { {0x7e7d002c,0x69c00030,0x66d801d3,0x0000006a}},	//   íspe, őmen, zúká,
  { {0xa3de000b,0xa2d5000b,0x6cd40015,0x3a230079}},	//   तया_, _मैन्, _أقبا, rijp_
  { {0xa3b3005d,0x7b670579,0x4c9b000a,0xdb1d008c}},	//   ज्ञ_, _отпе, _ובהו, tesä
  { {0xa3e8000b,0x9c580015,0x69d75181,0x7a290091}},	// [c690] बाई_, _تجوز_, _taxe, ežte
  { {0xc618005e,0x454b0e4d,0x6f4b004f,0x62820546}},	//   мієш_, очем_, חֲבַ, dpoo
  { {0xf7950010,0xdcfa003d,0xdb1d007c,0xd49b058c}},	//   _панэ, matē, sesä, юра_
  { {0x62840048,0x387e0125,0x23d40033,0xc6a701cf}},	//   ģion, ítre_, кцір, _орги
  { {0x628404f9,0xc2cb0086,0x7c2f0003,0xb3840033}},	//   ţion, تبال_, incr, тліл
  { {0x2cac00cb,0x3f8f007c,0x8234002b,0xeab2000a}},	//   kudd_, _segu_, پرها, רֹא_
  { {0x61420004,0x3ced000b,0x62820072,0xd4980132}},	//   леша, _छपें_, apoo, _орт_
  { {0xf441005e,0xb5fb0077,0x82d500ce,0x2cac0416}},	//   _собi_, _guár, _побє, dudd_
  { {0xe2350001,0xd7ba000a,0xdee5005e,0x3f8f001a}},	//   _знањ, הֶיך, хопи, _vegu_
  { {0x273e00a7,0x272c0023,0x7995003f,0x2d850493}},	//   ững_, ếng_, jazw, uble_
  { {0x3f8f0020,0x442f5182,0xc5f2000a,0x3519000a}},	//   _tegu_, ong_, אדי_, פוֹנ
  { {0xa1280015,0xe4a8000a,0xf3f90045,0x442f5183}},	//   _تكمل_, וֹשָ, _biţi_, nng_
  { {0x644b01e2,0xef0e05ae,0x1e8402e1,0x8416000a}},	//   ilgi, _см_, _алім, תקרב_
  { {0x2cac0026,0x2fcd016b,0x6f1d0f14,0x4efa000a}},	//   budd_, leeg_, úscu, _מהנו
  { {0xe4800064,0x98560004,0xaa030015,0xa85601ca}},	//   örüş, еташ, دِّي, етај
  { {0xad1a0008,0xf3f90011,0x2fcd0034,0x68e1001a}},	//   _מוצר, _fiţi_, neeg_, ælda
  { {0xe7370080,0xab660294,0x8cd7000b,0x442f02f2}},	// [c6a0] еет_, _явил, यिको, dng_
  { {0x7c260635,0x2bc1000b,0x442f5184,0xf62a0015}},	//   likr, ष्ठा, eng_, أسرى_
  { {0xe4750010,0x7bda000a,0x546a055f,0x20d10091}},	//   вучэ, ּקְו, чаем_, _nši_
  { {0xa87b0053,0xdb1d00c0,0x69dc0474,0x1c10000b}},	//   _מאטר, rdsö, ldre, ासिल_
  { {0x741300c3,0xeb93000a,0x7469005e,0x20d10b28}},	//   دونا, רָע_, єрєв_, _aši_
  { {0xf50a0001,0x4a9b0135,0x69ce5185,0xcb37004c}},	//   _енгл_, לינג, nebe, ענסק_
  { {0x3ce9005d,0x69dc5186,0x62820c3e,0x30a3056d}},	//   टमों_, idre, spoo, грыв
  { {0x69ce00b8,0xf957000a,0xa06703ae,0x7ae40073}},	//   hebe, עסקת_, наја_, _orit
  { {0x61eb03c0,0xcf260196,0x69ce1c08,0x765e003f}},	//   állí, عربي, kebe, ompy
  { {0xe29b000a,0x44265187,0xfe6f0015,0x60330045}},	//   _משמר, lio_, حدي_, răma
  { {0xf48e0036,0x26d20026,0x69dc5188,0xb55a005e}},	//   алiв_, hwyo_, ddre, олiт
  { {0x2cac003c,0x644200dd,0xa2d5000b,0x1beb000b}},	//   rudd_, nooi, _मैड्, टाइल_
  { {0xdcfa0024,0xdfcf0031,0x7ae430c5,0xab0b0015}},	//   tatē, _دين_, _crit, ستحق_
  { {0x69ce018b,0x7ae400b8,0x44265189,0x26d20026}},	//   gebe, _drit, hio_, dwyo_
  { {0xdcfa0024,0x8ddb0008,0x7ae40356,0x9e650086}},	//   ratē, _זקוק, _erit, _شاهن
  { {0x44260f58,0x67d40142,0x69dc2abe,0x23690b28}},	//   jio_, лосу, adre, žaji_
  { {0xb5a7007a,0x44262bb1,0x4c54012c,0x7ae4153b}},	// [c6b0] ерей, dio_, _حضور, _grit
  { {0x442f0176,0x69ce03af,0x4426016e,0x7bcf2574}},	//   wng_, cebe, eio_, lecu
  { {0x44260176,0xdcf80048,0xe5c40010,0xd4e409ef}},	//   fio_, _ievē, ысто, люци
  { {0x7ae4022d,0xf1d9005d,0x7bdd438e,0xc952000a}},	//   _yrit, _योजन, ndsu, _כמי_
  { {0xed460086,0x24580010,0x026b004a,0xba3b0144}},	//   _چپ_, хаць_, чшей_, buït
  { {0xc6920053,0x2fcd00dd,0x7bcf0125,0x6abd0012}},	//   _דאך_, weeg_, hecu, itsf
  { {0x8c3d0064,0xe588000a,0x6299162d,0xd24e0015}},	//   luğu, _רָשָ, sswo, غنى_
  { {0xa2d5000b,0x7bcf0077,0x50580033,0x387c0030}},	//   _मैथ्, jecu, ншыя_, _évre_
  { {0x6d4f002a,0x2fcd0079,0x6d4a0061,0xd1cb004a}},	//   ęcam, reeg_, _ayfa, _нужд_
  { {0x7d090124,0xdcf80024,0x1cb90015,0xee390004}},	//   дног_, _nevē, واجب_, ќно_
  { {0x7c2600df,0x6d4a0176,0x7ae400df,0xa2d5000b}},	//   tikr, _cyfa, _srit, _मैत्
  { {0xa6db002e,0x6d4a0026,0xab2a0484,0x212a002b}},	//   _eyði, _dyfa, дома_, _تيمی_
  { {0x539a000a,0x501a000a,0x7fb60015,0x765e008c}},	//   וירו, _קונו, _شهور_, ympy
  { {0x8c3d01e2,0x4426518a,0x4a4300a4,0xf1c4000b}},	//   duğu, zio_, иняв, ल्पन
  { {0x6d4a0176,0xe800005d,0x7ae427d7,0x290c0107}},	//   _gyfa, ैसला_, _writ, áda_
  { {0xea010023,0x98630015,0x7ae4518b,0x69ce518c}},	//   _đất_, لُّه, _trit, sebe
  { {0xcf9200b2,0xf62a0029,0x7c24002d,0x78bc0085}},	// [c6c0] יטן_, وسطى_, _imir, strv
  { {0x44260026,0x26d20034,0x45831453,0x80a20065}},	//   wio_, rwyo_, игув, _गिले
  { {0xe3ba0001,0x442614d9,0x6442518d,0x6603005b}},	//   дбе_, tio_, tooi, önka
  { {0x64a30010,0x8c3d0064,0xff47002b,0xba3b0144}},	//   раца, buğu, _نخ_, suït
  { {0xc7b3011f,0x93430724,0x8c3d0061,0x69c10144}},	//   _דבר_, анце, cuğu, òleg
  { {0x4426518e,0xb0c6004a,0x6d4f002a,0xa1581398}},	//   sio_, вщик, ęcaj, налу_
  { {0xa3dd005d,0x4426518f,0x43860015,0xe1230054}},	//   _थोक_, pio_, _للأق, имљи
  { {0x4fd430d1,0xa3e8000b,0x61430054,0x4fc608b0}},	//   ужит, बाओ_, јећа, тска
  { {0x628000da,0xb2c5006e,0xd1b2002b,0xdb06007c}},	//   _utmo, _مغلو, _نیشک, ngkä
  { {0xdb250089,0x531b0008,0x7c245190,0xdb1d0030}},	//   ásít, _חומצ, _amir, pesú
  { {0xab95005e,0x9b950e4b,0x6fb60058,0x0000006a}},	//   лині, линц, _لمضا,
  { {0xc00605e6,0x907b000a,0x442401d7,0x6abd5191}},	//   _шпек, _חטאי, _jmm_, ttsf
  { {0x7bcf2999,0x7a290091,0x7bdd5192,0x386023f0}},	//   recu, ežta, rdsu, dmir_
  { {0x386b0026,0xecba0015,0x7bcf4374,0x9e34004a}},	//   _sicr_, _قطعت_, secu, _щелч
  { {0xef19005c,0x19940afb,0xe919005e,0x9928006b}},	//   daży_, рася, хові_, вюта_
  { {0x80ba005d,0x0137000a,0x58840033,0x50db000a}},	//   _एमने, דרלת_, рыра, וקלא
  { {0xec38000a,0x7a290091,0xdc6c000a,0x96350aa1}},	// [c6d0] _שאחר_, ažta, _ק֣וֹ, гнац
  { {0xa5670086,0x8b08000a,0x6e280085,0x0614008b}},	//   ندان, _יִתֵ, nidb, адую
  { {0xd3710196,0xd5b80063,0x14740021,0x7d080034}},	//   مها_, ъст_, لانج, nyds
  { {0xa924032c,0xfbdf016e,0x60150046,0xd78b0015}},	//   ôžet, ndê_, _káme, _تخدم_
  { {0x59c0000b,0xeabf02b9,0xc2c50015,0xc2eb0015}},	//   श्वर, ntù_, ايتي, بعام_
  { {0x26d903af,0x471a000a,0xddc30045,0x2002001a}},	//   _isso_, _טורג, _minţ, ökin_
  { {0x046702bf,0x40940033,0x34780033,0xdcfa0091}},	//   _атам, арыт, _абсэ_, matė
  { {0xdb1d0bfa,0x2958000a,0xf958000a,0x60330045}},	//   besø, כסוך_, כסות_, rămo
  { {0xfe450083,0x2f54087a,0x6015002c,0x6449008c}},	//   лнио, итьс, _náme, _ikei
  { {0xdcfa0007,0x8ca4000b,0xee360088,0x7c245193}},	//   natė, _किशो, лны_, _smir
  { {0xd00e002b,0x38603993,0xcb09000a,0x3c6632b1}},	//   زلی_, ymir_, _צל_, лког
  { {0x236901a3,0xde950054,0x26d90eef,0x8ca40065}},	//   žaju_, _бадњ, _osso_, _किरो
  { {0x645b002d,0x8f9a000f,0x2ee65194,0x5ea50058}},	//   _mhui, _ניסי, _grof_, _إمتل
  { {0x2fc6010b,0xdcfa0007,0xddc30045,0x2dd90015}},	//   _zbog_, jatė, _dinţ, _سبتة_
  { {0x485a0010,0x6449008c,0x35c6000b,0x07a60b27}},	//   ераў_, _okei, र्फ़, лавн
  { {0x3860001a,0x7c245195,0x200d1351,0x05c60065}},	//   umir_, _umir, nkei_, र्नब
  { {0xdc3b004c,0xf71a0033,0xe7290015,0x3ebf35ef}},	// [c6e0] _רעפר, хівы_, نسكو_, ntut_
  { {0x64490091,0x442401c2,0xa76302a3,0x60150030}},	//   _akei, _smm_, скуд, _jámb
  { {0x26d904ed,0x645b002d,0x75d30015,0xf769000a}},	//   _esso_, _bhui, إيما, פק_
  { {0x645b017e,0x1957000a,0x290a0091,0x7469005e}},	//   _chui, _תבטל_, myba_, врів_
  { {0x14170029,0x645b002d,0xdcb10092,0x244e0107}},	//   دينة_, _dhui, hủ_, nými_
  { {0x8ca4005d,0x27e05196,0x70b40058,0x26c05197}},	//   _किलो, ldin_, لمتض, mtio_
  { {0x645b002f,0x14d80008,0x69de5198,0x26c00ec8}},	//   _fhui, _בַּמ, _mape, ltio_
  { {0xa6db002e,0xb4c2005d,0x244e0057,0x27e05199}},	//   _eyðu, ्बी_, kými_, ndin_
  { {0xa0670001,0x60e00007,0x26c0519a,0x539b000a}},	//   ћања_, _žymė, ntio_, _רימו
  { {0x601501b2,0x26c026c6,0xb6bb004c,0x27e00696}},	//   _ráme, itio_, עציי, hdin_
  { {0x85f700b2,0x765c0026,0x3d0e000b,0x6b96199a}},	//   אציע_, _mhry, ानें_, _beyg
  { {0x290a0007,0x3157004c,0x26c0008c,0x7d0802de}},	//   dyba_, _גיבן_, ktio_, ryds
  { {0x34d1014e,0x6f1b005c,0x9057000a,0x7d1a0030}},	//   _सन्द, czuc, _עבדו_, szts
  { {0x2b930074,0xdddb0024,0xeabf04ed,0x765c0034}},	//   جیکس, ppuš, rtù_, _nhry
  { {0x7d7b0053,0x4d7b000a,0xcd97000a,0x7d0e02de}},	//   _אנוו, _ארוע, _גדות_, øbsd
  { {0x6c830029,0xf77300e6,0x6d58519b,0x515b000a}},	//   _اليم, صار_, _izva, תכלו
  { {0x47340029,0x25ab0054,0xdcfa0091,0xe78402ed}},	// [c6f0] مركز, еђен_, tatė, сусо
  { {0x645b002f,0x60da0020,0x765c519c,0x6449519d}},	//   _shui, _ostm, _chry, _skei
  { {0x6a140086,0x93270086,0xb97a000a,0x03950033}},	//   _دبير, گران, _בנתי, арля
  { {0x69de28a5,0x78fa0008,0x3ebf002a,0xd7fb0054}},	//   _zape, _ספרו, ytut_, _чуо_
  { {0x69de02e8,0x8c1c000a,0x92b70015,0x60da0c86}},	//   _yape, עודי, احصا, _astm
  { {0x7bdf0152,0x4a7c000a,0x80e50015,0x46680033}},	//   _laqu, ערוב, لأعل, _брсм_
  { {0x3d0e014e,0x645b1395,0xbf0d005d,0xe4e40036}},	//   ानों_, _thui, िन्न_, _літн
  { {0xdb1d002e,0x92b70029,0x7bdf48a1,0x6f1b0028}},	//   efsí, _محطا, _naqu, tzuc
  { {0xddcb0048,0xcdf5054f,0x6f62006b,0x200d0012}},	//   _augš, ачны, овъз, rkei_
  { {0x6f1b0050,0x200d00dd,0x244e0227,0x3ebf519e}},	//   rzuc, skei_, vými_, rtut_
  { {0xd131003b,0xc0d50086,0x3ebf0604,0x6b963ec2}},	//   _بما_, _خياب, stut_, _peyg
  { {0xc1040002,0x6b660608,0x69de519f,0x244e0057}},	//   _دومي, икна, _sape, tými_
  { {0x7bdf001c,0x63a4002d,0x2cac0034,0x03d6000a}},	//   _daqu, óini, ardd_, בורם_
  { {0xc332011f,0xacf50087,0x3ead1156,0x245c0046}},	//   קום_, _نسبت, mret_, míme_
  { {0xc8660029,0x779600d7,0x69de51a0,0x7cc40015}},	//   لطري, ијац, _vape, _هزيم
  { {0x6ca40086,0x69de016b,0x290a0c89,0x22470079}},	//   _اصول, _wape, ryba_, honk_
  { {0xdce101e2,0x765c51a1,0x245c0107,0xd7f70016}},	// [c700] malı, _phry, níme_, ỡng_
  { {0xba9b000a,0xaa9b000a,0x6a9b000a,0xa926004a}},	//   _שסיי, _שביכ, _ששינ, _вдол
  { {0x26c051a2,0xb4c2000b,0x799c0034,0x3ead0359}},	//   stio_, ्बे_, marw, hret_
  { {0xdce10064,0x987b0053,0x3ead51a3,0x799c00a9}},	//   nalı, _שאכט, kret_, larw
  { {0x73360029,0x3ead0134,0x331a002b,0x765c0034}},	//   جرائ, jret_, خزاد_, _thry
  { {0x5bd3014e,0x2cac0026,0xa6db002e,0x3ead0293}},	//   _तस्व, yrdd_, _eyðs, dret_
  { {0x463b00b2,0xdce10064,0xf9930008,0x7d070134}},	//   _סעלע, kalı, חרו_, øjsl
  { {0xcfe80086,0x63bb002d,0x60150107,0x3ec6042b}},	//   افظه_, _gcun, _rámc, асоб
  { {0x2cac0176,0xdefa0892,0x3ead35d9,0xdce10061}},	//   wrdd_, тый_, gret_, dalı
  { {0xe731000a,0x59b2000b,0xa282002b,0x4e330015}},	//   לֵי_, _जागर, _هیچو, ْعَز
  { {0x05770008,0xa17b0135,0x5577000a,0xd657000a}},	//   יגים_, _סטאט, יעין_, שיית_
  { {0xdcfa0024,0xa08b000a,0x245c04b2,0xac270054}},	//   latī, _סְבִ, bíme_, рфок
  { {0x799c0176,0xc053000a,0x6ffb000a,0x50650015}},	//   farw, _וזף_, _שהדפ, _اطلق
  { {0x5d840029,0x799c0026,0xad26002b,0x5a470033}},	//   _الغل, garw, _پرتو, рэма
  { {0x60150084,0x6e3d00dc,0xf7730029,0xdce10064}},	//   _háma, ésbe, قاذ_, balı
  { {0x20d80092,0xbeb70046,0xdce10061,0x68e8001a}},	//   _mũi_, šíře, calı, ædda
  { {0xdcfa0048,0x799c002a,0x1bb8002b,0x78ae003d}},	// [c710] katī, barw, _ضايع_, arbv
  { {0x6a240015,0x79a71e48,0x63bb11ff,0xc56b002b}},	//   _وفيم, _трие, _scun, نحال_
  { {0x245c0227,0xf992000a,0x437500c3,0x69d551a4}},	//   zíme_, _מרי_, مهار, meze
  { {0x25fb005d,0xd8d6000a,0xddc20091,0x6b9d003d}},	//   लॉजी_, _פורט_, _nuož, nasg
  { {0x77f6000a,0x60150069,0x0000006a,0x0000006a}},	//   _המרד_, _náma,   ,
  { {0x42240036,0xdcfa0024,0xdd2b0007,0x245c0057}},	//   одів, gatī, _lėša, víme_
  { {0x6b9d0024,0xdce10064,0x69d50079,0xf48451a5}},	//   kasg, yalı, ieze, _мутн
  { {0x29380008,0x89380008,0xb9380008,0x69d516a6}},	//   יאון_, ירוע_, ירוג_, heze
  { {0x601502c1,0xe1f30115,0xc7b4000a,0x69d551a6}},	//   _cáma, _وسط_, קבץ_, keze
  { {0x69d500dc,0x245c002c,0xab5b0012,0xfe42005e}},	//   jeze, ríme_, rfül, зньо
  { {0xa5da0053,0x7fb90086,0x69d516a6,0x245c0107}},	//   אַכי, _مهار_, deze, síme_
  { {0x3205003e,0x3ead0134,0x61e11b61,0x6b9d1349}},	//   _holy_, pret_, _hall, gasg
  { {0x20c10014,0xdce10064,0xdce70064,0x8e8551a7}},	//   lói_, ralı, ılık, _الته
  { {0x69d551a8,0xfce90015,0x7d100030,0xbdf8002b}},	//   geze, _مفتي_, öksé, _پرها_
  { {0xfbdf03af,0xf7720029,0x61e151a9,0xc172000a}},	//   glês_, كاء_, _mall, לחם_
  { {0x998c002a,0xc9550033,0x0000006a,0x0000006a}},	//   ódł_, ітры,   ,
  { {0x8c1b0008,0x3f7a0053,0xc5760015,0x06ea0033}},	// [c720] _תופי, אָבע, مطاع, ымак_
  { {0xc1e1000b,0xb5a90015,0x20c10030,0x49960923}},	//   पयोग, لامك_, kói_, _ушит
  { {0xd9100086,0x1828002b,0xcd9a004c,0xa3ea006b}},	//   _غیر_, _نقدی_, רױער, лджа_
  { {0xad360053,0xdb0d0020,0xdb1d1506,0x61e1008c}},	//   זנעס_, _ebaõ, cesó, _aall
  { {0x6a6000b8,0xdcfa0024,0x18470008,0xddc20091}},	//   röff, tatī, _לְךָ_, _ruož
  { {0x61e151aa,0x6015006f,0x6a600012,0xc693004f}},	//   _call, _ráma, söff, _מאש_
  { {0x859b013a,0xdcfa0024,0x61e1052a,0x10e6006b}},	//   _תשלו, ratī, _dall, сюлм
  { {0x9ee80029,0x68e1193d,0x6537000a,0x889b000a}},	//   لفعل_, ældi, _האלף_, אבקי
  { {0x91ba0029,0xdcfa0024,0xadd80054,0x69d50030}},	//   _مطار_, patī, ампу_, yeze
  { {0x2d98002c,0xc27b000f,0x61e10495,0x4d98005e}},	//   úre_, _ערבי, _gall, шкою_
  { {0x35cf005d,0x69d551ab,0x27370264,0x9c390004}},	//   _सॉफ़, veze, ožné_, ипот_
  { {0x69d5199e,0x601500dc,0x806603ae,0xdb1d0980}},	//   weze, _táma, _увеж, pesü
  { {0x6e460010,0x69d50946,0x61e101f9,0x39ba0535}},	//   _ледз, teze, _yall, ząsł_
  { {0x7f3b0053,0xbed7000a,0x4c940d3e,0x4b540058}},	//   _געדו, _לודז_, _дикс, سَّر
  { {0x5d9b0008,0x6b840026,0xe918005e,0x5e57004c}},	//   _גבוה, _ffig, борі_, _היגע_
  { {0xb901005d,0x0855022a,0xfc65002b,0xa715005e}},	//   _धन_, іваю, _بختی, омбі
  { {0x2d9e04f9,0xdb1d005c,0x8cd4000b,0x20c10030}},	// [c730] oate_, resó, यौरो, zói_
  { {0xdb0400b8,0x7aed51ac,0x9567004a,0x69c8007c}},	//   _heiß, _irat, бъед, õdet
  { {0x4d7b00b2,0xe4d500e5,0x2d9e0045,0x98c70033}},	//   ארבע, تقاد, iate_, _успл
  { {0x2006020a,0x4cbb0053,0x61e151ad,0xb47c005e}},	//   _nooi_, רמאג, _sall, укцi
  { {0xe1f0002b,0x61e108b2,0xdb040012,0xf2c70888}},	//   کسن_, _pall, _meiß, ссен
  { {0x20890063,0x20c100dc,0x1a9c0053,0x2d9e51ae}},	//   айки_, tói_, ריגע, jate_
  { {0xa9bc000a,0x61e1074e,0x60190054,0xc198005e}},	//   אזור, _vall, ицир_, стії_
  { {0x1e85009c,0x600914f4,0xc918000a,0x61e11741}},	//   олим, рним_, מחות_, _wall
  { {0xd5c6005d,0xbe39005e,0x4dd5005e,0x61e151af}},	//   र्वज, ичої_, оінф, _tall
  { {0xd0d50063,0x442f153c,0xd1b80015,0x2d9e51b0}},	//   _мозъ, lig_, _هاما_, gate_
  { {0x63a40084,0x6d4601e2,0x7aed04f9,0x02440015}},	//   ðing, şkan, _arat, _عَمَ
  { {0x200600dd,0xae1d005d,0xf989000a,0x442f51b1}},	//   _gooi_, योजन_, _יר_, nig_
  { {0xab5b00b8,0x2d9e51b2,0x6a600012,0x7aed0738}},	//   nfüh, bate_, höfe, _crat
  { {0x2d810005,0xe81c005d,0x442f51b3,0x2d9e51b4}},	//   _ühe_, नसभा_, hig_, cate_
  { {0xab5b00b8,0xd7f20015,0x7de40021,0x442f51b5}},	//   hfüh, وكس_, _رسوم, kig_
  { {0x442f00bd,0x3ff90053,0x7aed51b6,0xdb040012}},	//   jig_, ספּע, _frat, _geiß
  { {0x644b0026,0x7aed51b7,0x245c006f,0xaa7b04b2}},	// [c740] dogi, _grat, jíma_, jvýh
  { {0x75d60015,0x05760015,0xb5aa0015,0xf65600fd}},	//   تيطا, زائد, شاطك_, ітаю
  { {0x1600005d,0x442f51b8,0x60150107,0x2bc1000b}},	//   लॉगर_, fig_, _námo, ष्का
  { {0x2d9e04f9,0x3d0a005d,0xab5b0012,0x442f51b9}},	//   zate_, ाहते_, ffüh, gig_
  { {0xa2940010,0x200600dd,0x63a9173a,0x0cb6000b}},	//   чалі, _rooi_, _dden, _अम्म
  { {0xaab2005d,0xcb130008,0x2d9e0011,0xfe670087}},	//   _जिनक, ולד_, xate_, _زد_
  { {0x61140036,0x2d9e51ba,0xb1170015,0x442f51bb}},	//   ядку, vate_, يقها_, big_
  { {0x2d9e005c,0xa2d5005d,0xd0070001,0x644b4330}},	//   wate_, _मैक्, жеће_, cogi
  { {0x601c00dc,0x2d9e0939,0xe423002b,0xa0070015}},	//   _néme, tate_, _تکلي, تقيل_
  { {0x70f600e6,0x27370016,0x36f70643,0x63a9036e}},	//   _وسائ, ầng_, קצים_, _zden
  { {0xdca3000d,0xa177000a,0x2d9e1a5f,0x5d540239}},	//   маќи, _ועבד_, rate_, якот
  { {0x6e18002b,0x60d6002a,0xc334000a,0x2d9e51bc}},	//   _گيتس_, łyms, ֜וֹ_, sate_
  { {0xc334000a,0xaf36012c,0x2d9e51bd,0x6015022f}},	//   לוֹ_, _برات, pate_, _zámo
  { {0xdb0400b8,0x442f0ec2,0x7aed51be,0xda670021}},	//   _weiß, zig_, _vrat, تاجي
  { {0x69c301e2,0x19590010,0xf8072c52,0x7aed51bf}},	//   _önem, савы_, очан, _wrat
  { {0x442f00c0,0x58d4005e,0x3ea60123,0x7aed51c0}},	//   xig_, ьост, _kvot_, _trat
  { {0x7c2d003f,0x66074d39,0x442f51c1,0x7aed51c2}},	// [c750] _imar, _pojk, vig_, _urat
  { {0x644b0026,0xa2d5000b,0x442f51c3,0xab5b02ad}},	//   wogi, _मैग्, wig_, vfüh
  { {0x89da000a,0x59c4000b,0x644b51c4,0x442f3a7e}},	//   _החתי, _लॉटर, togi, tig_
  { {0x245c002e,0x3cfb000a,0x0d3b004c,0xab5b0012}},	//   tíma_, ילבנ, סגאב, tfüh
  { {0x2458008f,0x386902ce,0x442f35c6,0x644b51c5}},	//   цаць_, mmar_, rig_, rogi
  { {0x442f51c6,0x867a0008,0xab5b00b8,0x2d9c51c7}},	//   sig_, _לרשו, rfüh, _neve_
  { {0xb882099c,0xab5b00b8,0x43952ed2,0x25a10353}},	//   žíva, sfüh, _навс, mahl_
  { {0x63a951c8,0x63f70015,0xa93c000a,0x601519fe}},	//   _uden, _بأسر, יתופ, _vámo
  { {0x442d065d,0x6d460064,0x443f51c9,0xb7fc000a}},	//   _ime_, şkal, _iju_, שפחת
  { {0x601532c9,0x7c2d51ca,0x0000006a,0x0000006a}},	//   _támo, _amar,   ,
  { {0x2d9c2f76,0xad240058,0x61ee039f,0x443f0160}},	//   _deve_, ِرُو, _óbla, _kju_
  { {0xca29013a,0x2fe40015,0xe61f006f,0xfb850138}},	//   _גם_, _يكلف, _stôl_, дыён
  { {0x442d4532,0xddca0046,0x3f7a004f,0x0000006a}},	//   _mme_, řiše, _האנס,
  { {0x7c2d0152,0x6e920054,0x89f50033,0x60330045}},	//   _emar, _џију, мясц, rămu
  { {0xfe7004b6,0x8dfa0008,0xf8b10029,0x395e00c0}},	//   _شده_, _להסת, َةِ_, åts_
  { {0xbb46008f,0x443f016f,0x068602bb,0x4ac60015}},	//   _нейк, _nju_, зган, _فيبق
  { {0x25a10012,0x8c1b000a,0x28130015,0x0000006a}},	// [c760] fahl_, _לוקי, روكس,
  { {0x7c2d005c,0x443f007c,0x386951cb,0xa3e4000b}},	//   _zmar, _aju_, amar_, _भोज_
  { {0x7c2d0026,0x397b0008,0x18a30010,0xa97b000a}},	//   _ymar, _לטינ, _паэм, _לאיכ
  { {0x97da0029,0xe4520002,0x8d48000a,0x394d0045}},	//   _ابدأ_, رضا_, חֲנֵ, şesc_
  { {0x201f003f,0x2bc1000b,0xfbc10065,0xc7b3004f}},	//   dhui_, ष्टा, ष्टम, _אבר_
  { {0x64a61507,0xcb37004f,0x521300ce,0x442d51cc}},	//   _нага, האני_, ндіт, _eme_
  { {0xc103002b,0xdb060030,0x672451cd,0xd1300058}},	//   فووي, egkü, lzij, ضمة_
  { {0xd010003b,0x853b0008,0xdfda0063,0x70dc000b}},	//   ئلة_, _הגלי, сък_, _मनील
  { {0x04434dbf,0xc7d7000a,0x64430140,0x93fb000a}},	//   _четн, לוקי_, énie, _פלמי
  { {0xab5b08e0,0x531b000a,0xa2d5000b,0x63a20125}},	//   ngüe, _הומצ, _मैट्, laon
  { {0x78450091,0xc5f305bd,0xcfaa0040,0x38690034}},	//   lėve, גדת_, _هاشم_, ymar_
  { {0x63a2000c,0x25a1018b,0x807b0008,0x70fb0008}},	//   naon, zahl_, _הנאצ, _להבח
  { {0x2d9c001c,0x69c30061,0xe451000a,0x5b1401b7}},	//   _teve_, _önek, דֶם_, емят
  { {0x58d50036,0x63a20125,0x67240079,0xbef7000a}},	//   могт, haon, dzij, _מצדו_
  { {0x2600005d,0xee290029,0x35cf000b,0x386951ce}},	//   रानी_, _بأنه_, स्फ़, tmar_
  { {0xab5b0251,0x63a21dad,0x4cbb000a,0x9cd7000a}},	//   egüe, jaon, _הזהו, _זוהה_
  { {0xdce801e2,0x7bfa000a,0x25a10012,0xbb440054}},	// [c770] madı, _וִיה, tahl_, _пећк
  { {0xdce80064,0xfb1c0008,0xf7700029,0x442d12d7}},	//   ladı, _לוחמ, طاق_, _sme_
  { {0xf650003b,0xb8830046,0x38740144,0x25a10012}},	//   ائق_, říbr, çarà_, rahl_
  { {0xd3710806,0xf77f001c,0xdce80064,0x5335004a}},	//   نها_, _faça_, nadı, меет
  { {0x14740029,0x27e951cf,0x87280033,0x2d850f21}},	//   رامج, mdan_, _еўра_, ycle_
  { {0x96fa000a,0xdb1d0123,0x27e951d0,0xe2900015}},	//   _ולשת, besö, ldan_, اذن_
  { {0xa4d40036,0x9f430089,0x660300f2,0xc5f2000a}},	//   _порі, ějí_, önku, _בדם_
  { {0x27e928f8,0x442d46cc,0xa8cc004f,0xdb1d0072}},	//   ndan_, _ume_, צ֖וֹ, lesõ
  { {0x27e900c0,0xdce80061,0x6279006f,0x62670015}},	//   idan_, dadı, _dňoc, _فائق
  { {0x27e900f2,0xe1650086,0x64592a98,0x0000006a}},	//   hdan_, _قضای, llwi,
  { {0x4d650191,0x41550010,0xceeb0086,0xc1050031}},	//   ьков, _ўвес, _گران_, _توضي
  { {0x443d0026,0x3f150142,0x10640015,0x3ed50015}},	//   nnw_, _одес, _كُلُ, _يقار
  { {0x27e90d75,0xe1e7002b,0x9368000a,0x26000065}},	//   ddan_, پس_, ּ֣רֶ, रामी_
  { {0x9e640036,0x27e951d1,0x6e450015,0xe8fa045f}},	//   _звід, edan_, _تنتم, олг_
  { {0x63a2003f,0x601c0003,0x0000006a,0x0000006a}},	//   yaon, _héma,   ,
  { {0x6f160050,0x1dbd005d,0x4c9a000a,0xa8550054}},	//   _życi, ्भवत, _ובקו, етуј
  { {0x060a0010,0x63a20085,0xe5a601cf,0x46a30138}},	// [c780] онак_, vaon, дизи, катв
  { {0x672451d2,0x69cd000b,0xd6a5005e,0x443d0034}},	//   rzij, द्दी, вiтн, enw_
  { {0x9f42002c,0x26c9003f,0x63a242c0,0x2600000b}},	//   ľké_, atao_, taon, राबी_
  { {0x7783006b,0xf77f016e,0xddc10030,0x69dc51d3}},	//   _илюз, _taça_, illő, lere
  { {0x69dc0079,0xc2970033,0x366a2e68,0x926a1068}},	//   oere, дкіх_, _мамо_, орка_
  { {0x6621005c,0x91e30054,0x408a0054,0x201d01c2}},	//   ązkó, воље, ољим_, _alwi_
  { {0x3a370008,0x3d17000b,0xdce80061,0xaa37000a}},	//   ורסם_, दनों_, yadı, וטסק_
  { {0xa50b0008,0x7ae451d4,0xeeaa3878,0x69dc51d5}},	//   _וּמִ, _osit, оток_, here
  { {0xa2890029,0xa1c60063,0x69dc51d6,0x3ed4002b}},	//   _فضلك_, _обад, kere, رقدر
  { {0x27e901e2,0x601c0152,0x6015002d,0x62650015}},	//   zdan_, _déma, _lámh, _كالق
  { {0xfe6f003b,0x45b70008,0x27e904e4,0x61fa20d9}},	//   جدي_, ופיל_, ydan_, _intl
  { {0x78bc0084,0xdfcf0086,0x61e851d7,0x69ce0079}},	//   durv, _نيم_, _hadl, efbe
  { {0xdce80064,0x63a0375d,0x69dc03b0,0x320c002a}},	//   radı, _memn, fere, _kody_
  { {0x3a740010,0xdce80064,0x69dc51d8,0x27e90034}},	//   кляр, sadı, gere, wdan_
  { {0x6ce60036,0x7ae451d9,0xc171000a,0x78bc001a}},	//   _ціле, _esit, ָ֗ם_, gurv
  { {0xb907014e,0xdc8b000a,0x59b1000b,0x63a051da}},	//   _मई_, _וְזָ, _जयवर, _nemn
  { {0xfc3f0089,0xf1ca002c,0x69dc51db,0x3cf6000b}},	// [c790] mní_, _kráľ_, bere, एमके_
  { {0xea010023,0xfc3f0089,0x61e807d4,0x69dc51dc}},	//   _đặt_, lní_, _nadl, cere
  { {0x26c9016f,0xe5c40063,0xfa340029,0xa8a70033}},	//   stao_, ъсто, _جريد, _ўрок
  { {0xfc3f51dd,0x8cd6000b,0xd3db0015,0x6a60001a}},	//   nní_, _बहनो, تبطا_, nöfn
  { {0x67470010,0xe299009f,0x320c04e2,0x61e81d52}},	//   _цэнз, чал_, _body_, _badl
  { {0x11d9003b,0xaab2014e,0xdb2600dc,0x6d550061}},	//   سوعة_, _जिसक, épér, üzak
  { {0x61e80026,0x69c5003f,0xa99c0008,0x499c000a}},	//   _dadl, _mche, חבור, חשוב
  { {0x61fa00b8,0xfc3f0057,0x68e8001a,0x69dc40ba}},	//   _entl, jní_, æddi, zere
  { {0xfc3f0089,0x7a220152,0x69dc0064,0x7bdd51de}},	//   dní_, _hôte, yere, desu
  { {0x69dc0298,0x6cea005d,0xfc3f0089,0x6abd007c}},	//   xere, टिंग_, ení_, dusf
  { {0x82340029,0x81bc0024,0xf652000a,0x69dc14dc}},	//   _شركا, _slēg, רצי_, vere
  { {0xeb97005f,0x69c551df,0x351a000a,0x601c2918}},	//   нию_, _ache, פורנ, _téma
  { {0x69dc099e,0xb436000a,0x4b55006b,0x6d5c001a}},	//   tere, תָיו_, върт, ýrar
  { {0x78bc384a,0xdca5135d,0x69dc51e0,0x69ce0012}},	//   turv, _заки, uere, ufbe
  { {0xc2120008,0xfc3f0089,0xae1a000a,0x6d580091}},	//   נהל_, bní_, _מוסכ, _gyva
  { {0x7bdd04f9,0x7ae40005,0xa5c2005d,0x2ba7000b}},	//   cesu, _tsit, _लाहौ, _ख़या
  { {0x7ae40752,0x4c3b000a,0xb907000b,0x69dc51e1}},	// [c7a0] _usit, _מתקב, _मै_, pere
  { {0x63a004f9,0xf77f001c,0xf203000b,0x2600000b}},	//   _semn, _faço_, लाफ़_, राधी_
  { {0x399b000f,0x628051e2,0xd499005e,0x299b000a}},	//   _מייד, _sumo, дрі_, _מסימ
  { {0x98160015,0x070a0015,0x61e81f63,0x62800046}},	//   _أبدا, _فيجي_, _sadl, _pumo
  { {0x08770053,0x69cd000b,0x877b000a,0x61e851e3}},	//   _רעכט_, द्वी, _מאכי, _padl
  { {0x35c6014e,0xfc3f0089,0x7bdd005c,0x7d0e02de}},	//   र्ख़, zní_, zesu, øbsk
  { {0x61e80024,0xfc3f0089,0xe6430142,0x320c0057}},	//   _vadl, yní_, _серп, _vody_
  { {0xefb20086,0x320c005c,0xf8b3000a,0xfc3f0046}},	//   ایشگ, _wody_, אשה_, xní_
  { {0xfc3f0089,0xc24634d4,0x6376007f,0x0000006a}},	//   vní_, _знак, _dünü,
  { {0x6abd007c,0x0000006a,0x0000006a,0x0000006a}},	//   vusf,   ,   ,
  { {0xd6220010,0xfc3f01b2,0xc0d30015,0xaa7b00bf}},	//   нiка, tní_, _ميلب, jvýr
  { {0x63760064,0xc4d3000a,0x611b000a,0x69c53724}},	//   _günü, נגר_, _מובה, _sche
  { {0xfc3f01cb,0x69a5000b,0x601c0003,0x7bdd51e4}},	//   rní_, _क़दी, _hémo, resu
  { {0x4efb0008,0xfc3f0107,0xf77f016e,0x6a60001a}},	//   _מהדו, sní_, _paço_, söfn
  { {0xfc3f0227,0x99840015,0xb606003d,0x7bdd51e5}},	//   pní_, الفو, iešā, pesu
  { {0x601c0152,0xa157000a,0x36d5107c,0xe9740015}},	//   _mémo, גבלה_, кобр, اهِد
  { {0xfc400089,0xaae70029,0x3207005c,0x69c50466}},	// [c7b0] čít_, _أسبو, yjny_, _tche
  { {0x63a40084,0x69c50026,0x96340010,0x163b0029}},	//   ðinn, _uche, гнуц, أسرة_
  { {0xe1ff00a7,0xd5b80010,0x44200033,0x0000006a}},	//   _đó_, эст_, гi_,
  { {0x9f5f002e,0x69cd000b,0x6a600012,0xd404005e}},	//   kkuð_, द्री, höfl, лячи
  { {0x86270010,0xfbd3000b,0x2bd3000b,0x0000006a}},	//   _зьве, ध्यम, ध्या,
  { {0x1a9c0053,0xe084002b,0x26d951e6,0x601c0003}},	//   לידע, گجوي, _ipso_, _bémo
  { {0x2ee600dd,0x33950015,0x92580067,0x883b000a}},	//   _asof_, _للأز, رشهر_, ּת֥ו
  { {0x601c038d,0x8f750127,0x7f75033f,0x682c000a}},	//   _démo, купі, купц, ּֽהְ
  { {0xd00e0015,0xe4480015,0xc7d8000a,0xcf880015}},	//   تلي_, _ألقى_, תוחי_, رضين_
  { {0x273e0023,0xee360033,0x93780015,0x394d0046}},	//   ắng_, кны_, _أصفر_, řesy_
  { {0xc5f2000a,0x91f6000a,0x9d451208,0x7c950058}},	//   בדי_, _שמעו_, тенд, خشخا
  { {0xdeb50033,0x7bcb0052,0x0000006a,0x0000006a}},	//   _абды, _ögul,   ,
  { {0x683a0046,0xef0e1977,0x1c430132,0x20130535}},	//   hůdc, _тм_, рням, ębić_
  { {0xc3320008,0xa96a0663,0xef1801f3,0xaf34006e}},	//   שוך_, дига_, _ямі_, _حرمت
  { {0x408c0008,0x6b8d0034,0x3ebf16f3,0xc8b5004a}},	//   ּאמְ, _ffag, luut_, лсты
  { {0xf772003b,0xab5b136c,0x200f06e7,0x4cba000a}},	//   لاء_, rfür, _jogi_, _חזקו
  { {0xc8690053,0x7c650029,0x3ebf0150,0xdb060030}},	// [c7c0] ַן_, _حاول, nuut_, egkö
  { {0xdb04001c,0x200f3010,0x395a0012,0xa95a0015}},	//   _adiç, _logi_, _typs_, _يجدر_
  { {0xe8760029,0xd4f50010,0xd6e2002a,0x6846030c}},	//   _لاحظ, ляцы, _siłą_, _анна
  { {0xb4d2005d,0x35c6005d,0x442051e7,0x7af60188}},	//   _वही_, र्ज़, ói_, _kryt
  { {0x25a300fb,0x245c0089,0x27e051e8,0x61d800f4}},	//   _fejl_, ními_, mein_, емля_
  { {0xdb04001c,0x62630036,0x97370033,0x69c30061}},	//   _ediç, авча, нiцы_, _önet
  { {0xb606003d,0xa0a30033,0x30a30033,0xc0ca0004}},	//   rešā, ашыл, арыв, фуле_
  { {0x68230020,0x27e0177b,0x4034011e,0x0000006a}},	//   _tõde, nein_, ѓепс,
  { {0x6a60002e,0x2e4a0063,0xa0670054,0x6015001a}},	//   töfl, дяно_, њања_, _námu
  { {0x442603af,0xa3c2005d,0x601c51e9,0x27e00012}},	//   lho_, ्भव_, _témo, hein_
  { {0x55bb0008,0x27e000f2,0xc1060086,0x44260107}},	//   ומיו, kein_, _جواي, oho_
  { {0x442603af,0x64424acf,0x3ebf13b5,0x7af651ea}},	//   nho_, nnoi, buut_, _bryt
  { {0x539b000a,0x3fcb002b,0xf1c9000b,0x2918001a}},	//   ויכו, _آدمی_, _रामन, eyra_
  { {0x3eb9032c,0xeef7000a,0x8cf40015,0x0000006a}},	//   áste_, _שמגר_, _مكتش,
  { {0x442600dd,0x6cd40015,0x1958054f,0x27e051eb}},	//   kho_, _إقبا, вары_, fein_
  { {0x4426002c,0x7c260012,0xfc300015,0x683a0046}},	//   jho_, chkr, _وحي_, vůdc
  { {0x163b0029,0x245c0057,0x85a70054,0x442601d7}},	// [c7d0] وسطة_, cími_, вјед, dho_
  { {0x8b580008,0x2fdf00b8,0x44260227,0x9afa000a}},	//   _ביחס_, zeug_, eho_, _נפתח
  { {0xfba7000b,0x9f4f0123,0xf96b0a32,0x27e01daf}},	//   _ख़ाम, _ingå_, _юрий_, bein_
  { {0x93940015,0x88f6000a,0x64420618,0xe3b00040}},	//   لجها, _עזרו_, gnoi, قره_
  { {0x1dc2014e,0x6746032c,0xab5b0061,0xc2c8006e}},	//   _शांत, čujú, zgün, نبول_
  { {0x78ba016f,0x65941356,0x21693ed3,0x644251ec}},	//   štve, _вару, нили_, anoi
  { {0x41b40010,0x1634004a,0xe3b3002b,0x20550076}},	//   рсіт, _теря, _پرز_, лтир
  { {0x63ad002e,0x397c0008,0x3fe512d2,0x442651ed}},	//   ðand, וטונ, ужив, cho_
  { {0xa3c2000b,0xcf390033,0x0000006a,0x0000006a}},	//   ्भर_, эчкі_,   ,
  { {0x7d090001,0xa4b5000f,0x60e8008c,0x2c7b0091}},	//   еног_, ְלָה_, äsmä, _būdo_
  { {0x6cc5008f,0x26c0003f,0x61130089,0xab5b0061}},	//   ыйна, zuio_, _dělá, ugün
  { {0x9ef500a2,0xab2a0054,0x245c3750,0xab5b0405}},	//   _مستش, еома_, tími_, rgün
  { {0xdd030061,0x0000006a,0x0000006a,0x0000006a}},	//   ısıd,   ,   ,
  { {0xceb2000a,0x29181ed6,0xad250067,0x27e051ee}},	//   _פיו_, tyra_, _مرعو, wein_
  { {0x69a5005d,0x3ead51ef,0x245c001a,0x442601c0}},	//   _क़री, lset_, sími_, yho_
  { {0x7d1c0cd8,0x3ff90053,0x1dcf000b,0x2ca6006b}},	//   ørse, עפּע, त्रत, _скъп_
  { {0x4426002c,0x291e51f0,0x27e051f1,0x3ead47e0}},	// [c7e0] vho_, šta_, rein_, nset_
  { {0x3ead022d,0xdb060f19,0x4a9b000a,0x27e051f2}},	//   iset_, jaké, _רייג, sein_
  { {0x442651f3,0xe3ba0848,0xd4160033,0xab5b0012}},	//   tho_, ебе_, льды, hgül
  { {0x69c301e2,0x3ead51f4,0x24970074,0x44260089}},	//   _öner, kset_, انند_, uho_
  { {0xf7720074,0x2d0f000b,0x3ead00bc,0x644251f5}},	//   _داد_, ाहुल_, jset_, rnoi
  { {0x44260f4d,0xe2970001,0xab5b00b8,0x386051f6}},	//   sho_, ћај_, dgül, llir_
  { {0xe0cf0029,0x6015002e,0x442651f7,0x38601f9f}},	//   كزي_, _náms, pho_, olir_
  { {0xdfd00029,0x4fc62cdf,0xb4fb05bd,0x3ead1254}},	//   آية_, уска, _אפלי, fset_
  { {0x63ad002e,0x74130087,0x442451f8,0x2ba8000b}},	//   ðane, _اوقا, _ilm_, _कज़ा
  { {0x3cd40010,0x7c240049,0x69d6000b,0x1ed70015}},	//   ажос, _alir, म्मी, ابيب_
  { {0xd6570008,0x25d70053,0x386051f9,0x50ba0015}},	//   ריית_, נוטן_, klir_, _سداد_
  { {0x7c240d0c,0xdb1d001a,0x60150069,0x3ead51fa}},	//   _clir, rfsþ, _dáms, bset_
  { {0x2bc6000b,0x4424229d,0x3ead0030,0x38600034}},	//   _वारा, _mlm_, cset_, dlir_
  { {0xa2cc000b,0x38600061,0x7bc602f2,0xa2a9000b}},	//   _समन्, elir_, agku, _क़िस्
  { {0xbd550086,0x195904f7,0x286b0054,0x7c2451fb}},	//   _پروژ, тавы_, ерао_, _flir
  { {0xe795002b,0x6d460061,0x7c240034,0xdb060030}},	//   شارک, şkas, _glir, zaké
  { {0x245c0089,0x96350329,0x6c480015,0xd5bb030e}},	// [c7f0] nímu_, анац, _حليف_, есе_
  { {0xa7740783,0x38600077,0x442424e0,0xa56702be}},	//   случ, alir_, _alm_, هدان
  { {0x94750086,0x7c360026,0x38600ad3,0x33950015}},	//   لگرا, _ymyr, blir_, للاز
  { {0x69c713e1,0xb89a000a,0x289a000a,0x889a000a}},	//   lgje, _שברש, _שירא, _שברי
  { {0x8388005e,0x245c0046,0x44241e8a,0xdb060030}},	//   убів_, jímu_, _dlm_, také
  { {0x44e50026,0x76ba0008,0x3ead0020,0xa0c50015}},	//   _tŷ_, _במשפ, vset_, ليتو
  { {0x40940010,0x5a18000a,0xdb060030,0xaa2c000a}},	//   брыт, רקון_, raké, עֵדֻ
  { {0xe3b30002,0x3ead1c7e,0xb97c004c,0xdb060030}},	//   _درس_, tset_, ענהי, saké
  { {0x99830007,0x600604ab,0x645b008c,0x60150030}},	//   nijų_, рным_, _ikui, _sáms
  { {0x3f8d001c,0xab5b0064,0x63ab13f0,0xef19002a}},	//   sceu_, rgül, lagn, ryż_
  { {0xcb090008,0x9f42002c,0x3d0f000b,0x01fa000a}},	//   _קל_, ľká_, ाहें_, _שפעל
  { {0x69c70014,0x61e30e4a,0x3ead41b9,0x212a002b}},	//   egje, lenl, pset_, _جيمی_
  { {0xde050191,0x60c301e2,0x501a0008,0x539a0008}},	//   _впли, lunm, _שונו, כירו
  { {0x7a2b0482,0x672d0c09,0x8d87017f,0x99830091}},	//   _lütf, dzaj, _судд, dijų_
  { {0xc87f0012,0x2609000b,0x61e30990,0x3860001a}},	//   _biß_, सानी_, ienl, tlir_
  { {0x63ab016f,0x61e304de,0x201f0091,0x7c2402f2}},	//   jagn, henl, nkui_, _ulir

  { {0x65960029,0x63ab04ed,0x99830007,0x6f1b01c2}},	// [c800] لجار, dagn, gijų_, nyuc
  { {0xf98a0029,0x645b01d7,0x7ae90061,0x61e32fd9}},	//   _جندي_, _akui, çete, jenl
  { {0x20d10023,0xcdb60008,0x84e6085d,0x61e351fc}},	//   _nơi_, שפעה_, роеж, denl
  { {0x7469005e,0xe29a1de1,0x63ab51fd,0x0000006a}},	//   грів_, вад_, gagn,
  { {0x998300df,0x672d0050,0xf1940ac7,0x201f007c}},	//   cijų_, czaj, биль, dkui_
  { {0x425600d0,0xb1e60015,0x20d10016,0x61e31b66}},	//   штет, شأته, _bơi_, genl
  { {0x03a60191,0xa4910086,0x3d0f000b,0x22290015}},	//   _вибо, _فیلت, ाहों_, دثني_
  { {0xdfda0063,0xdb0b0064,0x601c0030,0x3ed40015}},	//   тък_, _çiçe, _kémi, مقبر
  { {0xe61f0016,0x7e2a02a3,0x61e351fe,0xde880016}},	//   _muôn_, віна_, benl, _bịa_
  { {0x20d60191,0xe61f0023,0x3eb800bd,0x3eb9002d}},	//   _відс, _luôn_, črt_, ásta_
  { {0x6e3a07a3,0xefca0054,0xac190e3b,0x99830091}},	//   ritb, _алел_, гону_, zijų_
  { {0x711b000a,0x6ee60021,0xab5b007c,0x6e3a0dbb}},	//   _שואפ, _نستل, sgüm, sitb
  { {0x6e94003b,0x27f20176,0x5e940029,0x2aa80036}},	//   _التا, ddyn_, _التط, итро_
  { {0x27f20034,0x6aa401c2,0x4efb000a,0x69d50012}},	//   edyn_, _dwif, _שהגו, ufze
  { {0xe61f0092,0x69c700cb,0x58870033,0x672d002a}},	//   _buôn_, rgje, рыга, wzaj
  { {0x61e301e2,0x7aec00f2,0x5d7b01d8,0x99830091}},	//   zenl, ältä, _באוק, tijų_
  { {0xf7730074,0x69d500b8,0x61e30399,0x7c3d0209}},	// [c810] زار_, pfze, yenl, misr
  { {0x60c300b6,0x99830007,0x645b00dd,0x7c3d0e8b}},	//   yunm, rijų_, _skui, lisr
  { {0x99830007,0x228b13e1,0x672d062e,0x61e351ff}},	//   sijų_, _søk_, szaj, venl
  { {0x60c30064,0x20d10092,0x601c0152,0x9cd7000a}},	//   vunm, _rơi_, _fémi, שואה_
  { {0xc2930086,0xadf8005d,0x1da7005d,0x601c0140}},	//   زیاب, ्ञान_, _ग़लत, _gémi
  { {0xdcee0046,0xe296006b,0x63ab4d2b,0x7aed0012}},	//   áděj, щаш_, sagn, _msat
  { {0x61e326fa,0xd24e0029,0x63ab5200,0x10f50033}},	//   renl, عنى_, pagn, сяля
  { {0x13aa0086,0x1ec90080,0x60c30064,0xe0d60033}},	//   _منفی_, глии_, runm, ёвы_
  { {0x6459005c,0x7fe80115,0xa294005e,0x2d830b28}},	//   mowi, شريف_, _маті, žjem_
  { {0x2d8300fb,0x20d10092,0x79850026,0x63bf002a}},	//   øje_, _tơi_, _nghw, łyną
  { {0x3085040b,0x718c0053,0xa0c40029,0x90995201}},	//   _الصف, _סװאַ, _ويكو, _свет_
  { {0x64590050,0x1dd8005d,0x9ff40015,0x443d0542}},	//   nowi, ब्बत, _وأنص, niw_
  { {0x7aed0014,0x0b43005e,0x63a95202,0xa3cf000b}},	//   _csat, знян, _meen, _शान_
  { {0xa3d7005d,0x2bb80092,0x8d950015,0x601c1112}},	//   ़्त_, ọc_, _الغش, _rémi
  { {0x6459005c,0x7aed5203,0x7c95002b,0x601c0003}},	//   kowi, _esat, _اشتا, _sémi
  { {0xdb0600dc,0x6459002a,0x765c05de,0x60dc0012}},	//   lakí, jowi, _skry, _ärme
  { {0x6459005c,0x27f20026,0x18670185,0x443d0034}},	// [c820] dowi, rdyn_, сати_, diw_
  { {0xd0f9005d,0x2d9a007c,0x1dc7000b,0x6b610030}},	//   ्माण_, _õpet_, ललित, ságú
  { {0x2e3a00b2,0x3e3a0053,0x63a9059b,0x64592dce}},	//   נגענ, נגעװ, _been, fowi
  { {0xdc190050,0x62810026,0x4d5a004c,0xf7460121}},	//   _błęd, _ailo, אדעצ, _гемо
  { {0x6d5c0227,0x63a90234,0xb893002b,0x62815204}},	//   ýraz, _deen, _ولیع, _bilo
  { {0x765c5205,0xcad7000a,0x59db000b,0x60150125}},	//   _ukry, מונת_, म्पर, _sámp
  { {0xf0b70086,0x6459005c,0xf993000a,0xde880016}},	//   مايش_, bowi, הרו_, _cịn_
  { {0x24b7013a,0x30140036,0xf2e80086,0x443d10ec}},	//   _להלן_, ідпр, _نکته_, ciw_
  { {0x05cf000b,0x7a2b0012,0x62815206,0x441b004f}},	//   स्कब, _hüte, _filo, _עומס
  { {0x26c00026,0xb5960033,0xacb40054,0xe2460021}},	//   irio_, алiц, обољ, _اخري
  { {0xa3bc005d,0x8fa60086,0xa3cf005d,0x7c3d0209}},	//   _आया_, _هماه, _शाम_, tisr
  { {0x7f86003b,0xb4fb0053,0x2c27005e,0x7a2b0061}},	//   _الإن, אפטי, сьог, _müte
  { {0xe043005f,0x643b00b2,0x3ebf01f6,0x201a0535}},	//   _энци, רעכנ, crut_, ęzić_
  { {0x05c7005d,0x20030024,0x6459005c,0xc333000a}},	//   _लाइब, ējie_, zowi, לור_
  { {0x6615096c,0x6c350015,0xde8800a1,0x0000006a}},	//   _rozk, _وفتا, _xịn_,
  { {0x2c7b0048,0x17fb0015,0x2509002b,0x8c440054}},	//   _līdz_, درسة_, یرای_, _неје
  { {0x7aed062b,0x98aa0024,0xdce3003d,0x6be8000a}},	// [c830] _usat, ākās_, _iznā, _הַתַ
  { {0x644a5207,0x6459002a,0xccf80046,0x25aa0034}},	//   éfin, wowi, ově_, _cebl_
  { {0x26c05208,0x657a002e,0x54a70029,0x4ddb0008}},	//   ario_, _úthl, صحاف, רחבו
  { {0xdb0600dc,0x8cc0000b,0x69da007c,0xd2990033}},	//   zakí, _विनो, õtev, аткі_
  { {0xa2350010,0x248d04c6,0x64595209,0x70e1000b}},	//   жэйш, _čemu_, rowi, पब्ल
  { {0xcad80008,0x63a90409,0x4374005e,0xc2440033}},	//   צוות_, _ween, чуєт, пнік
  { {0x64590050,0x7a2b00b8,0x50b504f7,0x63a90100}},	//   powi, _güte, цслу, _teen
  { {0x682a0089,0xe0d60010,0xc0a80015,0x2eb5520a}},	//   _týde, івы_, حاول_, осос
  { {0x63b40089,0xfc3f0107,0x27aa004c,0x6281520b}},	//   řený, dií_, בספּ, _tilo
  { {0x7fb90074,0xfe420036,0x3ebf0b1f,0x627900bf}},	//   _چهار_, дньо, rrut_, _aňov
  { {0x51f40029,0x16c6005d,0xfc3f0057,0x05c7000b}},	//   _عسكر, _लम्ब, fií_, _लाईब
  { {0x5f740086,0x3156000a,0xfc3f0107,0xf3f2000a}},	//   _کامر, _ויען_, gií_, ֵ֣ר_
  { {0xe80d000b,0x5ac7006b,0x99f6005e,0x6279006f}},	//   हाना_, олям_, ояві, _dňov
  { {0xa2cc014e,0xc9850015,0xdca51293,0x20dd0065}},	//   _समस्, كشفي, _даки, _महाध
  { {0xfc320015,0x7c660015,0x26c00034,0xeb9a00ce}},	//   _يحب_, _واعل, wrio_, _кий_
  { {0xfc3f12c3,0x59db000b,0x57ea0004,0x78ba0b28}},	//   cií_, म्बर, јдам_, štvo
  { {0x32050041,0xba760029,0x7aa60029,0x3c320016}},	// [c840] _only_, _واخت, _بإعل, cơva_
  { {0x6a60002e,0x63ad002e,0x26c01240,0xb5a90015}},	//   töfu, ðann, rrio_, مامك_
  { {0x89db000a,0xd302000b,0xae56004c,0xb8b60015}},	//   _דחיי, लम्ब_, קסעס_, _بإخت
  { {0xf8b3013a,0x26c0520c,0x6a60002e,0x03a30054}},	//   _קשר_, prio_, röfu, дицо
  { {0xe81f000b,0xe800000b,0x7a2b0012,0xe2f8008b}},	//   _यकता_, _लोया_, _wüte, селі_
  { {0x5ba7000b,0xfc3f00bf,0x64a61cd9,0xd5b20058}},	//   _ख़्व, zií_, _мага, _زفر_
  { {0x628f0152,0x3ea6520d,0x4fc60a66,0x80c10065}},	//   _écon, _swot_, оспа, रंगे
  { {0x297b00b2,0xdfd00070,0xdd90002b,0xc0570015}},	//   סטקא, ريخ_, کود_, يشيا_
  { {0x63a4002e,0xe297198b,0x23270fea,0x11d601c6}},	//   ðinu, _мат_, _доти_, _міжр
  { {0xddd80263,0xcd2a0015,0xc0e6005e,0x601c0003}},	//   _bivš, لسجن_, _мозк, _rému
  { {0xc27b000a,0xe80d0065,0x527500af,0xccf8005a}},	//   _כרמי, हामा_, _хуту, uvě_
  { {0x2d870293,0x94bb000a,0xc0460015,0xbb94004a}},	//   _egne_, סמכת, _بخطو, мающ
  { {0xa3dc005d,0x447b0053,0xfc3f0057,0x8b67002b}},	//   त्य_, ינטע, rií_, تادم
  { {0x220a0008,0xfc3f002c,0xcd360015,0x44ec00da}},	//   ׁפָּ, sií_, _ورغب, _oſ_
  { {0x63a2520e,0x35dd000b,0xe8940033,0x7d1c0123}},	//   kbon, न्फ़, дась, ärsd
  { {0xa3dc005d,0x2b560030,0xac380015,0x24840012}},	//   त्म_, éccé_, _وسيط_, _nimm_
  { {0x36d4005f,0x47350010,0xc58b004a,0xc9870402}},	// [c850] мотр, чнас, ащее_, _муни
  { {0x41c9000b,0x69da007c,0x63a2520f,0xd2f202a3}},	//   _राइस, õtet, ebon, _мiкр
  { {0xbebd0f28,0x5bc4009a,0x0000006a,0x0000006a}},	//   nzūr, _عقیل,   ,
  { {0x69080008,0x58fa0053,0x44290092,0x48fa004c}},	//   _וּשְ, _פּינ, óa_, _פּיא
  { {0x23380010,0x27e95210,0xc6f8024e,0x4b7b004f}},	//   опцы_, mean_, _днях_, ׁא֣ו
  { {0xa2cc014e,0xd25b0010,0xf6790053,0x171a0008}},	//   _समर्, шце_, _לאָמ, _הושע
  { {0x2484002e,0x7d1c01f0,0xd4980004,0x63a21042}},	//   _fimm_, ørsl, _мрт_, bbon
  { {0xe7cb005d,0xd6220484,0x03c400d0,0x60090185}},	//   िलिप, нiза, _осум, сним_
  { {0xe2930086,0xee390235,0x644b0123,0x82650058}},	//   _آذر_, йни_, mngi, _فهرن
  { {0xf1a70148,0xfe71002b,0xdb0f03a0,0x0000006a}},	//   _фран, رگش_, macè,
  { {0x80a4003b,0x27e900f2,0x11d40015,0x03d5000a}},	//   _يمكن, kean_, _تتقد, ֔וֹם_
  { {0xf0f9005d,0x2fd40015,0x644b2626,0x2e29006f}},	//   ्मीद_, _يتنح, nngi, _dúfa_
  { {0xf1d2021e,0xdef40010,0x5f740067,0xee2e1301}},	//   _सामन, _опцы, _قاهر, _зн_
  { {0x52d6000a,0x4efa000a,0x5e9a000a,0x98c50046}},	//   הושע_, _להנו, _הבסק, _útěk_
  { {0x52c8000b,0xdcfe0045,0x25ff0065,0x0d57009a}},	//   _रम्स, ăvăl, _रफ़ी_, _بخشد
  { {0x2c7b0007,0x2fcd0026,0x27e91740,0xc172000a}},	//   _būdu_, ngeg_, gean_, תחל_
  { {0x99550089,0x0cdb005d,0x6f16005c,0x80f9000b}},	// [c860] _výši_, _बहुम, _życz, ्मुख_
  { {0xd4d60010,0x63bb5211,0xaae50015,0x7ae402f2}},	//   зідэ, _adun, _آسيو, _ipit
  { {0x7c26002e,0x3a37000a,0x644b001a,0x05760015}},	//   okkr, _זרים_, fngi, سائد
  { {0xd3440086,0x4cba004c,0x9f42006f,0x546a004a}},	//   وفای, ממעג, ľkú_, щаем_
  { {0x628f0152,0x57fb00f3,0x69ce4002,0xd7fb000a}},	//   _écol, _הלכו, ogbe, _ההכל
  { {0xfe670087,0x30a60155,0xc889002b,0x91fc003d}},	//   _سد_, прив, _دخیل_, _skāb
  { {0x69dc03ba,0x6aa9000b,0x2609000b,0x7a220003}},	//   ifre, _कब्र, सारी_, _côti
  { {0x7d1c06f5,0x92c101e2,0xbbc6005d,0x69dc1ffd}},	//   ørsm, üğün, वलोक, hfre
  { {0x644200f2,0x69dc0b4f,0xc2c90015,0xab5b0012}},	//   mioi, kfre, _وبكل_, ngüt
  { {0xd737013a,0x442639a2,0x471b0053,0x64421dad}},	//   פטית_, lko_, צויג, lioi
  { {0xc19b0008,0x44265212,0xdb0f0077,0x7f8600c3}},	//   _השבי, oko_, macé, _فلان
  { {0xdb0f0152,0x44265213,0x64425214,0x69ce1086}},	//   lacé, nko_, nioi, egbe
  { {0x1efa0015,0x93b7000a,0xdb23002b,0xc017000a}},	//   _دعاة_, הלכו_, روسی, _מקאו_
  { {0xa3dc005d,0xeb9f003c,0x442612d7,0xc333000a}},	//   त्त_, gjør_, hko_, גוש_
  { {0x4426022d,0x69ce005d,0x4ddb000a,0xfdf7000a}},	//   kko_, _तारी, _החוו, _מצגת_
  { {0xdc2b0086,0xad250015,0x69ce02f2,0xa09b000a}},	//   _دسته_, _ترهو, agbe, מילט
  { {0xa3c2014e,0x3bbc0008,0x644b0595,0x27e9124e}},	// [c870] ूलन_, _המחד, vngi, rean_
  { {0xa3cf005d,0x682a0227,0x27e95215,0x466b01b0}},	//   _शाह_, _výda, sean_, ёрам_
  { {0x61ea01e2,0xb8350080,0x27e95216,0x6442008c}},	//   defl, _женщ, pean_, fioi
  { {0xc9525217,0xe5700015,0x442602f2,0x644b5218}},	//   _ימי_, اطك_, gko_, ungi
  { {0x2458008f,0x386941b2,0x92590086,0x57fa000a}},	//   чаць_, mlar_, يشتر_, _ולרו
  { {0xdd8606e4,0x7c2d0251,0xc692000a,0x97420033}},	//   _لو_, _llar, _באך_, нiць_
  { {0x7c2d0482,0xfbbf005d,0xe61f0092,0x2c560024}},	//   _olar, ्लाम, _nuôi_, lāde_
  { {0x386901e2,0xb69b038d,0x44261827,0xab5b0061}},	//   nlar_, _grâc, cko_, ngüs
  { {0x69dc0026,0x442d5219,0x443f003f,0xdb1d002d}},	//   yfre, _ile_, _imu_, agsú
  { {0x41b50086,0xf2d2000a,0x38690f0a,0x2fcd0034}},	//   _آمار, _בעמ_, hlar_, sgeg_
  { {0x7a3000f2,0x3869521a,0x31c9000b,0x1bea0a21}},	//   _jäte, klar_, रलीध, одни_
  { {0x38690064,0x8d540010,0xca29039e,0xeb97004a}},	//   jlar_, этыч, _דם_, мию_
  { {0xb0dd005d,0xbfd20015,0x8e390015,0x765e0061}},	//   _महँग, _شيوع, _وستر_, yopy
  { {0xdde90086,0x442d488d,0xde940015,0x68fc1e01}},	//   _گرچه_, _lle_, _أجنب, tvrd
  { {0x7a3000c0,0x38693ced,0x44260c89,0x291e0011}},	//   _näte, flar_, yko_, âta_
  { {0x683102d2,0x38694514,0x7c2d32bc,0x69dc220e}},	//   _nådd, glar_, _glar, sfre
  { {0x644200f2,0x7ae4016f,0x2c560024,0x0f7a004c}},	// [c880] vioi, _upit, gāde_, ַרעל
  { {0x4426005c,0xb0dd005d,0x7a2b0020,0x69c00007}},	//   wko_, _महंग, _tüta, ėmes
  { {0x644200f2,0x442d29c9,0x84ea00e6,0x3869521b}},	//   tioi, _ble_, تفاق_, blar_
  { {0xc32a0015,0x78fb000a,0xe7b2000b,0x1bee000b}},	//   يكان_, _ולטפ, _ज़िप, ज़िल_
  { {0x442d0089,0x644200f2,0x6b49000a,0x66291ad6}},	//   _dle_, rioi, ּרוּ_, áskó
  { {0x20ee0089,0x38600152,0x644200f2,0xc5f50063}},	//   _při_, loir_, sioi, _пясъ
  { {0x644200f2,0x442600bd,0xc0e30180,0xdb060fb2}},	//   pioi, pko_, војк, lakä
  { {0xd010040b,0x68e3195d,0x61ea521c,0x853b000a}},	//   الة_, _ände, sefl, _וגלי
  { {0x5fbf005d,0x661c521d,0x64404986,0x22930015}},	//   _एयरल, _kork, _immi, _للقس
  { {0x20ee0089,0x38690064,0x1be1000b,0x9d1400d7}},	//   _tři_, zlar_, ग्नल_, едоч
  { {0x44fe00df,0x38690064,0xc5f3000a,0xdc98005e}},	//   _jį_, ylar_, דדת_, явні_
  { {0x2605005d,0xdb0600f2,0x386900c0,0xaf0a0015}},	//   _होनी_, kakä, xlar_, _وقام_
  { {0x4e170086,0xdb0600f2,0x62880410,0x3ed40015}},	//   ستید_, jakä, _kido, _أقتر
  { {0x7d2700dc,0x68310134,0x38690034,0x69d80030}},	//   össé, _måde, wlar_, _övel
  { {0x6d4f0011,0x9f46002d,0xe919005e,0x38694528}},	//   şcar, _naoú_, чові_, tlar_
  { {0x6ce30191,0x6c180029,0x7a180064,0xc6a70180}},	//   _ріше, _يتيح_, _aştı, држи
  { {0x7a300005,0x1995008f,0x3869521e,0x501b0008}},	// [c890] _säte, _папя, rlar_, קומו
  { {0x644002d7,0xcb120008,0xdcfa0064,0x2c560024}},	//   _ammi, _עלי_, latı, rāde_
  { {0x386901e2,0x80dd000b,0x442d521f,0xd5670033}},	//   plar_, _महें, _ple_, фтап
  { {0x2c08014e,0xdcfa0064,0xd3710031,0xf9680033}},	//   षाएं_, natı, هها_, _юрый_
  { {0xa2940036,0x661c4f15,0x179a000a,0xdb1d00cb}},	//   вачі, _fork, _מירב, ggsø
  { {0x863500b2,0x7a300437,0xa4d5005e,0x27f900da}},	//   _טאָג_, _täte, _погі, _hasn_
  { {0xb1160015,0xdcfa0061,0x442d09bb,0x62883ba5}},	//   فقوا_, katı, _tle_, _dido
  { {0x442d003f,0x443f016f,0x6f020220,0x7645008c}},	//   _ule_, _umu_, _broc, lihy
  { {0x3eb95220,0xdcfa0064,0x32550484,0xf412000a}},	//   ést_, datı, _звар, _גפן_
  { {0x6f02002d,0xe1f30015,0xb1d50015,0xee36156c}},	//   _droc, _جسر_, _سيؤث, ень_
  { {0xa3dc005d,0xe479000a,0xd479004c,0x1d090a21}},	//   त्व_, ּרָכ, ּאָל, чени_
  { {0xce95010f,0x8cc0014e,0xde950001,0xfc320115}},	//   _задъ, _विरो, _задњ, احد_
  { {0x3860038d,0xcf270015,0xddc50c7c,0x6f025221}},	//   voir_, _تراي, _збли, _groc
  { {0xc332000f,0x4a7501b0,0x8f1a004f,0xd336004f}},	//   רוך_, выст, _מונת, גרשה_
  { {0x9cf40033,0x38760054,0x386016c3,0xc8b50033}},	//   _ачыш, ећат, toir_, ксты
  { {0xa8870457,0xf1d00016,0xdb060b1f,0x05dd000b}},	//   ейса_, oạch_, takä, न्सब
  { {0x38600618,0x7a2b0061,0x4dd9000a,0xe73a012e}},	// [c8a0] roir_, _kütl, ּחֲו, чеа_
  { {0x9916008f,0x6736005c,0xdb37000a,0xa3e5000b}},	//   _зьмі, rzyj, _נניח_, _बॉब_
  { {0xf1c9014e,0x41c9005d,0xd8ba0029,0x661c00b8}},	//   _राजन, _राजस, _عددا_, _vork
  { {0x661c003e,0x889b0008,0x1e1c021e,0x62885222}},	//   _work, _מבטי, _पक्ष_, _sido
  { {0x48030010,0x3317002b,0x87b7000a,0x23270004}},	//   _спяв, فزود_, _אלכס_, ноци_
  { {0x8cc0014e,0xdcfa0061,0x27e05223,0x3239009a}},	//   _विलो, zatı, lfin_, وينگ_
  { {0x6288385d,0xdcfa0064,0xa2cc000b,0xdb04016e}},	//   _vido, yatı, _समक्, _feiç
  { {0x628807e9,0x27e00003,0x98aa002a,0x58fb004c}},	//   _wido, nfin_, czbą_, פּונ
  { {0x7799004f,0xc2c6009a,0x7d035224,0x0000006a}},	//   וֹתו, _سياي, _arns,
  { {0xa3dc014e,0xd010002b,0x437506f3,0xc0aa0369}},	//   त्र_, الک_, _руст, _فاصل_
  { {0x6f02005c,0xc04f017f,0x91bb000a,0x6d5d0061}},	//   _wroc, _бі_, _זמבי, şsan
  { {0xd3140036,0x3157000a,0x61fa0f0a,0xd5cc000b}},	//   _пiдт, _איבן_, _hatl, ालुओ
  { {0xdcfa01e2,0x6f02005c,0x6fa6000b,0x63ad001a}},	//   ratı, _uroc, _ट्यू, ðani
  { {0xaf490029,0xdf490015,0xdcfa0061,0xb69b0045}},	//   _تشمل_, _تؤمن_, satı, _brân
  { {0xdcfa0064,0x61fa5225,0x8dfb000a,0xa3c2000b}},	//   patı, _matl, _זהות, ूला_
  { {0xb909005d,0x6aad003f,0x9cd7000a,0x99840015}},	//   _यह_, _twaf, _נוחה_, طلقو
  { {0xa2cc000b,0x0c740002,0x2ba7000b,0x3a7507f7}},	// [c8b0] _समग्, _حدود, _क्या, _илир
  { {0x27f9003e,0xb69b0045,0xa6e2001a,0x6823007c}},	//   _wasn_, _frân, æðan, _rõdu
  { {0xbc680086,0x59960008,0x68230020,0xd3f90033}},	//   _زمین_, _בכתב_, _sõdu, дэлі_
  { {0x320c1e72,0xf4840033,0x7af60034,0xa3dc0065}},	//   _andy_, гучн, _ysyt, त्ल_
  { {0xc9870074,0x2c560024,0x321e1e80,0xdb0f0107}},	//   _تشکي, nāda_, _boty_, kací
  { {0x6595000d,0xe1f1002b,0x21690a6c,0x9f440144}},	//   _јаву, شست_, мили_, demà_
  { {0x7a300020,0x9f42002c,0xdb0f01b2,0x20552b7a}},	//   _jäta, ľký_, dací, ктир
  { {0x2605014e,0x2c560024,0x023b002b,0x9f42013f}},	//   _होती_, kāda_, _کثرت_, žký_
  { {0xa2950036,0xf1a70457,0x1ee7002b,0x929512ae}},	//   _разі, _зрен, رودی_, _разц
  { {0xbcd90015,0xa29401f3,0x26c90085,0x4e020033}},	//   وذجا_, _сафі, irao_, азьб
  { {0x7e610134,0xd2f20033,0x4094005e,0x7a300123}},	//   rolp, _мiгр, _бріт, _näta
  { {0xeb9a004a,0x7a220003,0xb5710033,0x22475226}},	//   ьим_, _nôtr, ынiл, link_
  { {0xa03a0053,0xcf240015,0x998e005a,0x0000006a}},	//   _קענפ, _مروي, ínům_,
  { {0x1f36000a,0xe000002a,0x8d650054,0xb69b0045}},	//   _ברנר_, ąłeś_, _ивле, _prân
  { {0x64d0005d,0xd959005e,0x7a2b0061,0xa9670de9}},	//   _हमेश, ешті_, _gütm, вира_
  { {0x2c08005d,0x9cd6000a,0x224700da,0xf092000a}},	//   षाओं_, _סופה_, hink_, שנן_
  { {0x18672c5e,0x7af6002a,0x26c90085,0xfa54002b}},	// [c8c0] тати_, _usyt, grao_, _مردگ
  { {0x8ab70008,0xb69b5227,0x66e31411,0xa92624e9}},	//   _שהיו_, _trân, рофа, _адол
  { {0xd4990191,0xa7aa0080,0xb69b016e,0xb9560054}},	//   ері_, _окна_, _urân, _штић
  { {0xfbdf0023,0xad1a00b2,0x82a60036,0x9d1a0053}},	//   hiên_, ווער, вадж, וועט
  { {0x73360015,0xdb4d000a,0x61fa5228,0x92f30015}},	//   خرائ, ּעוֹ, _patl, لأوض
  { {0xbb3b00a3,0xe5a341f8,0x9737004f,0xc4c60058}},	//   ועני, _вири, _ירכא_, _لترو
  { {0xf9930008,0xdb0f0156,0xe64303e7,0xca37000a}},	//   סרה_, vací, _терп, כנסה_
  { {0xc9530008,0xf8b30008,0x1ee6002b,0x75230012}},	//   ימו_, בשה_, نوعی_, änze
  { {0x11ea0029,0x61fa04a7,0x78a90085,0x9f5f001a}},	//   _يعطي_, _tatl, ćevi, örði_
  { {0x0000006a,0x0000006a,0x0000006a,0x0000006a}},	//     ,   ,   ,
  { {0x2fe60015,0xdb0f0046,0x68310123,0x45b7000a}},	//   _لكاف, rací, _låda, כפיל_
  { {0xc4d3000a,0x2c56003d,0xd0120015,0x60d7000a}},	//   סגר_, tāda_, _خلص_, _יובא_
  { {0xa3d7000b,0x7ac7006b,0xde880016,0x290c5229}},	//   ़्ट_, ъсне, _bịt_, ådan_
  { {0x2c560048,0x5a470010,0xa9c4004a,0x2c720046}},	//   rāda_, тэма, исск, ládl_
  { {0x29054f57,0x6d450046,0xe9b4005e,0x2dd70058}},	//   íla_, _žhav, рбсь, _شبوة_
  { {0x26c90085,0xf7730058,0x7a2b0072,0x0000006a}},	//   trao_, لاذ_, _kütk,
  { {0x41d2005d,0x7a220003,0xcc58015b,0xdb1d0012}},	// [c8d0] _सांस, _vôtr, _שבחי_, ngsü
  { {0x96340010,0x15150033,0xa6340033,0xddc1003d}},	//   ануц, лдзя, ануі, volū
  { {0xcd78000a,0x5d78000a,0xf992004f,0x0000006a}},	//   תְּכ, תָּנ, _לרי_,
  { {0xa2c4005d,0x7a30007c,0x3e790003,0xe3c40015}},	//   _रिश्, _jätn, mète_, لْمَ
  { {0x3e790152,0x69c1005c,0xeb92000a,0x7a300123}},	//   lète_, ólew, צָא_, _mätn
  { {0x1fbd005d,0x6264005e,0x722b004a,0x7a2b0030}},	//   ोल्ड, авіа, ьцев_, _sütj
  { {0x3e790152,0xa06915f7,0xddc1003d,0x2247522a}},	//   nète_, нака_, solū, rink_
  { {0xe3b3002b,0xddc80046,0xd00e0058,0xdb1d0052}},	//   _خرس_, lidň, كلى_, ngsó
  { {0x63ad002e,0x3e790003,0xc27503ae,0xc35503ae}},	//   ðanu, hète_, _блај, _скај
  { {0x7c3f0007,0x96d5005d,0x63b900e7,0x9758000a}},	//   _įpra, यूयॉ, lawn, כיחו_
  { {0xe7c3000b,0x4c8601c5,0xbd45012c,0x98c0003d}},	//   षणाप, ллов, انجي, īrīt_
  { {0x98aa005c,0x41df000b,0xfaa63122,0xf7b20065}},	//   czbę_, प्रस, ламо, _ज़ेङ
  { {0xe4560053,0x76890091,0xeab10015,0xef0e165a}},	//   רירט_, _ažym, ْعِ_, _ум_
  { {0x628f0152,0xed59522b,0xd62201f3,0xa3e5000b}},	//   _écou, _пол_, мiна, _बॉस_
  { {0x68fb005c,0x5895000d,0x683140cf,0x2617000b}},	//   łudn, ишту, _såda, नानी_
  { {0xf772003b,0x96ba0015,0x248d0647,0x63b9002a}},	//   ماء_, فائز_, _niem_, jawn
  { {0x63b9005c,0x95fd000b,0xdb0f016e,0xc869000a}},	// [c8e0] dawn, ॉफ़्ट_, racã, ִן_
  { {0x3e790003,0x89aa00eb,0xe8fa100f,0x77831adc}},	//   bète_, _яков_, _зло_, слуз
  { {0x200f0020,0x89db000a,0x0000006a,0x0000006a}},	//   _ongi_, _אחיי,   ,
  { {0x44200084,0x98160015,0x7aeb0030,0x69c10030}},	//   ði_, _إبدا, _ímtá, ólev
  { {0xe2f80036,0x8bd7000a,0x23e500ce,0x248d522c}},	//   телі_, רונו_, рієв, _diem_
  { {0x200f06f5,0x366a0010,0xc693004f,0xc2e90058}},	//   _angi_, _чаго_, _לאש_, ضعهم_
  { {0x90e600e5,0x31c50033,0x63b9002a,0xc2070015}},	//   استن, рсів, bawn, طقين_
  { {0xc0e70015,0xa0670054,0xb97b0643,0x6aa4522d}},	//   افين_, лаја_, ענקי, _otif
  { {0x21a600af,0x0000006a,0x0000006a,0x0000006a}},	//   _бизм,   ,   ,
  { {0x6fa4000b,0xf297000a,0x248d002a,0x200f001a}},	//   _ग्रं, _עכבר_, _ziem_, _engi_
  { {0x51930029,0x7a30006f,0xbdf70015,0x3ea2003d}},	//   _المذ, _pätn, ارًا_, ūkt_
  { {0xc0a903c4,0xcbc70015,0xd12f0015,0x14d7000a}},	//   _شامل_, دزدي, _عمن_, נוכל_
  { {0x2617005d,0x16040065,0x0000006a,0x0000006a}},	//   नामी_, रयार_,   ,
  { {0xad260074,0x9f53005e,0xdb0f0144,0x69350b27}},	//   _مربو, _увіч, racà, ангу
  { {0x6cc60010,0x1134000a,0xe8f80033,0x3e8b000a}},	//   _сёле, בָּר_, ллё_, _אָהֳ
  { {0x3e790152,0x5b250015,0xfbdf059d,0x0000006a}},	//   rète_, _نفعل, rnês_,
  { {0xd6970015,0xceb90046,0x36d50296,0x35b50912}},	// [c8f0] اشرة, tyři_, розр, ибар
  { {0x26c7065d,0x2d9e0abc,0x3b09522e,0x6f79000a}},	//   čno_, ncte_, _iraq_, דְעו
  { {0xfbdf0092,0x248d0024,0x6838002e,0x63b9002a}},	//   hiêm_, _piem_, _bídd, tawn
  { {0x81bc0024,0xe3b00029,0xe44e0127,0x7a30007c}},	//   _slēp, كره_, іж_, _lätl
  { {0x77ba009d,0xf7d60008,0x63b910ec,0x248d006f}},	//   _במרח, _דורש_, rawn, _viem_
  { {0x248d005c,0xe1250004,0x65940323,0x64b70015}},	//   _wiem_, имли, _гару, _محرر
  { {0x248d0048,0x2c4f002a,0x81f60015,0xd6a502a3}},	//   _tiem_, lędu_, شفير_, гiчн
  { {0x2d9e0011,0x63ad0077,0x7aed1827,0x6025033d}},	//   ecte_, ñand, _opat, рдиа
  { {0x200302d5,0x644b0035,0x8f75005e,0xb3a90061}},	//   ěji_, migi, шукі, ğıdı
  { {0x7d090001,0xcee800a2,0xa267006b,0xb3a90061}},	//   вног_, ارين_, _събл, şıdı
  { {0x59dc000b,0x7aed522f,0x3cc9006b,0xed591d8a}},	//   _बाबर, _apat, ълно_, тон_
  { {0xe0d00067,0xa09a000a,0x69c50390,0x408702d9}},	//   _رزم_, _סינט, _adhe, _сузб
  { {0x644b0020,0x628f0152,0x441a000a,0x9f05002b}},	//   iigi, _écos, דורס, _خوشو
  { {0x644b0035,0xa2cd000b,0x2605000b,0xa3e5000b}},	//   higi, _सिन्, _होली_, ब्त_
  { {0x2ba7005d,0x69d7005d,0xdb0f0c23,0xd7f20015}},	//   _क्वा, _बारी, racá, يكس_
  { {0xb8ee000b,0xa3e5000b,0x7a305230,0x7c8500af}},	//   _रि_, _बॉल_, _täto, _луње
  { {0x6aa400c0,0x78a501f0,0x644b5231,0xde880016}},	// [c900] _utif, _ethv, digi, _kịp_
  { {0x644b0007,0xc4c60015,0xbdf5000a,0x4b7b0643}},	//   eigi, لتصو, יֶ֣ה_, _באפו
  { {0x1ddd005d,0x7a300020,0x26d2003f,0x644b10e0}},	//   _मानत, _jätm, suyo_, figi
  { {0x644b00b6,0x3ebf00f2,0x7aed0007,0x73e602e1}},	//   gigi, ksut_, _ypat, родз
  { {0xa3e5005d,0x69c1002e,0xd36f0029,0x41b60015}},	//   ब्ध_, ðleg, وهم_, لمشر
  { {0x12a90029,0xe5ec008c,0x644b0091,0xda19000b}},	//   ادنى_, änää, aigi, दायत_
  { {0x00d70015,0x26c00091,0x8a17000a,0x7a300123}},	//   لبيت_, lsio_, יחסו_, _nätm
  { {0xa3e50372,0x7c240152,0xc7a9000a,0xdfd00015}},	//   ब्द_, _noir, ְׁתָ, أية_
  { {0xfba7005d,0xdcee0089,0xd007049d,0xc2e90087}},	//   _क्षम, ědči, рење_, _معلم_
  { {0x26c00026,0x1e340010,0x44245232,0x7ee30033}},	//   isio_, сноў, _hom_, іцые
  { {0xde880092,0x2c4f005c,0x2617000b,0x8597004c}},	//   _dịp_, zędu_, नाती_, ידיג_
  { {0x442400d9,0x7c24002d,0xa2cd000b,0x628f0003}},	//   _jom_, _coir, _सिम्, _écor
  { {0x7c24002d,0x2f0f002e,0x44243562,0xdb5b0c30}},	//   _doir, rögð_, _mom_, тюн_
  { {0xfba7005d,0x644b0111,0x3e340086,0x2ba7005d}},	//   _क्रम, zigi, _دفتر, _क्रा
  { {0x7c244611,0x3cf70015,0x8e7b000a,0x7aed002a}},	//   _foir, _نعيد_, _שנוה, _wpat
  { {0x44245233,0x6e230030,0x6e2e0030,0x2c7b003d}},	//   _nom_, _zonb, öbbf, _lūdz_
  { {0x69c1005c,0x7aed003f,0x6c840015,0xd5bb004a}},	// [c910] óles, _upat, _بليم, все_
  { {0x5afc000a,0xa2cd000b,0x160e000b,0x644b5234}},	//   _ילחצ, _सिब्, सागर_, wigi
  { {0x94750086,0xd9190008,0x44245235,0x6838013f}},	//   مگرا, _עוֹל, _bom_, _síde
  { {0x44245236,0x3ea60049,0xdc9b000a,0x2c4f002a}},	//   _com_, _otot_, דיאל, pędu_
  { {0x26c00026,0x15ff000b,0x26cf0030,0x644b2fb1}},	//   csio_, _उसपर_, ágod_, rigi
  { {0x644b5237,0xdb060107,0x4b38000a,0xc244022a}},	//   sigi, jaký, סרגל_, онік
  { {0x644b198e,0xe4a40004,0xd65c0033,0xc5f2000a}},	//   pigi, _мрто, нiцк, _מדם_
  { {0x39580008,0x397c0053,0x2ba7005d,0xf9580008}},	//   ישום_, כטונ, _क्ला, יסות_
  { {0x6f180010,0x600604ab,0x64490c59,0x1ea90015}},	//   ацэс_, сным_, _imei, داعي_
  { {0x30e70191,0x7a2b0020,0xfe450080,0xee36044e}},	//   _відб, _kütu, ённо, йны_
  { {0x2c7200dc,0x2fd903c4,0x3ebf008c,0xfe6e002b}},	//   ládi_, _مواد_, ssut_, رگه_
  { {0xca2901c8,0x6f950029,0x5f950015,0x38c8002b}},	//   _אם_, _الإض, _الإئ, یازی_
  { {0x7c240152,0x5ea50015,0x7f850015,0x1ae3008b}},	//   _voir, _امتل, _الشن, поям
  { {0xa2da005d,0x6e3a237b,0xff50002b,0x3b830033}},	//   _नमस्, chtb, _تخم_, яляг
  { {0xe8560029,0xcdb60008,0x26c00026,0x7c24002d}},	//   منسد, _הפצה_, wsio_, _toir
  { {0xccf20008,0x1cb6000a,0x7a30019a,0x26c05238}},	//   _זכה_, _פלפל_, _kätk, tsio_
  { {0x7a300005,0x26c0122e,0x2498007c,0x29050123}},	// [c920] _jätk, usio_, _surm_, ålar_
  { {0x26c0191a,0xa3e5000b,0x44240078,0xda660021}},	//   rsio_, ब्स_, _som_, _داعي
  { {0x672d003f,0xdcea0085,0x69fb0643,0x44245239}},	//   ayaj, čiće, _גליק, _pom_
  { {0x74690036,0xc3d60015,0xf487002b,0xe29a0033}},	//   арів_, إغاث, مانی, гад_
  { {0x4424523a,0xa2cd000b,0x96ba0015,0x7a300123}},	//   _vom_, _सिण्, _حاجز_, _nätk
  { {0xc5d50191,0x78a2016f,0xdb06005c,0x24980012}},	//   _місь, _čovj, lakó, _turm_
  { {0xa2c4005d,0x6ab60026,0x50f40036,0x44244dcd}},	//   _रिक्, _lwyf, ізит, _tom_
  { {0x50b700e6,0x8557000a,0x80a30015,0x7a2b0012}},	//   حدود_, _השלב_, أمين, _hütt
  { {0xa0670001,0x7a2b0020,0x2417000a,0x2bbe000b}},	//   љања_, _kütt, _פחמן_, ्णना
  { {0xa3c2014e,0xd337000a,0x5d54006b,0x9963006f}},	//   ूलक_, _הרמה_, жкот, _líši_
  { {0xdd900074,0x40960029,0xdb1d0c77,0x7a2b523b}},	//   بود_, _الصر, ngsö, _mütt
  { {0x7e6800dc,0xfbab004a,0xd0100015,0x63a2523c}},	//   sodp, ытой_, _زلت_, ncon
  { {0x7e680cbc,0x63a2523d,0x600b000a,0x5ba40033}},	//   podp, icon, _תִבְ, ярэз
  { {0x6ab60034,0x60cd003d,0xdb500015,0xbef7004f}},	//   _dwyf, ņame, رَّ_, _לצדו_
  { {0x28d9014e,0x48770029,0xd90f002b,0x63a20079}},	//   बंधि, مدرس, ریح_, kcon
  { {0x98a50064,0xdb0f0125,0x6ab60034,0xed5f0046}},	//   çlı_, ódói, _fwyf, ážek_
  { {0x7a2b0064,0xdb1f00f2,0xddda003d,0xd7c80015}},	// [c930] _sütu, äväl, rotņ, صوله_
  { {0x63a2523e,0xfb1c004f,0x28d90065,0x058702ed}},	//   econ, _תוזמ, बंदि, буем
  { {0xf7950033,0x6d5d0061,0xdb1d0123,0xdb0613c3}},	//   _манэ, şsav, ggsö, zakü
  { {0x69d801d1,0xa2cd005d,0xd3750001,0xbec20024}},	//   _över, _सिद्, олећ, _ķīna
  { {0x387e038d,0x7a2b0012,0x7bdf523f,0xfa6b004f}},	//   ître_, _fütt, _mcqu, ְכֶּ
  { {0x27e90176,0x644800df,0xd25b0010,0x7abc000a}},	//   lfan_, _įdie, ыце_, רצגו
  { {0x2bbe000b,0x008502c8,0x63a22a7a,0xe12502ed}},	//   ्णमा, олко, bcon, юмки
  { {0x2bdb005d,0x6449003f,0x63a2094c,0x2617005d}},	//   _भाषा, _umei, ccon, नावी_
  { {0x29040024,0x32550010,0xcdf50256,0x2a6a0030}},	//   āmai_, _двар, очны, yobb_
  { {0xa6e20084,0x926b0001,0x02440029,0xfe450036}},	//   æðin, _срба_, _فَقَ, інно
  { {0xcb0901c8,0x2c560024,0x63bb0049,0x61550021}},	//   _של_, lādi_, _keun, _بنائ
  { {0x63bb038d,0x59dc005d,0x20030024,0x629b003f}},	//   _jeun, _बाहर, ējis_, _kuuo
  { {0x27e90026,0xa3e1021e,0x2c560024,0x9963006f}},	//   dfan_, _दान_, nādi_, _ríši_
  { {0x27e90034,0xaa7b0046,0x1d09033d,0x3ead5240}},	//   efan_, stýn, _веки_, mpet_
  { {0xfe790089,0x27e90026,0x6e2e00dc,0x160d005d}},	//   ntům_, ffan_, öbbe, _सफ़र_
  { {0x7b09002e,0xd7f20015,0xe7aa08a6,0x2c56003d}},	//   óstþ, بكر_, рвал_, kādi_
  { {0x2c560048,0xe64a0010,0xdb0d001c,0x7a30007c}},	// [c940] jādi_, апад_, _reaç, _läti
  { {0xfe790046,0xe61704ca,0x64595241,0xdb060535}},	//   ktům_, оду_, enwi, sakó
  { {0x69dc0084,0xd4c60015,0x73c60015,0xa507006b}},	//   mgre, تغذي, قيام, жеха_
  { {0x69dc074c,0x87d60806,0x99d6002b,0x130a0121}},	//   lgre, _بغدا, _اتکا, иней_
  { {0x6281002f,0x63bb0026,0x2c560024,0x69dc0085}},	//   _bhlo, _deun, gādi_, ogre
  { {0xa5d8000a,0x999a000a,0xc4c60015,0x63a21139}},	//   _לַֽי, ׁבְט, _وتزو, scon
  { {0x63a2372c,0x40340033,0x6ab7000b,0x80a3012c}},	//   pcon, зейс, _अब्र, ومون
  { {0x2120010b,0xf9930008,0x3ae40123,0x232a067a}},	//   ćih_, ורו_, köp_, _коби_
  { {0x31690064,0x1eaa0015,0x2be1000b,0xd80b000a}},	//   ğaza_, جابي_, _काबू_, בִיָ
  { {0xf773000a,0xdd91002b,0xfe720015,0x200219c2}},	//   וקח_, کوپ_, بدع_, žki_
  { {0xafe60191,0xc2230086,0x859b0008,0x27e90026}},	//   _можл, _تکنو, ישיו, yfan_
  { {0x1ee9002b,0x61f8080d,0x69dc5242,0x60660058}},	//   جویی_, levl, egre, _بهؤل
  { {0xfad80063,0x69dc2061,0x7de6005e,0x6d415243}},	//   одящ_, fgre, _дійд, azla
  { {0xfc460084,0xa2cd005d,0x68fc0026,0xb95b0015}},	//   _þína_, _सिस्, fwrd, لجزء_
  { {0x2605014e,0x7a3f02d5,0xf84b0033,0x1994070c}},	//   _होगी_, vště, ачай_, даря
  { {0x64830020,0xdc2b002b,0x6934005e,0x7d1c014b}},	//   mõig, _خسته_, єнту, ärsu
  { {0x27e90026,0x6be80008,0x7aa70015,0x17f80015}},	// [c950] rfan_, _וַתַ, _بإبل, غرفة_
  { {0x7a3f0089,0x1a650086,0xcaf4002b,0x2ba7000b}},	//   uště, _ریزی_, _آسيب, कुरा
  { {0xf9fa0008,0x93f5005e,0xe4cb0015,0x6f090046}},	//   _ההתמ, зпец, شبان_, zvec
  { {0x2c560024,0x7afd1e32,0xe3c50015,0x7bdd5244}},	//   tādi_, owst, سْتَ, ngsu
  { {0xe2a30092,0xe2990a32,0x78a20085,0x6831194e}},	//   _giữ_, щал_, _čovi, _rådh
  { {0x2c560024,0x960b0010,0xddda0089,0xcad8000a}},	//   rādi_, _тэма_, potř, קוות_
  { {0x63f70015,0x10a2006b,0x88cb000a,0x7a0f0091}},	//   _وأرر, нищн, ׁמַ֖, mėtė
  { {0x6f0900c0,0x895c000a,0x7a0f0091,0x83870033}},	//   tvec, ידות, lėtė, _дызе
  { {0xed630089,0xfe790046,0x69dc377d,0xef1608f0}},	//   _mužů_, stům_, ygre, змы_
  { {0x7a3000b8,0xb77c0053,0xfe420063,0x6f095245}},	//   _täti, סאזש, еньо, rvec
  { {0xfbdf0016,0x69dc00cb,0x6f0915e9,0xf4b902a3}},	//   hiêu_, vgre, svec, алiз_
  { {0x7188000a,0x3ead0613,0x7536004c,0x6a7202de}},	//   _וְנַ, ppet_, פארד_, hæft
  { {0x7c950086,0xc0520053,0x207a004c,0x6e360030}},	//   _کشتا, _אזא_, _פאנא, ágbó
  { {0x7bdd0035,0xac96002b,0x69dc0012,0x99980091}},	//   agsu, _کنيا_, ugre, virų_
  { {0x69dc5246,0x7d1c038f,0x59750138,0x0000006a}},	//   rgre, ärst, дыту,
  { {0x7a3001d1,0xfc3f002d,0xb8f4000b,0x7d760015}},	//   _nätv, chí_, _हट_, _عمير_
  { {0xfc570008,0xdc3b000a,0x7bdb000a,0x9c850058}},	// [c960] _מבקש_, _לעקר, _הקפו, _تشوه
  { {0xd6cf0031,0x1be8000b,0x68fc0034,0x0000006a}},	//   اقل_, ट्रल_, pwrd,
  { {0xb3a901e2,0xda650086,0x999b0008,0x399b00f3}},	//   ğını, _تايي, _לביט, _לייד
  { {0xb3a90064,0x14590010,0xd91b000a,0x0000006a}},	//   şını, ошчы_, _הוטל,
  { {0x7d06003d,0xe3c30015,0xd4671377,0x46a30138}},	//   āksi, رْوَ, чице_, _паяв
  { {0xd5b200b0,0xa2cd005d,0x68310134,0x56930010}},	//   _سفر_, _सिर्, _rådi, _паўт
  { {0x490f014e,0x463b0053,0x61f80700,0xa1930033}},	//   डियो_, _פעלע, revl, нашч
  { {0x8f46010f,0xf9930008,0x155b000a,0xdb0f006f}},	//   зход, ערה_, _הכלב, racú
  { {0x141b0008,0x2c56003d,0xb69b0045,0x9ee70015}},	//   _פומב, nādu_, _urât, كفيل_
  { {0x2d980293,0x55bc000a,0x7bc0001a,0x68380077}},	//   øre_, ׁמ֖ו, ðmun, _oído
  { {0xfc3f002d,0xdd900021,0x1ddd000b,0x6fd60061}},	//   thí_, ضوح_, _मारत, gücü
  { {0x2fc00084,0x2c560024,0xa137000a,0xa157004f}},	//   _þig_, kādu_, _מאבק_, _צבאה_
  { {0x64830020,0x7afd0111,0xda19000b,0x6fb30015}},	//   sõig, uwst, दालत_, _أمها
  { {0x7de6002b,0x4efb000a,0x6f0224bd,0x0000006a}},	//   _رستم, _להדו, _isoc,
  { {0x68380046,0xd9140033,0xa87b0015,0x7d1c0804}},	//   _vídn, ндры, محرر_, årsd
  { {0xa2cd000b,0x6e2a5247,0xbd5b004f,0x0000006a}},	//   _सिल्, _hofb, _לכוש,
  { {0x387e0152,0x4993002b,0xfe780091,0xd7770058}},	// [c970] îtra_, بیگر, olį_, سارع
  { {0xdce30089,0x6aad003f,0xbb3c000a,0xc58b004a}},	//   _nyně, _itaf, _לתחז, бщее_
  { {0xa8a40063,0x6a720134,0xdb04001a,0xd5b806eb}},	//   _пряк, ræft, _heið, яст_
  { {0x442909f0,0x68380046,0x20060125,0x9419013e}},	//   ða_, _jídl, _naoi_, южет_
  { {0xfe780007,0xc7d6000a,0xc2c40015,0x15ab006b}},	//   klį_, _קושי_, فيني, _гъби_
  { {0x6aad003f,0x9165002b,0xb6040033,0xd49b2e06}},	//   _mtaf, وهشه, _пяск, _гра_
  { {0xdb040084,0x94770086,0x44290092,0x208909ef}},	//   _leið, _فدرا, ưa_, ойки_
  { {0x7a3000b8,0xc9180008,0xdb0600dc,0x2006002d}},	//   _hätt, לחות_, makö, _caoi_
  { {0x7a300005,0x1f6503e7,0xef19005e,0x72d4012e}},	//   _kätt, ьким, імо_, _потф
  { {0x7bcd0011,0x64830020,0x82380033,0xd1b80015}},	//   _adau, sõid, _езус_, _فاما_
  { {0x2006017e,0x6607016f,0x63a4001a,0x634f0030}},	//   _faoi_, _majk, þing, _főnö
  { {0xdb040084,0x7a3000c0,0x01640029,0xbf190015}},	//   _beið, _lätt, _ثُمَ, _وقاص_
  { {0x2024002c,0x15ff000b,0x8d77002b,0x63a40091}},	//   úsiť_, ैयार_, _کاشا, žing
  { {0x3e6a0086,0xdb06171f,0x66071822,0x7a300123}},	//   _وجوی_, kakö, _najk, _nätt
  { {0xe9a30033,0x26cf0030,0x2cb90021,0x63a91a2a}},	//   тасп, ágon_, _بُعد_, _ofen
  { {0xf772003b,0x9cd6000a,0x2c56003d,0xb7da0015}},	//   ناء_, _חוקה_, tādu_, تورا_
  { {0x7a3000c0,0x2fc00020,0xb3a90064,0xd6a50033}},	// [c980] _bätt, _õige_, ğılı, гiён
  { {0xb3a90064,0x7b040024,0xaae50015,0x2c56003d}},	//   şılı, ēttī, _أسيو, rādu_
  { {0x290403eb,0xe4a50036,0xb5a90015,0x92a3002a}},	//   āmas_, еріо, سالك_, ółno
  { {0x25fa005d,0xc5e90008,0x6d4e0125,0xf8b3004f}},	//   _उसकी_, יד_, úbai, _ששר_
  { {0xd7fb000a,0x57fb000a,0x2907001a,0x38650030}},	//   _והכל, _ולכו, _ánar_, élre_
  { {0x999a0046,0x15f8000a,0x27e05248,0x7a30008c}},	//   _popř_, _מִֽמ, lgin_, _tätu
  { {0x63a95249,0x2c0e005d,0xe1380010,0x2c560024}},	//   _ffen, ियां_, язкі_, nāds_
  { {0xf484002b,0xd0070054,0x64160015,0x7416006e}},	//   _سازی, деће_, _تورط, _تورا
  { {0x6442002d,0x7a30007c,0x27e0524a,0x2c5601ec}},	//   mhoi, _jäts, igin_, hāds_
  { {0x4426018c,0xddc8524b,0xdb04002e,0x68380057}},	//   ljo_, widł, _reið, _sídl
  { {0x828b011f,0x7af60007,0xda22005d,0x25d7000f}},	//   _וְאֶ, _apyt, मानत_, ווין_
  { {0xbc4b0036,0x644200f2,0x3cdf000b,0x4426524c}},	//   ічне_, nhoi, _कमरे_, njo_
  { {0x5e260029,0xd3660086,0xf0470086,0x7a300ca0}},	//   _يعتق, اه_, _تعلی, _näts
  { {0xc333039e,0xd12600e5,0xdb04001a,0x27e0042f}},	//   דוש_, هم_, _veið, egin_
  { {0x7a3001d1,0xdb1d002e,0xfdf70135,0x8c670c96}},	//   _rätt, masí, _חצות_, _отид
  { {0xb8f7000b,0x984b0033,0x7a30524d,0xdb1d524e}},	//   _सि_, цяга_, _sätt, lasí
  { {0x6aad0f4d,0xf7700029,0x929d005c,0x290c0123}},	// [c990] _utaf, لاك_, _osła, ådar_
  { {0xb3a90064,0xdb1d001a,0x7c2d524f,0xdb060061}},	//   ğımı, nasí, _hoar, takö
  { {0x38c90086,0xb3a90064,0x64420125,0x7c2d0cc1}},	//   _عادی_, şımı, fhoi, _koar
  { {0xfd57000a,0x920701ec,0x0000006a,0x0000006a}},	//   ושבי_, igāš,   ,
  { {0x7c2d0011,0x160a005d,0xd3010010,0xc7d6000f}},	//   _moar, _होकर_, _мiнс, _אורי_
  { {0x13080036,0x76ba0008,0xd1c50015,0x44260077}},	//   ьній_, _ממשפ, ريبً, ajo_
  { {0xa9bc000a,0xa3d5005e,0xf652004f,0xd3f40138}},	//   חזור, _повч, _עצל_, _вiрт
  { {0xf088002b,0x64425250,0x2c640061,0x8998000a}},	//   وئيه_, choi, kıda_, וכוס_
  { {0x8e550484,0x97a8000a,0x64580144,0xda0f000b}},	//   етні, וֹתֵ, èvie, ायात_
  { {0x442d00f6,0x7bda0007,0x1d2501c5,0xe2170015}},	//   _hoe_, ėtum, емом, _تبرع
  { {0xc19a0053,0x63a40007,0x7c2d5251,0xc5f200f3}},	//   _זשעי, žine, _boar, נדט_
  { {0xcfe90086,0xa0080015,0x644a0003,0x442d157c}},	//   _رفته_, _يقلل_, éfix, _joe_
  { {0x7ee40029,0x7c2d13e3,0x929d002a,0x442d3602}},	//   _لكنن, _doar, _ysła, _moe_
  { {0x442d0005,0x0f56013a,0x443f0026,0x7a30038c}},	//   _loe_, _אינם_, _llu_, _räts
  { {0x3da60191,0x7c2d04f9,0x2955006b,0x6d320015}},	//   _якщо_, _foar, вътр, _مفوض
  { {0x442d003c,0x02df005d,0x7b0500f2,0xdcf8003d}},	//   _noe_, _नमून, ättä, _uzvā
  { {0x2c640061,0x27e05252,0x442600bc,0x5a960c02}},	// [c9a0] cıda_, rgin_, vjo_, _проф
  { {0x4aa5005d,0x7bc62f12,0x7a300123,0x6b842bb9}},	//   _गंतव, laku, _väts, _izig
  { {0x6442002f,0x443f5253,0x6c9a000a,0x44265254}},	//   thoi, _blu_, ִשְׂ, tjo_
  { {0x7bc65255,0xeb3a000a,0xab5b007c,0xdb1d0046}},	//   naku, ּעַש, kaül, zasí
  { {0x68e327a9,0x442d3883,0x7794002b,0x44265256}},	//   _ändr, _doe_, _شیطا, rjo_
  { {0x443f0020,0x64420020,0x237a0024,0x673600f2}},	//   _elu_, shoi, āpj_, myyj
  { {0x6442002f,0x7bc62aa7,0x443f22bc,0x442d00da}},	//   phoi, kaku, _flu_, _foe_
  { {0x2c640064,0x7bc62023,0x38605257,0x68e301de}},	//   yıda_, jaku, nnir_, _ånde
  { {0xdb1d0014,0xcee70001,0x3860002e,0x044303de}},	//   tasí, едње_, inir_, _сетн
  { {0xdea3002b,0x7c2d5078,0x442d44d4,0x443f01ea}},	//   دیوی, _soar, _zoe_, _zlu_
  { {0x3860002e,0x7c2d0011,0xc5f3000a,0x0657000a}},	//   knir_, _poar, אדת_, תייך_
  { {0xf537000a,0x9207003d,0x629a5258,0x2c640061}},	//   גנטי_, rgāš, _hito, tıda_
  { {0x629a229a,0xdd2d002c,0xbb940080,0x2aab03ad}},	//   _kito, hŕňa, лающ, ятно_
  { {0x2c640064,0xaf070015,0x26cf0030,0x38605259}},	//   rıda_, _أقوم_, ágom_, enir_
  { {0x6e3500dc,0x38601d06,0x427b004c,0x28870054}},	//   özbe, fnir_, פאלג, ећав
  { {0x6d7b013a,0xc6a70ac7,0x3860002e,0xdd7b000a}},	//   _מאוח, ержи, gnir_, _מטול
  { {0xe9f90016,0xd6d803ae,0xcff7000a,0xe699006b}},	// [c9b0] _cuả_, етх_, עצמה_, дваш_
  { {0xe784000d,0x629a0035,0x6440525a,0x5678004a}},	//   ѓуто, _nito, _almi, ебуя_
  { {0xdfc6002b,0x9475002b,0xd9440004,0x9327002b}},	//   _پي_, نگرا, _беќи, کران
  { {0x13a70086,0x63a50089,0xe3b30115,0x5455006b}},	//   رنتی_, ěhno, ارض_, ъвет
  { {0xe6950015,0x91e5525b,0x442d525c,0xe7840974}},	//   _للحد, воле, _voe_, _буро
  { {0xa294005e,0xab5b007c,0x69c7525d,0x442d00da}},	//   гачі, vaül, naje, _woe_
  { {0xf1a70086,0x90890029,0x784c0064,0xa2cd005d}},	//   واژه_, ونتك_, aşvu, _सिक्
  { {0x6288022d,0x64580003,0x6d48003d,0x3494525e}},	//   _ehdo, évit, dzda, _баср
  { {0x6006054f,0x8464006b,0x046402d9,0xaec20174}},	//   тным_, _съре, _стрм, абыл
  { {0x7bc6003f,0x21a40015,0x14d5000a,0x69c71009}},	//   waku, _ممكّ, ֣וֹל_, jaje
  { {0x6b8400dc,0x0d820a7f,0x7bc60d06,0xdce3003d}},	//   _szig, ильн, taku, _iznī
  { {0x9ee90015,0x40350004,0x69d80030,0xfaa6243d}},	//   _يفضل_, _шеес, _övez, камо
  { {0xdb1d001c,0xde0510a6,0x3af50a1f,0x6d48525f}},	//   vasã, _апли, лярс, azda
  { {0xc332013a,0x7bc64e87,0xef84005e,0x69c70022}},	//   סום_, saku, _сліп, gaje
  { {0x64430024,0x3860002e,0x929d002a,0xc0ac000a}},	//   īnij, tnir_, _osło, ּימָ
  { {0x69c700f2,0x3860002e,0x64430007,0x4d7a000a}},	//   aaje, unir_, ūnij, _קרקע
  { {0xe9f90023,0x38601f9d,0xa2cd000b,0x8cbd000b}},	// [c9c0] _quả_, rnir_, _सिग्, वीरो
  { {0x6838001c,0x69c75260,0x3860001a,0x65960040}},	//   _mídi, caje, snir_, نجار
  { {0x629a04ed,0x69d90053,0x95960054,0x3860001a}},	//   _rito, _אַרו, траљ, pnir_
  { {0xb2c60029,0x77940086,0x6aa40297,0x629a5261}},	//   نغتو, _میزا, _kuif, _sito
  { {0x6aa40152,0x031a0015,0xddda1147,0x629a5262}},	//   _juif, بتات_, ultū, _pito
  { {0x7bc40020,0x53331b07,0x27f20034,0x9c7d0085}},	//   _leiu, решт, lfyn_, muče
  { {0x25760074,0x64580152,0x27f20026,0xa3ea000b}},	//   _شهرس, évis, ofyn_, _माप_
  { {0xdfd00029,0x69c706e7,0x6d4801c9,0x629a002a}},	//   حية_, zaje, vzda, _wito
  { {0x629a40df,0x26c70085,0x82a60daf,0x987b000a}},	//   _tito, ćnog_, _разж, ואקט
  { {0x4375008f,0x201d0026,0x629a0079,0x200d0045}},	//   _суст, _enwi_, _uito, adei_
  { {0xdb1d0030,0xa113002b,0xee77002b,0xec33002b}},	//   dasá, _پونت, خصيت_, لودگ
  { {0x26cf00dc,0xa3ea000b,0xb5820033,0x0000006a}},	//   ágok_, _माफ_, ынiк,
  { {0xa3ea005d,0x9c7d02c6,0x4fd7000a,0x3ed40015}},	//   _मान_, juče, _יואב_, _إقتر
  { {0x4af6002b,0xaa6405c1,0xee370597,0x3ea20052}},	//   اکيد_, атск, _инч_, íktu_
  { {0x27f20026,0xfe9b0008,0xdb0f02c1,0x2c4f002a}},	//   ffyn_, _קיומ, tacó, zędy_
  { {0x6ebf005d,0x69c70531,0x320c1650,0xd7020033}},	//   लीवु, saje, _lady_, зiра
  { {0x97150010,0xf1b4000b,0xe89401c5,0xe758005e}},	// [c9d0] ымац, ुरान, рать, виті_
  { {0x2cb30046,0x7c3d5263,0xd5d40058,0x7a2b026c}},	//   řadů_, lksr, لتمث, _lütz
  { {0xfa340086,0x9783002b,0xb4d5006b,0x657c0034}},	//   _خريد, _چیزه, ужещ, _cyrh
  { {0xccf300b2,0x8d5b0008,0x7a2b00b8,0xd6db006b}},	//   יכע_, וכבי, _nütz, _отг_
  { {0x64580251,0x69c50509,0x62351299,0x7c3d0547}},	//   èvia, _kehe, леду, iksr
  { {0x11d90029,0xbb3c000f,0xd6870054,0x69c50012}},	//   روعة_, ועדי, _јумп, _jehe
  { {0x41e40036,0x70f50015,0x90e40015,0x657c0034}},	//   річа, استئ, لسين, _gyrh
  { {0x69c506fa,0x999c000a,0x1ee7002b,0xc2c500c3}},	//   _lehe, ובוט, نوبی_, _ميري
  { {0xcf250015,0xe8e10016,0xdea4002b,0x23770058}},	//   ارعي, _ướp_, لینی, _شارح
  { {0x645910ec,0x41c7000b,0x51f8004a,0x6e450015}},	//   liwi, _रजिस, _иную_, اندم
  { {0xdb1d00dc,0x3e550046,0xf1b2000a,0x9cb2002b}},	//   vasá, větě_, _הסב_, یمیت
  { {0xe572000f,0x9f0500e6,0xa156000a,0x64590535}},	//   מַר_, _موصو, _גבעה_, niwi
  { {0xc0b90089,0xcf27002b,0x69c50106,0xeb97004a}},	//   žádá, _جراي, _behe, лию_
  { {0x9c7d016f,0xfce50e77,0xdea1002b,0x6459002a}},	//   vuče, _боко, _پیگی, hiwi
  { {0xd9430c9c,0x99860015,0xa2ca000b,0xa967029b}},	//   бери, الأو, _सौन्, гира_
  { {0x2b550086,0xa7b50001,0x2c1a005d,0xdb1d00dc}},	//   ایید_, исуј, धाओं_, sasá
  { {0x27f23dc5,0x69c50034,0xc0ee0016,0x17862df1}},	// [c9e0] rfyn_, _fehe, _bướu_, угам
  { {0xceb2013a,0xdb9b000a,0x7abb000a,0x95c60015}},	//   ציב_, _אספר, _רציו, اياه
  { {0x99160010,0x320c5264,0xa2c10065,0x0000006a}},	//   _сьпі, _rady_, रीस्,
  { {0x320c5265,0xb4c4000b,0x69c50012,0x82a60151}},	//   _sady_, _एबी_, _zehe, гадж
  { {0x7054002b,0x69c502f2,0x0000006a,0x0000006a}},	//   ینتا, _yehe,   ,
  { {0x93590063,0xc2c30015,0xf1aa0040,0xc4c6012c}},	//   ърху_, حيوي, راته_, _مترو
  { {0xca7b00b2,0x69c1002e,0xf0b7002b,0x2936004c}},	//   ענצט, ðlei, هايش_, טאַן_
  { {0x6459005c,0xc034009c,0xab5b007c,0x7537004c}},	//   ciwi, рниј, baüh, _גאלד_
  { {0x320c0089,0x627b005c,0x44ee0107,0xc7b3000a}},	//   _tady_, _słoń, lý_, זבח_
  { {0x1ef7003b,0x98ac0089,0xa2d30015,0x9e0601d2}},	//   اعية_, ádě_, _ديكت, учил
  { {0x2fe60029,0xd6220010,0x44ee0107,0x1677000a}},	//   _مكاف, лiка, ný_, רגיל_
  { {0xa2db014e,0x69c55266,0xcff5002b,0x660e003d}},	//   _निम्, _sehe, _نيمک, _labk
  { {0x98aa00df,0xe4570053,0x4ae70010,0x44ee0264}},	//   mybę_, ריכט_, ыўна, hý_
  { {0x44ee0264,0x645912d1,0xdd940033,0xceb3000a}},	//   ký_, ziwi, _калы, _היס_
  { {0x199536bb,0x8e57000a,0xc0d4000a,0x69c55267}},	//   равя, _תיוג_, יֵּה_, _vehe
  { {0x36d50080,0x98aa0091,0x57b5070f,0x69c50012}},	//   иобр, nybę_, рбат, _wehe
  { {0x69c55268,0xda6700c3,0x4905000b,0x865542f5}},	// [c9f0] _tehe, _مادي, _हैरो_, аках
  { {0x81c20024,0xd7880015,0x45d509b1,0x494702ed}},	//   šēja, انكو_, рожс, _бэмб
  { {0x6459020a,0xc668000d,0x98aa0007,0x3ea600f2}},	//   tiwi, уште_, kybę_, _luot_
  { {0xe3150001,0xdd000091,0xa3ea0065,0x8d77004f}},	//   имењ, štėj, _माण_, נגאו_
  { {0x61fc00dc,0x645900e8,0x339b0015,0x386c01d3}},	//   _űrla, riwi, رخصة_, édre_
  { {0x86270010,0xd5f90053,0x8505002b,0xa2c1000b}},	//   _сьме, _בפֿר, _پورن, रीष्
  { {0x90c20b18,0xda4c000a,0x349500ce,0xfc3f0052}},	//   обще, עֲדָ, _вавр, kkí_
  { {0x44d10780,0x6838002e,0x98aa0007,0xc0a80115}},	//   mą_, _fídu, gybę_, داول_
  { {0xfe45000d,0x44d1086a,0x3f990020,0x41e70031}},	//   инио, lą_, äsu_, _مساف
  { {0xee36005f,0xe0d50054,0xee39016a,0x8ea40058}},	//   ины_, _вожњ, тно_, حصين
  { {0x44d10713,0x21670010,0x611c0011,0x4905000b}},	//   ną_, _стаг, _călă, _हैलो_
  { {0x44d10870,0xed560839,0x5c560195,0x9b460015}},	//   ią_, рою_, ртоф, لنجو
  { {0xfaa62c2a,0x9e64002b,0xdb1d007c,0x4c6701b7}},	//   раго, شاین, jasä, риян_
  { {0x44d10b53,0x7f840029,0x200f0acf,0x0dcb0763}},	//   ką_, _الهن, _hagi_, _чуди_
  { {0x5d7900b2,0x44d12aec,0xa85603ae,0xfce50204}},	//   _באַק, ją_, атај, _тойо
  { {0xe80d005d,0x44ee04af,0x44d110da,0xb8ce000b}},	//   ाएगा_, vý_, dą_, _ओं_
  { {0xe737005f,0xf5b60015,0xbc7b000a,0x200f5269}},	// [ca00] ает_, لصاد, _שנפת, _magi_
  { {0x2ca700c0,0x7c210024,0x59760010,0xaa7b002e}},	//   _kund_, ēlre, _выму, stýr
  { {0x89db0008,0x9c7d016f,0x44d120b0,0x09f7000a}},	//   _בחיי, luča, gą_, _דמים_
  { {0x04460124,0x44ee0156,0x9c7d0089,0x7cf6004c}},	//   једн, rý_, ouča, יזעס_
  { {0x63a400df,0x98aa0007,0xddc100bc,0x2ca7526a}},	//   žino, vybę_, dolž, _lund_
  { {0x32530036,0xbb3b0053,0x44d11501,0x97370033}},	//   овір, כעני, bą_, лiцы_
  { {0x3d1f005d,0xa3ea0063,0x200f0d25,0x98aa0007}},	//   यमों_, _идва_, _bagi_, tybę_
  { {0xa4b7000a,0xf8b3000a,0x64a315d1,0x63ad0077}},	//   _כללה_, חשה_, _фата, ñant
  { {0xb3a901e2,0xa0670001,0x98aa0007,0x9c7d016f}},	//   ğıtı, јања_, rybę_, juča
  { {0x68fe06f5,0x2c720107,0x6f190034,0x9c7d0085}},	//   _oppd, mády_, _drwc, duča
  { {0xc27b0008,0xceb90046,0x2c7201c0,0xecb30058}},	//   _ירמי, apř_, lády_, يحَة
  { {0x515b0008,0x20330015,0xd00a0054,0xdd970138}},	//   _בכבו, _وفلس, _једе_, шшы_
  { {0xba770029,0xbf160086,0x1df80010,0xab870484}},	//   لاست, _خوشب, _белы_, рунк
  { {0x64830020,0x200413b9,0x8e730015,0x2ca72d9d}},	//   võim, lemi_, _واوض, _fund_
  { {0xdd8f0086,0x2289002c,0x6cd40018,0xac950877}},	//   _قوه_, núka_, _اقبا, _лакш
  { {0xdff8005d,0x44d10007,0x2004526b,0xfc300015}},	//   ्जिद_, vą_, nemi_, _يحي_
  { {0x44d10050,0x85a70001,0xcf93004c,0x2004002a}},	// [ca10] wą_, ајед, ַטע_, iemi_
  { {0x44d10b53,0xf8ae0086,0xe1110007,0x4b7c000a}},	//   tą_, بکی_, ščią_, _באחו
  { {0xe7ef005d,0xe4e7005e,0x2289001a,0x44f507be}},	//   _छापा_, різн, júka_, спес
  { {0xdcef016f,0x2004003f,0x44d110da,0x2f21001a}},	//   žeći, jemi_, rą_, nægð_
  { {0x7764010f,0xfc180008,0x44d10c85,0x1bfa004c}},	//   _държ, יקאי_, są_, רלױב
  { {0x44d11501,0x10a5006b,0x23260b1e,0x0736000a}},	//   pą_, бикн, соши_, _האשם_
  { {0x248d003e,0x200f0509,0x69ba000b,0xc692015b}},	//   _them_, _pagi_, ्रती, _מאך_
  { {0x2ca70b0f,0x66050375,0x27e9469f,0x60090054}},	//   _rund_, lehk, ngan_, уним_
  { {0xa115002b,0x200f108c,0xb3a90061,0xe7ef000b}},	//   _گوات, _vagi_, şısı, _छाना_
  { {0xd2510015,0xf1f80067,0x6483007c,0x200f002a}},	//   _عنا_, _نعمت_, kõik, _wagi_
  { {0x81c2003d,0xc5f2000a,0xcb09000a,0x200f526c}},	//   ģēta, הדי_, _רל_, _tagi_
  { {0x20040089,0x6f190034,0x683801c0,0x628320bf}},	//   cemi_, _trwc, _lídr, llno
  { {0x70740029,0xda660029,0xa3ea000b,0x0b5a0033}},	//   _بالذ, ماسي, _मास_, урны_
  { {0xceb60008,0x9c7d016f,0xdeb6000a,0x2ca7007c}},	//   _הפסק_, ruča, _הפסח_, _tund_
  { {0x6e230593,0x6e3c379f,0x7a300012,0xd9430680}},	//   _innb, örbe, _kätz, пери
  { {0x2a7800da,0xc7a6004a,0x27e9068b,0x9c7d526d}},	//   sorb_, сиак, ggan_, lučn
  { {0x64ac0064,0x7c240035,0x86c60015,0x6f090012}},	// [ca20] _eğil, _inir, صيان, nwec
  { {0xa3ea005d,0x27e9002d,0x2004526e,0x7ae6088a}},	//   _माह_, agan_, zemi_, mukt
  { {0xeafa0074,0x68fe01d1,0x69ce002e,0x62830089}},	//   _شرکت_, _uppd, mabe, dlno
  { {0x0326058f,0xe7ef000b,0x2c21000b,0x9cd6000a}},	//   йден, _छाया_, याएं_, מועה_
  { {0x26cf00dc,0x82f70086,0xfbd30008,0xf487002b}},	//   ágot_, مروز_, לתא_, حالی
  { {0x9c7d526f,0xfe670225,0x86750010,0xcb13000a}},	//   jučn, _رد_, _дысц, פלו_
  { {0x1a9b0053,0x291800dd,0xeb9f0293,0xb3a90061}},	//   ניצע, nvra_, ndør_, ğırı
  { {0x30130063,0x69ce136c,0x9ed80004,0xb3a90061}},	//   здър, habe, амит_, şırı
  { {0xa75b0053,0x26d20035,0x4424002d,0x69ce5270}},	//   ָדיר, nsyo_, _inm_, kabe
  { {0x07370008,0x644200f2,0x2004002e,0x1ee9002b}},	//   צאים_, lkoi, semi_, گویی_
  { {0x667b00b4,0x38ae002e,0x78bc0089,0x68fb005c}},	//   רטיק, _nýr_, jprv, łudz
  { {0xdee63589,0x1ee9002b,0x69ce007c,0x6442008c}},	//   _годи, دویی_, eabe, nkoi
  { {0xf1ac005d,0x644200f2,0x91ac000b,0xaa7b006f}},	//   _चलान, ikoi, _चलाई, jrýc
  { {0xdb1d00dc,0x38ae002e,0x69ce2c21,0xb9c50015}},	//   nbsé, _býr_, gabe, تقسي
  { {0x644200f2,0x30d8000f,0x27e90026,0x60d8000a}},	//   kkoi, יַּע, tgan_, יַּג
  { {0x25eb000b,0x88580054,0x63a40085,0x38ae001a}},	//   _चाही_, бисс_, žinj, _dýr_
  { {0x27e90495,0x9c7d0264,0x4c3c000a,0x69c1001a}},	// [ca30] rgan_, lučo, _תתחב, ðles
  { {0x31b4005d,0x7bcf013c,0x1c1d000b,0x44240012}},	//   ुरोध, lacu, _बोतल_, _anm_
  { {0x9f4d002d,0x92590086,0xe4e40010,0xdb0f016e}},	//   ifeá_, یشتر_, зічн, racõ
  { {0x26cf00dc,0xdd7b0643,0xb4e9000b,0xaa7b00bf}},	//   ágos_, נטאל, _ममी_, brýc
  { {0xa3ea005d,0x38695271,0x23290a24,0x0000006a}},	//   _मार_, mnar_, роли_,
  { {0x41e70191,0x93940015,0x7a300012,0x7bcf1112}},	//   сіда, سجنا, _sätz, hacu
  { {0x38695272,0x2fcd007c,0xca7c004c,0x9c7d0f81}},	//   onar_, taeg_, אנגט, vučn
  { {0x386905d8,0xd4980342,0x69ce5273,0x60960021}},	//   nnar_, _гру_, zabe, ينوس_
  { {0x2fcd0026,0xdb1d00dc,0x38695274,0x628301c9}},	//   raeg_, bbsé, inar_, plno
  { {0xc0cb1ec9,0x3f830024,0x6f0900b8,0x2fcd0020}},	//   _буде_, āju_, rwec, saeg_
  { {0xdbc7002e,0x9c7d04c6,0xd00e002b,0x6f090012}},	//   töði, ručn, رلی_, swec
  { {0x7f190036,0x32071e80,0xca29000a,0xe0d00015}},	//   _віку_, leny_, _בם_, _أزل_
  { {0xe0420191,0x4e29004a,0x290100aa,0x69ce5275}},	//   _інши, _волн_, _apha_, tabe
  { {0x9dab0063,0x9f4d002d,0x539a00f3,0x64495276}},	//   _съда_, cfeá_, יירו, _llei
  { {0x3ce0005d,0x485a0010,0x3869002e,0xa7aa0063}},	//   _किये_, араў_, fnar_, иква_
  { {0x68430015,0x2918006f,0x69ce5277,0x38695278}},	//   وَّل, rvra_, sabe, gnar_
  { {0xa2db014e,0x63a40007,0x35ca0001,0x05ba0015}},	// [ca40] _निष्, žink, игао_, لدات_
  { {0x65ba0001,0x645b002d,0x32070089,0x96760033}},	//   руар_, _amui, jeny_, цыбі
  { {0x32070089,0x85060087,0xca4a0086,0x644911b4}},	//   deny_, توان, _ملکه_, _blei
  { {0xa2db005d,0x64490026,0x9c83099c,0x3cfa0053}},	//   _निश्, _clei, _účto, ילענ
  { {0x6442022d,0x741300c3,0x56f60058,0xdc89004f}},	//   rkoi, بونا, _بأجز, צְעָ
  { {0xa2db0372,0x644903af,0x9b0b000a,0x7bcf1835}},	//   _निर्, _elei, שִׁ֥, zacu
  { {0xf65f002e,0x644905d8,0xf484002b,0x61ea0012}},	//   _tvær_, _flei, _فاری, rgfl
  { {0x644913fd,0x30770029,0x09b7005d,0x6abd0123}},	//   _glei, يحية_, _अभ्य, ypsf
  { {0x7e2a0010,0x32073d78,0x14230033,0x3f820052}},	//   аіна_, beny_, _ўдум, æku_
  { {0xa3ea005d,0x248613e1,0x01d70015,0xddaa0004}},	//   _माँ_, llom_, _ووقع_, штил_
  { {0x6449022d,0x24865279,0xc0460015,0x6b8d0030}},	//   _ylei, olom_, _وخصو, _szag
  { {0xa2c1005d,0x9c7d0107,0xd010002b,0x24860030}},	//   रीक्, ručo, _سلت_, nlom_
  { {0x6e2e00dc,0x24860c1a,0x7e7a0085,0x629800aa}},	//   öbbs, ilom_, potp, omvo
  { {0x7d17002e,0x7bcf0077,0xd90f002b,0xda7b0c02}},	//   ðasí, sacu, نیخ_, рям_
  { {0x39450f3c,0x91bb000a,0xa9350054,0xa3ea000b}},	//   áls_, שמלי, чевш, _मां_
  { {0x2c21005d,0x32070089,0x64830020,0x765c0026}},	//   याओं_, zeny_, lõiv, _amry
  { {0x25ab0001,0x2486002c,0xf7730002,0x3869527a}},	// [ca50] ађен_, dlom_, ذار_, rnar_
  { {0xab5b01e2,0xc6740086,0x19950010,0xf1bf0092}},	//   saüs, وطلب, _напя, _đáo_
  { {0x32070089,0x386901af,0x97c70015,0x6449527b}},	//   veny_, pnar_, _وتحم, _plei
  { {0x3cfb0053,0x59960008,0x442700e6,0x24862fd1}},	//   שלאנ, _מכתב_, غراف, glom_
  { {0x069b0074,0x64490547,0x7bcd266b,0xf3f00058}},	//   _نخست_, _vlei, _meau, ضأن_
  { {0x64490026,0xc73a000a,0xe601008c,0x768b0061}},	//   _wlei, _התשת, ävää, müyo
  { {0x768b0064,0x6aad002d,0x3207527c,0x11d60015}},	//   lüyo, _luaf, reny_, سوية_
  { {0xaadc000b,0xddc80030,0x1ec9004a,0x629800aa}},	//   _बिलक, didő, блии_, amvo
  { {0x768b0064,0x1f650342,0x63a9527d,0x9c7d0085}},	//   nüyo, яким, _igen, ručl
  { {0xfe71003b,0x5bb6005d,0x92580004,0x3ea30123}},	//   عدة_, ूर्व, _даут_, öjt_
  { {0x3eb90024,0x7bcd0493,0x6f0230c5,0x1d09006b}},	//   ūst_, _beau, _epoc, щени_
  { {0x80140036,0x7bcd527e,0x768b0061,0x0000006a}},	//   _офіц, _ceau, küyo,
  { {0x7ff40086,0x63a9003f,0x0b43006b,0xaab90015}},	//   _آسما, _mgen, енян, قدّر_
  { {0xdb0f002f,0xc332009d,0x25fd005d,0xdeba000a}},	//   ódái, תוך_, र्मी_, _המסל
  { {0x929d0050,0x6f020046,0x2486527f,0x63a95280}},	//   _usłu, _zpoc, ylom_, _ogen
  { {0xfc320029,0x63a41de0,0xed56000a,0x6d4100e7}},	//   _سحب_, žini, _מבצר_, myla
  { {0x6281016f,0x07b70015,0x3ebf5281,0x17c7005e}},	// [ca60] _oklo, سهلة_, nput_, ягти_
  { {0xa5960080,0xda0a002b,0x9c7d00bc,0x63a95282}},	//   прещ, _ايده_, jučj, _agen
  { {0x9a3b0008,0x9c8300bd,0xd82605b3,0x7556009c}},	//   _התיק, ščej, _едни, чњац
  { {0x6d5c0125,0xa98b000a,0x3a3a00d6,0x25fd0065}},	//   úrai, _לָכִ, _hopp_, र्बी_
  { {0x7e6100f2,0x289b000a,0xa2b3005e,0xa2d30015}},	//   kilp, _ליטא, ебіч, فينت
  { {0x26c002d7,0x6d410007,0x768b0061,0x63a90a3a}},	//   mpio_, kyla, nüyl, _egen
  { {0x403409ef,0x6f0211a0,0xf62302da,0x24865283}},	//   дейс, _spoc, _ядро, plom_
  { {0xa0a30004,0x3a3a0123,0x6d41250a,0x26c0008c}},	//   најд, _lopp_, dyla, opio_
  { {0xf34a004a,0x7bcd11ff,0x0000006a,0x0000006a}},	//   _упал_, _reau,   ,
  { {0x22570015,0x9325002b,0x63a900bc,0x78a65284}},	//   _فلقد_, _ترفن, _zgen, _likv
  { {0xc04f0191,0x41bb0008,0xb5f70008,0x91bb000a}},	//   _зі_, _הצבע, הציג_, _המבי
  { {0xf0440086,0x53cc005d,0xd00f0015,0x44d820d4}},	//   _تعطی, ारिश, _ملم_, ič_
  { {0x6d410064,0xa3ea000b,0xddc80030,0x9c7d0e1d}},	//   ayla, _माई_, sidő, lučk
  { {0xadbc0010,0x8f9b0008,0x4eb7000a,0x7ae00030}},	//   _такi, _הידי, _צהוב_, ámta
  { {0x661500bd,0x5dfb0008,0x8ca6005d,0x6c550080}},	//   _razk, _הפונ, _घंटो, _окку
  { {0xb905005d,0xf1bf0092,0x44f50cbf,0xe8e00016}},	//   _नि_, _đám_, vå_, _giọt_
  { {0x59bf005d,0xb8f4005d,0x2bc3021e,0xccf80046}},	// [ca70] ्रदर, _सौ_, _व्या, ltě_
  { {0xe2a30023,0x929d005c,0x768b3421,0x6d4702de}},	//   _chữ_, _opła, rüyo, øjag
  { {0x58d4005f,0x13f50010,0x9c7d0796,0xf9fa000a}},	//   _поэт, дзея, jučk, _והתמ
  { {0x9f9d03af,0xd8d6000a,0x9975002a,0x27ed02de}},	//   nção_, _קורט_, _męża_, _øen_
  { {0x9f9d001c,0x8bd8000a,0xabfc004c,0x661501c2}},	//   ição_, לואו_, מפאז, _tazk
  { {0xc2440010,0xc3240033,0xea17000a,0x2374002b}},	//   ннік, эмік, לַ֔י_, رانح
  { {0x628100bd,0x9c7d0085,0x6d410326,0x5694120a}},	//   _vklo, ručj, xyla, _чарт
  { {0xf9940053,0x78b80030,0x768b0061,0x63a95285}},	//   ערק_, _évve, züyl, _ugen
  { {0x59bf005d,0x25fd005d,0x7e615286,0x6d410034}},	//   ्रार, र्थी_, tilp, wyla
  { {0x6281010b,0x463a0053,0xfe42005e,0x5215005e}},	//   _uklo, ַערע, вньо, _ідет
  { {0xac0a28ff,0x0000006a,0x0000006a,0x0000006a}},	//   онна_,   ,   ,
  { {0x64830020,0xab5b00b8,0x417a000a,0x25fd000b}},	//   mõis, rbün, _ונעב, र्ती_
  { {0x4e350015,0x6b89002a,0xe9f90016,0x2d8a006f}},	//   _يعتز, żegn, _quế_, ýber_
  { {0x9f9d001c,0x8f9a000a,0xb69b0045,0x7f9a004f}},	//   ação_, _ויני, _spân, _ובנז
  { {0x768b0061,0x26c00034,0xfaa311c2,0x2fcf04a9}},	//   rüyl, wpio_, таро, _kegg_
  { {0x9f9d001c,0x7af70030,0xac760015,0x7e7c00bc}},	//   cção_, ögtö, _تاتش, črpe
  { {0xd7ef0029,0x1867000d,0xb8d5000b,0x3a3a4297}},	// [ca80] شكل_, фати_, _छू_, _topp_
  { {0xa5f70124,0xc1ac005d,0xb9c60115,0x2fcf13e1}},	//   међу_, _चलेग, _تقدي, _legg_
  { {0x9e7a0053,0x3ea70c0a,0x64c30015,0x88e6004a}},	//   קנעפ, _mint_, َيْل, _южне
  { {0x26c032fa,0x3ce0000b,0x2d870547,0x3ea700b7}},	//   ppio_, _किसे_, _myne_, _lint_
  { {0x17c70036,0xd12f0086,0x14170015,0x929d002a}},	//   _ігри_, یمه_, بينة_, _spła
  { {0x2d8b0050,0x93430063,0x8b570135,0xd36f0015}},	//   ęcej_, ънче, וינס_, جهه_
  { {0x20d30029,0xdfd00015,0x0000006a,0x0000006a}},	//   نتيج, هيث_,   ,
  { {0xf9930008,0xe571000a,0x7109005e,0x8f465287}},	//   כרו_, _עַם_, яхів_, дход
  { {0xdefa008f,0x929d005c,0x30830015,0xadd40054}},	//   цый_, _wpła, خليف, нопљ
  { {0x7bc60024,0x6483007c,0x3eb95288,0x0000006a}},	//   ebku, sõit, ísta_,
  { {0x9c7d28b4,0x260f000b,0xd1790033,0x7ae65289}},	//   luči, ड़ती_, _есці_, erkt
  { {0xccf80089,0xac190036,0x5f2a0080,0x718b000a}},	//   rtě_, чому_, _моем_, _וְדַ
  { {0x9c7d00df,0xccf80089,0x9f9d001c,0xbb94004a}},	//   nuči, stě_, rção_, кающ
  { {0xcd360015,0x5e440015,0xfe43006b,0x2ba501ec}},	//   _يرغب, _سَعْ, _инчо, _rīcī_
  { {0x9f9d001c,0xda0e000b,0xd83f006f,0x9f5f001a}},	//   pção_, ाज़त_, áčov_, lduð_
  { {0xe8940010,0x764e0026,0xdb250011,0x86c50015}},	//   вась, _alby, ăpân, فيرن
  { {0xe5e50086,0x9c7d0a00,0xa03b0053,0x7b140033}},	// [ca90] فزای, juči, קעמפ, _адых
  { {0xa6350033,0x628a0101,0xa5670040,0x758b009b}},	//   энзі, jlfo, ودان, осев_
  { {0xdcf803eb,0x69d5001c,0x67d50292,0x05190015}},	//   _izvē, maze, _пону, ثياب_
  { {0x44290467,0xf9920053,0x64830020,0x299a000a}},	//   ña_, _תרט_, võis, _מסתמ
  { {0xba740086,0xb30b0031,0x77ba000a,0x69c7528a}},	//   _سایت, تغال_, _ממרח, obje
  { {0x69d5528b,0xfe79005a,0x38b5174d,0x0000006a}},	//   naze, trům_, _kår_,
  { {0x7d1c002e,0xd1310002,0x3a38000a,0x94770015}},	//   ærsl, امع_, ורגם_, _قدرا
  { {0x7ae60843,0xe2f9005e,0x3ea7382b,0xd62201f3}},	//   yrkt, _небі_, _sint_, лiза
  { {0x63bb003f,0x69d5036e,0x2d8a0012,0x3ea74b1f}},	//   _ifun, kaze, üben_, _pint_
  { {0x77eb000b,0xc2c4002b,0xdd010091,0x69d5528c}},	//   टलुक_, _شيمي, žuči, jaze
  { {0x63a400df,0x769000f2,0x3ea7028f,0x61550015}},	//   žint, käyn, _vint_, _ثنائ
  { {0x3ea70111,0xddda0046,0x853a000a,0x9c7d00bc}},	//   _wint_, botů, לגתי, srčn
  { {0xe4520008,0xf0920053,0xe7e3000b,0x69d5016e}},	//   רֶת_, _ענד_, गणना_, faze
  { {0x7f5d02c1,0x7f3a0008,0x4f3a000a,0x2816002b}},	//   úsqu, _מתנג, _מתנע, کورس
  { {0x9c8300bd,0xf1b2000a,0xd37b0033,0xbcf50015}},	//   ščaj, רסל_, _лiчы, _أستغ
  { {0xf7720029,0x1602000b,0x25fd000b,0x929d0535}},	//   هاء_, र्नर_, र्सी_, _opło
  { {0xc05200a3,0xe7290015,0xd6d20015,0xbb46045f}},	// [caa0] אזן_, وسكو_, اقط_, _чепк
  { {0x69de0134,0xd910002b,0x38b52b04,0xe6173028}},	//   _udpe, _پیر_, _får_, нду_
  { {0x05760015,0x38b52b04,0x0446528d,0x248401c2}},	//   رائد, _går_, нежн, _pkmm_
  { {0x29370053,0x628a0546,0x0000006a,0x0000006a}},	//   _נאכן_, wlfo,   ,
  { {0xbb3b00b2,0x3383006b,0x93b30033,0xe2f800ce}},	//   ּעצי, лушв, убіц, фелі_
  { {0x68fc00bd,0xb425002b,0x3ce0000b,0x9c7d528e}},	//   otrd, _یعقو, _किले_, ruči
  { {0x73e60342,0xa507320a,0x68e301d0,0x0000006a}},	//   _повз, _пера_, _åndt,
  { {0xdfd00029,0x69c70085,0xb4fb000a,0x649100cb}},	//   جية_, zbje, _מפלי, låin
  { {0x25fd005d,0x64ac0064,0xe1f2002b,0xd4030033}},	//   र्वी_, _eğit, _مسا_, _вiту
  { {0x2ca9002f,0x28e1005d,0x52d70008,0xf1c3002c}},	//   _siad_, _फिलि, _נובע_, čší_
  { {0x827700b2,0x4d980036,0xd6570008,0x9e030010}},	//   _טעמע_, ькою_, גיית_, учыл
  { {0x6557000a,0xf1bf00a1,0x0000006a,0x0000006a}},	//   תבטא_, _đái_,   ,
  { {0xdb1d0014,0x9e140010,0x3d28002b,0x52db004c}},	//   vasó, _адлі, ستگی_, ּקלײ
  { {0x8fa30001,0x63ad02c1,0xc333000a,0x68e10030}},	//   _саче, ñanz, אוש_, áldo
  { {0x2db7000a,0xa81d0033,0x67d5187f,0x69d5391e}},	//   _אלון_, озвi, кову, raze
  { {0x38b51edc,0x69d50089,0x69da0030,0x69c701d0}},	//   _vår_, saze, óter, sbje
  { {0x17f80029,0x1602005d,0x69d54b1d,0xf7700015}},	// [cab0] عرفة_, र्भर_, paze, ماك_
  { {0xb7140080,0x97140033,0x2b530061,0x7afd0012}},	//   ыдущ, ымуц, ıncı_, mtst
  { {0x24190036,0x7aef16ac,0x63bb0012,0x929d002a}},	//   ділю_, luct, _pfun, _spło
  { {0x7af20089,0xe3b00115,0x7afd528f,0xf2c50015}},	//   šetř, مره_, otst, نْصُ
  { {0xb8f4000b,0xf5e7005e,0xdd86002b,0x1474006e}},	//   सी_, _півм, _چو_, دالج
  { {0xdd860086,0x98be0007,0x25fd000b,0x97420033}},	//   _نو_, štą_, र्शी_, лiць_
  { {0x7c2d4d3f,0x7afd06a8,0x9c7d0480,0xa4d5005e}},	//   _onar, htst, luču, _шові
  { {0x63bb0fcd,0xd9bf000b,0x3eb90046,0x71240021}},	//   _ufun, ्रुट, ísto_, ارول
  { {0xd2150054,0x1e9507d0,0x7afd4002,0x442d5290}},	//   _имаћ, крор, jtst, _ine_
  { {0x443f020a,0x33840010,0xc2c40029,0x5214005e}},	//   _hou_, _сусв, _إيلي, _йдут
  { {0xc6920008,0x2bc3021e,0x2d95006b,0x9f05002b}},	//   שאי_, _व्हा, ърис, روگو
  { {0x443f0f75,0xf5320008,0xa3e7005d,0x442d0209}},	//   _jou_, ׁ֥ר_, पलट_, _jne_
  { {0x9c7d0263,0x1602000b,0x442d5291,0x7afd1936}},	//   juču, र्डर_, _mne_, gtst
  { {0x0f56000a,0x62835292,0x443f5293,0xdee20bb1}},	//   _בינם_, nono, _lou_, _тоши
  { {0x442d5294,0x7afd2dcc,0x09d50033,0xad24009a}},	//   _one_, atst, ыцяў, _مريو
  { {0x442d003f,0xb3a90064,0x63ad01a3,0xa2d2000b}},	//   _nne_, şıyı, žanj, _डबल्
  { {0xd6d9005e,0xa68602b0,0xf1d1000b,0x068603ea}},	// [cac0] етє_, влад, हरान, вган
  { {0x27f20026,0x95fe000b,0x62835295,0xfaa608e8}},	//   sgyn_, ैजेट_, jono, _шапо
  { {0x443f5296,0x64a6042b,0xca37000a,0xea890015}},	//   _bou_, важа, _סנטה_, _ثخين_
  { {0x3d19005d,0xb6090024,0x443f04ad,0x0d3a004c}},	//   _बनने_, _atšķ, _cou_, וגעב
  { {0xd36f0029,0x442d0820,0xe81b000b,0x04430054}},	//   يهم_, _dne_, _पोटा_, јечн
  { {0xfe670070,0xcb1300a3,0x11d80015,0x92140015}},	//   _ضد_, ילד_, روبة_, اوثإ
  { {0xd130003b,0x443f38b5,0xd46a14f4,0x320e002a}},	//   صمة_, _fou_, _живе_, refy_
  { {0xd3f40010,0x443f00dd,0xb97b000a,0x25f2000b}},	//   _гiст, _gou_, ונצי, ुभवी_
  { {0xd0070e88,0xddea0086,0x44fc5297,0x10a30054}},	//   тење_, ورده_, lí_, шићн
  { {0x443f0298,0x22f7013a,0xdfd00086,0x7690008c}},	//   _zou_, _בזמן_, جيک_, käym
  { {0x44fc18f6,0x443f003e,0xc5f30008,0x2d8a02de}},	//   ní_, _you_, בדת_, æbe_
  { {0x98aa0007,0x7afd2d60,0xaf0a0015,0xfbd00015}},	//   mybė_, ttst, _يقام_, يتُ_
  { {0x7b64000d,0x98aa0091,0x44fc4d1d,0x5b14056d}},	//   атре, lybė_, hí_, амят
  { {0x661c1035,0x7aef0f43,0x2289006f,0x7afd5298}},	//   _nark, ruct, búku_, rtst
  { {0x44fc0089,0xadf700e6,0xc0d4000a,0xed360033}},	//   jí_, _شروط_, טֵּה_, _шэдэ
  { {0x6ca40010,0x7afd00b8,0x62835299,0x25cb000b}},	//   _крыж, ptst, zono, िर्ण
  { {0xa3e6005d,0x661c529a,0xf6990054,0x57b401f3}},	// [cad0] पणन_, _bark, евај_, рбут
  { {0x98aa0007,0xe5350010,0x442d02de,0xf8b1002b}},	//   kybė_, лезь, _sne_, _هکر_
  { {0x442d010b,0x99350029,0x661c529b,0x6440529c}},	//   _pne_, _صفحت, _dark, _bomi
  { {0x6440189e,0x6283002a,0x0000006a,0x0000006a}},	//   _comi, wono,   ,
  { {0x661c01e2,0x91e50083,0x3869529d,0x443f529e}},	//   _fark, голе, miar_, _vou_
  { {0x6d480007,0x43740036,0x44fc0264,0x443f0409}},	//   kyda, шуєт, bí_, _wou_
  { {0x64ac0064,0x44fc529f,0xefb1002b,0x98aa0091}},	//   _işin, cí_, میاگ, gybė_
  { {0x442d0b7a,0x629a00f2,0xae1b005d,0x2bc3000b}},	//   _une_, _ehto, _भोजन_, _व्ला
  { {0x62833e09,0x6d480061,0x7e7c00bc,0x6d5a003d}},	//   pono, eyda, črpn, ezta
  { {0x91ca005d,0xab5b00dc,0x2606000b,0x41b50015}},	//   _स्पै, baüz, स्पी_, _إمار
  { {0x3ff50015,0xdfd10015,0x8c462b12,0x0000006a}},	//   _مكار, _هيا_, гене,
  { {0x8c560015,0x5fb9004f,0x0000006a,0x0000006a}},	//   ائدا, _נֶ֣ג,   ,
  { {0x44fc0107,0x3af60033,0x386952a0,0xc016000a}},	//   zí_, ыянс, diar_, _תקנו_
  { {0xc1780007,0xbcd90058,0x99160138,0x6d480416}},	//   _odėl_, _كذبا_, льбі, byda
  { {0x2d940063,0xc8b5004a,0x4a750033,0x7c2f0125}},	//   _кръс, исты, рыят, áirí
  { {0x44fc52a1,0x201d01c2,0x201f52a2,0xccf2000a}},	//   ví_, _jawi_, ndui_, _הכה_
  { {0x290501e2,0x5baa0036,0x201d00d9,0xcc57000a}},	// [cae0] çlar_, _яким_, _mawi_, _תספק_
  { {0x44fc52a3,0x644052a4,0x7ae9006f,0x7690008c}},	//   tí_, _somi, šetc, mäyk
  { {0x99fb000a,0x644052a5,0xa3ea0004,0x69fb000a}},	//   _אפיפ, _pomi, едеа_, _אליק
  { {0x98aa0007,0x44fc0f45,0xc3d60015,0x64ac0061}},	//   vybė_, rí_, اغاث, _eşin
  { {0x661c52a6,0x6d48005c,0x44fc1d98,0xa80302e1}},	//   _tark, zyda, sí_, _узял
  { {0x98aa0007,0x5b7b0053,0xa2260015,0x64400012}},	//   tybė_, ערסא, طرته, _womi
  { {0x04960010,0x052702c8,0xf518000a,0x154309b1}},	//   _браў, _йорк_, _בֵּל, _лерм
  { {0x769000f2,0x6440333f,0x6d5a0046,0x67241667}},	//   käyk, _uomi, vzta, ovij
  { {0x61f60029,0x9e140010,0x6d480b90,0x51f60015}},	//   _مساء, адпі, wyda, _مسار
  { {0x98be0007,0x42db0008,0x715a52a7,0x6d4852a8}},	//   štę_, _נקבע, _прес_, tyda
  { {0xdd940010,0x127b0053,0xc27b000a,0xec35005e}},	//   раны, _טאמע, _טרמי, аннь
  { {0xc0ff0092,0xcf260015,0x6d4852a9,0x913b004c}},	//   _lướt_, _مرتي, ryda, _רעאק
  { {0x6d5a2ef0,0xe451000a,0x9e3407be,0x543b004c}},	//   szta, חֶם_, _велч, געכא
  { {0x28b6000b,0x6f930015,0x24570061,0xdb1d001a}},	//   _आंशि, _الهض, _içme_, kasö
  { {0x67240024,0xaa7b0057,0x386900ac,0xd8770021}},	//   evij, krýv, tiar_, هارب
  { {0x3d19000b,0x321e002a,0x63ad52aa,0x4815012e}},	//   _बनते_, _laty_, žani, јмас
  { {0x3eae02de,0x386952ab,0xe894004a,0x47350033}},	// [caf0] _kift_, riar_, сать, шнас
  { {0xd5d40015,0x79870015,0xdb1d001a,0x201f52ac}},	//   متمث, _مؤجل, fasö, zdui_
  { {0x38693457,0xe89552ad,0x1959056d,0x2cf20065}},	//   piar_, _вань, _раны_, _अमोल_
  { {0x69d700b8,0xa4d4005e,0x3eae1c67,0xf484098a}},	//   _hexe, соці, _lift_, бучн
  { {0xb7da0008,0xe3b8005e,0x64ac0061,0xcc78004f}},	//   _בקרי, убі_, _işil, נגדת_
  { {0xd25b0010,0xaabc0053,0x2478006f,0xe29903ae}},	//   эце_, עזוכ, rčma_, њак_
  { {0x3d14005d,0x81d40010,0x321e1212,0xb1160015}},	//   _फैले_, сціц, _daty_, لقوا_
  { {0xdb1d0020,0xc0c80054,0x69d70bd1,0xaab50065}},	//   lasõ, ћује_, _lexe, ंदाक
  { {0x7cc1003d,0x1602000b,0x201f0091,0xd808004f}},	//   _mēre, र्वर_, rdui_, אִתָ
  { {0x769000f2,0xdea4002b,0x9e650238,0xdb1d007c}},	//   väyk, مینی, рвод, nasõ
  { {0x2d820064,0x201d003f,0x672402c6,0x98480045}},	//   şken_, _tawi_, zvij, nşă_
  { {0x8b260010,0xe58c000a,0x20d30045,0x645a0091}},	//   адме, עָזָ, mţi_, _įtik
  { {0x3084003b,0x20d304f9,0x643a0053,0x543a0053}},	//   _النف, lţi_, דערנ, דערא
  { {0x4e790053,0x20d30011,0x2ba7000b,0xdb1d007c}},	//   _שאַצ, oţi_, _गणरा, jasõ
  { {0x20d304f9,0x290c0251,0x684607de,0xa3ca000b}},	//   nţi_, ïda_, анва, ोरम_
  { {0xe8e00092,0x20d30011,0xcc8a0086,0xd7f20015}},	//   _liệt_, iţi_, _جنبه_, تكر_
  { {0xa6aa00e6,0xe7aa006b,0x1899004a,0x09e60709}},	// [cb00] ناطق_, твал_, утрь_, _копн
  { {0xd5eb0023,0xcb9b0008,0xdb9b0008,0x9adb0643}},	//   _địn, _בספט, _בספר, _שחיט
  { {0x3f8f0091,0x69ce00da,0x24860547,0x672452ae}},	//   _lygu_, mbbe, toom_, svij
  { {0xcd9a0053,0x032608f2,0x2eed001a,0xd8db000a}},	//   דױער, иден, kref_, _בקטר
  { {0xe8e00023,0xd3870010,0x20d30011,0x38bc0030}},	//   _biệt_, айце_, eţi_, _hír_
  { {0x2eed0026,0x6ce5000b,0x645901c2,0x78a4019a}},	//   dref_, _किंग_, ahwi, lmiv
  { {0xe8e00092,0xdb1f11dd,0xddc80091,0x3eae26d0}},	//   _diệt_, _seqü, sidū, _rift_
  { {0xc0340124,0x64590c8c,0x80a300c3,0xf106000b}},	//   сниј, chwi, يمون, _शहीद_
  { {0x20d304f9,0x25fd005d,0x30170015,0x2d910061}},	//   aţi_, र्की_, شتية_, üzen_
  { {0xfe720029,0x7e54005e,0x38bc0077,0x98be0046}},	//   تدع_, своє, _oír_, átě_
  { {0x45b70053,0x0e330036,0x2d9813e1,0x20d30045}},	//   יפיל_, інюю, åre_, cţi_
  { {0x98be0089,0x69ce52af,0x2606000b,0x60ca0012}},	//   ště_, ebbe, स्ती_, mpfm
  { {0x69dc52b0,0x8fa60e4b,0xcb4452b1,0x0000006a}},	//   fare, _таде, охри,
  { {0xbea30010,0xdb1d0030,0x38bc0030,0x69dc52b2}},	//   _дачк, ncsé, _bír_, gare
  { {0x0e9b000a,0x5e57004c,0x6e3c0123,0x7e7d0077}},	//   _ששול, _דיגע_, örbu, éspe
  { {0x08540036,0xdd3b000a,0x7bc1002a,0x8bd50054}},	//   овсю, _יעוכ, ślub, _ужиц
  { {0x57a70063,0xda670087,0xbc7c000a,0x7bdd13ff}},	// [cb10] ршва, _نادي, _שנחת, masu
  { {0x69c00046,0x69dc52b3,0x78a4007c,0x7bdd2274}},	//   ěmec, care, amiv, lasu
  { {0xa3bb0029,0x74a70180,0xd5b82df1,0x25fd000b}},	//   ناشر_, ајде, рсу_, र्गी_
  { {0x68f50061,0xd0060015,0x6272002a,0x64ac0045}},	//   muzd, _عل_, hłod, _uşil
  { {0x387e00dc,0x290300dc,0x24580010,0xda04000b}},	//   étre_, ltja_, шаць_, श्वत_
  { {0xd2640036,0xf207006d,0x9405002b,0x2903007c}},	//   окій, рядо, _گوره, otja_
  { {0x2a5801c8,0xe8e000a7,0x68f50064,0x999a0024}},	//   שבון_, _việt_, nuzd, _kopš_
  { {0x20d304f9,0x69dc03d5,0x94050115,0x2eed0728}},	//   rţi_, zare, _دوره, tref_
  { {0x69dc01e2,0x8db500e2,0x2fcd52b4,0x9e6500ce}},	//   yare, йсні, rbeg_, йвид
  { {0xee390001,0x8e74005e,0xfc3f0046,0x2eed0061}},	//   уно_, жуюч, ejí_, rref_
  { {0xac860036,0x51950015,0x7fb50033,0x29030030}},	//   йгол, _الاذ, _лёлі, jtja_
  { {0xed560036,0x64ac0045,0x69dc52b5,0x7bdd52b6}},	//   сою_, _aşij, ware, gasu
  { {0x2903002e,0x69dc52b7,0x38bc0030,0x2ec50058}},	//   etja_, tare, _sír_, _اقتف
  { {0x9cb20086,0x539a0053,0xfc3f0089,0xade80015}},	//   _کميت, טירו, ají_, _نفهم_
  { {0x69dc52b8,0xfe70002b,0x7d1c001a,0x7bdd007c}},	//   rare, _غده_, ærst, basu
  { {0x8d74002b,0x69dc52b9,0x7c6500c3,0x39450123}},	//   _باها, sare, _وايل, älsa_
  { {0xfc570008,0xf5b60029,0x7c2b52ba,0xceb2000a}},	// [cb20] _לבקש_, مصاد, _ógra, ִיא_
  { {0xcf9200b2,0x38bc002d,0xc869004c,0x78a4007c}},	//   לטן_, _tír_, ײן_, smiv
  { {0xf1bf0092,0x7ae4003c,0x929d005c,0x186a024f}},	//   _đáp_, _hvit, _usły, _бани_
  { {0x54b70033,0xdd3b002a,0xc5090015,0x7ae4146d}},	//   ёгія_, dąża, شتمل_, _kvit
  { {0x61d80033,0xf77200c3,0x0000006a,0x0000006a}},	//   амля_, _راح_,   ,
  { {0x46a30036,0x38cb0086,0x06560029,0xd6cf0115}},	//   _наяв, _جایی_, _انسح, _سقف_
  { {0xab5b0012,0x2d910061,0xf657004f,0x9c83013b}},	//   nbür, üzel_, _פסלי_, ščij
  { {0xd138005c,0x8cd2005d,0xc56304ab,0x9206002b}},	//   _rząd_, _भौगो, _экск, _گذرن
  { {0x1047006b,0x22450aa0,0xb111001a,0x64a315f4}},	//   сящи_, _folk_, óðré, _хата
  { {0x2903002e,0x43570008,0x160b000b,0xd357000a}},	//   ytja_, _הסמל_, स्पर_, _הימי_
  { {0x25fd014e,0x7bdd52bb,0xa63b004c,0x628a52bc}},	//   र्टी_, tasu, אגיר, mofo
  { {0xb6060024,0xab95005e,0x7aef0125,0x9597004f}},	//   lašā, жимі, trct, מכיו_
  { {0x3f670080,0x441b000a,0xab870da4,0x6272002a}},	//   _лицо_, אוכס, сунк, płod
  { {0x7bdd0e95,0x9ee7002b,0x7ae40091,0x68f5003d}},	//   sasu, _افول_, _dvit, tuzd
  { {0x19580010,0x91bb0008,0xa3ca000b,0x07e708f0}},	//   бары_, רמלי, ोरा_, йцам
  { {0x290300dc,0x4cf70008,0x2ca00011,0xc051000a}},	//   rtja_, _הזהב_, _ghid_, ֵ֖ן_
  { {0xaae70029,0x290352bd,0x37c40015,0x61e83c63}},	// [cb30] _اسبو, stja_, سيلف, _oddl
  { {0xceb3011f,0x95d8004a,0x85a70054,0x8f9b000a}},	//   פיע_, йдут_, бјед, רימי
  { {0xf5790015,0x24570061,0x65150021,0x249f0034}},	//   جماع_, _açma_, توائ, _phum_
  { {0x3cfb0053,0xd3710031,0x25fd000b,0x6cfb004c}},	//   רלאנ, وها_, र्जी_, רפאס
  { {0x923920d1,0xc2c40015,0x3d18000b,0x75d50015}},	//   ичку_, كيني, यौते_, _ويحا
  { {0xa4d5008f,0xa229004a,0xb6040033,0x0000006a}},	//   _могі, ржка_, _няск,
  { {0xa1560001,0x6142006b,0xb2840033,0x2245288f}},	//   жају_, деща, чыцк, _volk_
  { {0x50580010,0xdb21002c,0x6272002a,0xaec51489}},	//   йшыя_, _štýl, głob, обил
  { {0xa267006b,0x870c000a,0xddda0030,0x22453135}},	//   _лъжл, ָּחֶ, eltű, _tolk_
  { {0x7d090001,0x3eb100dc,0x63ad0263,0xfce50c7a}},	//   аног_, özt_, žans, оооо
  { {0xc5f201e4,0xcf270086,0x1d09047d,0xdca60da4}},	//   ודי_, _گراي, шени_, жани
  { {0xb4fa0008,0x69c50e5f,0x4588000a,0x6e3c0123}},	//   ספרי, _afhe, מְר֣, örbr
  { {0xbd45002b,0xcf27006e,0xdb69004a,0xab630033}},	//   _ژنتي, _دراي, брёл_, двял
  { {0x769000f2,0x5ee8000a,0x3f7a000a,0xfc3f0077}},	//   näyt, _הַקְ, _דאנס, rmía_
  { {0xd826058f,0xceb2015b,0xde47002b,0x66170123}},	//   одви, _קיו_, _نیکو_, dexk
  { {0xdd12002b,0xab5b0359,0xa8060033,0x16020065}},	//   _آويخ, rbür, ўзал, _रॉजर_
  { {0x7690022d,0x39a300dc,0x28b6000b,0xe73a0004}},	// [cb40] käyt, tésé_, _आंकि, шеа_
  { {0xe5720015,0x5ee8000a,0xa596006b,0x7c243b16}},	//   وطا_, מַעְ, орещ, _hair
  { {0x7c2452be,0xd4f50033,0xa7d60015,0xe3ba2c2a}},	//   _kair, зячы, _وتحص, абе_
  { {0x87b9042b,0xa99b000a,0xe64a0061,0x6e230034}},	//   _гурт_, _כביר, ıkış, _lanb
  { {0x7c2452bf,0x2fdf4327,0x53160015,0x27e052c0}},	//   _mair, daug_, تذار, main_
  { {0xa9050086,0xdbd9002e,0xe731000a,0x27e04232}},	//   _ببین, hæði, _אֵל_, lain_
  { {0x71730086,0x628a472e,0xc21700ce,0x52830058}},	//   وهها, rofo, ієш_, بلوك
  { {0x30130063,0x6e230384,0x27e052c1,0xa93b000a}},	//   ддър, _aanb, nain_, שתקפ
  { {0xc1060074,0x628a003f,0x442452c2,0xe469004a}},	//   _ژوئي, pofo, _iam_, _ушёл_
  { {0x07370008,0xe7310020,0x27e01f22,0x270e0024}},	//   קאים_, _tööü, hain_, mēnā_
  { {0x55bb000f,0x7c2452c3,0x442452c4,0x2023008c}},	//   ימיו, _bair, _kam_, öriä_
  { {0xfe7800df,0x64424acf,0x5cb70010,0x442608aa}},	//   snį_, njoi, ўляў_, ndo_
  { {0x644200f2,0x44240d72,0x442652c5,0x27e052c6}},	//   ijoi, _mam_, ido_, dain_
  { {0xfe6f003b,0x644200f2,0x539b000f,0xcdb8005e}},	//   _لدى_, hjoi, ייכו, _угкц_
  { {0x7c240493,0x8cc1000b,0x27e00034,0x442652c7}},	//   _fair, _रूपो, fain_, kdo_
  { {0xa8a4042b,0x7c2452c8,0x442452c9,0x7690008c}},	//   друк, _gair, _nam_, käys
  { {0x44260176,0xf7700029,0xb902005d,0x501b000a}},	// [cb50] ddo_, ناك_, _नौ_, סומו
  { {0xe6130029,0x91ca000b,0x26070033,0x68e1001a}},	//   بشر_, _स्लै, ўчаг, álds
  { {0x1a9c0053,0x05680054,0x27e052ca,0x442452cb}},	//   _דיזע, ојци_, bain_, _bam_
  { {0x27e052cc,0x442452cd,0x442601d7,0x73390554}},	//   cain_, _cam_, gdo_, йзер_
  { {0x769000f2,0x883a0008,0x083a0053,0xa295005e}},	//   täyt, _התרו, _הערל, паді
  { {0x44260a49,0x76ba0008,0xc2440010,0x644200f2}},	//   ado_, _למשפ, мнік, ajoi
  { {0xf5590029,0xa3d50001,0x6e230034,0xd65c0033}},	//   _الأب_, _новч, _ranb, лiцк
  { {0xb97c013a,0x769000f2,0x397c01ac,0x7cc10024}},	//   ינוי, säyt, יטונ, _bērn
  { {0xdbd90084,0xf2070010,0xa3ca000b,0x883c000a}},	//   væði, _мяжо, ोरर_, שתחו
  { {0x4d6552ce,0x7c36001a,0x44242c1f,0x7c2452cf}},	//   зков, _snyr, _zam_, _sair
  { {0xc1080033,0x21580015,0xfc3f52d0,0xdbd9001a}},	//   _мэце_, _وجمع_, rmín_, tæði
  { {0xc19a000a,0x160b000b,0x81140015,0xf65f001a}},	//   _השעי, स्तर_, _تذكا, _stæl_
  { {0x7c2403eb,0xeb9f00fb,0xdbd90084,0xdb080064}},	//   _vair, lføj_, ræði, _ölüm
  { {0x19b90191,0x442600df,0xd019005c,0x645b0251}},	//   жуть_, zdo_, leń_, _llui
  { {0x485a0010,0x00c9000a,0x27e00904,0x7c2452d1}},	//   браў_, מֶּֽ, tain_, _tair
  { {0x7c24002d,0xd6d20015,0xb3420061,0x4999005e}},	//   _uair, فقر_, şçil, ітря_
  { {0xabfb000a,0x27e052d2,0xe7371adc,0x442452d3}},	// [cb60] _ההפר, rain_, пет_, _ram_
  { {0x17790191,0x8ca0000b,0x44245294,0x7690008c}},	//   ість_, _गीतो, _sam_, väys
  { {0x442452d4,0xf769000a,0x7cc1003d,0x69de0079}},	//   _pam_, נק_, _mēro, _iepe
  { {0x74690191,0x645b002f,0xd3260036,0x9cd6000a}},	//   орів_, _clui, зьки, פונה_
  { {0x6442022d,0x4424065d,0x3860002d,0x69de0d25}},	//   rjoi, _vam_, mhir_, _kepe
  { {0x4424005c,0x7690008c,0x645b007c,0xf194013e}},	//   _wam_, räys, _elui, миль
  { {0x769000f2,0xe1230004,0x442452d5,0xf484002b}},	//   säys, емји, _tam_, _قاری
  { {0x757b0008,0x50660010,0x644900dd,0x1614005d}},	//   _הטלפ, ятла, _goei, ड़कर_
  { {0xa4110064,0x7e2a0210,0x59be000b,0x41b6006b}},	//   lığı_, біна_, ्डार, _есет
  { {0x7ae90e9f,0x69de52d6,0xdbe5000b,0x0000006a}},	//   šetk, _nepe, कण्ड_,
  { {0x38600d25,0xa4110061,0x7ae652d7,0x0000006a}},	//   khir_, nığı_, eskt,
  { {0x6ab5005d,0x00bb0008,0xd019005c,0x251b004c}},	//   ंद्र, _המאמ, ceń_, זוטא
  { {0x69de00f6,0xdb24001a,0x600b000a,0x50650015}},	//   _bepe, ýrðu, _לִגְ, _تطلق
  { {0x69de0152,0xd357000a,0x38600061,0x2d58030c}},	//   _cepe, ליכי_, ehir_, _миль_
  { {0xdd930010,0x19580010,0x7e9b000a,0x6b841b49}},	//   _пашы, пары_, _הסגו, _exig
  { {0xa41101e2,0x5d7b0135,0x7d7b000a,0xfbc1000b}},	//   dığı_, _לאוק, _לנוו, _एलिम
  { {0x3d18005d,0xf77304c9,0x64490079,0xddda0030}},	// [cb70] यौरे_, رار_, _roei, litő
  { {0xd019005c,0x645b049c,0xaadc0008,0xd5bb0a61}},	//   zeń_, _slui, _החזר, сса_
  { {0x6449016e,0x38600125,0x645b0874,0xab5b0061}},	//   _poei, bhir_, _plui, zcül
  { {0x38810007,0x54550010,0x8464006b,0x629852d8}},	//   bėra_, ьвет, нъче, elvo
  { {0x3c780008,0x47340138,0x0000006a,0x0000006a}},	//   התאם_, _зняс,   ,
  { {0x7bdf0152,0xd5e1000b,0xc293002b,0x672d43f9}},	//   _lequ, _फ़िज, ریاب, mvaj
  { {0xf4970086,0x64ac0061,0x672d52d9,0xf410005a}},	//   _فشرد, _rşiv, lvaj, ížím_
  { {0x1128005e,0x92f20061,0x895c000a,0x629852da}},	//   яючи_, üğüm, מדות, alvo
  { {0x2127002b,0x2d9852db,0xd5e10065,0x60060138}},	//   زيکی_, üren_, _फ़ाज, фным_
  { {0x4328000a,0xfe45005e,0x916c0016,0x9f04002b}},	//   _מֵעֲ, єнно, uộc_, روپو
  { {0x1602005d,0x7cc10024,0x61e352dc,0xa4b5000a}},	//   र्टर_, _vēro, manl, ֽלָה_
  { {0x69de0849,0x909b0015,0x61e352dd,0xeb9a1cd9}},	//   _sepe, _اضطر_, lanl, жим_
  { {0x0b430036,0x7ff40029,0xe8e00092,0x69de3a62}},	//   внян, _أسما, _thịt_, _pepe
  { {0x3ab50001,0x672d0796,0xfe0e0016,0xdb210125}},	//   ељст, dvaj, _hững_, ótái
  { {0x386052de,0x6272002a,0x6f0952df,0x672d1e21}},	//   thir_, kłon, ltec, evaj
  { {0x63bb00b6,0x7bdf0012,0x61e352e0,0x98a301d2}},	//   _ngun, _gequ, hanl, висе
  { {0xe64a0286,0x4a760015,0x6f09160c,0x69de52e1}},	// [cb80] опад_, _يُعر, ntec, _tepe
  { {0xa4110064,0x61e3507d,0x63bb0509,0x4eaa004c}},	//   tığı_, janl, _agun, ַבײַ
  { {0x0446008f,0x9a3b000a,0xa507006b,0x61e352e2}},	//   межн, _ותיק, деха_, danl
  { {0x6f0952e3,0x7bdf016e,0xc953000a,0x17fa0015}},	//   ktec, _xequ, _ימת_, _بردة_
  { {0x2b7b0053,0x290a0030,0x61e352e4,0x6e280034}},	//   ֿטצײ, ltba_, fanl, yddb
  { {0x61e313b9,0xf773000a,0xc4c60015,0xda69000a}},	//   ganl, _יקר_, _يتزو, ּׁה֙_
  { {0xc1030029,0x290a00dc,0x6272002a,0xd4f5055f}},	//   نووي, ntba_, błon, _пяты
  { {0xdfd0003b,0x20020020,0x88bb000a,0x6f0902ad}},	//   دية_, üki_, חזקי, ftec
  { {0xf1cf005d,0x61e30064,0x30a30063,0x41cf000b}},	//   _स्वन, banl, ършв, _स्वस
  { {0x3f980024,0x2002005c,0x68fc2254,0x64ac0061}},	//   āru_, żki_, kurd, _eşit
  { {0x672d00bd,0x7bdf0e57,0xab5b0064,0x85f701ac}},	//   zvaj, _pequ, rcüm, וציע_
  { {0x83fd00dc,0x68fc1519,0x3d1e000b,0xbc8b0015}},	//   _előf, durd, _बनीं_, تضخم_
  { {0xa08b000a,0x6f09003d,0xbef70058,0xbae50058}},	//   _וְגִ, ctec, _قروض_, عكسي
  { {0x6272005c,0x8f9b000a,0xdb210052,0x0000006a}},	//   złon, _וידי, _ótím,
  { {0x19940063,0x8dfb000a,0x5dfb000a,0xf84b0033}},	//   варя, _והות, _ופונ, очай_
  { {0x9c870015,0x61e3068c,0xcc8800af,0x0000006a}},	//   _تشته, zanl, _обје_,
  { {0xe8940080,0x61e30064,0x59d0000b,0x9b440015}},	// [cb90] тать, yanl, _त्वर, _لنيو
  { {0xc5fb0029,0x7afd52e5,0x6bd9002b,0x321c0046}},	//   تعرض_, must, _بوکس_, jevy_
  { {0xe4cb0086,0x6c840086,0x7afd074e,0x0595002b}},	//   زبان_, _سلیم, lust, راطگ
  { {0x6f091212,0xb5a420fe,0x8c1c004c,0x73c50067}},	//   ytec, труй, ַווי, ريتم
  { {0x61e352e6,0x9f4b0061,0x7afd52e7,0xb902000b}},	//   tanl, ücü_, nust, नी_
  { {0x6272005c,0x23760015,0xcb58000a,0xeb92000a}},	//   słon, عمود_, וסדה_, נָא_
  { {0x7afd0005,0x2055000d,0x90e40015,0x7bc10046}},	//   hust, етпр, نسين, ěluj
  { {0xc9b80008,0x63bb0024,0x2c62002c,0xff2552e8}},	//   והות_, _ugun, _kóde_, емио
  { {0xef161292,0xfe0e0092,0x12870086,0x91ca000b}},	//   емы_, _vững_, _قمری_, _स्कै
  { {0xd1c50029,0x6f0952e9,0x7afd22a5,0x68fc0061}},	//   _أيضً, rtec, dust, yurd
  { {0xc692013a,0x6f0952ea,0x7afd52eb,0x0000006a}},	//   ראי_, stec, eust,
  { {0x9d520015,0xf1bf0016,0x68fc52ec,0x91fc003d}},	//   انَت, _đáy_, vurd, _elād
  { {0x9f050029,0x61e152ed,0xbb560015,0x7afd52ee}},	//   _أوتو, _kell, رنسب, gust
  { {0xf2d20135,0x61e152ef,0x68fc0708,0x60c152f0}},	//   רעם_, _jell, turd, _kulm
  { {0x5d790053,0x68fc20e9,0xa9240046,0x2aa40030}},	//   _מאַק, uurd, ěžov, több_
  { {0x290a00dc,0x7afd52f1,0xc8650058,0xf746009b}},	//   rtba_, bust, نطقي, небо
  { {0x1867005e,0xa5da0015,0xdb1d0030,0x7afd5241}},	// [cba0] хати_, كبار_, pcsá, cust
  { {0x61e10ede,0xab5b0064,0xa92602e1,0x78ad3acf}},	//   _nell, zcük, _здол, amav
  { {0x89db0008,0x78af001a,0xb60600bf,0x0000006a}},	//   _מחיי, ónvö, jváž,
  { {0xf4960029,0xc5e9000a,0x64ac0061,0xb606005a}},	//   رشاد, מד_, _aşir, dváž
  { {0x93e70015,0x321c006f,0xd6220033,0x61e152f2}},	//   رفوك_, tevy_, кiда, _bell
  { {0x60c101e2,0xc2c30086,0xb97a000a,0x61e10376}},	//   _bulm, ديوي, ּנֵי, _cell
  { {0x61e10ede,0x26c2000c,0x7afd03da,0x3d1e000b}},	//   _dell, _huko_, zust, _बनें_
  { {0xc0340001,0x61e1007c,0x8f46107c,0x26c202f2}},	//   тниј, _eell, еход, _kuko_
  { {0x80a30015,0x200a002a,0x61e152f3,0x764e4409}},	//   دمين, ębi_, _fell, _koby
  { {0x7afd52a6,0xdfd00086,0x61e10026,0x28a7000b}},	//   vust, ديک_, _gell, _कीनि
  { {0x85f70053,0x2d98079b,0xc5eb000a,0xf1ac000b}},	//   עצטע_, ære_, הַכֹ, टेशन
  { {0x61e100b8,0x7afd52f4,0x5b27004a,0x7863007c}},	//   _zell, tust, ньга, _kõve
  { {0x291e0064,0x61e135fb,0x4ae70033,0xba19002b}},	//   çtan_, _yell, эўна, ويحا_
  { {0xe9190010,0x7f3b01ac,0x7afd52f5,0x6459002a}},	//   могі_, _מעדו, rust, zkwi
  { {0x7afd52f6,0x19950063,0x929b000a,0xda700015}},	//   sust, тавя, פילת, حُّ_
  { {0xbca50031,0x2d820061,0x26c202f2,0x7afd3637}},	//   _جمعي, şkes_, _buko_, pust
  { {0xa08b000a,0x81c2003d,0xb6060046,0x78ad52f7}},	// [cbb0] לְמִ, ģēja, zváž, rmav
  { {0x4b7c0008,0x26cf0024,0xd7940015,0x058724cc}},	//   _מאחו, īgo_, الْخ, нуем
  { {0x61e128d3,0xb8950015,0x7aed52f8,0x764e1827}},	//   _rell, _للدع, _hvat, _doby
  { {0x999a0089,0x61e10100,0x8ca7000b,0x9cd7000a}},	//   _např_, _sell, _टीमो, גואה_
  { {0x4429002c,0xd3230010,0x83c4005e,0x7cc1003d}},	//   ľa_, _мiну, убіж, _pērk
  { {0xe3b00029,0x764e0035,0x6d47008c,0x645906ed}},	//   حرم_, _goby, äjak, skwi
  { {0x637300dc,0x3a38000a,0xddda0046,0x04c9002b}},	//   _bűnö, תרום_, entů, _آوري_
  { {0x2ca90026,0x61e1475f,0x7aed52f9,0x9f5f1e83}},	//   _nhad_, _well, _ovat, lgué_
  { {0xef190191,0x61e152fa,0xa2b50033,0x0ea900ce}},	//   ємо_, _tell, _абач, мкий_
  { {0x9f5f18b3,0x2ca90509,0x92b70015,0x61e130fa}},	//   ngué_, _ahad_, _أحرا, _uell
  { {0x42360053,0x2606005d,0x91ca000b,0xbea20033}},	//   _שנעל_, स्टी_, _स्टै, раэк
  { {0xed560191,0x2ca952fb,0x90551100,0x0000006a}},	//   тою_, _chad_, _швец,
  { {0x2bba0015,0xfaff0003,0x7cc1003d,0x4c670214}},	//   بادة_, guë_, _mēri, тиян_
  { {0x26c201d7,0xfaa62935,0x7bcd01f9,0x75220535}},	//   _ruko_, таго, _efau, łozi
  { {0x2ca9002d,0x4ea40004,0x09e32c75,0x764e52fc}},	//   _fhad_, _срца, росн, _roby
  { {0x2614005d,0xdc760033,0x50b30065,0xbd6802ed}},	//   न्नी_, _шыль, ुदिष, _ярче_
  { {0xd70a0010,0x6ca50015,0x47c30c31,0x66e6144a}},	// [cbc0] ьнае_, _حصول, рбув, тоза
  { {0x787b022d,0x7cc80046,0xd4d60033,0x78630072}},	//   tävä, _měrn, відэ, _rõve
  { {0x09f7000a,0xd5af0015,0x7aed0085,0x661e2bc1}},	//   _במים_, قفك_, _zvat, repk
  { {0x97da0029,0x25a90015,0x33260015,0x787b008c}},	//   _تبدأ_, ردلي_, َّاق, rävä
  { {0x77830063,0x27fd005c,0x24490015,0x93f30033}},	//   _вляз, ówne_, عجمي_, рпіц
  { {0xdce90046,0x98b80091,0xd24f009a,0x67240546}},	//   áněn, tyrė_, ينن_, mwij
  { {0xca7b000a,0xda7b000a,0x154312ab,0xef1f0061}},	//   ונסט, ונסר, _керм, çün_
  { {0xc953013a,0x98be0007,0x83fd00dc,0x628f0f14}},	//   שמה_, štė_, _előb, _ícon
  { {0xa4910086,0x67240111,0x889b0008,0x2ca90026}},	//   _اینت, nwij, ובקי, _rhad_
  { {0xc106002b,0x672b001a,0x8fa302d9,0x0000006a}},	//   _لوئي, ægji, шање,
  { {0x7aed04c6,0xa3c952fd,0xc0060033,0xb5fb000a}},	//   _svat, लुक_, _апек, וליכ
  { {0xa157000a,0x0179004c,0x67240079,0x3157000a}},	//   _שבאה_, _אָנל, kwij, _שיאן_
  { {0xcff7000a,0xfe6f002b,0x2ef3005e,0xab8700e2}},	//   _יצאה_, صدی_, _взір, тунк
  { {0x67240111,0xc333000f,0x0f57000a,0x5fe0000b}},	//   dwij, בוש_, _בידם_, नरवल
  { {0x67240111,0x0c7b0015,0x2ca90034,0x644d008c}},	//   ewij, _يصعب_, _thad_, öaik
  { {0x9c7d0007,0x8c440001,0x1d070001,0x3da5005e}},	//   ksči, _веће, _рећи_, _сріб
  { {0xec380053,0x16150033,0x2d9c008c,0x35e700ce}},	// [cbd0] _יאהר_, лдаў, _hyve_, вцев
  { {0x0708003b,0x7cc1003d,0xfaa40099,0xe873002b}},	//   ئيلي_, _sēri, _кањо, _چندگ
  { {0xf8ae002b,0xf8c6006f,0xa43d0033,0x0b94002b}},	//   تکی_, žéra_, зьлi, _مجید
  { {0xc6d70015,0x7d7b000a,0x3d1a000b,0x7c2d1c74}},	//   _لتست, ורבג, _बहने_, _jaar
  { {0x7c2d52fe,0x27e952ff,0xc2c40021,0x249d0034}},	//   _maar, maan_, ليني, rlwm_
  { {0xdd86003b,0xd25b008f,0x65950033,0xdb1d0123}},	//   _هو_, ьце_, _багу, bbsö
  { {0xc692013a,0x7cc10024,0xf204005e,0xd4c4005e}},	//   _האם_, _tēri, рячо, _всуп
  { {0x3495070e,0xb1160015,0x27e95300,0xc0c80054}},	//   _сабр, اقيا_, naan_, њује_
  { {0xdd2e0089,0xe3b30002,0x443f5301,0x78bd5302}},	//   měře, _ضرر_, _inu_, _misv
  { {0x27e90665,0x442d00f2,0x2f0b0134,0xbe650002}},	//   haan_, _hae_, røg_, اهدي
  { {0x2f0b00fb,0x6724005c,0x27e9236d,0xd131006e}},	//   søg_, zwij, kaan_, _دما_
  { {0x27e95303,0xa1580054,0x6f005304,0x9516004f}},	//   jaan_, _шаху_, bumc, נקרא_
  { {0x442d0b7c,0x7c2d00f6,0x5ac7005e,0x6008000a}},	//   _mae_, _daar, ллям_, _יִסְ
  { {0xf1bf002c,0x442d5305,0x4e7b0058,0x0d73009a}},	//   ášho_, _lae_, _تحصد_, _پختگ
  { {0xfe700086,0x8cca005d,0x395e002e,0xa96a4bb2}},	//   _بدن_, _संयो, áts_, хива_
  { {0x6cd20086,0x67240079,0x442d030d,0x2d94005e}},	//   _اقيا, twij, _nae_, _тріс
  { {0x7ae9002c,0x8bd7000a,0x8c1b000a,0x35fa00c3}},	// [cbe0] šetr, _גופו_, _טוקי, فراد_
  { {0x67240298,0x3a260080,0xcec1005c,0xe9da1453}},	//   rwij, _смог, mięć_, _яко_
  { {0xde510092,0xae06005d,0x67240111,0x442d5306}},	//   _đặc_, _शासन_, swij, _bae_
  { {0x442d398b,0xd5af0015,0xe4d70067,0x27e95307}},	//   _cae_, سفن_, اونت_, caan_
  { {0x68e31405,0x6e2100df,0xb3760086,0x98b3005d}},	//   _ændr, kelb, دداش, ूआरए
  { {0x62345308,0x115417bd,0xcb13000a,0x5213005e}},	//   реку, иклю, צלו_, йдіт
  { {0xd1300029,0xa22707c1,0xc0e30180,0x70f30015}},	//   زمة_, ужја_, бојк, مسيئ
  { {0x78630020,0x8cca005d,0xd53b000a,0xd0100015}},	//   _kõva, _संबो, _אתלט, آلة_
  { {0xd4670083,0xa8570008,0xe4750010,0x24530015}},	//   _сите_, טיקה_, _турэ, _انقس
  { {0x27e95309,0xd337000a,0x321a002b,0xdce30061}},	//   zaan_, _גרמה_, _سيصد_, _aynı
  { {0xf67b0008,0x06970008,0xcec80092,0xa697000a}},	//   תאימ, רדים_, _bộc_, רכיה_
  { {0x9c47004a,0x61ea4634,0xf537000a,0xdee60515}},	//   ухол, lafl, אנטי_, _боди
  { {0x27e9022d,0xeb070080,0x40930029,0x78bd02b9}},	//   vaan_, ычно, _النر, _risv
  { {0x7c2d29a7,0x27e91c4f,0x2d9c0013,0xa143003d}},	//   _waar, waan_, _tyve_, _šķis
  { {0x7c2d000c,0x27e952ff,0x64400150,0x48ab4c55}},	//   _taar, taan_, _onmi, етам_
  { {0x20ca0016,0xac990015,0x65690046,0xddc10091}},	//   _mùi_, _جنبا_, _řeho, bilų
  { {0xdd2e0089,0x628310bd,0x78bd530a,0xe7190021}},	// [cbf0] věře, ynno, _visv, ضيات_
  { {0x6abe0012,0x27e95300,0xf7700015,0x2be3000b}},	//   _gipf, saan_, ساق_, परवा
  { {0x2614005d,0x2eed00dc,0x2aba000a,0x7bcf0a45}},	//   न्धी_, zsef_, _שמתא, occu
  { {0xd0060029,0x8883002b,0x6272002a,0x6e21530b}},	//   _ظل_, _ایرن, ołow, zelb
  { {0x290300f2,0x3869002d,0x53c80010,0x23af000b}},	//   luja_, mhar_, угім_, जेंद
  { {0x2614005d,0x3869001c,0x6d5a122e,0x7aef002d}},	//   न्दी_, lhar_, kyta, isct
  { {0x290300bd,0x7afd00b8,0x83fd00dc,0xe0450658}},	//   nuja_, hrst, _előa, инки
  { {0x3869001c,0x6d5a0870,0x7e7a0012,0xfc3f0125}},	//   nhar_, dyta, eitp, imís_
  { {0xaec2008f,0x29031437,0x6e21530c,0xb367006b}},	//   обыл, huja_, telb, _съвк
  { {0x62720050,0x7e55209b,0x29030f7a,0xf8bf0152}},	//   dłow, ртиц, kuja_, _lié_
  { {0xc05b0191,0x8d750029,0x6f1c0011,0x32cb003c}},	//   _під_, شادا, ărca, _høy_
  { {0x6e21530d,0x9596000a,0x7cd30045,0x7bdb001a}},	//   selb, יכתו_, _lărg, ðuup
  { {0xdee50001,0x9d52002b,0x6272002a,0x929d002a}},	//   _толи, منیت, głow, _spły
  { {0x6d5a0026,0x9f84005e,0x7d0103b0,0xab270054}},	//   byta, _угід, puls, јора_
  { {0xdca6005f,0xcec80023,0xfe700086,0x38760001}},	//   _каки, _tộc_, _عده_, аћат
  { {0xad1a013a,0xeb9f0bfa,0x8cca000b,0x69dc530e}},	//   _יוצר, rfør_, _संतो, sbre

  { {0x27fd0050,0xf8bf020a,0x929d0050,0xd90d0086}},	// [cc00] ówna_, _dié_, _wpły, ویی_
  { {0x7df3005d,0x05ba0015,0x45d6024f,0x2903039f}},	//   _आयोग_, ندات_, рцат, buja_
  { {0x3869002f,0x929d005c,0x98a618fa,0x69fb015b}},	//   bhar_, _upły, _вине, _בליק
  { {0x1d1600b2,0x0d16004c,0x0d3a004c,0x386910aa}},	//   יקער_, יקעט_, כגעב, char_
  { {0x6d5a002a,0xd4670054,0x6be9000a,0x61ea530f}},	//   zyta, шице_, רַעַ, tafl
  { {0xcb370008,0x6458005c,0x7ae4003f,0xc2970033}},	//   יאני_, _ścią, _mwit, акіх_
  { {0x63a900dc,0x61ea5310,0x8cc1000b,0x58f6000a}},	//   _ezen, rafl, _रंगो, ׁמַע_
  { {0x14d7011f,0x9326002b,0x64405311,0x61130033}},	//   _כולל_, _پررن, _unmi, ідыу
  { {0x93fb0008,0xa8570008,0xaf070015,0x7e4612ae}},	//   _שלמי, שיפה_, لقيم_, ахне
  { {0x6d5a0007,0xab5b0064,0x7afd02c6,0x24865312}},	//   tyta, zcüs, vrst, lnom_
  { {0x160b005d,0x3860002e,0xc5f30008,0xdd940010}},	//   स्टर_, kkir_, חדת_, саны
  { {0x290300f2,0xdfcf00a2,0x248613e1,0x73f9000a}},	//   vuja_, _قيم_, nnom_, ְּרו
  { {0x3ed40029,0xe4510008,0xc0450015,0x6d5a0b48}},	//   _اقتر, הֶם_, _دخلو, syta
  { {0xf20e005d,0xde570036,0x6d5a005c,0xdb0d0020}},	//   _साफ़_, _ваші_, pyta, _igaü
  { {0x6272005c,0x3869002d,0xadd70008,0x07e70175}},	//   słow, thar_, _דווח_, ицам
  { {0x7cc10048,0xfc3f0251,0xdda90036,0x7bc404ed}},	//   _vērt, rmís_, _стіл_, _ggiu
  { {0x395f0024,0x24861ff2,0x62980fde,0x55c70054}},	// [cc10] ņus_, dnom_, kovo, аљез
  { {0x248600c0,0x38690273,0xcfb7000a,0x3438002b}},	//   enom_, shar_, שלמי_, یسند_
  { {0x91fc0024,0x63a92f97,0x7ae40f55,0xbab40015}},	//   _plān, _szen, _zwit, _بصيغ
  { {0xef1f0064,0x83fd00dc,0x24860144,0xc3d40033}},	//   çük_, _előn, gnom_, оўшы
  { {0x8c380053,0x24180036,0x28c0000b,0x5398005e}},	//   יטאס_, рією_, _शूटि, авця_
  { {0x6298065d,0xe1f10015,0x8934002b,0x60c80723}},	//   govo, سست_, _اعیا, _budm
  { {0x25a500dc,0x24861e1b,0x09f8000a,0x0000006a}},	//   _áll_, bnom_, שֶׂר_,
  { {0xc2c50015,0x63f40015,0x20195313,0x24860160}},	//   _هيري, _وأقر, ýsi_, cnom_
  { {0x7cd30011,0x62980057,0x2011002a,0x63a04b13}},	//   _măre, bovo, ęzi_, _gymn
  { {0x69c50026,0xf772000a,0x01e9000a,0x0e65024e}},	//   _nghe, פקי_, _תַּֽ, скон
  { {0xc1040015,0xd1080015,0x7ae42fa8,0x38600052}},	//   _ووكي, _نقله_, _swit, ykir_
  { {0xad660033,0x64940061,0x816813d6,0xcc8a009a}},	//   саюз_, _güiğ, _труб_, انحه_
  { {0xc43a0008,0xec77006b,0xf43a004f,0x0000006a}},	//   אתרי, спя_, אגרמ,
  { {0x539a0008,0xfbd8005d,0x8f9a000a,0x7f3a000a}},	//   רישו, _भ्रम, _גיני, _תעסו
  { {0x7cc10024,0x291e2bee,0xa8a60015,0xa9670c96}},	//   _vērs, ïta_, مصرو, бира_
  { {0x7cd30011,0xfc320015,0x787a0046,0x62985314}},	//   _căre, _رحب_, růvo, zovo
  { {0x2486049f,0xe7aa05b3,0x386013e5,0xcec80016}},	// [cc20] vnom_, увал_, rkir_, _lộn_
  { {0x1a0605c4,0x35b609ef,0x7c265315,0x3860001a}},	//   _упом, бщес, lekr, skir_
  { {0x248637f7,0x2a57000a,0x7c260150,0xd910002b}},	//   tnom_, _הבין_, oekr, _تیز_
  { {0xd4990191,0xddda003d,0xd91b000a,0xfc3f0077}},	//   арі_, titū, _גוטל, plíe_
  { {0xa3c9005d,0x33170015,0x389b000a,0xb2d30015}},	//   ोड़_, مزود_, _תיכנ, كينغ
  { {0xe2970010,0x25080086,0x24860d98,0x43930033}},	//   бач_, _پرسی_, snom_, чаіс
  { {0x867b0053,0x64a60c1d,0xc5e4000b,0x14d8000a}},	//   _ערלו, _гава, गरीय_, _כַּמ
  { {0x741600b0,0x27e011ac,0x78a40107,0x2eff0012}},	//   _دورا, nbin_, nliv, fruf_
  { {0x336606b4,0x62980480,0x8f342341,0x4426252d}},	//   _уваг, povo, цепц, meo_
  { {0x4426000c,0x17570008,0x57570008,0xddc80026}},	//   leo_, מספר_, צביע_, yndŵ
  { {0xe0da0124,0x869b0053,0xa00a0021,0xaf36002b}},	//   _све_, רייז, _مقال_, _گرات
  { {0x7cd30011,0x44265316,0x6a6b0061,0x7c265317}},	//   _bărb, neo_, _müfe, gekr
  { {0xddc8016f,0x3ed70015,0x3b64006b,0x78a40057}},	//   midž, _هونج_, първ, dliv
  { {0x6fa50029,0x44260092,0x60c2002d,0x69c80e8f}},	//   _بإمك, heo_, _hiom, žden
  { {0x44260f4d,0x7cd30011,0xacf30029,0x4e17000a}},	//   keo_, _păre, _فسيت, _החוב_
  { {0x7c265318,0xc7d90822,0xd3950138,0x44260160}},	//   cekr, рмах_, _кiшэ, jeo_
  { {0x76550050,0x66d50015,0x9f440144,0x44265319}},	// [cc30] _pozy, زيائ, namà_, deo_
  { {0x3dd8000a,0x35f500fd,0x83fd0030,0x60c20125}},	//   שַּׁ, іпер, _elől, _liom
  { {0x442633c0,0x78a4531a,0x27e0531b,0xda48004f}},	//   feo_, bliv, bbin_, _הֲרָ
  { {0x442604ed,0x241904ab,0xd5b801c5,0xcec80016}},	//   geo_, роды_, ссу_, _rộn_
  { {0x7eaf06f5,0x36d50054,0x0000006a,0x0000006a}},	//   løpe, _фогр,   ,
  { {0x7c260fce,0xddc80095,0x86c4002b,0x60c2008c}},	//   zekr, eidž, _ريفن, _aiom
  { {0x7cd30011,0xa3d5005e,0x60c2531c,0x99f8004f}},	//   _mărc, _мовч, _biom, מזגה_
  { {0x26c302c1,0x5f450015,0x1f65005e,0x4426531d}},	//   _hijo_, قنبل, жким, ceo_
  { {0x6272005c,0x53472dc2,0x7c26531e,0x60c23308}},	//   głos, _ухва, vekr, _diom
  { {0x8cca005d,0x78a401c9,0x248d0293,0xddc80091}},	//   _संशो, zliv, _hjem_, aidž
  { {0xf3f90011,0x7cd30011,0x5c8a0036,0x7eaf00cb}},	//   _alţi_, _sărb, ийом_, jøpe
  { {0x1619005d,0x753600a3,0x8c4607d1,0xb5710138}},	//   न्तर_, קארד_, цеме, янiл
  { {0x78a40089,0x3fa7002b,0xeb9700eb,0x7c26531f}},	//   vliv, _اصاف, жия_, rekr
  { {0x7fb606e4,0x7c265320,0xfce500ff,0x44260085}},	//   _ظهور_, sekr, _доко, zeo_
  { {0xdab70074,0x78a45321,0x26d9008c,0xceb2004f}},	//   زهفت_, tliv, _atso_, _חיג_
  { {0x248d0844,0x385901b0,0x26cb02b9,0x2c730015}},	//   _njem_, брую_, _buco_, _يُوس
  { {0x98be0007,0x44265322,0x18670bb9,0xf1c9000b}},	// [cc40] štį_, veo_, цати_, िखान
  { {0x7dec0053,0x95e4000b,0x6d5c007c,0x96b9008b}},	//   ָקאַ, गरेट_, ärag, буху_
  { {0x26c30467,0x052a0892,0x673d31b9,0x78a45323}},	//   _dijo_, роек_, _ersj, pliv
  { {0x14170029,0xa5da000b,0xf74637c6,0x0000006a}},	//   قيمة_, _प्रौ, _демо,
  { {0x60c2002d,0x8c1b000f,0x44265324,0x26c30077}},	//   _riom, שוני, reo_, _fijo_
  { {0x366a008f,0xbb3b0053,0x44265325,0x60c23c93}},	//   _таго_, יעני, seo_, _siom
  { {0xb4260015,0x60c21c75,0xddc80091,0x6272002a}},	//   _وعرو, _piom, tidž, włos
  { {0x3ea500c0,0x9f540036,0x656302de,0x74b90033}},	//   ellt_, звич, ønhe, _гуус_
  { {0xf8b3000f,0x25aa000b,0x8fa30054,0xddc814c7}},	//   ושה_, _करुण, маће, ridž
  { {0xbbe3000b,0x4357004f,0xb77b004f,0xd357004f}},	//   पर्क, _וסמל_, יאפש, _וימי_
  { {0xa0a60010,0x60c2002d,0x5637004c,0xa06a5326}},	//   _дажд, _tiom, קאטע_, _кажа_
  { {0xac19005e,0x3eb90091,0x2cb20034,0x69c80091}},	//   щому_, įsta_, _chyd_, ždel
  { {0x628a5327,0x7ba7009a,0x0000006a,0x0000006a}},	//   onfo, تصدم,   ,
  { {0x32d00016,0xf24a004f,0x25aa0065,0x628a0c4e}},	//   _mày_, ׁגָּ, _करूण, nnfo
  { {0x30d8000a,0x628a5328,0x5e430015,0x6d5c3dc8}},	//   מַּע, info, _زَيْ, ärad
  { {0x5b250015,0x4cf7000a,0xceb81ed6,0x83fd0030}},	//   _ففعل, _וזהב_, lmę_, _előj
  { {0x32d000a7,0x96eb004a,0x61fa08a9,0x0000006a}},	// [cc50] _này_, рьба_, _odtl,
  { {0xa3c0000b,0x85a70054,0xa567006e,0x6e2801c0}},	//   ीशन_, ојед, يدان, nedb
  { {0x69d5005c,0x454b0033,0x7d085329,0x628a006f}},	//   mcze, шчам_, nuds, dnfo
  { {0x32d00092,0xd3b9005e,0x69d5532a,0x8464006b}},	//   _bày_, блеї_, lcze, мъче
  { {0x4c3c00b2,0x13080036,0x999100dc,0xe28e000d}},	//   יגאצ, жній_, mező_, еа_
  { {0x999100dc,0x69d5005c,0x32d00092,0xe29907c1}},	//   lező_, ncze, _dày_, љак_
  { {0x82340029,0x81f60029,0xd24e0015,0xdb1d0030}},	//   برنا, سفير_, انى_, ecsü
  { {0x628a0026,0x11280036,0x3ea50034,0x45440015}},	//   anfo, юючи_, wllt_, _تنفق
  { {0x2cb20034,0x69d5002a,0x32d000a1,0xd25901ec}},	//   _rhyd_, kcze, _gày_, _suņu_
  { {0x32640063,0x7d090054,0x22580015,0x31350219}},	//   _отхв, бног_, _وجلب_, _незр
  { {0x999100dc,0xb65c0053,0x69d5005c,0x99830089}},	//   kező_, ידזש, dcze, dejů_
  { {0x69d5005c,0x672d003f,0xe3a70087,0x999100dc}},	//   ecze, kwaj, فر_, jező_
  { {0x70520029,0x5f28005e,0x20d10016,0xab630033}},	//   _سنوا, _моїм_, _hái_, евял
  { {0x7f3a0008,0x7d08532b,0x539a000a,0xcd28002b}},	//   _לענו, buds, מירו, حسین_
  { {0x6e160074,0xf8aa002b,0xc8c70015,0x3e320040}},	//   _رييس_, مدره_, كوّن_, _سفير
  { {0x20d10092,0x786a0057,0xfc3f532c,0x69d5002a}},	//   _mái_, _býva, plía_, acze
  { {0x20d10092,0x83fd00dc,0xa6db001a,0x628a0034}},	// [cc60] _lái_, _elők, _arðb, ynfo
  { {0x69d50089,0x7c360064,0x4b7b000a,0x069a0015}},	//   ccze, _hayr, _לאפו, حنطة_
  { {0x4a5b0008,0xfc3f002d,0x672d003f,0xb91a0015}},	//   _הדיו, ilín_, awaj, _اتخذ_
  { {0x136a0036,0xc20e005d,0x628a0495,0x2d910061}},	//   йшли_, _साहब_, wnfo, üzey_
  { {0x7c3600b6,0x883b0008,0x6234000d,0xe2f80010}},	//   _mayr, _התכו, делу, целі_
  { {0x20d10016,0x27f202f2,0xd233006b,0x628a16ee}},	//   _bái_, layn_, еншъ, unfo
  { {0x20d10023,0x6e28532d,0x29182a8c,0x628a27ff}},	//   _cái_, vedb, ntra_, rnfo
  { {0x69d5005c,0xdfd00029,0x7d0802ce,0xb4fb000a}},	//   zcze, خية_, vuds, _לפלי
  { {0x213e0176,0x69d5005c,0x74130002,0x436a005e}},	//   _wrth_, ycze, _سولا, _уаан_
  { {0xade30010,0x2903002e,0x7cd30011,0x20d1002e}},	//   нцюк, yrja_, _săra, _fái_
  { {0x6e28016f,0xceb8005c,0x20d10092,0x3c95004a}},	//   redb, rmę_, _gái_, динё
  { {0x672d005c,0x7d080134,0x69d5005c,0xe50d000b}},	//   ywaj, ruds, wcze, ांति_
  { {0x6e460010,0xdfcf0015,0xef1f0061,0x5ba70033}},	//   _недз, _إيه_, çüt_, яроз
  { {0xfe6f0029,0x4efb000a,0xadbc0033,0x83fd0030}},	//   _مدى_, _פלוג, _калi, _előh
  { {0x69d5005c,0x999100dc,0x67d50036,0xce370015}},	//   rcze, tező_, добу, _رأوا_
  { {0x7ceb000f,0xb8e7000b,0x7c360061,0xdca40054}},	//   _הַזֶ, _ों_, _gayr, _паји
  { {0x963502e1,0xcc340115,0xe7ee000b,0xf7700015}},	// [cc70] мнац, _سريع, _ज़रा_, هاك_
  { {0x5e78000a,0x786a04b2,0xdb26009a,0x672d532e}},	//   קָּד, _výva, _کویی, rwaj
  { {0xc4c70067,0x7863007c,0x290a3c3f,0x99910030}},	//   ستاو, _lõvi, cuba_, pező_
  { {0xf992000a,0x6b8200bc,0x0000006a,0x0000006a}},	//   _ירי_, _žogi,   ,
  { {0x9f590064,0xe3b00002,0x883a000a,0x42d4005e}},	//   üsü_, هره_, _ותרו, ніщу
  { {0xa0210064,0x20f70045,0xee2e0138,0x3f98007f}},	//   _çöze, tăi_, _анi_, ğrul_
  { {0x90b50001,0xe1f00002,0x6594071f,0x787a0091}},	//   мљиш, اسه_, _зару, eįvy
  { {0x42770086,0x260b000b,0x5277002b,0x5ef9045f}},	//   _کارآ, ालवी_, _کارز, охор_
  { {0x290a003f,0x25d5000a,0x52151377,0x64c40015}},	//   zuba_, ֽוֹן_, _одат, _سيكل
  { {0x20d10092,0xda1f005d,0xddc30011,0x4d651402}},	//   _tái_, म्मत_, _conş, дков
  { {0x90e70074,0xc5f20008,0xfc3f532f,0x62830e35}},	//   _رسان, כדי_, rlín_, mino
  { {0x0c7a0010,0x645b0152,0x62832fef,0xff51002b}},	//   існы_, _joui, lino, _لخت_
  { {0x6f090a40,0x645b0003,0x5e450015,0x76080030}},	//   quec, _moui, _يَصْ, nézü
  { {0x7e660048,0x1f640010,0x290a1f27,0x645b1650}},	//   ūkpr, _якім, tuba_, _loui
  { {0x485a0010,0x83fd0030,0x29184c66,0x19b9005e}},	//   ораў_, _elői, utra_, зуть_
  { {0x7c950010,0x29180097,0x8c3b0012,0x290a5330}},	//   _прыц, rtra_, toße, ruba_
  { {0x29185331,0xabfb000a,0x628332ce,0x98a35332}},	// [cc80] stra_, _והפר, kino, тите
  { {0x461a0010,0x8c3b00b8,0xda0a0015,0x8cd9000a}},	//   ўцаў_, roße, _بيده_, ַחְת
  { {0x645b1193,0x27f2008c,0xf769000a,0x6f1c0045}},	//   _boui, payn_, סק_, ărci
  { {0xc6890008,0xed56004c,0xc8b60033,0x628326a6}},	//   בא_, ובער_, _існы, eino
  { {0x23ba0015,0x628314b9,0xc4c500c3,0x87ba02db}},	//   آداب_, fino, رتمو, _фунт_
  { {0xfe6704b6,0xa2940010,0xa3bf000b,0xa3de000b}},	//   _شد_, эалі, ुख़_, _द्र_
  { {0x65c33188,0x645b0003,0x94d60015,0xa0220061}},	//   _абра, _foui, _آيرش, _çökt
  { {0xcec80023,0x628326f9,0x2c620227,0x6b965333}},	//   _hội_, aino, _kódu_, _oxyg
  { {0x80a30015,0xe80f000b,0x765c0188,0xe1fa0151}},	//   خمين, िलता_, _kory, _мга_
  { {0x7cd30011,0xe2460087,0x8d860004,0x01d70015}},	//   _căro, _تخري, думд, _يوقع_
  { {0x765c028a,0xcec80016,0x2056006b,0x91fc01ec}},	//   _mory, _mội_, _отдр, _blāv
  { {0x38880064,0xcec80016,0x0000006a,0x0000006a}},	//   oğru_, _lội_,   ,
  { {0xa6db0084,0x00bb000a,0x8cca000b,0x5f730067}},	//   _orða, _ומאמ, _संको, _لاور
  { {0x99580089,0x28a7005d,0xb0610209,0xdeb40033}},	//   láře_, _कीजि, _ääre, _яблы
  { {0xcec80023,0xad26002b,0x127b004c,0x7e9b000a}},	//   _nội_, _آرتو, קאלע, _וסגו
  { {0x99580089,0x3cfb000a,0xf773002b,0x9c580015}},	//   náře_, _ולהנ, پار_, _يجيز_
  { {0xb8d6000b,0x57790033,0x7bcd003d,0x645b0003}},	// [cc90] _ची_, чбаў_, _igau, _roui
  { {0xfc460107,0xff17000a,0x2bb80015,0x76ab005e}},	//   šíte_, וקמת_, _غاية_, ітав_
  { {0x7dd10030,0xcec80016,0x645b0003,0xd49b1411}},	//   _hűsé, _cội_, _poui, орд_
  { {0x05df014e,0xd5df005d,0x7aed12d1,0x97c70015}},	//   _प्रब, _प्रज, _kwat, _يتحم
  { {0xf3f00029,0x3c780008,0xe8df0092,0xb7da00f3}},	//   شأن_, ותאם_, _khỏe_, _מקרי
  { {0x64490034,0xc1c9000b,0x765c0226,0x38695334}},	//   _wnei, िखेग, _gory, lkar_
  { {0x02c20010,0x23690263,0x10a501e5,0x64ca000b}},	//   ыйшо, šaj_, никн, िदृश
  { {0x442b0092,0x386902ce,0x64c50015,0x2f55080e}},	//   _úc_, nkar_, _أيرل, етос
  { {0x3869002e,0x7d1a2078,0x7aed00aa,0x62835335}},	//   ikar_, etts, _nwat, pino
  { {0x53340054,0x7d090054,0x91fc003d,0x216703de}},	//   _јефт, пног_, _slāv, _отег
  { {0xd0110018,0x386905d8,0x2614000b,0xf652000a}},	//   _ملا_, kkar_, न्टी_, אצי_
  { {0x3e69002c,0x116a0086,0x113a000a,0x6019006b}},	//   _túto_, _علنی_, _מתעל, _ходя_
  { {0x9056000a,0xbf67012c,0xdb82005e,0x6615002a}},	//   _רבנו_, _تداو, урнi_, _oczk
  { {0x427900b2,0x0000006a,0x0000006a,0x0000006a}},	//   לאָג,   ,   ,
  { {0xae78008f,0x36e8000b,0x38720034,0x48b60734}},	//   _ўсіх_, _चौड़ी_, thyr_, ещат
  { {0x786a099c,0x6615002a,0x386901c2,0x63a90077}},	//   _vývo, _aczk, gkar_, _oyen
  { {0x62815336,0x2d1f000b,0x765c5337,0x6f1b153a}},	// [cca0] _omlo, _बहुल_, _pory, ntuc
  { {0xba760074,0xdb9b0008,0x75ce0030,0x38695338}},	//   _ساخت, _מספר, dőzí, akar_
  { {0x8a170008,0x78710f47,0xceb2000a,0x64ca000b}},	//   _אחיו_, _såve, ניב_, िदेश
  { {0x386901d1,0x787102ce,0x63a90293,0xcec80016}},	//   ckar_, _påve, _byen, _vội_
  { {0x52d7005e,0x3e720003,0xa34a0033,0x660b0030}},	//   емію_, _hâte_, язда_, álké
  { {0xcec80092,0x69c1001a,0x6d435339,0x0000006a}},	//   _tội_, ýleg, _orna,
  { {0x3a3a00c0,0x50660004,0x66c90091,0xa6c70015}},	//   _mapp_, етпа, _užka, _أوّل_
  { {0xc9530008,0x26ca003f,0xdfda006b,0x251b000a}},	//   רמה_, _hibo_, чък_, _מולא
  { {0x63060086,0xdb1d00dc,0xbe860054,0x4424533a}},	//   _سوال, lcsö, ећни, _ibm_
  { {0xdbfb005d,0x99580089,0x42fb000a,0x12fb000a}},	//   ्ल्ड_, sáře_, _מהמס, _מהמב
  { {0x83fd00dc,0xfc3f01b2,0x6d430085,0xdb160030}},	//   _előu, slím_, _crna, _együ
  { {0x2486005c,0xead50080,0x26ca0035,0x7f422f54}},	//   niom_, комь, _libo_, _troq
  { {0x386900bd,0xfbab0139,0x5b24005e,0x93fb000a}},	//   vkar_, ятой_, льра, הלכי
  { {0xcf890029,0xe1ee0033,0x64470091,0x2ba5000b}},	//   _تضمن_, агi_, _ėjim, _गुणा
  { {0x3e720011,0x1994006b,0x59a4000b,0x7c24001a}},	//   _câte_, гаря, _खुदर, _fbir
  { {0x35aa005d,0xbb850015,0xe8e00016,0x91fc003d}},	//   _करज़, _للعي, _chốt_, _klās
  { {0x7c2f0144,0x38693a47,0x6d430085,0x5bb900eb}},	// [ccb0] mecr, rkar_, _zrna, _юлия_
  { {0xc7c40080,0x7c240796,0x26ca02b9,0x3869533b}},	//   усси, _zbir, _cibo_, skar_
  { {0xf77f0152,0x442400e8,0xf5270033,0x91f50016}},	//   _reçu_, _bbm_, эфан, _bón
  { {0x62810089,0x6f1b005c,0x85b8002b,0xb6f50054}},	//   _smlo, ytuc, رالس_, _измј
  { {0x27e9533c,0x77f6000a,0x7c3d317d,0x4424533d}},	//   mban_, _במרד_, idsr, _dbm_
  { {0x7cc9005c,0x82180063,0x63a9003f,0x27e90f06}},	//   _ośro, ецът_, _vyen, lban_
  { {0x4095533e,0x3a38000a,0x5694533f,0xc0950054}},	//   крит, גרום_, _сарт, кшић
  { {0x27e90014,0xdb080061,0x2486002a,0x3eac0079}},	//   nban_, _ölçm, ciom_, eldt_
  { {0x7cc20024,0x93970029,0x442f0d38,0x8ccb000b}},	//   _tērz, _أجزا, meg_, _संजो
  { {0x83fd0014,0x78ad0107,0xcf240015,0x0e6541f8}},	//   _előt, hlav, اريي, ткон
  { {0x27e90014,0x2619005d,0x442f0409,0x61550015}},	//   kban_, _पानी_, oeg_, _جنائ
  { {0x442f0304,0x20030091,0x28d2000b,0xc058005e}},	//   neg_, ėjis_, _दूषि, _піч_
  { {0x207a00b2,0x907a0008,0x93fa0008,0x27e900dc}},	//   _קאנא, _קטני, ולרי, dban_
  { {0x2486005c,0x3e720003,0x442f5340,0x6d435341}},	//   ziom_, _pâte_, heg_, _trna
  { {0xc212013a,0x6f0902f7,0x6d43026a,0xf9835342}},	//   יהם_, lrec, _urna, агро
  { {0x442f010b,0x2904002c,0x27e900dc,0x5dc80008}},	//   jeg_, čma_, gban_, _אֶפְ
  { {0xbc1b0008,0x442f5343,0x2ee00064,0x6d4100dd}},	// [ccc0] _חופש, deg_, _çift_, lvla
  { {0x6d410085,0x78ad0e80,0xddc80046,0x442f03f8}},	//   ovla, alav, ejdř, eeg_
  { {0x27e90014,0x6f0900b8,0xda4b000a,0xe8e00016}},	//   bban_, hrec, _חֲכָ, _thốt_
  { {0x254100df,0xd4090015,0x78ad5344,0x27e90030}},	//   _dėl_, فتهم_, clav, cban_
  { {0xb2d30029,0xa2d300c3,0x8bd7000a,0x3eac0013}},	//   لينغ, لينت, דונו_, yldt_
  { {0x442f0020,0x5b7b0053,0x443d0026,0x6f095345}},	//   aeg_, ורנא, adw_, drec
  { {0xcec800a7,0x764e00c0,0x442f5346,0xe2a90040}},	//   _một_, _inby, beg_, راهن_
  { {0xf9930008,0x75370053,0x656303a4,0xc0340054}},	//   ירו_, _באלד_, änhe, униј
  { {0x83fd00dc,0x60cb0035,0xadd40054,0x72c62044}},	//   _elős, _digm, лопљ, _абаз
  { {0xa80601e2,0x91ba0087,0x9e740015,0x27e90030}},	//   ldığ, _قطار_, اهدت, zban_
  { {0x6f0904f9,0x78a400f2,0x2d980061,0x80a3002b}},	//   arec, koiv, çre_, طمین
  { {0xa80601e2,0x70530086,0xb4fb000a,0x5f060010}},	//   ndığ, _پنها, ופטי, _азда
  { {0x9b580063,0xeb07006b,0xcec80016,0x290a01c2}},	//   вият_, ъчно, _bột_, erba_
  { {0xcec80092,0x442f12e0,0x61f85347,0x6d4100bc}},	//   _cột_, zeg_, navl, bvla
  { {0x27e90014,0xeb9f0134,0x2ba5000b,0x443d0034}},	//   tban_, ggør_, _गँवा, ydw_
  { {0x69dc0f21,0x7c870783,0x27e95348,0x95eb0065}},	//   acre, _шуле, uban_, टर्ट_
  { {0xcaa7003b,0xf1a9005d,0x20d8002d,0xcc880015}},	// [ccd0] _لصدي, _चुनन, _léi_, _جنيه_
  { {0xe4e70036,0x61f8060b,0x27e900dc,0xfaf90007}},	//   відн, javl, sban_, šūs_
  { {0x27e900dc,0x2121000b,0xe4d40015,0x2815002b}},	//   pban_, _महेश_, لتنب, _یوگس
  { {0x254100df,0xd3b902e1,0xd7e4005e,0x29110061}},	//   _vėl_, нулі_, _віро, muza_
  { {0xd5bf0024,0xe73d0089,0xfc3f5349,0x442f1b63}},	//   _šādi_, _kříž, idí_, reg_
  { {0xd2510015,0x026b004a,0xe2990033,0x63ad002a}},	//   صنع_, ьшей_, эал_, żano
  { {0x29110064,0x68e2005c,0x8145002b,0x6d5c007c}},	//   nuza_, _łodz, انبن, äral
  { {0x83fd00dc,0x7f59000d,0x5434002b,0x50b50033}},	//   _előr, ејот_, _پرفر, ыслу
  { {0x2f540010,0xb4bf005d,0x61f8044c,0x4df501f3}},	//   атэс, ँगी_, bavl, лянт
  { {0x2911003f,0xa8060064,0x6f090390,0xb062008c}},	//   kuza_, mdış, rrec, _äänt
  { {0xcc8a0001,0x6f090596,0x02440015,0x3519004f}},	//   ебне_, srec, _خَلَ, עוֹנ
  { {0x6703005d,0x2911534a,0x6f090334,0x2ba5000b}},	//   _लिंक_, duza_, prec, _गुहा
  { {0x7cd304f9,0xdce80089,0xa8060061,0x4c8315f1}},	//   _mări, ozdě, ndış, сляв
  { {0xa8060064,0x29110011,0xd356000a,0x6d41042f}},	//   zdığ, fuza_, אישי_, pvla
  { {0x78a4008c,0x6e92002b,0xfe9a000a,0x6fe20046}},	//   toiv, _دلوا, _איסמ, síců
  { {0x69dc1647,0x2ba5000b,0x7afd01d0,0x0000006a}},	//   scre, _गुवा, bsst,
  { {0x3ea50020,0x29110045,0xdc9b000a,0x3e720003}},	// [cce0] oolt_, auza_, _ריפל, _hâta_
  { {0x66c900df,0xa3c9000b,0x78a4008c,0x7ae402f2}},	//   _užkl, ैशन_, soiv, _itit
  { {0xf2a70010,0x04462bb2,0x3a37000a,0xd46a007e}},	//   _якiх_, лежн, _גרים_, ниже_
  { {0xb8f8005d,0x33f60029,0x3ea5534b,0xe4a5005e}},	//   ाद_, اساس, holt_, аріо
  { {0x61f8065d,0xa8060064,0x57fb000a,0x3ea50030}},	//   tavl, rdığ, _אלכו, kolt_
  { {0xd13a03fc,0x68e2002a,0xcb37000a,0xfc3f01c0}},	//   ехи_, _łody, טאני_, zdí_
  { {0x61f8065d,0x2619000b,0xca37000a,0x3ea50030}},	//   ravl, _पाती_, רנצה_, dolt_
  { {0x6d5c0020,0x64a60cad,0xf5930015,0x61f80085}},	//   äram, _саба, _الفج, savl
  { {0x883b0008,0xa857000a,0xa3e4000b,0x5f940555}},	//   תתפו, ריפה_, पुण_, рипт
  { {0x073701e4,0xd7370008,0x7054002b,0x3ea50030}},	//   נאים_, נטית_, انکا, golt_
  { {0x7ae400df,0xa196023e,0xfe6f0015,0x4fea0033}},	//   _atit, _сјај, ثدي_, _змен_
  { {0x2fd60015,0x628a534c,0xfc3f0069,0x7afd1694}},	//   _إتاح, lifo, udí_, tsst
  { {0x2f1803e7,0x7afd177b,0xfe6f002b,0xfc3f534d}},	//   _роль_, usst, زدی_, rdí_
  { {0x7f3b0053,0x7ae0001a,0x7ae40125,0x628a534e}},	//   _רעגו, ímta, _dtit, nifo
  { {0xd5eb0092,0xa935005e,0x7afd0012,0x4ddb000a}},	//   _đìn, шевш, ssst, _אחוו
  { {0x91bb000a,0x5dcb000a,0x7afd534f,0x718b004f}},	//   תמלי, _נֶגְ, psst, גְמַ
  { {0x7c940086,0x804b000a,0xcb35006b,0x23c80091}},	// [ccf0] _دشوا, עֲלֶ, _тепъ, nįjį_
  { {0x2b490026,0x7cd30045,0x07080015,0x0000006a}},	//   _irac_, _sări, ايلي_,
  { {0xfbdf03af,0xceb3103d,0x7cd30011,0x89da000a}},	//   ocê_, ציע_, _pări, _בחתי
  { {0xd3710196,0xb4bf005d,0x63050015,0x3ea50030}},	//   يها_, ँगे_, لوصل, zolt_
  { {0x6d5c0604,0xd7fa000a,0x57fa000a,0x93240015}},	//   äraj, _שהשל, _בלרו, مرون
  { {0xc2c400e6,0x32bb0015,0x15ab006b,0x45d4109b}},	//   ميني, ردشة_, _зъби_, _горс
  { {0xc6920008,0x7cd30011,0xf4020011,0xf204005e}},	//   _ואם_, _tări, faţă_, сячо
  { {0x20190020,0xd1480067,0xaf052d90,0x5f29033d}},	//   üsi_, اشون_, апил, воим_
  { {0x7f75008f,0xcf8e0086,0x443f5350,0x7eaf003c}},	//   руйц, وژه_, _iau_, løpi
  { {0x92b70015,0x8d750015,0x786a04b2,0x2019002a}},	//   _إحرا, لاجا, _vývi, żsi_
  { {0xb0350080,0x3ea500dc,0xc1040015,0x78780030}},	//   _внеш, rolt_, _هولي, _híve
  { {0x3ea500dc,0x443f1ce1,0xcb6a0403,0x03d5000a}},	//   solt_, _jau_, ваме_, יוֹם_
  { {0x7aa60029,0x443f5351,0xce95006b,0x68e50125}},	//   لإسل, _mau_, _кадъ, _athd
  { {0x17ee000b,0x19960b1e,0x8f7a000a,0x2b495352}},	//   जर्व_, ајбр, _שנסק, _drac_
  { {0xa7fb0077,0x2eff01d7,0xf8aa002b,0x2bc7000b}},	//   _soña, lsuf_, ندره_, रेबा
  { {0xcec80023,0xad1a0008,0x614000dc,0xd5eb0092}},	//   _hộp_, _סופר, lálá, _đín
  { {0x787803af,0xa6860010,0x4c3b000a,0xdd2f0046}},	// [cd00] _níve, алад, _יתקב, věřt
  { {0x61400014,0x8afb0008,0x63a6003c,0x7c260855}},	//   nálá, _שהיי, _økni, lfkr
  { {0x7556023e,0x78710123,0x18b8002b,0x332d5353}},	//   шњац, _gåvo, _مضحک_, _apex_
  { {0x656300f2,0x443f414c,0x499b00f3,0xc7a6005e}},	//   änha, _cau_, _ישיב, _вимк
  { {0x443f5354,0x43730054,0xf4020045,0x61400030}},	//   _dau_, жујт, vaţă_, kálá
  { {0x443f0152,0xcec80092,0xcb13000a,0xe1ef0015}},	//   _eau_, _nộp_, קלו_, وسى_
  { {0xe6110008,0x52750001,0xd1300029,0x628a5355}},	//   _מִן_, ључу, سمة_, rifo
  { {0xd0100029,0xfbc7005d,0x20540063,0x443f0026}},	//   ألة_, रेडम, ския, _gau_
  { {0xcee70001,0x0877004c,0xd467067a,0x7cd30045}},	//   адње_, יעקט_, _тите_, _măru
  { {0x614000dc,0xd337000a,0x2ef30033,0x61f8000a}},	//   gálá, _דרמה_, ўзэр, _תִּג
  { {0x627b000a,0xc27b000a,0xb1170015,0x64405356}},	//   _שנבנ, _שרבי, _نقلا_, _kami
  { {0x2b49005c,0x4fa64d4b,0x44265357,0xf537000a}},	//   _prac_, _киев, nfo_, בנטי_
  { {0x64402d6a,0xdd390011,0x614000dc,0xfbdf016e}},	//   _mami, păşe, bálá, rcê_
  { {0x28db005d,0x4efb0008,0x644200f2,0x8bc40010}},	//   _मंदि, _יהדו, hdoi, ўсюд
  { {0x88870004,0xdebb000a,0x3ebb004f,0x0000006a}},	//   аѓал, _שמול, _שצוב,
  { {0x7cd30011,0x64400253,0x2b494158,0xdd1b0046}},	//   _căru, _nami, _trac_, _náře
  { {0xdc9c000a,0xe7190015,0xc6a7005e,0xcc340015}},	// [cd10] _שיחל, طيات_, аржи, _ذريع
  { {0x443f5358,0xe61303c4,0x6442008c,0xcec1002a}},	//   _sau_, تشر_, edoi, chęć_
  { {0xf8b10074,0x443f5359,0xba9a000a,0x4426535a}},	//   _فکر_, _pau_, _תסתי, ffo_
  { {0x61400014,0x29360053,0x3605002b,0x64402cb1}},	//   zálá, _פארן_, _گوسف, _cami
  { {0x6440535b,0xa6db002e,0x443f0251,0x4345006b}},	//   _dami, _orði, _vau_, селв
  { {0x7b38000a,0x52a80033,0xdcfe0046,0xf2e4005e}},	//   שָׁע_, авім_, ávěn, іючо
  { {0x61400014,0xfa78000a,0x6f02352d,0x6594512b}},	//   válá, שעות_, _avoc, _дару
  { {0x64405009,0x26d1441c,0x7cd30011,0x5998000a}},	//   _gami, _hizo_, _mărt, יכוב_
  { {0x33750001,0x6d4a0026,0x614000dc,0x6d5a05d7}},	//   _угар, _arfa, tálá, exta
  { {0x6f02002c,0xf1a7009c,0xdd1b0046,0x64403414}},	//   _dvoc, _крен, _záře, _zami
  { {0x63be005c,0x614000dc,0x41b50087,0x212a002b}},	//   ępne, rálá, _امار, _ميلی_
  { {0x672f0050,0xfc320029,0xf8bf0092,0xdb0a0046}},	//   _opcj, أحد_, _nhé_, řník
  { {0x9f40002e,0x2d8b005c,0x62880034,0x6d4a2036}},	//   _þið_, ńce_, _ymdo, _erfa
  { {0x63bb003f,0x7cd30045,0x2a9a0015,0xa2d8000b}},	//   _mzun, _săru, ائحة_, मदत्
  { {0x6a6b0064,0x38c80086,0x0dc80001,0x7cd30045}},	//   _nüfu, لاری_, _кући_, _păru
  { {0xb8660015,0xf8bf02b9,0x945d002a,0xbc9303ae}},	//   حاسو, _ché_, _mińs, _најј
  { {0x44f5032c,0x27e0535c,0x6440535d,0x2bc70065}},	// [cd20] eť_, rcin_, _rami, रेदा
  { {0x77c71e73,0x05ba0087,0x6b5b000a,0x6440535e}},	//   слуг_, هدات_, _עדיפ, _sami
  { {0x2619005d,0xd6cf0029,0xa5c6005c,0x58d30004}},	//   _पारी_, رقم_, _opóź, _ноќт
  { {0xf8bf0092,0x26d9535f,0xc3060015,0x74130015}},	//   _ghé_, _fuso_, مبتو, كوما
  { {0x8c1b013a,0x44f5002c,0x28b5005d,0x64425360}},	//   רוני, ať_, ंतरि, rdoi
  { {0x66e3010f,0x38600084,0x8b06005c,0x6440003f}},	//   _хора, ljir_, częś, _wami
  { {0x7af60026,0x5ba5000b,0xdfda006b,0x67245361}},	//   _lwyt, _ऐड्व, лъп_, ltij
  { {0xc9530008,0x049600e6,0x38600509,0xa2d60015}},	//   למו_, _الرح, njir_, _هيرت
  { {0x6d460024,0x9f5302bf,0xa857000a,0x25b8000b}},	//   ākam, звыч, מיקה_, _अरुण
  { {0x62650029,0xa3e4005d,0x867b0053,0xdbf1000b}},	//   _والق, पुर_, ָרטו, चर्ड_
  { {0x67240f8a,0xec35005e,0x81460015,0x9e66002b}},	//   htij, оннь, _دنان, لاگن
  { {0x7af60026,0xac190286,0x672406d6,0x91bb000a}},	//   _bwyt, шому_, ktij, _גמבי
  { {0xdfcf0015,0x60a50015,0x62985362,0x0b8b0763}},	//   _كيم_, _بإلق, onvo, усни_
  { {0xb69b0011,0x44f5002c,0x62981611,0xaf070015}},	//   _avân, yť_, nnvo, _اقوم_
  { {0xdd93008f,0xcce600e5,0x9178000a,0x66c90091}},	//   _нашы, _استي, בְּח, _užki
  { {0x63ad005c,0x998500dc,0x67240111,0x7af60026}},	//   żani, ülő_, ftij, _fwyt
  { {0x5b040015,0x3ef8000a,0x58840033,0x67240079}},	// [cd30] _فِيم, שִֽׁ, чыра, gtij
  { {0x32f6005c,0x1af8000a,0xcb12000a,0xb595006b}},	//   dły_, _המזל_, _קלי_, оизш
  { {0xf8bf0003,0x63bb0e8c,0xab98002b,0xddda0030}},	//   _thé_, _szun, _نخیر_, nktő
  { {0x9d1b000a,0x95c40015,0x20c10125,0x99910046}},	//   רואט, سينه, móig_, lezů_
  { {0x44f5002c,0x32f6005c,0x24180036,0x7c2d5363}},	//   sť_, gły_, сією_, _mbar
  { {0x6d460024,0xf9900086,0x95cb067a,0xa5c6002a}},	//   ākaj, _آبی_, _буба_, _spóź
  { {0x32f6005c,0x76ba000a,0x2903002a,0x78780030}},	//   ały_, _כמשפ, nsja_, _híva
  { {0x63b6002a,0x4f090588,0x7c2d0c4e,0x62980546}},	//   żyna, анин_, _nbar, anvo
  { {0x63bb0064,0xc0c80001,0x8e590054,0x60060033}},	//   _uzun, љује_, ајну_, цным_
  { {0xd1090086,0xf78a0053,0x29030d09,0x1758000a}},	//   _نقطه_, ינפֿ, ksja_, מסחר_
  { {0xbc6a0015,0x3f740016,0xda20000b,0x60da3147}},	//   لمدن_, àu_, _बाबत_, _gutm
  { {0x0f550015,0xac970015,0xe0ce00fd,0x8f550015}},	//   _وَاح, ْنَا_, _ів_, _وناش
  { {0x543a0053,0x643a0053,0x3b83017f,0xdcee003d}},	//   בערא, בערנ, дляг, ējāt
  { {0x3e7b0003,0x7c2d007c,0x3ec701f3,0x6a700012}},	//   _bête_, _ebar, _усеб, _käfi
  { {0x32f6002a,0x7cd30045,0x3860001a,0x442d05e3}},	//   zły_, _vărs, tjir_, _obe_
  { {0xf7720029,0x32f6005c,0x2816002b,0x9c7d0091}},	//   واء_, yły_, تورس, ypči
  { {0xa6db002e,0x3860002e,0x77940086,0xd5b80024}},	// [cd40] _orðu, rjir_, سیسا, _šā_
  { {0x20c1002d,0x3e7b482e,0x88c80046,0x78780247}},	//   lóid_, _fête_, dběž, _díva
  { {0x2a570008,0x7eaf003c,0xc68f0029,0xfe21000b}},	//   _ובין_, løps, خِل_, _मानस_
  { {0xd499005e,0xe71a002b,0x32f6002a,0x76550e98}},	//   брі_, _پيست_, tły_, _enzy
  { {0x83360115,0x57470033,0x96760033,0x386f0123}},	//   تراض, _дзям_, _дыві, ögre_
  { {0x3636002b,0x32f6002a,0x86790033,0xa6e2001a}},	//   _برحس, rły_, _лёсу_, áðun
  { {0x32f6005c,0x04960010,0xeab3000a,0x74160015}},	//   sły_, _драў, וֹק_, _ووسا
  { {0xb4d6000b,0xc0ca0004,0x3a380079,0xa6db001a}},	//   सदी_, шуле_, herp_, _erðu
  { {0x487b0008,0x96260024,0xb4c8000b,0x6306002b}},	//   יטקס, paņā, ैदी_, _ذوال
  { {0x35af005d,0xcdda0001,0x60da0064,0xf8da005d}},	//   _जुड़, шњи_, _tutm, भदाय
  { {0xc05a0036,0x3fe6006b,0x8637004f,0x70560058}},	//   _віл_, _джев, חריב_, _ونطا
  { {0x2c620264,0x29184eec,0x0000006a,0x0000006a}},	//   _kódy_, dura_,   ,
  { {0x8ae40036,0xa09b000a,0xa2bf000b,0x6e4601f3}},	//   дісл, _דיאט, _लीड्, _медз
  { {0x2911002a,0x29031de9,0x291801c2,0x2c620247}},	//   trza_, tsja_, fura_, _módy_
  { {0x8178000a,0x29050fab,0x094800eb,0x29185364}},	//   זְּק, éla_, очти_, gura_
  { {0x29030050,0xda17000b,0x7c2d002a,0xa6db001a}},	//   rsja_, _ताकत_, _ubar, _orðt
  { {0xbca40015,0x2bc7000b,0xc7cb056d,0x0000006a}},	// [cd50] _تميي, रेशा, рыве_,
  { {0x3e7b038d,0x29180035,0x78b60007,0x454b007a}},	//   _tête_, bura_, alyv, ичем_
  { {0xc4f80029,0xe4a75365,0xc50b002b,0x44200033}},	//   قعنا_, ордо, شتال_, мi_
  { {0xe7870001,0x787800dc,0xf992000a,0xb8590058}},	//   _дуго, _hívn, _טרי_, _الحص_
  { {0xa85a0008,0x185a000a,0x93940015,0x91e52374}},	//   _הדרכ, _הכרע, وجها, поле
  { {0x42d4005e,0x7288005e,0x442d02f2,0xd7a70065}},	//   міщу, обіг_, _wbe_, _कुएच
  { {0xd24e0015,0xd4370015,0x8234002b,0x790b004f}},	//   طني_, _وعرب, ظرها, ׁלַ֤
  { {0xa99c0008,0x60c22416,0x499c0008,0xd12e0115}},	//   יבור, _chom, ישוב, امي_
  { {0x57b9000b,0x29185366,0x60c20125,0x06ee000b}},	//   _आरोह, zura_, _dhom, _चढ़ाव_
  { {0x291800d9,0x1e82017d,0xc332004c,0x25d5000a}},	//   yura_, ельм, _אומ_, ּוֹן_
  { {0x3eb90048,0x3e720026,0xc692000a,0x8c460d4b}},	//   ēst_, _mâth_, תאי_, пене
  { {0x22450064,0xc1ba0008,0x91ba000a,0x78ad008c}},	//   _halk_, _המעש, _המעי, joav
  { {0xf092013a,0xeb9703fc,0x20c10125,0x60c919cf}},	//   _אנא_, зия_, róid_, mmem
  { {0x60c90064,0xef19002a,0x29185367,0xaea80058}},	//   lmem, muż_, tura_, _وطول_
  { {0x6d5c0005,0x0dcb0036,0xfaa30c1d,0xceb2000a}},	//   ärat, _туди_, харо, _ריו_
  { {0x83fd0014,0x47d60029,0x9cd60008,0x60c92459}},	//   _előz, سيطر, _צופה_, nmem
  { {0x27f20176,0x8c1b0008,0x60160064,0x186729ca}},	// [cd60] rbyn_, _הופי, lümü, чати_
  { {0xa6db002e,0xd7070033,0x29184662,0xbdf5004f}},	//   _arðs, януе_, pura_, לֶ֣ה_
  { {0x60160064,0x78b6002c,0x89db01d8,0x60c91bcb}},	//   nümü, plyv, _לחיי, kmem
  { {0x60c93f09,0xd4090015,0x7eb40144,0xaac0000b}},	//   jmem, قتهم_, ràpi, _शीतक
  { {0x44200024,0x22450150,0x60c9007c,0x6d46003d}},	//   ļi_, _balk_, dmem, ākai
  { {0x912a0029,0x63b6002a,0x60c90fc1,0x2508002b}},	//   مسبق_, żyno, emem, _ورزی_
  { {0x2245020a,0x21670001,0x78713d80,0x867b000a}},	//   _dalk_, зији_, _såvi, _פרלו
  { {0x859b0008,0x78710293,0x8856000a,0x459b000a}},	//   _השלו, _påvi, לֹ֥א_, _הסלע
  { {0x71fa002b,0x64a3302b,0x0000006a,0x0000006a}},	//   _هراس_, _чата,   ,
  { {0xd37b000a,0x4d98005e,0x5d980033,0x60c200da}},	//   _הרמט, жкою_, жкоў_, _whom
  { {0x70f6003b,0x60c204dd,0x290c0247,0x2ba5000b}},	//   _رسائ, _thom, ádal_, _गुजा
  { {0xf3f90011,0x515b000f,0xa177000a,0x8597004c}},	//   _poţi_, _לכבו, _מעבד_, לדיג_
  { {0x76800064,0x4ae70010,0x7d0200dc,0xe0850067}},	//   _köyd, яўна, _bírá, _تجلي
  { {0x6d5c0020,0x60160061,0x539b000a,0x9961003d}},	//   äras, bümü, מיכו, rīža_
  { {0x39a40b1e,0x2dd70015,0xda700015,0xdebb000a}},	//   ештв, _عبوة_, دُّ_, _המגל
  { {0x7680022d,0xf3f90011,0x6e3a00dc,0x27260026}},	//   _löyd, _toţi_, letb, fôn_
  { {0x27260092,0x97730010,0x7af00057,0x7d1a5368}},	// [cd70] gôn_, лiся_, čitý, luts
  { {0xfbd0003b,0xf7700196,0x6e3a00dc,0x2f5b0008}},	//   _حتى_, داف_, netb, זדמנ
  { {0x94750086,0x7d1a5369,0xe5080058,0x3888007f}},	//   وگرا, nuts, كيلو_, eşru_
  { {0xb901014e,0xe3b00086,0x320c01f9,0x0000006a}},	//   दद_, گرم_, _addy_,
  { {0xceb80007,0x22450020,0x60160061,0xe4540033}},	//   klę_, _palk_, zümü, экцы
  { {0x60160064,0xe3b0002b,0x7d1a536a,0x67480030}},	//   yümü, درم_, kuts, űrjü
  { {0x1a9c0053,0xa1560001,0x61420457,0xc619000b}},	//   זיגע, дају_, веща, दलीय_
  { {0x443908e0,0xb97c0008,0xf8bf000b,0x7d1a007c}},	//   _ús_, מנוי, ्षिय, duts
  { {0x27fd005c,0xe4c40080,0x60c9536b,0x7d1a536c}},	//   ówny_, _чёрн, rmem, euts
  { {0x3e890191,0xfe710029,0x9db90010,0x22950029}},	//   ійно_, ئدة_, жыму_, _غلاس
  { {0xa2aa014e,0x7d1a0005,0x98bf005d,0xe1350010}},	//   टवर्, guts, ्षाए, _інды
  { {0xa0c40029,0x60160064,0xa134002b,0xed56005e}},	//   _كيلو, rümü, _سرمش, фою_
  { {0x2bba0015,0x3af60449,0x6d5c0c9e,0xceb8002a}},	//   تادة_, ьянс, ärar, blę_
  { {0xaec40036,0x201f0251,0x5ea50015,0xf9920015}},	//   _збіл, lgui_, _تمتل, نبأ_
  { {0x2d940063,0x8288000a,0xddd3002a,0x7aed536d}},	//   _пръс, פְשֶ, łałe, _etat
  { {0x201f3ed2,0xaf57000a,0xa3bf000b,0x78780030}},	//   ngui_, ּׁ֑ה_, ीधा_, _vívo
  { {0x2be3000b,0x2d85536e,0x27260016,0x86460033}},	// [cd80] कुओं_, lzle_, uôn_, мнаж
  { {0x78a9018c,0x4eca0053,0xff47002b,0x0000006a}},	//   čeva, ַזײַ, _یخ_,
  { {0x29050014,0x186a057e,0x4a5b000a,0xd48f067a}},	//   álat_, _дани_, _ודיו, вр_
  { {0xf4870086,0x6e3a00dc,0x60dc0077,0xe3ba0fd2}},	//   وانی, zetb, _érmi, обе_
  { {0x63be005c,0x883b000a,0x93570004,0x6d4300aa}},	//   ępno, _ותכו, дрју_, _lsna
  { {0x463a0015,0xdb250030,0x6d43536f,0x0000006a}},	//   _بأحد_, ését, _osna,
  { {0x28c3005d,0x12a90029,0x6909000a,0x61470030}},	//   _वीडि, أدنى_, ִּקְ, vélá
  { {0x66c90007,0x05570067,0xcf9a0004,0xd1390033}},	//   _užkr, _تلفظ_, жјо_, яхі_
  { {0x42260054,0xceb8002a,0x1f030015,0xf8b3000a}},	//   _одав, tlę_, نِيف, כשה_
  { {0x7d1a0020,0x44240092,0x01360015,0x7c241728}},	//   tuts, _hcm_, _يعاد, _acir
  { {0xb80e014e,0x98be0046,0x26d85370,0x7d1a0147}},	//   िणाम_, ítě_, _miro_, uuts
  { {0xdefa0010,0x6e3a00dc,0x7d1a0971,0xdd970033}},	//   _дык_, setb, ruts, ьшы_
  { {0xc0a90002,0x6d430064,0xdf760087,0x2ef30033}},	//   _عامل_, _esna, _تداب, _азір
  { {0x20044a0f,0xfe6f0015,0x7d1a3f6e,0x9f3300ce}},	//   lami_, _ندى_, puts, _реші
  { {0x5d830029,0xdcf70015,0x99830091,0xb9250015}},	//   _للول, _قريش_, vejų_, عفري
  { {0xd5f40023,0x030e005d,0x787800dc,0x67d50054}},	//   _đán, _सिंह_, _hívj, еобу
  { {0x7aed003f,0xabfc000a,0x4bfc000a,0xfe780091}},	// [cd90] _utat, _והחר, _ולחס, okį_
  { {0xfe780007,0x20040049,0xaac70015,0x29050125}},	//   nkį_, hami_, _تتبن, álas_
  { {0xd3700086,0xe4e405d1,0x69c10061,0x58d50923}},	//   یهٔ_, вічн, üled, _поот
  { {0x26d8003d,0x7c3d5371,0x20045372,0x44245373}},	//   _eiro_, nesr, jami_, _ccm_
  { {0x20045374,0xf8b200a3,0x9732002b,0x2d855375}},	//   dami_, _תשכ_, _مکلا, zzle_
  { {0xbb78000a,0x28bf000b,0x63850003,0x659500d2}},	//   ועדו_, ्षवि, _aîné, _загу
  { {0x69fc0008,0xf2040036,0x66050509,0xdb0a001a}},	//   חלוק, тячо, mahk, ðnúm
  { {0x40940802,0x60090185,0x6605013c,0xfe780091}},	//   крыт, чним_, lahk, ekį_
  { {0xd4260064,0x64a4000d,0x82f80015,0x443d04a9}},	//   ıştı_, _раѓа, _يركز_, mew_
  { {0x8d65004a,0x443d5376,0x4d65027c,0x66055377}},	//   евое, lew_, еков, nahk
  { {0x506703ad,0x21580015,0x2fd9002b,0x6d46002a}},	//   _отда, _يجمع_, _فواد_, łkan
  { {0x90450067,0x20045378,0x443d1061,0x20c1016e}},	//   _سنته, cami_, new_, bóia_
  { {0xa3e4000b,0x99830030,0x2cbe003d,0x6605088a}},	//   पुट_, dejű_, ētd_, kahk
  { {0xddc304f9,0x60d90034,0x443d14ea,0xada501c5}},	//   _conţ, _hiwm, hew_, _палл
  { {0x19b90191,0x66050375,0x6d435379,0xf1b2004c}},	//   дуть_, dahk, _usna, ָסן_
  { {0xdb0f00dc,0x46ea0bb9,0x06ea0054,0x6d410034}},	//   őjár, здан_, змак_, mwla
  { {0x2905002e,0xfd650092,0x35fa0015,0xe0d2004c}},	// [cda0] álar_, _nhuậ, كراد_, רײן_
  { {0x98c00064,0x2004429c,0x0000006a,0x0000006a}},	//   ırır_, zami_,   ,
  { {0xc5d50010,0xf9fb000a,0x4aa9002b,0x26d8008c}},	//   віць, _מהימ, _تايپ_, _viro_
  { {0x73e6008f,0x26d80034,0xc4860174,0x27e91b6f}},	//   ходз, _wiro_, элек, ccan_
  { {0xfe780007,0x28bf000b,0x25860046,0x20041361}},	//   ykį_, ्षरि, _bílé_, vami_
  { {0xfe670086,0x2004005c,0xf9070086,0x6234000d}},	//   _صد_, wami_, _تأیی, теку
  { {0xa93a004c,0xd12f0033,0x46a30033,0x25be0030}},	//   לײַי, ых_, _сарв, _átl_
  { {0x6449002f,0xf9930008,0xbf340063,0xb3e90015}},	//   _gaei, טרו_, внищ, _يعقل_
  { {0x03a313ab,0x2004537a,0x8fa30054,0x2ef4006b}},	//   _бито, rami_, лаће, ъзпр
  { {0x27e902c1,0x2004537b,0xaf330021,0x6283537c}},	//   zcan_, sami_, اريت, chno
  { {0x6d410026,0x867b0008,0x2004537d,0xfe780091}},	//   gwla, פרטו, pami_, rkį_
  { {0xdee6085d,0x78780046,0x317b000a,0x6ff60015}},	//   _зоди, _dívk, _מאבד, _أساط
  { {0x9f4909f0,0xcfaa00c3,0x5f73006e,0x5c740a66}},	//   _það_, _عاصم_, _ماور, улят
  { {0x787800dc,0x443d005c,0x7bc4002a,0xceb90046}},	//   _hívh, zew_, _dziu, tuře_
  { {0x38c7085d,0x7c3d0030,0x19580174,0x98c707f7}},	//   ещав, pesr, нары_, есал
  { {0x5dbb0008,0x78a90085,0xed57004f,0x0000006a}},	//   _מזוה, čevo, _טבור_,
  { {0x291814ce,0x2bd0000b,0x2bc7000b,0x69c10061}},	// [cdb0] arra_, सेदा, रेखा, üleb
  { {0xdb9c0008,0x06b70086,0xfc3f0125,0x645b0079}},	//   _מסחר, رناک_, leí_, _snui
  { {0xd0060086,0xddc3002c,0x66050509,0xd919000a}},	//   _پل_, _konš, rahk, _קוֹל
  { {0x66050509,0x8464006b,0x68e1001a,0x02c9000b}},	//   sahk, лъче, íldu, िग्न
  { {0x62830176,0x387e0152,0x443d0673,0xfa6b000a}},	//   thno, être_, rew_, ּכֶּ
  { {0x672d0024,0x20c10125,0x60d90034,0x3e720003}},	//   mtaj, góin_, _siwm, _mâts_
  { {0x62830046,0x672d537e,0x0000006a,0x0000006a}},	//   rhno, ltaj,   ,
  { {0xfd650023,0xd9de000b,0x895c000a,0x645b0045}},	//   _thuậ, _मल्ट, לדות, _unui
  { {0x290a0030,0x672d537f,0xfc3f0069,0x0000006a}},	//   zsba_, ntaj, deí_,
  { {0x02dd000b,0x672d5380,0x63bb02f2,0x6f092ee9}},	//   मदीन, itaj, _iyun, rsec
  { {0xf6520008,0x672d0356,0x32075381,0x6da51440}},	//   בצי_, htaj, many_, тина
  { {0x3207005c,0x672d0024,0x1ae60146,0x6abc000b}},	//   lany_, ktaj, комм, ोग्र
  { {0xc4d200b2,0xac930033,0xe0d00021,0xd36f005e}},	//   יגט_, раўш, _ازل_, ичi_
  { {0x3207005c,0xfc470030,0xdfd40033,0x3869010d}},	//   nany_, áírt_, _сочы, ejar_
  { {0x9d4510a0,0x9915005e,0x290c5382,0x0000006a}},	//   _рейд, льті, éda_,
  { {0x63bb0064,0x63b6005c,0xad1a0008,0xbb860029}},	//   _oyun, żyni, _חוקר, _للبي
  { {0xb6070023,0xb8e9005d,0x47d3002b,0x37e30054}},	// [cdc0] _thờ, _ली_, ليفر, роуг
  { {0x386900d9,0xb2dd0033,0x69c10061,0x32070bba}},	//   ajar_, _унiя, ülec, jany_
  { {0x3207005c,0x7ae43de3,0x63bb5383,0xc7a9000a}},	//   dany_, _huit, _ayun, קב_
  { {0x7413003b,0x7ae45384,0x92a6005c,0x62810fb7}},	//   لوما, _kuit, zełą, _allo
  { {0x32073911,0xfe210065,0x0000006a,0x0000006a}},	//   fany_, _मांस_,   ,
  { {0xc7b3013a,0x7ae45385,0x32075386,0x46a60033}},	//   _כבר_, _muit, gany_, _рагв
  { {0x4a9b00b2,0x1a9b0053,0xb7e6005d,0x20c1002d}},	//   ויסג, ויסע, _कलाम_, róin_
  { {0x62810467,0xd0100029,0x4422003c,0x50b8002b}},	//   _ello, حلة_, _øk_, رگاد_
  { {0xa2e60191,0xc2464dd9,0x7ae40003,0x32075387}},	//   _розд, _инак, _nuit, bany_
  { {0xb06100f2,0x7878001c,0xf3c90015,0x6d46002a}},	//   _ääne, _dívi, _سبقه_, łkam
  { {0xc6930008,0x3869002e,0x7e7a0f55,0xfe6f0015}},	//   שאת_, yjar_, rktp, تدي_
  { {0x4f660029,0x672d0bba,0x2bcb0054,0x7ae45388}},	//   _لاتف, ytaj, дуго_, _buit
  { {0xce340086,0x93fb000a,0x6298008c,0x0f13005e}},	//   _موشک, ולכי, oivo, _вмію
  { {0x7ae45389,0x20c10125,0x6298538a,0x0000006a}},	//   _duit, hóil_, nivo,
  { {0xfce30124,0x38690251,0x99d40029,0xd7e7042b}},	//   _којо, tjar_, لتفا, візо
  { {0x672d022d,0x2db70008,0x3207005c,0xf8bf000b}},	//   ttaj, _שלהן_, zany_, ्षेप
  { {0x80da005d,0x38693029,0x7ae4164a,0x62981d65}},	// [cdd0] _पूछे, rjar_, _guit, kivo
  { {0x629801a3,0x2486006f,0x672d538b,0x7d1a19dc}},	//   jivo, ehom_, rtaj, orts
  { {0x8467006b,0xdc430046,0x320701c0,0x672d538c}},	//   къде, _léčb, vany_, staj
  { {0x32070050,0xa8790053,0x93e90015,0x9879004c}},	//   wany_, _נאָר, رفتك_, _נאָט
  { {0x86250086,0x87040033,0x7d1a0012,0xd3d800c3}},	//   _مکال, _вясе, hrts, نبها_
  { {0xb224005e,0x6b7c004f,0xf2c50058,0x6298538d}},	//   иміл, ורדנ, دْتُ, givo
  { {0x99980011,0x3a38000a,0x01350015,0x3207538e}},	//   merţ_, דרום_, اعتد, rany_
  { {0x3207005c,0x63050015,0x64c50015,0xddda003d}},	//   sany_, _مورل, _إيرل, aktū
  { {0x7d1a4124,0x3207538f,0x62985390,0xbf65009a}},	//   erts, pany_, bivo, ادعو
  { {0x225b0015,0xf772000a,0x7ae44061,0x8234002b}},	//   _تجرب_, צקי_, _ruit, _نرما
  { {0x7ae4174c,0x20c10030,0x51841377,0x9596000a}},	//   _suit, lóim_, _куца, ָ֛יו_
  { {0x8cb5005e,0x7db40033,0xdb160030,0x7ae45391}},	//   исяч, рсьц, őbír, _puit
  { {0xbf670029,0xff280015,0x7ae41915,0x7d1a2349}},	//   _جداو, _لكني_, _quit, arts
  { {0xbf9a00b2,0x8f9a0135,0x1e84022a,0x7ae40144}},	//   _אינש, _איני, _клім, _vuit
  { {0x63be0050,0x6e3400dc,0x485a0033,0xb606013f}},	//   ępni, égbő, нраў_, ntáž
  { {0x38cb0086,0x62980263,0x7ae4055e,0x4d76000a}},	//   فاقی_, zivo, _tuit, _תתקל_
  { {0x9b460806,0x47c61411,0x0000006a,0x0000006a}},	// [cde0] _صندو, убав,   ,
  { {0x4a460bb9,0x064a0015,0xb60604b2,0x7c260013}},	//   _снов, علاً_, ktáž, lgkr
  { {0xd6cf0029,0x29560063,0x24865392,0x96b90db7}},	//   أقل_, _съпр, thom_, туту_
  { {0xa2e60010,0xb386004a,0x2db6004c,0x448a0033}},	//   годд, ллел, אלען_, эбен_
  { {0xe29a292e,0x62985393,0x24860183,0xdc89004f}},	//   над_, tivo, rhom_, כְסָ
  { {0x6f1b00b8,0xf7730008,0x21d8002b,0xa2d3006e}},	//   druc, _הקש_, نژاد_, مينت
  { {0x78a4007c,0xe424002b,0x6f1b002a,0x62985394}},	//   oniv, _نکشي, eruc, rivo
  { {0x0edf000b,0xfe21000b,0x62985395,0x78a448d9}},	//   नदंड, _माउस_, sivo, nniv
  { {0x7e2a0484,0xc49b000a,0x64420125,0x764e5396}},	//   ніна_, _נשמת, meoi, _kaby
  { {0x2f370029,0x99980091,0x320500aa,0xc0e60238}},	//   اثية_, ndrų_, _gely_, _божк
  { {0x5275000d,0x2d810020,0xa1130015,0x127b004c}},	//   _туту, _ühel_, _هولت, _ראבע
  { {0x6442002d,0x44265397,0x66cb00dc,0x6f1b5398}},	//   neoi, ngo_, müke, bruc
  { {0x68e500f2,0x6f1b1232,0x409b004c,0x78a45399}},	//   _suhd, cruc, _אבאס, dniv
  { {0x6442002d,0x68e5008c,0xd1260067,0x753c002a}},	//   heoi, _puhd, يم_, _oprz
  { {0x82770053,0x66cb0030,0xd9181100,0x0000006a}},	//   נעלע_, nüke, льт_,
  { {0x5c070063,0x57f5539a,0x6f02002a,0x5dcb000a}},	//   _сяка, рпат, _kwoc, _אֶחְ
  { {0x6d580a00,0x6442539b,0x57a70239,0x764e1419}},	// [cdf0] _hrva, deoi, ушва, _baby
  { {0x44263925,0xe4e70036,0x78a4014b,0x7b000030}},	//   ego_, гідн, aniv, űzté
  { {0x290c1724,0x320500da,0x98480061,0x66cb0030}},	//   ádat_, _rely_, aşı_, jüke
  { {0x24190080,0x6f02005c,0x3cfb0053,0xd5b84adb}},	//   тоды_, _owoc, גלאנ, усу_
  { {0x76800064,0x872b0033,0x4429003d,0x6cac004f}},	//   _köyl, _яўна_, ļa_, עֹבְ
  { {0x4429005c,0x272f0064,0x5b7c004c,0x6f1b0079}},	//   ża_, mün_, ערגא, vruc
  { {0xfa780008,0x272f0061,0x66cb0030,0x2019059d}},	//   רעות_, lün_, güke, ósio_
  { {0x69c8005c,0x764e005c,0x6442002d,0x32050034}},	//   żdeg, _zaby, ceoi, _wely_
  { {0x6d580005,0xf77200b2,0x272f01e2,0x1e850001}},	//   _arva, ַקט_, nün_, илим
  { {0x2ca9007c,0x8eb2002b,0x78780030,0x60cb003d}},	//   _ajad_, يميش, _hívt, _šomē
  { {0x7e540010,0x26c1016e,0xddc5005e,0x0000006a}},	//   стыц, ilho_, рбни,
  { {0x6f1b00b8,0x272f0061,0x673d539c,0x66cb0030}},	//   pruc, kün_, _opsj, nükb
  { {0x768001e2,0x69c10064,0x4b230063,0x6d580150}},	//   _böyl, ülen, омяв, _erva
  { {0x8f1a000a,0x4426539d,0x66070046,0x272f0061}},	//   _יונת, zgo_, _nejk, dün_
  { {0x26c1002c,0xc896049d,0xfaa307be,0xd94604bc}},	//   dlho_, арањ, царо, шеви
  { {0x7d56013a,0xfc3f006f,0xdbdf001a,0x7d1c0077}},	//   _כיצד_, rníc_, _tíðk, árse
  { {0x753c0050,0x272f0064,0x6cd30029,0xa7660010}},	// [ce00] _sprz, gün_, _بقيا, шкад
  { {0x984801e2,0x290c002d,0xb5da0015,0x66cb0061}},	//   rşı_, ádas_, نباء_, yüke
  { {0x6442002f,0x92020024,0x754601b7,0x142601b7}},	//   teoi, šāka, рнез, иджм
  { {0x44260007,0x22570086,0x334a0015,0x58d30004}},	//   ugo_, یلند_, َلاَ_, _моќт
  { {0xf2e80086,0x6442002d,0x4426539e,0x23270054}},	//   اکره_, reoi, rgo_, иоци_
  { {0x8b570053,0xc2b60001,0x64420c1b,0x4426539f}},	//   יינס_, шљењ, seoi, sgo_
  { {0x753c005c,0x5578000a,0x7d150030,0xa507004a}},	//   _uprz, _גְּד, ázsl, _веса_
  { {0xbf660029,0xe0cf0029,0x9f4f0077,0x64a64217}},	//   لدخو, وزي_, _negó_, _таба
  { {0x08770053,0x66cb0030,0x30930015,0x4fc60174}},	//   שעפט_, süke, تشوس, шска
  { {0xd7370008,0x6d5801a3,0x78a906c0,0x0737004f}},	//   סטית_, _prva, čevi, סאים_
  { {0x272f0064,0xfc3f0077,0xd657000a,0x7d030034}},	//   zün_, enía_, ביית_, _cwns
  { {0x768001e2,0xb17b00b2,0xc19b0008,0xa17b0053}},	//   _söyl, _שטאר, _בשבי, _שטאט
  { {0xdef40010,0x9fe50021,0xad66002b,0x2f180280}},	//   _уплы, _اسمه, _چابه, _соль_
  { {0x6d580264,0x8d76002b,0x3fcb002b,0x0f7b000a}},	//   _trva, _ناعا, _شدنی_, _ברדל
  { {0xdd930010,0x7d030026,0x6d5803a4,0xcdf7000a}},	//   _машы, _gwns, _urva, _דמוי_
  { {0x272f01e2,0x4ddb000a,0xad1b000a,0x718b000a}},	//   tün_, _בחוו, _סוחר, דְמַ
  { {0x96eb0036,0x35e721e9,0xa615005e,0xb6c50058}},	// [ce10] тьба_, ацев, ймач, مْرً
  { {0x272f0064,0xbebd0f28,0x26c1016e,0x8f8b000a}},	//   rün_, ltūr, ulho_, כְבֵ
  { {0x19ab000d,0xceb3000a,0x1bb8002b,0x272f0061}},	//   _штип_, קיע_, _مایع_, sün_
  { {0xe4a40036,0x5dd90053,0xbebd2233,0x63050015}},	//   орчо, אַנס, ntūr, موصل
  { {0xb4c7005d,0x2911002a,0x66cb0030,0x7c2d01f9}},	//   _उठी_, lsza_, rükb, _mcar
  { {0xa229223b,0xc51b0015,0x06850015,0x2127002b}},	//   ужка_, _لغرض_, _السُ, ليتی_
  { {0xbebd1cdb,0x51550010,0x54670054,0x82340040}},	//   ktūr, стлу, _књаз, ترنا
  { {0x3f8d08e0,0xfbdf001c,0x40490001,0xf8c7000b}},	//   tzeu_, ndês_, упио_, लतिय
  { {0x7e7500dc,0x442d3562,0x7f160015,0x249d0034}},	//   özpo, _ice_, مييز_, miwm_
  { {0x628a00b8,0x42740029,0x52740029,0xe1f000e6}},	//   chfo, _والآ, _والز, _قسم_
  { {0xc2120008,0x7af6002e,0x2911005c,0xfc460264}},	//   _זהב_, _styt, jsza_, šíme_
  { {0x853a0008,0x249d0026,0xcb6a0608,0xe3a70015}},	//   נגרי, niwm_, гаме_, كر_
  { {0x929d005c,0x7645008c,0x1c4301f3,0x29110535}},	//   _zwła, kehy, чням, esza_
  { {0xeef6000a,0xff56004c,0x5159000a,0xbb430004}},	//   _המסר_, _לבנך_, ְכּו, џерк
  { {0x39790036,0xbcf50029,0x7e7c00b8,0x7e6300cb}},	//   астю_, _استغ, örpe, _innp
  { {0xad1a000a,0x7c2d0125,0x63ad002a,0x0dc8004a}},	//   _עופר, _gcar, żany, _тучи_
  { {0x249d0026,0x2911002a,0xa686144a,0xc052004f}},	// [ce20] diwm_, asza_, блад, הזן_
  { {0x49ba0021,0x442d53a0,0x598620b9,0x29110535}},	//   _ماجد_, _ace_, _глоб, bsza_
  { {0xa3da005d,0x64a60036,0x442d0ada,0xf52500ce}},	//   डेन_, бажа, _bce_, жфін
  { {0x75d30029,0xa50753a1,0xc7e6000a,0x442d0144}},	//   سينا, сеца_, _לוֹ֙_, _cce_
  { {0x43730054,0xb8de0157,0x88bb004f,0xebd6004f}},	//   зујт, ेत_, _תזכי, צֵ֣י_
  { {0x2aad006f,0x7680008c,0x92581b5d,0xcb37004f}},	//   oľba_, _möyk, ракт_, מאני_
  { {0xd1300015,0x8233006e,0xc872004f,0x41b4009a}},	//   ذمة_, سروا, ִן֙_, غمبر
  { {0x2348002b,0x4fc60033,0x80a40015,0x27f20e42}},	//   _پسری_, йспа, تمعن, ncyn_
  { {0x3f820089,0x987b004c,0x7413012c,0x657e2135}},	//   áku_, טאקט, _رولا, lyph
  { {0x22f7000a,0x7c2d53a2,0x2911002a,0xfe6f0015}},	//   _לזמן_, _scar, ysza_, ّدَ_
  { {0xb6bb0053,0x66bb000a,0x3f8253a3,0xe6bb000a}},	//   רציי, רמיה, šku_, רציש
  { {0x69c10064,0xdfd20067,0x999a0073,0x0000006a}},	//   ülem, _فيض_, _lapų_,
  { {0xd00b000a,0x0057000a,0x2911002a,0xdfd00015}},	//   _גּוֹ, _לשאת_, wsza_, _غيت_
  { {0xbebd0024,0x0000006a,0x0000006a,0x0000006a}},	//   stūr,   ,   ,
  { {0xce370008,0xc27b000a,0x4118000a,0x127b004c}},	//   _האות_, נרלי, יֵּא, נאלע
  { {0x2911005c,0xb4c7000b,0x98770061,0xd87700c3}},	//   rsza_, _उठे_, tçı_, حاسب
  { {0x29110014,0xe73000e6,0xe7190015,0xe69953a4}},	// [ce30] ssza_, فصل_, شيات_, аваш_
  { {0xeef70008,0xf77000e5,0x2911002a,0xa615005e}},	//   צמבר_, راق_, psza_, імеч
  { {0x2cfb004c,0x7afd53a5,0x59dd0065,0x442d53a6}},	//   ָלדא, lpst, _मणिर, _pce_
  { {0xccf300b2,0x799a000a,0x628853a7,0x7afd53a8}},	//   לכע_, _כשתס, _aldo, opst
  { {0xa3d3005d,0xe3b30029,0x9cd8000a,0x8c1c000a}},	//   हें_, أرض_, צודה_, רודי
  { {0xd9fb005d,0x82370029,0x9693009a,0x249d0416}},	//   ्रित_, إرشا, _عیاش, siwm_
  { {0xd12e0029,0xb1450036,0xdcf5003d,0x8557002b}},	//   نمو_, інил, ēcīg, _دیار_
  { {0xef191328,0x2eb3000b,0xe8e00016,0x628853a9}},	//   ами_, ुत्त, _thụt_, _eldo
  { {0xa4d40036,0x70760015,0x02450015,0x53990033}},	//   _хоті, تميز_, _وَرَ, _твая_
  { {0x273b0011,0xcee80021,0xee360449,0xae79006b}},	//   mână_, حرين_, онь_, рсих_
  { {0xd01906e4,0x7dc50086,0x8c4610a1,0x8d750067}},	//   _نقاش_, تقدن, оене, زادا
  { {0x2d8b0050,0x8c960036,0x7d1c00dc,0x22470359}},	//   ące_, ірні, ársa, lenk_
  { {0x25c6005d,0x2d8300bd,0xba56006b,0x10d80015}},	//   _वर्ण, šje_, отвъ, _ابلغ_
  { {0x09fa0029,0xefb30086,0xf8bf0264,0xbe650015}},	//   شفرة_, _ویژگ, _aké_, _ذهبي
  { {0x38c80074,0xce34002b,0xb8660067,0x7cc60015}},	//   ماری_, _رويک, يارو, _وزعم
  { {0x929d002a,0x3e7b0003,0x3eb800bc,0xa3da000b}},	//   _owło, _vêtu_, črte_, डेड_
  { {0xe1ff0092,0x62830234,0xcaf60015,0x060a1377}},	// [ce40] _đón_, kkno, _بسبب, инак_
  { {0xd6260029,0xfe65002b,0xe5a60054,0x657e279f}},	//   تعري, رگ_, оизи, typh
  { {0x44f60086,0x45460021,0x628300aa,0xa96a029f}},	//   زساز, تناق, dkno, _тина_
  { {0x67df0091,0x6abc0b95,0x83c6033d,0x64a303ca}},	//   _sąjū, lorf, обеж, маха
  { {0x926a04bb,0x9cd7004f,0x0000006a,0x0000006a}},	//   ирка_, קונה_,   ,
  { {0x273453aa,0xdce90089,0x62830177,0xda0a000b}},	//   män_, íněn, gkno, वरित_
  { {0xe57a0001,0x273400f2,0x67364444,0x91e300af}},	//   _тзв_, län_, ltyj, моље
  { {0xb97b00a3,0xc05a005e,0x50d30015,0x6abc0a79}},	//   ינצי, рік_, وزير, horf
  { {0x03a30036,0x228b003c,0x987b0053,0xeeaa0142}},	//   _жито, _søke_, שאפט, иток_
  { {0x67360007,0x079b0053,0x69c103ff,0x4223007e}},	//   ityj, יספל, ülek, _одув
  { {0x2734022d,0x673600f2,0xc5f3039e,0x929d002a}},	//   hän_, htyj, ודת_, _zwło
  { {0x6f660015,0x351b000a,0xdee6023e,0x2734008c}},	//   _وهام, סוכנ, _доди, kän_
  { {0x2734022d,0xf4130008,0x320c002c,0x6fb60029}},	//   jän_, ופר_, _kedy_, _بمشا
  { {0x2734022d,0xfc3f0089,0x99730046,0x6abc0034}},	//   dän_, mním_, _věže_, gorf
  { {0xfc3f0089,0x50f8000a,0x0000006a,0x0000006a}},	//   lním_, מִּד,   ,
  { {0x5b152354,0x7afd39d5,0xc0d4004f,0x3aef007f}},	//   _емит, ppst, לֵּה_, _tüp_
  { {0xfc3f0089,0x8c440054,0x0000006a,0x0000006a}},	// [ce50] nním_, _цење,   ,
  { {0x1efb0053,0x07080029,0x16380015,0x20c10030}},	//   ילמע, تيكي_, قسمة_, lóit_
  { {0x7aed002f,0x39830086,0xea000016,0xc539398c}},	//   _huat, _غیرف, _hiếu_, спех_
  { {0xe3b30086,0xf494002b,0xc355006b,0x4518002b}},	//   ورش_, وشند, зъкъ, زآمد_
  { {0xeab00086,0x13040010,0xfc3f0046,0x5398005e}},	//   _سعی_, дзім, jním_, овця_
  { {0xe1f10074,0xb7da0008,0xfc3f0089,0x877a000a}},	//   رست_, _לקרי, dním_, _האשי
  { {0x7ae5003f,0x7aed4ac7,0x91e253ab,0x320c01d7}},	//   _miht, _luat, ноше, _dedy_
  { {0x7ae50005,0xf92a0053,0x628353ac,0x22470030}},	//   _liht, צופּ, skno, senk_
  { {0x69c500f2,0x600604ab,0x443f35a6,0xe2f8005e}},	//   _lyhe, чным_, _ibu_, _меті_
  { {0x765504af,0xe1670015,0x6eed006f,0x320c0034}},	//   _jazy, _وداي, _hĺbk, _gedy_
  { {0xc692000a,0x27340012,0x69c5405d,0x6abc4124}},	//   גאי_, zän_, _nyhe, vorf
  { {0xfc3f0089,0x6abc00b8,0x673653ad,0x6ab4000b}},	//   bním_, worf, ytyj, ंक्र
  { {0x7aed02c1,0x3fc9002b,0x4b55006b,0x6d5a00cb}},	//   _cuat, _ادای_, мърт, avta
  { {0x2734022d,0x7655005c,0xddc80024,0x5efa000a}},	//   vän_, _nazy, ņoša, _הפסד
  { {0xdcf90074,0x443f005c,0x6d46005c,0x186a53a1}},	//   _ارتش_, _obu_, łkar, бави_
  { {0x6736022d,0x386602c1,0x7aed53ae,0x273404ea}},	//   ttyj, ñor_, _fuat, tän_
  { {0xa686000d,0x2c02000b,0x7655002a,0xf74353af}},	// [ce60] плад, _व्यू_, _bazy, нето
  { {0xdce20007,0xdb9b0008,0xc50a0015,0x273430de}},	//   tylė, _לספר, متصل_, rän_
  { {0x4a7b0008,0x7a7b000a,0x2734008c,0xfc3f013f}},	//   _הריב, _הריס, sän_, zním_
  { {0xd4990036,0xef19002a,0x66cb0061,0xe452006e}},	//   орі_, zyża_, lükl, عضا_
  { {0x69c00064,0x833a004a,0xf7190033,0x9a76004f}},	//   şmed, счет_, _міры_, ּתֶף_
  { {0xfc3f0089,0xbb3b0135,0x6d4353b0,0xd30c000b}},	//   vním_, מעני, _opna, _हबीब_
  { {0x67240079,0x320c006f,0x6d4f002a,0x154319cc}},	//   lrij, _vedy_, łcaj, _перм
  { {0xfc3f16f1,0x251b000a,0xc953000a,0x75d30015}},	//   tním_, _לולא, תמה_, _سيقا
  { {0x7e78018c,0x67240111,0x320c037f,0x2bde000b}},	//   _povp, nrij, _tedy_, नेमा
  { {0x660e0048,0xfc3f0089,0x877b000a,0x9757000a}},	//   _jebk, rním_, מאפי, ליפו_
  { {0x67240298,0x7aed064e,0x24860085,0xef19002a}},	//   hrij, _suat, okom_, ryża_
  { {0x7ae50005,0x672401a3,0xc0d30015,0x68e63670}},	//   _siht, krij, _كيلب, _nikd
  { {0xe451000f,0xfc3f0107,0x46be000b,0x7ae5014b}},	//   כֶם_, lník_, ्ताह, _piht
  { {0xdfa500e6,0x672453b1,0x2fc602f2,0x34a90065}},	//   _تحمي, drij, _iyog_, _कद्द
  { {0xfc3f002c,0x6e3b000a,0xbe3b000a,0x0d66006b}},	//   nník_, _התוד, _העות, _хълм
  { {0x3ebe00dc,0x67241fe1,0x99540033,0x248606f2}},	//   lott_, frij, эксц, jkom_
  { {0x47350010,0x7ae50020,0x2486002c,0xe7330029}},	// [ce70] ьнас, _tiht, dkom_, عصر_
  { {0xcb12013a,0x66cb0061,0x20c10125,0x3ebe0702}},	//   _שלי_, cükl, nóir_, nott_
  { {0x53fb0015,0x9a3a000a,0x3eac0079,0x05b9002b}},	//   مرشح_, _ותתק, indt_, زگست_
  { {0xa3f40036,0x20c1002d,0xfc3f0107,0x248600aa}},	//   епці, hóir_, dník_, gkom_
  { {0xa85a000a,0x9735002b,0x3ebe53b2,0x5fb8000b}},	//   _ודרכ, _تکزا, kott_, _उँगल
  { {0xcb140053,0x92940033,0x78ad53b3,0x60c253b4}},	//   גלס_, начц, lnav, _akom
  { {0x3ebe0014,0x20c1002d,0xc5f2000a,0x2486006f}},	//   dott_, dóir_, _ידם_, bkom_
  { {0x40940080,0x78ad4fab,0x2486122c,0x443f10ee}},	//   ерьт, nnav, ckom_, _ubu_
  { {0x66cb0064,0x78ad53b5,0x644b53b6,0x04c80058}},	//   yükl, inav, megi, _روكي_
  { {0x20c1002f,0x3ebe0c19,0x867a004c,0x64591692}},	//   góir_, gott_, ַררו, ldwi
  { {0x78ad00dd,0x442f3040,0xfc3f0b7e,0x67240085}},	//   knav, ogg_, cník_, zrij
  { {0xc0580036,0x20c111d4,0xc1ba000a,0x3eb800bc}},	//   _ніч_, róis_, _ומעש, črta_
  { {0xda660086,0xeb970404,0x6e890015,0x3ebe53b7}},	//   واسي, дия_, _ونصف_, bott_
  { {0x67243ca0,0x60c20046,0x24860816,0x60c953b8}},	//   vrij, _zkom, zkom_, llem
  { {0xb9b50063,0x66cb0064,0x66d0008c,0x24860244}},	//   естъ, rükl, jäka, ykom_
  { {0x7680022d,0x60c901e2,0x3f890024,0xd70a0010}},	//   _löyt, nlem, _ļauj_, жнае_
  { {0x59c0005d,0xc7a31a11,0xfc3f0227,0x644b0091}},	// [ce80] _एडवर, витк, zník_, degi
  { {0x2d810020,0x78ad00f2,0xd6c4002b,0xdbcf0061}},	//   _ühes_, anav, رمای, _sıçr
  { {0x60c901e2,0x644b0251,0x6459042f,0x248653b9}},	//   klem, fegi, fdwi, tkom_
  { {0x3ebe0014,0xfc3f0057,0x672453ba,0xd4090015}},	//   zott_, vník_, prij, كتهم_
  { {0x248653bb,0x82f70067,0x69c1007c,0x27f8002a}},	//   rkom_, وروز_, ülev, ągną_
  { {0x4432005c,0x248d00dc,0x248653bc,0xdb97000a}},	//   ży_, _elem_, skom_, ודנט_
  { {0x60c901e2,0x21670001,0xe297000d,0x248653bd}},	//   flem, дији_, ќај_, pkom_
  { {0x21200844,0x60db0035,0x30a30139,0xfc3f0264}},	//   čih_, gmum, крыв, rník_
  { {0x3ebe0014,0x200f002e,0x20c1002d,0xfc3f0107}},	//   tott_, _degi_, tóir_, sník_
  { {0x60c90152,0x78a4101e,0x78ad02c6,0x11d60015}},	//   alem, hiiv, znav, _قتاد
  { {0x3ebe53be,0x60c953bf,0x7d6a00ce,0x78ad064c}},	//   rott_, blem, ішов_, ynav
  { {0x10160086,0x2bd3000b,0x3ebe0030,0x20c10125}},	//   _آباد, _सरदा, sott_, sóir_
  { {0x3ebe00dc,0x78ad0844,0x7c3d001a,0x9bc40033}},	//   pott_, vnav, rfsr, вёрк
  { {0x60c053c0,0x644b002a,0x79950012,0x0000006a}},	//   lomm, zegi, tzzw,
  { {0x19580010,0x28f80080,0x442f02d2,0x7680008c}},	//   мары_, десь_, ygg_, _löys
  { {0x60c053c1,0x58d453c2,0xa157000a,0x0c780015}},	//   nomm, вост, ובלה_, _يصيب_
  { {0x0b190015,0x78ad3c5b,0x3f8453c3,0x644b53c4}},	// [ce90] _عقدة_, rnav, nymu_, vegi
  { {0x0f370008,0x60c90df3,0x78ad169b,0x20c1002d}},	//   ורמט_, zlem, snav, hóip_
  { {0x60c90064,0xab620020,0xaab80015,0x66cb007c}},	//   ylem, _üürn, _تدير_, lükk
  { {0x94750074,0x7d0d005c,0xa2a1000b,0x3f840091}},	//   رگزا, _łask, कोन्, kymu_
  { {0x13080036,0xe3ae0127,0x7680008c,0x64592932}},	//   дній_, уб_, _pöyt, rdwi
  { {0x02440015,0xd5bb006b,0x200f53c5,0x3f8453c6}},	//   ََنَ, _дсб_, _segi_, dymu_
  { {0x60c953c7,0x349514a3,0xa3d3000b,0xe5c42fff}},	//   tlem, _завр, हेज_, _асто
  { {0x45d4005f,0x249f0375,0xb9c8000a,0x60c953c8}},	//   _росс, _umum_, וּחַ_, ulem
  { {0x60c904db,0x200f0144,0x60db068c,0xa2b50054}},	//   rlem, _vegi_, rmum, _збач
  { {0xfe71003b,0x26c10264,0x60c953c9,0x22580015}},	//   ادة_, noho_, slem, _يجلب_
  { {0x200f0020,0x2ca03d15,0x672d007c,0x60c953ca}},	//   _tegi_, _pmid_, huaj, plem
  { {0x7f950010,0x60c00b62,0x91a80015,0xed56005e}},	//   _паех, comm, _تهمك_, хою_
  { {0xdd8e0086,0x78a40604,0x4c830010,0x26c10107}},	//   لوی_, viiv, уляв, koho_
  { {0x3f7a0053,0x69c8002a,0xdbd20072,0x0000006a}},	//   _מאנס, żdem, müüm,
  { {0x3ea90089,0x78a409e7,0x7cff0045,0xdca653cb}},	//   čitě_, tiiv, fârş, _паки
  { {0x8d74002b,0x3ea5007c,0xfc3f0125,0x7680008c}},	//   _جاها, lilt_, cfí_, _nöyr
  { {0xdbd20020,0x29030030,0xeab20015,0x9c0b004f}},	// [cea0] nüüm, apja_, _معد_, _מִיִ
  { {0x78bb016f,0x3ea50020,0xeb97000a,0x47d30015}},	//   čuva, nilt_, _נדיר_, ايكر
  { {0x1a9b00b2,0x69c10014,0xd6cf0029,0x3f840bba}},	//   _זייע, ület, حقل_, zymu_
  { {0x13a8002b,0x3ea553cc,0x6603007f,0x0000006a}},	//   ونای_, hilt_, ınka,
  { {0x93f30010,0x60c000f2,0x8c1b000a,0xa3da000b}},	//   упіц, vomm, פוסי, डें_
  { {0xd1300021,0x66d0008c,0x7d1c00bf,0x201a002a}},	//   لمت_, mäko, ársk, _śpi_
  { {0x889a0008,0xd5b20002,0x057a0015,0x5637004c}},	//   ּבִי, _صفر_, _عمرة_, _ראלע_
  { {0xd010003b,0x81430115,0x653b0053,0x853b000a}},	//   جلة_, اپيم, _מעלד, _מגלי
  { {0x9ed80080,0x3ea50101,0x60c053cd,0x6387003d}},	//   ммит_, filt_, romm, _cīnā
  { {0x3ea553ce,0x72060015,0x3f840034,0x66cb0030}},	//   gilt_, _أوام, rymu_, vükk
  { {0xc6930008,0x291e016f,0x06970008,0x60c03286}},	//   ראת_, štaj_, גדים_, pomm
  { {0xe1ff0092,0x66cb007c,0x458b004f,0xe58b004f}},	//   _đói_, tükk, לְכ֣, לָכָ
  { {0x9f340036,0x832a0008,0xab87042b,0x7cff0045}},	//   _релі, הוָ֖, хунк, vârş
  { {0xdfcf0021,0xfe6f0015,0xafe3004a,0x628a0eb9}},	//   _ايه_, _هدى_, _сочл, nkfo
  { {0x3cea005d,0x3e5b000a,0xdd8f02a3,0xe919005e}},	//   _घंटे_, _מדגס, _сш_, ьові_
  { {0x67d5005e,0x9b950015,0x672d53cf,0x7d1a2035}},	//   вобу, _للبت, tuaj, msts
  { {0x16be014e,0x66d000c0,0x9c08000a,0x628a00cb}},	// [ceb0] ्तूब, räkn, _אִתִ, kkfo
  { {0x69c10020,0xc13b0092,0xd371002b,0xaa47008c}},	//   üles, _cướp_, یها_, ätää_
  { {0x26c1003f,0x442002e1,0xddc31071,0x7d1a285a}},	//   roho_, лi_, _manş, nsts
  { {0xe4e405fc,0x2bde005d,0x6aa70111,0x95c40015}},	//   гічн, नेवा, lijf, ديمه
  { {0x69d84882,0x8c1c000a,0x9324002b,0x96f8006b}},	//   _úver, לואי, هرون, _пеят_
  { {0x42d4005e,0x25ac0046,0x7d1a179f,0xf6c80138}},	//   ліщу, áhlá_, ksts, _зыск_
  { {0x45d40063,0xd49b15ce,0x92680033,0x6d5d003d}},	//   _борс, _ера_, эрца_, āsak
  { {0x44f70064,0x6aa70111,0xa4d5042b,0xe1640021}},	//   _iç_, hijf, _робі, ادوي
  { {0x91f50023,0x3f8b002c,0xcf8e0086,0x7f750010}},	//   _các, ácu_, يژه_, туйц
  { {0x645b0a9a,0x3ea500da,0xc87f0012,0x2d855221}},	//   _haui, uilt_, _loß_, tyle_
  { {0xc5f201d8,0x3ea50020,0xfc3f002d,0x7d1a53d0}},	//   ידי_, rilt_, hníu_, gsts
  { {0x3ea5007c,0xfe71002b,0xe3a7002b,0xdca61440}},	//   silt_, ادک_, لر_, тами
  { {0x40e8000a,0x3ea5393e,0xa09a000a,0xdd02003d}},	//   _נַעֲ, pilt_, _קינט, ārād
  { {0xc332000a,0x66d0008c,0xbea53a8a,0x6e9200af}},	//   בוך_, väko, _шалк, _виљу
  { {0x18a60004,0x78bb0085,0x88c6002b,0x6f1b4a5b}},	//   вавм, čuvn, نترل, lsuc
  { {0x999e0030,0xab6609c3,0x3cf701ec,0x0000006a}},	//   ütő_, _авил, ēgvā_,
  { {0x44f70064,0xbc79002c,0x69c108f5,0x8a06006b}},	// [cec0] _aç_, úšťa, üler, _изпе
  { {0x6aa70079,0x99d60015,0xe6be000b,0xa50a0461}},	//   cijf, _لتجا, ्तेज, дежа_
  { {0xd826000d,0x98ad0064,0x6f1b00b8,0x66d0008c}},	//   _идни, _çoğu_, hsuc, säko
  { {0xe4750010,0x79b7000a,0x88f7000a,0x7d7a000a}},	//   лучэ, _יליד_, _שזכו_, ונעו
  { {0xe3b20087,0x645b00c7,0xddc30030,0xe29a09da}},	//   جرا_, _daui, _manő, мад_
  { {0x6603007a,0xe1ef0015,0xe1d80033,0x7d1a53d1}},	//   _впра, يسى_, ндлі_, ysts
  { {0x91f50023,0x6f1b00b8,0x99980091,0x628a53d2}},	//   _sác, esuc, merų_, rkfo
  { {0x85570008,0x60d90026,0xbf34005e,0x6f1b0012}},	//   _בשלב_, _chwm, гнищ, fsuc
  { {0x2f130010,0x765c0d25,0x30770015,0x7e2a008b}},	//   адыё, _kary, ضحية_, міна_
  { {0x66cb0020,0xd3370008,0x539b000a,0x98a3002a}},	//   tüki, _ברמה_, _חימו, mują_
  { {0xf2970008,0x765c0673,0xcec1002a,0x98a3002a}},	//   _שכבר_, _mary, djęć_, lują_
  { {0x91f50092,0xa3d6005d,0x6abd000b,0xd083004a}},	//   _tác, _हरा_, ोत्र, _выши
  { {0x7d1a00b8,0x98a3005c,0xc87f0012,0x5f730040}},	//   ssts, nują_, _roß_, _ناور
  { {0x765c0007,0xf21a000b,0xa935005e,0x69c00061}},	//   _nary, _नजफ़_, легш, ğmen
  { {0x63be005c,0x59f80036,0x69c00064,0x6aa70111}},	//   ępny, теся_, şmen, rijf
  { {0x515b0008,0x98a3005c,0x2aad016f,0x07090015}},	//   וכלו, kują_, džbe_, فيري_
  { {0xd7c90086,0xf6f50086,0xd7d50001,0x765c53d3}},	// [ced0] روطه_, ازرگ, ужањ, _bary
  { {0xba5503f1,0xe7300029,0xa5070010,0x64420152}},	//   _свој, تصف_, вядл, efoi
  { {0x765c03b7,0x9c64002b,0x2dd8004f,0xe3a5009a}},	//   _dary, _صهیو, תַּב, گشای
  { {0x6f0212df,0xa31909ef,0xb8f7000b,0x0000006a}},	//   _otoc, ежду_, ित_,
  { {0x289a000a,0x98a3002a,0x4c9c015b,0xd3b8005e}},	//   _נישא, gują_, ובאו, куші_
  { {0xfb1600b2,0xdb0e00dc,0x6d4a0134,0x6d58044c}},	//   אַקט_, ókér, _opfa, _osva
  { {0xc6920053,0xda7c0008,0x98a30007,0x6f0233e8}},	//   _פאל_, ונגר, aują_, _atoc
  { {0x30190015,0x14190015,0x66150046,0x765c0bba}},	//   رتبة_, _سيئة_, _hezk, _zary
  { {0x2127002b,0x284a004c,0x98a3002a,0xfe710015}},	//   ريکی_, געפּ, cują_, مدد_
  { {0x6f1b018b,0xb2d50029,0x2aad006f,0x291e0091}},	//   rsuc, _صياغ, oľbu_, štai_
  { {0x273d0092,0xe139005e,0x2035002b,0x3236000a}},	//   hìn_, _їзді_, _مفاس, _תטען_
  { {0x7f190036,0xe588000a,0x628153d4,0xeb9a098b}},	//   _зіку_, דָשָ, _holo, еим_
  { {0x4fa40191,0x6d5e0089,0x9f340036,0x207a004c}},	//   _київ, _špat, _вечі, _ראנא
  { {0xc33200b2,0x539a000a,0x6f7a000a,0x0d73002b}},	//   זוך_, גישו, _רְאו, _نخبگ
  { {0xd6e40036,0x98a3005c,0xdcfa0007,0x38c8002b}},	//   пiюв, zują_, tytą, ناری_
  { {0x88e600d7,0xe704002b,0xd019002a,0x62810a38}},	//   ужбе, لسطی, nań_, _lolo
  { {0x7c24002f,0x0ab60029,0xd6d20015,0x99980091}},	// [cee0] _idir, _محدد, مقر_, terų_
  { {0x55e6005e,0xd6250015,0xeed5000a,0xa3c7000b}},	//   гозб, لعمي, אֵ֣ת_, _उड़_
  { {0x765c1491,0x98a3002a,0xd019002a,0x45d603ae}},	//   _vary, wują_, kań_, уцат
  { {0xa85600d7,0x98a3002a,0x2aad006f,0x395a00c7}},	//   _стој, tują_, ržbe_, _isps_
  { {0x8c1b013a,0x64420152,0xd019005c,0x289b0053}},	//   תוני, rfoi, dań_, _טיטא
  { {0xa2260086,0x64420011,0x386053d5,0x98a3005c}},	//   ارشه, sfoi, ldir_, rują_
  { {0x628153d6,0x98a3005c,0xddc30003,0x463b004c}},	//   _dolo, sują_, _manœ, _רעלע
  { {0xf9930008,0x386053d7,0x99580227,0xd019002a}},	//   מרו_, ndir_, káže_, gań_
  { {0x628104f9,0xc32a0029,0xa3cb005d,0x1eaa0015}},	//   _folo, _سكان_, _रुप_, فادي_
  { {0xa2e62073,0x43830029,0x628153d8,0x3f89003d}},	//   _созд, _الْق, _golo, _ļaut_
  { {0x386053d9,0x6e630138,0xd0190535,0x64bc0160}},	//   kdir_, стыж, bań_, pčid
  { {0xd00f0029,0x69c00064,0x41bb000a,0x66cb0061}},	//   _فلم_, ğmel, _אצבע, lükt
  { {0x69c00064,0x7c240026,0xefd60010,0x386006ee}},	//   şmel, _ddir, _сюжэ, ddir_
  { {0x8f9b00b2,0x2eb1000b,0x1af40342,0x2f5b000a}},	//   _אידי, ीकृत, спря, _נדונ
  { {0x828b0008,0x6d580085,0x44240573,0x2e230015}},	//   תְכֶ, _usva, _odm_, _طفيف
  { {0x6947016f,0x442401d7,0x7d1c01d3,0x0000006a}},	//   jčeš, _ndm_, ársu,
  { {0x06150a61,0xa5f90054,0xf7730015,0xa6150588}},	// [cef0] идаю, везу_, حاز_, имач
  { {0x85050015,0xd5bb53da,0xb9c70015,0xd019002a}},	//   لوطن, нсе_, _متجه, zań_
  { {0xf9fa000a,0x91f50016,0x66cb0061,0xd5670033}},	//   _בהתמ, _bán, dükt, ытап
  { {0xa8790053,0x297a0135,0xad1b000a,0xe4cb006e}},	//   _סאָר, _סטרא, תואר, ربان_
  { {0x4c9c000a,0xbbd3000b,0x66150061,0x6281391e}},	//   עבדו, _सरोक, _tezk, _polo
  { {0xe8e00023,0xd019005c,0x8afc0053,0x6b9d0030}},	//   _đức_, wań_, עהוי, izsg
  { {0x70b2014e,0x82340029,0xd019005c,0x9991005c}},	//   ुकूल, إرها, tań_, lazł_
  { {0xd00e0029,0x5f750087,0x94e9002b,0x6305002b}},	//   ولى_, لاخر, _شکاف_, _نورل
  { {0x98b80024,0x3f890024,0xef160139,0xa247002b}},	//   ntrā_, _ļaus_, амы_, _میشل_
  { {0x672d016f,0x999800dc,0x38600064,0x9758000a}},	//   iraj, zerű_, zdir_, ריזו_
  { {0x672d01b2,0x66cb007c,0xf652000a,0x386053db}},	//   hraj, lüks, חצי_, ydir_
  { {0x0d82005e,0xe0ce005e,0x672d1367,0x66d00601}},	//   ілян, _єв_, kraj, täkk
  { {0x6449002f,0x7ff40031,0x5f770002,0xe456004c}},	//   _mbei, _اسما, _حاضر, בירט_
  { {0x8f9a009d,0xb69b0011,0xa2f6000a,0x8d75002b}},	//   _ביני, _stân, ימשה_, _نابا
  { {0x7d760015,0x200d0012,0x66d0008c,0x672d53dc}},	//   _نمور_, obei_, säkk, eraj
  { {0xf77200a2,0xa806170d,0x6d410400,0x7c2402b9}},	//   ياء_, рзал, mtla, _udir
  { {0x38603f14,0x672d53dd,0x7c96002b,0x66cb0061}},	// [cf00] rdir_, graj, _مشکا, yükt
  { {0x91f50023,0x442400e8,0x7e61002e,0x644953de}},	//   _sán, _sdm_, ndlp, _abei
  { {0x2baa005d,0x63ad002d,0x64bc0085,0x98b8003d}},	//   _चेता, úann, jčic, atrā_
  { {0xd91b0008,0x3eb800bc,0x98a3002a,0x14f30033}},	//   _בוטל, črti_, kuję_, ізіў
  { {0x68e40020,0x6d410020,0xbcb7000a,0xe4530033}},	//   mmid, htla, ספנו_, ікшы
  { {0x68e40020,0x8bd7000a,0x6f0900da,0xd36f012c}},	//   lmid, בונו_, dpec, بهه_
  { {0x649301e2,0xbbd3005d,0xddc8005c,0x5bd3021e}},	//   _için, _सर्क, zedł, _सर्व
  { {0xddd8002c,0x8f463839,0x1306030c,0x22490085}},	//   _novš, аход, _взам, đaka_
  { {0x6d410050,0x6e440029,0x30830029,0xa067049d}},	//   etla, منظم, تليف, рања_
  { {0x26c7016f,0x200d00b8,0x9987006f,0x7e98006e}},	//   čnog_, abei_, _čiže_, اندر_
  { {0x85f70053,0xe5f7004c,0xb5f7004c,0x68e400aa}},	//   יציע_, יזיר_, יציג_, kmid
  { {0x98a3002a,0x23660085,0x2aad0085,0x321c01c0}},	//   buję_, ovoj_, džba_, lavy_
  { {0xcf77003b,0x600b000a,0x6d4153df,0xa09b004f}},	//   _نصوص_, _יִגְ, atla, _ביאט
  { {0xadbc0010,0x68e40171,0x6fb30015,0xa9c70015}},	//   _палi, emid, _بمها, لزأو
  { {0x2bd3014e,0x39580026,0x66cb0f87,0x28a70033}},	//   _सरका, gwrs_, züks, ашаг
  { {0x1410005d,0x88940080,0x6d7b000a,0x23660085}},	//   ारोह_, оисх, _יאוח, kvoj_
  { {0xc7cb0033,0xaa89012c,0x68ef0061,0x29050091}},	// [cf10] тыве_, _منظم_, _vicd, ūla_
  { {0x68e40020,0x8f9b000a,0x2607243d,0x86980054}},	//   amid, דימי, рчаг, акус_
  { {0x672d0604,0x2d9e0012,0x200d0091,0x98a3002a}},	//   sraj, nzte_, ybei_, zuję_
  { {0x321c53e0,0x6f0930d2,0xb0d50065,0x672d53e1}},	//   eavy_, ypec, _डींग, praj
  { {0x6f09003e,0x9cd80008,0x08760053,0xe3b00031}},	//   xpec, בואה_, _הערט_, وره_
  { {0x78ad0007,0x69da007c,0x984f0061,0x8b58000a}},	//   liav, üteg, _işık_, יידס_
  { {0xf5950029,0x66cb0020,0xd1c90080,0x2ca90020}},	//   _الأج, süks, ылке_, _omad_
  { {0xf3f90011,0x2d9e002c,0xb817005d,0x66d000f2}},	//   _faţa_, dzte_, तरिम_, väki
  { {0xff510029,0x200d00b8,0x4fa5006b,0x63a40125}},	//   سخة_, rbei_, сипв, úint
  { {0x78ad08c7,0x66d0008c,0x6f0953e2,0xe2930067}},	//   hiav, täki, rpec, _بذر_
  { {0x2d9101b2,0xcee80015,0xc692004c,0xc2c400c3}},	//   áze_, جرين_, פאט_, _بيلي
  { {0x41740029,0x3b0a000d,0xc18c0053,0x718c0053}},	//   _باكس, лемо_, _שטאָ, _שװאַ
  { {0x64bc00df,0xe4560053,0x9f0500a2,0x6d4153e3}},	//   nčia, זירט_, _اوتو, stla
  { {0xd37a00b2,0x64bc00df,0x6ec40015,0x8a03004a}},	//   ארשט, ičia, _وتوق, ззре
  { {0xc8960001,0xf2d2000f,0xef19002a,0x52d6004c}},	//   брањ, פעל_, ryżu_, מושע_
  { {0x60c90991,0x64bc0007,0x68e40f9d,0x98a32791}},	//   noem, kčia, umid, писе
  { {0x15f60029,0xac970087,0x64bc002c,0x1867005e}},	// [cf20] مساح, _دنيا_, jčia, щати_
  { {0xe6290015,0x64bc006f,0x2608000b,0xe6170128}},	//   لثمن_, dčia, ाँधी_, йду_
  { {0x64bc0007,0x09f7000a,0x26cb002b,0x68e40079}},	//   ečia, _למים_, اطقی_, pmid
  { {0x291e00df,0xd4090015,0x64b7000b,0x25de000b}},	//   štas_, لتهم_, _अदृश, केगी_
  { {0xdc8d0053,0x321c0057,0xcc3b004c,0x64930061}},	//   כװאָ, tavy_, רענט, _içil
  { {0xe6960029,0x66cb0030,0x4254012c,0x8bd7004f}},	//   _السد, sükr, زنبر, זונו_
  { {0xd14a0086,0x72290036,0x64bc1de0,0x321c0264}},	//   اشتن_, рців_, ačia, ravy_
  { {0xb97b0008,0x63a4002d,0xc0340054,0x831a006e}},	//   טנצי, úins, цниј, _مقرر_
  { {0xdfd0003b,0x08770053,0x93590001,0x93fb00f3}},	//   بية_, מעקט_, _врху_, _תלמי
  { {0x2d9e018b,0xf7730008,0xb87b0092,0xa7fb02c1}},	//   tzte_, פקת_, _khíc, _maña
  { {0xa2c5000b,0x3eac0bfa,0xdfd2002b,0x867b000a}},	//   ाकर्, ridt_, _کيش_, אריו
  { {0xa1770008,0x7e980086,0xb87b002d,0x2d9e0012}},	//   _לעבד_, انگر_, _mhíc, rzte_
  { {0x661e034c,0x66d0008c,0x78ad53e4,0x0000006a}},	//   kapk, läku, viav,
  { {0xdd94054f,0x6d5c001a,0x6df40015,0xff57000a}},	//   _малы, æras, _بكثا, _לבדך_
  { {0x66d000f2,0xceb8002a,0x78ad014b,0xe919005e}},	//   näku, mnę_, tiav, робі_
  { {0xb7150063,0x64bc0091,0x3eb800bc,0x6af4002b}},	//   ждащ, yčia, črtu_, _کثير
  { {0x78ad53e5,0xa7fb0077,0x69c80012,0x0000006a}},	// [cf30] riav, _caña, üder,
  { {0x6c350086,0x1efb0053,0x9b18000a,0xa7fb0077}},	//   _افکا, טלמע, _החזה_, _daña
  { {0x25b90029,0x35550015,0xf20b000b,0x9475002b}},	//   جهاد_, تناز, सुफ़_, يگرا
  { {0xe5700015,0x14c8004a,0x81c7003d,0x7d0453e6}},	//   عطل_, бычи_, nzēš, _čisl
  { {0x98b804f9,0x083a0053,0x1dcf000b,0xdfc60021}},	//   stră_, _דערל, _सुनत, _آي_
  { {0x161d005d,0x64bc0007,0xe2960b75,0x2127002b}},	//   _फ़िर_, rčia, жаш_, ميتی_
  { {0x64bc09f6,0x91e253e7,0xb4950054,0xceb8002a}},	//   sčia, моше, _дивљ, dnę_
  { {0x3f420084,0x64bc53e8,0xceb80b48,0x2019123c}},	//   fðu_, lčin, enę_, úsi_
  { {0x3f42002e,0x81c70024,0xb4d5005d,0x8e55017f}},	//   gðu_, dzēš, हती_, отні
  { {0x0ea9004a,0x64bc0910,0xfd490248,0x1d250248}},	//   ркой_, nčin, азок_, омом
  { {0xa2c6014e,0x22640089,0x98b80007,0x66d00123}},	//   िवर्, řská_, ltrą_, mäkt
  { {0x25e1005d,0xceb8005c,0x66d00123,0x50d7002b}},	//   _करनी_, anę_, läkt, _ازطر
  { {0x98b80007,0xe79c0064,0x0000006a,0x0000006a}},	//   ntrą_, düğü,   ,
  { {0xbebd003d,0xfe710015,0x64bc53e9,0xdea1009a}},	//   grūt, _زدت_, jčin, _آیدی
  { {0xe81a0001,0xada505ae,0xc4c9000b,0x443f0085}},	//   ицај_, _файл, िकाओ, _ocu_
  { {0x64bc12d7,0x798e0034,0x0000006a,0x0000006a}},	//   ečin, rybw,   ,
  { {0xc0520008,0x661e0049,0x4ac60015,0xe73a1328}},	// [cf40] וזן_, tapk, _ويبق, рез_
  { {0x443f53ea,0xf626005e,0x6f7a000a,0xe7170015}},	//   _acu_, ідео, יְבו, تيكت_
  { {0x661e064e,0x7e6304a9,0x201f01c2,0x98160058}},	//   rapk, _manp, kaui_, _وبحا
  { {0xe73a004a,0xceb8002a,0x75230045,0x64bc0796}},	//   _кем_, znę_, ânza, ačin
  { {0xceb8005c,0x66e6070e,0x93770015,0x66090061}},	//   ynę_, _мома, قصور_, _şeke
  { {0xb87b0023,0x236d0134,0x79fa000a,0xe5a602b0}},	//   _thíc, _drej_, ׁלְח, _диги
  { {0xd1300029,0xca7b00a3,0x599a000a,0x90440015}},	//   رمة_, ינסט, ישַׁ, كنغه
  { {0x7e63016b,0xc0e70015,0x228b00cb,0x661c53eb}},	//   _aanp, يفون_, _søkt_, _herk
  { {0x66d000f2,0xdfda006b,0x672453ec,0x661c1a4c}},	//   säku, шък_, nsij, _kerk
  { {0x3f420084,0x6724022d,0x52a70afa,0xcee70054}},	//   rðu_, isij, _двум_, одње_
  { {0x64bc00df,0xd657000a,0xd5fb004c,0x661c53ed}},	//   nčio, חיית_, יפיר, _merk
  { {0xceb80870,0x62884560,0x67244c1d,0x90e50058}},	//   snę_, _hodo, ksij, _فسنن
  { {0x7d0d0089,0x81c70024,0xd00b000a,0x63a253ee}},	//   _čase, rzēš, _דּוֹ, nzon
  { {0x661c002a,0x7c3a0091,0xccfa0054,0x9f52002a}},	//   _nerk, ėtra, _кћи_, źców_
  { {0x2d8300fb,0x7dc60029,0x6726003c,0xac950010}},	//   øjet_, _بتشك, _avkj, _накш
  { {0x4adb000b,0x628853ef,0x672b01d3,0x0000006a}},	//   _मीरव, _lodo, ágjo,
  { {0x661c510b,0xe7190029,0x63a20111,0x66d000f2}},	// [cf50] _berk, صيات_, jzon, jäks
  { {0x63a20050,0x62880048,0x7bdf02c1,0x661c39c5}},	//   dzon, _nodo, _izqu, _cerk
  { {0x4a5a000a,0x64bc023a,0x661c53f0,0x545502ed}},	//   _הדתו, rčin, _derk, звет
  { {0xb4d5014e,0x236d00bd,0x18350053,0x629a20b6}},	//   हते_, _prej_, _צאָל_, _alto
  { {0x9cd80008,0x66d000c0,0x987a0135,0x628853f1}},	//   קודה_, täkt, _הארט, _bodo
  { {0xf6c80033,0xd36e0040,0x03780015,0x628853f2}},	//   _дыск_, اهو_, تحمت_, _codo
  { {0x62880a7e,0x45d4022a,0x64bc07c4,0x63a20077}},	//   _dodo, _жорс, očil, azon
  { {0x69c101e2,0x64bc0057,0xd49b0054,0xa9bc000a}},	//   üley, nčil, _трг_, יזור
  { {0x63a20050,0x4e790029,0x53140015,0x4f950033}},	//   czon, محدد_, _يذكر, ярку
  { {0x479c0008,0x645953f3,0x979c000a,0x7c3d0012}},	//   ייחס, lewi, ישחק, egsr
  { {0xfbc90008,0xdc6a067a,0x20060034,0x8d750021}},	//   _עת_, банд_, _ffoi_, سادا
  { {0x757a0008,0x64590e18,0x6283044c,0xec9a009c}},	//   צטרפ, newi, ljno, стој_
  { {0x76930064,0x7e63013c,0x5ffa000a,0xee2e0839}},	//   _kıyı, _tanp, _ההנה, _пн_
  { {0x8e490029,0x2d830134,0x64bc0007,0x5e440015}},	//   _طلبك_, øjes_, yčio, _يَنْ
  { {0x63a204ed,0x6459003e,0xe7f8000b,0xa7fb0077}},	//   zzon, kewi, ंखला_, _caño
  { {0xfc2b0089,0x66d000f2,0xa7fb0077,0x69de00bc}},	//   íští_, yäks, _daño, _vzpe
  { {0x672400f0,0xcce500a2,0x64593174,0x661c43ad}},	// [cf60] usij, _تسوي, dewi, _perk
  { {0x66d0022d,0xddc10014,0x67241ce1,0x98f60033}},	//   väks, lelő, rsij, _нямч
  { {0xf9fb0008,0x62881aa1,0x4994002b,0xf506005e}},	//   _להימ, _rodo, _غیرر, їздо
  { {0x6ba10064,0x66d000f2,0x661c34e8,0xb97b000a}},	//   _özgü, täks, _werk, _הנטי
  { {0x6e2100df,0x661c0d25,0xddc100dc,0x628853f4}},	//   kalb, _terk, ielő, _podo
  { {0x63a253f5,0xf655004a,0xa2260067,0x66d0008c}},	//   rzon, _отсю, سرته, räks
  { {0x66d0022d,0x32030029,0x63a253f6,0xa97a004c}},	//   säks, رِيق, szon, מאַכ
  { {0x25e1005d,0xc9530008,0x55bb0008,0x6288002a}},	//   _करती_, גמה_, _המלו, _wodo
  { {0x628806d4,0xa87b0053,0xa8570008,0xd007009c}},	//   _todo, מאקר, ליקה_, чење_
  { {0x6e2100df,0x539b000a,0xff4f0015,0x9e660015}},	//   galb, _הימו, اخي_, ساخن
  { {0x0000006a,0x0000006a,0x0000006a,0x0000006a}},	//     ,   ,   ,
  { {0xd1970008,0x2cbf0020,0xddc100dc,0x2d820085}},	//   _מכבי_, õud_, gelő, ćke_
  { {0xa0c90029,0x2d830134,0x30830015,0xac240033}},	//   _بذلك_, øjer_, _سلوف, эфэк
  { {0xb87b00a7,0x6459005c,0x2ec7000b,0xa7fb039f}},	//   _chín, zewi, रकृत, _paño
  { {0xa9c404ab,0x58d50004,0x64bc0085,0xadd30054}},	//   естк, довт, ečim, _пошљ
  { {0xc8d9005e,0x321e53f7,0x64bc1c97,0xc8f4006b}},	//   імає_, _lety_, učil, езсъ
  { {0xb904005d,0x38340010,0x6283002a,0x7c2d53f8}},	// [cf70] _पी_, энтр, yjno, _idar
  { {0xfb1c0008,0x4bd800a2,0xd6db04ab,0x35e7005e}},	//   _הוזמ, _عبيد_, ёта_, пцев
  { {0x64bc00bd,0xf905002b,0x645947bd,0x2509002b}},	//   mčij, _تأخی, tewi, زرای_
  { {0xc4350086,0xb4c7000b,0x23b500c3,0x660553f9}},	//   بکست, ईके_, وماس, schk
  { {0xa3bb0015,0x84360015,0xe3f80015,0x386953fa}},	//   حاضر_, ذكور_, أعمش_, mdar_
  { {0xbb3c0053,0xddc100dc,0x386918af,0x66d00123}},	//   מעדי, zelő, ldar_, säkr
  { {0x85050086,0x7af7164a,0x6e2153fb,0x0000006a}},	//   _آورن, _mixt, valb,
  { {0x1dd0005d,0xa99c000a,0x38693d14,0x961d000b}},	//   _हड़त, מבור, ndar_, _फ़ुट_
  { {0x53340ea6,0x442d53fc,0xfe710067,0x64bc0085}},	//   _петт, _ide_, ندد_, kčij
  { {0x97580008,0x9ea90036,0xdd1b0264,0x7c2d53fd}},	//   ליחו_, івна_, _váže, _adar
  { {0xc6920008,0x442d0107,0xddc10030,0x386900bc}},	//   דאי_, _kde_, telő, kdar_
  { {0x442d0089,0x71880008,0x929d005c,0xb87b002d}},	//   _jde_, _מְנַ, _bułg, _shín
  { {0x7c2d0176,0x386953fe,0xcf240015,0xac930033}},	//   _ddar, ddar_, _كروي, таўш
  { {0xb87b002f,0xddc100dc,0xd336000a,0x4efa0447}},	//   _bhío, selő, ורשה_, _והסו
  { {0xf2d200b2,0xa3d4000b,0x9998002a,0xa96705c8}},	//   דעם_, _सुन_, warł_, мира_
  { {0xb87b002d,0x442d53ff,0x9998002a,0x290c003d}},	//   _dhío, _nde_, tarł_, īda_
  { {0xd6d2003b,0x4b26008f,0x290c0048,0xb87b0092}},	// [cf80] نقر_, _ўмов, ūda_, _thín
  { {0xb87b002d,0x64b8005d,0x442d5400,0xe5da012e}},	//   _fhío, ेक्श, _ade_, офеј_
  { {0xb9260029,0x69c00064,0x68fe02f2,0x8a7b000a}},	//   _تفجي, ğmes, _uupd, _ואית
  { {0x69c00064,0x9998002a,0x2fc0001a,0x9d28004f}},	//   şmes, parł_, _þigg_, לֵנִ
  { {0x442d0026,0xb87b002d,0xf487002b,0x82a62e38}},	//   _dde_, _mhíl, بالی, мадж
  { {0x06560015,0xe297084f,0x0556009b,0x442d5401}},	//   _تنسح, мач_, _отбя, _ede_
  { {0x6d480012,0x321e0e1c,0x843a0058,0x0000006a}},	//   xtda, _vety_, _وكسر_,
  { {0x442d016f,0xd0100029,0xe58b000a,0x0000006a}},	//   _gde_, دلة_, _וָמָ,
  { {0xc306002b,0xc246009c,0x2ef40195,0x934300c9}},	//   _آبرو, _онак, нзир, _инте
  { {0x442d0089,0x6d482c35,0x2486016f,0x877b000a}},	//   _zde_, ttda, ljom_, קאיי
  { {0x2d98002c,0xfe420086,0xdd940033,0x98b8002a}},	//   áre_, _یکدی, ханы, strę_
  { {0x2486016f,0x7af7148e,0x15e3000b,0x67365402}},	//   njom_, _sixt, केटर_, kryj
  { {0xba770086,0xfc3f002d,0x386902ce,0xf413000a}},	//   واست, rgí_, vdar_, כפר_
  { {0xda7b0127,0x8ae40033,0xb87b0125,0x7c2d002a}},	//   цям_, вісл, _phío, _wdar
  { {0xa2b1005d,0x64bc00bc,0x8e57000a,0x99d400c3}},	//   _अगस्, rčij, _חיוג_, نتفا
  { {0x7c2d12e8,0x89340058,0x38695403,0x0000006a}},	//   _udar, ضعفا, udar_,
  { {0x9bf5005e,0x38693eb8,0x98aa0046,0xd6980033}},	// [cf90] _язич, rdar_, lubě_, кiро
  { {0x76d5003b,0xb87b002f,0x96340010,0xd6db022a}},	//   رياض, _thío, кнуц, іта_
  { {0x44200010,0xf1ae000b,0xd5b10015,0xe895027a}},	//   кi_, _झेलन, دفا_, _зань
  { {0xb69b0011,0x629800dd,0x64c9000b,0x59380033}},	//   _atât, ekvo, िकेश, _ўзяў_
  { {0x98b10045,0x68ed5404,0x2418005e,0x42d501c6}},	//   auză_, mmad, фією_, ніку
  { {0x471a0008,0x91e51179,0x2169006d,0x68ed5405}},	//   _מושג, ноле, зики_, lmad
  { {0x24190010,0x68ed5406,0x045b0015,0x25a50123}},	//   _новы_, omad, _وجرت_, _åll_
  { {0x68ed0064,0x442d0134,0x2486002a,0x51840054}},	//   nmad, _ude_, cjom_, туља
  { {0xe4480029,0x2d8a0012,0x2901042c,0xdd2e0046}},	//   _تلقى_, äben_, _luha_, věše
  { {0xb87b002d,0xd7ba0008,0x8e74005e,0xc7d8000a}},	//   _shíl, לֶיך, вуюч, ווחי_
  { {0xa6e2002e,0xf652004c,0xdd2e0046,0x68ed3838}},	//   íðin, נצט_, těše, kmad
  { {0x859a013a,0x80270086,0xb87b0125,0x6736002a}},	//   פשרו, _آرام, _bhím, yryj
  { {0x9e640086,0x0c230010,0x501a004f,0x68ed005a}},	//   راین, ымян, _זונו, dmad
  { {0x60db0005,0x249f0251,0x69da007c,0x2aad006f}},	//   llum, _llum_, üteo, oľby_
  { {0xf3f904f9,0x940a005d,0x3e6a002b,0xdd03003d}},	//   _daţi_, हुँच_, _رجوی_, ērēt
  { {0xd5b70092,0x248d0177,0xf1b2000a,0x2901174f}},	//   _ứng_, _noem_, אסל_, _duha_
  { {0x17c70036,0xe7aa006b,0xa6e61e60,0x07a35407}},	// [cfa0] егти_, чвал_, ежал, гатн
  { {0x7c2617f7,0xe61a005e,0xe5a6249a,0x67364e7b}},	//   lakr, їде_, низи, rryj
  { {0xe45a0080,0x60db00d9,0xe3b20086,0x7d0b0045}},	//   зже_, klum, گرا_, _însă
  { {0x9d1a000a,0x44200016,0x24070785,0x53e6352f}},	//   פונט, úi_, енци_, нцла
  { {0x7cfe0024,0x57fb000f,0xd7fb000a,0xa7d60015}},	//   _vīri, _מלכו, _מהכל, _ستحص
  { {0xbb3b0053,0x2ca00034,0x7d0d30b4,0x60db5408}},	//   פעצי, _llid_, _časn, elum
  { {0x2ca00020,0x64a60219,0xe5050015,0xc2070021}},	//   _olid_, _зава, _لبقي, رقين_
  { {0xa3cb000b,0x40a8002b,0x6ee6001a,0x60db5409}},	//   _रुक_, بختی_, iðbe, glum
  { {0xb4be005d,0x4426016f,0x7995002a,0x22b6002a}},	//   ीकी_, mao_, zyzw, ałka_
  { {0xddd80089,0xe357000a,0x4d98005e,0x5d980033}},	//   _zavř, _אשמח_, дкою_, дкоў_
  { {0x24ea000a,0x2fda002b,0x68ed0061,0x0136012c}},	//   ּקָּ, _کوشد_, ymad, _سعاد
  { {0xd1260086,0x6442151a,0xc19b000a,0x25a5007c}},	//   یم_, ngoi, _משבי, _ülle_
  { {0x44260092,0xd36600c3,0x7ac70588,0x29013405}},	//   iao_, جه_, есве, _suha_
  { {0x539b000a,0xad260015,0xcfa90021,0x4426540a}},	//   ליכו, _كربو, _غانم_, hao_
  { {0x4426540b,0x68ed2286,0x7cfe0091,0x8d730369}},	//   kao_, tmad, _būre, _مايا
  { {0x4426016f,0x26c71e1b,0x4ddb000a,0x6d4f002a}},	//   jao_, čnom_, _מחוו, ńcac
  { {0x4426016f,0x248d0079,0xc6f90c30,0x68ed540c}},	// [cfb0] dao_, _roem_, днах_, rmad
  { {0xe8e00016,0xb69b0045,0x7b07003d,0x68ed540d}},	//   _đục_, _atâr, ēptā, smad
  { {0x68ed0064,0xceb30135,0x248d14e6,0xe5ab023e}},	//   pmad, ניע_, _poem_, чњак_
  { {0x4426010b,0x78a4540e,0x2c37000a,0xf4841833}},	//   gao_, chiv, תָ֑ם_, лучн
  { {0xe28e000d,0xa3cb000b,0x1308005e,0x69e30085}},	//   аа_, _रुख_, еній_, šteć
  { {0x7c2616c6,0x6d584bfe,0x6d5d003d,0x0000006a}},	//   zakr, _opva, āsaz,
  { {0xa1560124,0x44260f58,0x10a50063,0xc692000a}},	//   вају_, bao_, кикн, _דאם_
  { {0x397c000f,0xd1780033,0x045b0015,0x60db019a}},	//   לטונ, эсіі_, _عجزت_, ulum
  { {0xa8580008,0x7c260f49,0xb7c80011,0x60db540f}},	//   תיחה_, vakr, miţâ, rlum
  { {0x60db0084,0xe3b000e6,0x82370002,0x1ee7002b}},	//   slum, _طرق_, _سرطا, عودی_
  { {0x60db0064,0x4df4034e,0x7c265410,0xdca6107c}},	//   plum, ляют, takr, вани
  { {0x6fb20086,0x66090064,0x6f0204ed,0x69b7005d}},	//   امیا, _şekl, _fuoc, ोपनी
  { {0x26c7016f,0xab630afb,0x7c262fd0,0x0000006a}},	//   čnoj_, авял, rakr,
  { {0x6e440029,0x4426016f,0x5d850015,0xfebb0015}},	//   _منهم, zao_, _للتل, _عاشت_
  { {0x2d8a0134,0xceb6000a,0xf2d2000a,0xdeb6000a}},	//   øbet_, _בפסק_, יעך_, _בפסח_
  { {0x6e230134,0x4c360010,0x2aad0085,0xd9430054}},	//   _henb, _рэкт, džbu_, јети
  { {0x4426010b,0x7d033ce2,0xac83006b,0x6e230079}},	// [cfc0] vao_, _huns, _ъгъл, _kenb
  { {0x7c240334,0x05ba0015,0xb69b0045,0xeb97000a}},	//   _heir, ودات_, _stâr, _סדיר_
  { {0x95860063,0x44265411,0xca37000a,0x4a9b000a}},	//   ълже, tao_, _בניה_, _חייג
  { {0xb4be005d,0xb4cc005d,0xd499005e,0x7d030241}},	//   ीके_, रके_, нрі_, _muns
  { {0x4426010b,0x7c245412,0x64421359,0x04430de5}},	//   rao_, _meir, rgoi, речн
  { {0xe8e00023,0x4426010b,0xcb130008,0x395a01d7}},	//   _độc_, sao_, סלו_, _kpps_
  { {0xa6e20084,0x4426016f,0x75d60031,0x8555002b}},	//   íðun, pao_, _شيرا, _میلر_
  { {0xf9930008,0xe0cf0029,0x3ea500b8,0x6d5c0061}},	//   שרה_, يزي_, ehlt_, çram
  { {0xf8b3013a,0x44240024,0x78a30011,0x4fc6006b}},	//   ישה_, _iem_, _înve, ъска
  { {0x3860003e,0x33d50010,0x15e6005d,0xd1320029}},	//   heir_, _сіст, _करार_, _نمط_
  { {0x06970008,0x6db4005e,0x7173002b,0x7c245413}},	//   דדים_, уйну, _پهنا, _beir
  { {0x44245414,0x7c2450bf,0xbcd80015,0x7d035415}},	//   _jem_, _ceir, َذَا_, _duns
  { {0xd0070cb9,0x7c244fb8,0x8fa306eb,0x8f340923}},	//   _рече_, _deir, _каце, _селц
  { {0x0f570008,0x6e93005e,0x6e2302de,0x3cfd000b}},	//   _סיום_, _вишу, _genb, _रूके_
  { {0xceb8005c,0x4efb01ac,0x7c245416,0x7d032903}},	//   mię_, _קלוג, _feir, _guns
  { {0x44245417,0x7c24172c,0xb4be000b,0xb4cc000b}},	//   _nem_, _geir, ीको_, रको_
  { {0x64bc00df,0x58840010,0xf77300e5,0x7cfe003d}},	// [cfd0] nčiu, шыра, جاز_, _vīru
  { {0x64bc00df,0xd6280124,0xceb80050,0x26c1016e}},	//   ičiu, кође_, nię_, unho_
  { {0x442403af,0xa9c45418,0x84390015,0xa979004c}},	//   _bem_, _всяк, فكار_, _װאָכ
  { {0x6ba80064,0xd4e40036,0xe5340036,0x0577002b}},	//   _örgü, аючи, рець, _یازد
  { {0x83640029,0x47340010,0xa2950036,0xb8f7005d}},	//   لدول, _княс, ладі, ाक_
  { {0x21270086,0xdce40046,0x929d002a,0x672b0030}},	//   نيتی_, _brně, _buła, ágju
  { {0x91280029,0x2bda000b,0xc1050015,0xceb8002a}},	//   نسيق_, _युना, دوبي, dię_
  { {0x44245419,0xa4d5005e,0xddc30045,0xdb060030}},	//   _gem_, _собі, _lanţ, szké
  { {0x672d0467,0x6e233174,0x7d03541a,0xfeb90015}},	//   nsaj, _penb, _suns, فادت_
  { {0xceb8005c,0x76450026,0x7c24541b,0x672d3631}},	//   gię_, nghy, _seir, isaj
  { {0x99830089,0x7c243c93,0xc11503ae,0x64bc0091}},	//   dajů_, _peir, _смеј, ačiu
  { {0x442400a7,0x98b80024,0x909b0015,0x853a004c}},	//   _xem_, kurā_, _تضطر_, עגרי
  { {0x7d0300b8,0xceb8005c,0x38600144,0x2d8a02de}},	//   _wuns, bię_, veir_, øber_
  { {0xb3ba000a,0x7c242239,0xc279000a,0x7f3a000a}},	//   תמשכ, _weir, ׂרָי, _נעצו
  { {0x38600026,0x19b9005e,0x672d1252,0x68fd0079}},	//   teir_, вуть_, esaj, _bisd
  { {0x18670292,0x64bc002c,0x6d41541c,0x88c50015}},	//   ласи_, nčit, mula, لتقل
  { {0x87250015,0x46ea0684,0x6d41541d,0x38600034}},	// [cfe0] لعلم, едан_, lula, reir_
  { {0xcc8a0086,0x6449541e,0x442439b6,0x1bfb000a}},	//   _آنکه_, _acei, _sem_, _אלפב
  { {0x6d41500e,0xe5050015,0x67230085,0xe8fa0099}},	//   nula, لبني, ćnja, _пло_
  { {0x7cfe231a,0x94260004,0x64bc2adc,0x6e280030}},	//   _jūra, умде, yčiu, zadb
  { {0x8c1b039e,0x7e6104f8,0x9cd7000a,0x4424376a}},	//   גוני, kelp, נונה_, _vem_
  { {0x6ffb0024,0x7e61003c,0x291802b9,0x929d002a}},	//   _mācī, jelp, opra_, _puła
  { {0x4424541f,0xa4940086,0xc5f50063,0x7e6106a5}},	//   _tem_, _پیشت, _вятъ, delp
  { {0x6449002f,0xa4f8002b,0xceb8002a,0x7afe5420}},	//   _gcei, _شکار_, wię_, _lipt
  { {0x74130086,0xc0e70015,0x69d6000b,0x6e2801c2}},	//   _طولا, دفين_, _मुसी, tadb
  { {0xe3b70484,0x6e980658,0x6d540054,0x64bc0091}},	//   _сбу_, твор_, акођ, rčiu
  { {0xceb8005c,0x64bc0007,0x6e2800bd,0xac1901e7}},	//   rię_, sčiu, radb, кону_
  { {0xbd870074,0x85f705bd,0x61e50012,0x459b004c}},	//   چنین_, טציע_, ühle, גסטע
  { {0xceb8005c,0x207b015b,0x68fd01c2,0xcab50015}},	//   pię_, _ראדא, _risd, لمحظ
  { {0xedb50086,0x7afe0049,0x3ffb000a,0x8f8b000a}},	//   اجیک, _cipt, _נפגע, _רְאֵ
  { {0xc27b0053,0xdeb7000a,0x35d9000b,0x6d415421}},	//   ערלי, _תפוח_, _बुढ़, cula
  { {0x69de00cb,0x98b8003d,0x6d4f0045,0x7793009a}},	//   _dype, turā_, ăcat, میجا
  { {0xdc3c000a,0x29180030,0xd759012c,0x68fd5422}},	// [cff0] _נעזר, apra_, ضلات_, _visd
  { {0x68fd003e,0xba550180,0x9f97000a,0x644951cb}},	//   _wisd, _твој, אדמה_, _scei
  { {0x66d000f2,0xbafa0008,0x2614000b,0x8afa000a}},	//   näky, _שהתש, धड़ी_, _שהתי
  { {0x4867010f,0xc86712bd,0x95540015,0xd5380015}},	//   _съоб, _стои, إخلا, اثلا_
  { {0x69de134d,0x234a002b,0xa7fb0077,0x07a40033}},	//   _zype, نسوی_, _pañu, _гаўн
  { {0x33180086,0x6d410064,0x82370115,0x9bb8000a}},	//   ازند_, yula, ارشا, נהגה_
  { {0x21a50036,0xf3c9002b,0x008505c0,0x95c80d3c}},	//   рийм, ربچه_, илко, _бута_
  { {0x27e6005c,0x98b80045,0xd1b80021,0x75230045}},	//   żone_, mură_, داها_, ânzu
  { {0x2d98079b,0x6d411f36,0x64bc0227,0xef19006b}},	//   øren_, wula, rčit, ъмп_
  { {0xcdf5005f,0x5e450015,0xe718000a,0x23940015}},	//   ичны, جَدْ, אחזר_, _الْآ
  { {0x62814883,0x6d41166f,0xa4b5000a,0xcee80015}},	//   _inlo, uula, ֹלָה_, درين_
  { {0x6d415423,0x7fb6002b,0xeb9a2f30,0xe588000a}},	//   rula, اهیر_, вим_, אָשָ
  { {0x6d415424,0xb866002b,0xe4a8000a,0xddc300bc}},	//   sula, یارو, רֹתָ, _danš
  { {0xdaba0010,0xa2f5000a,0xee390e41,0x6d415425}},	//   тымі_, ימָה_, _рнк_, pula
  { {0x48b600a4,0x610300dc,0xdeba000a,0xb9230015}},	//   ащат, _főle, _במסל, ْفِي
  { {0x6cd30029,0xfcd30015,0x98b80045,0x291803a0}},	//   _وقوا, _ويوج, dură_, rpra_

  { {0x69de005c,0x1867226a,0xf7462791,0x98a30719}},	// [d000] _wype, шати_, резо, ците
  { {0x61110024,0x69de3c42,0xe61707ec,0x7cff01ec}},	//   _zāle, _type, иду_, _jūrn
  { {0x98b80011,0x9a3b0008,0x29050046,0x84060033}},	//   gură_, _בתיק, ílat_, апеж
  { {0xed5600b2,0xc6890008,0x64a60b1e,0x6a7c0123}},	//   יבער_, וא_, јада, _fåfä
  { {0x78a30045,0x8c29000a,0x24490058,0xdc1d01ec}},	//   _înva, רֵעֵ, اجمي_, _zņēm
  { {0x62d70033,0xa2b3005e,0x387204d1,0xadf70065}},	//   аміў_, обіч, ldyr_, ीशान_
  { {0xc4480074,0x12190010,0xe2970e88,0x98b80045}},	//   _میان_, уючы_, рај_, cură_
  { {0xea000092,0xc05a005e,0x04430076,0x628116ee}},	//   _giấu_, тік_, _месн, _enlo
  { {0x660901e2,0xdfd00015,0xc43b000a,0xf43b000a}},	//   _şeki, ثية_, _שתמי, _שתמש
  { {0xc6b6004f,0x0000006a,0x0000006a,0x0000006a}},	//   יהִי_,   ,   ,
  { {0xa0a6005f,0x1ef70029,0x4e930015,0x6abc001a}},	//   _кажд, جعية_, تشير, dirf
  { {0xd00f0018,0x41bb000a,0x6abc0034,0xb19b000a}},	//   _قلم_, _בצבע, eirf, _שיאכ
  { {0xdfd20074,0x9be70036,0x66d0008c,0x6abc001a}},	//   _بيش_, рінк, säky, firf
  { {0x799c0026,0x8f9b0008,0x5ed30015,0x5faf000b}},	//   fyrw, _בידי, _وتوز, _जेटल
  { {0x9e650086,0xb9250015,0x61030030,0x5e7b000a}},	//   _دانن, إفري, _tőle, _שָׂד
  { {0x5dfb000a,0xaff8000a,0x7bc80061,0x48a82a6f}},	//   _בפונ, ָּֽי, ğdur, атум_
  { {0x28f80080,0x7d0d00bc,0x1798004a,0x9635005e}},	// [d010] реть_, _časi, авты_, йнац
  { {0x98b804f9,0xc7c40036,0x6b9d0026,0x6e98000a}},	//   tură_, істи, mysg, נֹּג
  { {0x7cff0007,0xa2b7000b,0x5967006b,0x95390054}},	//   _jūro, ्चस्, _тъпа, узет_
  { {0xe3b30086,0xe43c0046,0x04b4005e,0xf504005e}},	//   يرش_, bříč, осія, ізіо
  { {0x6b9d0176,0x98b80011,0xbebd0024,0xb87b002d}},	//   nysg, sură_, osūt, _dhít
  { {0xe6950015,0x8bd8000a,0xd517002b,0x98b80045}},	//   _الآد, בודו_, _نظرب, pură_
  { {0x6b9d0034,0xba38004f,0x0000006a,0x0000006a}},	//   hysg, בטוח_,   ,
  { {0xe4a70292,0x26c70107,0x64c5012c,0x929d002a}},	//   _трго, čnou_, _ايرل, _tuło
  { {0x6006004a,0xd3db0015,0xc4f80058,0x0000006a}},	//   щным_, _شبرا_, _ضعفا_,
  { {0x6b9d0026,0x91fc0024,0x628100da,0x26e5000b}},	//   dysg, _paāt, _unlo, _कठोर_
  { {0x11440015,0xed590054,0x69c00061,0x0000006a}},	//   _وَكُ, ћом_, şmez,
  { {0x6b9d0176,0x31ba000a,0x50f50054,0x6abc00a9}},	//   fysg, _גזענ, _узет, wirf
  { {0x6abc0084,0x547a0008,0xbf670086,0xf3f2000a}},	//   tirf, אטרו, _خداو, ּ֣ר_
  { {0x61e100f2,0x6f1b0092,0xbda90015,0x9d990015}},	//   _kyll, mpuc, _مطعم_, _مخبأ_
  { {0x6abc0084,0x49990036,0x395e0251,0x2d94006b}},	//   rirf, аття_, ïts_, _мръс
  { {0x48060010,0xa9280264,0xd94305e6,0xbebd003d}},	//   спав, _nižš, џети, asūt
  { {0x8c1b000a,0xb8650015,0xf7710015,0x2905001a}},	// [d020] _גופי, غافو, واْ_, ílar_
  { {0xe7ee000b,0xd7ef0015,0xdd390045,0x38720013}},	//   चेगा_, ركل_, căţe, sdyr_
  { {0x8afb000a,0x94060015,0x96f90033,0x0000006a}},	//   _תהיי, مواه, рэту_,
  { {0xb87b002d,0xe5f30015,0x04463ad5,0xe43c0046}},	//   _dhís, سكند, седн, příč
  { {0x68e40064,0x98b80024,0xe29a2bb2,0xa29402a3}},	//   mlid, strē_, лад_, жалі
  { {0x2902002e,0x98a3002a,0x68e45426,0x7d1a01c0}},	//   _hika_, rsją_, llid, ypts
  { {0x61e10026,0xf5960015,0xddda002a,0xf518000a}},	//   _cyll, _الزج, zetł, _כֵּל
  { {0xbebd0024,0x29020375,0x50660baf,0x6537000a}},	//   zsūt, _jika_, стка, _לאלף_
  { {0x7e2a02e1,0xa0670001,0x289b000a,0xcf260015}},	//   ліна_, сања_, טיקא, حربي
  { {0x69c00064,0x29025427,0x61e13efe,0x7eb80510}},	//   şmey, _lika_, _fyll, ргос_
  { {0xac990029,0xe0d603e7,0xa2b7000b,0x81a50015}},	//   لندا_, _людь, ्चर्, _وحمل
  { {0xb5fb0053,0x90e60015,0x6b9d0034,0xdb0a01c0}},	//   טליכ, _اسطن, tysg, žným
  { {0xdd390011,0x9e3405b3,0xe457004c,0xbebd003d}},	//   tăţe, _делч, זיכט_, tsūt
  { {0x290200f2,0xcef6049d,0x7ac70088,0x0f37004f}},	//   _aika_, _учењ, ссме, _פרוט_
  { {0xbebd0024,0x5e57004c,0xae57000a,0xdd390045}},	//   rsūt, _ליגע_, _הסוס_, răţe
  { {0x08550010,0x25ef000b,0x2bda000b,0x18550033}},	//   ўваю, _अरबी_, _युवा, ўваў
  { {0xe8940146,0xec38000a,0x656e0125,0x22b6002a}},	// [d030] чать, _האחר_, _asbh, ałki_
  { {0x8f9b0008,0xc7f8005e,0x963500fd,0x3ebe5428}},	//   אימי, снує_, інец, nitt_
  { {0xb87b002d,0x7a88000a,0x200207c4,0x2bda002b}},	//   _dhír, _הָרַ, žkih_, _مایک_
  { {0x27e6005c,0x4429002e,0x0596002b,0x98b8002a}},	//   żona_, úa_, غالگ, turą_
  { {0x6eef0134,0x93450010,0xa3d4000b,0xe7380033}},	//   løbe, інке, सॅल_, _леў_
  { {0x236d00bc,0x61e10034,0x99580046,0x26da5429}},	//   _vsej_, _pyll, láše_, copo_
  { {0xd9f9014e,0xa2d20029,0x3ebe003c,0x6a9c004c}},	//   ंधित_, بيوت, ditt_, רשונ
  { {0x7f590083,0xbf59005e,0x49bc000a,0x50b50033}},	//   ајот_, арої_, טמוס, ўску
  { {0xb4d5005d,0x7d0a00b8,0x9f850010,0x3ebe002e}},	//   सकी_, _aufs, ігод, fitt_
  { {0x3ebe003c,0x3205055e,0x2ca9007c,0x68e40061}},	//   gitt_, _ugly_, _alad_, zlid
  { {0xfd440010,0x2ca94de0,0xa05b0015,0x2cba0015}},	//   пэўн, _blad_, _مؤشر_, لاحظ_
  { {0x26da003f,0x442f542a,0x2ca900da,0x71d6015b}},	//   zopo_, nag_, _clad_, _וועד_
  { {0x7cd203eb,0xda660029,0xee2e274e,0x7d18007c}},	//   vārd, ياسي, _он_, _etvs
  { {0xe8e00092,0xeff6000a,0xd37a000a,0x60c9542b}},	//   _đốc_, _ומנכ_, ברשט, lnem
  { {0xed56005e,0xc8960004,0xcce60015,0xbce60015}},	//   _дощ_, орањ, _وسعي, _وأعو
  { {0x38cb0086,0x442f0024,0x60c9542c,0x02b6000b}},	//   لاقی_, jag_, nnem, _अग्न
  { {0x3f8d0251,0xa61a0029,0x60c911a7,0x68e40915}},	// [d040] nxeu_, لغاء_, inem, rlid
  { {0x290200b6,0xf6290015,0x461a0033,0x442f0125}},	//   _wika_, مسمى_, рцаў_, eag_
  { {0x29020048,0xa2d8005d,0x55660029,0x7cd20024}},	//   _tika_, यवस्, تهاك, pārd
  { {0xbc0d0008,0xd4090029,0x5c37004c,0x6f031524}},	//   ְהוָ, متهم_, ַרצן_, _linc
  { {0x60db0085,0xa3d4000b,0x78a4007c,0x60c9542d}},	//   doum, _सुख_, mkiv, dnem
  { {0x6f030014,0x644b04ed,0x7d040e95,0x4b7b000a}},	//   _ninc, aggi, _liis, יאנו
  { {0xeb9f0134,0x442f043a,0x98b1002a,0xf42a0033}},	//   ncør_, bag_, erzę_, _вобл_
  { {0x22400064,0xc0340001,0x7d040607,0x60c9542e}},	//   şik_, чниј, _niis, gnem
  { {0x78a404ed,0x24530015,0x234b002b,0xbe8a292e}},	//   ikiv, _تنقس, _نسلی_, асне_
  { {0xc243005e,0xa225002b,0x6f0308aa,0x60c9542f}},	//   _онук, _فرمه, _cinc, anem
  { {0x767b000a,0x867b000a,0x78a40044,0x2dd30033}},	//   בטיח, בריו, kkiv, джэр
  { {0x7d0d2f2b,0x3ebe31ec,0x2d9e2f65,0x7f860015}},	//   _čast, sitt_, ryte_, _ولان
  { {0xb4fb01ac,0xfe6f0086,0xe4fb0053,0x6f032f88}},	//   ילטר, ردی_, יפטש, _finc
  { {0x2ca90026,0x49a7000d,0x60c008b1,0x8e770015}},	//   _wlad_, ојба, limm, _ومنذ_
  { {0x644b0084,0x442f00b6,0x59db005d,0x28c7000b}},	//   yggi, yag_, _मुशर, रचलि
  { {0xa3aa005d,0x929d005c,0x6d480509,0x60c004ea}},	//   खना_, _pułk, muda, nimm
  { {0xab280001,0x7c9c000a,0xfcab002b,0x69da52db}},	// [d050] _доња_, _כשהג, _ماکو_, üter
  { {0x442f00b6,0xc9870063,0x7c2d17ce,0x8f8b000a}},	//   wag_, _думи, _hear, יְבֵ
  { {0xd6d80127,0x78ad0af5,0x442f5430,0x7c2d22bc}},	//   іту_, phav, tag_, _kear
  { {0xb4d5005d,0x442f0034,0x6d485431,0x60c0008c}},	//   सके_, uag_, iuda, jimm
  { {0xdfc6003b,0x3869001c,0x60c0008c,0x7c2d3fd8}},	//   _أي_, mear_, dimm, _mear
  { {0x7c2d5432,0x98b8002a,0x6d48001a,0x7ead006f}},	//   _lear, durę_, kuda, _kúpe
  { {0x442f025c,0xd5540063,0x22580015,0x52740015}},	//   pag_, _окръ, تجنب_, بانز
  { {0x7c2d0541,0x6f03114d,0x6d485433,0x20f7000b}},	//   _near, _sinc, duda, ुदेश_
  { {0xddc102d5,0x7d040209,0xea000016,0x60db5434}},	//   telů, _riis, _phẫu_, roum
  { {0x0ea9005f,0xfe420036,0x7d04267f,0x98a3005c}},	//   ской_, нньо, _siis, rsję_
  { {0x7d040e95,0x7c2d0334,0xcc8a002b,0x9f05002b}},	//   _piis, _bear, منده_, _کوتو
  { {0x7c2d5435,0xed56005e,0xdbd7008c,0x9596000a}},	//   _cear, чою_, kääm, לכתו_
  { {0x7c2d002f,0xdd8e0086,0x4bda0010,0x78a40020}},	//   _dear, نوی_, сьня_, vkiv
  { {0x6d480049,0x78bd001a,0xfaa60174,0x442d5436}},	//   buda, _amsv, чаго, _lee_
  { {0xea000023,0x3869002d,0x7c2d0541,0x2bdc000b}},	//   _khẩu_, fear_, _fear, _गुरू_
  { {0x6d3a0008,0x2bf60010,0x442d0150,0x7c2d5437}},	//   _התקנ, _няпр, _nee_, _gear
  { {0x6843008f,0x7cd20024,0xb6a6004a,0x8f19000a}},	// [d060] энта, pārb, пиал, מוּת
  { {0x6b7b00b2,0x27e6005c,0xd7ef0015,0x60c00bae}},	//   _פרינ, żono_, اكك_, zimm
  { {0x7c2d0041,0x6a9b013a,0x186a000d,0x1a9b000f}},	//   _year, _השינ, _лани_, _הייע
  { {0x7e68005c,0x1d160053,0x0d3a004c,0x2a6a0030}},	//   zedp, לקער_, מגעב, lebb_
  { {0x39580024,0x03a30001,0x60c0008c,0xb8f0000b}},	//   ltrs_, ницо, vimm, वच_
  { {0x3f8000df,0xcb130008,0x6d48063e,0x60c001f1}},	//   _šiuo_, עלו_, yuda, wimm
  { {0x39580024,0xba57000a,0x60c05438,0x442d5439}},	//   ntrs_, פסקו_, timm, _fee_
  { {0x442d020a,0x25ae0064,0x98b8005c,0x6d48543a}},	//   _gee_, ıklı_, turę_, vuda
  { {0x60c000f2,0x7c2d543b,0x67360535,0x2a6a01d3}},	//   rimm, _rear, nsyj, kebb_
  { {0x60c0022d,0x442d0111,0x7b0b0024,0xa79b000a}},	//   simm, _zee_, _kļuv, משפח
  { {0x6d480020,0x6288065b,0x7c2d543c,0x7e6803cd}},	//   uuda, _indo, _pear, redp
  { {0x7cff00df,0x629a0107,0x0cab0254,0x6d48543d}},	//   _kūri, _hoto, стои_, ruda
  { {0xfb870010,0x63a2043a,0xd00f0015,0xaffa002b}},	//   чынн, nyon, _إله_, _افشا_
  { {0x7c2d003e,0x3ed40015,0xdd90002b,0x7cff0091}},	//   _wear, _تقتر, _لوت_, _mūri
  { {0x3869185c,0xceb30008,0x7c2d0541,0x0e5b000a}},	//   tear_, _ריצ_, _tear, _הדוב
  { {0xe894008f,0x6abe018b,0x25e0005d,0x2c09002b}},	//   нась, _empf, _कड़ी_, _بعثی_
  { {0x6288000c,0x4c3c0008,0x4cbc0008,0xf1bf002c}},	// [d070] _ondo, _התחב, _לזהו, čšia_
  { {0xcb140053,0x442d0100,0xdbd7008c,0x7cd2003d}},	//   _אלץ_, _see_, rääm, māra
  { {0x38690041,0xdbd7022d,0x54550004,0x7cd2003d}},	//   pear_, sääm, двет, lāra
  { {0x2936015b,0x7cff0091,0xd3710015,0xdbd7008c}},	//   _קארן_, _būri, َها_, pääm
  { {0x69d80293,0x7764006b,0x442d543e,0xa34901f3}},	//   _øver, _пърж, _vee_, ізка_
  { {0xa565002b,0x91e50a5b,0x629a543f,0xfc3f022f}},	//   _يگان, моле, _coto, chív_
  { {0x2419008f,0x63a20035,0xcf8e0086,0x442d5440}},	//   _мовы_, ayon, یژه_, _tee_
  { {0x6aba005d,0x62885441,0xef193a02,0x2a6a0030}},	//   _उग्र, _endo, оми_, zebb_
  { {0x4f320015,0x2d985442,0x7ead2ea8,0x02450015}},	//   نفيذ, ären_, _núpc, _يَرَ
  { {0xddc8138a,0x629a2aef,0x6da5222c,0x0000006a}},	//   cedū, _goto, диоа,
  { {0x8c46071a,0x02440015,0x51840054,0x2a6a0030}},	//   мене, _أَمَ, _пуца, vebb_
  { {0xe3a70086,0x4c830036,0xe45f007c,0xdca60d3c}},	//   نر_, влюв, _ööd_, фами
  { {0x4e950029,0xbbc8000b,0x7052002b,0x2a6a0030}},	//   _يشتر, रपेक, _شنوا, tebb_
  { {0xddc53a02,0x6ffa000a,0x7d0e0125,0x5ffa000a}},	//   _обли, _והנפ, úisí, _והנה
  { {0x63a20064,0x09e309fe,0xdce90061,0x7cc60015}},	//   zyon, ворн, aydı, _يزعم
  { {0x2a6a0014,0xa2bd000b,0xbebd0091,0x394a31aa}},	//   sebb_, वोत्, spūd, rubs_
  { {0xdc8b0008,0xba760015,0x39585443,0x394a5444}},	// [d080] _וְיָ, _قادت, strs_, subs_
  { {0x290c0f14,0x63a2003f,0xcaf60015,0x4438002a}},	//   ídas_, vyon, _تسبب, _śr_
  { {0xd826034e,0x7cff0091,0x629a49c6,0x0000006a}},	//   _одни, _sūri, _roto,
  { {0xcd960008,0x2eaa005d,0x448a006b,0x64a30937}},	//   ודעת_, _छत्त, юбен_, каха
  { {0x41c3014e,0xe3b20029,0xf487002b,0x20110046}},	//   _वेबस, خرا_, ظامی, ězil_
  { {0x7cf61115,0x63a25445,0x0000006a,0x0000006a}},	//   lárd, ryon,   ,
  { {0x66030010,0x63a22bcc,0x629a047e,0x91e30054}},	//   _апра, syon, _voto, коље
  { {0xc953039e,0x55bb000a,0x1f74006b,0x7cff2647}},	//   דמה_, _ומלו, елия, _tūri
  { {0x44265446,0x93460036,0x940b000f,0x4f6a005e}},	//   mbo_, _інже, _וּבֵ, ішим_
  { {0x628800ea,0x139b000a,0x99980091,0x7c26086c}},	//   _undo, _ובמע, ngrų_, ebkr
  { {0x1d340010,0x2f120026,0xfeb700e6,0xfe780091}},	//   эння, _wâg_, بايت_, rdį_
  { {0xe571000a,0x90a60015,0x4bb50248,0xf5370c44}},	//   נַי_, _تحطم, еймс, ונטי_
  { {0xd3660074,0x9be40036,0x78a30011,0x8ae70036}},	//   ده_, вірк, _învi, дівл
  { {0xc3330008,0xe7e2005d,0xfd380015,0x6eef02de}},	//   כוש_, _खड़ा_, _فكتب_, løbn
  { {0x442600b6,0x59c50015,0xe801000b,0x0000006a}},	//   kbo_, ريرك, लेना_,
  { {0x2d58038d,0x7ead0125,0x7cf60030,0xf7950138}},	//   mée_, _iúpa, várg, набэ
  { {0x4426018c,0x2d58038d,0x3cf80029,0x8cdc000b}},	// [d090] dbo_, lée_, _تعود_, नवरो
  { {0x442602d5,0x7c3b002e,0x49755447,0x6d5a5448}},	//   ebo_, ðurf, _злос, otta
  { {0x2d58038d,0x7ea40251,0x25090086,0x7ae5013c}},	//   née_, _còpi, سرای_, _ikht
  { {0x6d5a022d,0xf9fa000a,0x23750015,0x6d0b004f}},	//   itta, _מהתמ, فاتح, קִבַ
  { {0xf8b6000a,0x2d580003,0x58050015,0x62651017}},	//   _נפשי_, hée_, _سوسك, евла
  { {0x7e7800bc,0x61e81827,0x6d5a0804,0x44265449}},	//   _navp, _bydl, ktta, abo_
  { {0xdbfc000b,0x38a7007c,0x15140033,0xfa98000a}},	//   _एण्ड_, _nõrk_, _адся, ודגש_
  { {0x2d580152,0x85050015,0x2aad01c0,0x7fca0065}},	//   dée_, _أورن, ržby_, ापूँ
  { {0x41df005d,0xfe710015,0x8e55008b,0x443f544a}},	//   _पुरस, هدد_, нтні, _idu_
  { {0xf1a70142,0xf772000a,0x9ea9005e,0x2d5801f6}},	//   _орен, נקי_, ївна_, fée_
  { {0x6cc6008f,0x2d580152,0x443f0089,0xfbc9000a}},	//   ейна, gée_, _kdu_, _פת_
  { {0x7fd50010,0x30840015,0xa0a40054,0x7cf600bf}},	//   _пілі, _للمف, _ишчл, káre
  { {0x7655005c,0x0aea0015,0x4b55006b,0x6d5a544b}},	//   _oczy, كرسي_, кърт, atta
  { {0x6ee6002e,0x8f9a039e,0x2d580003,0x1f36000a}},	//   fðbu, _מיני, bée_, _טרנר_
  { {0x2d580152,0x6aa1001a,0x7ead0125,0x2d9801de}},	//   cée_, ölfa, _gúpa, øret_
  { {0x291e0048,0xddc1003d,0x443f2318,0x7afc544c}},	//   īta_, celš, _ndu_, smrt
  { {0x7cd20024,0x7b760015,0x291e003d,0x2b460125}},	// [d0a0] lāro, _أطبا, ūta_, _íoc_
  { {0xfc3f002d,0xddc30057,0x9bb7000a,0x443f544d}},	//   bhís_, _manž, _נהיה_, _adu_
  { {0x3abb0008,0xca570053,0x6c7a0008,0x546a006b}},	//   _זמינ, _אייז_, ּרְד, заем_
  { {0xd91b000a,0x6b84544e,0x443f544f,0x44265450}},	//   _מוטל, _krig, _cdu_, ubo_
  { {0x81bc0024,0x443f0026,0x44265451,0xa5c6002a}},	//   _neēr, _ddu_, rbo_, dnóż
  { {0x2d580152,0x6d5a02ce,0xbb3b004c,0x2aaf0061}},	//   yée_, ytta, לעני, _küba_
  { {0x04460036,0x2d580003,0xa194006b,0x291c0030}},	//   _певн, xée_, тайч, _évad_
  { {0x2d58038d,0x0f260036,0xf993000a,0xea000016}},	//   vée_, ньом, ררה_, _nhậu_
  { {0x68e30251,0xa3460086,0x3f820107,0x4fc60033}},	//   _índe, _سپاه, íku_, эска
  { {0x2d580152,0x61e85452,0x433b004c,0x6d5a0e05}},	//   tée_, _tydl, _מעמב, ttta
  { {0x6d5a022d,0xa00a0029,0xfe6d002b,0x7cf60030}},	//   utta, _فقال_, زگو_, záre
  { {0x2d58038d,0xac190036,0x61e40064,0x40a8002b}},	//   rée_, ьому_, ğild, _تخطی_
  { {0x2d58038d,0xbea60010,0x7b64268e,0x62860091}},	//   sée_, _падк, лтре, _ėkoj
  { {0x8d940029,0x2d580152,0x6b840026,0x2d980293}},	//   _للتش, pée_, _drig, øres_
  { {0x48ab0010,0x62980111,0x59db005d,0x6440066f}},	//   птам_, ijvo, _मुखर, _odmi
  { {0xed570008,0x61e50012,0x6b845453,0xa9780033}},	//   _נבחר_, ühli, _frig, эйсу_
  { {0xf7730086,0xfc640063,0x35d9000b,0xda670015}},	// [d0b0] داز_, _същн, _बुज़, _كادي
  { {0xa7740033,0x3860001a,0x64400c10,0xb8040015}},	//   ылуч, afir_, _admi, ابِه
  { {0x15a80063,0xda480008,0xc50b0015,0x13a7002b}},	//   нъци_, _אֲרָ, ستال_, کنشی_
  { {0x85040029,0x7655002a,0x4974005e,0x6b84039f}},	//   هولن, _wczy, _слюс, _yrig
  { {0x889a011f,0xc8860012,0x66180061,0x68ed5454}},	//   _חברי, ößen_, çakç, mlad
  { {0x7655005c,0xd6e2005c,0x61450010,0x216910a0}},	//   _uczy, _całą_, века, дики_
  { {0x68ed002f,0x823403c4,0xd13100e6,0x71720015}},	//   olad, ارها, جمع_, لهوا
  { {0xb7f5000b,0x6111003d,0xd00e0015,0x68ed5455}},	//   _आराम_, _jāli, يلى_, nlad
  { {0x99910089,0x68ed5456,0x290b5457,0x6d485458}},	//   kazů_, ilad, _mica_, erda
  { {0x290b5459,0x7ec60003,0x6d480034,0x68ed545a}},	//   _lica_, _répè, frda, hlad
  { {0x3860002e,0x68ed1b78,0x4d140b9b,0x0000006a}},	//   yfir_, klad, льят,
  { {0x7db40033,0x7cf60046,0x7f850015,0x80270015}},	//   усьц, dárc, _للصن, _أرام
  { {0x6d48545b,0xeb970404,0x2d980cd8,0x7cf600dc}},	//   arda, вия_, ører_, tárb
  { {0x61e401e2,0xc3320008,0x7dc50015,0xf772002b}},	//   şile, שום_, _لتعك, یاء_
  { {0x6cda00a4,0x68ed545c,0x09e60f5c,0xceb2000a}},	//   _офис_, flad, товн, _דיג_
  { {0x7a3f0064,0x3945001a,0x68ed545d,0xa8550054}},	//   _açtı, álsa_, glad, лтуј
  { {0xd70a0010,0x3860545e,0x290b3f6c,0x37350015}},	// [d0c0] днае_, rfir_, _dica_, ُرْآ
  { {0x68ed4b60,0xeafa0067,0x248d0144,0xfb37000a}},	//   alad, _تربت_, _anem_, _שאיש_
  { {0x200f04ed,0x290b001c,0xb91a0029,0x68ed545f}},	//   _oggi_, _fica_, _تتخذ_, blad
  { {0x25d90086,0x67245460,0x68ed5461,0xb5450015}},	//   رهنگ_, ppij, clad, اخله
  { {0xa8030064,0x68e400f2,0x64a30001,0x248d413b}},	//   şırs, moid, јача, _dnem_
  { {0xe7370124,0x290000f2,0x248d00bd,0x753c0089}},	//   _јер_, lmia_, _enem_, _tvrz
  { {0x244a0029,0x867b000a,0xc2e90015,0x21670054}},	//   _يجري_, _קרלו, رعهم_, вији_
  { {0x2ca0002d,0x89db000a,0x68e45462,0x3faa0054}},	//   _noid_, וחצי, noid, дњом_
  { {0xa0670124,0x7306008f,0x290000f2,0xa857000a}},	//   тања_, _апаз, imia_, דיפה_
  { {0x3c3200a7,0xd3570008,0x68e40020,0x68ed0064}},	//   _được_, _בימי_, hoid, zlad
  { {0xf653000a,0x68e45463,0xa116002b,0x98b20046}},	//   בצת_, koid, _شوشت, ýběr_
  { {0x68e400f2,0x9e030010,0xc157000a,0xbdf70015}},	//   joid, шчыл, _ישבו_, خرًا_
  { {0xe0b700b2,0x99910089,0xa0670054,0x68ed5464}},	//   _בלאט_, tazů_, _јача_, vlad
  { {0x68ed0026,0xadbc0033,0x7c3b001a,0x29005465}},	//   wlad, _налi, ðurb, emia_
  { {0xeef7013a,0x1ea90029,0xada300d0,0x7d780015}},	//   _שמור_, _ثاني_, _вајл, _أمبر_
  { {0x71d70053,0x61d7000a,0x6d5d0045,0x3c470033}},	//   דולד_, דולף_, ăsat, _рэкв
  { {0x57f5249a,0xd7e7005e,0xd7020033,0xf7700015}},	// [d0d0] упат, тіво, пiра, ياك_
  { {0xd51a0023,0xcf930053,0x7d0d0213,0x6935002b}},	//   _bằn, ױטע_, _hias, _مکرر
  { {0xceb300b2,0x7d0d000c,0x7cf60bd7,0xb995002b}},	//   סיע_, _kias, lára, _صلحب
  { {0x78b600df,0xd3f90010,0x24190256,0xf8b1002b}},	//   chyv, нэлі_, ходы_, _اکس_
  { {0x7d0d0050,0xe3b00031,0x9cda004c,0x4cbc000a}},	//   _mias, يره_, עקױפ, וזאו
  { {0x13080036,0x7ead002d,0x78ad5466,0xe1f90cb0}},	//   вній_, _cúpl, lkav, нгл_
  { {0xe5340256,0x2602000b,0x1a9c004c,0x65941ab1}},	//   _весь, वेदी_, ויגע, _кару
  { {0x28c6000b,0xaf99006b,0x22490061,0x78ad5467}},	//   रोपि, етох_, şak_, nkav
  { {0x7cf600dc,0xf1bf0089,0x6267002b,0x7e99002b}},	//   jára, _řád_, _لااق, فنظر_
  { {0x63a4022d,0xe3b00086,0xdb240030,0xce59009a}},	//   äine, _برف_, örít, رشخص_
  { {0x31580029,0x3cca06ac,0x60550225,0x78ad5468}},	//   _لجنة_, елно_, _مناط, kkav
  { {0xa03900b2,0x7d0d5469,0xc5f2000a,0x61e50012}},	//   _װײַז, _cias, מדי_, ühlu
  { {0x68e4151a,0x6ee6001a,0x3a38003d,0x60c9546a}},	//   void, rðbr, tarp_, miem
  { {0x9af60029,0x7f3a000a,0xd51a0016,0x60c9546b}},	//   اكست, _טענו, _lắn, liem
  { {0x39160086,0x1a660086,0xa9670c96,0x60c90045}},	//   اورز, نیکی_, лира_, oiem
  { {0xd51a0023,0x4c360033,0xad88000a,0x60c9546c}},	//   _rằn, _сэкт, _יְפֻ, niem
  { {0x98350010,0x38cb002b,0x88350033,0xb8dc000b}},	// [d0e0] рэсі, رافی_, рэсц, _अत_
  { {0xd702008f,0x7c36002e,0x78b6008c,0x68e4546d}},	//   пiса, _heyr, shyv, soid
  { {0x7c360084,0xda5b000f,0x75d30015,0x60c9546e}},	//   _keyr, _אכיל, ميكا, kiem
  { {0xe424002b,0xd4f50033,0x60c92b0f,0xe660007f}},	//   شکري, аячы, jiem, ğrış
  { {0x13940036,0xebd60008,0x82a64fba,0x33940033}},	//   рилю, נֵ֣י_, ладж, ралё
  { {0x38b506f5,0x261a000b,0xbb77000a,0x2d87546f}},	//   _våre_, मुखी_, טענו_, _orne_
  { {0x5578000a,0xd578039e,0x60c90046,0x7229005e}},	//   _בְּד, _בָּר, fiem, тців_
  { {0x89370053,0x3f860251,0xd51a0092,0x89e9000a}},	//   ארקע_, _prou_, _gắn, כַפֵ
  { {0xdfd00029,0x46a8000b,0x04570015,0xf2560015}},	//   تية_, _गवाह, _حلقة_, _مضاد
  { {0x7cf6002c,0x78ad0024,0x3f8600dd,0x33d5005e}},	//   vára, zkav, _vrou_, _тіст
  { {0x2d87016f,0x7d0d5470,0x0697000a,0x98b1002a}},	//   _crne_, _pias, אדים_, lszą_
  { {0x7cf600dc,0xc19b0008,0x10160015,0x60c95471}},	//   tára, _רשאי, _إباد, ciem
  { {0x6e940036,0x2d870134,0x7c360026,0xd0f7000a}},	//   _вилу, _erne_, _deyr, _עמדת_
  { {0xdb2400dc,0xbda60087,0x6d5d0045,0x5b1402d9}},	//   ásáb, _محبو, ăsar, смрт
  { {0x7cf65472,0x6e3a06cd,0x78ad154d,0xce37000a}},	//   márn, matb, tkav, _גאות_
  { {0x6e3a316b,0x7cf60107,0x01fb000a,0x5c74006b}},	//   latb, lárn, תפלל, _глът
  { {0x98b1005c,0x9475002b,0xd794006b,0xddda0030}},	// [d0f0] jszą_, یگرا, битъ, mető
  { {0x60c9005c,0xba190029,0xca730086,0xddda00dc}},	//   ziem, _جيدا_, _اندک, lető
  { {0x7ae7016f,0x600b0061,0x7cfd0030,0xd70200e2}},	//   mojt, _kömü, gérg, пiта
  { {0xe4e400fd,0xdd57004c,0x47d5006e,0x52dd0065}},	//   бічн, רבאט_, _نيجر, यव्स
  { {0x883a0447,0x7cf60227,0xa856000a,0x58d5002b}},	//   _בתרו, kárn, _דירה_, _ميگذ
  { {0x46b9014e,0xddda0014,0x57d4000d,0x38a70020}},	//   _इतिह, hető, _ѓорѓ, _võru_
  { {0x60c95473,0x98b1002a,0x746b0361,0x7cf60247}},	//   tiem, aszą_, _прав_, dárn
  { {0x6e3a0024,0xe1f00015,0x99830091,0xdb0a006f}},	//   eatb, أسه_, lajų_, ľném
  { {0xddda00dc,0xc87f00b8,0x2295002b,0x60c95474}},	//   dető, _maß_, _پلاس, riem
  { {0x0ea90080,0x60c95475,0x5db50015,0x7c360061}},	//   ткой_, siem, لإجر, _seyr
  { {0xcc8a0086,0x7cd20024,0x60c90024,0xbca60029}},	//   ننده_, lāri, piem, لمدي
  { {0x1607005d,0x2d8700bd,0xfce61f67,0x6cd30015}},	//   वेयर_, _vrne_, ромо, ْقَا
  { {0x7cc40014,0x7cd2003d,0x5f16000b,0x7ae70030}},	//   nőri, nāri, नदण्_, fojt
  { {0xceb8005c,0x6eef02de,0x7cf616ee,0xab2738b6}},	//   chę_, købi, cárn, рора_
  { {0x7c360026,0xa9060015,0x2d875476,0x4e8a004f}},	//   _teyr, لبرن, _urne_, _שָׂ֣
  { {0xf1b201ac,0x645b002d,0x2711000b,0x600b0061}},	//   קסן_, _ncui, ़दूर_, _gömü
  { {0xc87f018b,0x7cf6002c,0xf0920008,0x87250015}},	// [d100] _daß_, láro, חנן_, معلم
  { {0x8b3b000a,0xabfb000a,0x064a0015,0xda660e91}},	//   _שתיצ, _בהפר, ئلاً_, _твои
  { {0x7cf60057,0x98b1002a,0xc5d50033,0x0000006a}},	//   náro, wszą_, біць,
  { {0x6e3a00dc,0x63ab02de,0x7cf60307,0x89db000a}},	//   zatb, fygn, zárn, _יחיי
  { {0xf7460124,0x9377003b,0x43760080,0xe29a0001}},	//   _њего, لصور_, рует, кад_
  { {0xddda00dc,0x66f9005d,0x7cfd3959,0xab5b0012}},	//   zető, ्गणक_, mére, szüg
  { {0x90440029,0x74560063,0x7cf601b2,0x7cfd0003}},	//   منغه, _възх, várn, lére
  { {0x645b002f,0x757b0008,0x63ab0bfa,0x98b1002a}},	//   _gcui, _בטלפ, bygn, pszą_
  { {0x7cfd0152,0x6e3a003c,0xddda00dc,0x2602005d}},	//   nére, tatb, vető, वेरी_
  { {0x600b0061,0x6e8a0054,0x1be1000b,0xfe6f0015}},	//   _sömü, тљив_, _गुगल_, ودٍ_
  { {0xd6570008,0xdfd00086,0x7cfd1f0d,0x7cf65477}},	//   סיטת_, تيک_, hére, gáro
  { {0x557700b2,0x6e3a0024,0x7cf602e6,0xd12f0015}},	//   בעטן_, satb, sárn, _آمن_
  { {0x00bb0008,0x141b000a,0x6fb30015,0xb09b000a}},	//   _במאמ, כוכב, _ومما, _שידר
  { {0x6b4c002e,0x7cfd2c80,0xd00b000a,0x99d70015}},	//   _sögð, dére, _בּוֹ, لتزا
  { {0xe8950080,0x63ab005c,0x38c701b7,0x09f90015}},	//   бавь, zygn, ащав, افأة_
  { {0x7cfd038d,0x290f17df,0x9ccb0033,0x48153aca}},	//   fére, öga_, _шыла_, смас
  { {0xd8380010,0x28c6000b,0xf7730021,0x69de0490}},	// [d110] рэс_, रोधि, غار_, _expe
  { {0xf770002b,0x6ac40015,0xfaa40054,0x7cd2003d}},	//   باف_, _وقيم, _мањо, vāri
  { {0x64150029,0xaadc000a,0x29840033,0x8aa40033}},	//   مواط, _בחזר, _дыяг, _фрыд
  { {0x9d1b004c,0x7cd2003d,0x99830091,0xad1b000a}},	//   דואט, tāri, sajų_, דואר
  { {0xdb06002a,0x7cf60030,0xe28e5478,0xdc6c004f}},	//   czkó, záro, па_, ד֣וֹ
  { {0x93940015,0x72c4005e,0x7c3d5479,0x65952c19}},	//   تجما, обіз, hasr, _лагу
  { {0xc6920053,0x7cd2003d,0x63ab002a,0xab5b0012}},	//   _צאל_, sāri, sygn, nzüb
  { {0x7cf600dc,0xd0590033,0x7cd2003d,0xb938004f}},	//   váro, уркі_, pāri, בנהו_
  { {0xb4e3005d,0x93b50001,0xd25b0004,0xea000016}},	//   नकी_, _убац, _аце_, _thầu_
  { {0x7cf60014,0xe8e00023,0x7c3b002e,0x66f9005d}},	//   táro, _đọc_, ðurn, ्गिक_
  { {0xd011003b,0x7d0a0001,0xea000016,0x7cfd0030}},	//   _فلا_, лног_, _khấu_, zére
  { {0xe2a6002e,0x98b30089,0x443d1880,0x6281547a}},	//   _öðru_, ědět_, naw_, _halo
  { {0xee2e0010,0x7cf60eed,0x547a004c,0x62835265}},	//   _нн_, sáro, נטשו, odno
  { {0xed5902bf,0x539a000a,0x7ff40015,0x7cfd3e66}},	//   _бок_, אישו, _بسما, vére
  { {0xc2120008,0x443d4894,0x2d980b1f,0x6281547b}},	//   להם_, kaw_, äret_, _malo
  { {0x62810035,0x50190053,0x7cfd1f0d,0xadf6000b}},	//   _lalo, רוּו, tére, ीधरन_
  { {0xcc57000a,0x98a303fa,0x443d108d,0x6e2e0030}},	// [d120] _הספק_, чите, daw_, űbbe
  { {0x38b501d1,0x62810198,0xfbd3000a,0xccf90046}},	//   _våra_, _nalo, _מתח_, htěl_
  { {0x9986003b,0x2e3a0053,0xc7a90053,0xbbe9002b}},	//   _الجو, רגענ, עב_, _مریم_
  { {0x7cfd1649,0x99980089,0x443d0035,0x6d41547c}},	//   mérc, larů_, gaw_, isla
  { {0xe4e90015,0x7cf60b31,0x672600cb,0x6281547d}},	//   جعله_, járm, _utkj, _balo
  { {0x6d410f3b,0xfe670015,0x62810fda,0x248006db}},	//   ksla, _عد_, _calo, žim_
  { {0x7cd20024,0x443d4894,0xd12f0d9b,0x91860015}},	//   lāru, baw_, ях_, إجتم
  { {0x3969000a,0x93160015,0x94d60015,0x61e413cc}},	//   ׁבוּ_, _هورش, _ايرش, şilo
  { {0x59cf000b,0x925a0015,0x6d41547e,0x62813a54}},	//   _हेनर, _مشار_, esla, _falo
  { {0x7cf600dc,0x877b0053,0xd36f0002,0x3243239c}},	//   sárl, נאיי, _سهم_, _неуг
  { {0xdc990036,0x7c2902c1,0x1df80080,0x7cfd0533}},	//   авні_, ñero, рены_, jérc
  { {0x4f660029,0x62813414,0x6f190034,0x78a600aa}},	//   _هاتف, _zalo, _fuwc, _nokv
  { {0x61110048,0xd00f0015,0x6ff6002b,0x26ca07cb}},	//   _tālr, _كلم_, _اساط, _ombo_
  { {0xcd330086,0x28c60065,0x2d984b76,0x0000006a}},	//   _کروب, रोसि, äres_,
  { {0x443d0035,0x52d7000a,0x61ed0061,0x291a15d0}},	//   yaw_, צולע_, ğalg, _cupa_
  { {0x4735008f,0x291a0011,0x26ca0863,0xddc30034}},	//   жнас, _dupa_, _ambo_, _canŵ
  { {0x7bda01e2,0xfc3f002d,0x28f8004a,0xd794006b}},	// [d130] ştur, maí_, сеть_, питъ
  { {0xfc3f002f,0xcb38000a,0xe6950015,0xc7c400ce}},	//   laí_, _הנזק_, غلاد, їсти
  { {0x7c240084,0x28c6005d,0x7cf600dc,0x443d3e1b}},	//   _yfir, रोहि, zárm, taw_
  { {0xfc3f002f,0xb4e3005d,0x6b8d547f,0x93f5005e}},	//   naí_, नके_, _krag, опец
  { {0x20d30011,0xd6db006b,0x443d1a0b,0x7cd2003d}},	//   nţie_, _бтв_, raw_, pārv
  { {0xfc3f017e,0x3869024b,0x672d0085,0x2b44006f}},	//   haí_, lfar_, mpaj, ámci_
  { {0x3869002d,0x4a5c00a3,0xea000016,0x62835480}},	//   ofar_, אדוו, _thấu_, rdno
  { {0x3869002d,0x6b8d5481,0xc9b80643,0x7c3b001a}},	//   nfar_, _orag, מהות_, ðurl
  { {0xdbf20089,0xfc3f002d,0xef160256,0x62815482}},	//   _přír, daí_, омы_, _talo
  { {0x82340074,0x7535004c,0xb77c004c,0x6d415483}},	//   _فرما, ֿאָד_, ראזש, tsla
  { {0x7cd20048,0x6d4100df,0xf6520008,0xfc3f002d}},	//   kārt, usla, וצי_, faí_
  { {0xd00e0086,0xca29039e,0x7188000a,0x25be007c}},	//   علی_, _ים_, _לְנַ, _ütle_
  { {0x2d980c77,0x547a000a,0xdbf20046,0x6b8d04a9}},	//   ärer_, בטרו, _třír, _crag
  { {0x6b8d5484,0x6d415485,0x9f050058,0x6d460073}},	//   _drag, psla, _بوتو, ąkar
  { {0xed595486,0x78a60844,0xa3d5000b,0x20d30045}},	//   _той_, _pokv, ाऊँ_, aţie_
  { {0xd9290010,0x6449002d,0x3869002d,0xb4e3005d}},	//   сцёл_, _ndei, gfar_, नको_
  { {0x20d304f9,0x3ea7005c,0x3787005e,0x7c650015}},	// [d140] cţie_, _kont_, обто_, _رايل
  { {0x64490176,0x7cfd0152,0x291a003f,0x61273d05}},	//   _adei, méra, _tupa_, _kıld
  { {0x6eef0134,0x7cfd0003,0x186a0923,0x3ea75487}},	//   løbs, léra, _кани_, _mont_
  { {0x39585488,0x3869002d,0x28c6000b,0x99fb000a}},	//   murs_, cfar_, रोशि, _כפיפ
  { {0x7cfd038d,0xf4870086,0x64490026,0x6d47006f}},	//   néra, تالی, _ddei, ájaj
  { {0x68f60026,0x26ca003f,0xe73705e6,0x395819b0}},	//   llyd, _umbo_, _фер_, ours_
  { {0x1a9b0053,0x307a0015,0xdb1d0030,0x68f60034}},	//   ייסע, لحظة_, rzsé, olyd
  { {0xddd804af,0xc4c50015,0x6f6a0004,0xdb1d0030}},	//   _navš, _فتقو, ајов_, szsé
  { {0x629e022d,0x4fd40080,0x3ea70026,0x1eaa0029}},	//   öpos, яжит, _bont_, لادي_
  { {0x3ea704f9,0x7cfd0152,0xf3c90086,0xd37b000a}},	//   _cont_, déra, _طبقه_, _דרמט
  { {0xfc3f017e,0x3ea7038d,0xac190036,0xdd940010}},	//   taí_, _dont_, йону_, чаны
  { {0xe57100b2,0x7cfd0003,0x24865489,0x39580b43}},	//   ײַט_, féra, ndom_, durs_
  { {0x39580152,0x68f60026,0xfc3f002d,0x2bc5021e}},	//   eurs_, dlyd, raí_, _लेखा
  { {0xfc3f002f,0x6b8d0298,0x20d30045,0x2484316f}},	//   saí_, _vrag, rţie_, _lamm_
  { {0xfc3f002f,0xcd330029,0xca140063,0xa8a70fbd}},	//   paí_, _قريب, ддръ, орак
  { {0x7cfd0152,0xe8940010,0x20d30011,0x9c390001}},	//   béra, мась, pţie_, _упит_
  { {0xec380008,0x907b000a,0x3869548a,0x63a4008c}},	// [d150] _ואחר_, סטמי, rfar_, äinl
  { {0xe801005d,0x61270064,0x3869002d,0x248608b8}},	//   लेगा_, _yıld, sfar_, edom_
  { {0x7cd20024,0xe5f50015,0x395803fe,0xda7a000a}},	//   pārt, أكاد, curs_, _הנתר
  { {0x24580010,0xa97a0053,0x4ddb000a,0xa879004c}},	//   жаць_, _פארכ, סחאו, _פאָר
  { {0x889a013a,0x24180036,0x2909008c,0x7ead006f}},	//   _הברי, цією_, mmaa_, _kúpt
  { {0x290900f2,0x68ed548b,0x42c8005e,0x2ca92345}},	//   lmaa_, load, огін_, _load_
  { {0x3abc000a,0xe4530015,0x2909008c,0x947700c3}},	//   שמונ, _يضر_, omaa_, _ودرا
  { {0x3ea7038d,0x38bc002d,0xbf59005e,0x29090601}},	//   _sont_, _tíre_, брої_, nmaa_
  { {0xff510015,0x2909008c,0xc4d2000a,0x2d9e30fa}},	//   رخة_, imaa_, _נגמ_, exte_
  { {0x92b70074,0x7cf6001c,0x32550004,0x67bc000a}},	//   _بحرا, mári, _ѕвер, ימחק
  { {0xf6520053,0x3ea74701,0x7cf63ade,0xaea800c3}},	//   עצט_, _vont_, lári, تطيل_
  { {0x01fa0008,0x7cfd0152,0x7cff0007,0x2a7800b8}},	//   _הפעל, téra, _kūry, werb_
  { {0x7cf62122,0x03d5000a,0xce95006b,0x68ed0034}},	//   nári, לוֹם_, _надъ, doad
  { {0x6ec40029,0x1e840036,0xdd010024,0x3b0a004a}},	//   _يتوق, _олім, ītāj, сего_
  { {0xda790010,0x1d0a006b,0x7cfd435c,0x5e9a000a}},	//   цяў_, _леки_, séra, _לבסק
  { {0x7cfd548c,0xe8fa0010,0xc72609ef,0xbd280015}},	//   péra, ёла_, здай, _بأول_
  { {0x47c60033,0x3958548d,0x60db4a04,0xab5b06cd}},	// [d160] чбав, surs_, inum, lzün
  { {0x7cd20024,0x461a0010,0x2484007c,0x7cf6548e}},	//   pārs, сцаў_, _samm_, dári
  { {0xda0a0086,0x3a37000a,0xca37000a,0xe9d2002b}},	//   _ديده_, _מרים_, _מניה_, _سغد_
  { {0x0457003b,0xa3a50046,0x7cff0091,0x29d30015}},	//   كلمة_, lářů_, _būry, _سيُس
  { {0x33f6003b,0xd138005c,0x7d04002d,0x7cf6548f}},	//   أساس, _swą_, _mhis, gári
  { {0x66c001d1,0x78a401a3,0xd7fb000a,0x24865490}},	//   _sökf, ljiv, _להכל, sdom_
  { {0x7c3b002e,0x386b002d,0x9fb50046,0x24840d48}},	//   ðurk, _éirí_, _dřív_, _tamm_
  { {0x78a4016f,0x5f94017a,0xb4250040,0x60db5491}},	//   njiv, диит, _يعقو, gnum
  { {0x442608db,0x289b0135,0x2ca9347e,0x7cf609ae}},	//   mco_, מיקא, _road_, cári
  { {0x7d0404f6,0x64420125,0xa3a50046,0x63bd007c}},	//   _ahis, laoi, jářů_, _üsna
  { {0xb5820010,0x828b000a,0x44265492,0xc04f008b}},	//   днiк, _לְאֶ, oco_, _пі_
  { {0x44261139,0x64420573,0x1bd5006b,0xc19b000a}},	//   nco_, naoi, домя, _לשבי
  { {0xaf070086,0x68ed001c,0x68e35493,0x78a40085}},	//   تقیم_, voad, _índi, djiv
  { {0x64420125,0x0fc3006b,0xb2e7000a,0xbea32fa0}},	//   haoi, _яйчн, ּ֥ךְ_, _пачк
  { {0x09940004,0x2ca95494,0x68ed5495,0x199407d0}},	//   нарџ, _toad_, toad, наря
  { {0x9ddb0008,0xe8b50064,0x7cfd4701,0xfdf7000a}},	//   _לקוח, _dışı, méro, _מצות_
  { {0x20d30011,0x6d5a5496,0x97150033,0x5719005e}},	// [d170] nţia_, luta, дмац, іжжя_
  { {0x6d5a003f,0x29090e95,0xaa590015,0xb6f40054}},	//   outa, smaa_, _بلدا_, езуј
  { {0xf5790115,0x7cfd1112,0x6d5a5497,0x60db0012}},	//   تماع_, néro, nuta, ynum
  { {0x7cf65498,0x04b40010,0x7c3b002e,0x6d5a1732}},	//   tári, нсія, ðurh, iuta
  { {0xd7e4005e,0xc324005e,0x6d5a5499,0x0324005e}},	//   _зіро, емік, huta, едін
  { {0xdb060014,0x7cf6549a,0x179a000a,0xf79a000a}},	//   szkö, rári, _וישב, _ובשמ
  { {0x7cf6549b,0x6d5a549c,0xc692000a,0x10a503fc}},	//   sári, juta, _באם_, дийн
  { {0xf94a0053,0x4426549d,0x6d5a3591,0x25e6000b}},	//   קעפֿ, cco_, duta, _जुटी_
  { {0x7cfd00dc,0x60db549e,0x6d5a01c2,0xaf0508ad}},	//   térn, rnum, euta, мпил
  { {0x6d5a0f4d,0x443f08e0,0x38bc0089,0xab5b0012}},	//   futa, _heu_, _míra_, tzün
  { {0x20d30011,0x7db402bf,0x41b50015,0x77ec000b}},	//   aţia_, есяц, _تمار, _फ़र्क_
  { {0xdfce0074,0x443f0152,0xc1040015,0x3f8f02d8}},	//   ايی_, _jeu_, _كولي, _trgu_
  { {0x20d30011,0xab5b00dc,0x3f830024,0x2ab4007c}},	//   cţia_, szün, ājus_, _häbi_
  { {0x66c03c8f,0x7d04549f,0x442654a0,0x6d5a1f85}},	//   _köke, _whis, zco_, buta
  { {0x6d5500dc,0x3f8d001c,0xd946004a,0x7aee006f}},	//   ázad, lveu_, ьеви, robt
  { {0x443f54a1,0x38c80086,0xe8fa078f,0x6aa1002e}},	//   _neu_, سازی_, іла_, ölfr
  { {0x2ab40005,0x26d3001c,0x7c850054,0x61e40061}},	// [d180] _läbi_, fixo_, _чује, ğili
  { {0x61e40064,0x257e0089,0x5b57000a,0x05ba0021}},	//   şili, _půl_, _קייב_, يدات_
  { {0xd5b20029,0x3945002e,0xba9b000a,0x6a9b000a}},	//   خفض_, álst_, _וסיי, _ושינ
  { {0x66c00123,0x69da0003,0x26d3016e,0xb3290016}},	//   _sökd, ûteu, aixo_, _ảrập_
  { {0xda0a0086,0x7c3b002e,0x937a00a2,0x64421b35}},	//   _ديگه_, ðuri, تصار_, raoi
  { {0x7bc600bd,0x443f00dd,0x3860002e,0xd1300021}},	//   izku, _eeu_, lgir_, همت_
  { {0x443f357f,0xa1270029,0xdc300007,0xd2950033}},	//   _feu_, وكول_, _užėm, эрць
  { {0x6d5a0005,0x6b84016f,0x24530029,0xa989000a}},	//   vuta, _osig, _لنفس, לָפִ
  { {0x4fc6065e,0x27240030,0x69d80091,0x6440006f}},	//   ьска, _jön_, _žvel, _iemi
  { {0xad660029,0x7cfd0003,0x7ead006f,0x20d30045}},	//   واجه, téro, _súpr, rţia_
  { {0x6b8454a2,0x867b0008,0x26570053,0x52d70008}},	//   _asig, חריו, וסיש_, _קובע_
  { {0xe57100b2,0x40930029,0x20d30011,0x3f8d0085}},	//   אַך_, _للمر, pţia_, bveu_
  { {0x6d5a1c23,0x764e1332,0x6440013c,0x4fb60015}},	//   suta, _odby, _memi, _تصار
  { {0x20d30011,0x7cfd0152,0x6ffb000a,0xdd900021}},	//   nţin_, péro, _והדפ, _موت_
  { {0xaf07003b,0x61270064,0x5e430029,0x6b8404ed}},	//   _تقوم_, _kıla, _شَيْ, _esig
  { {0x3860002e,0xceb81256,0x3eae003d,0x27240123}},	//   ggir_, lkę_, žotā_, _bön_
  { {0xa6350036,0x6d4801f0,0xe7190015,0x4c3c000a}},	// [d190] ензі, lsda, سيات_, _ותחב
  { {0x443f54a3,0x27240064,0x7cfd00dc,0xceb810da}},	//   _seu_, _dön_, zérl, nkę_
  { {0x628a0176,0x443f0277,0xdd120061,0x64402322}},	//   ddfo, _peu_, nüşl, _bemi
  { {0x8505002b,0x44290016,0x6d4854a4,0xe534005e}},	//   روشن, ùa_, isda, тець
  { {0x66c000c0,0xd7e70036,0xdfc60029,0x443f18b3}},	//   _söke, _ціно, _إي_, _veu_
  { {0x2919003f,0xf8bf002e,0xa294005e,0xceb8002a}},	//   _hisa_, _hlé_, качі, jkę_
  { {0x443f0ae9,0x628854a5,0xceb8005c,0x644054a6}},	//   _teu_, _dado, dkę_, _femi
  { {0x764500d9,0x629a54a7,0x64402c9c,0xceb8002a}},	//   lahy, _ento, _gemi, ekę_
  { {0xcf580010,0x6d4a01a7,0x2d98156a,0xb27502b0}},	//   мрэч_, _avfa, åren_, _плаш
  { {0x7cfd00dc,0x7ce80064,0x0f320086,0x291954a8}},	//   sérl, zırd, اکند, _lisa_
  { {0xab5b0014,0x3f82002e,0xb0350484,0x8d7500e6}},	//   szül, ækur_, _знеш, رادا
  { {0x6b8400dd,0xe3a70087,0x7cf60030,0x62881367}},	//   _psig, هر_, járt, _zado
  { {0x2bba0029,0x00c80033,0xfbd20015,0xceb8002a}},	//   ساحة_, _ўлік_, اتج_, bkę_
  { {0xc33201e4,0x6d480134,0x7fd6000a,0x1ee7009a}},	//   רום_, bsda, _אונס_, _توتی_
  { {0x291900e8,0x7ce80064,0x7bc60fce,0xf8bf0003}},	//   _bisa_, tırd, szku, _blé_
  { {0xad1a0053,0xf8bf1939,0xadd6000a,0x7cfd0030}},	//   _צופר, _clé_, _רוקח_, hérj
  { {0x27e60152,0x38600130,0x64402ebb,0x7f491b65}},	// [d1a0] çon_, rgir_, _remi, nseq
  { {0x66c000c0,0xf8bf00dc,0x6440180b,0x6ef40144}},	//   _sökb, _elé_, _semi, làbr
  { {0x24970086,0x64400d25,0x3860003c,0x05760015}},	//   کنند_, _pemi, pgir_, عائد
  { {0x44f6002b,0xceb8002a,0xd40600f4,0x934645fb}},	//   رساز, zkę_, няли, енде
  { {0x7cf6002c,0x628854a9,0xceb81256,0x9cd7000a}},	//   lárs, _pado, ykę_, עונה_
  { {0x764e0134,0x20d30045,0x93b30033,0xf8bf0069}},	//   _udby, uţin_, ыбіц, _zlé_
  { {0x66e30fba,0x628818a6,0x20d30011,0x8707005e}},	//   _сора, _vado, rţin_, _черв_
  { {0xd5b9008f,0xc9530008,0xceb8005c,0x62880fcd}},	//   _ўсё_, אמה_, wkę_, _wado
  { {0xceb8005c,0xdfd00087,0x628854aa,0x93aa012c}},	//   tkę_, شيد_, _tado, _عارف_
  { {0x7cf61a4b,0xc7b3000a,0xdf73002b,0x6d4854ab}},	//   kárs, טבח_, اديب, tsda
  { {0xceb8005c,0x6d480007,0x7cf654ac,0x752900bd}},	//   rkę_, usda, járs, _čezk
  { {0x27e6005c,0x7cf6002c,0xdd120064,0x7f491e0f}},	//   żony_, dárs, rüşl, bseq
  { {0x2ab4007c,0xceb8002a,0x6d481daf,0x4fb30021}},	//   _läbu_, pkę_, ssda, _مصور
  { {0x6d48003c,0x8f9b00a3,0x29190049,0xf3f1000a}},	//   psda, _מידי, _sisa_, ׁ֣ם_
  { {0xa2b3005d,0xf8bf002d,0x090701c5,0x291954ad}},	//   _अवस्, _plé_, ечам, _pisa_
  { {0x8dfb000a,0xc19b000a,0x4dfb000a,0x3dfb000a}},	//   _מהות, השלי, _מפוא, _מלוד
  { {0x3f860089,0x291954ae,0x56f50004,0x291e001a}},	// [d1b0] _jsou_, _visa_, впаѓ, ítar_
  { {0x659514f4,0x35e7006d,0x98140015,0x7cf607f4}},	//   казу, нцев, طبقا, bárs
  { {0x96b80015,0x7cf610e5,0x764554af,0x7c2d01f9}},	//   راكز_, párt, rahy, _kfar
  { {0x53350923,0x95540040,0x7cf60030,0x3eae0898}},	//   ведт, اخلا, lárr, _loft_
  { {0x45180086,0x7cfd00dc,0x80a4000b,0x1c2c000a}},	//   رآمد_, eérk, काने, הֽוּ
  { {0xf7d6000a,0xbb3c000a,0xc7d6000a,0xf2c70033}},	//   _יורש_, לעדי, _יורי_, эсен
  { {0x7cfd00dc,0x2b4d0089,0x88cb000a,0x0000006a}},	//   gérk, šech_, ּמִ֖,
  { {0x23d2000b,0xa99c000a,0x7124009a,0x3f5102ed}},	//   _देवद, לבור, درول, ади́
  { {0x24800020,0xb0f60015,0x7cf60030,0x4f091377}},	//   õime_, خفيض_, zárs, мнин_
  { {0xf7720008,0x7cfd00dc,0x7c2d332f,0xe2930021}},	//   סקי_, lérh, _afar, _حذر_
  { {0xc6920008,0x69d1000b,0x7f4954b0,0x0000006a}},	//   באי_, _डेली, sseq,
  { {0x90450015,0x22474467,0x7f750c7c,0xd0d900ce}},	//   _شنته, lank_, _аукц, _юдеї_
  { {0x30d800b2,0x3b83008f,0x5e950015,0x8e8554b1}},	//   _אַװע, аляг, _للإط, _агле
  { {0x7cf61754,0xc004008b,0x2d950bc0,0x0000006a}},	//   társ, _спік, _арис,
  { {0x7c2d0026,0xaa43006d,0xdb1d0030,0xf2d205bd}},	//   _ffar, ресл, rzsá, בעם_
  { {0x224700c7,0xdb1d0030,0x442d0034,0x7cf619ed}},	//   hank_, szsá, _nfe_, rárs
  { {0xf7460432,0x7cf6006f,0x7cfd0030,0x16663770}},	// [d1c0] тезо, sárs, zérk, квам
  { {0x39a4005e,0xc7af0015,0xb5da0015,0xa92619cc}},	//   _блоґ, غّل_, وباء_, _идол
  { {0xdb1d00dc,0x546a02bf,0x0446006b,0x7abb000a}},	//   özöt, даем_, веен, _חציו
  { {0xa3bd000b,0x24530015,0x6b9654b2,0x0000006a}},	//   ँईं_, لنمس, _kryg,
  { {0xdb0f0089,0xa2b3000b,0x61ed0061,0xe3630d3e}},	//   zycí, _अवश्, şall, икци
  { {0x62630124,0xe6120015,0x7cfd0307,0x61fa0046}},	//   авља, _نشأ_, térk, _pytl
  { {0xe2970cb9,0x11d80015,0xa2b3000b,0x51861cf3}},	//   тај_, عوبة_, _अवर्, тула
  { {0x6b96005c,0x660300dc,0x61fa01c9,0x3eae54b3}},	//   _oryg, ünke, _vytl, _soft_
  { {0xd3f40010,0x1fa30033,0xb355002b,0x8003004a}},	//   _лiст, арэг, _مینا_, ичье
  { {0x38b50123,0x66c0008c,0x1e340033,0x7cfd54b4}},	//   _hårt_, _yöka, ыноў, méri
  { {0x61e40064,0x865b0008,0x7c2d00b8,0x7cfd54b5}},	//   ğils, ודיי, _pfar, léri
  { {0xc5f30008,0xcb350063,0x5c74017d,0xcb1e000b}},	//   ידת_, лемъ, алют, पदंड_
  { {0x7cf600dc,0x9f53005e,0x3f86016e,0xde58017f}},	//   tárr, _ввіч, _usou_, _залі_
  { {0xf413000a,0x6b9654b6,0x501b004f,0x7cfd01d3}},	//   יפר_, _dryg, _חודו, zérh
  { {0x7c3b0084,0xddc8005c,0xb92500a2,0xc3480092}},	//   ðurs, nedż, افري, hổ_
  { {0x38720026,0x7c2d003f,0x6b9654b7,0x629c001a}},	//   gfyr_, _ufar, _fryg, _órof
  { {0x66c000c0,0x28f8004a,0x57790033,0xc66b004a}},	// [d1d0] _söka, теть_, эбаў_, дшее_
  { {0xe3b30086,0x60c20144,0xdb9a000a,0x29240125}},	//   یرش_, _llom, _נסתר, úsaí_
  { {0x1a9a0053,0x7cfd00dc,0x7af50089,0x60c22f0e}},	//   _װירע, térh, mozt, _olom
  { {0x6d5a05d8,0x7cfd54b8,0x5dd9004c,0xa3ac0046}},	//   irta, féri, ײַעס, léřů_
  { {0x42d5022a,0x6d5a0012,0x785e0045,0x7cfd3d28}},	//   ліку, hrta, săvâ, géri
  { {0x16340080,0xf990002b,0x36d52566,0x91e501e1}},	//   _веря, _ابی_, _согр, лоле
  { {0xfa7801c8,0xd1480086,0xd24e0015,0x6625003d}},	//   דעות_, نشين_, سني_, ārkā
  { {0x7af500dc,0x25c50061,0x7cfd54b9,0x1f6502db}},	//   hozt, ıslı_, béri, гким
  { {0x63a400f2,0x7af500dc,0x22470020,0xc4d2000a}},	//   äint, kozt, pank_, _הגן_
  { {0x52740074,0x61270064,0x9756000a,0xc7b2000a}},	//   _نامز, _yıll, ניתו_, צבי_
  { {0x8db50036,0xc692000a,0x61270061,0xddc80046}},	//   успі, זאי_, _kılm, nadň
  { {0xadb60015,0x7cd2003d,0x60c254ba,0xbca5009a}},	//   اهَا_, lārz, _glom, لمپي
  { {0xa2b9014e,0x2024032c,0xeb970f13,0xfc4702c1}},	//   ्सप्, ásiť_, гия_, ñías_
  { {0x7cc40014,0x6b9600dd,0x8f52002b,0x7af50030}},	//   nőrz, _vryg, _انوش, gozt
  { {0x8d840086,0xb9b50063,0x5d79004c,0x2d870085}},	//   _نشين, астъ, _טאַק, _usne_
  { {0x6b9654bb,0xbc660608,0x4dfa004c,0x0000006a}},	//   _tryg, _свик, _אפצא,
  { {0xd70a0010,0x57450015,0xc7a3219d,0xa806011c}},	// [d1e0] енае_, لخلف, битк, узал
  { {0x8c1b0008,0xbc1b0135,0x67360091,0x7cfd3e8b}},	//   _אופי, _אופש, rpyj, véri
  { {0x96f90010,0xe45a025f,0x9e09000a,0x7c290046}},	//   тэту_, еже_, תִּ֖, žere
  { {0x18a60a61,0x98a61440,0x248d016e,0xa34a2bb4}},	//   _самм, _симе, _caem_, езда_
  { {0xcc3b0053,0x38b51edc,0x2bba0065,0x68e4039f}},	//   גענט, _vårt_, उनटा, mnid
  { {0x61fe0111,0x7cc400dc,0x290054bc,0xa1580054}},	//   üplo, gőrz, llia_, ваку_
  { {0x68e42a15,0x21670001,0x2ca00034,0x27f60046}},	//   onid, гији_, _onid_, řeně_
  { {0x7cfd54bd,0x045a0029,0x26da31c8,0xe97b000a}},	//   péri, _سلطة_, lipo_, תנקש
  { {0x290000f2,0x68e41519,0xf8b3000a,0x2bc6000b}},	//   ilia_, inid, משה_, रैमा
  { {0x4d980036,0xce6a0004,0x672601c2,0x23270d7a}},	//   вкою_, хрид_, _mukj, _софи_
  { {0x2b91032c,0xd6db0008,0x29002254,0x61270061}},	//   _môcť_, תחיל, klia_, _yılm
  { {0x703a0029,0x7ce80064,0x6d5a002d,0x7cfd0030}},	//   _أساس_, tıra, rrta, hérv
  { {0x7af50014,0x60db0053,0x26da09de,0xda7b0142}},	//   tozt, _אקאנ, kipo_, няв_
  { {0x66c001d1,0x3d940036,0x68e454be,0xde580033}},	//   _sökn, _викр, enid, _ракі_
  { {0x7af500dc,0x68e40112,0x63b9002a,0x6d5c0030}},	//   rozt, fnid, zywn, árad
  { {0x290002d7,0xfaff00aa,0xb4be000b,0x58d43de5}},	//   glia_, duëe_, इसो_, бост
  { {0xaae70086,0x96f9000d,0xe8940080,0x7d0d0f7a}},	// [d1f0] _مسدو, веат_, щать, _ihas
  { {0x68e4007c,0x248d016e,0x290054bf,0xaa670d4b}},	//   anid, _saem_, alia_, _стик
  { {0x66c00123,0x7d0d1390,0x26070033,0xa5d50099}},	//   _tökn, _khas, учаг, јжеш
  { {0x63b90050,0x94190015,0xfa34002b,0xe4c70033}},	//   tywn, نقاذ_, _پرید, ыёзн
  { {0xe28e000d,0x0d18004c,0x66c00061,0x04c80015}},	//   оа_, אקאט_, _kökl, دوني_
  { {0x2d850026,0x78ad54c0,0x24430016,0xb7da000a}},	//   ywle_, ljav, ằm_, _יקרי
  { {0xe2c90086,0x78ad01a3,0x63b9002a,0x20d30045}},	//   _یورو_, ojav, sywn, lţii_
  { {0x22450111,0xb97c0053,0x7f850029,0x78ad01a3}},	//   _welk_, גנהי, للبن, njav
  { {0x2019022d,0x4f250083,0x644b54c1,0x20d30011}},	//   äsi_, јдоб, magi, nţii_
  { {0x78ad014b,0x644b54c2,0x2eb5029b,0x7c3d0012}},	//   hjav, lagi, рсис, ebsr
  { {0xd24e002b,0x82a40054,0xde05005e,0x92b4002b}},	//   _آچه_, _уште, рпни, _احقا
  { {0x361a0053,0x30e40010,0xcb090008,0x628354c3}},	//   כותד, _лічб, _חל_, leno
  { {0x7655005c,0x3ceb013f,0xbea554c4,0x628300bc}},	//   _odzy, _živé_, _валк, oeno
  { {0xfc030036,0x13ba0053,0x644b0213,0x78ad00bd}},	//   іпро, דזשע, hagi, ejav
  { {0x66c001d1,0x628354c5,0x78ad001a,0x7cfd0030}},	//   _söko, ieno, fjav, vérv
  { {0x60c900f2,0x7d0d06e8,0x628354c6,0x290002e8}},	//   nhem, _ghas, heno, ulia_
  { {0x3cfb000a,0xacfb000a,0xf71a0033,0x684301f3}},	// [d200] _שלפנ, _שהפכ, віжы_, інфа
  { {0xfd4c0023,0xdcf90089,0x628307d4,0x66c00061}},	//   _nhiệ, _osvě, jeno, _gökl
  { {0x4a5b0008,0x20d30045,0x29002602,0x26da02f2}},	//   _בדיו, aţii_, plia_, ripo_
  { {0x6e2d4574,0x26da0573,0x82f7002b,0x644b54c7}},	//   _şabl, sipo_, یروز_, gagi
  { {0x20d30011,0x883b0008,0x1394005e,0xf772002b}},	//   cţii_, _בתכו, силю, _باج_
  { {0x644b0c59,0xb2370015,0x7cfd0030,0x62830599}},	//   aagi, لكها_, lért, geno
  { {0x644b00e8,0x41b40029,0x867b000a,0x69ce54c8}},	//   bagi, إمبر, _שרלו, nzbe
  { {0x7cfd0030,0x60db2cc8,0x6537004f,0x644b007f}},	//   nért, gium, _כאלף_, cagi
  { {0x61270061,0x4ea615d1,0x7cfd0030,0x3013006b}},	//   _yılk, арна, iért, одър
  { {0x62330124,0x7d0d1740,0xd007049d,0x21760b1e}},	//   _међу, _shas, шење_, _вудр
  { {0x06970008,0x7cfd00dc,0x0dca017c,0x5d63005e}},	//   בדים_, kért, тупи_, отяз
  { {0x66c000c0,0x211a002b,0x6f010125,0x5ce40015}},	//   _sökl, _شتاب_, allc, ْكَل
  { {0x69ce0085,0x7e6b008c,0xdee621a4,0xd0d30015}},	//   ezbe, ämpö, _коди, _بينظ
  { {0x7ce80061,0x8f9b000a,0xd0071411,0xcef30058}},	//   lırl, _שיגי, _тече_, _وأوغ
  { {0x6d430026,0x2e370008,0xa2a7000b,0xbdf7002b}},	//   _gwna, _דרוש_, चात्, _پروا_
  { {0x7ce801e2,0xa8a40001,0x31570053,0x7cfd00dc}},	//   nırl, орук, יילן_, gért
  { {0x2f0b0134,0xa7b80033,0x78ad54c9,0x628354ca}},	// [d210] søge_, алту_, rjav, yeno
  { {0x20d30011,0xd5bb54cb,0x6b8d54cc,0x644b54cd}},	//   rţii_, ксе_, _isag, wagi
  { {0xb9950029,0x628354ce,0x0568012e,0xc98754cf}},	//   _الجب, veno, ијци_, _тупи
  { {0x20d30011,0x77640251,0xa3550015,0x7cfd0307}},	//   pţii_, buix, مختص, mérs
  { {0x7ce80064,0x987a0053,0xe458005e,0x33870004}},	//   dırl, _גארט, ржі_, руев
  { {0x86c50086,0x8c1c000a,0x6b5e001a,0x62833057}},	//   _ايسن, דודי, _hægð, ueno
  { {0x644b0298,0x7ce80064,0x8467006b,0x628354d0}},	//   pagi, fırl, _възе, reno
  { {0x628354d1,0x38693a47,0xd498005e,0x6b8d54d2}},	//   seno, ngar_, _кру_, _osag
  { {0xfd4c0023,0x60db54d3,0x60c92c99,0xe3fb002b}},	//   _thiệ, rium, rhem, _شعرش_
  { {0xe57f0024,0xaec50010,0x38690034,0x0ea90088}},	//   šķus_, сбол, hgar_, укой_
  { {0xa2940036,0x2fcd00dc,0xcc8a002b,0x02fa004c}},	//   _фахі, szeg_, هنده_, _עלעמ
  { {0xed56005e,0x757a000a,0xb115226c,0xe1f000c3}},	//   щою_, נטרפ, _умеш, _غسل_
  { {0x66c000c0,0x80a4000b,0xf412000a,0x1419000a}},	//   _sökm, कारे, ּ֤ר_, טוֹב
  { {0x38690084,0x6d5c002d,0x69ce00b8,0xa3af021e}},	//   egar_, árac, tzbe, _ओपन_
  { {0xcd350225,0xfe36000a,0x5ed40015,0x6da40015}},	//   _ارتب, _פרקי_, _بتنز, _ومهم
  { {0x7c24003f,0x6d56000a,0x09f70015,0x38694514}},	//   _ugir, _היקף_, صفقة_, ggar_
  { {0x69ce00dc,0x68430010,0xdc3b0053,0xccf300a3}},	// [d220] szbe, янта, _געפר, _מכה_
  { {0x7ce80064,0x064a0002,0xa3ab000b,0x7cfd0eab}},	//   zırl, الاً_, गमन_, sért
  { {0x7cfd336a,0x644900b8,0xba9b0053,0xab5b0030}},	//   pért, _beei, _עסטי, szüt
  { {0xed560053,0x4dfa0053,0xb97b000a,0x7469005e}},	//   מבער_, אפעא, _גנטי, ирів_
  { {0x33f60021,0x68f9002a,0xb353005e,0x93770015}},	//   حساس, ładó, зкіш, مصور_
  { {0x26d8016f,0x8c1b0008,0x7ce80064,0x661a001a}},	//   _umro_, אוני, dırm, _útko
  { {0x7ce80064,0x80a4005d,0xfc3f0089,0x1a9b0053}},	//   tırl, काले, ybí_, טיסע
  { {0x141a0029,0x644900b8,0x85570008,0x493b000a}},	//   _ميزة_, _geei, _לשלב_, נגפו
  { {0xdbf10089,0x30770015,0x43432e06,0x7cfd0030}},	//   _příc, صحية_, _нетв, zérs
  { {0x66fa014e,0xd337000a,0xe7b7000a,0x2379007c}},	//   ्तिक_, _לרמה_, צהיר_, _äsja_
  { {0xd24f012c,0xa1c50015,0x067b000a,0x720600c3}},	//   _سنن_, _وآمن, ננטל, _اوام
  { {0xd12f0029,0x7cfd016e,0x5cc7004a,0xac19007e}},	//   _أمن_, vérs, ссоз, иону_
  { {0x06fa014e,0xc4d3000a,0x7f93005e,0xcff4009a}},	//   ्ताव_, פגש_, _наїх, _بيشک
  { {0x38bc0089,0x38690026,0x764a001a,0x66c0001a}},	//   _míru_, wgar_, ðfyl, _dökk
  { {0x98c70010,0xa8030064,0xaab60086,0xfcd50015}},	//   бсал, ğıms, تگير_, _ويتج
  { {0xad3705bd,0x58d42ded,0x320c01c0,0x38692ec8}},	//   _פנחס_, пост, _mzdy_, ugar_
  { {0xd6270029,0x2486002c,0xf7700115,0x6b8d20ef}},	// [d230] معاي, deom_, فال_, _usag
  { {0x6449003e,0x6efd0152,0xdb0b0015,0x2d9c0046}},	//   _seei, lèbr, _حزبه_, _krve_
  { {0x661a001a,0xf60b00e2,0x66c00030,0x3eb101d3}},	//   _útkl, ухай_, _zökk, özti_
  { {0x6efd0003,0x20d30045,0x7ce80061,0x24860183}},	//   nèbr, nţit_, yırm, geom_
  { {0x4902000b,0x69d8001a,0xdc6c000a,0xa31902ed}},	//   _वीटो_, _þver, א֣וֹ, ажду_
  { {0xb3840033,0xc3480088,0xe29911c2,0x5b7c000a}},	//   яліл, сяце_, рак_, טרדא
  { {0x9608008f,0x32cb003c,0x3abc000a,0xc692004c}},	//   _гэта_, _nøye_, רמונ, _קאל_
  { {0x7ce80064,0xc5f2000a,0x64c50015,0x2f55008a}},	//   tırm, _חדל_, _بيرل, отос
  { {0x2d9c54d4,0x1ec9004a,0x2d980723,0x0000006a}},	//   _arve_, илии_, æren_,
  { {0x20030024,0xd3d80015,0xd251006e,0xb4c9000b}},	//   āji_, _طبقا_, _آنا_, _ऋतु_
  { {0xb0350063,0xdb06005c,0x66c000c0,0x31c71923}},	//   _днеш, zykó, _sökk, _усав
  { {0x6efd0003,0xc0ab00c3,0x66c0001a,0x23600160}},	//   gèbr, _حائل_, _pökk, šije_
  { {0xb4fa0053,0x0b43006b,0x7ce80061,0xab2a0c6e}},	//   שפרי, мнян, lırk, рога_
  { {0xc332000a,0x539a000a,0x0c230033,0x61ed0045}},	//   ווך_, בישו, ьмян, şalu
  { {0x7ce80064,0x2d983e55,0x48b61045,0x0000006a}},	//   nırk, året_, ощат,
  { {0xdb06005c,0x66c0001a,0x0000006a,0x0000006a}},	//   tykó, _tökk,   ,
  { {0xe8f705d1,0x9d1b0008,0xcc57000a,0xb8f2000b}},	// [d240] ілу_, _דוקט, _וספק_, _वत_
  { {0xdb06002a,0x463a0033,0x0000006a,0x0000006a}},	//   rykó, рчая_,   ,
  { {0x7afc0495,0x08fa0015,0x842a067a,0x7d0654d5}},	//   mort, _نرحب_, ажев_, olks
  { {0xdd7a004c,0x14760015,0x23db000b,0xc60a000b}},	//   יטעל, تائج, _मेहद, _वरीय_
  { {0xdc8d0053,0x78a654d6,0x7afc54d7,0xc347009b}},	//   טװאָ, _inkv, oort, ояще_
  { {0x7afc232a,0x623400d0,0xab8b000a,0xb2d30015}},	//   nort, чеку, שָׁ֖, وينغ
  { {0x889a000a,0x99980091,0x0000006a,0x0000006a}},	//   ֹבִי, marų_,   ,
  { {0x66c000c0,0x81130015,0x7afc54d8,0x0000006a}},	//   _sökh, وذيا, hort,
  { {0x20020084,0x98b3016f,0xbe860054,0x7afc54d9}},	//   æki_, žeće_, оћни, kort
  { {0x2d9c01a3,0x22570015,0x3f9d0034,0x7afc0ebd}},	//   _prve_, _ولقد_, _drwu_, jort
  { {0xa2a7000b,0xa2b9000b,0xe2970a23,0x1df808f0}},	//   चार्, ्सर्, _фах_, сены_
  { {0x99980091,0x3d05000b,0x61ed0061,0x8025002b}},	//   harų_, रतें_, ğalt, _فرهم
  { {0x70530086,0x99980007,0xd0070001,0xa0290015}},	//   _آنها, karų_, _деце_, _اسمك_
  { {0x7afc0061,0x1eaa002b,0x5ed30058,0x4e97009a}},	//   gort, _خاصي_, _يتوز, _وپنج_
  { {0x7c360026,0xdb1d00dc,0xf84b0b08,0x28bf000b}},	//   _ffyr, nysé, ичай_, _एकदि
  { {0x34b9005d,0x26ca005c,0x59f80010,0x37350010}},	//   _आवेद, _albo_, цеся_, знаё
  { {0x7afc54da,0x5c740033,0x3cf20030,0xe7300015}},	// [d250] bort, _ўльт, ézve_, نصل_
  { {0x501b0008,0x2607004a,0xfc3f0046,0x7afc03b8}},	//   שומו, очег, ajít_, cort
  { {0x63b600f2,0xe5ab0054,0xb866002b,0xcaf40058}},	//   äynn, шњак_, _کاپو, _تسيب
  { {0xf9fa0008,0x6d8b000a,0x6d550030,0x44b50033}},	//   _להתמ, יָדְ, ázai, ябес
  { {0xb3870015,0x07a40033,0xe5080058,0x0000006a}},	//   تجاه, _жаўн, آينو_,
  { {0x77ba0008,0x67ba0008,0x7ce80064,0x02c5000b}},	//   _המשח, _המשק, tırk, वसेन
  { {0x20090048,0xca7c00a3,0xda7c000a,0x98ac0091}},	//   _šai_, ינגט, ינגר, ūdą_
  { {0x25752ced,0x3d05000b,0x4078004a,0x70550015}},	//   mål_, रतों_, ощью_, أنظا
  { {0x66c000c0,0x6d5c25df,0x3e890015,0xb4d7000b}},	//   _söki, áran, مَةَ_, ाफी_
  { {0xf1950036,0xae58005e,0x81a70021,0xf6b6000a}},	//   _низь, орює_, _وحال, ִּית_
  { {0x7afc54db,0x11440015,0xed590054,0x25d5000a}},	//   vort, _يَكُ, љом_, פוֹן_
  { {0xdb0d002c,0x7afc54dc,0xbfb7002b,0x7d0654dd}},	//   ľkýc, wort, _وحشت, ulks
  { {0x7f190010,0xa2d2005d,0xaaa7005d,0x7afc54de}},	//   _ліку_, भोक्, खांक, tort
  { {0x64420011,0x2f180080,0xcf92000a,0x8f9a015b}},	//   zboi, _дочь_, _נטו_, _ליני
  { {0x7d110014,0x3ea7001a,0x7afc54df,0x0000006a}},	//   üksé, _innt_, rort,
  { {0x7afc2903,0xdcfa0015,0x9dd6000a,0xa92302ed}},	//   sort, _دفعت_, _מוצק_, едсл
  { {0x7afc52c0,0x99980073,0x0000006a,0x0000006a}},	// [d260] port, tarų_,   ,
  { {0x7bdb000a,0x64420034,0x0000006a,0x0000006a}},	//   _לקפו, wboi,   ,
  { {0x3abb0008,0x7abb0008,0xaabb0008,0x0000006a}},	//   _המינ, _הציו, _הזיכ,
  { {0x27ed044c,0x3d12000b,0xd46a00af,0x0000006a}},	//   _žene_, _धीमे_, сиде_,
  { {0x29020005,0x389b0008,0xa2940484,0x889b000a}},	//   _ikka_, _היכנ, далі, _הבכי
  { {0xba3a00b2,0x32050089,0x8b57000a,0x645b3633}},	//   זײַט, _byly_, לינס_, _edui
  { {0xb9090092,0x987c006f,0xe5060015,0x04460499}},	//   _nghỉ_, _míľ_, _فبري, _невн
  { {0xf4840086,0xf9930008,0xc1040029,0x61e5002c}},	//   _تاسی, תרה_, بوعي, úhla
  { {0x250b0086,0xdd1f0089,0x1eaa0015,0xb3ca0054}},	//   _طرفی_, tížn, مادي_, _улаз_
  { {0xd357000a,0x4357000a,0xd80b000a,0x77bb000a}},	//   _מימי_, _מסמל_, מִיָ, צמיח
  { {0xaab0014e,0xd23b0008,0x81a50015,0x2d8c0079}},	//   ञानक, _הגבל, _يحمل, uwde_
  { {0x718b000a,0xa1130015,0x628a54e0,0x629854e1}},	//   _לְדַ, _كولت, lefo, ldvo
  { {0xde58017f,0xc4d3000a,0x8fa301b0,0xb4fb000a}},	//   _далі_, תגר_, _паце, מפטי
  { {0x753c0050,0x764e0089,0x501b000a,0x66c0001a}},	//   _otrz, _neby, _הודו, _köku
  { {0xc9840809,0x4e7b000a,0x8e7b000a,0x9e7b000a}},	//   нути, _האוצ, _הנוה, _הנופ
  { {0xdd01003d,0xdde9002b,0x6d3b004f,0x0000006a}},	//   ītēj, _برهه_, _פתחנ,
  { {0xf7730115,0x628a54e2,0x1af5006b,0x764e2ecb}},	// [d270] عار_, kefo, _опия, _beby
  { {0xf7480015,0x0aeb0015,0x7b740015,0x569407f7}},	//   سلمي_, _دربي_, _أطيا, наут
  { {0x764e0026,0xb8840046,0x69130061,0x765c0034}},	//   _deby, _smíř, tçed, _ddry
  { {0x765c0176,0x24580010,0x386d02de,0x62981b54}},	//   _edry, заць_, _øer_, edvo
  { {0x68ed54e3,0x889a000a,0x289a000a,0xb89a000a}},	//   mnad, _וברי, _וירא, _וברש
  { {0x66c001d1,0x290900f2,0x628a54e4,0x764e0bfa}},	//   _sökv, llaa_, gefo, _geby
  { {0x95c50029,0x2ca954e5,0xddc8002a,0x68ed54e6}},	//   _غيره, _onad_, hadł, onad
  { {0x7f590083,0x04c90015,0xd5a6002b,0x6298007c}},	//   ојот_, _بوري_, _تلفی, advo
  { {0xa2270086,0x2909008c,0x628a54e7,0x68ed54e8}},	//   _فراه, ilaa_, befo, inad
  { {0xf4120008,0x68ed0026,0xdb0a0061,0x9e1d005e}},	//   _יפן_, hnad, ünüm, ичнi
  { {0x569c0008,0xcc8a0432,0x672f002a,0xb6ab02a3}},	//   מיזצ, обне_, _lucj, рмiн
  { {0x859a0008,0x01fa000a,0x68ed0079,0x0000006a}},	//   קשרו, _ופעל, jnad,
  { {0xdce20024,0x66c00061,0x68ed54e9,0x62810160}},	//   gulā, _kökt, dnad, _kblo
  { {0x7d070152,0x32000064,0x3ea7002e,0x2909008c}},	//   térê, şiye_, _unnt_, elaa_
  { {0x6281002d,0x3cfa0015,0xacf60054,0x5ee8000a}},	//   _mblo, _وعبد_, _очиј, _מַקְ
  { {0xbcf60029,0x628a06e7,0x6d41164a,0x69130061}},	//   _تستغ, zefo, mpla, eçeb
  { {0x753c005c,0x7d0427e4,0x6d41276b,0x628141e8}},	// [d280] _strz, _ikis, lpla, _oblo
  { {0xc7950010,0x2909008c,0x2ca9002a,0x6d4154ea}},	//   эрсы, alaa_, _znad_, opla
  { {0x7e7e00c0,0x628a54eb,0x6d41415a,0x2ca90416}},	//   _öppe, vefo, npla, _ynad_
  { {0xcdb60008,0xd4d50010,0x299b000a,0xf48301c6}},	//   ופעה_, нічэ, _וסטמ, вушн
  { {0x764e0026,0x628a2e47,0x68e4143f,0x6d410ba4}},	//   _teby, tefo, miid, hpla
  { {0x68e40020,0xd13a0c71,0xa2260015,0x52d80033}},	//   liid, охи_, ورثه, ямлю_
  { {0x753c005c,0xf6230010,0x7a89000a,0x1fb8000b}},	//   _utrz, _адро, לָקַ, ेन्ड
  { {0x09f7000a,0x6d4154ec,0x6d5c3251,0x68e42a1e}},	//   ומצם_, dpla, áram, niid
  { {0xbe8a09c2,0xd0070054,0x6d4154ed,0x00f70058}},	//   осне_, меће_, epla, بعوث_
  { {0x66c054ee,0x2ca90089,0x72160015,0x7d044a04}},	//   _töku, _snad_, _قذائ, _akis
  { {0x01da0029,0x68e40020,0xc693000a,0x6d412d6e}},	//   _بوضع_, kiid, דאת_, gpla
  { {0xbfc6010f,0x7d1654ef,0x66c0203a,0x3cf4016d}},	//   _обек, _chys, _köks, _ľavé_
  { {0x5c04008f,0x68e40020,0x711b0053,0x8144002b}},	//   вяра, diid, _וואפ, _آنچن
  { {0x6d4100c0,0xe9d30015,0x9ea7006b,0x69d50012}},	//   bpla, نغز_, _овча_, tzze
  { {0x6d5500dc,0xe919005e,0x4efb000a,0x5db30015}},	//   ázat, зові_, _והגו, _لإير
  { {0xdce20024,0xddc8005c,0x69d50012,0x7ce80030}},	//   pulā, padł, rzze, tűre
  { {0x7c2d54f0,0x8d180015,0x69130061,0x5d180015}},	// [d290] _igar, _تزور_, eçec, _تتوج_
  { {0x85b8002b,0x66e40054,0x68ed54f1,0x236654f2}},	//   ژانس_, вођа, snad, droj_
  { {0xe3b00074,0x68ed00c0,0x68e454f3,0xd6d800ce}},	//   یره_, pnad, biid, єту_
  { {0x66c001d1,0x809e005d,0x628102b9,0xdce20045}},	//   _sökt, _खोले, _sblo, mulă
  { {0x9cd80008,0x883a000a,0x6d5c006f,0xe3c50015}},	//   וואה_, _מתרו, áraj, عْتَ
  { {0xc7d6000a,0x6d4154f4,0x0000006a,0x0000006a}},	//   _טורי_, ypla,   ,
  { {0xb2360015,0x7c2d002a,0x66c0001a,0x6d4100da}},	//   ركيا_, _ogar, _vökt, xpla
  { {0xd12e0015,0x236600b3,0xc517002b,0xa29f000b}},	//   حمي_, broj_, _آبست, _गोर्
  { {0x787a000a,0xf907000b,0x7d04008c,0x442d54f5}},	//   הָיו, _वीज़ा_, _rkis, _ige_
  { {0xe2930015,0x02440015,0x6d4154f6,0x7c2d2a82}},	//   _جذر_, _لَكَ, tpla, _agar
  { {0x1d0a0b9c,0x75290111,0x5f750086,0x41740015}},	//   зени_, _kiez, ذاکر, _لانس
  { {0x55da00b2,0xa2b9005d,0x41740029,0x6d412fb9}},	//   פֿינ, ्सक्, _جاكس, rpla
  { {0x10d80029,0x68e40020,0x7529179d,0x2be0000b}},	//   _تبلغ_, viid, _miez, _पेशा
  { {0x5159000a,0x6d411156,0x60c954f7,0x6d550030}},	//   ּכּו, ppla, lkem, ázas
  { {0x38c80086,0x2cab002d,0x2d940033,0x60c9008c}},	//   واری_, áidí_, _арыс, okem
  { {0x75290050,0x26fa005d,0x7d04003f,0x7d760029}},	//   _niez, ्त्र_, _ukis, _أمير_
  { {0x68e4267f,0xdbc7007c,0xb87b013f,0xb6a60195}},	// [d2a0] riid, _sööm, _smíc, ниал
  { {0x442d0041,0xdb7b00b2,0x14c80086,0x60c9093f}},	//   _age_, _צװיש, ژهای_, hkem
  { {0x66c000c0,0x6c9a0008,0xe5720015,0x6f010034}},	//   _söks, ּשְׂ, ططا_, iolc
  { {0xd49702e1,0xe4520087,0x236654f8,0xf525005e}},	//   ерш_, اضا_, troj_, вфін
  { {0xf1d8014e,0x6abe00b8,0x33940010,0x7ce80064}},	//   _भेजन, _kopf, талё, lırs
  { {0x236000bd,0xdbc7007c,0x60c90577,0x6d5c0030}},	//   šijo_, _tööm, ekem, árak
  { {0x7ce80064,0xd8da000a,0x82570015,0x693c0046}},	//   nırs, ּקִר, رؤوس_, _učed
  { {0xdb1d0046,0x7de0006f,0xfbd00065,0x0000006a}},	//   vysí, násť, हनाम,
  { {0xb4be000b,0x2480007c,0x0000006a,0x0000006a}},	//   ेसी_, õimu_,   ,
  { {0x60c900f2,0x7c2d54f9,0x200a003d,0x7ce80061}},	//   akem, _sgar, ābi_, kırs
  { {0xdcf00061,0x0000006a,0x0000006a,0x0000006a}},	//   çeği,   ,   ,
  { {0xbebc0024,0x60560015,0x70560015,0x629a54fa}},	//   kmīg, _أنشط, _أنشا, _hato
  { {0x9b58010f,0x00bb000a,0x629a54fb,0x6f0145b6}},	//   ният_, _ממאמ, _kato, bolc
  { {0x2f970008,0x7ceb0123,0x7db40015,0xd00f0040}},	//   _נכון_, förä, _لمتص, _اله_
  { {0x3a2501d1,0x629a54fc,0x0e9b004c,0x78bd37e6}},	//   älp_, _mato, _זשול, _posv
  { {0xe8940b75,0x7c2d54fd,0x6d5a54fe,0x99980033}},	//   лась, _ugar, msta, экст_
  { {0x7c84005f,0xe73300e5,0x6d5a54ff,0x67d40850}},	// [d2b0] _суще, اصر_, lsta, готу
  { {0x66c001d1,0x7ce80064,0x629a0188,0x6d5a05e9}},	//   _sökr, bırs, _nato, osta
  { {0xeef70053,0x75295500,0x6d5a059f,0xaa64056d}},	//   עמבר_, _piez, nsta, _стык
  { {0xe5070086,0xed57000a,0xe4740033,0x7ae725c2}},	//   رباي, תבאר_, гушэ, lijt
  { {0xa856000a,0x9cd8000a,0x69c7008c,0x947400c3}},	//   _שישה_, עודה_, lyje, ادما
  { {0x6262004a,0x6d5a5501,0x7dcb0030,0x91e504b9}},	//   авша, ksta, nösö, коле
  { {0xc6480015,0x60c90201,0xba3c004c,0x7bc6002a}},	//   _سجّل_, tkem, לײגט, zyku
  { {0x442d0134,0xceb8005c,0xc2ed0046,0x60c9008c}},	//   _uge_, eję_, _řídí, ukem
  { {0x629a001c,0xa2830086,0x60c93b95,0x7ce80061}},	//   _fato, _میشو, rkem, zırs
  { {0xaec20080,0x69d80030,0x7bc60091,0xaec55502}},	//   ибыл, _üveg, vyku, тбол
  { {0x6d5a5503,0x6f015504,0xd1b2002b,0xdc6a03a7}},	//   gsta, rolc, _نیوک, манд_
  { {0x7bc60050,0x83fd00dc,0x4c830036,0x249d0034}},	//   tyku, _időb, алюв, ndwm_
  { {0x28a5000b,0x845a000a,0x6f015505,0x6d5a5506}},	//   _ऑफ़ि, וכרז, polc, asta
  { {0xceb80050,0xef180036,0x6a860063,0x3d12005d}},	//   cję_, _змі_, ълга, _धीरे_
  { {0xfaa30b1e,0x7bc601d7,0x48e60121,0xab2715d5}},	//   јасо, syku, вовв, тора_
  { {0x657a0012,0x7ce80061,0x3cfa0015,0x26d10e3c}},	//   _äthi, rırs, _تعتد_, _alzo_
  { {0xc05200b2,0xad1b000a,0x7ae720f6,0x3cf90030}},	// [d2c0] יזן_, _קופר, bijt, érve_
  { {0x864300eb,0xb8c90065,0x6abe01d0,0x27360052}},	//   инуж, _गो_, _uopf, _væn_
  { {0x4d8c000a,0xbebc003d,0x629a5507,0x69c70535}},	//   ּאדַ, smīg, _rato, cyje
  { {0x43460010,0x09f7011f,0xceb8005c,0x6d5c03d9}},	//   ведв, _ימים_, zję_, árai
  { {0x8c430064,0x93930029,0x629a5508,0xceb8002a}},	//   _öğel, لجوا, _pato, yję_
  { {0x6d5a5509,0x02be000b,0x41b6000b,0x94230054}},	//   ysta, ्सेन, _अपदस, јмље
  { {0xd46a0015,0x24840061,0xdb1d0030,0x31570015}},	//   _يحرم_, _tbmm_, nysá, نجية_
  { {0x2eca005d,0x629a003f,0x23760015,0xc953000a}},	//   िस्त, _wato, _لائح, במה_
  { {0x6d5a0050,0x69c7005c,0xdfd00029,0x629a2fa8}},	//   wsta, zyje, صيد_, _tato
  { {0xfe6f0015,0x63a201d7,0x4ea600eb,0x6d5a33cd}},	//   يدٍ_, mvon, триа, tsta
  { {0xdb040092,0x42d50010,0xe1650029,0x30860015}},	//   _triê, _сіту, _مدني, _للاف
  { {0x69130064,0xceb8005c,0xa3b6000b,0x69c710fd}},	//   eçen, sję_, _छपा_, vyje
  { {0x3f980024,0x6e960015,0x5bb8004a,0x60b7000a}},	//   ārus_, _للشا, вляя_, _שהדף_
  { {0x69c7008c,0x9d9a0015,0x27ed2c11,0xc333000a}},	//   tyje, _ينشئ_, _ženo_, יוש_
  { {0xdf150010,0xa954005e,0xa9c41028,0x3eb8001a}},	//   _сьць, икрі, астк, örtu_
  { {0x257c0089,0x98f40029,0x66c000c0,0xc19b00f3}},	//   díl_, لثقا, _sökp, ושלי
  { {0xf77000e6,0x7ae70079,0xe89400f4,0x1707009a}},	// [d2d0] قال_, pijt, шать, نفری_
  { {0x0f7b000a,0xc6a7006b,0x7bc8000a,0x657e01d3}},	//   ורמל, ърби, _יֶתֶ, ftph
  { {0x569401b7,0x63a2550a,0x1af8004f,0x062700af}},	//   рахт, evon, _במזל_, тфам
  { {0xb87b0089,0x7c3d0030,0xe7910061,0xdb041b5e}},	//   _zmín, ncsr, _göğü, _ariè
  { {0x43850015,0xdb040003,0x2f190003,0x25e3000b}},	//   التق, _briè, lège_, _टेरी_
  { {0xe3b00031,0x24510016,0xb364006b,0x02440015}},	//   ترم_, ạm_, ръцк, لَهَ
  { {0x45d50080,0x7abc000a,0xd1bb0015,0x3abc000a}},	//   _совс, וצגו, باشا_, ומגנ
  { {0x320c0026,0x2f190003,0x0000006a,0x0000006a}},	//   _dydy_, iège_,   ,
  { {0x6459005c,0x93f50937,0xfe790033,0xd4e4004a}},	//   mawi, _спац, нёны_, _тюри
  { {0xe7aa0020,0x1e951a0d,0x6459550b,0x1ee7009a}},	//   _tööõ, урир, lawi, ئودی_
  { {0x5de50033,0xacea20b9,0x0000006a,0x0000006a}},	//   ужна, емна_,   ,
  { {0x7e7e01d1,0x75352239,0x6459550c,0xcb6a112c}},	//   _öppn, _muzz, nawi, наме_
  { {0x691301e2,0x31a30061,0x62830034,0x0b5a0033}},	//   tçen, _hız_, ofno, эрны_
  { {0x31a30064,0x2d9500d7,0x1a66002b,0x69b5000b}},	//   _kız_, _брис, دیدی_, _उपशी
  { {0x9936002b,0xdd03003d,0x645945a3,0x2d980013}},	//   افرت, ņrād, kawi, æret_
  { {0x64590050,0xddc80089,0xe6c6002b,0x443f0034}},	//   jawi, jadř, گتري, _nfu_
  { {0x98a30063,0x9d1b0008,0x1f360053,0xad1b00f3}},	// [d2e0] щите, _אוקט, ָרער_, _אוקר
  { {0x7d06022d,0x0bb7000a,0xe6c6002b,0xb4be000b}},	//   loks, _עלים_, دتري, ेस्_
  { {0x4a7b0053,0x7d060020,0x1e560053,0x7a7b000a}},	//   _אריב, ooks, רשער_, _אריס
  { {0x7d060945,0x2d51016f,0x64590035,0x62830026}},	//   noks, iše_, gawi, efno
  { {0x54530036,0xdb040152,0xf8b3000a,0xf485005e}},	//   світ, _priè, _השר_, руєн
  { {0xd24f0029,0x2d510b6c,0xc2c40015,0x69130061}},	//   كنه_, kše_, شيعي, hçel
  { {0x2d51018c,0x91860029,0x7d06550d,0x6459002a}},	//   jše_, اجتم, koks, bawi
  { {0xc953000a,0xc0340054,0x8fa40015,0xb114116f}},	//   זמה_, шниј, لمعه, јмиш
  { {0x6d4300df,0x543b0053,0x289b000a,0x20d80125}},	//   _atna, _װעבא, תיפא, _léig_
  { {0x7d0600f2,0xb77b0053,0x75220030,0x7db40015}},	//   eoks, עאיש, lmoz, لمخص
  { {0x4086006b,0xd086004a,0xd1750033,0x1df8004a}},	//   _булб, _были, _вычы, тены_
  { {0x7d0f0014,0x91bb000a,0x9c470138,0x7d06005b}},	//   ulcs, _רמאי, ыхол, goks
  { {0x2d8b0011,0x3eb800c0,0x69c80013,0x2d51391e}},	//   ăcea_, örts_, øden, aše_
  { {0x945d0050,0x6459005c,0x2f190003,0x2d5100bc}},	//   _końc, zawi, tège_, bše_
  { {0x7655005c,0x59f8004a,0x3da30033,0x7d06153c}},	//   _rezy, геря_, _грыб, boks
  { {0xa157000a,0x60c2007c,0x38c4009b,0x6d484e69}},	//   טבלה_, _joom, бщув, mpda
  { {0x62830026,0xab95005e,0x6288550e,0x69dc00bc}},	// [d2f0] yfno, _типі, _obdo, azre
  { {0x60c20005,0x88830086,0x38bc0089,0x6b8d0035}},	//   _loom, _گیرن, _míry_, _ipag
  { {0x64590050,0xc5d90015,0x95570015,0x0000006a}},	//   tawi, خواص_, اخطا,
  { {0x23750029,0xfc3f529f,0x5c38004c,0x6b8d02f2}},	//   لاتح, ncí_, ָרגן_, _kpag
  { {0x20d8002f,0xa85a0008,0x27f8002c,0x6459550f}},	//   _méid_, _בדרכ, čenú_, rawi
  { {0x26cf0024,0x8b58000a,0x2d51006f,0x81a5002b}},	//   īgos_, ניוס_, yše_, لحعل
  { {0xfc3f0089,0x71640015,0x925800c3,0x4254005e}},	//   kcí_, مايك, اشهر_, стіт
  { {0xdd02006f,0xe4e70033,0x261a000b,0x90c5004a}},	//   _ľuďm, _сігн, _भरती_, рбие
  { {0x63b600f2,0xf8b40008,0x3cfb000b,0x98a50091}},	//   äynt, משק_, ोकने_, ūlė_
  { {0x66d2002e,0xbf880115,0xc7b2000a,0xfc3f006f}},	//   _lækn, ائيل_, קבי_, ecí_
  { {0x7d06022d,0x69130064,0x249f0747,0x6b8d00be}},	//   toks, tçel, _kaum_, _apag
  { {0xce180010,0x7d0600f2,0x63a95510,0xed5620fe}},	//   ыцыі_, uoks, _kren, шою_
  { {0x9f6b010f,0xc104002b,0x2d980723,0x6d480144}},	//   _чрез_, _اوني, ærer_, apda
  { {0x212f003e,0xfaa6004a,0x69dc0012,0x9bd50033}},	//   _high_, шаго, tzre, сцюш
  { {0xa856009c,0x6d5c0eed,0x7d061075,0x0189004f}},	//   итај, árat, poks, כָּ֜
  { {0xfc320806,0x8d48000a,0xb7da0067,0x6b8d0046}},	//   _بحث_, _עֲצֵ, نوزا_, _fpag
  { {0xe7370063,0x66d202de,0x69dc0030,0xa6e60a96}},	// [d300] иет_, _dækn, szre, ажал
  { {0x86960054,0x6f1d0079,0x2ca05511,0x0000006a}},	//   јјач, ïsch, _haid_,
  { {0x63a95512,0xe45a005e,0x200f0091,0xd5760088}},	//   _aren, вже_, _lygi_, рузь
  { {0xfdf60008,0xa533017f,0x212f00da,0x63a92377}},	//   בצעת_, ініч, _nigh_, _bren
  { {0xcc3b0053,0x2ca00100,0x60c21b61,0x3373005e}},	//   דענט, _maid_, _room, жгір
  { {0x809e005d,0x60c20020,0x212f002d,0x2ca00bf5}},	//   _खोजे, _soom, _aigh_, _laid_
  { {0x20f70045,0x1169002b,0x63a95513,0x649a0a24}},	//   răin_, هلوی_, _eren, _итар_
  { {0x68f60176,0x859b0008,0x2ca00026,0x2369016f}},	//   nnyd, _בשלו, _naid_, šaja_
  { {0x68f60176,0x1eaa0029,0x999800bc,0xe2960004}},	//   inyd, نادي_, jbrž_, _вреќ
  { {0x38bc0046,0x68f60034,0xeeaa0004,0x9f030040}},	//   _víry_, hnyd, ттик_, يويو
  { {0x6b8d04ed,0x60c20020,0x42db000a,0x8717000a}},	//   _spag, _toom, _שקבע, שקיע_
  { {0xfc3f0089,0x4fea05c4,0x69130061,0x6d480091}},	//   ucí_, _имен_, tçem, rpda
  { {0xd0100086,0x7e9a0015,0x2ca00034,0x7ac72044}},	//   _علت_, _لنشر_, _daid_, асве
  { {0xdb24002e,0x68f60026,0x6d480971,0x4fdb000a}},	//   ærðu, enyd, ppda, _שַׁד
  { {0x68f60b7c,0x0dca000d,0x26c302c1,0x394500dd}},	//   fnyd, _јули_, _rojo_, ëls_
  { {0x2f0b0134,0xfce400d0,0xc051000a,0x6f08013b}},	//   søgt_, _мојо, ּ֖ן_, lodc
  { {0x249f00b8,0x61350007,0x7d0d31c8,0x3cfc000a}},	// [d310] _raum_, _išle, _ikas, _שלחנ
  { {0xba990036,0x85a70001,0x2ca01553,0x6f79004f}},	//   _своє_, ијед, _zaid_, טְעו
  { {0x66d2002e,0xca96000a,0xa634005e,0x07080058}},	//   _tækn, _הדתי_, інці, جيلي_
  { {0x63a95514,0x9848006b,0x8467006b,0xf5e4005e}},	//   _pren, _вяра_, ръже, ціум
  { {0x20d1002d,0x28b6000a,0xf8b6000a,0xdb1d008c}},	//   _dáil_, _הפרש_, _הפרי_, pysä
  { {0x05770086,0x1b7a0053,0x1308017f,0x68ed5515}},	//   _پاسد, רטװע, аній_, liad
  { {0x20d1002f,0x7d0d0035,0xfb1c0008,0xcad8000a}},	//   _fáil_, _okas, דוגמ, שוות_
  { {0x68ed0176,0x09f8039e,0x59ba000b,0xf94a004c}},	//   niad, ימום_, _उपसर, נעפֿ
  { {0x63a9003f,0xc0c80001,0xceb50015,0x90e40021}},	//   _uren, рује_, محدث, تسون
  { {0x2ca05516,0x20110024,0x68ed0112,0x2909008c}},	//   _said_, āzi_, hiad, hoaa_
  { {0x68f60176,0x2ca011a3,0xdca602b0,0xcfa8002b}},	//   ynyd, _paid_, бани, هایم_
  { {0xc5f2000a,0xdb0e0046,0x2909008c,0xa0c400c3}},	//   לדי_, ějíc, joaa_, _ويلو
  { {0x2ca00005,0x68ed5517,0xa3d7005d,0xd496000a}},	//   _vaid_, diad, ानि_, זכרת_
  { {0xce94006b,0x8e850021,0xdde8002b,0x68f60034}},	//   _мачъ, _طلبه, اریه_, wnyd
  { {0x68ed0176,0x2ca00034,0x2f0b02de,0x2fdf0012}},	//   fiad, _taid_, søgs_, lzug_
  { {0xa3d7005d,0x60db001c,0x68f60026,0x68ed5518}},	//   ाना_, nhum, unyd, giad
  { {0xbb86003b,0x386f002d,0x36360029,0x9cd70008}},	// [d320] _الخي, ógra_, مراس, _לוקה_
  { {0x3bbb000a,0x86750033,0xa142003d,0xbb1a0015}},	//   _עמיד, жыцц, šķin, _حزبا_
  { {0x1a9b0053,0x8d5a0053,0x36060015,0xfc5a000a}},	//   _גייע, ָכני, حواف, ָכְמ
  { {0x69ce0007,0x045a00e6,0x68ed0ab6,0x0000006a}},	//   mybe, اجات_, ciad,
  { {0x60db003f,0xd4670004,0xfe780091,0x87b90fd5}},	//   dhum, сиче_, ygį_, _курт_
  { {0xd5d6044e,0x067502e1,0x0ea6000b,0x96ba2df1}},	//   _любы, _муся, _कोंड, _суму_
  { {0xc5d5005e,0xc5b8000a,0x0269005e,0x057a0015}},	//   _діть, _דֶּר, ршій_, _حمزة_
  { {0x765e00df,0x751a0015,0x78a45519,0x7c360034}},	//   lapy, _إقرأ_, ndiv, _ngyr
  { {0xd0100029,0x69ce08d0,0x9f5f001a,0x7f830015}},	//   بلة_, hybe, ýrði_, كلين
  { {0x27e00064,0x7d0d002a,0x979b004c,0x693c0085}},	//   izin_, _skas, נשיק, _pčel
  { {0xc04f05fc,0xb2a50015,0x15fa000b,0xc0e605b5}},	//   _ні_, _بحقه, ्थिर_, _ложк
  { {0x691301e2,0x3c440033,0x693c013f,0x69ce02de}},	//   rçek, зэрв, _včel, dybe
  { {0x78a404ed,0x68ed2cb1,0x10160015,0x711b000a}},	//   ddiv, viad, _اباد, _עודפ
  { {0x27e00050,0x68ed4b4c,0x7c360030,0x0000006a}},	//   dzin_, wiad, _egyr,
  { {0x68ed551a,0x6ce70127,0x3da70029,0x15e8021e}},	//   tiad, _гіпе, _هُوَ_, _टेलर_
  { {0x32cb003c,0x61350046,0x98c40a13,0xc7bb0138}},	//   _høyt_, _ušle, псул, лёз_
  { {0x68ed0f48,0xe918005e,0x69ce0061,0x69d80061}},	// [d330] riad, соті_, aybe, _üven
  { {0xa3ac005d,0x98be0024,0xbbd8000a,0x501b000a}},	//   गिन_, ītā_, _לוחץ_, רומו
  { {0x69ce0111,0x98a20091,0x9567006b,0xd70202a3}},	//   cybe, _likę_, създ, нiта
  { {0x76490061,0x8415076f,0xfcfc004f,0xd1260058}},	//   _şeyd, омех, ְּׁל, _زم_
  { {0x987a0053,0xdc8c0008,0xd00600e5,0xc7cb0132}},	//   _דארט, רְבָ, _آل_, _сыне_
  { {0x236900bd,0x8c1c000a,0xd1c9007e,0x0000006a}},	//   šajo_, אודי, илле_,
  { {0xa4d50191,0xda7c000a,0xe12509c3,0x83fd0030}},	//   _дові, טנגר, омки, _időm
  { {0x2b49016f,0x20d1002d,0xe1640015,0xdce2003d}},	//   _otac_, _táim_, أدوي, rtlī
  { {0x7e990015,0xa8cc000a,0x60db2964,0x0000006a}},	//   لنظر_, ר֖וֹ, rhum,
  { {0x7c360176,0x2fdf0012,0x69c802de,0x66fb000b}},	//   _sgyr, rzug_, ødek, ्विक_
  { {0xed590124,0x2b491b9e,0x81440015,0x2fdf0012}},	//   јом_, _atac_, _فنلن, szug_
  { {0x7fd502e5,0x41740002,0x69ce551b,0x1d0a016a}},	//   _мілі, _رامس, vybe, реми_
  { {0xf8bf0003,0xf8b80016,0x78a401c0,0x5f9400ce}},	//   _liés_, _đĩ_, vdiv, _ницт
  { {0x69ce0007,0x7ce80030,0xb2b9004f,0xaf0400ce}},	//   tybe, zűrh, ׁמָר, _епіл
  { {0x19b90036,0xd943023e,0xad25002b,0x66c00061}},	//   буть_, деси, تریو, _göky
  { {0xed56000a,0x27e0551c,0x69ce22d9,0x645b551d}},	//   _ובקר_, tzin_, rybe, _neui
  { {0xf0920008,0xfaa60033,0xdc3b004c,0x06ea0033}},	// [d340] ונן_, _дапо, _דעפר, амак_
  { {0x32000064,0xa3bd000b,0xceb2004f,0xe717009a}},	//   şiyi_, इमन_, ֽיא_, قيقت_
  { {0x66d20084,0x2d85003e,0x8ab7000a,0xfc3f0077}},	//   _hækk, ntle_, _והיו_, ldía_
  { {0x83fd00dc,0xd876002b,0xfc3f0077,0x3dfa004f}},	//   _időj, _بادب, odía_, בלעד
  { {0xfc3f02c1,0x693c1b4b,0x1513005e,0xc3060015}},	//   ndía_, _oček, єдія, يبتو
  { {0x8c1b0008,0x6442551e,0x7791002b,0x60d90034}},	//   בוני, scoi, _سیما, _alwm
  { {0xd259078f,0x645b0152,0x66d2002e,0x052a005e}},	//   сці_, _feui, _lækk, _вовк_
  { {0x3860551f,0x765c0bc7,0x645b0079,0x2f8a00af}},	//   nair_, _hery, _geui, аљон_
  { {0x60f7008f,0xb6020089,0x2d85002a,0x7bcf5520}},	//   ўныя_, řádn, etle_, xycu
  { {0x3860002f,0x61010024,0x66d2002e,0x539b000a}},	//   hair_, vēle, _sækj, _דימו
  { {0x06970008,0xe2b50010,0x25a500dc,0x963b000a}},	//   חדים_, _эстэ, _állt_, יגיט
  { {0x628a0026,0x759b000a,0x753c002a,0xc19b000a}},	//   lffo, ביטח, _murz, _כשבי
  { {0x613500df,0xd0f90053,0x62980111,0x386008f6}},	//   _išla, _פּער, oevo, dair_
  { {0x66d20134,0x2d8500da,0x4a440033,0x628a0034}},	//   _dækk, btle_, днёв, nffo
  { {0x66d20084,0x273f0026,0x386000ea,0x38c70c30}},	//   _tækj, _sîn_, fair_, ощав
  { {0x66d2002e,0x38601f22,0x63a00046,0x63ad006f}},	//   _fækk, gair_, _osmn, ťani
  { {0x14ab005d,0xd7590029,0xf7730115,0xb8e3000b}},	// [d350] _घोषण, صلات_, ظار_, _एच_
  { {0x57780029,0x62981b4b,0x6ac40015,0x645b0003}},	//   تصفح_, jevo, _يقيم, _seui
  { {0xba9a0008,0x6a9a0008,0x3860002d,0xc56b0086}},	//   _הסתי, _השתנ, bair_, شحال_
  { {0x3860406b,0x5dfb004c,0x291e0144,0xd90f002b}},	//   cair_, ספאנ, ïtat_, _شیء_
  { {0x645b0152,0x83fd00dc,0xad1c000a,0x88ba000a}},	//   _veui, _idők, בואר, _הזרי
  { {0x629809f2,0xe7f8000b,0x47d40015,0xdb9c004c}},	//   gevo, ंपरा_, _غيّر, יסדר
  { {0xd24e0015,0xe0d10015,0xa1560054,0xd1790033}},	//   دنى_, فزة_, пају_, ёскі_
  { {0x673d0020,0x76455521,0x99fc000a,0x69fc004f}},	//   _kusj, lchy, יפופ, ילוק
  { {0xb4d7014e,0x753c00b8,0xa2a6000b,0x765c0061}},	//   िसी_, _zurz, _टोक्, _yery
  { {0x2d85003e,0xd2510029,0x66d20134,0xc27403ae}},	//   ttle_, _أنا_, _rækk, _олуј
  { {0xf2d2000a,0xdca60df0,0xc236000a,0xc0350054}},	//   _רעב_, пани, _זרעו_, _енеј
  { {0xd0110029,0x23720091,0x2b440046,0x2d855522}},	//   _كلا_, šyje_, ímco_, rtle_
  { {0x2d855523,0x38600144,0xdcf9003d,0x2d910046}},	//   stle_, vair_, _apvē, ůze_
  { {0xa3ac005d,0xfc3f0077,0x66d202de,0x38600034}},	//   गित_, rdía_, _vækk, wair_
  { {0xc3320008,0x38604da8,0xdeba000a,0x7e615524}},	//   תום_, tair_, _למסל, malp
  { {0xe207005c,0x76450026,0x3860002d,0x765c2f6c}},	//   ciół_, echy, uair_, _sery
  { {0xfbd20029,0xbc7b0008,0x765c5525,0x3696006b}},	// [d360] _ستة_, _הנפת, _pery, зшес
  { {0x2d670085,0xe9da004a,0x7e615526,0xd7570058}},	//   ođe_, _гко_, nalp, سلمت_
  { {0x80db014e,0x2a570008,0xba9b0008,0x7cf60024}},	//   बसाइ, _מבין_, _פסטי, ašre
  { {0x765c005c,0x19bb0008,0xe4a3005e,0x5924002b}},	//   _wery, _המטב, ершо, _آکسف
  { {0x7e610048,0x765c005c,0x753c00b8,0x1837000a}},	//   kalp, _tery, _wurz, _מאכל_
  { {0xe57f0024,0xa6f8000a,0x62980077,0x8c1b000a}},	//   šķas_, _וִֽי, uevo, זוני
  { {0x628a0176,0x78a6016f,0x69130064,0x2905001a}},	//   rffo, _kakv, rçev, élag_
  { {0x6125002e,0xf993000a,0x403403fb,0x64a3468c}},	//   hólf, גרה_, мейс, _паса
  { {0x20d8002f,0x62985527,0x3013006b,0x20020061}},	//   _féin_, pevo, ндър, çki_
  { {0xe804005d,0x62810125,0xddc10034,0x74130015}},	//   _रखना_, _gclo, nglŷ, _أوكا
  { {0xdc990036,0xde180015,0x2019001a,0xe297009b}},	//   овні_, تقدت_, ýsir_, _хах_
  { {0x98ab0011,0x7e61007c,0x225e007c,0x7ce80030}},	//   _mică_, aalp, _hetk_, zűrv
  { {0x66d30064,0x70530015,0x6b9d0079,0x76450542}},	//   _yıkı, _أنها, uwsg, ychy
  { {0x8f9b0008,0x4fd3005e,0xfbd00015,0x2d06000b}},	//   _לידי, _яжіт, اتَ_, रवॉल_
  { {0x673d1c1e,0x1a780033,0x79540015,0xbd870040}},	//   _susj, ябры_, فَّا, _فنون_
  { {0x5dfb000a,0x7d7b000a,0x69341ecc,0x213e02ad}},	//   _לפונ, _הנהו, енсу, _muth_
  { {0x47352971,0xf7940033,0x6aa501c2,0x7d0e002a}},	// [d370] днас, натэ, _tahf, łosó
  { {0xb9990036,0xb714004a,0x79a7067a,0x7d0f1351}},	//   _двох_, едущ, _ерме, locs
  { {0xddcd0007,0x26ca00bc,0x83fd0030,0x76455528}},	//   _įkūr, _dobo_, _idői, rchy
  { {0x94190080,0x66150089,0x66d30064,0xe4e4042b}},	//   ожет_, _vyzk, _sıkı, нічн
  { {0xc1b70065,0x213e5529,0x0000006a,0x0000006a}},	//   ेङ्ग, _auth_,   ,
  { {0x90d50023,0x77ba000a,0x67ba000a,0xc7d6000a}},	//   _cùn, _ומשח, _ומשק, _חושי_
  { {0x26fb014e,0xd1790010,0x90d50092,0x65940418}},	//   ्वीर_, іскі_, _dùn, _пару
  { {0xb4650086,0xc1050067,0xc5f2000a,0xe1f0012c}},	//   _آگاه, بوبي, _סדן_, دسه_
  { {0x7e61552a,0x09ba000b,0x66d2001a,0x98ab0045}},	//   talp, _उप्य, _sæki, _zică_
  { {0xef16005f,0xe3b00002,0xcee9005e,0xb87b41a9}},	//   ммы_, _حرف_, ідне_, _hlíd
  { {0xe718000a,0xfc3f0077,0xddc10091,0x213e0125}},	//   החזר_, rdín_, malū, _guth_
  { {0x2d670085,0x8f7500ce,0x7e61552b,0x0000006a}},	//   rđe_, _жукі, salp,
  { {0xd00e002b,0x69130061,0x78a6552c,0xef0e2b43}},	//   _پلو_, hçes, _rakv, _ам_
  { {0xed590124,0x66d2002e,0x69130064,0x4f24005e}},	//   _док_, _tæki, kçes, _здіб
  { {0x78a600df,0x7d0f00dc,0x26ca552d,0xc332000a}},	//   _pakv, bocs, _robo_, כוך_
  { {0xd87a0029,0x693c0085,0x26ca00bc,0x64493d94}},	//   تمرت_, _očev, _sobo_, _nfei
  { {0x59ba005d,0xf7720196,0x06ca0033,0x3ea749c0}},	// [d380] _उपकर, ضاء_, огай_, _kant_
  { {0xde8e0092,0x644900e1,0x6125001a,0xa3ac0065}},	//   _lịng_, _afei, bólg, गिस_
  { {0x27260023,0x78a6552e,0x7abb000a,0xaabb000a}},	//   hông_, _takv, _וציו, _וזיכ
  { {0xc6890008,0x60cb0111,0xc953000a,0x3ea70865}},	//   יא_, _nogm, _שמר_, _lant_
  { {0x2b7b00b2,0xa2940036,0x443200f2,0xcc3b004c}},	//   ַטקײ, еалі, äy_, קעסט
  { {0x61010048,0x6449001c,0x3ea70026,0xf773000a}},	//   vēla, _efei, _nant_, _בקש_
  { {0x64490176,0x60cb0134,0x90d50092,0x75d6002b}},	//   _ffei, _bogm, _vùn, _غيرا
  { {0xd7020010,0x6101003d,0xd4030033,0xc05a0033}},	//   нiча, tēla, _кiру, цік_
  { {0xe2920115,0x90d50016,0xdfd00015,0x60cb1efa}},	//   _لذا_, _tùn, ايخ_, _dogm
  { {0x20180024,0x61f900dc,0x3ea7552f,0x7ce80030}},	//   āri_, áblá, _cant_, zűrt
  { {0x9d190afb,0x3eb80061,0x6b960091,0x64490034}},	//   зонт_, ırt_, _apyg, _yfei
  { {0x3eb80030,0xfc3f0077,0xad27009a,0x0000006a}},	//   űrt_, rdío_, برخو,
  { {0x9b580063,0x3ea7003c,0xdfd20029,0xe4570053}},	//   мият_, _fant_, _جيش_, ויכט_
  { {0xab2b0015,0x3ea75530,0x6e930058,0x0000006a}},	//   تسجل_, _gant_, _للها,
  { {0x20d8002f,0xdce20024,0xdb0d0003,0x8e7b000a}},	//   _léim_, gulē, _fraî, _ונוה
  { {0x25f4005d,0xe8940010,0x69130064,0xcd2b0086}},	//   ्पनी_, кась, eçer, _بستن_
  { {0xdd90002b,0x6bd90015,0x66b55531,0x0000006a}},	// [d390] _شوک_, _رودس_, нбау,
  { {0x4a550036,0x69130064,0xfc3f01c0,0x20d1002d}},	//   _якос, tçes, zdíl_, _háit_
  { {0x644900b8,0x6da90053,0x61250030,0x58d502ed}},	//   _pfei, ּׁנֶ, lóle, _зонт
  { {0x2458008f,0xcdf7000a,0xfdf7000a,0xe57f003d}},	//   даць_, ומבי_, וצבת_, šķos_
  { {0x20d8002d,0x2ca92d25,0x69d50c0a,0xe6671dc9}},	//   _céim_, _maad_, lyze, _отво
  { {0xe804005d,0x66d2002e,0x6b7c0008,0x1b7c004c}},	//   _रखता_, _bæku, קרונ, קטוע
  { {0xb87b0089,0xe1640015,0x3ea75532,0x2127009a}},	//   _umís, نديي, _rant_, ويتی_
  { {0xdbc70064,0x3a38000a,0xb87b0046,0x3ea75533}},	//   _göçm, ורום_, _zmír, _sant_
  { {0x7f190033,0xde8e0016,0x3ea75534,0x0000006a}},	//   зіну_, _vịng_, _pant_,
  { {0x92b40029,0xa2270058,0xddc500af,0x0000006a}},	//   _لحما, _قراه, ебои,
  { {0xa3d7005d,0x3ea72c35,0xc69200a3,0xcee800c3}},	//   ानक_, _vant_, נאט_, برين_
  { {0xa1560008,0x98ac0024,0x3ea75535,0xe572000a}},	//   _נבנה_, īdī_, _want_, נַת_
  { {0x3ea705d4,0x64da004c,0xbed50054,0xbdf9002b}},	//   _tant_, פֿטס, _подј, ترکا_
  { {0x693c0844,0xcee80015,0xbd450015,0x3ea70144}},	//   _očet, _يرون_, _كنتي, _uant_
  { {0xf2d20053,0x682a00dc,0xdb0d0152,0x69d50030}},	//   נעל_, ködé, _traî, gyze
  { {0xb87b0046,0xaa870016,0xdb0d006f,0x98a30912}},	//   _smír, _phýõ, ľkác, лисе
  { {0xcb6a0086,0x66760086,0x1da7005d,0x39350010}},	// [d3a0] _عمده_, فدار, गिकत, тэрс
  { {0xa3b3005d,0x8b57000a,0x20d80125,0x2ca90079}},	//   टिन_, _רייס_, _réim_, _zaad_
  { {0xda5b0008,0x69c10020,0x61010024,0xe7f0000b}},	//   _מכיל, älet, vēln, _घेरा_
  { {0xe73a12d2,0x8d5a000a,0xd516002b,0xa3ac000b}},	//   _нем_, פכני, رباغ, गिल_
  { {0x883b0008,0x7de60030,0x6d5c0030,0x981600c3}},	//   _מתכו, _késé, áraz, _سبحا
  { {0x68e4001c,0x290012e0,0xf9fa000a,0xb87b0046}},	//   lhid, lnia_, ּהֵמ, _umír
  { {0x04960010,0x7643006f,0x8717000a,0x29005536}},	//   _праў, žnyc, _נקלע_, onia_
  { {0x7c24018c,0x10e9002b,0x29120061,0xbf64002b}},	//   _ozir, وژنی_, noya_, نگتو
  { {0xd252003b,0x289b0053,0x63a40064,0x389b000a}},	//   _منذ_, ליקא, çind, ליקנ
  { {0x15f4005d,0x2ca90020,0x61080089,0x63a2003f}},	//   _आधार_, _saad_, děle, mwon
  { {0x20d60191,0x3ce011b2,0x52d7000a,0x68e401c2}},	//   _підс, _bliv_, _רובע_, khid
  { {0xade3005e,0xafe607be,0x29002c8a,0x0000006a}},	//   уцьк, _поел, jnia_,
  { {0x290010fe,0x14d7000a,0x693c00bc,0x613500bc}},	//   dnia_, תוכל_, _očes, _ošlj
  { {0x29000050,0x83fd00dc,0x7c24003d,0x657e00aa}},	//   enia_, _időt, _dzir, kuph
  { {0xe9190036,0x7af500dc,0xc333000a,0xb9e4005e}},	//   дові_, rizt, טוש_, гіти
  { {0x5ba70036,0xd7e7017f,0xa3e0000b,0xb87b0046}},	//   _зроз, нізо, दना_, _slíb
  { {0xabf60053,0xa6db001a,0x63a20079,0x69c80723}},	// [d3b0] זאָגן_, _auða, jwon, øder
  { {0x7d040089,0x7d1d3a99,0x63a20079,0x69c1007c}},	//   _zjis, llss, dwon, äles
  { {0x66d2001a,0x29120077,0x63a20651,0x68f60061}},	//   _rækt, boya_, ewon, biyd
  { {0x693c0089,0x61010024,0x68e40939,0x20d1002d}},	//   _včet, vēlo, chid, _láir_
  { {0x78ad0007,0xd4140010,0x18a40033,0x03a508ad}},	//   mdav, льшы, _саўм, тило
  { {0x61010024,0x78ad5537,0xf8bf0016,0xe2960c96}},	//   tēlo, ldav, _khéo_, ваш_
  { {0x8aac0008,0x693c00bc,0x15150033,0x25f4000b}},	//   לֹהֶ, _hčer, _адвя, ्पणी_
  { {0x78ad5538,0x8464006b,0xb9bc004f,0xd12e0058}},	//   ndav, _бъфе, לצות, يمو_
  { {0x60090036,0x27e902c1,0x8e5500fd,0xfe790033}},	//   ьним_, nzan_, ктні, мёны_
  { {0x2900062e,0x59b3000b,0xdce2003d,0x62670015}},	//   znia_, ुमार, dslā, _سائق
  { {0x753b003f,0x29000305,0x1d0a0b97,0xc4d5000b}},	//   _kiuz, ynia_, дени_, _दवाओ
  { {0x76490064,0xcb090008,0x2369016f,0xcb6a0254}},	//   _şeyl, _ול_, šaju_, маме_
  { {0x83fd0014,0x3ce00089,0x20d1002e,0x29120003}},	//   _idős, _vliv_, _fáir_, voya_
  { {0x60db0048,0x2900005c,0x60c95539,0x62832fea}},	//   lkum, wnia_, ljem, ngno
  { {0x3f8d0251,0xf8bf0092,0x2900062e,0x443f0085}},	//   lteu_, _chéo_, tnia_, _ogu_
  { {0xa7fb02c1,0x7d040089,0x38c8002b,0x443f0016}},	//   _seña, _ujis, رازی_, _ngu_
  { {0x6d430176,0x3f8d0251,0x60db553a,0xa686202c}},	// [d3c0] _huna, nteu_, ikum, клад
  { {0x39460080,0x78ad002c,0x5b7b000f,0x60db1bcb}},	//   _иног, adav, _קריא, hkum
  { {0x60db041c,0x60c9003c,0x64a605b3,0x5693005e}},	//   kkum, kjem, кажа, раєт
  { {0x7529003f,0x385a0015,0xa947000a,0x628300aa}},	//   _chez, _تشدد_, _בָךְ_, egno
  { {0x31da005d,0xd4670001,0x33940029,0x18a30010}},	//   बन्ध, тиче_, التز, _таям
  { {0xa3d30010,0x63a2553b,0x66d202de,0x7cf6003d}},	//   рошч, rwon, _væks, kšro
  { {0x693c016f,0x98a0016f,0x8afb000a,0x22d50033}},	//   _učes, gmić_, ופסק, ыццё
  { {0x60db0035,0x7c3b0b6c,0x61080046,0xfc3f0046}},	//   gkum, žuri, dělc, rdík_
  { {0x673c0e2b,0x68e30011,0x43750b9b,0x03a3105a}},	//   _kirj, _înde, _бухт, _кито
  { {0x6d43002f,0x78ad2823,0x661c02ce,0x60db553c}},	//   _buna, zdav, _kyrk, akum
  { {0x6d44032c,0x867b0008,0x661c00f2,0x667b000a}},	//   _čias, וריו, _jyrk, וטיק
  { {0x3eb90024,0x83fd00dc,0x3f8d0251,0x9f6400dc}},	//   ēsta_, _időr, bteu_, ától_
  { {0x3f8d0251,0x9f9c001a,0xce94006b,0x7d1d553d}},	//   cteu_, _gæða_, _балъ, rlss
  { {0xdd900015,0x67da003d,0xdb0d16ee,0xa3b3000b}},	//   _هوت_, _mājā, _traí, टित_
  { {0x7b050024,0x6d430049,0x661c008c,0x61ea0012}},	//   _ērtā, _guna, _nyrk, nzfl
  { {0xce37000a,0x7ce6553e,0xd8770015,0x6e37004f}},	//   _באות_, _córd, ضارب, _בטוף_
  { {0x6d43553f,0x78ad5540,0x8c250015,0xd138002a}},	// [d3d0] _zuna, rdav, _حفظه, _brąz_
  { {0x60db0089,0xe71900e5,0x6d430568,0x78ad0091}},	//   zkum, ريات_, _yuna, sdav
  { {0x673c00e8,0x60c9002a,0x661c002a,0xbebc03e9}},	//   _dirj, yjem, _cyrk, alīg
  { {0x661c02cd,0x6125001a,0x0000006a,0x0000006a}},	//   _dyrk, kóla,   ,
  { {0xb0b6005d,0xf8bf002c,0xdfc60196,0x3915002b}},	//   _अफ़ग, _iné_, _اي_, _لوگز
  { {0x7bdc0008,0x61350007,0x45450029,0x9f9c002e}},	//   וקדו, _išli, _منسق, _ræða_
  { {0x70550015,0xe47b0015,0x60db019a,0xb2840033}},	//   هنغا, _يحرص_, tkum, рычк
  { {0x3869049c,0x60db1f8a,0x7ce64c33,0xa4d400e2}},	//   naar_, ukum, _kóre, _косі
  { {0xc34b0010,0xbebc0024,0xf4340010,0x612500dc}},	//   _цябе_, klīd, _ветэ, góla
  { {0xfe71003b,0x6d44002c,0x4ec5005e,0x2d8b002a}},	//   حدة_, _čiar, уйов, ńcem_
  { {0x3f8d0251,0x38690161,0x51840033,0x41551a9d}},	//   steu_, kaar_, _вуча, _свес
  { {0x3f8d0251,0x4c83005e,0x7e680079,0x3d00000b}},	//   pteu_, блюв, aadp, ोकें_
  { {0xd110005d,0x2bba0015,0x38690079,0xf8bf0016}},	//   ावरण_, راحة_, daar_, _chém_
  { {0x6d435541,0x3ffa004c,0x945d002a,0xbb430588}},	//   _tuna, _אפנע, _końs, серк
  { {0xcdc80015,0x6d4302f2,0x945d002a,0x09e30302}},	//   _لذين_, _uuna, _jońs, борн
  { {0xbebc0024,0x4c860785,0xa8550054,0x673c007c}},	//   alīd, _слив, итуј, _sirj
  { {0xb8dc000b,0xdd04003d,0x7ce6002a,0xccf3000a}},	// [d3e0] _आफ_, šsēd, _córe, _לכה_
  { {0x661c00f2,0x6b5b000a,0x0000006a,0x0000006a}},	//   _pyrk, _רדיפ,   ,
  { {0x63a95542,0x38690161,0xa2c2000b,0xd62a01c5}},	//   _asen, baar_, लास्, хоже_
  { {0x98ba04f9,0xe97b0053,0xb97b00f3,0x59830127}},	//   _după_, _אנטש, _אנטי, _улюб
  { {0x66740086,0x63a900dc,0x7ce9000a,0xb87b0046}},	//   _نگار, _csen, כַסֶ, _klín
  { {0x61080089,0xa5660086,0xf6d50033,0x2a6a5543}},	//   děla, _مدرن, _кіся, nabb_
  { {0xd259005e,0xd6271377,0xb87b0125,0xe4da0015}},	//   тці_, _боре_, _mlín, _كوست_
  { {0x6ad1014e,0x25d7000a,0xe6173391,0xab5b0061}},	//   _सक्र, _גולן_, _сдс_, ryüz
  { {0x84060010,0xdfd00115,0x03a90015,0x5ea40015}},	//   _спаж, زيد_, _لدلو_, لمظل
  { {0x83fd00dc,0x2a6a00dc,0x612500dc,0x539b000f}},	//   _időp, jabb_, róla, _אימו
  { {0xa3ac005d,0xdd940010,0x02d528ff,0x067b004c}},	//   गिक_, шаны, _тютю, ענטל
  { {0x7056003b,0xc5f30008,0xd00f002b,0xa6db001a}},	//   _إنشا, מדת_, _کله_, _auðl
  { {0x38691663,0x9be4005e,0xd0100015,0x8ae7005e}},	//   vaar_, бірк, _ظلت_, гівл
  { {0xa7fb02c1,0x38690234,0x2a6a0030,0x32f6002a}},	//   _seño, waar_, gabb_, kłym_
  { {0xda35004a,0xca480015,0x38692252,0xbebc01ec}},	//   ревы, الفه_, taar_, rlīd
  { {0x671d000b,0x3eae5544,0x18550033,0x08550033}},	//   _बीजक_, _haft_, рваў, рваю
  { {0x98170074,0xf7700029,0x3869016b,0x26d10077}},	// [d3f0] ابزا, كال_, raar_, _pozo_
  { {0xa3b3005d,0x386920e9,0xcb8c000a,0xe945002b}},	//   टिस_, saar_, _נְחֹ, _پردی
  { {0xbb3a000a,0x07080015,0x32f6002a,0xe895107b}},	//   _שעתי, ديلي_, głym_, _кань
  { {0xddc10011,0xa8a703ad,0x34952666,0xb87b5545}},	//   lalţ, _срок, радр, _zlín
  { {0x3cfd005d,0xb4640036,0x69c8007c,0x2489003d}},	//   _लगने_, скіл, ädev, ļam_
  { {0x61250050,0x877a0053,0x3f980011,0xe2995546}},	//   góln, _באשי, ărul_, так_
  { {0xd49b008f,0x3abc0008,0x45d5005e,0x96080033}},	//   _пра_, תמונ, _товс, _бэта_
  { {0xdfd10029,0x6fb500a2,0x2a6a00dc,0xe293002b}},	//   قيع_, لمعا, zabb_, _گذر_
  { {0x3fc70086,0x6d4e02c1,0x82870115,0xc2c4002b}},	//   ادعی_, íban, _مجال, _گيلي
  { {0xb77c0053,0x877c0053,0x3eb9003d,0x9758000a}},	//   גאזש, גאזי, ēsto_, איזו_
  { {0x6cc602c5,0xf2c400a4,0xa2c2000b,0xa3b3000b}},	//   айна, _устн, लार्, टिव_
  { {0x1fb5004a,0x201d0034,0xd5c8000a,0x612516ee}},	//   _вскр, _tywi_, אֶשָ, mólo
  { {0x2a6a0030,0x3b8300e2,0x3fc9002b,0x0000006a}},	//   tabb_, оляг, _جدای_,
  { {0xbebc0024,0xd335000a,0xab2a1886,0xd5b8003d}},	//   alīb, ירָה_, тога_, _šām_
  { {0xfd120021,0x2a6a0030,0xa967006b,0xfce6005e}},	//   _وجب_, rabb_, иира_, _войо
  { {0x2a6a0014,0xb87b0125,0x5bc60015,0x48e3005e}},	//   sabb_, _dlío, _نقبل, оосв

  { {0xb8fe0372,0x96660080,0x9d1b000f,0xad1b000a}},	// [d400] _तक_, икае, _שופט, _בוקר
  { {0xe9da20f1,0x06560033,0xf65600e2,0xf62607d1}},	//   _ако_, ртаў, ртаю, адзо
  { {0x4a7b000a,0x7a7b000a,0x61080046,0xa6db001a}},	//   _בריב, _בריס, děln, _guðm
  { {0x7afc01e2,0xb3860015,0xe4760033,0xcd96004f}},	//   lirt, لجته, ружэ, ידעת_
  { {0x68e30011,0x33f6000d,0xf8b3000a,0x6101003d}},	//   _înda, јчес, _ושר_, cēli
  { {0x66e60549,0x9bb7000a,0xa2f3005e,0x62630054}},	//   _тога, יהנה_, опіч, овља
  { {0x7afc00f2,0x3265005e,0x3eae5547,0x64a64db5}},	//   iirt, стів, _raft_, _кава
  { {0xa3b3005d,0xc95300f3,0x7afc5548,0x91b7006b}},	//   टिश_, חמה_, hirt, ргът_
  { {0x61250050,0xd0100029,0x7afc5549,0xe8d7000a}},	//   póln, ثلة_, kirt, שופר_
  { {0xd6d3000a,0x7522554a,0xf402003d,0xdcfb01ec}},	//   ַׂר_, lloz, riģē_, dutā
  { {0x78a40007,0xc04f0127,0x10a605b3,0xc0d6002b}},	//   keiv, _мі_, _виен, _پيشب
  { {0xf1b3005d,0x4c95004a,0x69dc554b,0x75220079}},	//   ंटरन, щимс, dyre, nloz
  { {0x8f5403c4,0x657e002d,0x69da00cb,0x9b450015}},	//   _انتش, hrph, øten, إنسو
  { {0x61010048,0x3f84554c,0x3f910011,0x6e940031}},	//   vēli, mumu_, ăzut_, _طلبا
  { {0x5d84003b,0x8937003b,0xdcfb0024,0x3f84554d}},	//   _العل, لعرا, autā, lumu_
  { {0xacf40029,0x61010024,0xf77300e6,0x99840015}},	//   _وسيت, tēli, قاط_, تلفو
  { {0x7522016f,0x629a00bd,0x7afc554e,0x97250015}},	// [d410] dloz, _obto, birt, مفرو
  { {0x4545003b,0x8f570008,0x69dc0f47,0xab280054}},	//   منطق, יסמא_, byre, _коња_
  { {0xdb0d01e2,0x3f84003f,0x79a70180,0x69c804f8}},	//   _araç, humu_, _трпе, ädet
  { {0x45180191,0x78a40041,0x3f844379,0xa3b3005d}},	//   ація_, ceiv, kumu_, टिल_
  { {0x3f8403eb,0x07a40010,0x889a0008,0xa3f4005e}},	//   jumu_, _даўн, _גברי, опці
  { {0x60c2554f,0x3f845550,0x2169004a,0x7ce60125}},	//   _anom, dumu_, гики_, _móra
  { {0xe0570086,0xfa780008,0xddda0089,0xd24e0015}},	//   لیات_, בעות_, patř, رني_
  { {0xf8a7014e,0x27ed0107,0x8505002b,0x339b0015}},	//   ख़िय, _ženy_, _اورن, _لخطة_
  { {0xef190063,0xdb0d001c,0xfc3f002d,0x3f845551}},	//   лми_, _graç, idís_, gumu_
  { {0x60c200c0,0x0d85058f,0x2bcb000b,0x8189006e}},	//   _enom, блон, ामना, _منطق_
  { {0xa6db0084,0x290b005c,0x6da5085d,0x7afc5552}},	//   _auðk, _ojca_, щина, virt
  { {0x7afc00b8,0x63bb5322,0x4c83005e,0xacea004a}},	//   wirt, _krun, плюв, умма_
  { {0x7afc0007,0x7ce6002d,0x69c1003c,0xeb9703fc}},	//   tirt, _córa, ålen, бия_
  { {0x75220237,0xa3d8000b,0xfe450004,0x69dc2ecb}},	//   zloz, ाहत_, _унко, tyre
  { {0xf2d20053,0x7afc0084,0x3ea55320,0xb9b5006b}},	//   לעך_, rirt, melt_, остъ
  { {0x26c3016e,0x7ce6006f,0xdcfb003d,0x3859004a}},	//   _anjo_, _fóra, putā, ирую_
  { {0x3cfd000b,0x7ce6002a,0xb87b001a,0xf74a0067}},	// [d420] _लगते_, _góra, _glím, اجره_
  { {0xd3080092,0xa7850015,0x78a40030,0xfc3f0030}},	//   iệc_, تشفو, seiv, rdít_
  { {0xfad70053,0x69c8003c,0x41a6000b,0x9446002b}},	//   _הויך_, åded, _कैंस, مپان
  { {0x20d8002f,0xdb0d001c,0x3ea510cc,0x1c1c000b}},	//   _léir_, _praç, helt_, _नडाल_
  { {0x2d851341,0x2618000b,0xd91b000a,0xdcfb0045}},	//   hule_, _बुरी_, _תוכל, lută
  { {0x3f840048,0x2d8536e0,0x63bb5553,0xc2970033}},	//   vumu_, kule_, _drun, йкіх_
  { {0xd1300074,0x21670001,0x63bb0028,0x75d60067}},	//   ومت_, бији_, _erun, _ايزا
  { {0x63bb0011,0x9f540511,0x20d8016e,0x3f845554}},	//   _frun, ович, _réis_, tumu_
  { {0x39420005,0x9ec60086,0xf8b3000a,0x1eaa0021}},	//   _miks_, مزده, לשה_, هادي_
  { {0xd36f0029,0x3f840df3,0x5d980010,0x4357000a}},	//   _أهل_, rumu_, акоў_, _לסמל_
  { {0x2d855555,0xb1e50015,0xdcfb0045,0xd257000a}},	//   gule_, _وأمه, jută, _השבה_
  { {0xf1b3013a,0x272f0064,0x39420409,0x6d5a2233}},	//   _מסע_, müne_, _niks_, rpta
  { {0x8fa30080,0x38600c76,0xda7b005e,0x10030033}},	//   _наце, dbir_, ляв_, _няшм
  { {0x3ea50024,0xde58042b,0xda7b0033,0x7bdd0034}},	//   celt_, _такі_, ыям_, rysu
  { {0xf3f904f9,0x1e970008,0xac950033,0x272f0061}},	//   _veţi_, _הכול_, _дайш, nüne_
  { {0xcce70086,0xa3d8000b,0x2e230058,0x98ba0535}},	//   _دستي, ाहा_, _عفيف, _kupę_
  { {0x6d4a003f,0x69c80c77,0x6101003d,0x5b250015}},	// [d430] _hufa, äder, cēlu, _وفعل
  { {0x6d4a000c,0xba99005e,0x7c2d5556,0x17f80015}},	//   _kufa, _твоє_, _izar, حرفة_
  { {0xbb3c0053,0x68e30011,0x7e9b000a,0x394200cb}},	//   _געזי, _îndo, רסבו, _fiks_
  { {0xa6340036,0x3ea50548,0x69c800cb,0x628a0030}},	//   їнці, zelt_, ådee, egfo
  { {0x68ed3719,0xd37b0a9d,0xe28e05a7,0xf8b6004f}},	//   mhad, уче_, ма_, _ופרי_
  { {0x68ed03af,0x6d58016f,0x1308005e,0x8b8c000a}},	//   lhad, _otva, бній_, רָאֶ
  { {0x20d8002f,0x23600024,0x290900f2,0x272f0064}},	//   _réir_, ģija_, onaa_, güne_
  { {0xfbdf001c,0x69130064,0x3ea500b8,0x63bb162b}},	//   ncês_, tçey, welt_, _trun
  { {0x443903af,0xa6db002e,0x6d581cdb,0x63ad001c}},	//   _às_, _auði, _atva, çand
  { {0x7d0d0607,0x8d750015,0x442d0f0a,0x2d855557}},	//   _ajas, ياجا, _ize_, tule_
  { {0x70790086,0x7d0a0054,0x3cca113a,0x272f0061}},	//   _نماز_, иног_, ално_, cüne_
  { {0x3ea51c23,0x61010024,0xee360010,0xe3a70002}},	//   selt_, tēlu, ўню_, ور_
  { {0x7c2d005c,0x351a0053,0x80270067,0x79950028}},	//   _czar, שורנ, _ارام, etzw
  { {0x7ce6005c,0xc43a000a,0x1c430033,0x3ce9007c}},	//   _górn, יתרי, ьням, _elav_
  { {0x442d0089,0x68ed32cc,0x3942002a,0x4dd50033}},	//   _lze_, fhad, _piks_, _філф
  { {0xa9260191,0xa3e9021e,0xfc3f0077,0xcd360015}},	//   ідал, मना_, seía_, _برتب
  { {0x6d4a00b8,0x272f0061,0x38603e80,0x69c80789}},	// [d440] _zufa, züne_, rbir_, ådeb
  { {0x98b90024,0xb7d70015,0x272f0061,0x1db0000b}},	//   _visā_, غولا_, yüne_, _जनमत
  { {0x39420048,0x68ed002d,0x4a9b000a,0x1a9b004c}},	//   _tiks_, bhad, _דייג, _דייע
  { {0xff47002b,0x98be003d,0x76490061,0x6e2300aa}},	//   _يخ_, ītē_, _şeyt, _mynb
  { {0xbebc0024,0x54b70033,0xf772006e,0x442d0bba}},	//   dlīn, ўгія_, _تاج_, _cze_
  { {0x6d440604,0x272f0061,0xfc17000a,0x78b60091}},	//   _liia, tüne_, חקני_, ldyv
  { {0x84e60036,0x442d0111,0x6ecd000b,0xb97a000a}},	//   _довж, _eze_, तानु, ׁנַי
  { {0x68e40020,0xf1170015,0xc4c60015,0x272f068c}},	//   nkid, يغيت_, _بتسو, rüne_
  { {0x6d580a00,0x68e40020,0xb87b002e,0x4ea61ab5}},	//   _stva, ikid, _slík, орна
  { {0x232a010f,0x42530015,0x7f435558,0x7bcb0144}},	//   _този_, _ينقر, _cinq, _àgui
  { {0xf653013a,0x68e40020,0x7e6a002e,0x7c2d0eba}},	//   וצת_, kkid, _vefp, _szar
  { {0x26d802d7,0xa0a6004a,0xd48f0054,0x6fb60015}},	//   _loro_, _фадд, ерy_, _ومضا
  { {0x9bf40010,0x309b004f,0xa7fb039f,0x0000006a}},	//   дзяч, _כשאמ, _teñi,
  { {0xcf260015,0x29670054,0x4424002a,0x6d4a5559}},	//   _برصي, жњав, _mym_, _tufa
  { {0x5b140191,0x286b0001,0xe6c9005d,0xb86b000d}},	//   ємст, ирао_, रासङ, ијае_
  { {0xd7770029,0x61080089,0x32f6002a,0x5ba70a66}},	//   قاطع, dělk, pływ_, _дроз
  { {0xd7940063,0xf7730018,0x68ed013c,0xaceb002b}},	// [d450] митъ, باز_, rhad, _مرکل_
  { {0x7d1d4429,0xd5bb0760,0x6f79000a,0x1f5b004c}},	//   loss, исе_, מְעו, ידמא
  { {0x25480061,0x69c10789,0x7d1d014b,0x442d1351}},	//   _oğlu_, æled, ooss, _sze_
  { {0x83fd00dc,0x3eb90024,0xe4e413ae,0xfe370008}},	//   _időz, ēsti_, мічн, קראי_
  { {0x27f2005c,0xc7b90030,0xdce90091,0x26d829c1}},	//   czyn_, _éő_, sudė, _foro_
  { {0xa6db0084,0x6d02005d,0x883a0008,0x614504c2}},	//   _auðv, _लगभग_, _לתרו, пека
  { {0xddc30011,0x1a9c0053,0x1a7c000a,0xa252002b}},	//   _menţ, ייגע, שְׂמ, رپيش
  { {0xf8bf0016,0x54552fd2,0x26d8555a,0x439500ce}},	//   _ghét_, _хват, _zoro_, _набс
  { {0xd12e0029,0x7d1d555b,0x442410d2,0x442d0085}},	//   دمي_, doss, _gym_, _uze_
  { {0x6d440020,0xa3d8000b,0xaf980033,0xf2d80015}},	//   _siia, ाहर_, ітых_, _وظلت_
  { {0x1c01005d,0xa3b3005d,0x32b80029,0xe1650086}},	//   _लेबल_, टिक_, _بدقة_, _رضای
  { {0x692c00b8,0xc212000a,0x1d0a004a,0x6eed2d10}},	//   eßen, _אהב_, семи_, _súbd
  { {0xd3080023,0x6d440020,0xeb9703ad,0xa3c4000b}},	//   iện_, _viia, пия_, एमए_
  { {0x5e450029,0x6fb20029,0x2734007c,0xddc30045}},	//   _عَبْ, _أموا, mäng_, _cenţ
  { {0x38c80074,0xc3320008,0x7ced0003,0xa9670a32}},	//   ياری_, גום_, _sûre, зиса_
  { {0xf1b20053,0x7d7a0008,0x993a05d1,0x4dda000a}},	//   עסן_, _הנקו, сягу_, _לחצו
  { {0x68e40020,0xdb04002e,0x61130045,0x2ca0555c}},	// [d460] rkid, _frið, căle, _ibid_
  { {0x98a9005c,0xc7230080,0xabfb0008,0xf1bd005d}},	//   ymać_, едуй, _להפר, ्मान
  { {0x7ae100dc,0xf769000a,0xaadb000a,0x27f2002a}},	//   ölte, רק_, _החיר, szyn_
  { {0xdcfb0024,0xed560053,0x1957000a,0x4498005e}},	//   ortā, לבער_, _מבטל_, івлю_
  { {0xd8d700b2,0x88bb000a,0xe8d7000a,0xa6db001a}},	//   _זוכט_, _הזכי, _זוכר_, _auðu
  { {0xe7370063,0xb15c005e,0x0000006a,0x0000006a}},	//   _нея_, анкi,   ,
  { {0x55870004,0x21670054,0xe5a32124,0x6f0100bc}},	//   _нбрм_, пији_, _пири, dilc
  { {0x757b0008,0x4424066f,0x21670054,0x239e003d}},	//   _לטלפ, _tym_, чићи_, tājā_
  { {0x4053040b,0x7d1d51ec,0x7afe0006,0x7879004f}},	//   رئيس, voss, _ompt, חָתו
  { {0xd24f0029,0xb23a0029,0x620700dc,0x2ca01839}},	//   _منك_, _هكذا_, árlá, _abid_
  { {0x612500dc,0x10a6007a,0x0697000a,0x64490061}},	//   zóli, _нижн, הדים_, şmiş
  { {0x7afe00dd,0xc104002b,0x7ce62568,0x27340072}},	//   _ampt, _کوچي, _fórm, bäng_
  { {0xa2d3005d,0x00bb000a,0x6be40015,0xe81c000b}},	//   बॉक्, _למאמ, ّكُم, _भुला_
  { {0xa03b013a,0x3f7b0053,0x61080089,0xdb500015}},	//   _העדפ, _פאוס, děli, اَّ_
  { {0x3a2500fb,0xd3080023,0xfe9b013a,0x0e9b0008}},	//   ælp_, yện_, _היומ, _השול
  { {0x7afe003e,0x7db30015,0x69c800cb,0x6125555d}},	//   _empt, _أصوا, ådea, tóli
  { {0xc64b0029,0xbc7c000a,0x7b150004,0x27340123}},	// [d470] مجال_, _הנחת, _одих, känd_
  { {0x3f520092,0xaa67004a,0x4a5501c5,0x612510e5}},	//   _mâu_, _этик, _юкос, róli
  { {0x3f520092,0x94d5042b,0xa4d5005e,0xaadc000a}},	//   _lâu_, можц, можі, _לחזר
  { {0xe4540033,0xb87b016e,0x6125555e,0x6f01555f}},	//   екцы, _alív, póli, zilc
  { {0xa6db002e,0xd7f8000d,0xddc30057,0x3f520016}},	//   _suðu, _еур_, _menš, _nâu_
  { {0xeb92000f,0xd299005e,0xceb8002a,0x27340123}},	//   דָה_, ітлі_, jdę_, väng_
  { {0x31560015,0x6f015560,0x0000006a,0x0000006a}},	//   ولوج_, vilc,   ,
  { {0x27340123,0x64490034,0x0000006a,0x0000006a}},	//   täng_, _ugei,   ,
  { {0x3f520023,0x442b0092,0x1ef90015,0x33950058}},	//   _câu_, _ác_, قعدة_, _زلاز
  { {0x273400c0,0x0ea90080,0x6006054f,0xb4440033}},	//   räng_, цкой_, ьным_, _чэск
  { {0x81bc0024,0x9db90010,0xbebc0024,0xcee80015}},	//   _dzēs, цыпу_, olīj, ثرين_
  { {0xddc30024,0xeb9a05c4,0xc1050002,0x6f015561}},	//   _cenš, оим_, _توصي, silc
  { {0xc476000a,0x27340012,0xceb80091,0x7c29002a}},	//   ותרו_, läne_, bdę_, żern
  { {0xfe710086,0x3f980011,0x6f7a0008,0x63a40064}},	//   _شدت_, ărut_, _וְהו, çini
  { {0x61130011,0xbb43194a,0xab2718fc,0x0000006a}},	//   călc, терк, фора_,
  { {0x52da014e,0x3eb9003d,0xbb860015,0xd7ea00af}},	//   _बक्स, ēstu_, _قلبي, омбе_
  { {0xf0920008,0x61e30034,0xdce9003d,0x3f520016}},	// [d480] כנן_, hynl, zudī, _xâu_
  { {0x61e300dd,0xc9aa04ab,0x4eca004c,0xc956004a}},	//   kynl, _двое_, ֿזײַ, _отмы
  { {0x273401d1,0x395e0030,0xa6db001a,0xcb13000a}},	//   vänd_, ítsd_, _auðs, _בלז_
  { {0x2d85002f,0x2d53001c,0xd4670001,0x61080089}},	//   irle_, _mãe_, дице_, pěli
  { {0x97840086,0x1bf6000b,0xd5b10016,0x1c040065}},	//   _سیاه, ीपटल_, _ấn_, रपटल_
  { {0x98b900df,0x2492005c,0x8c1b000a,0x3f5236c3}},	//   _visą_, żym_, חוני, _râu_
  { {0x3f520092,0x7ce6005c,0x0566042b,0xf8bf0016}},	//   _sâu_, _córk, _іван, _khép_
  { {0xf9930008,0xe6110008,0xceb8005c,0x8ca0000b}},	//   דרה_, _עִם_, wdę_, ग्मो
  { {0xb7db00b2,0xaffc0033,0xa6db001a,0x98be0091}},	//   ַקטי, сопi, _guðs, ūtė_
  { {0xceb80007,0x81bc003d,0x1dc9000b,0x1fa3006b}},	//   udę_, _dzēr, िमंत, тръг
  { {0xdb2100dc,0xdd900021,0x7ce61116,0xb2260033}},	//   _ítél, دوج_, _kórh, _ўмел
  { {0x6ee40251,0x41030063,0xd3080016,0x2167006b}},	//   _mòbi, _изхв, iệm_, _цици_
  { {0x69c802df,0xddda0030,0x2d855562,0x69da5563}},	//   åden, ratő, arle_, äten
  { {0xce94006b,0xddd80061,0xf2df0045,0x1eaa00c3}},	//   _чакъ, _gevş, _îât_, _ذاتي_
  { {0x39150403,0xd915004a,0x61130045,0x26cd0016}},	//   емвр, едвы, lăla, _đeo_
  { {0xf8bf0092,0x67d5005e,0x2d8c007c,0x200b002a}},	//   _chép_, нобу, mude_, źcie_
  { {0xf7700225,0x2d8c5564,0x0c740031,0xdcff0091}},	// [d490] لال_, lude_, _شديد, _švėk
  { {0xf72b0010,0x96070021,0x65870033,0x1a65009a}},	//   іцай_, وبام, дыдз, _سیری_
  { {0x2d8c2b7d,0x3eac0079,0x0000006a,0x0000006a}},	//   nude_, iedt_,   ,
  { {0x395e00dc,0xd7fb0054,0xf8bf0016,0xbf1a0065}},	//   ítse_, _дуг_, _ghép_, नकुन_
  { {0x7d0f00dc,0xb87b002d,0x185a000a,0xa85a000a}},	//   incs, _dlít, _מכרע, _מדרכ
  { {0x41b50124,0xeb920008,0x2d8c007c,0x61e3008c}},	//   есит, רָא_, kude_, tynl
  { {0xe97c0053,0xcad8000a,0xbbcb000b,0x2d8c5565}},	//   ַנזש, ווגת_, ामुक, jude_
  { {0xfa0d0023,0x78ad04f9,0x2d8c2bb7,0xc5f2000a}},	//   _đầu_, neav, dude_, _עדן_
  { {0x61e301f0,0x63050015,0x6009005e,0xdee502ed}},	//   synl, _كورل, яним_, еопи
  { {0xf8ac005d,0xd2510015,0x61080046,0xc7b2000a}},	//   _चस्प, _إنا_, dělu, נבי_
  { {0x2d8c0020,0xe718000a,0x78ad008c,0x0000006a}},	//   gude_, וחזר_, keav,
  { {0x998d0050,0x31560053,0x6eed002d,0xa107002b}},	//   łeś_, _װיסן_, _dúba, _غذاه
  { {0xf3f2000a,0x78ad5566,0x9fe700c3,0x4d1502ed}},	//   ָ֣ר_, deav, _تساه, тьэт
  { {0x3eb90024,0x69c8003c,0x2d8c0156,0xdaba0010}},	//   ēsts_, ådeo, bude_, чымі_
  { {0xf8bf0023,0x18a606b3,0xf1a70015,0x3f8d0144}},	//   _phép_, навм, دء_, lueu_
  { {0x395e0048,0xa3cf005d,0xfd12002b,0x236d002a}},	//   īts_, षमा_, _حجت_, _owej_
  { {0xf7720029,0x3f8d0251,0xb908000b,0xb806002b}},	// [d4a0] طاء_, nueu_, _भव_, ربره
  { {0x8c1b013a,0xbc1b000a,0x2905001a,0x5a66013e}},	//   _מופי, _מופש, élar_, _якоб
  { {0xf8bf0092,0xcb13000a,0x1cba000a,0xe6930015}},	//   _thép_, _תלת_, ּמְע, المد
  { {0x7d065567,0x78ad5568,0x0000006a,0x0000006a}},	//   niks, ceav,   ,
  { {0xa29402e5,0xf7720018,0x2bc3000b,0xd326034e}},	//   валі, _حاج_, शिया, ньки
  { {0xd24f0087,0x60cb5569,0xb87b0052,0x7d06142c}},	//   منه_, _angm, _flís, hiks
  { {0xe5060015,0x44fa0033,0x7d0601be,0x799c002a}},	//   _كبري, _ехаў_, kiks, ntrw
  { {0x859b0008,0xd3720002,0x7d06008c,0x2d8c007c}},	//   _משלו, _مهر_, jiks, vude_
  { {0x3f8d08e0,0xff0602bf,0x61080046,0x7d06556a}},	//   gueu_, еянн, dělt, diks
  { {0x798e000c,0x7d062233,0xd80b000a,0x629e0144}},	//   kubw, eiks, לִיָ, òpod
  { {0xa3d8005d,0xf56e005e,0x3eac2a94,0x69da008c}},	//   ाहक_, акiв_, redt_, ätel
  { {0x2d82556b,0x798e003f,0x2d8c4e9b,0xa157000a}},	//   čke_, dubw, rude_, _נבדה_
  { {0x70530029,0xddd800dc,0x2d8c435a,0xdee6176f}},	//   _إنها, _vevő, sude_, _поди
  { {0x7f170015,0x2be2000b,0x7d06433c,0xfa370058}},	//   _كينز_, _पथरा, aiks, فرزد
  { {0x1e57000a,0xc9840877,0x7d060601,0xcb34006b}},	//   _אשור_, лути, biks, уеръ
  { {0x61f50014,0x765c005c,0x6ec8000b,0x7bc4556c}},	//   _üzle, _afry, ़ाकु, _friu
  { {0xcaa70015,0x97250015,0xab620061,0xd7e4008b}},	// [d4b0] _كصدي, نفرو, şüre, ліфо
  { {0x93c70045,0xf7840015,0x8f8b000a,0x2d6e0046}},	//   nvăţ, اللَ, לְבֵ, oře_
  { {0xd9150010,0x61080089,0x236d005c,0x3f990061}},	//   _адны, něls, _swej_, çsuz_
  { {0xa8790053,0xd5b10092,0x16380015,0xb87b0030}},	//   _קאָר, _ấm_, رسلة_, _elír
  { {0x98ab005c,0x3869556d,0x765c0034,0xf3670148}},	//   _chcą_, mbar_, _ffry, хтен
  { {0x6b9d00b8,0x7d060064,0x38692d92,0x2127002b}},	//   itsg, ziks, lbar_, کيبی_
  { {0x41b20015,0x6b9d02ad,0x38690160,0xe4a7116f}},	//   لمور, htsg, obar_, _прао
  { {0x61080089,0x9f520264,0x38690abd,0x2ea9000b}},	//   děls, ždým_, nbar_, क़्त
  { {0xe3e9002b,0x68e30045,0x7d06556e,0xccf90046}},	//   _تکان_, _îndu, viks, rpěl_
  { {0x3869556f,0x7fe800a2,0x3f8302c6,0xa2270015}},	//   hbar_, عريف_, čju_, _كراه
  { {0xcc8a0074,0xee390a7f,0x30e70036,0xaad5005d}},	//   ونده_, ьно_, _підб, दानक
  { {0xd7d1014e,0x69c8003c,0xc1780029,0x6b9d04d4}},	//   समाच, ådem, _أصلا_, ftsg
  { {0x3f8d08e0,0xde160086,0x547a000a,0x3d02000b}},	//   queu_, فقیت_, וטרו, _लगीं_
  { {0x2d6e0089,0x212d00d9,0x7d0643d9,0x63a90573}},	//   bře_, lleh_, siks, _mpen
  { {0xc92a0036,0x212d0375,0x6b9d0ec2,0x38690012}},	//   довж_, oleh_, atsg, fbar_
  { {0x99430029,0x63a95570,0x6ba50123,0x98a00091}},	//   لَّه, _open, åtgä, klią_
  { {0x69c500b8,0x657c016f,0x799c0026,0x6bd700a2}},	// [d4c0] _erhe, _svrh, strw, _لويس_
  { {0x96630080,0x386903b7,0x16590033,0xdb08008c}},	//   икуе, abar_, ерць_, äläi
  { {0xceb20008,0x63a95571,0xd5af0015,0x38695572}},	//   שיב_, _apen, يفك_, bbar_
  { {0xd4d50010,0x80a1005d,0x62812e4a,0x1957000a}},	//   лічэ, _कॉले, _adlo, _שבכל_
  { {0x2912064e,0x39405573,0x6c57004f,0x98a00535}},	//   mnya_, mmis_, דינא_, glią_
  { {0x39400c58,0x2912013c,0x7413002b,0xf1a6052b}},	//   lmis_, lnya_, جوها, врин
  { {0x7d040197,0x39400007,0x8cc5000b,0xaaa4000b}},	//   _omis, omis_, ियमो, ख्यक
  { {0x2d6e0089,0x2912013c,0x41e3005e,0x361b000a}},	//   vře_, nnya_, ріша, _חולד
  { {0xa8e00023,0xb4ae005d,0x3940002d,0x9ec60086}},	//   _độn, क़ी_, imis_, نزده
  { {0xf7730008,0x29120849,0x883b000a,0x2d6e0046}},	//   סקת_, hnya_, ותפו, tře_
  { {0x2912013c,0xc693000a,0x01da0015,0x40960015}},	//   knya_, באת_, _توضع_, _للضر
  { {0x291201c2,0x6b9d11b6,0x2d1d0065,0x6281005a}},	//   jnya_, ttsg, नवेल_, _zdlo
  { {0xdb2500dc,0xa3d8005d,0x29120509,0xf093000a}},	//   ősít, ाहट_, dnya_, _כנף_
  { {0xd00f0086,0x39400020,0x2fc602f2,0x7d045574}},	//   _بله_, emis_, _irog_, _emis
  { {0x386900b8,0x1dd70015,0xda090015,0x29120049}},	//   tbar_, _لبيع_, ريره_, fnya_
  { {0x395e00dc,0x68f60026,0x91bb000a,0x2fc65575}},	//   ítsa_, ghyd, ומלי, _krog_
  { {0x386602c1,0x38351588,0xa854006b,0x38695576}},	// [d4d0] ñora_, унар, ркуч, rbar_
  { {0xb6f40124,0x8f9b0008,0x2124002d,0x29120049}},	//   азуј, וימי, homh_, anya_
  { {0x272f00dc,0x69c55577,0x29120049,0x2d9e0d40}},	//   lünk_, _urhe, bnya_, ntte_
  { {0x68f60026,0x3ebc0293,0x4864006b,0x6108002a}},	//   chyd, _lavt_, _върб, yśla
  { {0x3cfc0053,0x6d4d02b9,0x78fa000a,0x272f0030}},	//   ולאנ, _miaa, _נפשו, nünk_
  { {0xe2960083,0x68ed5578,0x6d480030,0x0324005e}},	//   гаш_, lkad, íjaz, адін
  { {0x6eed5579,0x10a50063,0x78bd09e7,0x27e9557a}},	//   _súbo, гийн, _kasv, lyan_
  { {0x272f00dc,0x7fd90004,0x3d02000b,0x2909008c}},	//   künk_, ефот_, _लगें_, niaa_
  { {0xdce20024,0xc0c80001,0x78bd0024,0x7c2d557b}},	//   zslē, тује_, _masv, _nyar
  { {0xb0620c8d,0x66ac0008,0x69c8003c,0x9e6502bf}},	//   ääri, ֵיכֶ, ådek, ывод
  { {0x7c2d01e2,0xde05032e,0x645e002a,0x27340123}},	//   _ayar, упни, śpie, känn_
  { {0x78bd00bd,0x9e3c0107,0x3079004c,0x2a780012}},	//   _nasv, veďt, _װאַנ, warb_
  { {0x2d9e557c,0xbea50b97,0x272f00dc,0xb4fa000a}},	//   atte_, _балк, günk_, תפרי
  { {0xdce20048,0x442d003c,0x7dc50015,0xed4e002b}},	//   tslē, _mye_, _مقتن, _کپي_
  { {0x63be0024,0x68f60dc7,0x2912013c,0xaa570015}},	//   āpni, thyd, tnya_, الفا_
  { {0x2dd80029,0xdce20024,0x290900f2,0x3940138c}},	//   _جبهة_, rslē, giaa_, umis_
  { {0x27e900b6,0x68f60026,0x29120849,0x8cd1005d}},	// [d4e0] gyan_, rhyd, rnya_, धारो
  { {0x29120849,0x7bcb001c,0x60db007c,0x8ca0000b}},	//   snya_, _água, hjum, ग्रो
  { {0x1a9b00b2,0x4a9b0053,0x3f9f00f2,0x96550001}},	//   _אייע, _אייג, htuu_, рђуј
  { {0xdb0d0084,0x68ed557d,0x4e360053,0xb4ae005d}},	//   _hrað, ckad, אָדן_, क़े_
  { {0x98a0005c,0xa2e6005e,0x6eed4b02,0x28d1000b}},	//   elić_, лодд, _públ, हारि
  { {0x68e30011,0x2d9e079b,0x80a1000b,0xa6460015}},	//   _îndr, ytte_, क्से, _مخزن
  { {0x81a60029,0x60db002e,0x272f00dc,0x442d437f}},	//   احتل, fjum, zünk_, _eye_
  { {0x6fb40029,0xdfd00002,0x2054006b,0xd4690015}},	//   لمبا, قيب_, шкия, _لحكم_
  { {0x98ab005c,0xd0100029,0x8cd8005d,0x2ef405aa}},	//   _chcę_, تلة_, यानो, изир
  { {0x979b0053,0xc7b3000a,0x6e940015,0x6abe06cd}},	//   עשיק, צבת_, جلدا, _napf
  { {0x23600024,0x7c2d0d25,0x22160010,0x2d9e151c}},	//   ģiju_, _syar, _сфар, utte_
  { {0x61e500b8,0x272f00dc,0x4c95004a,0xd5fb000a}},	//   ähle, tünk_, шимс, תפטר
  { {0x9b580063,0xbed4000d,0x75eb0030,0x78bd3009}},	//   лият_, _волј, _közú, _rasv
  { {0x7ce6002f,0x272f0014,0x3ffb0053,0xbebc0024}},	//   _sórt, rünk_, _אפדע, glīt
  { {0xc333013a,0x80a1000b,0x272f0030,0x7e7a0990}},	//   מוש_, क्वे, sünk_, matp
  { {0x272f0030,0xd7fb0004,0x0000006a,0x0000006a}},	//   pünk_, нуз_,   ,
  { {0x7c2d01e2,0xd7950063,0x67d4000d,0x290900f2}},	// [d4f0] _uyar, ризъ, боту, riaa_
  { {0x2d8c020a,0x7ce6024b,0xa6350033,0x66740015}},	//   orde_, _fórs, анзі, مدمر
  { {0x7ce6005c,0xe4e70127,0x2a76000a,0xd5b10067}},	//   _górs, лідн, _דעתך_, تفا_
  { {0xf795008f,0x672500f2,0xd3080092,0x2d8c002d}},	//   _камэ, sohj, iệu_, irde_
  { {0x672500f2,0x287a000a,0xe299557e,0x987a000a}},	//   pohj, _שנשמ, вал_, _בארט
  { {0x0595002b,0x98a009bb,0x3a2d0046,0x91e50740}},	//   _پاسگ, tlić_, řepu_, иоле
  { {0x442d00dd,0x929200d0,0xf314002b,0x6d5c0046}},	//   _wye_, цајц, حبنظ, íral
  { {0x3f9f00f2,0x442d00dd,0x2d830046,0x69c800cb}},	//   ttuu_, _tye_, ájem_, ådei
  { {0x80a1005d,0x2d8c0384,0x3f9f00f2,0xbf640086}},	//   क्षे, erde_, utuu_, یدیو
  { {0x2ca90275,0x2d8300bc,0x63bb01c2,0x7e5503ae}},	//   _abad_, šjem_, _isun, штиц
  { {0xe80c014e,0x3f9f00f2,0x51840010,0x41b50067}},	//   _सेना_, stuu_, _гуча, _خمار
  { {0xe1620086,0x4c83005e,0xe588000a,0x1d0a170d}},	//   _بگوي, олюв, נָתָ, теми_
  { {0x4c360033,0xfc32006e,0x63ad016e,0x2d8c557f}},	//   рэнт, تحد_, çanh, arde_
  { {0x80a1005d,0x7a4000dc,0x5ffa000a,0x6ffa000a}},	//   क्रे, játé, _בהנה, _שהספ
  { {0x0000006a,0x0000006a,0x0000006a,0x0000006a}},	//     ,   ,   ,
  { {0xc955065e,0x3f5b0092,0x993a005e,0x57d1000b}},	//   стры, _kêu_, тягу_, समूह
  { {0xb8de005d,0x37060010,0xdc8b000a,0x6abe0353}},	// [d500] _इस_, апаг, _בְיָ, _tapf
  { {0x8ca7000b,0x4b7b004c,0x98ab003d,0x657e0012}},	//   ट्ठो, _שטיג, ījās_, tsph
  { {0xd3080092,0x63bb5580,0x98a607c3,0x7bc604d1}},	//   iệt_, _asun, _кине, lvku
  { {0x61ee00b8,0x938a18a7,0x9e48000a,0xb97b000a}},	//   _übli, вска_, אֲנִ, _בנטי
  { {0x3f5b0092,0x96760010,0xe3b200e5,0x657e5581}},	//   _nêu_, _выбі, ترا_, ssph
  { {0x3f8d08e0,0x2d8b005c,0x7a400046,0xfc3f0077}},	//   dreu_, ącej_, cáté, nfía_
  { {0xd259008b,0x4906000b,0x7e7a5191,0x0000006a}},	//   уці_, सोथो_, vatp,
  { {0x55bb0008,0x1f74006b,0x1fa60c6e,0x2d8c0085}},	//   _במלו, блия, арог, vrde_
  { {0xdfd000e5,0x50b700a2,0xdee60015,0x0000006a}},	//   سيد_, شديد_, لأدي,
  { {0xe465002e,0x9ed8000d,0x539b000a,0x5275005e}},	//   _þörf_, умот_, _בימו, _гуцу
  { {0x07370008,0x667b0053,0x6cd50015,0x3f8d0144}},	//   שאים_, כטיק, مقدا, areu_
  { {0x3fc80086,0x3f8d18b3,0xa06a1398,0x8fa6029f}},	//   _مدتی_, breu_, _рада_, _ваде
  { {0x81c70024,0x9d1800a4,0x63a25582,0x4ae70033}},	//   rtēš, роят_, nton, аўва
  { {0xdce200df,0x81c70024,0x63a25583,0x4ffb000a}},	//   kslė, stēš, iton, _שִׁנ
  { {0xed570083,0x58d5017a,0xedd30015,0x090720fe}},	//   _кој_, бовт, _ويهد, ачам
  { {0x3f5b0023,0xa3d6000b,0x08550033,0x718b000a}},	//   _yêu_, िमा_, сваю, כְמַ
  { {0xfb850086,0xad1c000a,0x56670015,0x63a20085}},	// [d510] _ادبی, _שוחר, لداف, jton
  { {0x6d580c8d,0x8bd8000a,0xdce2003d,0x63a206bb}},	//   _kuva, _כוחו_, mplā, dton
  { {0x24550115,0xe207002a,0xd5bb006b,0x63a25584}},	//   مناس, okół_, ъса_, eton
  { {0x95c40015,0xb6070091,0x6d580061,0xf487165a}},	//   غينه, _rašė, _muva, ружн
  { {0xd3080023,0x7ae509e7,0x493a0008,0x63a20ad5}},	//   yệt_, _koht, _תגרו, gton
  { {0x7ae5022d,0x7ae100dc,0x217500d0,0x3f5b0016}},	//   _joht, ölth, буир, _rêu_
  { {0x6d585585,0xe0d10015,0x63bb002a,0x63a23bb1}},	//   _nuva, كزة_, _wsun, aton
  { {0x5a180008,0x3f8d10f6,0x34940004,0x11390033}},	//   יקון_, treu_, _маср, ыялы_
  { {0x63bb0050,0xd3710086,0xfe790033,0x3f8d0144}},	//   _usun, _رها_, лёны_, ureu_
  { {0x3f8d2960,0x59d7005d,0x02450029,0x7995003f}},	//   rreu_, डमार, _هَذَ, kuzw
  { {0x91f40015,0xdee40015,0x69c70085,0x6d580022}},	//   _وأما, تأيي, jvje, _cuva
  { {0xf1c30007,0xcb6a5586,0x70592f14,0x6d585587}},	//   rašė_, ламе_, _садр_, _duva
  { {0x6f650029,0x70520806,0xa136000a,0xc1040015}},	//   _اهتم, _عنوا, _פאנק_, _بوني
  { {0x543a0053,0x643a0053,0xda650015,0xcf240015}},	//   טערא, טערנ, قافي, _وروي
  { {0x5d85003b,0x63a20014,0x8d950029,0xc33201d8}},	//   _البل, zton, _العش, פול_
  { {0x97da0080,0x63a25588,0x386001f6,0x0000006a}},	//   льзу_, yton, ucir_,
  { {0xddc30046,0x69c70085,0x38601e83,0xbb1a009a}},	// [d520] _jenž, avje, rcir_, _مزدا_
  { {0x0656008f,0xf6560418,0x6d580061,0xc815005e}},	//   стаў, стаю, _yuva, ієть
  { {0x2a570008,0x463a00a4,0x27340123,0x160a0015}},	//   _לבין_, учая_, länk_, دياً_
  { {0x6723016f,0x69c8003c,0xb0a6000b,0xd499005e}},	//   čnja, ådeu, _कॉंग, ирі_
  { {0xdb0d0020,0x4c9b000a,0x395a008c,0x63a25589}},	//   _eraõ, רבנו, _hups_, uton
  { {0xf7730008,0x63a2558a,0xf2c3006b,0x1837000a}},	//   _מקש_, rton, зсън, _לאכל_
  { {0xddda2233,0x63a2558b,0x41c60033,0x25ab013f}},	//   ratū, ston, сёла, čilá_
  { {0xa6170008,0xc953000a,0x27340123,0x64a329b7}},	//   _הקלד_, המה_, känk_, _наса
  { {0x69c7016f,0x7ff60015,0x15430054,0x6d58558c}},	//   zvje, إسعا, _хетм, _suva
  { {0x57fb000a,0xd7bb004c,0x67bb000a,0x69c70030}},	//   טלפו, נציר, נמיק, yvje
  { {0x12eb0008,0x1cd90033,0xd5b10016,0x22570015}},	//   _עַמּ, адны_, _ất_, _المد_
  { {0xa1570008,0xb1460001,0x7afc0012,0x3237004f}},	//   _הבאה_, _унел, ehrt, _פטאן_
  { {0xeafb0086,0x69c802de,0x7ae5558d,0xb1a60052}},	//   هرست_, æden, _poht, óðfæ
  { {0x6b841283,0x6d58558e,0x80b8000b,0xdce90061}},	//   _dvig, _tuva, ्यवे, rtdı
  { {0x395a00c7,0x5a440033,0xd90f002b,0x6b400030}},	//   _cups_, зэта, فید_, zögg
  { {0x61130011,0xdcfb003d,0x31c30046,0x2251006f}},	//   tăli, rutē, lézá_, _úzke_
  { {0x60c2000c,0xddc8016f,0xe803005d,0x7ae50451}},	// [d530] _maom, nadž, _रेखा_, _toht
  { {0x692c00b8,0x7c29002a,0x629e0144,0x0000006a}},	//   ußer, żers, òpol,
  { {0x69c83040,0xaa640033,0xfaf8002b,0x69da3286}},	//   ådet, _этык, _دريغ_, ätet
  { {0x60c21740,0x89e8000a,0xdce20045,0x64a5005e}},	//   _naom, _הַשֵ, mplă, іала
  { {0x889a000f,0x93a7004a,0x31a1002a,0x7544005e}},	//   _דברי, сшед, wóz_, їніз
  { {0xa2760054,0x1b7c004c,0x4b7c0643,0x0000006a}},	//   обљу_, נטוע, נאוו,
  { {0x6a9c013a,0x6aaa00b8,0x1a9c0053,0x04f50010}},	//   אשונ, _öffe, טיגע, _дзвю
  { {0x63ac0046,0x7a40001a,0x613e00aa,0x6f65030e}},	//   ílný, _hátí, eëlb, овиз
  { {0x7d0f00dc,0xb87b0107,0x8cd8000b,0x7b090c6d}},	//   dics, _blíz, यासो, ržuj
  { {0xe4500029,0x5f050036,0x0cb2000b,0xbd8500eb}},	//   _أضف_, ізна, ज़्म, огок
  { {0xc6920008,0x7ed50086,0x6b84558f,0x2d830030}},	//   ואי_, مزگا, _svig, éje_
  { {0x2d8b0089,0xbebc0024,0x7bcd5590,0x395a5591}},	//   čce_, slīp, _brau, _rups_
  { {0x6d5e0003,0x7c3a002a,0xdce20045,0xbb75009b}},	//   _épan, ętro, eplă, зусъ
  { {0x7bcd18a6,0x5f74002b,0x2d95011e,0x0000006a}},	//   _drau, _راهر, _дрис,
  { {0xd3080092,0xceb2000a,0xf2d2000a,0xaa4a006b}},	//   iệp_, _חיו_, ועם_, рпва_
  { {0x7bcd1bfa,0xe8f70004,0x2734008c,0xa5da002b}},	//   _frau, олс_, mäni_, یبار_
  { {0x26c30467,0xd70a0010,0xa6e60080,0xfc320015}},	// [d540] _bajo_, анае_, ожал, _تحث_
  { {0x249f04f9,0xeb910053,0xdce20024,0x69c80cbf}},	//   _acum_, _אָט_, kslī, ådes
  { {0xa2dd005d,0x9f44006f,0xdcfb003d,0x26c300bc}},	//   पान्, nymá_, lstā, _dajo_
  { {0x7ae10030,0x69c8006f,0x236a012e,0x7fa9000b}},	//   öltv, ťdes, ајко_, _कहूँ
  { {0xa533005e,0xdc3a000a,0x44205592,0x3373005e}},	//   єніч, ׁעֲר, çi_, дгір
  { {0x3872003c,0x6b8b02de,0x018a0121,0x6b400012}},	//   lbyr_, _ægge, ащий_, böge
  { {0xe2970054,0xd24f002b,0x290b219f,0xd1b70015}},	//   цај_, ننه_, _ymca_, قايا_
  { {0xc0ca0124,0x89db0008,0xdcfb0024,0x6108002a}},	//   руке_, שחקי, kstā, ośli
  { {0x78fb0643,0x63ad5481,0xc0e70015,0xe4750033}},	//   יפקו, çant, تفين_, _хусэ
  { {0x201804f9,0x7f180015,0x945d002a,0xab630061}},	//   ări_, إيدز_, _tańc, şükt
  { {0x7d0f00f2,0xb65b0053,0x7bcd0007,0x865b0008}},	//   tics, ידיש, _srau, ידיי
  { {0xcd070191,0x7bcd5593,0x0000006a,0x0000006a}},	//   ічни, _prau,   ,
  { {0xdcfb0048,0x9be700e2,0xdbdd0030,0x7ac720f0}},	//   gstā, цінк, _káér, осве
  { {0x7d0f1e6b,0x0000006a,0x0000006a,0x0000006a}},	//   sics,   ,   ,
  { {0x80a1000b,0x52db004c,0xddc8002a,0xc87b0054}},	//   क्के, סקלײ, nadż, иџа_
  { {0x5e430029,0x5c75004a,0x6b400012,0xdcff003d}},	//   _غَيْ, _элит, vöge, ēvēj
  { {0x6fbc005d,0x69da00b8,0x984b0063,0x7d0d0091}},	// [d550] ्टिं, äter, рява_, _imas
  { {0x8ca7005d,0xc66b0010,0xd8280033,0x47780174}},	//   ट्रो, ршае_, ціск_, юбую_
  { {0x2aba013a,0x3aba0008,0xbb3c0053,0xa2ce000b}},	//   _המתא, _המתנ, _דעזי, _दफ़्
  { {0xe80c014e,0xf9920053,0x2eb7000b,0x290b0034}},	//   _सेवा_, _ארט_, _अस्त, _umca_
  { {0x39495594,0xf8da000a,0x26c31279,0xc8da004f}},	//   mmas_, _החרמ, _tajo_, _הקרט
  { {0xf776000a,0x291c001a,0xaacb000b,0x8505002b}},	//   _מעשי_, _ívar_, ायिक, _کورن
  { {0xd49b0083,0x78b40014,0xdcfb0024,0x39490a49}},	//   _врз_, _üdvö, zstā, omas_
  { {0x2734008c,0x94050015,0x25ac0123,0x6f1a5595}},	//   väni_, _فوزه, _ädla_, entc
  { {0xdcfb0007,0x3cdf000b,0x3f840091,0x44395596}},	//   lutė, गाने_, gsmu_, _ás_
  { {0x3f860089,0x7d1d002e,0x3949007c,0x61130045}},	//   _dvou_, érsn, hmas_, vălu
  { {0xcee80074,0xdcfb00df,0x00550058,0x0000006a}},	//   ترين_, nutė, _فَاج,
  { {0x6108005c,0x645c00dc,0xcb09000a,0xe572000a}},	//   yśli, _őriz, _גל_, עַת_
  { {0x2bba0029,0x2fc9002d,0x2734008c,0x3949007c}},	//   حاجة_, _éag_, säni_, dmas_
  { {0xdcfb0048,0xa0380015,0xcf270015,0x61130045}},	//   rstā, _بأمر_, _برؤي, rălu
  { {0x78af0023,0x9e7a000a,0xf9910015,0xd9460342}},	//   _bbcv, _הנצפ, َبِ_, зеви
  { {0xdcfb13b3,0x7bc0001a,0xec7a01b7,0x48e3261b}},	//   dutė, æmus, _упи_, носв
  { {0x4c9b0008,0xb4e5000b,0x7ceb000a,0x69d85597}},	// [d560] _השפע, _पकड़_, _הַיֶ, _šved
  { {0x39492f6d,0xfbd3000a,0x69cc000b,0x6125001a}},	//   amas_, _נתת_, हिदी, róly
  { {0x7e7e0005,0x4a5b0008,0x20bd000b,0x6d56179a}},	//   _õppe, _לדיו, ्याध, _kiya
  { {0x89db000a,0xba76002b,0xfdf6004f,0x23c70065}},	//   _החטי, _باکت, הצעת_, लिंद
  { {0x6d44002d,0xa857000a,0x7ccd004c,0x29125598}},	//   _mhia, _מיכה_, יצאַ, miya_
  { {0x6ef60152,0x883b000a,0xcc3b004c,0xdcfb0091}},	//   _câbl, _לתכו, זענט, butė
  { {0x3f860089,0x27f200f2,0xc1b8005e,0x82630015}},	//   _svou_, lyyn_, ілих_, رهين
  { {0x751a003b,0x2900001c,0x361b0008,0x6d565599}},	//   _اقرأ_, nhia_, _הולד, _niya
  { {0xa0670054,0x2cb90030,0x75230030,0xc3e60015}},	//   чања_, vesd_, énze, _عثرو
  { {0x27e00251,0x39490095,0x291211ac,0x6440559a}},	//   ixin_, zmas_, hiya_, _izmi
  { {0x394900df,0x6d5602f2,0x4c9520e6,0x0000006a}},	//   ymas_, _biya, минс,
  { {0x660101e2,0x6d44559b,0x20c90015,0x3f860046}},	//   _ülke, _chia, _وبني_, _tvou_
  { {0x703a03c4,0x6d44002d,0xa4e7000a,0x3cdf000b}},	//   _اساس_, _dhia, לֵךְ_, गाबे_
  { {0x3f8200df,0x1959008f,0x6f79000a,0xdee304d7}},	//   škus_, жавы_, _וְקו, _почи
  { {0x6d560064,0x6d440125,0x7f3b000a,0x9e331923}},	//   _fiya, _fhia, _העגו, _пешч
  { {0xce370008,0x57790010,0x6d4404ed,0xa954017f}},	//   _מאות_, жбаў_, _ghia, ексі
  { {0x7ae10014,0xb8e5005d,0x80a1000b,0x3949559c}},	// [d570] ölts, _एस_, क्टे, rmas_
  { {0x6d5601e2,0x4b7c0008,0xdb7c000a,0xabfc000a}},	//   _ziya, _האזו, _הנזכ, _להחר
  { {0x1875006b,0x2d540045,0x6440559d,0xe859135f}},	//   _огня, _oţel_, _azmi, _манш_
  { {0x4518005e,0x98a9002a,0x443f002a,0xf1c70046}},	//   пція_, dlać_, _pzu_, žáky_
  { {0x27e00016,0x53a50004,0x03a50fd5,0x41c20065}},	//   cxin_, фалб, фило, _वैबस
  { {0x2d85002c,0xb7da000a,0x200401c2,0xc87f0012}},	//   ysle_, _וקשי, dzmi_, _heß_
  { {0xf8b2001a,0xb457002b,0x82840058,0xd6d00369}},	//   _þáði_, _فیاض_, رجول, _حقّ_
  { {0x35b30036,0x3aef0072,0x0000006a,0x0000006a}},	//   _обґр, _küps_,   ,
  { {0x9f4400f2,0x6d440026,0x645b0077,0x33f40015}},	//   kymä_, _rhia, _igui, _كسكس
  { {0x6d5611d0,0x8e74042b,0xdd890248,0x4d651305}},	//   _siya, нуюч, обод_, мков
  { {0x57ba014e,0x6d560064,0x112b034e,0x8027002b}},	//   _उन्ह, _piya, _люди_, _کرام
  { {0xd00e0074,0x31c40036,0x6283559e,0x2d850e47}},	//   الی_, _ясув, lano, rsle_
  { {0x2d9a003c,0x5b360033,0x6d560061,0xbea504e7}},	//   _åpen_, дэву, _viya, _жалк
  { {0x7d1d00f2,0x2912003f,0x6008039e,0x6d5601d7}},	//   anss, wiya_, _מִצְ, _wiya
  { {0x6d5600b6,0xc3320008,0xe9a30127,0x6d440c0b}},	//   _tiya, דום_, карп, _thia
  { {0x62830176,0xbd460115,0x7d7a000a,0x27f2008c}},	//   hano, _تنبي, _ונקו, tyyn_
  { {0x3af400f2,0x27340123,0xc87f0012,0x2912559f}},	// [d580] _läpi_, känt_, _deß_, riya_
  { {0x291200b6,0x2900003f,0x60c900f2,0x473a0033}},	//   siya_, shia_, hdem, ічаў_
  { {0x29120035,0x5693005e,0x8ca5000b,0x7a470003}},	//   piya_, таєт, _कामो, rété
  { {0x6abc238c,0x60c92803,0x0000006a,0x0000006a}},	//   lerf, jdem,   ,
  { {0x9f520089,0x23ba0015,0x7a470003,0x799c0034}},	//   ždém_, تداب_, pété, lurw
  { {0x416a0001,0xe9a90086,0x98a9002a,0xe57a006b}},	//   ојим_, _بدین_, tlać_, _мзг_
  { {0xbebc0024,0x6440002a,0x6abc0012,0x65c30fd5}},	//   lnīg, _wzmi, ierf, _ибра
  { {0x6abc0084,0xe643168f,0x6682002b,0x628325d3}},	//   herf, _респ, _سیچل, aano
  { {0x6abc23f2,0x20040085,0x644032fc,0x628355a0}},	//   kerf, uzmi_, _uzmi, bano
  { {0x7ce6005c,0x6283047e,0xdef70033,0x23890046}},	//   _górz, cano, дыю_, řují_
  { {0x0697013a,0xecd0000b,0xa697000a,0xbe38006b}},	//   ודים_, _तोहफ, וכיה_, язох_
  { {0x799c0034,0x8d73002b,0xc0d30058,0xcd340058}},	//   durw, کایا, _ليمب, َرَب
  { {0x6ee60029,0x6c080015,0xdee60015,0x9f44008c}},	//   _يستل, ِيُّ_, _يأتي, tymä_
  { {0x8f8b0008,0xe6c8000b,0x6abc55a1,0x73f9004c}},	//   _וְהֵ, रयोज, gerf, פּרו
  { {0xfe9b000a,0x0e9b000a,0x0f57000f,0x3eb7004c}},	//   _ויומ, _ושול, _קיום_, _חלומ_
  { {0x6aaa00b8,0xa2a7000b,0x628341ac,0x6abc0039}},	//   _öffn, _फ़ॉन्, zano, aerf
  { {0x6abc55a2,0x96f90004,0x57b50033,0xc6a7004a}},	// [d590] berf, пеат_, эбат, дреи
  { {0x60c90030,0x80d5000b,0x569406f4,0x97250058}},	//   zdem, _मोने, каут, رفضو
  { {0x273400c0,0x04950015,0xc6a4006b,0xd4d90033}},	//   vänt_, فلاح, ърти, зьлі_
  { {0x8cbc004c,0x5d69004c,0x26c705e3,0x656a0125}},	//   ַצוק, לדעֶ, žno_, ífha
  { {0xdb0d0020,0xe28e275c,0xd0060015,0x628355a3}},	//   _osaü, ла_, _إل_, tano
  { {0xeb920008,0x8c1c0008,0x877a0135,0xbc1c000a}},	//   אָה_, חודי, _מאשי, חודש
  { {0xf1b10029,0x6b9d0035,0x395955a4,0xb2840033}},	//   اءت_, husg, _kiss_, тычк
  { {0x6283075c,0x41b20029,0xc5f20008,0xa1560001}},	//   sano, امير, _גדל_, нају_
  { {0x3959026e,0xa3d0000b,0x628355a5,0xdb060030}},	//   _miss_, षिण_, pano, stké
  { {0xfe710029,0x2251002c,0x0ea90892,0x60c92ecb}},	//   ددة_, _úzko_, чкой_, sdem
  { {0x7bcf0064,0x4e950086,0x6281003d,0xee3901e5}},	//   evcu, وشگر, _ielo, яно_
  { {0xdcfb005c,0xfce6059c,0x6abc4443,0xa0c50015}},	//   ystą, хомо, werf, _سيتو
  { {0x628155a6,0x84fa004c,0xbab60033,0x69c52ac8}},	//   _kelo, פּטה, нёвы, _ashe
  { {0xa3d0014e,0x799c00b8,0xb4bc000b,0xaed203ae}},	//   षित_, turw, _अस्_, _бољш
  { {0x443a0023,0x4efa000a,0x7f3a000a,0xb062007c}},	//   ́p_, _מהסו, _צעצו, äägi
  { {0x0d820063,0xfe360008,0xe6c6002b,0xc2120643}},	//   _слън, _ארצי_, کتري, אהל_
  { {0x2cbf0020,0x6abc189e,0x9d1b000a,0xa696012e}},	// [d5a0] õude_, perf, _מוקט, ереј
  { {0xf1c50023,0xe73a004a,0x628155a7,0x86c60369}},	//   _đáng_, чез_, _nelo, عيان
  { {0x8a7b0008,0xceb200f3,0xe5720015,0x4a7b000a}},	//   _מאית, ריב_, اطئ_, _מריב
  { {0x62810176,0x7413002b,0x38694d3f,0x765c0542}},	//   _aelo, گوها, ccar_, _wgry
  { {0xf8b30008,0xe3af0002,0x628155a8,0x2348002b}},	//   _גשר_, مرو_, _belo, وستی_
  { {0x273400c0,0x628155a9,0xa5fe0033,0x3f7d006f}},	//   räns_, _celo, _любi, dňu_
  { {0x628155aa,0xfb17004c,0x70bd000b,0x6b9d0030}},	//   _delo, ײַגט_, ्यूल, zusg
  { {0xf9930008,0x6d5e0152,0x250b002b,0x6281007c}},	//   ארה_, _épai, _فرقی_, _eelo
  { {0x925a0086,0x628152ef,0x03260666,0x8cc4000b}},	//   _فشار_, _felo, _здан, िजनो
  { {0x1ddb005d,0x6fd2000b,0xbfb300c3,0x91e604d7}},	//   यमंत, तिबं, احيت, _позе
  { {0x32070050,0x2d8a00dc,0xa2dd000b,0x48e302ed}},	//   czny_, ébe_, पार्, но́в
  { {0x26ca0024,0xac190839,0x6b9d1c2c,0x0000006a}},	//   _labo_, дому_, tusg,
  { {0xd12f0002,0xc4d3000a,0x69da0795,0x3959047f}},	//   _امن_, אגר_, åten, _riss_
  { {0xdfcf009a,0xce94009b,0x0000006a,0x0000006a}},	//   _ديه_, _ракъ,   ,
  { {0x6b4000b8,0x318c0089,0x7f2b000a,0xda35004a}},	//   mögl, něz_, _מֵהֶ, тевы
  { {0xadd70008,0x61e500b8,0x2eee1266,0xfe780091}},	//   _טווח_, ähli, _hoff_, lbį_
  { {0x98170074,0xf7700070,0xa8550010,0x38690518}},	// [d5b0] ربرا, مال_, ткач, rcar_
  { {0xbebc0024,0x2d9e1151,0x26ca0656,0x386955ab}},	//   lnīb, oute_, _cabo_, scar_
  { {0x2d9e3815,0x69c51d95,0x628155ac,0xfe780073}},	//   nute_, _ushe, _relo, ibį_
  { {0x628155ad,0xe4e40484,0xd4e405ae,0x23a90030}},	//   _selo, лічн, лючи, túj_
  { {0x628155ae,0x69e60045,0x3ebe55af,0xb3e80015}},	//   _pelo, ăreş, kett_, فعول_
  { {0x2d9e0005,0x3ebe06f5,0x4b7c0053,0x04420054}},	//   kute_, jett_, לאדו, јешн
  { {0x3ebe0832,0xa2a7000b,0x659503ae,0x628155b0}},	//   dett_, _फ़ॉण्, _јабу, _velo
  { {0x3207005c,0xed630107,0x50b5004a,0x628155b1}},	//   rzny_, _leží_, тску, _welo
  { {0x2d9e00b8,0x13b40031,0x3207002a,0xc4d2000a}},	//   eute_, _مصلح, szny_, _דגן_
  { {0x2d9e06e8,0x3ebe55b2,0x9e65006b,0xbebc003d}},	//   fute_, gett_, ъвод, enīb
  { {0x60b50015,0x9d460004,0x2d9e038c,0xf559004f}},	//   _لمائ, кеод, gute_, ֽדָמ
  { {0xdcfb005c,0xd164006b,0xa0c4012c,0x0000006a}},	//   ostę, _съфи, _ميمو,
  { {0x8cb3005d,0xed63006f,0x3ebe01f1,0xd0f6000a}},	//   ेज़ो, _beží_, bett_, _שמנת_
  { {0x501a000a,0xf412000a,0x2d9e55b3,0x6b400030}},	//   _קוסו, שפך_, bute_, rögo
  { {0x6a830010,0x19b9007a,0x2d9e3206,0xc332000a}},	//   рлса, нуть_, cute_, יוך_
  { {0x26ca55b4,0xe944009a,0x69230138,0x0000006a}},	//   _sabo_, ارسی, амса,
  { {0xf772003b,0x3f42002e,0x60cb55b5,0xccf3000a}},	// [d5c0] شاء_, iðun_, _magm, _ככה_
  { {0x75230030,0xdcfb002a,0xbebc003d,0x60cb0795}},	//   énzn, dstę, mnīc, _lagm
  { {0xd5d50010,0xd6cf0225,0xc486194a,0x3ce6000b}},	//   люцы, تقل_, влек, टापे_
  { {0x3ebe0014,0x60cb0035,0x80bd000b,0xdb060030}},	//   zett_, _nagm, ्यों, itkí
  { {0xa3b405fc,0x2d9e0011,0x22940342,0x92940004}},	//   ублі, zute_, гиля, галц
  { {0xc7b3000a,0x318c0046,0x9343261d,0x78a455b6}},	//   _דבש_, těz_, анче, lgiv
  { {0xdcfb005c,0x95d7004a,0x2d910046,0x05560033}},	//   astę, _идёт_, ázel_, _атая
  { {0x3f420084,0xd37200a2,0x2d9e04ed,0xddd840ca}},	//   gðun_, _نهر_, vute_, _nevš
  { {0x3ebe0014,0x3ce6005d,0xff06004a,0x8fe30033}},	//   tett_, टाने_, вянн, ацэд
  { {0x60cb002d,0x2d9e55b7,0xb2c50058,0xd344009a}},	//   _eagm, tute_, _مغمو, _صفای
  { {0x5d55010f,0x3ebe55b8,0x69d80007,0xe2a90086}},	//   лкот, rett_, _šven, _سالن_
  { {0x3ebe55b9,0x752250a0,0xe165002b,0x2d9e55ba}},	//   sett_, nnoz, _صدمي, rute_
  { {0xaade005d,0x3ebe00dc,0x3157000a,0x5f061119}},	//   मांक, pett_, _סידן_, _изда
  { {0x9b580063,0x9b450087,0x60c00ae5,0x52c0000b}},	//   кият_, انسو, lemm, _एसोस
  { {0x3eab0264,0xed63006f,0x3ebb004f,0xd90f009a}},	//   žitý_, _veží_, _חצוב, قید_
  { {0xdcfb005c,0x60c055bb,0xf7730015,0x78a401e0}},	//   ystę, nemm, لاط_, ggiv
  { {0x58840010,0x4615002b,0xe679005e,0x60c0008c}},	// [d5d0] рыса, گوار, ейзі_, iemm
  { {0x60c055bc,0x290201d7,0x96bb012c,0x77390058}},	//   hemm, _elka_, بارز_, ركاز_
  { {0xda7a000a,0x4615006e,0x60c055bd,0xdbe40030}},	//   _אנתר, دوار, kemm, _réér
  { {0x6d5e0152,0x60c055be,0xb867002b,0x752255bf}},	//   _épau, jemm, _جادو, gnoz
  { {0x2458008f,0x44290e2c,0xd7e4022a,0x289a00f3}},	//   ваць_, ça_, _кіро, _אירא
  { {0x60c0008c,0x0000006a,0x0000006a,0x0000006a}},	//   eemm,   ,   ,
  { {0x60cb0035,0x27e90011,0x28aa000b,0xbebc003d}},	//   _pagm, ţină_, ङ्कि, znīc
  { {0x26c104b2,0x4a5c000a,0x50450af4,0x90c5029b}},	//   leho_, ודוו, лейб, убие
  { {0xa1560054,0xddd800bc,0x3f42001a,0x2d8c55c0}},	//   ћању_, _revš, rðun_, esde_
  { {0x26c155c1,0xfde905f8,0xe8e0000b,0x0d750033}},	//   neho_, едок_, _पच्च, лымя
  { {0x273d0092,0x53360053,0x60cb55c2,0xd25b0033}},	//   rình_, _ענען_, _tagm, _цца_
  { {0x60c00152,0xe0d00002,0xeb9a2a71,0x61e50012}},	//   cemm, _وزن_, ним_, ählu
  { {0x8ca5014e,0x26c1002c,0x69c10064,0x78a401f0}},	//   _कारो, keho_, çlen, vgiv
  { {0xa9a60083,0x6e950029,0x6f920029,0x63bb003f}},	//   лигд, _إلغا, _الوض, _mpun
  { {0xceb20008,0x66090089,0xba1a0029,0x78a402d2}},	//   _היו_, _řekn, ريرا_, tgiv
  { {0xb87b0f14,0xbebc003d,0x9975012e,0x7bd6002a}},	//   _aníb, pnīc, рурш, _tryu
  { {0x3f8d0251,0x7d040b63,0x6cab000a,0x28aa000b}},	// [d5e0] nseu_, _ilis, _אֹיְ, ङ्गि
  { {0x4b7b0008,0x26c1006f,0x78a455c3,0x75220535}},	//   _ראיו, geho_, sgiv, wnoz
  { {0x4efa004c,0x7d044e1b,0x78a42318,0x63bb55c4}},	//   עלעג, _klis, pgiv, _apun
  { {0x05770015,0xf4830054,0x299b004f,0xfc3f0052}},	//   امنة_, бушн, _אסטמ, lgía_
  { {0x60c0008c,0x07a30033,0x6c7b004f,0x752255c5}},	//   vemm, _лаян, גרנד, rnoz
  { {0x7d0408e0,0x26c1002c,0xf3880092,0xb97a0008}},	//   _llis, ceho_, rợ_, ֲנִי
  { {0x7d043fd4,0x7658006f,0xd13000c3,0x394055c6}},	//   _olis, ľvys, يمت_, olis_
  { {0xb87b03af,0x7643005c,0x645e0046,0x8cd4000b}},	//   _iníc, żnyc, ěpis, _बोलो
  { {0xa50755c7,0x60c055c8,0xdcfb0046,0x69d80091}},	//   _сета_, remm, astě, _švel
  { {0xd24f0074,0x60c0022d,0x7d0455c9,0x82660015}},	//   _کنم_, semm, _alis, _إهان
  { {0xc27b0008,0x63a200f2,0xf1a900e6,0x80a60086}},	//   _נראי, luon, _لانه_, _ممان
  { {0x394000d9,0xb87b006f,0xa0670054,0x7d0455ca}},	//   jlis_, _mníc, _баца_, _clis
  { {0xab620064,0x8ff700e5,0x7d040125,0x60db000a}},	//   şüne, _مرور_, _dlis, _רקדנ
  { {0x628a2511,0x7d0455cb,0x394055cc,0x3f7b004f}},	//   nafo, _elis, elis_, _טאדס
  { {0xe9190036,0x63a200f2,0x1efb0053,0x7f3b0053}},	//   вові_, huon, _אלגע, _רעוו
  { {0xd7e70036,0x63a2003f,0xa2070008,0x3f42002e}},	//   лізо, kuon, רֶךְ_, iðum_
  { {0x6c780115,0x4bdb0015,0x3b270015,0xb715006b}},	// [d5f0] _صحيح_, _أبعد_, _معدّ, адащ
  { {0x7d16066f,0x25a10012,0xa8480015,0x628a014b}},	//   _zmys, tuhl_, الكم_, jafo
  { {0x26c100b6,0x63bb1b19,0x7d160026,0xf647017f}},	//   reho_, _spun, _ymys, ухан
  { {0xba740086,0x94750086,0x98790053,0x48640063}},	//   _پایت, شگرا, _שאָט, _гърб
  { {0xdfc6003b,0x63a22e01,0xe285033d,0x24f80033}},	//   _بي_, guon, алли, ынцы_
  { {0x2d910089,0x68ed55cd,0xf836000a,0x7982002a}},	//   ázek_, ljad, _כנרת_, _łowi
  { {0x6f1a0298,0x3f42002e,0xa229006b,0xfaf8004f}},	//   ditc, gðum_, ъжка_, רצוי_
  { {0xa2a7005d,0x68ed013c,0x2909008c,0xe0d9121e}},	//   _फ़ॉर्, njad, nhaa_, тви_
  { {0xdcfb003d,0x68ed55ce,0x5f750058,0x5f2902ed}},	//   artī, ijad, جابر, коим_
  { {0x7d160089,0xcef5000d,0x518718ea,0xa195005e}},	//   _smys, рчињ, _буда, _важч
  { {0x245a0064,0x3f8d0251,0x68ed002e,0x7d0455cf}},	//   _tümü_, sseu_, kjad, _plis
  { {0xe3a70115,0x7fd5022a,0xcb6a16b2,0x0000006a}},	//   ير_, _вікі, каме_,
  { {0x2909000c,0x66090089,0xdee50809,0x57df000b}},	//   dhaa_, _řekl, _воли, नमोह
  { {0xbea2008f,0x5fb60135,0xfaa60054,0x7c96002b}},	//   _дашк, _כהנא_, јаво, دشگا
  { {0xda790010,0xfc3f1167,0x8f1a000a,0xada5194c}},	//   ыяў_, rgía_, _בוסת, _тайл
  { {0x7529016f,0x7d16005c,0x7d0455d0,0x628a0030}},	//   _njez, _umys, _ulis, zafo
  { {0xa6860036,0x6d3b000a,0x0686109b,0xc7a6005e}},	// [d600] илад, _בתקנ, иган, ризк
  { {0xd7070010,0x6d5f0152,0x68ed326b,0x394000aa}},	//   ануе_, _épar, ajad, slis_
  { {0x6a9b0008,0xceb8005c,0x1a9b000a,0x5a9b000a}},	//   _בשינ, sięg_, _בייע, _בשיא
  { {0x2db60053,0x07a60afa,0xf65520fe,0x76430061}},	//   ילען_, _камн, стую, ünya
  { {0xf8630191,0xb6070048,0xdc89000a,0x44970033}},	//   _євро, ekšē, רְעָ, рвію_
  { {0x29001437,0x11d60015,0x8bd7000a,0x61130045}},	//   lkia_, لتعد, יונו_, călz
  { {0xe81a014e,0x69d80046,0xcb57000a,0xd5d501b0}},	//   _नेता_, _švej, בססה_, _люты
  { {0x3f420084,0x29000321,0xdfd00015,0xa1330015}},	//   rðum_, nkia_, كيب_, يريش
  { {0x29000007,0x80b7000b,0x902a006b,0x63a20003}},	//   ikia_, ्ज़े, ъцка_, quon
  { {0x3eb8002e,0x6d4d55d1,0xc7b3000a,0x3eaa0012}},	//   ýrt_, _shaa, קבת_, übt_
  { {0x290000f2,0xb6d90053,0xc6d90053,0xd357000a}},	//   kkia_, אַרט, אַרר, _כימי_
  { {0x718b000a,0xe611000a,0x01fb004c,0xfbe80016}},	//   _יְדַ, פִי_, _שפאל, _trễ_
  { {0x62880273,0xa1130015,0x442d16c3,0x6b9d042f}},	//   _kedo, _بونت, _xxe_, ursg
  { {0x6288018b,0xdd90006e,0x6b841bd0,0x4e17002b}},	//   _jedo, _فوت_, _dwig, اتید_
  { {0x8d940029,0x68ed0251,0x6da3049d,0x6b8405c7}},	//   _البش, tjad, _дија, _ewig
  { {0xae5b00a3,0x4d73002b,0x31710030,0x5dcb000a}},	//   _בכור, _بطور, _ézze_, _יֶחְ
  { {0xc0530053,0x62880026,0x68ed55d2,0xf7730115}},	// [d610] ַזע_, _oedo, rjad, تاز_
  { {0xe7300029,0x68ed0020,0x8f9b000a,0x75290046}},	//   وصل_, sjad, כימי, _sjez
  { {0x7d1d26b2,0x672500cb,0xa634005e,0x443f01d7}},	//   oiss, rnhj, онфі, _syu_
  { {0xe3b10029,0xd1260018,0x2d9e0125,0x39550061}},	//   كرت_, _رم_, irte_, çası_
  { {0x2d9e018b,0xe3b30115,0x44270015,0x628855d3}},	//   hrte_, ترض_, جراف, _bedo
  { {0x6440002a,0x7d1d55d4,0x73c40015,0xa856000a}},	//   _dymi, hiss, تيهم, _לירה_
  { {0x7d1d55d5,0x81a80021,0x9f590046,0xf426008c}},	//   kiss, لطيف_, ásí_, _ääni_
  { {0x753b00aa,0x7d1d008c,0xa50700ce,0x0584116d}},	//   _ukuz, jiss, _тягл, _фурм
  { {0x2d9e3db4,0x7ff50029,0xf41f318c,0x2e69004a}},	//   erte_, إسبا, _ää_, липп_
  { {0xaf0555d6,0x62880150,0xaf090015,0x200d1835}},	//   спол, _gedo, اقدم_, rzei_
  { {0x7d76002b,0x7d1d55d7,0x200d0030,0x2d910247}},	//   یمیر_, fiss, szei_, éze_
  { {0x7d1d55d8,0x41551c44,0x1d0a006b,0x26d155d9}},	//   giss, _увес, уеми_, _lazo_
  { {0x38c80086,0x0c2312ae,0x8fc7006e,0x2d9e55da}},	//   یاری_, змян, _خزان, arte_
  { {0x20a7005d,0xd436000a,0x7d1d5360,0xcb6700af}},	//   _गाँध, מטרי_, aiss, саре_
  { {0x7bcd55db,0xe1e70021,0x2d940033,0x2900008c}},	//   _esau, أس_, _дрыс, tkia_
  { {0x3cf1002c,0xb8660029,0x29000007,0x7d760087}},	//   ľová_, صارو, ukia_, _امير_
  { {0x69030005,0x999a0089,0x9b930015,0x26d135f9}},	// [d620] _tõen, _typů_, _فليت, _bazo_
  { {0xc68f0015,0x25f4000b,0x291904f6,0xb8ff0065}},	//   ِّل_, ंहली_, _emsa_, _धो_
  { {0xf992003b,0x20a7005d,0xb0a7005d,0x628855dc}},	//   _عبد_, _गांध, _गांग, _redo
  { {0xe76a0002,0x15b90033,0x6903007c,0x7794002b}},	//   _محسن_, рыфы_, _jõel, _ویزا
  { {0x19570008,0x69030020,0x54360029,0x0676006b}},	//   _לבטל_, _mõel, حرار, _губя
  { {0xfbd3000a,0x2d9e13e1,0x0443004a,0xd14a002b}},	//   פתו_, yrte_, чечн, گشتن_
  { {0x6440005c,0x7e7e0020,0x5578000a,0xd578000a}},	//   _wymi, _õppi, _כְּד, _כָּר
  { {0x6560002f,0x6b40002e,0x60f803fc,0xa507004a}},	//   _uimh, mögu, рния_, _леса_
  { {0x6b40002e,0x7d1d2739,0x0000006a,0x0000006a}},	//   lögu, viss,   ,
  { {0x7d1d0b8e,0x2bb9000b,0x3eca0054,0xdf730015}},	//   wiss, ेबसा, ућим_, أديب
  { {0x200255dd,0xa3d0000b,0xdb06008c,0x7d1d4867}},	//   ški_, षिक_, itkä, tiss
  { {0xa06a0124,0xc5f30008,0x2d9e0012,0xa50b000a}},	//   _сада_, לדת_, rrte_, ָּטִ
  { {0x705600e6,0x23e7000a,0x7c22001a,0x8fe50015}},	//   _انشا, ֶֽךָ_, _þorl, _وأهم
  { {0xde58008f,0x7d1d55de,0x2d9e19c2,0x05c8000b}},	//   _калі_, siss, prte_, रबाब
  { {0xc2110008,0x6f4b000a,0x7afa0123,0x7d1d55df}},	//   ֵ֔ל_, _עֲדַ, ötta, piss
  { {0xa9350033,0x6b40001a,0x5e430015,0x7bcd003d}},	//   цебш, dögu, _عَيْ, _tsau
  { {0x2d910089,0x02fa000b,0xc1b5000b,0x56670015}},	// [d630] ázev_, ्साह_, _अङ्ग, مداف
  { {0x0000006a,0x0000006a,0x0000006a,0x0000006a}},	//     ,   ,   ,
  { {0xef110008,0x7e6d0061,0x9477002b,0xdcfb0061}},	//   וּא_, _şapk, مدشا, lttı
  { {0x2e3b0053,0x2ec5005d,0xb87b002d,0x26d1003f}},	//   נגאנ, _वस्त, _inío, _wazo_
  { {0x95540015,0xb062007c,0x62650c7c,0x34c90065}},	//   أخلا, ääli, овла, _रसीद
  { {0xfbb8000a,0x0bb8000a,0xd346002b,0x69d813b3}},	//   צפות_, צלום_, قیقه_, _švei
  { {0x945d0050,0xdce4016f,0x8afc0135,0x29050091}},	//   _pańs, _sunč, רהוי, ūlau_
  { {0x85050021,0x338701ca,0xa98c004f,0x0000006a}},	//   _بورن, _гужв, נָוִ,
  { {0x23740015,0xc2c50015,0x1ef90058,0x0000006a}},	//   _فالح, _ويري, لعدة_,
  { {0xdcc2005d,0xea000016,0xbebc003d,0x6903007c}},	//   षज्ञ, hoại_, lnīj, _sõel
  { {0x6b520134,0x3ce6000b,0xacea00d2,0x945d002a}},	//   lægg, टाले_, амна_, _tańs
  { {0x42040015,0x25d6000a,0x3236000a,0xa3ad000b}},	//   _عِنْ, קורן_, _וטען_, _कमा_
  { {0xcb6a0124,0xb87b002f,0xc3f90008,0x3fc9002b}},	//   раге_, _anío, ׁלֹש, _خدای_
  { {0x9056000a,0x8b26005e,0xda650015,0x6ea6000b}},	//   _ובנו_, ідве, كافي, _खाएँ
  { {0xfd12003b,0x69030020,0xab19042b,0xdcfb007f}},	//   _يجب_, _tõel, сцях_, attı
  { {0x186714f4,0xea000016,0x394601f3,0x48e3144a}},	//   жати_, goại_, інаг, мосв
  { {0x7b760015,0xdb0603c1,0x9aa5009a,0x7af741a2}},	// [d640] _بطبا, ttkä, _کمپو, _foxt
  { {0x4ded000b,0x76a60015,0x6d4655e0,0xabfb004f}},	//   _छपाई_, تحرك, llka, _כהפר
  { {0xa2d4005d,0xa96a0001,0xb87b002d,0xe61a00d0}},	//   _योग्, _њима_, _gnío, јде_
  { {0xec3600b2,0xd4c60015,0xe4e3005e,0x6b40001a}},	//   ֿאַר_, تغطي, дішн, rögu
  { {0xfbca000b,0x289b000a,0x6b40001a,0xe3af0067}},	//   िबिम, _דיכא, sögu, نرو_
  { {0x2ae3014e,0xb06200f2,0x9bcb000a,0x6d460012}},	//   खाएँ_, äämi, שֶׁ֖, hlka
  { {0xaab2014e,0x4ab2000b,0xecaa000b,0x0566005e}},	//   _जानक, _जानव, _कांफ, _єван
  { {0xa2ba000b,0xd1300015,0x61f70123,0xb97b000a}},	//   _शॉर्, عمة_, äxla, בנקי
  { {0xc953013a,0xdec60054,0xcec60195,0xe4d700c3}},	//   ומה_, ољно, ощни, _بوقت_
  { {0x7b10018b,0xeeb7008f,0x2fdd0026,0xe4230086}},	//   _häuf, ольш_, _drwg_, _تکمي
  { {0x81c70024,0x7b1000d5,0x6b400123,0x9f590d46}},	//   trēš, _käuf, högs, ásá_
  { {0x2fe60015,0xc05a005e,0x7afa0123,0x63a255e1}},	//   _وكاف, _кіл_, öttn, oron
  { {0x9f4600b8,0xfc64006b,0x00bb000a,0x7d540033}},	//   _groß_, дърн, _כמאמ, ьвюх
  { {0xdcfb0064,0x7b1000b8,0xd00b000a,0x6d461ba2}},	//   rttı, _läuf, _כּוֹ, alka
  { {0x2d910089,0x59ce005d,0xa955005e,0x0178000a}},	//   ázet_, _हैदर, зкві, מָּל
  { {0x8d180225,0xdc3f28cc,0x319b0008,0xb9250029}},	//   _وزير_, líčo, יבלנ, أفري
  { {0xe908000d,0xf7700002,0x69de55e2,0x466b12d9}},	// [d650] цатa_, نال_, _erpe, арем_
  { {0x8cbc005d,0x3f7b0053,0x7643002a,0xd8380033}},	//   ष्ठो, יאמס, żnym, цэс_
  { {0x7e7e007c,0x63a255e3,0x9da3000b,0xd6780058}},	//   _õppu, eron, _कमज़ो, تحقا_
  { {0xf9da00b2,0xae57004c,0x63a20119,0x629a55e4}},	//   _פֿיל, קסאס_, fron, _adto
  { {0x2bde000b,0xad1c000a,0x248f00da,0x63a255e5}},	//   मिया, סודר, ragm_, gron
  { {0xe7380010,0x57fa0008,0xc8ab005d,0xfa6b000a}},	//   _меў_, _הלשו, _छाँट, ׁכְּ
  { {0x62080029,0x63a204ed,0x4a9c000a,0x71a50973}},	//   يْهِ_, aron, ביוג, чайз
  { {0xdcfb0024,0x81d40010,0x78ad55e6,0xddc8002a}},	//   istē, ьціц, ngav, łośn
  { {0xc4d2000a,0xef190342,0x6b5202de,0x48b6000a}},	//   _אגן_, йми_, læge, הִין_
  { {0x8e7400fd,0x41e70015,0x0309000a,0xc7b2004f}},	//   муюч, _وساف, _פִּֽ, עבי_
  { {0xa3440010,0x628300bd,0x7bdf55e7,0xc8ab000b}},	//   _цэтл, mbno, _arqu, _छांट
  { {0xc1ba0008,0x6d4600f2,0x71d6039e,0xe4470015}},	//   _למעש, ulka, _מועד_, فض_
  { {0x8027003b,0x78ad02de,0x69de0046,0xdcfb003d}},	//   _برام, dgav, _srpe, estē
  { {0x3d02005c,0x63a455e8,0x60c955e9,0x290b026a}},	//   _mówi_, šing, leem, _alca_
  { {0xdce90064,0x5d790015,0x7bdf3381,0x236555ea}},	//   ardı, _احتج_, _erqu, _milj_
  { {0x248d049c,0x78ad55eb,0x60c955ec,0x8dfa000a}},	//   _neem_, ggav, neem, _להצת
  { {0xc8690053,0xd70a0033,0xac170054,0x2fcd02f7}},	// [d660] ָן_, бнае_, _ноћу_, nweg_
  { {0x69de0c1a,0xdaaa55ed,0x6beb000a,0x63a255ee}},	//   _trpe, _увод_, _הַטַ, vron
  { {0x8afb0008,0xbafb000a,0x657e001a,0x60c9014b}},	//   _הפיק, _ההיש, upph, keem
  { {0x63a255ef,0xcd9a004c,0xd5af006e,0xe4b800fd}},	//   tron, מױער, طفه_, іллі_
  { {0x645d0107,0xf8db000a,0xd4090015,0x60c9074e}},	//   _úsil, _החכמ, يتهم_, deem
  { {0xb3e9003b,0x236501a3,0x018a004a,0x63a255f0}},	//   تعمل_, _cilj_, бщий_, rron
  { {0xd1b70015,0x7b100012,0xd24f006e,0xe29701ca}},	//   كايا_, _täuf, هنه_, чај_
  { {0x859b013a,0xe01d005d,0x63a255f1,0x89db000a}},	//   _לשלו, _बेहद_, pron, מחצי
  { {0xe29a29b7,0x2fcd0079,0x03a3107f,0x0000006a}},	//   _газ_, gweg_, _пито,
  { {0x38170008,0xc7d70008,0x4d98005e,0xdce4003d}},	//   פקים_, לופי_, окою_, _runā
  { {0x908a003b,0xc27b0008,0x127b0053,0xb87b0107}},	//   _هناك_, _הרבי, _האבע, _sním
  { {0xcd07005e,0x0000006a,0x0000006a,0x0000006a}},	//   їчни,   ,   ,
  { {0x8ae70036,0x9be7005e,0x656e02f2,0x69dc55f2}},	//   півл, чінк, _lubh, evre
  { {0x7b640083,0xb87b0107,0xc214000a,0x6903007c}},	//   етсе, _vním, ֵהּ_, _tõek
  { {0xdebb0008,0x78ad55f3,0x8cf50015,0xceb3000a}},	//   _המול, tgav, _يكتش, _ניק_
  { {0x8e47003b,0x6b520134,0xa3ad000b,0x0000006a}},	//   _عليك_, væge, _कमल_,
  { {0x78ad0298,0xdbdd002e,0x62830107,0x5b250015}},	// [d670] rgav, _háþr, ybno, _يفعل
  { {0x248d003e,0x7d0d0057,0xa81800c3,0xc7340058}},	//   _seem_, _hlas, ستقر_, ّفْظ
  { {0x8afc0008,0x28f918a9,0x7b1000b8,0x2aba000a}},	//   _להזי, _день_, _säug, _ומתא
  { {0xf6500029,0x65780030,0x656e01b3,0x69c500aa}},	//   ائك_, ívha, _dubh, _iphe
  { {0xe28e078f,0x88f6000a,0x39490845,0xa77406eb}},	//   ка_, _חזרו_, mlas_, _пляч
  { {0x49b80074,0x7bdd0020,0xe3b00018,0x394955f4}},	//   _باید_, ivsu, طره_, llas_
  { {0x3949002d,0x60c93223,0x56840015,0x7d0600cb}},	//   olas_, teem, _سجِّ, ykks
  { {0x7c3a0050,0xa4d40036,0xa1560001,0xe5090015}},	//   ętrz, _посі, мају_, _بيرو_
  { {0xa2b5010f,0x1fb40010,0x60c91844,0x69dc0085}},	//   _обач, нсэр, reem, zvre
  { {0x69ce0026,0xd9ff000b,0xe3ca0077,0x22950067}},	//   ywbe, ैनात_, señó_, _آلاس
  { {0xcc8a0086,0x3cca0658,0x394955f5,0x290c0091}},	//   ينده_, олно_, klas_, ūdai_
  { {0xce180010,0xcb09000a,0x7d0d1aec,0x63a40160}},	//   яцыі_, _דל_, _clas, šine
  { {0xed570036,0xd496000a,0x9ef50015,0x2ef517b6}},	//   ьою_, וכרת_, _يستش, _оздр
  { {0xada1002c,0xdce40045,0x63ab02b9,0x2fd80030}},	//   ľúbe, _bună, iugn, üggő_
  { {0xb87b006f,0x39490034,0x69dc0da5,0x7d0d0c10}},	//   _kníh, flas_, uvre, _flas
  { {0x99430029,0xdce40011,0xcd360015,0x691102de}},	//   نَّه, _dună, _ترتب, _nåed
  { {0x1dd5005d,0x7ceb000a,0x4c9b0447,0x657c01c0}},	// [d680] धिकत, _וַיֶ, _ובפו, _strh
  { {0x98a0005c,0x61e10026,0x7d0d345a,0x7b100012}},	//   dnią_, _orll, _zlas, _bäue
  { {0x75d60029,0x39490077,0x98a0002a,0xd48f0342}},	//   بيضا, blas_, enią_, кр_
  { {0xfdf60008,0x100d000b,0x63ab0012,0x80bd000b}},	//   וצעת_, िनाश_, fugn, _वॉले
  { {0x31c6005d,0x3f42002e,0x61e10026,0x63ab02f2}},	//   लब्ध, iður_, _arll, gugn
  { {0x8b89000a,0x394055f6,0x76660058,0xab5b02ad}},	//   פָנֶ, lois_, _يُحم, lwür
  { {0xaac0014e,0x63ab0035,0x6d440091,0x966321e9}},	//   श्यक, augn, _okia, _акре
  { {0x399b01c8,0x31570015,0x361b000a,0xab5b0012}},	//   קיפד, وجية_, _וולד, nwür
  { {0x8fa30e88,0x26d80007,0x248614b4,0x6e941411}},	//   вање, _karo_, mbom_, нипу
  { {0xc3fb000a,0x33fb000a,0x23fb000a,0x8857000a}},	//   _ולמש, _והמנ, _והמא, ושפע_
  { {0x2d982497,0x7d0d55f7,0x2d8a0003,0x39494060}},	//   ére_, _plas, èbe_, ylas_
  { {0x26d80035,0x7e6d0011,0x3f42002e,0x6da3001a}},	//   _laro_, _şapt, gður_, _síað
  { {0x69c50b00,0x6fb30015,0x6fb40015,0x5fb30015}},	//   _sphe, _لمنا, _أمتا, _لمنط
  { {0x5f030063,0x2004002a,0x21240125,0x3f42001a}},	//   _изча, mymi_, limh_, aður_
  { {0x39400152,0xcda70086,0x2124002d,0x6a25002b}},	//   fois_, _قهوه_, oimh_, رفرم
  { {0x2124002d,0x3cf80015,0x98a0002a,0xab5b0012}},	//   nimh_, _يعيد_, ynią_, gwür
  { {0x20041ad1,0xd6db0063,0x8bd40010,0x39492203}},	// [d690] nymi_, жте_, _ажыц, rlas_
  { {0x0854005f,0x39493270,0xcfb70008,0x4b7c000a}},	//   твую, slas_, ולמי_, _ואזו
  { {0x69c500da,0x9f550030,0x26d855f8,0x6d5d0125}},	//   _uphe, égén_, _daro_, omsa
  { {0x68f8032c,0x98a0005c,0x8d5c004c,0x2004006f}},	//   ľadá, tnią_, ַכגי, kymi_
  { {0xc4840010,0x987a01ac,0xf3cb0031,0x03a5005e}},	//   тлік, _מארט, تباه_, хило
  { {0x05770086,0x290900f2,0x63b90034,0x98a0002a}},	//   _يازد, lkaa_, rtwn, rnią_
  { {0x3f42002e,0x63b90026,0x6145023e,0xdb160030}},	//   yður_, stwn, нека, écéb
  { {0x63ab4624,0x74a4116f,0x0000006a,0x0000006a}},	//   pugn, _ајфе,   ,
  { {0x833502e5,0x290900f2,0xafe5017f,0x7afa0030}},	//   _знах, ikaa_, хопл, öttk
  { {0x93440001,0x51870033,0x60c200cb,0x83190015}},	//   _анђе, _жуда, _ebom, _عقار_
  { {0x2909022d,0xd12e0086,0x1105005e,0x6b8d02f2}},	//   kkaa_, شمی_, _підґ, _awag
  { {0x28df021e,0xfd120115,0x5f750015,0xb5a8000a}},	//   _पोलि, اجد_, _كاتر, וֹשֻ
  { {0x3f420084,0xeb9755f9,0x2004005c,0x656900f2}},	//   rður_, ния_, cymi_, _mieh
  { {0x3b0a0080,0x60db2a52,0x7b100012,0x5ffa004f}},	//   чего_, ldum, _säub, _מהנה
  { {0x19b90036,0x1d0a0001,0xf2d20053,0xc332000f}},	//   муть_, _неки_, װען_, אום_
  { {0x6d44003f,0xed57006b,0xe9d70033,0x60db55fa}},	//   _ukia, _пощ_, экс_, ndum
  { {0x69c10064,0x3940028f,0xe7aa006b,0xab5b0012}},	// [d6a0] çler, rois_, явал_, rwür
  { {0x77460015,0xab5b0012,0x2909008c,0x7bd602f2}},	//   رَام, swür, akaa_, _isyu
  { {0x394003af,0x2004005c,0x8cda009d,0xe57a005e}},	//   pois_, zymi_, ּחְת, їзд_
  { {0xb0ae000b,0x99f7000a,0x98a0002a,0xbebc003d}},	//   _टाइग, _נזכה_, dnić_, lnīt
  { {0x98a0005c,0x26d80026,0xc953000a,0xa3d40004}},	//   enić_, _taro_, _תמר_, толч
  { {0xeb93004c,0xbcfb0003,0x7d1d0030,0x60db003d}},	//   אָק_, mmée, érsz, edum
  { {0x2004005c,0x64a60010,0xbebc003d,0x2fc600aa}},	//   wymi_, _пава, inīt, _spog_
  { {0x21670124,0xdfd00029,0x25bb000a,0x80bc000b}},	//   нији_, ليب_, _מצלמ, ्जें
  { {0xcf260029,0x25af005c,0x2124002d,0x30770015}},	//   فردي, ągle_, rimh_, رحية_
  { {0xdcc9014e,0x656900b8,0x539b0008,0xd7b7004c}},	//   िज्ञ, _zieh, _מימו, עהיט_
  { {0x7bd600d9,0xddea002b,0x21a3006b,0xd345002b}},	//   _asyu, سرده_, _бихм, _جیوه_
  { {0xc8df000b,0x5185002b,0x61460054,0x6b52001a}},	//   _पोंट, _ششمق, _џеда, væga
  { {0x7c67003b,0x539b0643,0xc4d3000a,0x70fb000a}},	//   عاجل, ּילו, נגש_, _מהאח
  { {0xdcfb0007,0x6df40015,0xdee30054,0xdce4002a}},	//   ystė, _لكتا, _бољи, _runą
  { {0x290900f2,0x68fd00dd,0x67250f7a,0xb9250015}},	//   tkaa_, _posd, vihj, نفسي
  { {0xc8c90115,0x7975002a,0x290f0125,0x6e2b000a}},	//   بورن_, _wąwo, óga_, _מֵחַ
  { {0x6b8d0050,0xbcfb1a87,0x6934017f,0xd795006b}},	// [d6b0] _uwag, rméd, унту, тизъ
  { {0x6569018b,0xa0370008,0x98a0002a,0x2909008c}},	//   _sieh, תאמה_, ynić_, skaa_
  { {0xfb1c0008,0x644900d9,0x6935004a,0xb1a4005e}},	//   _מוזמ, _syei, _анну, _згiд
  { {0x48ab005f,0xd5b80010,0x7bda0024,0x7afe005c}},	//   _этом_, эсу_, ātuv, _zopt
  { {0xda670086,0xc6a70cb9,0x98a0005c,0x65691122}},	//   _تاکي, _први, wnić_, _vieh
  { {0x8c1c013a,0x13080036,0xeb920008,0xf2d10015}},	//   הודי, нній_, בָה_, شآت_
  { {0x15a80063,0xf6e40033,0x7afa00d5,0xd475009b}},	//   _пъти_, _сцян, ötti, _албъ
  { {0x60db003f,0xbebc0024,0xf99400a3,0x53a50015}},	//   udum, znīt, ארק_, _لمرك
  { {0xe0d6065e,0x200b0107,0x60db55fb,0x6fb20015}},	//   твы_, áci_, rdum, لميا
  { {0xaf05000d,0x6efe0046,0x8fc40058,0x0000006a}},	//   тпол, _nábě, ازين,
  { {0x200b06cf,0x867a000a,0xc2570015,0x6903007c}},	//   šci_, ורתו, _أخذت, _jões
  { {0xd48f005e,0x7158005e,0x27e0008c,0xdb0d001a}},	//   арi_, _зріс_, yvin_, _spað
  { {0x711a000a,0x4c360033,0x9ee90015,0x7afe55fc}},	//   _קונפ, тэнт, _يفصل_, _popt
  { {0xa3e2014e,0xe8ff0003,0x0b4332b1,0x8fa201e9}},	//   धित_, _aoû_, инян, _таше
  { {0x1a66002b,0xcb6749eb,0x0000006a,0x0000006a}},	//   ضیحی_, таре_,   ,
  { {0x2d850c90,0x27e00d40,0x332724d9,0x0000006a}},	//   mple_, tvin_, hinx_,
  { {0xf0920008,0xa6960001,0xc9550033,0x5f18000b}},	// [d6c0] ינן_, вреј, утры, योक्_
  { {0x32070057,0x0683005e,0xbcfb0003,0x2d8500da}},	//   kyny_, игун, rmée, ople_
  { {0xba9b000a,0xf1e5000b,0xceb8002a,0xdbe30003}},	//   _קסטי, किफ़_, więk_, _rééc
  { {0x7c22002e,0xca37000a,0x7794002b,0xe4a300fd}},	//   _þors, _יניה_, _میرا, аршо
  { {0x69030005,0x290c121a,0x23b70015,0x7174002b}},	//   _võet, ūdas_, ندوب_, گهبا
  { {0x8c1b0008,0xc2c40015,0xa894003d,0xa6f8000a}},	//   ווני, ايغي, šķīr, _אִֽי
  { {0xcb13000a,0x98a0002a,0x7bc10045,0x6aa1001a}},	//   שלו_, wnię_, ălui, ólfi
  { {0xf993013a,0x660355fd,0x0000006a,0x0000006a}},	//   ברה_, änke,   ,
  { {0xa8ab0008,0x13a8002b,0x1eaa0015,0xc2ca0015}},	//   וֹיִ, _سنای_, وادي_, _يبطل_
  { {0x9df8000d,0x98a0002a,0x0000006a,0x0000006a}},	//   енот_, rnię_,   ,
  { {0x6db40010,0xd1760010,0x4c9503a8,0x3207002a}},	//   ыйну, _рызы, линс, cyny_
  { {0xd02603ad,0x110a0015,0x459b004c,0x602600c9}},	//   _имей, _تغطي_, וסטע, _идеа
  { {0xdcfb0048,0xd00f003b,0x9d18024f,0x7ff3009a}},	//   lstī, _ولم_, тоят_, _نسوا
  { {0xb345001c,0x5b270036,0xda7b0080,0xcfa90015}},	//   moçã, тьма, ьям_, _ساهم_
  { {0x1db6005d,0xcf57000a,0x2ef8001a,0xf96b0033}},	//   _अमित, _שבות_, örfu_, драй_
  { {0x89340015,0xdcfb003d,0x61f70123,0x69342fa0}},	//   لعقا, istī, äxli, ансу
  { {0x085505d1,0x3207002a,0x629855fe,0xd7f800af}},	// [d6d0] уваю, zyny_, kavo, куф_
  { {0xdcfb0048,0x8504002b,0x629852aa,0x17f80058}},	//   kstī, یولن, javo, خرفة_
  { {0x63a4002d,0x4b380008,0xdb36000a,0x0574012c}},	//   áinn, _ברזל_, _תנתח_, لاند
  { {0x5884044e,0xf4870809,0xc4550015,0x0000006a}},	//   _выра, тужн, هَاب,
  { {0xad1c00b4,0x4ac0005d,0x9d1c0053,0xaac0000b}},	//   וואר, श्वव, וואט, श्वक
  { {0x69030020,0x62980938,0xe7e0000b,0x6354005e}},	//   _tões, gavo, निरप, авчу
  { {0xb5940063,0x8afc000a,0xd5b84dd9,0xdb06006f}},	//   _висш, והגי, _ист_, nuká
  { {0xdfd10029,0x3207005c,0x50b50b75,0x7c3a13cc}},	//   ميع_, ryny_, уску, ştri
  { {0x9404002b,0x629807ff,0xdcfb01ec,0x0000006a}},	//   _پوله, bavo, astī,
  { {0x637f0045,0xc3550058,0xc17b0058,0xc1a7011e}},	//   _vână, _صَاع, _قصصا_, _ајди
  { {0xd2510029,0x20d70015,0x4d661c31,0x25d5000a}},	//   _انا_, _لتشج, лков, נוֹן_
  { {0x637f0011,0x2d8555ff,0xf652000a,0xdb065600}},	//   _tână, rple_, מצי_, duká
  { {0xfbd20015,0xbebc003d,0x8fa50513,0x4fa51411}},	//   حتج_, rnīr, _сале, _силв
  { {0x8f9a00b4,0xe45600b2,0xa3bb000b,0x2d853947}},	//   _װיקי, טירט_, _अमन_, pple_
  { {0xfce60036,0xc332000a,0xda650015,0x8af70033}},	//   _бойо, צול_, لافي, ынёс_
  { {0x62981724,0xec160021,0x6903007c,0x399e0073}},	//   zavo, _موعد, _sõer, rįs_
  { {0x27e6002f,0x6d465601,0xf7720015,0xb7e60033}},	// [d6e0] íon_, moka, صاء_, ыжак
  { {0x6b840035,0x6d465602,0x563a02d9,0xbc1b004f}},	//   _itig, loka, нџер_, _נויש
  { {0x3abb0008,0x69370085,0x34aa0054,0xc869000a}},	//   _אמינ, mćen, евео_, פן_
  { {0x2db60053,0xb87b0896,0x3545005e,0x6d465603}},	//   טלען_, _caíd, ахів, noka
  { {0x44200023,0xd326004a,0xa3f40033,0x6d3b000a}},	//   ài_, льки, рплі, עֲבו
  { {0x533400d7,0x8bd7000a,0x41b40015,0x6d465604}},	//   јект, טונו_, لمتر, hoka
  { {0xa5d80008,0xd5d80008,0x62985605,0x6d465606}},	//   _בַּי, _בַּש, ravo, koka
  { {0x2902022d,0xf993013a,0x4154000d,0x91b7006b}},	//   _joka_, זרה_, јвис, угът_
  { {0xe292040b,0x7ff60029,0x2d520030,0x29025607}},	//   _هذا_, اسعا, ráel_, _moka_
  { {0x3f820024,0xc7d70008,0x29025608,0x41dc000b}},	//   īku_, נויי_, _loka_, _मनपस
  { {0x36f7000a,0x3f82003d,0x6d46073f,0x10a60499}},	//   אצים_, ūku_, foka, _биен
  { {0x9fe600e6,0x6d4630bf,0x709a0015,0xeca40058}},	//   _مسته, goka, _أنشأ_, ٍٍٍٍ
  { {0xdb1d0014,0xc621005d,0x3157000a,0xa157000a}},	//   ltsé, _मध्य_, _עידן_, _עבדה_
  { {0x501b013a,0x705300c3,0xcb680033,0x78b65609}},	//   _אודו, _انها, лаўе_, egyv
  { {0x19950010,0xfe6f0015,0x6d460030,0xdb1d01ce}},	//   рабя, _عدو_, boka, ntsé
  { {0x93c70011,0x6b52002e,0x2d9e560a,0xf7730015}},	//   ltăţ, nægj, mste_, ماط_
  { {0x2d9e1717,0x6562006f,0x1ddc0065,0x76b9009b}},	// [d6f0] lste_, dmoh, यिकत, клар_
  { {0xb87b001c,0x2d9e00bd,0xaf770053,0x8c1c000a}},	//   _saíd, oste_, טעמס_, _רוזי
  { {0x2d9e560b,0x4427002b,0xef67000a,0xa5d507be}},	//   nste_, گراف, רֹן֙_, ржеш
  { {0x39a100df,0x9474002b,0x2d9e560c,0xcdb7004f}},	//   mės_, مدها, iste_, רפאה_
  { {0x39a100df,0x889a009d,0x24580010,0x389a000a}},	//   lės_, _בברי, гаць_, _שישנ
  { {0x6b7c00b2,0xd2a6059c,0xdce40046,0x9f4600aa}},	//   ערונ, акше_, _buně, _droë_
  { {0x39a10780,0x2d9e560d,0x6d463e50,0xda05000b}},	//   nės_, jste_, yoka, रहित_
  { {0xd131003b,0x93c70011,0x25ab0024,0x2d9e2b4e}},	//   تمع_, etăţ, īklā_, dste_
  { {0x7f190010,0x2d9e560e,0x92a703ae,0x692c0045}},	//   віну_, este_, _бјел, nşea
  { {0x39a100df,0x00e5002b,0x6d46002a,0x212601d7}},	//   kės_, اتژی, woka, _emoh_
  { {0x671a000b,0xf1c80015,0xc105002b,0x692c0061}},	//   फोटक_, _مولى_, _پوشي, iğer
  { {0x39a100df,0x6d4600f2,0xd2280015,0x808b0015}},	//   dės_, uoka, _حكمه_, _أضاف_
  { {0x29020c1a,0x6d46560f,0x2d9e5610,0xd00900af}},	//   _roka_, roka, aste_, _јеле_
  { {0x6d4624a6,0xbcfb0c1b,0x501a000a,0x8f9a000a}},	//   soka, rméa, _בונו, _סיצי
  { {0xc896050e,0x6f03002d,0x8a0305c4,0xceb2000a}},	//   ирањ, _ionc, озре, _ויו_
  { {0x692c0064,0xbcfb0030,0x764e0034,0x8b961886}},	//   eğer, lmén, _ryby, _кроч
  { {0x6bd70086,0x69370085,0xbcfb0107,0x7afa025d}},	// [d700] _نويس_, pćen, omén, ötts
  { {0x39a100df,0xdb060064,0x8b9b000a,0xb7d70015}},	//   bės_, dukç, _שבית, ؤولا_
  { {0xab5b00b8,0x69030020,0x290247ea,0x2bde000b}},	//   stüc, _tõep, _toka_, मिका
  { {0x7d04022d,0x660300c0,0x452a006b,0xdb16001a}},	//   _jois, änka, ъжен_, ðbæt
  { {0x65620509,0x64360015,0xd3d70015,0x23770067}},	//   rmoh, جراء, لبوا_, لمند_
  { {0xbcfb0089,0xdb1d00dc,0x7d160026,0x75d60086}},	//   jmén, ttsé, _llys, _پيرا
  { {0xbcfb00dc,0x60280024,0x4aad005d,0x62d3002b}},	//   dmén, zīmī, फ़्टव, زآور
  { {0x3d10005d,0x7b1000b8,0x7d040bf5,0xf1a7000b}},	//   ासों_, _säul, _nois, _गिरन
  { {0x39a100df,0x60f70010,0x351b000a,0x1836000a}},	//   zės_, рныя_, _סומנ, יאֵל_
  { {0x2d9e0384,0x7b1000b8,0x7f180015,0x5f430015}},	//   tste_, _bäum, ايدز_, ينيل
  { {0x7bcd00df,0x67ca0024,0x80a60086,0x39525237}},	//   _spau, lējā, _نمان, klys_
  { {0x39a10007,0x7d042cdd,0x3d27005e,0x2d9e5611}},	//   vės_, _cois, рьов, rste_
  { {0x6f03038d,0x9ffa0029,0x2d9e5612,0x93c70045}},	//   _fonc, _جراء_, sste_, ptăţ
  { {0x6e94003b,0x39a100df,0x8f9b0632,0xbcfb0089}},	//   _الثا, tės_, _יידי, cmén
  { {0xe9190036,0xba080063,0xdb0a0030,0xdb06007c}},	//   гові_, ахте_, ónáj, dukä
  { {0x9875008f,0x39a10007,0x39520091,0x7d165613}},	//   слац, rės_, glys_, _glys
  { {0x39a10007,0x984b006b,0x2aab0004,0xceb8002a}},	// [d710] sės_, тява_, _итно_, ogę_
  { {0x39a100df,0x67ca0048,0x1dda005d,0xceb80c89}},	//   pės_, dējā, _बनात, ngę_
  { {0x09f9003b,0xbb3a000a,0x3634002b,0x466b0280}},	//   _صفحة_, _תעתי, يرمس, трам_
  { {0x4d790053,0x28f90080,0x7d7b004c,0xbcfb0030}},	//   אָסא, _семь_, דראג, zmén
  { {0xda67002b,0x8cbc000b,0xd7f805b5,0x0000006a}},	//   _حاکي, ष्टो, _кур_,
  { {0x97350086,0xc32406b4,0x20d10092,0x795a0026}},	//   _اکرا, омік, _ại_, pïwc
  { {0x75820086,0x81c70024,0x200200f2,0x41290fa5}},	//   _فیلم, ksēš, äkin_, локо_
  { {0x7b1000b8,0x6f035614,0xba38000a,0x3a38000a}},	//   _räum, _sonc, יטוח_, ירום_
  { {0xbcfb00dc,0x7529003f,0xa3ae000b,0x6f035615}},	//   tmén, _imez, _किय_, _ponc
  { {0x6f1a04a9,0xef16056d,0x7d16001a,0x7d045616}},	//   ghtc, ймы_, _slys, _sois
  { {0x7d040ae5,0xd33600f3,0x7d16063b,0x7db40151}},	//   _pois, _פרעה_, _plys, осяц
  { {0xcb09011f,0xd256000a,0xa3ae000b,0x0000006a}},	//   _אל_, _השעה_, _किम_,
  { {0x7f85003b,0x7d0439e5,0x6f1a0125,0x853a0643}},	//   _التن, _vois, bhtc, רגרי
  { {0xbcfb0030,0x3f76002a,0xbb4a0058,0x6f1a5617}},	//   lmél, _sług_, الآن_, chtc
  { {0x7d045618,0x75290089,0xd3560008,0x39525619}},	//   _tois, _omez, מישי_, tlys_
  { {0x8d84002b,0xb87b0077,0x2d590003,0x39492a67}},	//   _بشون, _raíc, léen_, goas_
  { {0xc6760029,0xd7ea0010,0x07a60010,0x66760115}},	// [d720] مطاب, ымае_, сазн, مدار
  { {0xe6460191,0x3952020a,0xab5b00dc,0x2d590003}},	//   безп, slys_, ltün, néen_
  { {0x645b016e,0x0599002b,0xd9461440,0xb65a009b}},	//   _azui, لملک_, _гени, ушах_
  { {0x67ca0024,0xf525005e,0x98ac003d,0x69de561a}},	//   tējā, офін, ēlēs_, _ispe
  { {0xa947000a,0x68e40061,0xe7bc003d,0xc30a01c6}},	//   _לָךְ_, mdid, īpēš, ледж_
  { {0x67ca0024,0x11d60029,0x43430033,0xbcfb0030}},	//   rējā, متعد, печв, emél
  { {0x2900003f,0x41e64da9,0x8c3b0012,0xe731000a}},	//   ojia_, إستف, maße, _חֵן_
  { {0xd130003b,0x67ca0024,0xc872000a,0x68e4561b}},	//   ظمة_, pējā, ּן֙_, ndid
  { {0x68e4007c,0xd4690015,0x75230079,0xab5b0030}},	//   idid, _نحكم_, ënze, dtün
  { {0x272f005c,0xf5aa0008,0x23eb002b,0x68e40061}},	//   ożna_, ְבָּ, _حذفی_, hdid
  { {0x9e14005e,0x629a561c,0xceb81e7f,0xde5801c6}},	//   ідмі, _ieto, rgę_, рані_
  { {0x5c0749a2,0x69370085,0xd657004f,0x0000006a}},	//   бяга, tćem, מיית_,
  { {0xdfd00086,0x68e40034,0xe0431664,0x69de561d}},	//   _آيت_, ddid, _енци, _aspe
  { {0x629a0152,0xc87f00b8,0xf1ac000b,0xa3e9000b}},	//   _jeto, _maße_, _घटान, यित_
  { {0xc3330008,0x28a70010,0x127b004c,0x629a561e}},	//   לוש_, йшаг, ראלע, _meto
  { {0x9955009e,0xce37000a,0x629a09cb,0x68e402f2}},	//   ікац, _לאות_, _leto, gdid
  { {0xe787005e,0xdb0f0f7b,0x765c01c2,0xfb85002b}},	// [d730] субо, lucí, _azry, _بدبی
  { {0x05790029,0x3949001c,0x63a2561f,0x68e45620}},	//   لمئة_, soas_, dson, adid
  { {0x65d500e6,0x6eca000b,0x63a25621,0x7af30091}},	//   تياط, त्यु, eson, četė
  { {0xa3b90087,0x54552b7a,0x984b006b,0xe4c500ce}},	//   لاتر_, овет, _бяга_, ійли
  { {0x2bdf005d,0xe824004a,0x629a5622,0xb867002b}},	//   _पैमा, _ефро, _beto, _دادو
  { {0x65950b75,0xcb9c000a,0xab5b0030,0xa18900fd}},	//   _магу, נסוט, ztün, абка_
  { {0xf1a80086,0x63a220d7,0x3abc000a,0x629a3653}},	//   مايه_, ason, אמונ, _deto
  { {0x753b003f,0x75292f86,0xdb0f0077,0x1fa9004a}},	//   _ujuz, _umez, ducí, акии_
  { {0x600604ab,0xef19384f,0x63a202a8,0xf41f0123}},	//   жным_, ими_, cson, _åä_
  { {0xc34b008f,0x27e9008c,0x629a5623,0xff25005e}},	//   _сябе_, ivan_, _geto, імно
  { {0x29190064,0xab5b00dc,0xa5db000a,0x2d590003}},	//   _olsa_, ttün, רַ֖י, réen_
  { {0x4c83005e,0x3ff50015,0xec9a00af,0x0000006a}},	//   млюв, _وكار, штој_,
  { {0xe1340010,0x814c0053,0x2ca90026,0x2d590152}},	//   _энцы, _געאַ, _ddad_, péen_
  { {0x63a4002f,0xdaba0010,0x2ca95383,0x02f9000a}},	//   áini, шымі_, _edad_, ׁלָמ
  { {0xcdc80029,0x7bdf194d,0x3f8d0144,0x6ee40040}},	//   _هذين_, _esqu, lpeu_, _رسول
  { {0x63a4138a,0x7d1d0012,0xab5b0061,0x6d47006f}},	//   šini, chss, ltül, čkac
  { {0x98a9005c,0xaa8a0086,0x68e45624,0x7c660015}},	// [d740] znać_, _پنجم_, rdid, _باغل
  { {0xab5b01e2,0x98a9002a,0xd7ef0015,0x29192789}},	//   ntül, ynać_, ضكم_, _elsa_
  { {0x8c3b00b8,0x69de0198,0x27e900f2,0xef12000a}},	//   raße, _uspe, avan_, וּף_
  { {0x7bc62438,0x62835625,0x8c3b0012,0x629a5626}},	//   otku, ecno, saße, _seto
  { {0xd40305c4,0x43942352,0x98a9002a,0x9313002b}},	//   дящи, чалс, wnać_, ژوهش
  { {0xfbb2005d,0x37d90053,0x47d90053,0xa3bb000b}},	//   _जिनम, _פֿרע, _פֿרײ, _अमर_
  { {0xc3270029,0x63a204a0,0x7bc6007c,0x65c308ad}},	//   تكون_, sson, htku, _обра
  { {0x63ad03eb,0x60f8085d,0x1fa6245b,0x0446006b}},	//   šana, сния_, орог, _дебн
  { {0xf0b70074,0xdfd00070,0x50b70086,0xa2d60015}},	//   زايش_, ريد_, زديد_, _ويرت
  { {0xbcfb0152,0xcf260015,0x51f60015,0xdb06001a}},	//   rmém, تربي, _وسار, yrká
  { {0xa3e2005d,0x27e916a8,0x667b00f3,0x867b000a}},	//   धिक_, zvan_, יטיק, יריו
  { {0xbfa30023,0x657c00f2,0x27e90064,0x71650015}},	//   _kiế, _murh, yvan_, _فانك
  { {0x4ae7008f,0xa06a0001,0x9be4005e,0xdb1d001a}},	//   оўва, _тада_, мірк, stsí
  { {0xfe6f002b,0xe451000a,0x0000006a,0x0000006a}},	//   عدی_, גֶל_,   ,
  { {0x657c0375,0xa2bf000b,0x7bc65627,0xaa59005e}},	//   _nurh, ल्ट्, atku, сиву_
  { {0xa3bb000b,0x8c3b0012,0x718b000a,0xad670058}},	//   _अमल_, raßb, יְמַ, _باته
  { {0x2bb2000b,0x27e9008c,0xbab6009a,0xdb0f00d4}},	// [d750] _जिया, uvan_, _کمپب, rucâ
  { {0xa9280089,0xd6db009c,0x27e95628,0x657c055d}},	//   _požá, јта_, rvan_, _burh
  { {0xab5b00b8,0xe678005e,0x056b0004,0x657c01d7}},	//   ntüm, ійці_, ајди_, _curh
  { {0xbfa30023,0x04c80029,0x04c90015,0xe578008b}},	//   _biế, قومي_, صوتي_, ізі_
  { {0x78fa0008,0x7ae50607,0x97c70015,0x04c80015}},	//   _הפרו, _kaht, _بتجم, توني_
  { {0xfbb80008,0x8bdc000a,0x8c1c000a,0x20e70016}},	//   קפות_, שַׁח, סוגי, _ối_
  { {0x4648008f,0xdb240084,0xe4d70015,0x9f460125}},	//   _дзён_, ðrét, _وترب, _croí_
  { {0x7ae50e95,0xc5f201ac,0x04c90015,0x2fd90015}},	//   _laht, _אדל_, _دوري_, موعد_
  { {0x69c7010b,0x78fc000a,0xc954000a,0x91280015}},	//   htje, שפחו, ומק_, تسوق_
  { {0x7ae508f5,0xa2b44f9c,0xef19047d,0x2374006f}},	//   _naht, _обуч, смо_, ľajú_
  { {0x9f420046,0x24803672,0x3f76002a,0xab5b52db}},	//   íká_, žime_, _płuc_, gtüm
  { {0x69c700fb,0x8c462d1e,0xce180033,0xab5b5629}},	//   dtje, земе, юцыі_, stül
  { {0xa088000a,0x8d75002b,0x2bdf000b,0x7ae50bc7}},	//   _וְצִ, _کاتا, _पैदा, _baht
  { {0xa3ae005d,0x28ce005d,0x692c0061,0x291e003d}},	//   _किस_, ह्नि, rşem, ītam_
  { {0xab27008b,0x7bc6562a,0x811f0065,0x7bdd01f9}},	//   чора_, stku, _बताओ_, awsu
  { {0xf1e2000b,0xcf25002b,0x657a0003,0x77860054}},	//   _कैफ़_, _برچي, _éthi, злаз
  { {0x18670185,0x1cbb000a,0x4cbb000a,0xfaf60015}},	// [d760] зати_, _המפע, _המפג, _فأدخ
  { {0x69dc00da,0xfb3a0015,0x69c704d1,0x0000006a}},	//   pwre, _دأبت_, btje,
  { {0xceb20008,0x8a7b000a,0x9aeb000a,0x4a7b000a}},	//   תיב_, _לאית, _הַכִ, _לריב
  { {0x7ae5065d,0xd946049d,0x75d30015,0x9e48000a}},	//   _zaht, _хеми, عينا, חֲנִ
  { {0xf8b3013a,0x23480086,0xdb1d00dc,0x2d98562b}},	//   _אשר_, يستی_, ltsá, árez_
  { {0xbfa30023,0xd3790036,0xe7320015,0x657c008c}},	//   _viế, ічі_, _أصح_, _turh
  { {0x7d1d00aa,0x2d83005a,0x6b5201d0,0x68e6013b}},	//   ërsk, íjel_, lægs, _kakd
  { {0xbfa30023,0xbcfb0014,0xd2590010,0xe58b000a}},	//   _tiế, rmék, цці_, _לָמָ
  { {0x692c0064,0x44220123,0x24863695,0x68e601ec}},	//   eşek, _åk_, mcom_, _makd
  { {0x141b000a,0x10130015,0xa3d9000b,0x441b000a}},	//   _הומב, عبيد, ़बर_, _הומס
  { {0x2d980b7a,0x1cd902bf,0x7ae5008c,0x8cc10065}},	//   ère_, одны_, _raht, _वादो
  { {0xd1970008,0x7ae519a2,0x2486122c,0xdca40004}},	//   _זכאי_, _saht, ncom_, наџи
  { {0x61dc000b,0xab5b0359,0x0000006a,0x0000006a}},	//   _मनुष, stüm,   ,
  { {0x32cf0064,0xbcfb002d,0xc9770015,0x26da0085}},	//   cıyı_, iméi, كارث, jepo_
  { {0xceb3000a,0x48ab056d,0x7ae505ff,0xd357000a}},	//   _טיס_, йтам_, _vaht, פילי_
  { {0x7655005c,0xb87b0046,0x6e3b0643,0x69c74ae1}},	//   _ryzy, _hníz, _לתוד, rtje
  { {0x5ba4008f,0x69c7562c,0x2486562d,0x7ae5562e}},	// [d770] _прэз, stje, dcom_, _taht
  { {0xec380008,0x6b8d0035,0x6d4f562f,0x8c1c000a}},	//   _מאחר_, _itag, loca, _לוחי
  { {0x692c0061,0xfc3f0125,0x317e02ad,0x0000006a}},	//   kşeh, saíd_, _nutz_,
  { {0x95570015,0xe8550015,0x27fc0046,0x32cf0061}},	//   أخطا, _يندد, ózní_, zıyı_
  { {0x5c38004c,0x6d4f02b9,0x32cf0061,0x7655002a}},	//   ּרון_, ioca, yıyı_, _wyzy
  { {0x6d4f002f,0x63ad0340,0x35b50b08,0xd7fa000a}},	//   hoca, šano, _обгр, _והשל
  { {0xdb2400dc,0x6145004a,0x95570067,0xc5570015}},	//   éséb, мека, _فخرا, _فضرب
  { {0x2d830057,0x92580015,0xdfd10015,0x7b100012}},	//   íjem_, أشهر_, نيع_, _häut
  { {0x63a4002d,0xd0a800e5,0xb4b9000b,0xc4d2000a}},	//   áint, سطين_, चली_, _בגן_
  { {0xee39557e,0x5f05005e,0x3f8b003d,0x6d4f0978}},	//   жно_, єзна, īcu_, eoca
  { {0x63a90084,0x6d4f5151,0x82150015,0xfd120015}},	//   _hven, foca, _تواص, نجح_
  { {0x60c2002f,0x30150142,0x63a9002e,0x01640015}},	//   _gcom, _одер, _kven, _كُلَ
  { {0x212a0086,0xeb9703fc,0xafe50054,0x32cf0061}},	//   _بينی_, мия_, _цолл, pıyı_
  { {0xdb1d00dc,0x6b8d002d,0xd7f80045,0x1ee7002b}},	//   ttsá, _dtag, _ăă_, _روبی_
  { {0xdcfb0064,0xb8f60015,0x1d0a07be,0x4e940015}},	//   artı, وكسب, _меки_, _أشهر
  { {0x26da003f,0x63a901f0,0x997d005e,0x8c3b0012}},	//   wepo_, _oven, стрi, maßn
  { {0x2486002c,0x63ad002e,0xd70a0033,0xcece0016}},	// [d780] vcom_, áanl, онае_, _mộng_
  { {0x2486005c,0x0bb7000a,0xb63600c3,0xb75a005e}},	//   wcom_, _קלים_, وعات, ішає_
  { {0x8afb009d,0x5afb0008,0x63a91915,0xc7a9000a}},	//   _והיי, _וליצ, _aven, שב_
  { {0xe45a1664,0xf993004f,0x0000006a,0x0000006a}},	//   оже_, _שרר_,   ,
  { {0x2ca00020,0xc3da0225,0xf8db000a,0xe2f801f3}},	//   _meid_, تباط_, _וחכמ, зелі_
  { {0x25080086,0x2ca00a11,0x60c25630,0x78a45631}},	//   _کرسی_, _leid_, _scom, laiv
  { {0x7b1000b8,0x4b37000a,0x1ddd000b,0x63a9473d}},	//   _häus, ורסל_, _फैलत, _even
  { {0xcece0023,0x2ca00005,0x760b0008,0x21670054}},	//   _cộng_, _neid_, _וּמַ, мији_
  { {0xc953000f,0xf957000a,0x6d4f0ebc,0x72c60054}},	//   כמה_, וסקת_, voca, _обаз
  { {0x4426000c,0xd7fb0008,0x22160063,0x57fb000a}},	//   mzo_, קהיל, _офер, קליו
  { {0x1df80080,0x1d3506b4,0x27e000d9,0x56b70008}},	//   чены_, ення, hwin_, ופין_
  { {0x660304ea,0x81690015,0xd01a0004,0xd1750138}},	//   änki, _فإنّ_, _мфл_, _зычы
  { {0x44265316,0x101600e5,0xdeb40033,0x290b5632}},	//   nzo_, _تباد, _зблы, _roca_
  { {0x27e05633,0x44265634,0x0000006a,0x0000006a}},	//   dwin_, izo_,   ,
  { {0xd90f0086,0x2bdf005d,0xf77f0061,0xdebb000a}},	//   لید_, _पैरा, _suç_, _ומול
  { {0x79540015,0xc8c90015,0x58d42003,0xa2d5000b}},	//   نَّا, ثورن_, кост, _मॉन्
  { {0x4c9c000a,0xa8340054,0x58840033,0xd6ab006e}},	// [d790] _ובחו, ветљ, тыса, قدام_
  { {0x44261164,0x69370085,0x60db0030,0xfd8a004f}},	//   dzo_, ećet, zeum, ַטְּ
  { {0x27e00035,0xc9870031,0x63a91b28,0xd5b10015}},	//   awin_, _تشخي, _sven, افؤ_
  { {0xb4b9000b,0x75220030,0x7d0d5635,0x7b1002ad}},	//   चले_, ghoz, _joas, _fäus
  { {0xdb1d00fb,0xcece0023,0x94740086,0xc355006b}},	//   rtsæ, _rộng_, ندها, нъкъ
  { {0xfbb2014e,0xfc18000a,0x1308005e,0xdb1d02de}},	//   _जिसम, וקדי_, мній_, stsæ
  { {0x11670086,0xf6740010,0xba9c000a,0xe5c4133a}},	//   ولتی_, _агрэ, חסוי, _исто
  { {0x7d0d04f9,0x75225636,0xfa78039e,0xa0c5002b}},	//   _noas, choz, ועות_, ريخو
  { {0x20190014,0xe454008f,0x61f8002c,0x4426002a}},	//   ási_, _акты, _ďalš, czo_
  { {0xc432002b,0x92670015,0x2ca001f1,0x22950015}},	//   _حکمت, _قدام, _seid_, _ألاس
  { {0xa2c4005d,0xa2dc000b,0x7d0d00da,0x2bb2000b}},	//   _रात्, फ़र्, _boas, _जिहा
  { {0x7d0d14e6,0xdb0601b2,0x361a004c,0x692c1999}},	//   _coas, mské, פורד, lşev
  { {0x50b80086,0x2ca0002d,0xdb0601b2,0x78a4030a}},	//   _زدند_, _veid_, lské, vaiv
  { {0x316d0064,0xa0380015,0xada50822,0x80cb0065}},	//   lmez_, _تأمر_, _закл, थ्रे
  { {0x442602d7,0x2ca00020,0x5f740086,0xa96a023e}},	//   zzo_, _teid_, _شاهر, зива_
  { {0x316d0064,0xbcfb0077,0xdb1d008c,0x3ea55637}},	//   nmez_, eléf, etsä, lalt_
  { {0x63ad0198,0x7f8c0053,0x6d3b000a,0x96b60054}},	// [d7a0] šanj, ַנאַ, _מתקנ, есељ
  { {0xff7a0053,0x78a4030a,0x27e05638,0x3ea53583}},	//   פטעמ, saiv, rwin_, nalt_
  { {0xba9b0008,0x316d0064,0x2724002e,0x1a9b000a}},	//   _מסיי, kmez_, _löng_, _מייע
  { {0x3d1e005d,0xdb060107,0x3ea55639,0x7b100012}},	//   _पतों_, dské, halt_, _täus
  { {0xba76002b,0xd130002b,0xdb060046,0x3ea52d03}},	//   _تاکت, یمت_, eské, kalt_
  { {0x3ea50005,0x39402f6d,0xd3700021,0x213f01c2}},	//   jalt_, lnis_, جهت_, enuh_
  { {0x8cc1005d,0x3ea55320,0xcb13000a,0x6d560061}},	//   _वालो, dalt_, רלו_, _okya
  { {0x394026a3,0x2567007c,0x3ea50158,0x4fd4005e}},	//   nnis_, võlg_, ealt_, вжит
  { {0x7d0d0a1c,0x987b004c,0x250b002b,0x934608b0}},	//   _roas, האפט, _عرفی_, _знае
  { {0x3940018b,0x80170029,0xc2e90029,0x33d50036}},	//   hnis_, عزيز_, _يعلم_, _шіст
  { {0x07370008,0xdb0600dc,0xd36f0087,0x3940288a}},	//   תאים_, cské, _اهل_, knis_
  { {0x721b000a,0x395200da,0x2724001a,0x20c90015}},	//   _מובח, joys_, _hönd_, _يبني_
  { {0x0b8b0063,0x7d0d0011,0xa2d5000b,0x3ea53b45}},	//   ясни_, _voas, _मॉड्, balt_
  { {0x6ffb000a,0x7b100012,0x628a0a8b,0x39403fb1}},	//   _מהדפ, _säur, ncfo, enis_
  { {0xcf570008,0x19590033,0x799e0034,0x3940563a}},	//   _רבות_, давы_, _cwpw, fnis_
  { {0x0e5b0008,0x2724002e,0xda080015,0x3940563b}},	//   _מדוב, _lönd_, ريقه_, gnis_
  { {0xd6db006b,0xdb060046,0xdb1d0dca,0x5bb80138}},	// [d7b0] зте_, zské, ttsä, _злыя_
  { {0x6d5d00c0,0x4c3c0008,0x3940048c,0xfb27002b}},	//   llsa, _מתחב, anis_, _سرخپ
  { {0xdb1d01d1,0x394000b8,0x86c40015,0xa899004a}},	//   rtsä, bnis_, ايمن, _окну_
  { {0xdb06563c,0x7b100012,0x451800fd,0x43952666}},	//   vské, _häup, нція_, вадс
  { {0xdb1d00b8,0x68ed0061,0x24f80033,0xc7c70c31}},	//   ptsä, mdad, энцы_, _ясни
  { {0x2724002e,0xdb060107,0x8234002b,0x2909008c}},	//   _röng_, tské, گرها, ljaa_
  { {0x3ea50005,0x9f4b0089,0x04950029,0x6d473827}},	//   valt_, ící_, _للأح, čkaj
  { {0x3ea500b8,0x13f50063,0x290900f2,0x660300b8}},	//   walt_, _избя, njaa_, änku
  { {0xa3ae005d,0x31560029,0x443900c0,0xf8bf00dc}},	//   _किए_, خليج_, _äs_, _elég_
  { {0xbcfb0089,0xdb060089,0xe3a70086,0x39400e9f}},	//   hléd, pské, یر_, znis_
  { {0xdc34032c,0xa3e9005d,0x6e45030e,0xa2f6000a}},	//   rúča, यिक_, тенз, _שמעה_
  { {0x6aca014e,0x3ea50005,0x40870063,0x7db40010}},	//   िभ्र, salt_, _чужб, ысьц
  { {0x68ed0845,0x395200da,0x73ac000a,0x40e8004f}},	//   ddad, voys_, ּילֵ, _רַעֲ
  { {0x68ed001c,0x80640036,0xf8bf0144,0x692c0061}},	//   edad, _свіж, _omés_, hşet
  { {0xa2c4005d,0xc3320008,0x394000b8,0xdb04001c}},	//   _रास्, בום_, tnis_, _aviã
  { {0xdcf90024,0xf1b200a3,0x6d440509,0x68ed563d}},	//   _tuvā, יסל_, _ujia, gdad
  { {0xdb16002e,0xed57000a,0x39520f21,0xabaa0033}},	// [d7c0] ðbót, _בבקר_, roys_, _ўвоз_
  { {0x66760086,0x2606005d,0x39401a37,0x2909008c}},	//   ندار, _सऊदी_, snis_, ajaa_
  { {0x75890036,0xa486002b,0xa50a006b,0xbcfb0324}},	//   есів_, نجشن, межа_, mmér
  { {0x6b840020,0x63b90026,0xbcfb00dc,0xf669002b}},	//   _kuig, frwn, lmér, رحله_
  { {0xb906000b,0xb5450015,0xbcfb016e,0xccf3000a}},	//   फ़_, دخله, omér, יכא_
  { {0xf5960015,0x26de006f,0xe8010065,0xf74600ce}},	//   _للسج, _úto_, ोहरा_, _рего
  { {0x31340036,0xf1a30010,0x26140008,0xbcfb0152}},	//   лекр, арын, _גַּם_, llée
  { {0x9fe60015,0x63b90034,0x69ce02f7,0x74fa0058}},	//   نسخه, brwn, itbe, _تفرز_
  { {0xa4b7039e,0x7413002b,0x42ca0004,0x3f661d90}},	//   _שלמה_, _پولا, _оган_, ктоб
  { {0x4d980036,0xf2e8002b,0x5d980033,0x3f76002a}},	//   нкою_, _سکته_, нкоў_, _tłum_
  { {0x72060086,0x9e3c002c,0xe357000a,0xb6bb000a}},	//   _جوام, raďo, _ישמח_, וציי
  { {0xa5c2005c,0x20020020,0xf653000a,0xe611000a}},	//   łówn, äkis_, יצת_, צִי_
  { {0xcfb40063,0x70b7000a,0xd12f0021,0xeafb0015}},	//   _сблъ, _יהאד_, _بمن_, ورست_
  { {0xe7f6000b,0xdce6003d,0x0eba0033,0xbcfb0030}},	//   ँटना_, rmkā, _цуды_, gmér
  { {0x987e0064,0xaa580001,0x98a9005c,0x0f7b000a}},	//   _açık_, виру_, niać_, _קרול
  { {0xbcfb1714,0x3987007c,0x63ad05e3,0xd5bf003d}},	//   rmés, _võs_, šani, šāks_
  { {0x19581292,0x290900f2,0xa3e2000b,0xadea000b}},	// [d7d0] таты_, rjaa_, _फैल_, टिकन_
  { {0xa2c4014e,0xcc58000a,0x7d1d0028,0xe7300015}},	//   _राष्, _בבחי_, lkss, يصل_
  { {0xe919005e,0xfdfb000b,0xb6350015,0x765c002a}},	//   _зоні_, एमएस_, دفاع, _cyry
  { {0x99f6013a,0x2d590152,0x3eb90007,0xe3b100e6}},	//   _עזרה_, mées_, ėsti_, مرت_
  { {0x63a00176,0x2d590152,0xd0060196,0x291e0024}},	//   _cwmn, lées_, _ال_, ītat_
  { {0x5694009e,0xdb1d0152,0x82a40054,0x8c1c000a}},	//   _варт, fusé, ашће, וודי
  { {0x2d59038d,0xa19d0033,0x74a700af,0x7d1d18c9}},	//   nées_, чылi, _ајзе, kkss
  { {0x4fe9000d,0x11d60029,0x2d590152,0xd24e0015}},	//   емин_, اوية_, iées_, ثنى_
  { {0x3fc80074,0x63a00026,0x7ff500e5,0xcf39005e}},	//   نگوی_, _gwmn, اسبا, ечні_
  { {0x27240012,0x98a9002a,0x8e0912bd,0x6b840079}},	//   _töne_, biać_, енов_, _ruig
  { {0xdb1d0003,0x613e003d,0x2fcd563e,0xdca610b3}},	//   cusé, zīli, steg_, лани
  { {0xa3e7005d,0xa5da0053,0x8d55005e,0x2d590003}},	//   _बना_, ײַטי, итяч, dées_
  { {0xdcf90048,0xbab60010,0xdb04016e,0xfc3f0125}},	//   _atvē, лёвы, _aviá, saín_
  { {0x6fb20002,0x703a004c,0xab630033,0xbcfb0140}},	//   _اموا, _אײנצ, йвял, umér
  { {0xc332009d,0x2d590152,0x5ee8000a,0xbcfb0030}},	//   מוך_, gées_, _יַקְ, rmér
  { {0x6b84002d,0xa2d5000b,0x5fb7000b,0x28950054}},	//   _tuig, _मॉस्, _इटाल, ијус
  { {0xbcfb0030,0x765c002a,0x9696011a,0x78660a32}},	// [d7e0] pmér, _syry, греш, указ
  { {0x681a0024,0x613e003d,0x2d590003,0x69ce232f}},	//   _rādā, rīli, bées_, ptbe
  { {0x2d590152,0x692c0045,0xd5af0015,0x0000006a}},	//   cées_, uşes, كفل_,
  { {0xc6890008,0x291e0024,0xab5b0012,0x142627f6}},	//   לא_, ītas_, stüt, лдем
  { {0x98a9005c,0xbd2d0053,0x628f0011,0x765c002a}},	//   wiać_, וואָ, _şcoa, _wyry
  { {0xab5b03ba,0xfbd3000a,0x7cfb008c,0xd75a0058}},	//   ltür, צתו_, _kärä, _ألست_
  { {0x6ef400dc,0x1546000d,0x47330033,0x0000006a}},	//   nübő, _бевм, _унёс,
  { {0x60f80063,0x6d5d0089,0x75d30015,0x681a003d}},	//   тния_, ůraz, _ديفا, _tādā
  { {0xd3f40036,0x04464d4b,0xc837004c,0xa3ae0065}},	//   _мiст, _сеан, ָטיץ_, _किट_
  { {0x2d590152,0x0fd70015,0xdd900015,0x8f340248}},	//   yées_, ابيث_, يوخ_, реоц
  { {0xbcfb00dc,0xe29b0008,0x2d590003,0x8757000a}},	//   jléc, _נשאר, xées_, רביג_
  { {0x2d590152,0xac19006d,0xb2370015,0x8ed7002b}},	//   vées_, вому_, _حكما_, پذیر_
  { {0x351b0008,0x40ab002b,0x7d1d563f,0xd12f0040}},	//   תוכנ, _سخنی_, rkss, _عمه_
  { {0xce940063,0x2d590152,0xbcfb0152,0xadd8005e}},	//   _такъ, tées_, fléc, _амку_
  { {0xa3ab014e,0xdd900015,0xd9150033,0xaa590511}},	//   _कौन_, _بوب_, адвы, тиву_
  { {0x2d590152,0x7db300c3,0x0dc701da,0xc9840766}},	//   rées_, _اصوا, _суши_, сури
  { {0x2d59038d,0x7d7c004c,0x47355326,0x2eee00cb}},	// [d7f0] sées_, _אנהו, анас, _kaff_
  { {0x56670015,0x2d590003,0xe7330031,0xab5b0475}},	//   هداف, pées_, حصر_, rtüs
  { {0x78a600dc,0x36d4004a,0xd019002a,0x58d51411}},	//   _fekv, сохр, zyń_, _конт
  { {0x05740074,0x54a70086,0xd3b90010,0xa4d50036}},	//   ماند, احاف, вукі_, роді
  { {0x8d4c000a,0xbcb8004f,0x0000006a,0x0000006a}},	//   עֲבֵ, רפדו_,   ,
  { {0x77ba0008,0x87070010,0x883a0008,0xeb920008}},	//   _במשח, _сяме, _יתרו, חָה_
  { {0x22490063,0xab5b00b8,0x2997004f,0xca98004f}},	//   ъпки_, prüf, אֻ֖ם_, נדהי_
  { {0x2bb6000b,0xa2d5000b,0x3a38000a,0xf994004f}},	//   _अटला, _मॉर्, טרום_, זרק_
  { {0xa2cd000b,0xa1120015,0x68ef3283,0xf1c7006f}},	//   _साप्, تويت, _macd, _snáď_
  { {0xe80d005d,0xef16004a,0x249d0034,0x62810085}},	//   _सपना_, имы_, lbwm_, _uglo
  { {0x5284003b,0x60b50086,0x96ca000b,0x12fa000a}},	//   _المك, _نمائ, स्टॉ, _שהעב
  { {0xc19a000f,0xe167002b,0x0d820033,0x0656000a}},	//   _ישעי, _صداي, ўлян, ייתך_
  { {0xa09a00b2,0x8d550010,0x8fa52bbd,0x78a65640}},	//   _סיסט, стэч, _тале, _rekv
  { {0x5e870010,0xa2cd000b,0xfaa30c5b,0x75f00030}},	//   _судз, _साफ्, жаро, nózá
  { {0xc3320008,0x2d590003,0x83fd0030,0xd9560015}},	//   קול_, réer_, _szől, لنسخ
  { {0xe8fa006b,0x2eee01c2,0x3ea75641,0x7cfb008c}},	//   ълб_, _zaff_, _hent_, _värä

  { {0x1bed000b,0xb8ee000b,0xc6960015,0x3ea75642}},	// [d800] _चैपल_, _रा_, لشاع, _kent_
  { {0xf77200a2,0x36960010,0xab5b0012,0x2567007c}},	//   زاء_, ршас, stür, võla_
  { {0x2d87003e,0x3abb000a,0x7abb000a,0xaabb000a}},	//   _june_, _במינ, _בציו, _בזיכ
  { {0x63640251,0x6d465643,0xab5b0012,0x3ea72ab6}},	//   tòno, nnka, trüg, _lent_
  { {0x44320023,0x9cd70008,0x636d002e,0x44205644}},	//   ày_, שונה_, kúnd, ái_
  { {0x8c1b0008,0xa596004a,0x159a0015,0x24170033}},	//   כוני, _вращ, _لنسخ_, рошы_
  { {0x1bed005d,0xdcc6005d,0x44204074,0x61ed002a}},	//   _चैनल_, _वांछ, ši_, łaln
  { {0x44200092,0xf9930008,0x68e45645,0x2eee0034}},	//   ơi_, חרה_, neid, _saff_
  { {0x42ea0001,0xff060010,0x3ea75646,0x506601f3}},	//   _имао_, аянн, _bent_, штка
  { {0x11d60191,0x2d870011,0x6d460e8f,0x539b039e}},	//   _відр, _bune_, enka, _סיבו
  { {0x171b0053,0x36f70008,0x63ad0007,0x68e41190}},	//   דויע, בצים_, šant, keid
  { {0x68e400f2,0x659b000a,0xd657000a,0x2d871aec}},	//   jeid, כיטק, שיטת_, _dune_
  { {0x6f940029,0xa2cd005d,0x3ea75647,0x69de0376}},	//   _التض, _साम्, _fent_, _appe
  { {0xd2460029,0x3ea75648,0xad27002b,0x3ffb000a}},	//   كن_, _gent_, ارگو, _שפגע
  { {0x68e4002f,0xc9870c1c,0x298805c8,0x3eac0030}},	//   feid, руги, исто_, madt_
  { {0x68e400df,0x1d080001,0xdb1d0107,0x3eac1e86}},	//   geid, _већи_, musí, ladt_
  { {0xbcfb3d91,0xe796002b,0x656201c0,0xad27009a}},	// [d810] cléa, مالک, dloh, _مرکو
  { {0x3077013a,0x2ca90100,0x98ac003d,0xdc3c000a}},	//   שתמש_, _head_, ēlās_, _שעזר
  { {0xd6d80001,0xb87b5649,0x58870010,0x68e4564a}},	//   јту_, _país, _выга, beid
  { {0x6705014e,0x45840036,0x2d800003,0xccf2004f}},	//   राहक_, ігів, _xiie_, ּ֛א_
  { {0x37e40010,0x3eac00dc,0x61fa002d,0x9cda004c}},	//   _доўг, kadt_, _artl, רקױפ
  { {0x78ad00f2,0x2ca90556,0x52e1000b,0xa3c9000b}},	//   laav, _lead_, फ़ेस, लंब_
  { {0x8ab8000a,0x51f50015,0x02d60067,0xb3080067}},	//   בלוג_, إستر, صويب_, شغول_
  { {0x3ea7564b,0x78ad05ff,0x2d87564c,0xefc9009b}},	//   _sent_, naav, _rune_, глил_
  { {0x8ff9002b,0xa1560054,0x7f1900fd,0xb938004f}},	//   اربر_, љању_, гіну_, ינהו_
  { {0xdb1d002e,0x2d870ee0,0x27e90035,0xf2d80015}},	//   fusí, _pune_, iwan_, _نظمت_
  { {0x78ad00f2,0x31850015,0x21260012,0x3ea70223}},	//   kaav, _الصِ, _floh_, _vent_
  { {0x3ea70041,0x2ca9002d,0x6d4600dc,0xb0f40015}},	//   _went_, _cead_, unka, _وأنش
  { {0x68e403eb,0x2ca9003e,0x2d800020,0xb4fa000a}},	//   veid, _dead_, _viie_, אפרי
  { {0x6e950029,0x68e40313,0x60c9564d,0x5ea50015}},	//   _الغا, weid, lgem, _امثل
  { {0x68e4564e,0x2ca90125,0xaa4a006b,0x60c943da}},	//   teid, _fead_, упва_, ogem
  { {0x628f0011,0xbcfb338f,0xcdb6000a,0x88860195}},	//   _şcol, llén, _הפקה_, слаж
  { {0xa3c9000b,0xb87b016e,0x68e4564f,0xdcf90091}},	// [d820] लूम_, _saír, reid, _atvė
  { {0x7adf000b,0xab5b0012,0x0a5a0015,0x8c37000a}},	//   _पॉपअ, arüb, _مشجع_, _לטפס_
  { {0x7bc62aa7,0x69de0876,0x99d600e5,0x9b1705bd}},	//   luku, _uppe, _اتخا, _החיה_
  { {0xab5b0064,0x2db6004c,0xdcf90091,0x3386033d}},	//   crüb, מלען_, _buvę, букв
  { {0x7bc644c3,0xd7f20015,0x7d04051e,0xdc89000a}},	//   nuku, _عكس_, _mnis, בְצָ
  { {0xff470086,0x60c903ff,0xb5aa0015,0x8bd7000a}},	//   _رخ_, egem, _مارك_, מונו_
  { {0xdb1d001c,0xe1ef0015,0x2b7b004c,0x24890085}},	//   lusã, فسي_, נטצײ, žama_
  { {0xf8ba005d,0x361b0008,0x7bc65650,0xa491002b}},	//   ेलिय, _גולד, kuku, _قیمت
  { {0x2ca9003e,0x60f70010,0x3eac0745,0x43860015}},	//   _read_, сныя_, tadt_, _طلاق
  { {0x75220014,0x63b30089,0xf1a9002b,0xbdb40099}},	//   lkoz, ření, _چانه_, обој
  { {0x80a60086,0x2ca90020,0x3eac00dc,0x398e002e}},	//   _همان, _pead_, radt_, _nýs_
  { {0x30860029,0x867b0008,0x7bc6003f,0xb58202a3}},	//   _الإف, טריו, fuku, онiк
  { {0x78ad00f2,0x2ca9007c,0xdb1d001a,0x2fd3006e}},	//   vaav, _vead_, rtsþ, _فتوح
  { {0xab5b00b8,0x2724002e,0x26ce0144,0x83fd0030}},	//   drüc, _sönn_, òfol_, _szők
  { {0xc3390089,0x2ca9007c,0x78ad008c,0xab5b0012}},	//   _říká, _tead_, taav, trüb
  { {0x7c970086,0xdb1d016e,0x63a40091,0x7bc61e8a}},	//   _اشغا, fusã, šiny, buku
  { {0x78ad022d,0x3d290086,0x636d0341,0xc8671b01}},	// [d830] raav, _متکی_, núnc, стви
  { {0xab980074,0x7d04005c,0x75220079,0xd7c80067}},	//   _اخير_, _znis, ekoz, صومه_
  { {0x78ad008c,0xc66b0033,0xa3ab000b,0xf5b400ce}},	//   paav, ушае_, कीन_, зсію
  { {0x2ee50111,0x34ab0015,0xab5b5651,0x7ae75652}},	//   zelf_, اداً_, brüc, lejt
  { {0xd2a90054,0x7d7c004c,0xdfc600c3,0x39495653}},	//   акле_, אנאו, _تي_, mnas_
  { {0xf7940010,0x39490095,0xa3aa000b,0x28d5000b}},	//   _харэ, lnas_, _खबर_, ड्रि
  { {0x51840001,0x754800dc,0x34950c5b,0x41750015}},	//   пуња, ószá, _мавр, يابس
  { {0x7ae70089,0xa4d4017f,0x39495654,0x7bc60509}},	//   hejt, _носі, nnas_, yuku
  { {0xcc8a0086,0x7ae70107,0xd407005e,0x69d501f1}},	//   ینده_, kejt, _уяви, htze
  { {0x0ea901c5,0xa6fb000a,0x60c9185b,0x7bc6503c}},	//   шкой_, רִ֗י, sgem, vuku
  { {0x7ae70089,0xbe650029,0x31950024,0xf1dd021e}},	//   dejt, تهدي, _bāze_, _महिन
  { {0x63a404f9,0x2ee5014c,0xcb09000a,0x7bc65655}},	//   ţine, self_, _בל_, tuku
  { {0xdbf4005d,0xc1780002,0x4adb000b,0xbcfb5656}},	//   इटेड_, _اصلا_, म्भव, mlél
  { {0xa3ab005d,0x41dd005d,0xf1dd005d,0x6d4d00e8}},	//   कीय_, _महास, _महान, _ejaa
  { {0xe93a0001,0x4229000a,0x7bc6040f,0x6aae0012}},	//   ачај_, בֵּ֣, suku, rabf
  { {0x799c0026,0x986a0015,0xbdf8002b,0x6aae0012}},	//   rprw, لحذف_, _درها_, sabf
  { {0xab5b00b8,0x69c70091,0xa3ab0065,0xb8650058}},	// [d840] urüc, auje, कीम_, كاكو
  { {0x2a6d0046,0xab5b0012,0x69c71e25,0x753b0045}},	//   řeba_, rrüc, buje, _amuz
  { {0x75220014,0x75d6002b,0xcf56000a,0xab5b0012}},	//   tkoz, تيضا, קבעת_, srüc
  { {0xd5760036,0xab5b00b8,0x6aaa000b,0x63640144}},	//   цузь, prüc, _क़ुर, mòni
  { {0x63640251,0xa29402e1,0x9e3c04b2,0x93930067}},	//   lòni, палі, laďt, وجوا
  { {0x96fa0010,0x752904ed,0xd36f0015,0x68f60091}},	//   _тэму_, _elez, نهن_, ldyd
  { {0x63640251,0xe6060015,0xcb13000a,0xc2070015}},	//   nòni, _بِأَ, ולג_, ققون_
  { {0x31570029,0x6736005c,0x68f62aad,0x859b000a}},	//   يجية_, żają, ndyd, _כשלו
  { {0x68f60026,0xd007009c,0x69c71e25,0x42d600e2}},	//   idyd, жење_, zuje, _міжу
  { {0xa3df005d,0xb7db00f3,0x91e61293,0xdb060400}},	//   _तहत_, סקיי, _мозе, nskä
  { {0x7ae75657,0xc693000a,0xde58005e,0xdb1d0030}},	//   vejt, ואת_, сані_, jusá
  { {0x40930086,0x55bb000a,0x69c75658,0x63640144}},	//   _قلمر, סמכו, vuje, dòni
  { {0x7ae70089,0xe571000a,0x8177000a,0xa1130015}},	//   tejt, גַם_, _וגאס_, _تونت
  { {0x4f570225,0x63640251,0xdd900015,0x69c70d7e}},	//   _وجود_, fòni, _كوت_, tuje
  { {0x3a250084,0x69d500b8,0x636d002d,0x7ae70f49}},	//   álp_, utze, núna, rejt
  { {0x91bb0008,0xdc2b0086,0x2d9e5659,0x41bb004c}},	//   ימלי, _نسخه_, mpte_, יצלע
  { {0xcd2b0086,0x4d740029,0x3949565a,0xab5b007c}},	// [d850] _مسکن_, _تطور, rnas_, nuük
  { {0x8f9b0008,0x0705005d,0x24670046,0xdb060123}},	//   יימי, राइव_, _jímž_, gskä
  { {0x394900c0,0xa2c4021e,0x75293f2a,0x95cb0a10}},	//   pnas_, _राज्, _plez, руза_
  { {0xe5700029,0x636d002d,0xd9190008,0x6b8d003f}},	//   نطن_, dúna, _הוֹל, _kuag
  { {0x53a50661,0x3cfc01ac,0xa849002b,0x2459004a}},	//   чалб, ילאנ, _طلسم_, щадь_
  { {0x6f18016f,0x51f50015,0x24670046,0x6d5d0710}},	//   _novc, كسبر, _nímž_, hosa
  { {0x2919000c,0xf6280036,0x7bda0045,0x636d0030}},	//   _kosa_, _діти_, ătui, gúna
  { {0x3cf5000b,0xf53f0123,0x27e201d7,0x6b8d565b}},	//   इयों_, _öå_, _ypkn_, _ouag
  { {0x42550086,0x6b8d0003,0x7e630123,0xc0c80054}},	//   _کنار, _nuag, _synp, цује_
  { {0x91f70029,0x51870010,0x636d002e,0xb4e6000b}},	//   _وأضا, _дуда, búna, बड़ी_
  { {0x3f990048,0xf8bf03af,0xfbc90008,0x68f60026}},	//   ūsu_, _além_, _תת_, ydyd
  { {0x63a90f4d,0xc616000a,0x6d5d565c,0xbcfb464f}},	//   _kwen, לחתי_, gosa, blém
  { {0xdb0600f2,0xd0040015,0x3940007c,0x60c61ad6}},	//   yskä, _يومً, viis_, ókme
  { {0x3b0a005f,0x63a9000c,0x69960036,0x207a0053}},	//   щего_, _mwen, зрах, _פאסא
  { {0x6d5d565d,0x7e9a000a,0x394050a1,0xdcfb0061}},	//   bosa, _פסקו, tiis_, astı
  { {0x636408e0,0xed570063,0x5fc2000b,0x9e3c00bf}},	//   ròni, _нощ_, _शिमल, raďt
  { {0x68f60176,0x8ca2005d,0xab5b0020,0x8c46000d}},	// [d860] rdyd, _क्यो, kuüh, _хепе
  { {0xcc570008,0xdb1d00dc,0x4bfb0053,0x3940007c}},	//   _מספק_, pusá, _פליס, siis_
  { {0xceb20008,0xc7a9000a,0xb5a5005e,0xa3c9000b}},	//   גיב_, רב_, дрій, लूस_
  { {0x6e3c016e,0x938a011c,0x69c10046,0xdb0602dc}},	//   úrbi, бска_, šlec, sskä
  { {0x07fa0015,0xe3b7008b,0xb97b000a,0xa3e60065}},	//   _ارجع_, зліч_, _לנטי, यौं_
  { {0xf1a6565e,0x2d9e565f,0xab5b0072,0x0000006a}},	//   прин, ypte_, guüh,
  { {0x64a6078f,0xa2cd005d,0x6d5d003f,0x63a95660}},	//   _нава, _सार्, yosa, _ewen
  { {0x55bb0008,0x2508002b,0x636d0b31,0xbcfb005a}},	//   _למלו, _برسی_, rúna, tlém
  { {0x63a90176,0x7986003f,0x636d002d,0x50b70015}},	//   _gwen, _mikw, súna, سديد_
  { {0xd138005c,0x539b000f,0xb4bc000b,0xf837000a}},	//   _stąd_, _לימו, _आयु_, פנית_
  { {0xd29b000a,0x6d5d4c41,0x425600c3,0xe37b000a}},	//   _השבט, tosa, _عنصر, _פרבר
  { {0xab5b00b8,0xbcfb01bb,0x6d5d0091,0x816900ce}},	//   grün, mlék, uosa, _дріб_
  { {0xbcfb00dc,0x8d86002b,0xa4b7000a,0xd109000b}},	//   llék, _کشتن, הלכה_, वारण_
  { {0x6d5d0209,0x8f540015,0xbd87002b,0x2d9e0dca}},	//   sosa, _تنتش, _کنين_, ppte_
  { {0x6edb013a,0xda78085d,0xfd390015,0x6d5d5661}},	//   _החופ, зят_, _وكتب_, posa
  { {0xd8770015,0x3eae02f7,0x319b004f,0x0000006a}},	//   كاذب, _heft_, מבלנ,
  { {0x79860409,0xcb690015,0x37090015,0xf6e7006b}},	// [d870] _dikw, _ومعه_, يْرُ_, зцен
  { {0x8f9b000a,0x6bd40015,0xdb1d001a,0x9f4d0061}},	//   ציבי, _أتير, orsí, rveç_
  { {0x25aa0026,0xcb12000a,0xbcfb0030,0x63a943b5}},	//   _cwbl_, _סלט_, jlék, _swen
  { {0x3eae003e,0xe8eb0086,0x27f200f2,0x38c9002b}},	//   _left_, _اردو_, ännä_, _بادی_
  { {0x78fa000a,0xdb060123,0xd7e4008b,0xc355006b}},	//   _ופרו, rrkö, _піро, мъкъ
  { {0xadec000b,0xc2c40015,0x1c2c000a,0x13e800ce}},	//   जबान_, فيهي, מֽוּ, ямій_
  { {0x25aa0026,0x29d75662,0x3abc000a,0xdce40085}},	//   _gwbl_, nça_, זמונ, _uhić
  { {0x212b005c,0x85050002,0x63a95663,0x3f76002a}},	//   óch_, _تورن, _twen, _słup_
  { {0x6009005e,0xdfce0015,0x60db5664,0xe8f2004f}},	//   іном_, ليي_, rfum, דֻת_
  { {0x29d70064,0xa294017f,0x23740015,0x6d4f039f}},	//   kça_, _зафі, _كالح, éban
  { {0xc332013a,0x0696000a,0xa3c9000b,0xab5b0012}},	//   _שוב_, ודתם_, लूर_, trün
  { {0x3f9f008c,0xe0d0002b,0x3eae0079,0x8d76009a}},	//   ppuu_, _مزه_, _eeft_, باخا
  { {0x9f4d00dd,0x6af60015,0xdb1d2fd0,0xdca30054}},	//   nweë_, وثآر, arsí, ђари
  { {0x257e0046,0x09e605a7,0xbcfb0046,0x0000006a}},	//   _vůli_, могн, hléh,
  { {0xfe9a000a,0xab5b0475,0xbcfb0046,0x9f4d005b}},	//   _ויצמ, ntüy, kléh, rveä_
  { {0xb4bc000b,0x48e312ae,0x3f87001a,0xab5b007c}},	//   _आये_, косв, _hinu_, brüo
  { {0x29d7001c,0xb07a0053,0x18672105,0x7986003f}},	// [d880] aça_, ַנעז, дати_, _vikw
  { {0x8c4300b8,0x670e000b,0x060a0015,0x2b58002b}},	//   ößer, साधक_, يْءٌ_, _ریزد_
  { {0x3f870005,0x3f8f0020,0xe6060015,0x917a0016}},	//   _minu_, _lugu_, بِاَ, _lấy_
  { {0xf8b2000b,0x9e48000a,0xf525008b,0xe5a318dc}},	//   _ज़िय, הֲנִ, нфін, тици
  { {0xf8b30008,0x394d05ca,0x8b65009a,0x0000006a}},	//   _בשר_, čest_, _زایم,
  { {0xc2c40015,0xae0d000b,0x3714000a,0x65c60238}},	//   ريعي, िमान_, _אַֽל_, _обга
  { {0x91e30001,0xf8b2000b,0x2019008c,0x2d590003}},	//   воје, _ज़ाय, äsin_, réez_
  { {0x66030134,0xab5b00dc,0xd259005e,0x2d8e5665}},	//   ænke, erül, чці_, _rufe_
  { {0xa0670054,0xc5150015,0xd48b004f,0x0000006a}},	//   маћа_, _ثبّت, _וָבֹ,
  { {0x8e1400d0,0x692c0061,0xdb1d025d,0x3f8f2acd}},	//   едоц, rşey, ltsö, _dugu_
  { {0x63a200dc,0x7bc00030,0x3f870022,0x6ecf000b}},	//   lpon, ámun, _dinu_, _दारु
  { {0xa00a003b,0x3f870084,0xc237000a,0xdb1d0123}},	//   _وقال_, _einu_, _קראו_, ntsö
  { {0x7b6705cb,0xfc640063,0x7af71d95,0x717b004f}},	//   дтве, върн, _paxt, _ונאס
  { {0xf047002b,0x78af287b,0x29d70061,0xbcfb0125}},	//   _تعمی, _secv, tça_, iléi
  { {0x1dc5000b,0x59f8006b,0xb345016e,0xdb1d016e}},	//   _वियत, меря_, liçã, ersã
  { {0xc1f70008,0xfc3f02c1,0x63761224,0xa3c9000b}},	//   ומלץ_, abía_, lând, लूँ_
  { {0xb8f7005d,0xb345001c,0x29d75666,0xc98404bb}},	// [d890] _सा_, niçã, sça_, тури
  { {0x63760045,0x29d70061,0xd6db0033,0xbcfb0125}},	//   nând, pça_, ўта_, dléi
  { {0xdb06006f,0x63a25667,0xd5bb04d5,0x07080058}},	//   yskú, epon, юса_, ظيمي_
  { {0xe8d5000a,0x0574012c,0x629a5668,0x78bd02de}},	//   _אוֹר_, ناند, _afto, _udsv
  { {0xdfc60029,0x1c0f005d,0x68ed001c,0x889a000a}},	//   _حي_, ामिल_, mead, _מברי
  { {0x68ed002f,0xb345001c,0xab5b0012,0x9f4d00aa}},	//   lead, diçã, krüm, rweë_
  { {0xe0d10029,0x9f59002d,0x44295669,0x3f8f2f1f}},	//   هزة_, ísí_, ša_, _sugu_
  { {0x3f87566a,0x68ed566b,0x636d0077,0xdb0f002a}},	//   _sinu_, nead, múnm, orcó
  { {0xbcfb002d,0x00e20033,0xff251293,0xe3d70015}},	//   cléi, ужын, емпо, _تتزع
  { {0x809f005d,0x27e400c0,0x24980089,0x891f004c}},	//   _ग्रे, _ämne_, čemž_, _אַן_
  { {0xc579000a,0x68ed00cb,0x25d5000a,0x8e7400e2}},	//   ּרָת, kead, עוֹן_, куюч
  { {0xb345001c,0x01fa000a,0x8d760015,0x2d650015}},	//   biçã, _מפעל, عادا, َطَّ
  { {0x69c104af,0x63760011,0xa1160031,0xd13e002a}},	//   álen, bând, _سقوط_, żąco_
  { {0xab2a0010,0x643a0053,0x6376566c,0x501a0008}},	//   чога_, לערנ, râng, _מונו
  { {0x63a20014,0x69c10089,0x68ed002d,0xade80015}},	//   zpon, šlen, fead, _يفهم_
  { {0xba170086,0x63760011,0x63bb02b9,0xdb1d0123}},	//   ريقا_, mâne, _ovun, xtsö
  { {0x27e60cfd,0x6d46566d,0x69c7566e,0x63a215c8}},	// [d8a0] ïon_, mika, arje, xpon
  { {0x6d46566f,0xe9da3142,0x39955670,0x248d059d}},	//   lika, _еко_, _fås_, _agem_
  { {0xfad700b2,0x2cfa000a,0x02c9000b,0x68ed0125}},	//   _אויך_, ּלְא, _राजभ, bead
  { {0x6135002e,0x63760011,0x809f000b,0xe71a002b}},	//   _hálf, zând, _ग्ले, _کيست_
  { {0xe2f80036,0x69ce002e,0x63a4003d,0x2c36000a}},	//   делі_, lube, ģino, עָ֣ם_
  { {0xdb1d0123,0x6d46471f,0x27f20034,0x6135001a}},	//   stsö, hika, mwyn_, _jálf
  { {0x6135002e,0x27f20335,0x3f994f57,0x63030015}},	//   _málf, lwyn_, ísun_, طويل
  { {0x31ba0024,0xb345001c,0x63a25671,0x6d460509}},	//   rīz_, tiçã, ppon, jika
  { {0x63760011,0x27f20026,0x2002002e,0x73c60067}},	//   tând, nwyn_, íki_, _سيام
  { {0xb34503af,0x083b0008,0x6d46322f,0x4d98005e}},	//   riçã, פעיל, eika, мкою_
  { {0xb34503af,0xa0a60549,0x2d4400dc,0x27f20026}},	//   siçã, _заед, rűen_, hwyn_
  { {0x63760045,0x80e50015,0x6d461403,0x69dc5672}},	//   sând, _لأهل, gika, dtre
  { {0x4426025c,0x48fb005d,0xd0070004,0x8fa35673}},	//   nyo_, _लोगो_, _пеце_, _баче
  { {0x27f20026,0x69c700bd,0x2ca40064,0x69dc0303}},	//   dwyn_, trje, ımda_, ftre
  { {0x99850089,0xdb0402c1,0xd90f0086,0x4efb000a}},	//   álů_, _avió, مید_, _מהגו
  { {0x7bda04f9,0x7c300030,0xa3c2000b,0x7d79002b}},	//   ătur, óiró, ्ढा_, _تمبر_
  { {0x28b2005d,0xa9540036,0xdb1d002d,0x68ed0541}},	// [d8b0] _ज़रि, укті, arsá, read
  { {0x68ed5674,0xbcfb00dc,0x4426191c,0x69c70085}},	//   sead, glév, dyo_, prje
  { {0xceb300b2,0x69dc1740,0xeb3c0053,0x7ae1007c}},	//   ריע_, ctre, _מעזש, õltu
  { {0xa5670086,0x7bdd0020,0x8883002b,0x5a16004f}},	//   ردان, otsu, _میزن, _סקרן_
  { {0x7bcf01e2,0x7bdd0020,0xe28e000d,0x3d19005d}},	//   nucu, ntsu, иа_, _बचने_
  { {0x02c2078f,0xeb98004c,0xdbcc001a,0xe3b0012c}},	//   айшо, עדור_, _móðg, صره_
  { {0x1a9c00b2,0x95c80001,0x7bdd0020,0x7c26005c}},	//   ליגע, _пута_, htsu, zykr
  { {0xa2cd000b,0xa1560054,0x25be001a,0xd24e0015}},	//   _साक्, кају_, _ætla_, تنى_
  { {0xb87b002f,0x43950063,0xe534004a,0x69ce0012}},	//   _mbío, _разс, _сеть, zube
  { {0x84640063,0xe4500015,0x6376016e,0x7d0d5675}},	//   _съсе, _اضف_, tâne, _anas
  { {0x6135002e,0xc692000a,0xf772000a,0xdca60988}},	//   _nálg, יאי_, שקי_, кани
  { {0xd24e0086,0x6376016e,0x02440015,0x6135001a}},	//   _بچه_, râne, _حَمَ, _sálf
  { {0x317f0064,0x7bcf0085,0x69c10046,0x6d465676}},	//   mmuz_, gucu, šlel, rika
  { {0x8ca2005d,0x316d2038,0x6d465677,0x69dc5678}},	//   _क्रो, llez_, sika, ttre
  { {0x69dc0152,0x21fc01cb,0x7bdd2c46,0xf2d20135}},	//   utre, máhá_, atsu, יעם_
  { {0xdb0f002d,0x5e56000a,0x69dc5679,0x9dd6000a}},	//   rscá, _ביצע_, rtre, _סופק_
  { {0x3ff900b2,0x2cee005d,0x69dc567a,0x7bcf01c2}},	// [d8c0] ופּע, ज़ील_, stre, cucu
  { {0x4426000c,0x9bb70008,0x3ce3005d,0x27f20026}},	//   vyo_, _שהיה_, ट्ठे_, rwyn_
  { {0x14c80086,0x44260026,0x160a0015,0xd48f153d}},	//   فهای_, wyo_, بياً_, ир_
  { {0xf4b40086,0xf503006b,0x2a57000a,0x44261d46}},	//   اشاگ, изхо, _יבין_, tyo_
  { {0x63f30029,0x07a6000d,0xd8430264,0x44260077}},	//   لأور, _јагн, ročí_, uyo_
  { {0x44263310,0x1837000a,0xcc3b004c,0xe1d80033}},	//   ryo_, _יאכל_, וענט, едкі_
  { {0x442600b6,0xf743030e,0x27240030,0xd1b70058}},	//   syo_, _теро, _dönt_, نايا_
  { {0x50f4005f,0x69a7005d,0xbcfb00dc,0x8ca2000b}},	//   узит, टीटी, nlét, _क्लो
  { {0xe805014e,0x60f70010,0xb805000b,0x3013006b}},	//   रिया_, тныя_, रियम_, идър
  { {0xaf060a61,0xbcfb0003,0x1f140033,0x6d44248e}},	//   тчик, hlét, умоў, _amia
  { {0x316d0003,0x39520091,0x2d830046,0xdb1d0030}},	//   blez_, knys_, ňkem_, pusú
  { {0x69c10030,0x7bcf0061,0xc19b000a,0x55bb000a}},	//   álem, tucu, _חשאי, ומטו
  { {0x10130086,0x6f0d0089,0x7bdd0601,0x60c2567b}},	//   _نبود, áncí, utsu, _idom
  { {0x6d4400dc,0x7bcf1e8c,0x69c10227,0xcfb7000a}},	//   _emia, rucu, šlem, _ילדי_
  { {0xa923002c,0x27360134,0x7bdd567c,0xbcfb0003}},	//   áľov, _mænd_, stsu, flét
  { {0x7d0d06e8,0xdb060107,0xd9100015,0x7bcf3c56}},	//   _unas, mský, يٌّ_, pucu
  { {0xdb0601b2,0x60c2003f,0xed58000a,0x6aa20045}},	// [d8d0] lský, _mdom, _שבחר_, _şofe
  { {0x6d440050,0x4734066a,0x0000006a,0x0000006a}},	//   _zmia, анус,   ,
  { {0xdb060057,0xde78000a,0x65940015,0x7547002b}},	//   nský, תְּך, لجنر, نیسف_
  { {0xe795009a,0x26ce03a0,0x0000006a,0x0000006a}},	//   _ماسک, òfor_,   ,
  { {0xd103000b,0xceb80091,0xfbdf016e,0xdb04001a}},	//   _शोषण_, nkęs_, ntê_, _kvið
  { {0xf9900086,0x6376001c,0x61354f57,0x3949567d}},	//   _دبی_, vânc, _mále, lias_
  { {0xbbe0005d,0x2169087a,0x68fd0007,0x16350010}},	//   _पङ्क, ники_, _kasd, _севя
  { {0x6376001c,0xdb060107,0xe0d90238,0xab5b007c}},	//   tânc, dský, хви_, srüh
  { {0x61350057,0xe425002b,0x54550a0b,0x316d0003}},	//   _nále, _حکاي, _сват, rlez_
  { {0x20060026,0xdb06001a,0x6376255e,0xa858000a}},	//   _droi_, fský, rânc, כיחה_
  { {0x39490007,0xd12e002b,0x98c3000b,0xf1c90015}},	//   kias_, زمی_, षणाए, _أوصى_
  { {0xc19a0053,0x3cee000b,0x02df000b,0x63761358}},	//   _טשעי, ज़ें_, प्रभ, mâna
  { {0xeb97250c,0x4bd60033,0x3949567e,0xd087004a}},	//   лия_, ыўну, dias_, _рыжи
  { {0x99f6005e,0x30780015,0xab770015,0x2d91016e}},	//   лябі, _شحنة_, ُمَا_, ízes_
  { {0xbcfb22fd,0xc3480092,0x39493a96,0xceb2000a}},	//   glés, uổi_, fias_, _פיה_
  { {0x6d44002a,0x3949567f,0xf93500ce,0xe8f70766}},	//   _umia, gias_, ахую, ллс_
  { {0xd70a0010,0x7d7b0135,0xc8b5004a,0x480601b0}},	// [d8e0] ннае_, _אנקו, рссы, ыпав
  { {0x66760086,0xbcfb00dc,0x4c3b000a,0x3949007c}},	//   هدار, slét, _נתיב, aias_
  { {0xf8bf038d,0x7c650086,0x61350057,0xbcfb5680}},	//   _clés_, _مایل, _zále, clés
  { {0x394906d4,0x27e65681,0xbcfb01ce,0x09f7000a}},	//   cias_, çons_, llér, _עמכם_
  { {0x9cd70008,0x7afe0832,0xe4e5005e,0x9816002b}},	//   רונה_, _kapt, рієн, _صبحا
  { {0xf7460146,0x6ed8000b,0x2d980d46,0x68e45682}},	//   _сего, _माधु, írek_, lfid
  { {0x41e600e6,0x15f8000a,0x27e05683,0xf1a30033}},	//   استف, _בִּמ, ltin_, брын
  { {0x3cee005d,0x21670001,0xd01000e6,0x3ff40015}},	//   ज़ों_, лији_, قلب_, لكبر
  { {0xb4c2000b,0x273602de,0x2ef42a55,0x62870030}},	//   ूली_, _tænd_, азпр, _újon
  { {0x138a003b,0x24740092,0x7afe00dc,0x68e4002d}},	//   _أخرى_, _ìm_, _napt, hfid
  { {0x2293040b,0x32930029,0xde580036,0x2cb900dc}},	//   _المس, _المأ, тані_, tasd_
  { {0x40a80074,0x0e330036,0x20060026,0x8c190015}},	//   _شخصی_, снюю, _troi_, نيجر_
  { {0x5577004c,0xdb06001a,0xd012002b,0x6e3a0030}},	//   טעטן_, sský, _دلش_, sztb
  { {0x61350089,0xdb060089,0x6b960064,0xab5b0061}},	//   _vále, pský, _duyg, ksüe
  { {0x13d1014e,0xbd6b0063,0x27e0056c,0xfe9b000a}},	//   _सम्भ, _прие_, etin_, _איומ
  { {0xbcfb0014,0x68e40125,0x28f801f3,0x29000144}},	//   rlés, gfid, лесь_, gdia_
  { {0x7afe04f9,0x67d509a7,0xeb34002b,0x39495684}},	// [d8f0] _fapt, розу, _گريخ, rias_
  { {0x39495685,0xd7c80015,0x27ff0091,0x7afe0034}},	//   sias_, اوله_, _šuns_, _gapt
  { {0x24740092,0x39490656,0x5eeb000a,0xcb12000a}},	//   _àm_, pias_, עַמְ, _ולי_
  { {0x68e4002d,0x23b50015,0xc56b006e,0x67d509a8}},	//   cfid, لمؤس, رحال_, _кому
  { {0x7afe01e2,0x84470015,0x88ba000a,0x0ed4000b}},	//   _yapt, دخال, _בזרי, _दांड
  { {0x569402bb,0xab5b0012,0x59ac000b,0x2d440030}},	//   _гарт, lsüb, टीकर, tűek_
  { {0x3ce90089,0x4ad3000b,0x81f60021,0xe4a702d9}},	//   _obav_, _ताईव, لفور_, _брзо
  { {0xe53401f3,0x2d440030,0xab5b0012,0xf0a6009b}},	//   _лесь, rűek_, nsüb, акъл_
  { {0xa1560054,0x61fa5686,0xe3b3002b,0x2ca05687}},	//   јању_, _estl, _درز_, _rfid_
  { {0x7fe800c3,0x2fd6002b,0x2900006f,0x2fdf01de}},	//   اريف_, گوید_, zdia_, rtug_
  { {0xd2510196,0x50f50063,0x43840029,0x98a9005c}},	//   _بنا_, _взет, _اللق, chać_
  { {0xd011003b,0x6ff50029,0x7afe5688,0xeb9a5689}},	//   _ولا_, _نستط, _sapt, ким_
  { {0x2d8200aa,0xd48f005e,0x9971002a,0x80270021}},	//   rmke_, орi_, _wąś_, _حرام
  { {0xa3e8005d,0x2fcd00aa,0x61fa0034,0x20d5000b}},	//   _बहस_, mreg_, _ystl, _धाँध
  { {0xc332013a,0x63a40048,0x31950024,0xc9860015}},	//   חום_, ģini, _bāzi_, لشري
  { {0xdb06001a,0xab5b0012,0x27e0568a,0x2900568b}},	//   tskó, gsüb, ttin_, udia_
  { {0x7afe568c,0x68e40110,0x2fcd00aa,0xdb080030}},	// [d900] _tapt, rfid, nreg_, álói
  { {0x4a460080,0xbcfb00dc,0x3bbb0008,0x27e0568d}},	//   _внов, llép, _שמיד, rtin_
  { {0xdb06002e,0xc5d60036,0x75d60029,0x27e0568e}},	//   sskó, різь, شيشا, stin_
  { {0x84e6017f,0x19bb000a,0xa507006b,0xda5b000a}},	//   родж, _במטב, иеха_, _יכיל
  { {0x2d52016f,0x4394004a,0xa8030033,0xbcfb0030}},	//   ašeg_, щалс, _дзял, ilép
  { {0x6abc568f,0x69ce5690,0xfbd3000a,0xeb93000a}},	//   narf, orbe, קתו_, חָק_
  { {0xd24f03c4,0xe2970001,0x443d002a,0x23270054}},	//   ونه_, шај_, azw_, роји_
  { {0xbcfb0089,0x92650015,0x2fcd00aa,0xc5fb000a}},	//   jlép, حدهم, freg_, _בפלט
  { {0xd0e2005d,0x8937004c,0x2bdb000b,0x69ce0012}},	//   क्षण_, ירקע_, _बमधा, hrbe
  { {0x257501d1,0x80a6005d,0xbcfb00dc,0x69c10091}},	//   håll_, _ट्रे, elép, šlei
  { {0x06970b7b,0xa0c6002b,0x6abc0dca,0x78ad0069}},	//   ידים_, _نياو, darf, ybav
  { {0x6a8000dc,0x61350089,0x6abc01b3,0xd24f0369}},	//   záfé, _válc, earf, _تنم_
  { {0x6abc0176,0x4f9609c3,0x69ce5691,0x69c81730}},	//   farf, _треу, erbe, áden
  { {0xe2a30092,0x7b6700d0,0x70530015,0x6d5d0003}},	//   _ngữ_, ртме, _بنها, érab
  { {0xff7b0053,0xc1780091,0xbcfb0030,0x61350030}},	//   _שטומ, _upės_, blép, _hála
  { {0xe8940a61,0x2d520085,0x7c67002b,0xce37000a}},	//   жать, všeg_, _پابل, _כאות_
  { {0x286b0001,0xdb04001c,0x58870139,0x8c440045}},	// [d910] трво_, _aviõ, рыва, âşti
  { {0x2607004a,0x9b440015,0x46a70033,0xab5b0012}},	//   ичег, _ونيو, ршаб, ssüb
  { {0x04950029,0xd0060086,0x7af50030,0xdb1d007c}},	//   ملاح, _کل_, mezt, iusü
  { {0x95090015,0x7af50030,0x84c80015,0x69d5005a}},	//   طقتك_, lezt, لِمك_, muze
  { {0x93e90015,0xfc3f0046,0xe4500015,0xab5b0012}},	//   افتك_, nzí_, وضه_, brüt
  { {0xebf80008,0xf36700d7,0x257c0247,0x7af50030}},	//   שֶׁת_, штен, víle_, nezt
  { {0x27f50061,0xdb1d007c,0x0000006a,0x0000006a}},	//   şanı_, dusü,   ,
  { {0x2fcd3e9e,0x4a58000a,0x2a58000a,0xf8b90065}},	//   treg_, ישול_, יבון_, ेणिय
  { {0xc4d20008,0x7af500dc,0xdee50661,0xc2eb0015}},	//   _מגן_, kezt, бопи, _لعام_
  { {0x7af500dc,0xfc3f002c,0x41e702e1,0x2fcd0d4f}},	//   jezt, dzí_, _віда, rreg_
  { {0x7af500dc,0xae58005e,0x6ed8000b,0x2fcd00aa}},	//   dezt, ирює_, _मारु, sreg_
  { {0x4095003b,0x69d55692,0xee3613d6,0x3519004f}},	//   _الإر, duze, сню_, אוֹנ
  { {0x6abc0084,0x30850029,0xdbf4000b,0x20850015}},	//   tarf, _الشف, ेटेड_, _الشّ
  { {0x7af500dc,0xfaa30c5b,0xab5b0012,0x69d50045}},	//   gezt, заро, drüs, fuze
  { {0x49990036,0x23d1000b,0xfe710015,0xbb431111}},	//   иття_, _समझद, _عدت_, черк
  { {0x3a2500c0,0x399c0144,0xab5b0012,0xd94301ca}},	//   älpa_, _vís_, früs, песи
  { {0xc6960015,0x79840034,0x06ea067a,0x36c6008b}},	// [d920] مشاع, rmiw, лмак_, йбаг
  { {0xf7720029,0x9b030033,0xc7460015,0xab5b0012}},	//   ساء_, _езьд, حضري, rsüc
  { {0x23480086,0xd0f9000b,0x5afb000a,0x064a0015}},	//   یستی_, ्याण_, _גליצ, دلاً_
  { {0x93aa003b,0xd9100086,0x5a170008,0xdb1d002a}},	//   هاتف_, _تیر_, _הקטן_, busó
  { {0x44320092,0xa294005e,0xe50500c3,0x232a1c3f}},	//   áy_, оалі, تبلي, лоди_
  { {0xf6d50191,0x29020e03,0x68f6007f,0x0000006a}},	//   _міся, _haka_, leyd,
  { {0xf1a30010,0x1a9b0053,0xb0dc000b,0xdb1d0003}},	//   прын, ניקע, _यादग, ussé
  { {0xf993013a,0xc4c50029,0x68f60061,0xc03403ae}},	//   הרה_, _وتقو, neyd, жниј
  { {0xaed4000d,0x69d55693,0x2902015a,0xdb1d007c}},	//   оопш, zuze, _maka_, tusü
  { {0x613503c0,0x11d6078f,0x539b00f3,0x57fb000a}},	//   _vála, _гідр, _עיבו, נליו
  { {0x2d9800dd,0x7af50f49,0x7de30033,0x9cf5008b}},	//   êre_, vezt, піяд, озні
  { {0xd7fe00a7,0x290200b6,0x63a40011,0x636d0125}},	//   _đăng_, _naka_, ţinu, súnt
  { {0xbc4b0124,0x71650029,0x2d920064,0xd12f0015}},	//   учне_, _بالك, _diye_, _ثمن_
  { {0xfc3f02d5,0xf9930029,0xdce90064,0xfaa90015}},	//   rzí_, كبر_, ılıy, شهري_
  { {0x68f60026,0xda340010,0x7af55694,0x29025695}},	//   feyd, перы, rezt, _baka_
  { {0x49750010,0x09750036,0x57b505b3,0xfd130015}},	//   ілас, ігаю, жбат, _رجع_
  { {0x29070089,0x8c440001,0x6d4f03b8,0x7af50030}},	// [d930] ěna_, _неће, mica, pezt
  { {0xec38013a,0x8f9b0008,0x0c740029,0xcf93004c}},	//   _לאחר_, טימי, _عديد, פטע_
  { {0x3ebe00dc,0xab5b0012,0x95c40015,0x889501ca}},	//   iatt_, srüs, كيله, _минх
  { {0x85c80029,0x68f65696,0xab5b06d1,0x272f0061}},	//   إِنْ_, ceyd, prüs, _sını_
  { {0x83c4005e,0x2459004a,0x24580033,0xd4690054}},	//   збіж, шадь_, баць_, јиле_
  { {0x55bb0074,0xdcb6005d,0x85bb04c9,0x8bbc0053}},	//   _مطرح_, _अज्ञ, _مارس_, נצוה
  { {0x91d50010,0x32160015,0xaadc000a,0x61350046}},	//   іцкі, قيود_, אחור, _dáln
  { {0x6d4f2fdc,0xa99c000a,0xefc9008a,0x0000006a}},	//   jica, נבחר, алил_,
  { {0x3cef005d,0x7f190010,0x200b0057,0x6d4f3d41}},	//   ेजने_, аіну_, íci_, dica
  { {0x9f850010,0x68f60064,0x63a95697,0x671c000b}},	//   ўгод, zeyd, _iten, नायक_
  { {0x52550015,0x637f016e,0x442f5698,0x42550067}},	//   _بناء, gêne, lyg_, _بنار
  { {0x6d4f03b8,0xdb060400,0xed5700e2,0x91f70065}},	//   gica, nskö, жою_, ूटीओ_
  { {0xae170074,0xde550024,0x69c513e1,0x1c430033}},	//   _گذشت, _šādā_, _avhe, дням
  { {0x3b0a005f,0x539a0008,0x3ea10020,0x63a9003f}},	//   шего_, יישו, _üht_, _mten
  { {0x68f6022d,0xbd460015,0x60db007c,0x6f030045}},	//   teyd, _ونتي, ogum, _ianc
  { {0xe8fa07c1,0x63a913e5,0xed57006b,0x24920091}},	//   јла_, _oten, _мощ_, žymi_
  { {0xdc9b00a3,0x574a2b9d,0x2d8b0046,0x98360033}},	// [d940] _דיפל, азам_, ůbec_, цэві
  { {0x7d045699,0x0a5a0015,0xb6360040,0x68f60727}},	//   _hais, _نشجع_, يعات, seyd
  { {0x2902569a,0x7d04569b,0xa2af000b,0x6135013f}},	//   _taka_, _kais, ुरन्, _nálo
  { {0x7a7b0008,0x186a007a,0x442f0034,0x6f03569c}},	//   _כריס, _вами_, fyg_, _lanc
  { {0x69c10057,0x05770015,0x25ad0107,0xd38a0a1f}},	//   šlet, آمنة_, _čele_, айде_
  { {0x60db0024,0xe73a0146,0x6d4f3b6d,0x6f031915}},	//   egum, _тег_, zica, _nanc
  { {0xf1f70086,0x613500dc,0xa2db000b,0x7b0f004c}},	//   قعيت_, _váln, _नार्, פֿרעג
  { {0x442f0176,0x26c7002c,0x7d04569d,0x8cd6000b}},	//   byg_, ónov_, _nais, _भागो
  { {0x3ebe0f3e,0x6d4f569e,0x6f03569f,0x69c8013f}},	//   tatt_, vica, _banc, ádej
  { {0x6f03052a,0x6d4f005c,0x7f830015,0x3817000a}},	//   _canc, wica, ولين, קקים_
  { {0x613c0014,0x1df80080,0x577b0053,0x6f031350}},	//   _péld, щены_, שטיצ, _danc
  { {0x3ebe02d2,0x7d0452d1,0x613c56a0,0x0000006a}},	//   satt_, _cais, _béle,
  { {0xe133008f,0x613556a1,0x60c000f2,0x6d4f0d2d}},	//   _іншы, _zálo, mamm, rica
  { {0x637f016e,0x9e65002b,0x656b0030,0x2d980030}},	//   mênc, _کاهن, zogh, íres_
  { {0xd90f0074,0x9e660074,0x637f001c,0xb9e40036}},	//   نید_, _باشن, lênc, міти
  { {0x29c50048,0x613c0030,0xdd910015,0x60c01f26}},	//   rķa_, _féle, _ثوب_, namm
  { {0x8bb70029,0x2d9c0020,0x7bb70015,0x637f016e}},	// [d950] _بإعا, _huve_, _بإعط, nênc
  { {0x1bf40010,0x637f016e,0x257c001a,0x60c0234d}},	//   _ўпэў, iênc, víla_, hamm
  { {0x7d160026,0x8afa000a,0x7afa007c,0xbafa000a}},	//   _ynys, _ההתי, õtte, _ההתש
  { {0x442f01d1,0x2fc6010b,0x60c056a2,0x64c50015}},	//   tyg_, _ovog_, jamm, سيتل
  { {0x18350053,0xc6d70029,0x9475002b,0xdb060123}},	//   _זאָל_, _وتست, سگرا, rskö
  { {0x637f001c,0x442f0026,0xd6d802e1,0xf1c90015}},	//   dênc, ryg_, _мтс_, موتى_
  { {0x6d4d0201,0x6f0356a3,0x63a9002a,0xe5c404b4}},	//   _omaa, _ranc, _wten, _осто
  { {0xda5c0008,0x613500dc,0x6f03164a,0x26c102f2}},	//   יכול, _válo, _sanc, laho_
  { {0xe4490029,0x637f001c,0x92a70001,0x7d040493}},	//   _الذى_, gênc, _дјел, _rais
  { {0x6d5d0152,0xdb1d002e,0x7d0456a4,0xfe4503ad}},	//   éran, fssí, _sais, зноо
  { {0x613c56a5,0xc3320b7b,0xe802000b,0x671c000b}},	//   _séle, _רוב_, _रैना_, नातक_
  { {0xc1040029,0xc27a0008,0x8288000a,0xa3df000b}},	//   _يولي, _הרעי, _וְנֶ, _थमा_
  { {0xa09a0053,0xab5b03ba,0x6f0356a6,0x637f016e}},	//   _הינט, rsün, _tanc, cênc
  { {0xade90074,0xdb06002c,0x7d040705,0xff530015}},	//   _هفتم_, jskô, _wais, _تخص_
  { {0xd3560008,0x7d0456a7,0xdeba000a,0xba1a0015}},	//   לישי_, _tais, _המצל, حيزا_
  { {0xdb06006f,0x7d040125,0x613c56a8,0xc7b20058}},	//   eskô, _uais, _téle, فّر_
  { {0xd7f90036,0xed570008,0xaa8a0086,0x6d3b000a}},	// [d960] жує_, _מבקר_, _گندم_, _לתקנ
  { {0x2b1d014e,0x869a0ea6,0x78a456a9,0xac76002b}},	//   माणु_, стат_, sciv, _واکش
  { {0xba9b0008,0x6a9b0008,0x4a9b0053,0x3a060086}},	//   _לסיי, _לשינ, _לייג, _عکسی_
  { {0x637604f9,0xdb0d0084,0x2bd3000b,0x6995006b}},	//   mâni, _hvað, _तिमा, _орях
  { {0x61350014,0x26c10035,0x60c000f2,0xdb0d001a}},	//   _váll, baho_, vamm, _kvað
  { {0xf487002b,0x637f016e,0x273f0045,0x599a000a}},	//   سانی, vênc, _cînd_, ֖שֶׁ
  { {0x2fc6016f,0xa50a0e44,0x60c056aa,0xdbf20046}},	//   _svog_, _лева_, tamm, dřív
  { {0xd130003b,0x637f001c,0xf55a0029,0x865b000a}},	//   ئمة_, tênc, _الرب_, _הדלי
  { {0x7bc612ef,0xd0070004,0x65630030,0x2d9c01bc}},	//   jsku, зење_, énhe, _suve_
  { {0x637f03af,0xc43b0008,0xdb1d494a,0x60c056ab}},	//   rênc, _התמי, tssí, samm
  { {0xbfa50023,0x6e940029,0xacf90036,0x637f001c}},	//   _hiệ, بلدا, онну_, sênc
  { {0xbfa50023,0x667b0008,0xc19b0008,0x06570053}},	//   _kiệ, מטיק, _השאי, לייך_
  { {0xdfcf006e,0x7c8416db,0x6abe0012,0x7bc609c0}},	//   _مين_, еуре, _bepf, gsku
  { {0x6ffb0008,0xab5b00dc,0xa4f10061,0x2d9c56ac}},	//   _להדפ, csül, kışı_, _tuve_
  { {0xbfa50023,0xde570036,0xbe970029,0x0f7b000a}},	//   _liệ, _наші_, _عضوا_, _הרגל
  { {0x6d4d0035,0xdff3005d,0xa4f10064,0x286b00d0}},	//   _umaa, _अहमद_, dışı_, брзо_
  { {0xb905005d,0xbfa50016,0x2ca9050b,0x98750c96}},	// [d970] _ना_, _niệ, _ifad_, флац
  { {0x6abe0012,0xfb85002b,0x6376016e,0xcc58000a}},	//   _gepf, _تدبی, bâni, _מבחי_
  { {0x6376016e,0x75294262,0x6d5d56ad,0xdbd7008c}},	//   câni, _poez, onsa, sääj
  { {0xbfa50092,0x7455002b,0x394044e4,0xdbd7008c}},	//   _biệ, وپائ, chis_, pääj
  { {0x2d5200bd,0xdce60024,0x6d5d56ae,0x24580033}},	//   kšen_, nokā, insa, паць_
  { {0xbfa50023,0x78a2002c,0x69c7016f,0x7bdc0008}},	//   _diệ, ľove, osje, מקדו
  { {0xd015005d,0xa1890036,0xe805000b,0x69c756af}},	//   तम्भ_, обка_, रिका_, nsje
  { {0x6d5d0152,0x3d07005d,0x68ed0ac5,0x7bc656b0}},	//   éral, षयों_, nfad, ysku
  { {0xc0c80001,0x69d50c1f,0x68ed003f,0x600604ab}},	//   чује_, hrze, ifad, дным_
  { {0x33390074,0x27e90375,0xff25005e,0x69d5002a}},	//   _بزرگ_, itan_, ємно, krze
  { {0x69d5005c,0x225900e6,0xc2c4006e,0x02350058}},	//   jrze, _بلاد_, _سيني, _تفاح
  { {0x27e901e2,0x69d5005c,0x69c756b1,0x7db40033}},	//   ktan_, drze, dsje, эсьц
  { {0x68ed002d,0x9045002b,0x2003003d,0x7bc60d4a}},	//   dfad, _تنشه, ājis_, usku
  { {0x9f840191,0x6376001c,0x7bc656b2,0xa4f10061}},	//   _згід, tâni, rsku, yışı_
  { {0xcf240086,0x69960036,0x69d5005c,0xdb1d002e}},	//   _سروي, драх, grze, ersó
  { {0xdb1d0020,0x6376016e,0x27e91cef,0x2611000b}},	//   dusõ, râni, ftan_, णिनी_
  { {0xb87b0089,0x48e30063,0x25ad1ffb,0x07a60e41}},	// [d980] _sbír, ъотв, _čela_, фазн
  { {0x69d5005c,0x613c0152,0x68ed003f,0x9b46002b}},	//   brze, _méla, afad, _آندو
  { {0x27e9064e,0x7afc56b3,0xb5a90015,0x6a870003}},	//   atan_, mert, كانك_, réfé
  { {0x61354f57,0xa4f10061,0xf65501f3,0x151a0015}},	//   _dálk, rışı_, хтую, غزاة_
  { {0x53fa0029,0x8cb1000b,0x27e90077,0x03a30248}},	//   تراح_, ूरतो, ctan_, вичо
  { {0xbfa50023,0xe71a0086,0x63bb002a,0x7afc56b4}},	//   _việ, _بيست_, _dwun, nert
  { {0x6d5d001a,0xb87b0046,0x41e601c6,0x7afc56b5}},	//   ynsa, _ubír, філа, iert
  { {0xbfa50092,0x2348002b,0xbcfb0046,0xdfd00021}},	//   _tiệ, _کسری_, sléz, هيب_
  { {0xbcfb038d,0xa9280046,0x7afc56b6,0xe2ca0a0b}},	//   nnée, _zažá, kert, _млад_
  { {0x613c0152,0x51f60015,0xdce6003d,0x7afc56b7}},	//   _déla, _يسار, vokā, jert
  { {0x68ed29d6,0x2ca900b8,0xaf030033,0x69dc4c77}},	//   yfad, _pfad_, тчык, jure
  { {0x2002002e,0x613c002e,0x69d50089,0xb5820033}},	//   ækis_, _féla, vrze, ннiк
  { {0x61ea018b,0x69dc0999,0x7afc56b8,0x69d5002a}},	//   ltfl, eure, fert, wrze
  { {0x69d50050,0xe4510008,0x7afc17a7,0x69c74fe9}},	//   trze, אֶל_, gert, tsje
  { {0xda7803ad,0xeef7000a,0xe919005e,0xab94005e}},	//   дят_, _חמור_, пові_, тирі
  { {0x2d520085,0x69c73b5d,0x63760045,0x27e956b9}},	//   nšel_, rsje, mânu, ttan_
  { {0xbcfb0003,0x8d74002b,0x7afc05b2,0x69c700cb}},	// [d990] gnée, _جاوا, bert, ssje
  { {0x69d50050,0x7bdd00b6,0x9f9a022d,0xdb1d0020}},	//   prze, musu, mään_, tusõ
  { {0xa2af000b,0x63bb00da,0x95c8005e,0x9f9a008c}},	//   ुरस्, _swun, дуча_, lään_
  { {0x61350089,0xe3b100e6,0x27e956ba,0x7bdd005b}},	//   _válk, هرت_, ptan_, ousu
  { {0x9f9a00f2,0x628106e7,0x97c70015,0x7bdd56bb}},	//   nään_, _szlo, _تتجم, nusu
  { {0x63a00440,0xc2c50029,0xec380053,0x77ba000a}},	//   _dumn, ريبي, ונדז_, _ממשח
  { {0xa4d50191,0xe1f100b0,0xe296000d,0xa0a500fd}},	//   _пові, است_, наш_, найд
  { {0x9f9a00f2,0x645a1a4b,0x3d1e000b,0x7afc376f}},	//   kään_, áciá, _बचें_, zert
  { {0x9f9a00f2,0xa8a8000a,0x63c10046,0x7ae556bc}},	//   jään_, וֹתִ, ávně, _ocht
  { {0x6135002e,0x200d30ac,0xf484006b,0x02450015}},	//   _máli, rvei_, _русн, _كَذَ
  { {0xe29a0053,0x2002002e,0x7afc0106,0xf772000a}},	//   _זשער, ækir_, vert, רקי_
  { {0xc0e90086,0x7ae50aad,0x463a0053,0x7bdd0064}},	//   _رفتن_, _acht, פערע, fusu
  { {0x7afc31a6,0x3af60342,0x9f35008b,0x7bdd56bd}},	//   tert, нявс, _педі, gusu
  { {0x69dc0f43,0x7afc3642,0xdbd2007c,0xafe2004a}},	//   ture, uert, müüj, _сошл
  { {0x2cab002d,0xf2d200a3,0x6376098d,0x69dc0209}},	//   éidí_, טעם_, mânt, uure
  { {0x7ae53074,0x6376001c,0xe7aa4198,0x7afc56be}},	//   _echt, lânt, звал_, sert
  { {0x77860001,0xe73a000d,0x7b960036,0x7bdd0064}},	// [d9a0] елаз, пеа_, _прої, cusu
  { {0x8f9a013a,0xe2050023,0x98c50024,0xbcfb56bf}},	//   פיעי, _đóng_, ētās_, rnée
  { {0x1f3600b2,0x63a046e9,0x2d520046,0x3abb000a}},	//   ערער_, _sumn, yšel_, _ממינ
  { {0x80be005d,0x89360029,0x9b460086,0x53e604f7}},	//   _एजें, _أعدا, _آنگو, ецка
  { {0x289b0008,0x2d5200bc,0x3f8c001a,0x3ce1000b}},	//   _מיכא, jšem_, ymdu_, कलते_
  { {0xae1f000b,0x98a9002a,0xb4650015,0xdb1d0030}},	//   यमान_, tkać_, خدمه, űzöt
  { {0xf7770008,0x3ce1000b,0x61350107,0x271b004c}},	//   _נעלי_, _काले_, _záli, _צולײ
  { {0x9f9a00f2,0xab5b007c,0x7bdd089c,0x2d520046}},	//   yään_, tsük, yusu, ušel_
  { {0x04570029,0x98a9005c,0x613c0030,0x63760045}},	//   _كلفة_, skać_, _féln, fânt
  { {0x9f9a00f2,0x7ff30029,0x798d005c,0x7e460e3f}},	//   vään_, اسيا, zmaw, ехме
  { {0xb1e50029,0x35d8005d,0x2bd3000b,0x432b000a}},	//   _لأنه, _डिफ़, _तिहा, _מֵאֲ
  { {0x9f9a022d,0x7bdd01e2,0xc5f30008,0xd23b0008}},	//   tään_, tusu, נדר_, _מגבל
  { {0xf537000a,0x3157000a,0x3c460003,0x7b672de5}},	//   תרכז_, _איאן_, _rêvé_, етве
  { {0xf8b80092,0xa0070029,0x501b0008,0xdc340015}},	//   _đĩa_, _أقول_, _מודו, ارَة
  { {0x9f9a00f2,0x2bd3000b,0xdb500015,0xe9870054}},	//   rään_, _तिवा, حَّ_, ећан
  { {0x9f9a022d,0x798d0035,0x8e7b000a,0x7e7b000a}},	//   sään_, umaw, _מנוה, _מאוז
  { {0xa7750001,0x671c005d,0x798d56c0,0x9f9a008c}},	// [d9b0] влач, नांक_, rmaw, pään_
  { {0x368b000d,0x78a2002c,0x2d52002c,0x4de4005d}},	//   псен_, ľova, jšej_, _कमाई_
  { {0x2d52002c,0xb6060024,0x2d9b0030,0x659500fd}},	//   dšej_, jušā, _épes_, важу
  { {0xa4d50036,0xb6060024,0xc5390033,0x04590015}},	//   тоді, dušā, ьпех_, ولاة_
  { {0x0d16004c,0x39140033,0x61350030,0x290b0045}},	//   כקײט_, _смяр, _kálv, _iaca_
  { {0x3394004a,0x2d5212c4,0x2bd90065,0x98140058}},	//   гачё, všem_, _भटना, _إبَا
  { {0x637604f9,0x613c00dc,0x7a3c00f2,0x290b0509}},	//   vânt, _célo, mätö, _kaca_
  { {0x2d52002c,0xd24e0015,0x85050021,0x613c56c1}},	//   ašej_, غني_, _جورن, _délo
  { {0xd12e0029,0x95640063,0xd56407c1,0x33f400e6}},	//   تمي_, _сърд, _стрп, _مسلس
  { {0xddd80007,0x93970015,0x21cc0046,0x2a6d0046}},	//   _gyvū, _أجرا, běh_, řeby_
  { {0x7bcd00f2,0x26c300bd,0xf2e6002b,0x1e82004a}},	//   _avau, _mejo_, _شکوه_, ильм
  { {0x70520086,0xc0cb004a,0xee3601fe,0xc10400c3}},	//   انیا, _хуже_, тню_, _مومي
  { {0xd0090969,0xafe500f4,0x600a0030,0x9f05009a}},	//   _целе_, _ролл, römá, _لوشو
  { {0xeb97010f,0xdde9002b,0xfc0301ca,0xbea22b43}},	//   кия_, _قرعه_, јпро, _кашк
  { {0x44200023,0xdcfb0064,0xceb2000a,0xdb1d0123}},	//   ̣i_, aptı, _דיו_, dssä
  { {0xdb1d008c,0xa3d2000b,0x290b4b24,0x0000006a}},	//   essä, _विल_, _caca_,
  { {0x290b0011,0x672e016f,0x9a9e00fd,0xd70a0033}},	// [d9c0] _daca_, _pobj, _мунi, мнае_
  { {0x6fd4014e,0x98b30024,0x249f00e8,0x5c37000a}},	//   _दिसं, ādāt_, _agum_, _סטיב_
  { {0xe7fe005d,0xa696009c,0x2d520069,0x80b3000b}},	//   _उनका_, трај, všej_, ीराइ
  { {0xceb8005c,0x3cc9000a,0x613c0030,0xb60601ec}},	//   zbę_, ֲלוּ_, _céll, vušā
  { {0x44320023,0x6d5d0152,0x68e400dd,0xa3f40010}},	//   ây_, érai, mgid, уплі
  { {0xfbb7000a,0x41b4002b,0x68e4558e,0x29002a67}},	//   דפסת_, همتر, lgid, leia_
  { {0x44200440,0x7791002b,0x31c3004a,0x2d52006f}},	//   ţi_, _ایلا, асыв, ršej_
  { {0x751a0015,0x613c0003,0xb606003d,0x21670054}},	//   _تقرأ_, _vélo, rušā, кији_
  { {0xc95304dc,0x60c2016f,0x9597000a,0x2d52006f}},	//   ימה_, _veom, _יכלו_, pšej_
  { {0x63760045,0x290056c2,0xfc3f005a,0x0000006a}},	//   râns, heia_, ucím_,
  { {0x02190010,0xcf770015,0xfe6f0015,0x26db000a}},	//   _піць_, خصيص_, ْدُ_, וקימ
  { {0xc237000a,0xfc3f0030,0x212f56c3,0x27e056c4}},	//   _שראו_, scím_, _gogh_, kuin_
  { {0x2900001c,0xdb1d008c,0x7ac70a3e,0xdc0d0065}},	//   deia_, yssä, ксве, िटेड_
  { {0x442603af,0xd24600e6,0xbb850015,0x6d460509}},	//   ixo_, من_, السي, ahka
  { {0x4f9b013a,0x4a540001,0x39a4009c,0xaa54009c}},	//   _קבוצ, акрс, иштв, аврш
  { {0x58d40080,0x6d46207b,0x1e97000a,0x26c307c4}},	//   иост, chka, _בכול_, _sejo_
  { {0x27e008e0,0x4815008f,0x65620089,0x199400a4}},	// [d9d0] guin_, ымас, dnoh, ратя
  { {0x4ab7005d,0x656200f2,0xdc8c000a,0x7d0d56c5}},	//   _अभिव, enoh, _קְהָ, _haas
  { {0x7d0d0005,0x68e400dd,0x290b4479,0xf4d9006b}},	//   _kaas, bgid, _taca_, емеш_
  { {0xa3c0000b,0x2d52036d,0x2900059d,0x38c60073}},	//   ूओं_, všek_, ceia_, tūrų_
  { {0x613523d1,0x613c0030,0x88f6000a,0x286b01ca}},	//   _mált, _célm, _גזרו_, _црно_
  { {0x7d0d020a,0x98a20073,0x0000006a,0x0000006a}},	//   _laas, _voką_,   ,
  { {0x51f5003b,0x799d000c,0xf772000a,0x256e0046}},	//   استر, _kisw, _הקם_, hýly_
  { {0x34950010,0x661a00dc,0x7d0d56c6,0x95c80054}},	//   _бабр, _átka, _naas, _јура_
  { {0x349428c8,0x1477002b,0x4f9500ce,0x78ad1dc4}},	//   _ватр, _شارج, лроу, icav
  { {0x481600b4,0x20d30092,0x257c01b2,0xc7d6000a}},	//   אַטן_, ợi_, víli_, נותי_
  { {0x7d0d0020,0x3f9c0ca3,0x10f50033,0x64680045}},	//   _baas, _divu_, _бяля, ăsiţ
  { {0xcb09000a,0x91ba000a,0x10150021,0x6d4643db}},	//   _מל_, _נמני, _مبتد, uhka
  { {0xbad60010,0x60c9007c,0xc1720c44,0x80270058}},	//   лівы, maem, _פחד_, _جرام
  { {0xa03a004c,0x257c006f,0x6d4656c7,0x644b007f}},	//   _רעספ, ríli_, shka, izgi
  { {0x799d0012,0x7d0d05ff,0x68e40061,0x290056c8}},	//   _bisw, _faas, tgid, teia_
  { {0x7d0d0020,0x60c9007c,0x69260033,0x2bdc000b}},	//   _gaas, naem, ымба, _बिपा
  { {0x799d0026,0x6d4406e8,0x378a0054,0x290056c9}},	// [d9e0] _disw, _ilia, ебао_, reia_
  { {0x613c00dc,0xbcfb00dc,0x27e00234,0x9bbb000a}},	//   _célj, nnén, ruin_, _רציפ
  { {0x4e89000a,0x2900016e,0x3a250123,0xeb97000a}},	//   תָּ֣, peia_, älpt_, _תדיר_
  { {0x25b70074,0x6135001a,0x78ad1c75,0x69ce56ca}},	//   اهند_, _máls, ccav, msbe
  { {0xebd6000a,0xc3d70015,0xd3d70015,0x27e056cb}},	//   רֵ֣י_, هبوط_, هبوا_, quin_
  { {0x2377002b,0x6352002a,0x2bdc29ac,0x46a32797}},	//   همند_, ołni, _बिना, _гарв
  { {0x366a0080,0xe1ef0015,0xbcfb0030,0x69ce56cc}},	//   _чаво_, كسي_, dnén, nsbe
  { {0x3d0e014e,0x3f9c022d,0x3134023e,0x361b000a}},	//   ियों_, _sivu_, реир, _אולד
  { {0x60f70033,0xc102002b,0x446601c6,0x69dc0012}},	//   уныя_, لوژي, _свав, hrre
  { {0x8ff7003b,0x7d0d56cd,0xadf403ae,0x69ce2cb5}},	//   ارير_, _saas, апош, ksbe
  { {0x6d44002f,0x3f820024,0xed01005e,0x69ce0079}},	//   _blia, ēku_, однi_, jsbe
  { {0x6d44002d,0x62880024,0xa0a60355,0xdd910015}},	//   _clia, _izdo, _садд, توج_
  { {0x613503c0,0x7d00007c,0x7d0d1f40,0x6352002a}},	//   _vált, õmsa, _vaas, ełni
  { {0xb09b000a,0xcf25002b,0xce94006b,0x799d034c}},	//   _ניגר, _پرهي, _калъ, _sisw
  { {0x613c0014,0x7d0d4e87,0x0f7b000a,0xceb3000a}},	//   _nélk, _taas, _ראוב, _פיק_
  { {0x127b004c,0x628800bf,0x6d4456ce,0x0000006a}},	//   גאלע, _mzdo, _glia,
  { {0xd6db1afd,0x69dc56cf,0xead5004a,0x6d5d0003}},	// [d9f0] ете_, arre, _копь, érau
  { {0x69da0089,0xab5b0030,0x6bec000a,0x6d44006f}},	//   átec, gsüt, _נַחַ, _zlia
  { {0x613c00dc,0x69ce0030,0xe78409c3,0xf6550004}},	//   _célk, csbe, суто, јвеќ
  { {0xf8b10086,0x613c27b8,0x637f2aa4,0x19ba000a}},	//   _ذکر_, _délk, mêni, _שמרב
  { {0xd00606e4,0xc2c50029,0x3949002d,0x7bcf04f3}},	//   _بل_, ليشي, mhas_, nscu
  { {0x3949001c,0x97320086,0x257c0089,0x7bcf56d0}},	//   lhas_, _وکلا, dílu_, iscu
  { {0x20020064,0xe1250923,0x3949007c,0x64b70015}},	//   çkin_, имки, ohas_, _محذر
  { {0x394903af,0xb4f90053,0x6f010383,0xbcfb00bf}},	//   nhas_, _שפּי, welc, liéf
  { {0xbcfb00dc,0x443902de,0x60c901f9,0xb87b005a}},	//   tnén, _æs_, raem, _abíz
  { {0x28980053,0xff510115,0x69ce0034,0x6d440125}},	//   נדזן_, تخب_, ysbe, _slia
  { {0x23ab0134,0xd12e0086,0x6d21000b,0x4d661191}},	//   _høj_, سمی_, यांग_, иков
  { {0xa2af005d,0xf532000a,0xfce60850,0x8d5601c5}},	//   ुरक्, ַ֥ר_, шомо, рточ
  { {0x40e8000a,0x5d67004a,0x65690085,0x3e32009a}},	//   _תַעֲ, риям_, _mjeh, مفیر
  { {0x6fb20029,0xbb76006b,0x2bdc000b,0x1a5a0015}},	//   _بموا, румъ, _बिठा, نشأة_
  { {0x7e7900b2,0x5e560074,0x3956000d,0x4e790053}},	//   _באַז, _پليس_, ањат, _באַצ
  { {0x6d5d038d,0x3949002f,0x6d44003f,0x98a31365}},	//   érat, ghas_, _ulia, жите
  { {0x7d7b0008,0xe8f70054,0x88c80046,0x69ce04a3}},	// [da00] _בנקו, јлу_, jtěž, ssbe
  { {0x8c1b013a,0x57470001,0xdc370053,0xe6c50015}},	//   _יופי, азум_, _כאפט_, متمي
  { {0x3949002f,0xaadb01d8,0x1dab000b,0xc4c60058}},	//   bhas_, _בחיר, _घूमत, لتشو
  { {0xfdf60008,0x394956d1,0x35db000b,0xdda8004f}},	//   יצעת_, chas_, मंज़, אֱסָ
  { {0xb6a60036,0xe3af0115,0xab5b0030,0x232a005e}},	//   _вигл, ورو_, psüt, коди_
  { {0x68f60026,0xfc170008,0xf487002b,0xd252002b}},	//   lfyd, יקני_, جامی, ينش_
  { {0x66840086,0x61e3117f,0xc2070015,0xe80e000b}},	//   _ایال, gunl, لقون_, सिका_
  { {0x23ab0134,0x39400007,0x68f60026,0xd0100015}},	//   _føj_, nkis_, nfyd, كلب_
  { {0x29370053,0x27f20026,0xa2e60860,0x659b004f}},	//   שאפן_, ntyn_, _возд, _יילק
  { {0x2d820111,0xa2d30015,0x613c00e9,0x671c000b}},	//   elke_, _ويقت, _méli, नाटक_
  { {0x62880024,0x4d990036,0x3940400c,0x2d680085}},	//   _uzdo, лкою_, kkis_, rđen_
  { {0xfcab002b,0x637f016e,0x25d7000a,0xcce70058}},	//   کاگو_, vêni, סוכן_, جسدي
  { {0xed580010,0x2d850024,0xda090086,0xcb22000b}},	//   роў_, ēle_, گيزه_, मांड_
  { {0x68f60026,0x6df40015,0x5f730015,0xbcfb0069}},	//   efyd, _هكتا, _واور, mném
  { {0x68f60e18,0x29970015,0xf99f02b9,0x38c7006b}},	//   ffyd, لجرح, _piè_, ищав
  { {0x5e9b0008,0xfe9b000a,0x0e9b000a,0x6135001a}},	//   _בבוק, _ביומ, _בשול, _jálp
  { {0xf09300b2,0x61e30061,0xc6f9004a,0x613c56d2}},	// [da10] ַנע_, zunl, лнах_, _céli
  { {0x613c0152,0xf7700070,0x2bdc000b,0x3207002a}},	//   _déli, وال_, _बिता, ywny_
  { {0x95d90080,0xab5b0020,0xdb1d02de,0x2d5200bc}},	//   удет_, ssüs, dssø, ršev_
  { {0x9475002b,0x0596002b,0x26c7002a,0x613c56d3}},	//   مگذا, مانگ, źno_, _féli
  { {0xdb23001a,0x6d5d014b,0x7c3d0034,0xbcfb013f}},	//   _þróa, iisa, nysr, jném
  { {0xfbb8013a,0xdb04002d,0x61e30064,0xd7f80010}},	//   ספות_, _stiú, tunl, _тую_
  { {0xdb040467,0x6602002a,0x6d5d1d5f,0x45d41cd9}},	//   _quié, łokr, kisa, _морс
  { {0x6b4b0014,0x61e301e2,0x6d5d003f,0x41b20029}},	//   _függ, runl, jisa, أمير
  { {0xf92a0053,0x30190015,0x23c6000b,0x61e30061}},	//   רופּ, اتبة_, रीदद, sunl
  { {0x91710092,0x43850015,0x1ee7002b,0xd25b0054}},	//   _mở_, _الطق, جودی_, _ице_
  { {0x39400007,0x212d016f,0x63a9003f,0x27f2002a}},	//   ykis_, pjeh_, _huen, ztyn_
  { {0x63a9000c,0x3cf4005d,0x200b02de,0x7e540033}},	//   _kuen, ेजें_, æcis_, ітэц
  { {0x814c00b2,0x51740029,0x41740029,0x443d0026}},	//   _בעאַ, _بالأ, _بالس, nyw_
  { {0x7fb40086,0x6d5d56d4,0xdde8002b,0x63a956d5}},	//   _بلوچ, érar, دریه_, _muen
  { {0x443d0026,0xc332000a,0x6219004c,0x6d5d56d6}},	//   hyw_, הום_, װוּק, bisa
  { {0x35d1005d,0xccc609ef,0x6d5d56d7,0x98a00085}},	//   _हिज़, _убий, cisa, njić_
  { {0x7d061920,0x394056d8,0x2fdf0034,0x68f60034}},	// [da20] meks, rkis_, nrug_, rfyd
  { {0xcc570008,0xdb0e00f2,0xa3ab000b,0x7d0656d9}},	//   _לספק_, äkär, _गढ़_, leks
  { {0xb5a9003b,0x2f5a0053,0xfb370008,0x27f256da}},	//   لانك_, נדענ, _האיש_, styn_
  { {0x56930036,0x63a956db,0xdff9000b,0x14260248}},	//   чаєт, _buen, ्बाद_, йдем
  { {0x63a90467,0x6ba10064,0xbcfb0003,0x4d7b004c}},	//   _cuen, _üzgü, siég, נרנע
  { {0x62810007,0x63a10024,0x6d5d1cec,0xa318004a}},	//   _bylo, _ciln, zisa, ржку_
  { {0x599a000a,0xbcfb0003,0x321a006f,0x6135016e}},	//   ְשִׁ, liée, ípy_, _pálp
  { {0x63a902c1,0x463b0053,0x563b0053,0x3d18000b}},	//   _fuen, _געלע, _געלײ, _बोले_
  { {0xcf260029,0x2fdf0026,0x6b4b0012,0xe8e00016}},	//   مردي, grug_, _hüge, _ngọt_
  { {0x9df80083,0x6d5d00e8,0x320d008c,0x2489007c}},	//   анот_, wisa, äkyä_, üame_
  { {0xa0160074,0x52860029,0xdd950010,0x877b0135}},	//   _گذاش, _الاك, жаны, ראיי
  { {0x63a104f9,0xdc990036,0x869b0053,0x26ca002c}},	//   _ziln, ивні_, טייז, _lebo_
  { {0x4096003b,0x7984005c,0x69da002c,0x703a0087}},	//   _الشر, dliw, áten, _حساس_
  { {0x26ca0089,0x7b670ea6,0x6d5d495f,0x27e02463}},	//   _nebo_, стме, sisa, drin_
  { {0x69da010b,0x91710023,0x6ce70010,0xbb840015}},	//   šten, _sở_, _ліпе, سلفي
  { {0x8e83003b,0x7d0601e2,0xbcfb0152,0x2d520089}},	//   _عليه, ceks, fiée, ušet_
  { {0x76a70029,0x58870080,0xe8940080,0xfcaa004c}},	// [da30] محاك, сыва, зать, _דיפּ
  { {0xa3d2000b,0xdb1f008c,0xbd040046,0xd795006b}},	//   _विज_, äväm, riéř, цизъ
  { {0xdf360023,0x26ca02c1,0xcb38000a,0x1efb004c}},	//   _đặt_, _debo_, _לנזק_, רלבע
  { {0x63a902c1,0xe4cb0002,0xc4c3000b,0x63a11837}},	//   _puen, ابان_, शरेख, _siln
  { {0x63a11cdb,0xbcfb0152,0xe3b30086,0x25ad044c}},	//   _piln, ciée, سرش_, _čelu_
  { {0x2b22005d,0x7d06005c,0x443d0026,0x6b4b00b8}},	//   माएँ_, zeks, ryw_, _füge
  { {0xeb920008,0x63a12758,0x7d06386b,0x6b7c000a}},	//   וָה_, _viln, yeks, ארגנ
  { {0x13a70086,0x628101b2,0x2fdf56dc,0x63a1157b}},	//   _هنری_, _vylo, trug_, _wiln
  { {0xe81c014e,0x63a90020,0x98a9002c,0x6281005c}},	//   निया_, _uuen, kiaľ_, _wylo
  { {0x289c0053,0xbcfb0057,0xd488000a,0xbf650015}},	//   ניזא, lnéh, _הָעֹ, تدعو
  { {0x2bdc005d,0x7996005c,0xa3af000b,0x79840034}},	//   _बिहा, ymyw, _ऐंड_, yliw
  { {0x200e00f2,0xbcfb0264,0x6d5d0003,0xee3602a3}},	//   äjiä_, nnéh, érap, іня_
  { {0x4c36008f,0xbcfb0046,0x613c3e42,0xac9a0015}},	//   цэнт, inéh, _célu, شنسا_
  { {0x7d0656dd,0x5ea50015,0xab66005e,0xf0640033}},	//   seks, _بمثل, іввл, _экіп
  { {0x6e950196,0x999e0089,0x7984005c,0x5ee8000a}},	//   _بلغا, átů_, tliw, _הַפְ
  { {0x201d005c,0xbcfb0107,0xc212000a,0x27e0420e}},	//   _krwi_, jnéh, והל_, trin_
  { {0x60cb00dc,0x49990080,0xbcfb0264,0x0d8302a3}},	// [da40] _megm, ётся_, dnéh, _ільн
  { {0x60cb00dc,0x361a0286,0xf7720015,0xbcfb0003}},	//   _legm, ицею_, ذاء_, riée
  { {0x8afb0008,0x36060015,0x7984002a,0xb87b0125}},	//   _דהיי, تواف, pliw, _scít
  { {0x92a6005c,0xe5060015,0x5dfa004c,0x8699004a}},	//   zyłą, تبطي, יפענ, стут_
  { {0xd6da002b,0x613c0030,0x39470045,0x248d002a}},	//   _پوزش_, _mélt, _însa_, _czem_
  { {0x8c1b0008,0x7c0b000a,0x84130033,0x8c0b000a}},	//   יוני, שִׁ֔, ьміх, שִׁ֤
  { {0xe5060029,0xbcfb0264,0x2d800091,0x2018003d}},	//   _وبري, bnéh, _okie_, ārim_
  { {0x1a9b0053,0x0657000a,0x9657000a,0x201d002a}},	//   סיקע, _וילך_, _ושלא_, _brwi_
  { {0xf99304dc,0xff0603ad,0x9097006b,0x637f016e}},	//   ורה_, оянн, овът_, tênt
  { {0x2d80002a,0xa6fa004f,0x0000006a,0x0000006a}},	//   _akie_, בִ֛י,   ,
  { {0x69da02d5,0x82660086,0x171b004c,0x471b004c}},	//   átel, _بهان, בויע, בויג
  { {0x3f850026,0x8fa6017a,0x613c10e5,0x62650015}},	//   allu_, _даде, _célt, _عالق
  { {0x459b0053,0x98a9002c,0xc4d3000a,0x9f440003}},	//   יסטע, tiaľ_, וגר_, humé_
  { {0xada5002c,0x9e660015,0x98ab002a,0xbcfb56de}},	//   _skúš, _واثن, _mocą_, inéi
  { {0xf1b80008,0xda350080,0x099b0015,0x613c0030}},	//   מֶּל, чевы, لضرب_, _félt
  { {0xed580431,0x98a9006f,0xdb0d016e,0x57b506b5}},	//   _мој_, siaľ_, _otaç, збат
  { {0x08550010,0xbcfb0264,0x98ab002a,0x36ab0054}},	// [da50] чваю, vnéh, _nocą_, ађем_
  { {0xbb55009a,0xd774009a,0x1ab402ed,0x0000006a}},	//   _رنجب, والع, _обья,
  { {0xbcfb0057,0x88c70015,0x248d0030,0xab9800c3}},	//   tnéh, _وتحل, _szem_, _بخير_
  { {0xaba80086,0x69d500dc,0xaae7002b,0x7e9b004f}},	//   _دهیم_, msze, _اسکو, בסבו
  { {0xbcfb0227,0xad1c000a,0xf8b6000a,0x28b6000a}},	//   rnéh, יואר, _מפרי_, _מפרש_
  { {0x883a000a,0x889a0008,0x27e9013c,0xbcfb0227}},	//   _התשו, _לברי, muan_, snéh
  { {0x44290011,0x02190210,0xe5730031,0x69d51fad}},	//   ţa_, сіль_, _قطر_, nsze
  { {0x2600005d,0x2bdc000b,0x20550238,0x2608000b}},	//   _रहती_, _बिला, зтор, सबरी_
  { {0x27e902f2,0x7f1909a0,0x0000006a,0x0000006a}},	//   nuan_, біну_,   ,
  { {0x2ca90035,0x69d512e0,0x2d9956df,0x69dc000b}},	//   _agad_, ksze, ïren_, _फिली
  { {0x69d5005c,0xd2510029,0x27e9064e,0x290900f2}},	//   jsze, _ثنا_, huan_, keaa_
  { {0x69d546a3,0x27e9013c,0x3114017f,0x3ce6000b}},	//   dsze, kuan_, _офіс, कलें_
  { {0x5067003b,0x27e9013c,0x31b10030,0x69d51022}},	//   _بطاق, juan_, _ház_, esze
  { {0xa026002e,0xe4560053,0x63bb003f,0x27e90375}},	//   stöð, לירט_, _mtun, duan_
  { {0x6b5001d1,0xda660029,0x69d50c19,0x2f120015}},	//   _lägg, ساسي, gsze, _سِير
  { {0xc212004c,0x6995008b,0x6e3c0012,0x68ed56e0}},	//   עהן_, друх, ärbe, ggad
  { {0x69d5002a,0x6b420016,0x27e90260,0x63bb56e1}},	// [da60] asze, _lôgi, guan_, _ntun
  { {0x6d4601a0,0x656b0509,0x0ebd000b,0x9f440003}},	//   lkka, engh, ोरिड, tumé_
  { {0x63bb04f9,0x7d1656e2,0xbb3b000a,0x69260033}},	//   _atun, _kays, _העיי, _емна
  { {0x27e90049,0x6b500123,0x6d4656e3,0x07a6112c}},	//   buan_, _bägg, nkka, _намн
  { {0x29370053,0x9f440152,0xfc3f006f,0x6d4656e4}},	//   _זאכן_, sumé_, ncíp_, ikka
  { {0x6b500123,0x656b56e5,0x8bd7004f,0x64a300ce}},	//   _dägg, angh, לונו_, хача
  { {0xf107005d,0xcb130008,0xbcfb002d,0xf1aa0015}},	//   वजूद_, גלו_, snéi, حاته_
  { {0xb6a356e6,0x32430015,0x3ce6000b,0x9c870046}},	//   _числ, عنيف, कलों_, _jičí
  { {0x69d54439,0x5f94029f,0xd843005a,0x50630138}},	//   zsze, миит, mičí_, етэа
  { {0xa8570008,0x69d5062e,0x68ed56e7,0x613c0030}},	//   פייה_, ysze, zgad, _célr
  { {0xa2d30015,0xa2bb000a,0x6f08006f,0x613c0030}},	//   _سينت, _המבט, redc, _délr
  { {0x656200f2,0xd84301b2,0x14cc000b,0xd5a60015}},	//   nioh, ničí_, ारिण, ضف_
  { {0x69d5005c,0xa3cf005d,0x21370008,0x613c00dc}},	//   wsze, वीप_, _מטאל_, _félr
  { {0x6d46022d,0xfe6f002b,0x69d556e8,0xb09b0c44}},	//   akka, ئدی_, tsze, _הידר
  { {0xd90f0086,0x4efb0447,0x656b0026,0x2909008c}},	//   هید_, _הלוג, yngh, teaa_
  { {0x27e9013c,0xe8f90033,0x6e870015,0x69d556e9}},	//   tuan_, ўнач_, _عنيف_, rsze
  { {0x69d50014,0xd1970008,0x7aee0125,0x36d501e3}},	// [da70] ssze, לכלי_, úntá, дозр
  { {0xfbd20008,0x69d512f7,0x57f40033,0x600b000a}},	//   _שתי_, psze, эпут, מִבְ
  { {0xe4d9003b,0x8afa000a,0xbafa000a,0xa3cf000b}},	//   قوات_, _והתי, _והתש, वीन_
  { {0x27e911ec,0x65620034,0x656b56ea,0x31b1013f}},	//   puan_, gioh, ungh, _ráz_
  { {0xe1f10086,0xa4870029,0x9cd8000a,0xa3e900fd}},	//   چسب_, أجان, לואה_, ідка_
  { {0xaabf005d,0x07a40010,0xe1f10015,0x6b500123}},	//   ्रिक, _паўн, نسب_, _vägg
  { {0x9195000d,0x8235002b,0xf5390247,0xe296007b}},	//   мјиш, ظرتا, _toť_, маш_
  { {0xa5350033,0x34952044,0x7fd90004,0xa0a502a3}},	//   _ўнач, _жабр, офот_, майд
  { {0x1abf000b,0x8f7502a3,0xd9da000b,0x4abf000b}},	//   ्राथ, дуні, _बट्ट, ्राव
  { {0x200d003f,0xf8aa000b,0x8f960015,0x7d1602f2}},	//   rwei_, _कल्प, ونيذ_, _says
  { {0x6d4d020a,0x7d160152,0x7529044c,0x1d0a05b3}},	//   _blaa, _pays, _knez, оени_
  { {0xc27a000a,0x6d46008c,0x361a000a,0x6b5004d2}},	//   _ורעי, ukka, קורד, _mäge
  { {0x6d4600f2,0x6b5000c0,0x6b4b0020,0xdde00089}},	//   rkka, _läge, _süga, ětši
  { {0xa3cf014e,0x2f180080,0x9f34005e,0x5b350033}},	//   वीय_, _ночь_, _печі, нэсу
  { {0x316d0011,0x6b5010cc,0x092a0015,0x99710091}},	//   onez_, _näge, يسري_, _sąš_
  { {0xe8fa0010,0x316d0003,0x753b0046,0x8d76002b}},	//   ўла_, nnez_, _nouz, _تاتا
  { {0xbf8a0023,0xd7f90036,0xc7a6024f,0xa96700af}},	// [da80] _đoạn_, зує_, диак, фита_
  { {0x6ac6003b,0x86ea0029,0xbcfb0077,0x49ba006e}},	//   _تقدم, تعرف_, nién, _واجد_
  { {0x95c30015,0x860a0021,0x65623009,0x753b56eb}},	//   َيْه, تقاق_, tioh, _bouz
  { {0x448a18dc,0x273f0045,0x998a0091,0x0000006a}},	//   обен_, _sînt_, rybų_,
  { {0x753b0152,0x645d0091,0x78a2006f,0x65620bb5}},	//   _douz, _žsir, ľovs, rioh
  { {0x7529003f,0xa294022a,0x43730054,0xcc57000a}},	//   _enez, налі, кујт, ובני_
  { {0xe1ef0029,0xd2500029,0xbcfb0077,0x753b01c2}},	//   لسي_, طنة_, dién, _fouz
  { {0xd130003b,0x613c00dc,0xfa77000a,0x316d4265}},	//   امة_, _célp, ועצת_, gnez_
  { {0xd007000d,0x673c0604,0x61ea0045,0x60f70033}},	//   дење_, _korj, sufl, фныя_
  { {0xc43b000a,0x6d4d0f8c,0xf43b000a,0x3eaa02de}},	//   _ותמי, _slaa, _ותמש, øbt_
  { {0x673c00bd,0x917a0092,0x32460015,0x6d4d1c00}},	//   _morj, _cậy_, _تناف, _plaa
  { {0xdfcf0086,0xe61101d8,0x61e50089,0x50d6002b}},	//   _چين_, נִי_, áhle, _آزار
  { {0xe5710053,0x6d4d0159,0xdefa0010,0x319b000a}},	//   אַם_, _vlaa, _дый_, _ובאנ
  { {0xbcfb0533,0x673c00f2,0xab5b0061,0x5f440058}},	//   cién, _norj, lsüz, _سنعل
  { {0x0f7b000a,0x63a847e0,0xf9890058,0xdb500058}},	//   _ורגל, _midn, كنسي_, جَّ_
  { {0xac950010,0xcda90053,0x35d8005d,0xd90f002b}},	//   _пайш, _ציפֿ, _डिज़, جیح_
  { {0x6b500c77,0xd7f80891,0x673c56ec,0x0000006a}},	// [da90] _säge, дух_, _borj,
  { {0xcff7000a,0xd6d10015,0x478b0033,0x368b029f}},	//   וצמה_, اقا_, ісам_, осен_
  { {0x753b06d5,0xcb12000a,0x61350030,0x58d50cb0}},	//   _pouz, _גלי_, _válz, _понт
  { {0xa8350124,0x6a9a0008,0xba9a0008,0x6b50012d}},	//   _земљ, _משתנ, _מסתי, _väge
  { {0xfd580008,0xf4d60015,0xd40b0015,0x88ba000a}},	//   ושאי_, رووغ_, تتام_, _מזרי
  { {0x2919000c,0x94740029,0xa856000a,0xdb0d0533}},	//   _hasa_, خدما, _טירה_, _ataú
  { {0x200604f9,0x4b380008,0x2369016f,0xceb8002a}},	//   _apoi_, ורגל_, đaj_, dcę_
  { {0x394915ff,0x90d50086,0x05950086,0x2919013c}},	//   nkas_, رآبا, _سازگ, _jasa_
  { {0x600602bf,0x29190d31,0xbcfb0077,0x337501f3}},	//   еным_, _masa_, tién, _згар
  { {0x6d9600dc,0xaf090015,0xbcfb0077,0x7e750015}},	//   záad, أقدم_, uién, فاجئ
  { {0x8d6603e7,0x62881ba4,0x3949187b,0x23a8000b}},	//   евне, _gydo, kkas_, _छूटद
  { {0x917a0092,0x2919043a,0x2d8456ed,0xc212000a}},	//   _vậy_, _nasa_, ôme_, _תהא_
  { {0x66f0000b,0x2ca40123,0xbc19005e,0xa136000a}},	//   _चालक_, ämd_, мірі_, _ראנק_
  { {0x5dd9006b,0x2d8b56ee,0xa03a004f,0x29190072}},	//   _ефир_, alce_, _מענפ, _aasa_
  { {0x499656ef,0x63810046,0x2bdc000b,0x39490061}},	//   ешат, míně, _बिका, fkas_
  { {0xa3c1000b,0x291956f0,0x394956f1,0x386d01ec}},	//   ूठा_, _casa_, gkas_, _žera_
  { {0x57ea223b,0x6b500123,0x9f440046,0x25bf0085}},	// [daa0] ядам_, _vägb, zumí_, _čula_
  { {0x394900f2,0x9b460015,0x1bfb000a,0x2d82007f}},	//   akas_, _أندو, _צליב, loke_
  { {0xd6390010,0x1af7000a,0xd946030e,0x291956f2}},	//   мяці_, _אמיל_, _зени, _fasa_
  { {0x394901d1,0x3a2500fb,0xcdda00b2,0xf769000a}},	//   ckas_, ælpe_, פֿבר, זק_
  { {0x66150014,0x9cd70008,0x673c00f2,0x628856f3}},	//   _eszk, תונה_, _torj, _sydo
  { {0xfbd30008,0x9f4d008c,0x3f49001a,0x291956f4}},	//   נתו_, nteä_, _búum_, _zasa_
  { {0x7d0456f5,0x29190064,0x63a856f6,0x917100a1}},	//   _obis, _yasa_, _vidn, _sớ_
  { {0x7afb010b,0x9f4d00f2,0xceb8005c,0xc4c50029}},	//   đuti, hteä_, wcę_, _لتكو
  { {0xf0b70086,0x63a800c0,0x6288005c,0xc4cc000b}},	//   رايش_, _tidn, _wydo, ारीख
  { {0x77f7000a,0xd130002b,0x7d0456f7,0x59b0000b}},	//   עמיד_, امک_, _abis, झदार
  { {0x442404f6,0xd6fb000a,0xceb8002a,0x91e31d90}},	//   _hrm_, הפיכ, rcę_, _бохе
  { {0x6c3500e6,0xc05a0138,0x917100a1,0x0000006a}},	//   نفجا, _ніл_, _tớ_,
  { {0x5c040010,0x29190375,0xcff5002b,0x5cb80033}},	//   ляра, _rasa_, _لينک, эляў_
  { {0x2919000c,0x3e340029,0xe451000a,0x9057000a}},	//   _sasa_, _لفتر, בֶל_, _אבדו_
  { {0xb9e40191,0xda780063,0xfd390015,0x5e430015}},	//   літи, еят_, _يكتب_, _مَوْ
  { {0x4424002f,0x69da0152,0x5a340010,0x39490007}},	//   _orm_, âtea, ынст, ukas_
  { {0xb8d9014e,0xf6e71e92,0x19580033,0x23cf000b}},	// [dab0] _चल_, ецен, хаты_, _सौंद
  { {0x2aee005d,0x48140010,0x29000020,0x7d0f24ae}},	//   _जाएँ_, ымус, afia_, lecs
  { {0x3f9e002e,0x0f7b0053,0x8624007a,0xfb1a000a}},	//   imtu_, לאמב, льце, _חותמ
  { {0x59b6005d,0x94750086,0x02bb000b,0xe3c50015}},	//   _आंतर, نگذا, ॉर्न, نْصَ
  { {0x53e0005d,0xe3b8005e,0x7d1d56f8,0x945d0535}},	//   _निःश, ебі_, idss, _reńs
  { {0x044205b3,0x6385006b,0xfa6b000a,0x51f50015}},	//   решн, ъгла, ּכֵּ, نسبر
  { {0x69da1eae,0x6615005c,0x81f60015,0x6b5004d6}},	//   štev, _uszk, نفور_, _jäga
  { {0x3f8c002e,0x65950033,0x27e956f9,0x7d1d49db}},	//   eldu_, _рабу, oran_, jdss
  { {0x2fd60086,0x3ff20015,0x2d8200da,0xe3150054}},	//   نويد_, لكير, voke_, _имањ
  { {0x4f22004a,0x73c40015,0x257c0046,0xf70701f3}},	//   адьб, _إيلم, díly_, днiх_
  { {0x91710092,0xb6ba000a,0xbcfb0077,0x2d8256fa}},	//   _cỡ_, וצתי, piél, toke_
  { {0xd00e0086,0x6459005c,0x14d5000a,0x7c24377c}},	//   حلی_, ozwi, כוֹל_, _prir
  { {0xef0e08df,0x645902f7,0x2d8256fb,0xed5756fc}},	//   _км_, nzwi, roke_, тоя_
  { {0x0056013a,0x27e956fd,0xe6cb000b,0x9f4d0123}},	//   _בשנת_, dran_, िरोज, fteå_
  { {0x798d0026,0xc3320008,0x91710092,0xbcfb013f}},	//   flaw, סול_, _gỡ_, rnér
  { {0x7d0456fe,0x5d7a0015,0x4ea40054,0xa2c1000b}},	//   _ubis, _تحتج_, _срча, रुत्
  { {0x18672105,0x629c0057,0x684308f7,0xab5b0061}},	// [dac0] вати_, _úrov, анта, opül
  { {0x798d0035,0x998d0085,0x6459002a,0xab9a0058}},	//   alaw, ćeš_, dzwi, _تخبر_
  { {0xd5b90036,0x2a360010,0x99860029,0x75d30015}},	//   есі_, _рэпр, _للدو, ليلا
  { {0xdb1d00dc,0x4424046c,0x2e3a015b,0xe4e30033}},	//   özös, _prm_, וגענ, аішн
  { {0x3f8704c0,0x23b30015,0x3f8c001a,0xb8f6000b}},	//   _oknu_, لمنس, yldu_, हर_
  { {0x69dc10ca,0x7d0f0030,0x23272a91,0x0000006a}},	//   osre, zecs, кочи_,
  { {0x672e01d1,0xd24f03c4,0xbebc0024,0x91f30015}},	//   _inbj, ينه_, ldīg, لأيا
  { {0xdce600df,0x60f80063,0x660d00dc,0xc872000a}},	//   mokė, хния_, őnké, ֹן֙_
  { {0x4fd30010,0x6702005d,0xceea012c,0x442419e7}},	//   ажыт, र्थक_, وردن_, _urm_
  { {0xa2c1005d,0xbebc003d,0x6b4b007c,0x9f5f001a}},	//   रुद्, idīg, _pügm, ærði_
  { {0x6e940029,0xc106002b,0x4357004f,0xe8190065}},	//   طلحا, _لواي, _שסבל_, _नैना_
  { {0xa00a0029,0xc5f300f3,0x3eb90046,0xbcfb0030}},	//   _يقال_, סדר_, ěsta_, gnép
  { {0x46b2000b,0xa3b8000b,0x2018003d,0x6b500123}},	//   जशाह, _घूम_, āris_, _säga
  { {0x2bb5005d,0x6abf005d,0x31b80030,0xe451004f}},	//   ंदबा, ्रेर, _kéz_, זֶל_
  { {0x1f37000a,0x798d00da,0x7d0f0030,0xaa59007e}},	//   _ברגר_, tlaw, pecs, хиву_
  { {0x2e59008f,0x2d6800dc,0x27e956ff,0x38c4005e}},	//   _яшчэ_, lően_, tran_, ищув
  { {0x9b450087,0x58870139,0x798d0509,0x27e95700}},	// [dad0] _منظو, тыва, rlaw, uran_
  { {0xd6db000d,0x5b150c1c,0x27e95701,0xe7190015}},	//   ќта_, _смот, rran_, عيات_
  { {0xc6a70080,0xcb12000a,0xe9750015,0x57a432b0}},	//   траи, _פלט_, _مهدد, ршта
  { {0x45180036,0x98b30024,0xc17e0091,0x7bdd4a91}},	//   кція_, ādēt_, žėjo_, ossu
  { {0xdfc60029,0x69da0796,0xe8e00016,0x94050067}},	//   _دي_, štet, _ngột_, اوته
  { {0xb3840010,0xc2c40015,0x66010123,0x7bdd4572}},	//   аліл, ليهي, _älko, issu
  { {0x45d40080,0xbb3c0053,0x2d680030,0x64590647}},	//   _восс, ועגי, dően_, szwi
  { {0x7bdd387c,0x41b20058,0x0000006a,0x0000006a}},	//   kssu, حمير,   ,
  { {0xe4750001,0xc4d2000a,0x236700bc,0x4094004a}},	//   _слањ, _לגן_, pinj_, ирьт
  { {0xa2ca005d,0x60c60061,0x2d680030,0x69dc5702}},	//   _स्प्, ıkma, gően_, ysre
  { {0xfbdf0092,0xa3cf000b,0x6807003d,0x877c015b}},	//   uyên_, वीर_, lījā, ואזי
  { {0xc6920008,0x69dc079b,0xbc1a0033,0xab5b0012}},	//   מאי_, vsre, нігі_, spül
  { {0xc104002b,0x6807003d,0xd116000a,0xfbd10015}},	//   _خوني, nījā, _תקנה_, ْتِ_
  { {0x6008000a,0x69dc1d89,0x0000006a,0x0000006a}},	//   _יִצְ, tsre,   ,
  { {0x44320023,0xb9b50063,0x7984003f,0x1a66002b}},	//   ̣y_, истъ, toiw, ایجی_
  { {0xfe700086,0x69dc5703,0x3f851ca8,0x7bc6393e}},	//   _بده_, rsre, lolu_, ppku
  { {0x69dc0012,0xdb24001a,0x7d770058,0x0000006a}},	// [dae0] ssre, þrót, _حمير_,
  { {0x68070024,0x442a0046,0x69dc5704,0x34cc0065}},	//   dījā, _čb_, psre, ार्द
  { {0xceb2000f,0x8afb0c44,0xf8a9000a,0xa6960054}},	//   ציא_, _אליז, פש_, урај
  { {0x8936003b,0xd5af0087,0x25ad353c,0xa2c1000b}},	//   _إعدا, سفه_, _ciel_, रुस्
  { {0x43460617,0x44320016,0x54b70033,0x25ad0f07}},	//   ледв, ãy_, угія_, _diel_
  { {0x2bb7005d,0xc7b3004f,0xfbb7004f,0xd4090058}},	//   _इंसा, _לבש_, אפסת_, ضتهم_
  { {0x394200c5,0x3f8529d6,0x1c1b000b,0xe81c000b}},	//   _koks_, dolu_, _पैनल_, निका_
  { {0x394200c5,0xba9b000a,0xc217005e,0xc2070015}},	//   _joks_, עסקי, уєш_, اقين_
  { {0x2d6800dc,0x9f540180,0x2937004c,0x98ac0091}},	//   tően_, ивич, ראפן_, ėlės_
  { {0x38170008,0x25ad0b8e,0x26da003f,0x57fb000a}},	//   נקים_, _ziel_, napo_, עליו
  { {0x1d3506b4,0x69da0003,0xa75b000a,0x2d680030}},	//   ання, âtel, גדיר, rően_
  { {0xc27b0053,0xcce70015,0xade5000b,0x7bdd02ad}},	//   _ארבי, دسدي, _किरन_, tssu
  { {0x9f340010,0x26da003f,0xbca50015,0xfd1f02b9}},	//   _велі, kapo_, شمسي, rdì_
  { {0x90970036,0x40930029,0xdb160092,0x9a87027a}},	//   _світ_, _الهر, _huyê, губл
  { {0xf99300b0,0x26da003f,0xa1430024,0x8e470015}},	//   مبر_, dapo_, _šķir, _ملوك_
  { {0x2489002a,0x391503ae,0xe91800ce,0x0000006a}},	//   żami_, јмар, лосі_,
  { {0x7d740086,0x69c7016f,0x6d8c000a,0x38355705}},	// [daf0] _داوط, spje, _אָזְ, шнар
  { {0x613c0014,0xbebc0024,0x4c9c000a,0x69c70030}},	//   _célz, ldīb, _אבחו, ppje
  { {0xcf9300b2,0x2d6f0089,0x25ad02c1,0xf7700015}},	//   צטע_, před_, _piel_, ساك_
  { {0x68070024,0xcdf7004f,0x0000006a,0x0000006a}},	//   tījā, רמאי_,   ,
  { {0x26da003f,0x6d9d002d,0x25ad0b8e,0xa3cf000b}},	//   bapo_, méad, _viel_, वीं_
  { {0x02c20036,0x3bbc000a,0x03a50511,0x6807003d}},	//   ойшо, עמוד, шило, rījā
  { {0x68070024,0x877a000a,0x32d40033,0xc1050058}},	//   sījā, _יאשי, сціс, لوثي
  { {0x6009129d,0x3fe51179,0x69c500aa,0x6d9d176a}},	//   вним_, ажив, _mthe, néad
  { {0xdb160023,0xe8d80008,0x6702005d,0x9477002b}},	//   _duyê, אוחר_, र्वक_, _صدرا
  { {0x9397003b,0x69c5003e,0x20d30092,0x20e50092}},	//   _إجرا, _othe, ải_, ồi_
  { {0x644b14e7,0xbd460029,0xed5a5706,0x539a000a}},	//   lygi, لندي, вон_, _סיעו
  { {0xe1f00115,0x3f853ac8,0x0c26004a,0xdb160016}},	//   _رسم_, solu_, аммн, _guyê
  { {0x06f7000b,0x69c545aa,0x31840015,0x6b4b0012}},	//   ुभाव_, _athe, _النِ, _zügi
  { {0xfc030033,0xd335000a,0xeb9a1dd3,0xbea5016a}},	//   ўпро, ׁרָה_, тиг_, _калк
  { {0x6d9d002d,0xa96a0ea6,0xfaa63050,0x0d760138}},	//   féad, вива_, раво, _выпя
  { {0xdb160092,0x69c1002d,0x26da003f,0x60db4bf0}},	//   _xuyê, ílea, wapo_, naum
  { {0xe7660010,0x26da2254,0xad1b000a,0xeab20015}},	// [db00] авап, tapo_, _יוקר, _وعد_
  { {0x6d440020,0xf6520015,0x28b8000b,0x644b0034}},	//   _hoia, يئا_, _अलवि, dygi
  { {0x6702014e,0x86750010,0x39420007,0x64c60015}},	//   र्षक_, быцц, _toks_, ليال
  { {0x4a7b000a,0x6d40007c,0x6d9d0125,0x89db000a}},	//   _יריב, ömah, réag, _בחטי
  { {0x98360010,0x6b4b0020,0xe45a006b,0x64330058}},	//   _тэні, _sügi, ъжд_, قروء
  { {0x656b002d,0x6702000b,0x23e5005e,0x6d440045}},	//   aigh, र्शक_, сіїв, _loia
  { {0x6d5600dc,0x27e02874,0xcb37000a,0x877b000a}},	//   _olya, lsin_, ינסק_, _סאלי
  { {0xdb160023,0x26d810df,0x361b000a,0x60db003d}},	//   _quyê, _hero_, _בולד, gaum
  { {0x27e05707,0xe58b000a,0x70540015,0xe3aa2e68}},	//   nsin_, _יָמָ, صندا, _акад_
  { {0x27e05708,0x75205709,0x7f830015,0x8f54005e}},	//   isin_, _hamz, يلين, свої
  { {0xdb160023,0x56b7000a,0x3039002b,0x6b500123}},	//   _tuyê, יפין_, نتیک_, _vägl
  { {0xa2ca014e,0xdcbb0063,0x3dde002a,0x27e0570a}},	//   _स्त्, ъщо_, rstw_, ksin_
  { {0xae430086,0x6d9d002d,0x6b5000b8,0x2d6f0046}},	//   مپیو, véad, _tägl, třeb_
  { {0xf4130008,0x9f5f002e,0x656b570b,0x4426570c}},	//   חפש_, _ærðu_, zigh, ivo_
  { {0x4f9b0008,0x9f9b0008,0xbf9b000a,0xbcfb0003}},	//   _שבוצ, _שסופ, _שיוש, diév
  { {0x4426016f,0xc27b000a,0x5d840015,0x6d44016e}},	//   kvo_, דרלי, _ولول, _goia
  { {0xd6db044a,0x656b080b,0xe6c70015,0x76c70015}},	// [db10] вте_, vigh, لتاي, لغال
  { {0xcdd4013a,0x26d8570d,0x23e00065,0x656b0e9d}},	//   ֶךְ_, _cero_, _निजद, wigh
  { {0x60db0152,0x6d9d002d,0x644b0026,0x4b7c039e}},	//   yaum, péad, wygi, _באזו
  { {0xfe37000a,0x5e77000a,0xeb9f02de,0x6d960030}},	//   ירבי_, סתאן_, stød_, jáal
  { {0x27e0029d,0xd7e40127,0x4429570e,0x1d0c000a}},	//   csin_, _міро, ía_, דּוּ
  { {0xb8ca005d,0x656b014c,0x8388005e,0x67d41eda}},	//   गे_, sigh, абів_, _фору
  { {0x442600df,0x92070024,0x656b0bfa,0x95cb0054}},	//   avo_, ksāš, pigh, _југа_
  { {0xc69200b2,0x9a780008,0xd24e0029,0xfa78039e}},	//   _זאל_, יתוף_, عني_, יעות_
  { {0x6569003f,0xe1640029,0xc6f9000a,0x60db343e}},	//   _imeh, تدوي, ְלֹך, raum
  { {0xf207008f,0x26c140a1,0xdce60073,0x0000006a}},	//   _вядо, ncho_, rikč,
  { {0x2295003b,0xb87b0089,0x2f54005e,0x0d8601b7}},	//   _الاس, _sdíl, ітьс, йлон
  { {0x27e000f2,0x8d561206,0x82340015,0x7d56005e}},	//   ysin_, сточ, _بركا, стої
  { {0x69c10089,0xd4790053,0x251a000a,0x1c1b000b}},	//   ílen, ראָל, נושא, _पैदल_
  { {0xaa4609e8,0xe452000a,0xcb760054,0x316d50d6}},	//   бегл, פֶר_, сумњ, liez_
  { {0xfbd2002b,0x7f3a000a,0x27e04fcf,0x9d4609b1}},	//   _کتب_, _תעצו, wsin_, _гейд
  { {0x26c10077,0x44260091,0x38c8002b,0x27e02022}},	//   echo_, yvo_, شاری_, tsin_
  { {0x26d8570f,0xed570008,0x46b60015,0xd94314c2}},	// [db20] _pero_, _לבקר_, محاس, чети
  { {0x6569003f,0x27e05710,0x9b46009a,0x0000006a}},	//   _ameh, rsin_, _طنجو,
  { {0x14c80086,0x26d85711,0x27e05712,0x7c65002b}},	//   لهای_, _vero_, ssin_, _هایل
  { {0x38bd00dc,0x75890036,0x45b70033,0x63e60015}},	//   _váró_, асів_, ёгію_, مستك
  { {0x44264e6d,0x6d9d002d,0xc953000a,0x752211b7}},	//   uvo_, léac, _זמר_, rdoz
  { {0x8c1b0008,0x69b6000a,0xdc9b000a,0xf756012c}},	//   טוני, ֖לֶף_, ניסל, _انسج
  { {0x6d9d002f,0x316d0152,0xcb130008,0x9f5f0152}},	//   néac, fiez_, פלה_, ctué_
  { {0x2054006b,0xd25900fd,0x39405713,0x39520073}},	//   жкия, шці_, njis_, nkys_
  { {0x6d9d002d,0xa02a0015,0x25bf0085,0xdb0d001a}},	//   héac, اسبك_, _čuli_, _otað
  { {0x5457000a,0xdbd41279,0xb356002b,0x0000006a}},	//   _הסמן_, _núñe, _دیتا_,
  { {0xab5b0527,0x6f230015,0x0000006a,0x0000006a}},	//   nqüe, سَّن,   ,
  { {0x06970008,0x25a60026,0x61430219,0xbcfb0030}},	//   מדים_, nmol_, _неха, lnéz
  { {0xed580010,0x219b000a,0xb19b000a,0x7c87005e}},	//   соў_, _עבדא, _עידכ, суне
  { {0x139b0053,0x0eba02bf,0x7017000a,0x386001c2}},	//   ָבלע, _суды_, _לחדד_, dzir_
  { {0x6d9d0152,0x4f6500e6,0x99850046,0xbcfb0030}},	//   réab, _بانف, ílů_, inéz
  { {0x588702ed,0x0000006a,0x0000006a,0x0000006a}},	//   быза,   ,   ,
  { {0xf7bb002b,0x57b40fea,0x2004006f,0x7d0d02f2}},	// [db30] ادرش_, збут, ntmi_, _ibas
  { {0x2d8b02b9,0xa09b004c,0x26c15714,0xdce6003d}},	//   loce_, רימט, ucho_, mikā
  { {0x46150115,0x3f520045,0x8f9b000a,0x7c21003d}},	//   توار, _râul_, ניבי, ālru
  { {0xbcfb038d,0x2d8b1a30,0x26c10012,0x2004006f}},	//   ciét, noce_, scho_, ktmi_
  { {0xdce60024,0xdb1d012d,0x9f5f00dc,0x1605000b}},	//   nikā, ppsä, űség_, _रहकर_
  { {0xbcfb00dc,0x2d6800dc,0x4c9c000a,0x1308005e}},	//   gnéz, tőek_, אבדו, йній_
  { {0x316d0003,0x5afc004c,0x3ce9007c,0xe0d10015}},	//   tiez_, אלוצ, _odav_, وزة_
  { {0x6569003f,0x7c2d11c8,0xbfc50608,0xdfd10015}},	//   _umeh, _orar, обик, ويع_
  { {0xf94a0053,0x316d0152,0x2909003f,0xcf390036}},	//   שעפֿ, riez_, ifaa_, ачні_
  { {0xddc800dc,0x316d0003,0x8e0918dc,0xdce6003d}},	//   ezdő, siez_, анов_, dikā
  { {0x6da6000d,0x316d0152,0xe8d90092,0x8027002b}},	//   жина, piez_, ghị_, _گرام
  { {0xdb0d09f0,0xdce60048,0x7db40010,0x63bb055a}},	//   _stað, fikā, ясьц, _kuun
  { {0x63bb0020,0x351a000a,0x8027012c,0x7c9a006b}},	//   _juun, בורנ, _درام, рънс_
  { {0x7d0d0020,0x8fa40015,0x2fe8000a,0x9f84005e}},	//   _ebas, _فمنه, _הַקֳ, _егід
  { {0x6d5d002d,0x01e9000a,0x2d8b0046,0x7d041ad6}},	//   bhsa, יַּֽ, boce_, gíró
  { {0xae7802e5,0x6d9d002d,0x6d5d0383,0x442d5715}},	//   _усіх_, réac, chsa, _ore_
  { {0xbcfb0152,0xb7360015,0x97da004a,0x37c6002b}},	// [db40] riét, يفرب, рьбу_, زياف
  { {0x9696000d,0xe73a0054,0x07a60033,0xa69601ca}},	//   ореш, јеж_, цазн, ореј
  { {0x442d003e,0xfb37000a,0xbcfb1fcf,0xe61a025f}},	//   _are_, _ואיש_, miér, рде_
  { {0x75460010,0xa50a364e,0x25a90015,0xaa9b000a}},	//   ўндз, реда_, مدني_, _כביכ
  { {0x24800064,0x25a620aa,0xbcfb0030,0xa2a7000b}},	//   çim_, rmol_, tnéz, टेस्
  { {0x442d0e18,0x799610d4,0xdc9b000a,0xe5ca0015}},	//   _dre_, llyw, בינל, _نظره_
  { {0x98a20007,0x41e60033,0x11d80015,0xdce6003d}},	//   _kokį_, ціла, حوبة_, zikā
  { {0xb3ea0015,0x463b004c,0x96d8000b,0xf1aa0015}},	//   _نعطل_, _דעלע, यरवॉ, جاته_
  { {0xb0a4005d,0xc05a0036,0xb4e6005d,0x442d00bd}},	//   खेंग, рій_, पणी_, _gre_
  { {0xf8370008,0xf2a600ce,0xceba00af,0x0000006a}},	//   קנית_, _дизп, шљи_,
  { {0xdd950010,0xb4ab002e,0x2004017b,0xb6bb015b}},	//   заны, _íþró, stmi_, יציי
  { {0xd00a0036,0x7c2d0472,0xdce6003d,0xac191a2f}},	//   _веде_, _prar, tikā, бому_
  { {0x98b30024,0x3e550092,0x4f660015,0xe571000a}},	//   ādīt_, át_, _واتف, תַי_
  { {0x70530018,0xdce60024,0x2d8b1e80,0x8c180015}},	//   _تنها, rikā, soce_, غيّر_
  { {0xbcfb0152,0x2bb7000b,0x6e63006b,0xa9350766}},	//   théd, _इंका, _отъж, певш
  { {0x3f8c0048,0x27f20026,0x98b9009c,0xb9380015}},	//   lodu_, fryn_, слат_, يًّا_
  { {0xe894004a,0x27f20034,0xf7730015,0x6bd70015}},	// [db50] дать, gryn_, واط_, _بتعر
  { {0x4e1e005d,0x8af90054,0x442d0030,0xb9c70015}},	//   _बनाई_, _унос_, _rre_, _وتجه
  { {0x63bb0356,0x672500cb,0x6af40033,0x442d5716}},	//   _suun, rdhj, _юзэф, _sre_
  { {0x442d5717,0x63bb008c,0x6a14002b,0xa4d4008b}},	//   _pre_, _puun, _کبیر, доці
  { {0xbcfb0152,0x493a000a,0x9474002b,0xdb040077}},	//   chée, _הגרו, ودها, _guió
  { {0xfc3f0251,0x77ba000a,0x35fb002b,0x67ba000a}},	//   ixí_, _למשח, _پرسد_, _למשק
  { {0x94d50001,0xa4d50127,0x2d6f0046,0x569416e8}},	//   _новц, _нові, vřen_, _жарт
  { {0xa0090029,0x6b500020,0xdcfd0024,0x8a7c0008}},	//   مقبل_, _vägi, ilsē, יאות
  { {0x24580080,0x69c10089,0xf99400a3,0x442d5718}},	//   _дать_, ílej, ורק_, _ure_
  { {0xf8b8005d,0x9e65144f,0x0e650214,0x72d402ed}},	//   _अल्प, звод, зкон, _жофф
  { {0xc7b4013a,0x22770086,0x3e550016,0xf772000a}},	//   ובץ_, _بلاگ_, út_, תקי_
  { {0x670b005d,0x070b005d,0xe29a0008,0xc1050015}},	//   स्तक_, स्तव_, _השער, _روتي
  { {0x9f350036,0xe1e70086,0x2d6f0046,0x3f8c09df}},	//   _неді, کس_, mřel_, bodu_
  { {0x3b0a0054,0xef1801ec,0x0000006a,0x0000006a}},	//   љево_, ceļ_,   ,
  { {0xc3320008,0xb87b02c1,0x7f3a000a,0xcf92000a}},	//   עול_, _leíd, _לעסו, _רטו_
  { {0x27f2005c,0xa9670178,0xd9431179,0x47c61402}},	//   tryn_, писа_, неси, збав
  { {0x1dd7000b,0xc6d60015,0x27e60003,0x46ea027a}},	// [db60] भीरत, كتات, éon_, йдан_
  { {0xf772003b,0xd7ef0029,0x2ca000bc,0xb7d70015}},	//   راء_, اكل_, _izid_, سوما_
  { {0x7abb0008,0x98a20007,0x3abb0008,0x14ca0080}},	//   _לציו, _tokį_, _למינ, были_
  { {0x35690036,0x6d9d12bf,0xdc56000a,0x3f8c09bb}},	//   орін_, héan, ּסַח_, zodu_
  { {0x999e0091,0x68b7000a,0x3207002a,0xab5b0030}},	//   štų_, _מלכא_, etny_, mpür
  { {0x6703005d,0x421a0029,0xfa76000a,0xd75a0015}},	//   _लायक_, مزعج_, ּעֵת_, _الست_
  { {0x07a3008f,0x6d9d002d,0x3f8c1744,0xeab6000a}},	//   _чарн, déan, vodu_, הִ֤י_
  { {0x867b0008,0x3f8c005c,0xf67b000a,0xc03403ae}},	//   _הרלו, wodu_, _האלמ, дниј
  { {0x7ff60029,0x853b000a,0xb4ca000b,0x3f8c5719}},	//   أسعا, _פגמי, ोरी_, todu_
  { {0x20ec0023,0x74130086,0xe2920029,0x3eb801f0}},	//   ới_, _سوما, _كذا_, ørt_
  { {0x3f8c3469,0x0000006a,0x0000006a,0x0000006a}},	//   rodu_,   ,   ,
  { {0x5bb5000b,0xc5f3000a,0x91bb000a,0xc1bb000a}},	//   ंद्व, עדר_, _המאי, _המאש
  { {0xdb070030,0xe1650058,0x0000006a,0x0000006a}},	//   lmjé, _تدلي,   ,
  { {0x501b000a,0x90530033,0xe457004c,0xde5800fd}},	//   _לודו, _явіц, ליכט_, _малі_
  { {0xf4020011,0x6e9304e0,0xfaa90015,0xdb500015}},	//   luţă_, _пишу, زهري_, دَّ_
  { {0x7e7b000a,0x999900e2,0x8e7b004f,0x4e7b004f}},	//   _לאוז, ікат_, _לנוה, _לאוצ
  { {0x57b51e92,0x5c74006b,0xb8d5000b,0x0000006a}},	// [db70] дбат, _плът, _छः_,
  { {0xb8f4005d,0x64d5005d,0xa03b0053,0x3c78000a}},	//   _स्_, दर्श, זעמפ, _מתחם_
  { {0x74b9006b,0x249f002a,0x2d99571a,0xdb04039f}},	//   оулс_, _szum_, olse_, _guiñ
  { {0xceb3039e,0xa4d5005e,0x7f940144,0x055400ce}},	//   גיע_, фоді, màqu, нтія
  { {0xe4540010,0x74290015,0x2d6f0046,0x6b500123}},	//   нкцы, تكشف_, vřel_, _vägv
  { {0x97350086,0xe7870658,0x883a000a,0x26c5007c}},	//   _تکرا, _хумо, _ותשו, _ülo_
  { {0x6fd5014e,0x2254002c,0xeb920008,0xd56710a1}},	//   _मौजू, _čaká_, כָה_, _етап
  { {0x394b0251,0x65940839,0x3968000a,0xd12e0015}},	//   _jocs_, _засу, ּ֑הּ_, لمى_
  { {0x96e1000b,0x32071d08,0x394b1349,0xee150065}},	//   _फ़ाउ, stny_, _mocs_, तब्ध_
  { {0xbebc0024,0x4ed40036,0x337402e1,0x8e75011d}},	//   ldīj, нюют, _згур, думч
  { {0x7bcd0fec,0x6727007c,0xe1f00067,0x2d6f0046}},	//   _atau, _majj, _مسن_, přel_
  { {0xed570839,0x9055005e,0x31a40058,0x0000006a}},	//   дою_, _овец, _كملف,
  { {0x10080015,0x1c430342,0xf40200d4,0xbebc01ec}},	//   _فتوى_, вням, cuţă_, idīj
  { {0x6d9d002d,0x2d991325,0x6008000a,0xfaa6571b}},	//   léal, alse_, _זִקְ, даго
  { {0x394b0026,0x20180045,0x7bcd001a,0x7ed40015}},	//   _bocs_, ărie_, _etau, _أزها
  { {0xceb2000a,0x2492002a,0x6995008b,0x6d9d571c}},	//   _ביו_, żymi_, ерух, néal
  { {0x60dd002e,0x394b571d,0x66e60a1f,0x3b861673}},	// [db80] ósmy, _docs_, доза, _олиг
  { {0xbcfb002d,0x1bf7000a,0xf8b10015,0x6d4606f2}},	//   mhéa, _קציר_, اةِ_, ljka
  { {0x5b57000a,0xd5b20029,0xe5c50036,0xbb3b000a}},	//   _חייב_, نفط_, есіо, _ועיי
  { {0x6d460844,0xd7ca0015,0x6e2300da,0x6f1a0160}},	//   njka, _ووجه_, _msnb, zetc
  { {0x27760010,0x68e4571e,0xd38a005e,0x64360015}},	//   _жывё, maid, ойде_, براء
  { {0xbebc0024,0x68e4571f,0xd5d60015,0x37e3012e}},	//   adīj, laid, _يتأث, _јорг
  { {0x65c3008f,0xcb13000a,0x2900007c,0xddc8002a}},	//   _абса, דלו_, ogia_, zydł
  { {0x29004412,0x68e45720,0x46a301ca,0x7c245721}},	//   ngia_, naid, _расв, _osir
  { {0xe571011f,0xf9930008,0x73060e44,0xdb1d003c}},	//   _עַל_, כרה_, _опаз, ppsø
  { {0x68e4002f,0x03260036,0xb356002b,0x7f180015}},	//   haid, _іден, _زیبا_, أيدز_
  { {0x36f70008,0x6b5000c0,0x6f1a003e,0x68e45722}},	//   וצים_, _lägs, retc, kaid
  { {0xc0a90074,0x68e40410,0xf1a90015,0xbd6b005e}},	//   _کامل_, jaid, _فانه_, ірне_
  { {0x718b0008,0xe043249a,0xf1c40157,0x394b01f6}},	//   _וְגַ, _инци, _लंडन, _rocs_
  { {0xfe6f0074,0x44244e00,0xd2460067,0xb09b000a}},	//   ادی_, _msm_, هن_, _וידר
  { {0x394b0251,0x68e4002d,0x44240fc4,0x6f79000a}},	//   _pocs_, faid, _lsm_, _מְקו
  { {0xbcfb002d,0x44240089,0x29005723,0x68e45724}},	//   bhéa, _osm_, ggia_, gaid
  { {0x47350010,0xbcfb0003,0xe8d90016,0x7d1d5725}},	// [db90] ннас, chéa, ghề_, mess
  { {0x70bb005d,0x7d1d5726,0x0000006a,0x0000006a}},	//   _उल्ल, less,   ,
  { {0xfad6013a,0x7afa001a,0x8aa70f5c,0x6b500123}},	//   _אותך_, ótte, _юрид, _vägt
  { {0xbebc003d,0x7d1d2dd3,0x68e45727,0xc6a401e1}},	//   udīj, ness, caid, труи
  { {0x94750086,0xf9920135,0xc7c4004a,0x05740015}},	//   رگرا, _תרכ_, _асси, خالد
  { {0x7d1d5728,0xb7da000a,0xcc58000a,0xdcbc0065}},	//   hess, _מקשי, ובדי_, _एल्फ़
  { {0x07a4008f,0x41b50608,0xb607003d,0x44241a13}},	//   _раён, нсит, ugšē, _esm_
  { {0x6562003f,0x8ab8000a,0xc1050015,0xdb0a0046}},	//   choh, ולוג_, روخي, ěnéh
  { {0xa2ca005d,0x27e95729,0x7d1d572a,0x45240015}},	//   _स्क्, nsan_, dess, _جرِّ
  { {0x6b5000c0,0xc7d6000a,0x787a000a,0x3224008c}},	//   _lägr, עותי_, לָיו, äsyä_
  { {0x52380029,0xe7f3000b,0x7d1d0d65,0xd25100c3}},	//   _يسمح_, ेंडा_, fess, _حنا_
  { {0xbcfb002d,0x90e70086,0x8c96017f,0x27e9572b}},	//   théa, _آسان, ергі, ksan_
  { {0xdfd10029,0x636d002a,0x2d9e003d,0x68e4572c}},	//   _صيغ_, eźni, ēte_, vaid
  { {0x68e4000c,0x70760053,0xd335000a,0x0076000a}},	//   waid, _אײנע_, ׂרָה_, _אתני_
  { {0x1d96004a,0xb87b006f,0xbcfb0125,0x7d1d572d}},	//   _приё, _odís, shéa, bess
  { {0x7d1d0d2d,0xb87b0125,0xb8830247,0x7d04572e}},	//   cess, _ndís, klíč, _ucis
  { {0xd7f90036,0xe0d20053,0x68e4572f,0x7d7b000a}},	// [dba0] дує_, טײן_, raid, _מנקו
  { {0x68e4000c,0x3a26017f,0x6b500123,0xd6d20040}},	//   said, _змог, _vägs, اقض_
  { {0xeb9f0134,0xaadb0008,0x8a0600fd,0x27e90049}},	//   ktøj_, _מחיר, _язне, asan_
  { {0x2ee50705,0xd406005e,0x75d30021,0xe596002b}},	//   half_, еяки, اينا, رشاخ
  { {0xb87b001c,0x88bb0008,0x9cd7000a,0x65620012}},	//   _veíc, _מזכי, גונה_, rhoh
  { {0xf4870086,0x08770053,0x7d1d5730,0x54530033}},	//   رانی, _װעלט_, zess, ывіт
  { {0xe1ef0015,0x46a3027a,0xb8830046,0xa22702d9}},	//   مسي_, _барв, alíč, ежја_
  { {0xb6370008,0x7229005e,0xdcef003d,0xc872000a}},	//   _ארלס_, ьців_, rocī, ָן֙_
  { {0x251b0053,0xd007000d,0xd430005e,0xff06005e}},	//   _צומא, еење_, _мiсц, нянн
  { {0xd47b0053,0x636d002a,0x1013002b,0x31a10417}},	//   _זאמל, yźni, ابيد, róza_
  { {0x26c7016f,0xf5aa000a,0x3d05000b,0xdce60091}},	//   žnog_, ּבָּ, _वादे_, likę
  { {0x867b000a,0x91f50033,0x667b000a,0x63ba52ae}},	//   לריו, _шчуч, לטיק, _hitn
  { {0x7c84017a,0x7d1d5731,0x0ca80fac,0xdfcf0058}},	//   гуре, ress, етри_, _هين_
  { {0x99d70029,0x7d1d5732,0x9e140033,0x5b240323}},	//   فترا, sess, _адкі, льса
  { {0xe3b30053,0x539b000a,0x7214000a,0x7d1d5733}},	//   טױש_, פילו, כַּב_, pess
  { {0x0e9b0008,0x5e9b000a,0xfe9b000a,0x7e9b000a}},	//   _משול, _מבוק, _מיומ, _מסוו
  { {0x60dd002e,0x718b000a,0x6b500123,0x27e9127c}},	// [dbb0] ðsmi, לְמַ, _vägr, usan_
  { {0x501b000a,0xb8940015,0xb8830046,0x27e932eb}},	//   הומו, الْع, vlíč, rsan_
  { {0xf7480029,0x27e95734,0x3a74004a,0xa6ab0015}},	//   علمي_, ssan_, _блэр, سائق_
  { {0x7ae712d7,0x15f40015,0xc4f80015,0xa3d50088}},	//   lajt, اسلح, فعها_, водч
  { {0x24580010,0x2fc0002d,0x63ba0263,0xd6db1c7d}},	//   наць_, _éigh_, _bitn, _нтв_
  { {0x7ae70e9f,0x39492b60,0xe299427e,0x6824004a}},	//   najt, ljas_, мал_, _сьюз
  { {0x629a4ef2,0x05770029,0x63520180,0x6262004a}},	//   _cyto, _كارد, рвју, ивша
  { {0x569417b7,0x7ae73fa2,0x753b0061,0x3d20000b}},	//   _саст, hajt, _unuz, _बसें_
  { {0x7ed50036,0x386902c1,0x60060080,0x3fe20010}},	//   кінч, nzar_, вным_, ажыв
  { {0x23b50086,0x63ba0035,0x7ae70796,0xd347002b}},	//   _شماس, _gitn, jajt, _سیبه_
  { {0xa2ca005d,0xfe710015,0x7ae75735,0x6d5f0091}},	//   _स्ट्, شدد_, dajt, _įpar
  { {0x2127002b,0x6e3c0123,0xbc1a0033,0xed5a13d0}},	//   _سيتی_, årba, мігі_, фом_
  { {0xa0c40015,0x4c83005e,0x5d67004a,0x0c230033}},	//   _إيهو, илюв, тиям_, амян
  { {0x7ae700bd,0x93fa000a,0xda660015,0x207a004c}},	//   gajt, ולשי, نازي, _קאסא
  { {0x1ae30080,0xbcfb0152,0x49961032,0x200d5736}},	//   росм, chéo, вшат, ltei_
  { {0x6d96001a,0x9627003d,0x0000006a,0x0000006a}},	//   ráas, ieņē,   ,
  { {0xcc8a0086,0xa6e70016,0xcd97000a,0x7ae704a6}},	// [dbc0] _زنده_, _thừ, _בדקת_, bajt
  { {0x7bfb013a,0xcb6a0074,0x44380089,0x1bfb000a}},	//   _קפיצ, _آمده_, _čr_, _קליב
  { {0xd2450086,0xcf92000a,0xb87b0077,0xf50a0004}},	//   _اچ_, סטב_, _veía, днел_
  { {0xceb20008,0xd2520086,0xf769000a,0xd910002b}},	//   ביב_, ینش_, חק_, _دیر_
  { {0x1427005e,0x93aa0015,0xe6c60015,0x938a053b}},	//   віщо_, واتف_, _لتزي, мска_
  { {0xfbd3000a,0xe71a0015,0x232703ae,0xe3af00c3}},	//   סתו_, _تيست_, вољи_, يرو_
  { {0xd5b20196,0xdd020089,0x2912003f,0x63ba22af}},	//   _نفس_, ítěz, ofya_, _vitn
  { {0xc05a0036,0x63ba003e,0x2d54016e,0x629a0046}},	//   діо_, _witn, _mães_, _vyto
  { {0x50b7002b,0x63ba0091,0x20030015,0x629a002a}},	//   پديد_, _titn, لِيِ, _wyto
  { {0x7d160089,0x63ba049c,0x9f53004a,0x629a002a}},	//   _abys, _uitn, ивыч, _tyto
  { {0x7d1b007c,0x200d3bbc,0xee20005e,0x602f0030}},	//   õuso, atei_, щенi_, tőmö
  { {0xdb16002e,0xc69300f3,0x11e90058,0x0000006a}},	//   _styð, יאת_, _أعلي_,
  { {0x7ae75737,0xed580010,0xc173000a,0x6d9d571c}},	//   tajt, тоў_, _דחף_, néai
  { {0x69c300dc,0x3e340015,0x9e660015,0xceb80091}},	//   _ének, _مفتر, _لابن, udęs_
  { {0xe9190036,0xfb840010,0x7c360026,0x6d96002e}},	//   нові_, рыян, _eryr, ráar
  { {0x386908e0,0x3f9e4e43,0xac550029,0xa2a7000b}},	//   tzar_, lltu_, _منبث, टेट्
  { {0x0c740086,0x394917df,0x9715239c,0x4d740015}},	// [dbd0] _پديد, rjas_, лмац, _خطور
  { {0xf7700115,0x3949007c,0x38695738,0x7d160bba}},	//   يال_, sjas_, rzar_, _zbys
  { {0x3869005c,0x3a8404ab,0x5a470033,0x3f9e001a}},	//   szar_, _выяв, _рэпа, iltu_
  { {0xa8a70033,0x04c90015,0xe0df0016,0x6d5d5739}},	//   _аргк, روتي_, ưòi_, nksa
  { {0x7ae50005,0x2489001c,0x69c5003f,0xa988000a}},	//   _keht, çam_, _huhe, _יָשִ
  { {0xb4640036,0x59da005d,0x420940bd,0x0000006a}},	//   шкіл, यीकर, енко_,
  { {0x69c50020,0x96f80054,0xe2150015,0xe296573a}},	//   _juhe, _јест_, ابتع, лаш_
  { {0x32160086,0x3abc0008,0x62320054,0x7ae5573b}},	//   اييد_, ומונ, сећу, _leht
  { {0x6d9d002d,0xd00e0015,0xbd04005a,0x0000006a}},	//   céai, كلي_, nkéř,
  { {0xd25b0098,0x200d573c,0x6d5d573d,0x7ae5005a}},	//   _оце_, rtei_, eksa, _neht
  { {0x200d04f9,0x1d0a0063,0xf2040010,0xdce4002a}},	//   stei_, нени_, _вячо, _zmię
  { {0x200d0045,0x6abe000b,0x92580248,0xd5b2004f}},	//   ptei_, ्ड्र, _шахт_, ֶׁם_
  { {0xff530086,0x3af60342,0x60db4bdb,0xbcfb573e}},	//   _پخش_, лявс, mbum, chém
  { {0xdfcf0074,0x3ffa000a,0xdee50098,0x6d5d573f}},	//   _هيچ_, _נפצע, _соки, ërar
  { {0x64590034,0xd93a00af,0x0000006a,0x0000006a}},	//   hywi, нчаш_,   ,
  { {0x98a9002c,0x2489002a,0x6d5d5740,0x98a00085}},	//   adač_, żamy_, cksa, ndić_
  { {0x999e00dc,0x59c0000b,0xccf3000a,0x980a0015}},	// [dbe0] ítő_, _शंकर, _הכח_, عترف_
  { {0x6459005c,0x9b460015,0xab2a0054,0x78a6005a}},	//   dywi, _إندو, _џона_, _vzkv
  { {0x9bb70008,0x75d30029,0xceb2004f,0x0000006a}},	//   _תהיה_, ميلا, ֖יב_,
  { {0x64590026,0x4a7b0643,0x7a7b000a,0x5693005e}},	//   fywi, _טריב, _טריס, щаєт
  { {0x4d7b00b2,0xbebc0024,0xdcef0045,0x33f6096d}},	//   ערנע, ldīt, lică, учес
  { {0xf8b3000a,0xf79a0015,0x3716000a,0x53341411}},	//   _לשר_, _أنسب_, _עַ֚ל_, рект
  { {0x3d05005d,0xa79b0008,0xed610107,0x51f30021}},	//   _वाले_, _נשלח, ážky_, مسير
  { {0xbcfb0152,0x41c300e6,0xbebc0024,0x9f4d008c}},	//   thém, حقيق, idīt, hreä_
  { {0xa3cb005d,0xc953000a,0xdb0e016e,0x79840034}},	//   _रूप_, ממה_, ambé, iniw
  { {0x66e4005d,0x30170029,0x141b01ac,0x441b004f}},	//   गरिक_, اتية_, _אומב, _אומס
  { {0x3eb8124b,0x977b004f,0x59b40065,0x7ae5005b}},	//   ärt_, תריה, ंगार, _reht
  { {0x4426005c,0x69c500b8,0x68e60820,0x5c075741}},	//   owo_, _ruhe, _nekd, ляга
  { {0x5c070010,0x55770053,0xfc64006b,0x6d5d5742}},	//   ыяна, רעכן_, бърн, rksa
  { {0xdcef04f9,0x69c5022d,0x0703000b,0xaed4009b}},	//   fică, _puhe, _लाइव_, _токш
  { {0x8e370086,0x6459005c,0xe6e1000b,0xab5b016e}},	//   _مسير_, zywi, _फ़ौज, nqüi
  { {0x4426003f,0x78d5006b,0x58d52d90,0x09d40033}},	//   kwo_, ржах, роат, сцёў
  { {0xed580008,0x7ae509e7,0xb6060085,0xbebc003d}},	// [dbf0] _תבחר_, _teht, _lišć, adīt
  { {0xf7730029,0xe8740115,0x98a0002a,0x4426002a}},	//   حار_, حافظ, ndię_, dwo_
  { {0x57a4034e,0x9f4b0030,0xe4d500c3,0x4426002a}},	//   сшта, écé_, لقاد, ewo_
  { {0x60c25743,0x25f80015,0xb9350004,0xbebc003d}},	//   _ngom, اءلة_, _темј, ldīs
  { {0x0d160053,0xbcfb0003,0x6d8c000a,0x99a50030}},	//   יקײט_, ckée, עָבְ, _ütők_
  { {0x64595744,0x57fa0008,0xe3b30015,0xb779004c}},	//   rywi, _בלשו, حرص_, _יאָש
  { {0x8b58000a,0x45d4004a,0xe8d90016,0x6618006f}},	//   ריוס_, _госс, ghệ_, čaká
  { {0x8505002b,0xfa78000a,0xdb1c0030,0x41b20058}},	//   _خورن, טעות_, _özön, يمور
  { {0x8467010f,0xbfc2004a,0x60db5745,0xbcfb0030}},	//   _съве, обык, rbum, kkéb
  { {0x2f5500d0,0x889c0053,0xa858000a,0x9f050015}},	//   ртис, עבזי, טיחה_, جودو
  { {0xc2c40074,0x2fc60026,0x79840026,0x8d760002}},	//   _ايمي, _euog_, yniw, لاحا
  { {0xa3a9000b,0x9c660015,0xa696000a,0x318c0046}},	//   _गीत_, لهجو, יכתה_, těze_
  { {0xe50d000b,0x6ea1000b,0x515a000a,0xa3cb000b}},	//   _हानि_, _ऑरकु, _שכנו, _रूम_
  { {0x98a2005c,0x60c20045,0xa2d8000b,0x5f770015}},	//   _jaką_, _zgom, नुप्, _حاصر
  { {0x09e60f22,0xbebc0024,0xb976000d,0x0f7a0135}},	//   робн, udīt, аѓањ, _ברסל
  { {0xdcef0045,0x3c460015,0xdb0701d3,0x44265746}},	//   rică, _نَبِ, rmjá, ywo_

  { {0x7c950033,0xa6e602db,0x0000006a,0x0000006a}},	// [dc00] _грэц, ижал,   ,
  { {0x7c290064,0xfc5b000a,0xdb24002b,0x75d60058}},	//   çere, _סכימ, _اودی, ليطا
  { {0x5afb00b2,0x59a7000b,0x8afb0447,0x49ba0015}},	//   _בליצ, _कीवर, _בפיק, _لاحد_
  { {0xe45a005f,0x44260050,0x75d30086,0x25d90086}},	//   кже_, two_, زيها, اهنگ_
  { {0xa5330010,0xd90d002b,0xf8db000a,0x24070076}},	//   ўніч, _سیل_, _בחכמ, инци_
  { {0x21f40015,0xd36f0015,0x82360015,0x60c202b9}},	//   مكتس, وهن_, لرعا, _sgom
  { {0x63030029,0x25bf0011,0x661c016f,0xc2e90015}},	//   زويل, _fiul_, _uprk, اعهم_
  { {0x25d7000a,0x98a7002a,0xbcfb01c0,0x0000006a}},	//   _כולן_, śną_, chéh,
  { {0x7f9d0152,0xa4fb0008,0x34fb000a,0xb4fb000a}},	//   hèqu, _שלמט, _שהמד, _שלמר
  { {0x38170008,0x200b0251,0xf776000a,0x3f13005e}},	//   סקים_, àcia_, יעִי_, одьс
  { {0xb7370053,0x0737000f,0xd737000a,0xfe6f0058}},	//   בריװ_, באים_, בטית_, ِدُ_
  { {0xc27b000a,0xc2550015,0x61431208,0x0000006a}},	//   _ברבי, _اخْت, _меха,
  { {0xd007010f,0xff4f002b,0x7173002b,0x9f34008b}},	//   _вече_, سخی_, _بهنا, _гелі
  { {0x27170089,0x2004144e,0xdb230061,0xbebc003d}},	//   _mění_, mumi_, _örün, udīs
  { {0xda35004a,0xa924006f,0xaa5401ca,0x20045747}},	//   щевы, _žľaz, оврш, lumi_
  { {0x4dd30015,0x644d008c,0xdebb000a,0xb8d7002b}},	//   _بتوس, äaik, _במול, شترش
  { {0xb6c74fba,0x2d995748,0x38340f5c,0x27d90033}},	// [dc10] асей, mose_, онтр, удзь_
  { {0x7c2d0e8a,0x96f80021,0x2d995749,0x3ce901f9}},	//   _isar, لعمر_, lose_, _heav_
  { {0x2004003f,0xf7700029,0xcf9300f3,0xfb1c000a}},	//   humi_, ذاك_, קטע_, _יוזמ
  { {0x20042109,0x7b2d0053,0xe57000e6,0x2d99574a}},	//   kumi_, פֿונע, وطن_, nose_
  { {0x20040048,0xb8dd005d,0x68ed0020,0x48ab000d}},	//   jumi_, ेख_, maad, _штом_
  { {0xc5fb0029,0xb5c900e6,0x68ed574b,0x28b6000a}},	//   _لعرض_, _موسم_, laad, _לפרש_
  { {0x926b006b,0x2d99574c,0x6d9d0003,0x7d0d31fc}},	//   ърда_, kose_, néas, _ocas
  { {0x2d990007,0xf5e4017f,0xbcfb002d,0x7c2d0913}},	//   jose_, _фірм, bhéi, _osar
  { {0xf94a00b2,0x656b002d,0x249f0064,0x98a2005c}},	//   רעפֿ, mhgh, _uyum_, _taką_
  { {0x442d48e7,0x1f650724,0x7d0d574d,0xb5f9000a}},	//   _ise_, ском, _acas, ְלָכ
  { {0x68ed0020,0xed5a268f,0xc2bb0015,0x7c2d574e}},	//   kaad, гон_, _شاطئ_, _asar
  { {0x01340029,0x2d990007,0xc27a000f,0x6366001a}},	//   _وعند, gose_, _גרעי, _iðna
  { {0x68ed0020,0x29f30085,0x67250789,0x442d24ac}},	//   daad, eća_, kehj, _jse_
  { {0xb47a0053,0x4fd60008,0x1dcf005d,0x66050375}},	//   אָלי, _הוסב_, _संपत, kuhk
  { {0xdf740086,0xa96a006b,0xfaa60033,0x2d993a0c}},	//   _بدنب, гива_, саво, bose_
  { {0x75c50007,0xfdf6000a,0x442d574f,0x08c62797}},	//   _jėzu, _המקש_, _ose_, сбан
  { {0xdb1e002f,0x6d9d0003,0x65a3007c,0x6d445750}},	// [dc20] _lipé, réat, põhj, _inia
  { {0x672502de,0xa088004f,0x0000006a,0x0000006a}},	//   gehj, בְעִ,   ,
  { {0x6d560064,0xceb20008,0x3bbb000a,0x2608000b}},	//   _koya, ִיד_, _תמיד, ांधी_
  { {0xe4e30036,0xbcfb002d,0x69dc0fb7,0x1514005e}},	//   пішн, théi, mpre, ідля
  { {0x69dc5751,0x59830239,0x7d1b007c,0x250b002b}},	//   lpre, _хляб, õusi, ارمی_
  { {0x20040024,0xe1d80010,0x66050213,0x27f20f47}},	//   vumi_, адкі_, buhk, msyn_
  { {0x442d0467,0xd5d8000a,0xa5d8000a,0x11d80015}},	//   _ese_, _כַּש, _כַּי, جوبة_
  { {0xf126129a,0xdfd00070,0x6d9d002d,0x865b000a}},	//   сько, ويب_, héar, _גדלי
  { {0xa4940074,0x70540086,0x27f202cd,0x6fb400c3}},	//   _بیشت, زندا, nsyn_, يمبا
  { {0x543b00b2,0x08570008,0x6d44130f,0x68ed0030}},	//   _געמא, צבים_, _ania, zaad
  { {0xa3e4005d,0x179b0053,0x2d990007,0x69dc0559}},	//   भीर_, רייב, tose_, jpre
  { {0x2d990007,0x27f200f2,0x3ea20024,0x2eec003f}},	//   uose_, ksyn_, ākt_, sadf_
  { {0x68ed0020,0x6d44005c,0x2d995752,0x6d560bc7}},	//   vaad, _dnia, rose_, _doya
  { {0x2d990007,0xab87005e,0x7aee0012,0x69dc0012}},	//   sose_, сумк, gabt, fpre
  { {0x2d990376,0x61f8000a,0x656201be,0x6dd40015}},	//   pose_, יִּג, kkoh, _بقبض
  { {0x6d9d002f,0x984b006b,0x5ea30015,0x6d44002a}},	//   réas, ляза_, _عميل, _gnia
  { {0xb8d1014e,0x47d50029,0x6d9d002d,0x69dc0796}},	// [dc30] _ओर_, زيار, béar, apre
  { {0x66050665,0x68ed0d11,0xcdd4000a,0xd6ab002b}},	//   tuhk, saad, ַךְ_, هدام_
  { {0xa53500fd,0x69c8006f,0x656b0125,0x442d5753}},	//   жнеч, ídet, thgh, _sse_
  { {0xe7ed000b,0x47d50015,0xd1260067,0x85040015}},	//   _चौथा_, _ويجر, _غم_, كومن
  { {0xe3b10002,0xd006012c,0x6605007c,0x437500ce}},	//   ورت_, _تل_, suhk, жуйт
  { {0x442d018c,0x66050020,0x889a0008,0x31b3000b}},	//   _vse_, puhk, _כברי, ुद्ध
  { {0x93940015,0xa4d50033,0x94d500ce,0x0000006a}},	//   أجنا, _мові, _мовц,
  { {0x3495070e,0x4a7c000a,0x7a7c000a,0x89ec000a}},	//   _дабр, טרוב, טרוס, רַגֵ
  { {0xe4540010,0x442d07cc,0x6d560493,0x5f750015}},	//   _екты, _use_, _roya, قادر
  { {0x2d8b0014,0x6d560064,0x6fb20015,0x7f740033}},	//   ében_, _soya, وميا, зуюц
  { {0xd12e002b,0x2f54005e,0xc579000a,0xddc50fea}},	//   رمی_, їтьс, ֹרָת, юбни
  { {0x69dc018c,0x75350053,0x35d0005d,0xf532000a}},	//   vpre, קאָד_, _तूफ़, ֵ֥ר_
  { {0x9f350036,0x316d00dc,0x6d5619b0,0x5f75012c}},	//   _меді, mhez_, _voya, _واتر
  { {0x316d00dc,0x3b0a0054,0x69dc5754,0x9f3400ce}},	//   lhez_, јево_, tpre, _нечі
  { {0xa3cb005d,0x497a0010,0xbcfb00dc,0xe1e70067}},	//   _रूस_, асаў_, mkén, بس_
  { {0x316d00dc,0xdce40a05,0x38c8002b,0xbcfb0030}},	//   nhez_, _klič, صاری_, lkén
  { {0x3ff90053,0x06ea0001,0x69dc5755,0x316d0030}},	// [dc40] יפּע, имак_, spre, ihez_
  { {0xbf870023,0xbcfb0014,0x316d00dc,0x99d60021}},	//   _điện_, nkén, hhez_, _وتجا
  { {0xdd8f0074,0x201804f9,0x316d0014,0x6719005d}},	//   _سوی_, ării_, khez_, न्धक_
  { {0x96da000b,0x16aa000b,0x394f0123,0x6562007c}},	//   _प्रॉ, _करीब, ögst_, ukoh
  { {0x6b9c016b,0xbcfb0030,0x316d0030,0xeb9f063b}},	//   oorg, kkén, dhez_, brød_
  { {0x47c3010f,0x69c30152,0x65620356,0xcc3b0053}},	//   _обяв, _éner, skoh, יענט
  { {0xe1ef0029,0x416a0001,0x79fa000a,0xbcfb0030}},	//   نسي_, ијим_, ׁלַח, dkén
  { {0x316d38c8,0xdced0085,0xf3da0021,0xc95a000a}},	//   ghez_, _imać, _نورث_, יכֶם
  { {0x7f4a0036,0x6b9c00c0,0x60f70033,0xe5a306a6}},	//   аїна_, korg, цныя_, _цити
  { {0x25a60026,0x5457000a,0xbcfb0030,0x7879000a}},	//   llol_, _וסמן_, gkén, מָתו
  { {0xe8a7005d,0x52860029,0x7054002b,0x4d99005e}},	//   _खर्च, _بلاك, زنگا, йкою_
  { {0xd1300086,0x3d270036,0x316d2c80,0xe611000a}},	//   _سمت_, цьов, chez_, עִי_
  { {0x41770015,0x0cab080e,0x6b9c5756,0x55bb004f}},	//   _بمنح_, ртни_, forg, ימטו
  { {0xa3b0005d,0x99d70029,0xdf370015,0x7bdd003d}},	//   _टीम_, قترا, _وكنت_, rpsu
  { {0x0eba0010,0x6edb000a,0xda340174,0x7ed30058}},	//   _туды_, _דחופ, меры, _غزوا
  { {0x65a30020,0x9bf5006b,0x26c7006f,0xac95008b}},	//   põhi, _езич, ľnom_, _найш
  { {0x26c70e9f,0x58050015,0x6b9c5757,0x69c800e1}},	// [dc50] žnom_, ثوذك, borg, íder
  { {0x5a47008f,0xb902005d,0x97a702e1,0x57b4005e}},	//   _дэма, _न्_, ірал, дбут
  { {0xcb120008,0x8f9b000a,0x61e80034,0x9b940058}},	//   _אלי_, סיבי, _nwdl, _تشيش
  { {0x8aa40010,0x05740087,0xc4f80015,0xe4b90033}},	//   _юрыд, واند, قعها_, блеі_
  { {0xb4270029,0x14190029,0x7bc52bb7,0x44270115}},	//   تعاو, صيغة_, _kihu, تراف
  { {0xd8ba0008,0xc5db0029,0xdb0e0125,0x7bdc015b}},	//   _לצרכ, _نظرا_, ombá, סקוו
  { {0xdce41007,0x316d00dc,0xdcf60046,0x7afa001a}},	//   _slič, thez_, _smyč, ótti
  { {0x657b003f,0x6b9c5758,0x7bc504f6,0x65690046}},	//   _umuh, zorg, _lihu, _uleh
  { {0x44395759,0x7ff50029,0x22950086,0xbcfb00dc}},	//   _és_, أسبا, _کلاس, tkén
  { {0x316d0014,0x3959273c,0x2d8b0493,0xe80c000b}},	//   shez_, _loss_, ence_, िंता_
  { {0x6b9c0a83,0xada6006b,0xbcfb0030,0x316d0030}},	//   vorg, занл, rkén, phez_
  { {0xbcfb575a,0xb6ab0010,0x3236000a,0x443f575b}},	//   skén, ымiн, _מטען_, _kru_
  { {0x212a0086,0x98a70089,0x160d005d,0xbcfb0030}},	//   _دينی_, ěně_, ांडर_, pkén
  { {0xd00e003b,0x00560008,0x703a0053,0x26c7016f}},	//   _صلى_, _משנת_, _לײנצ, žnoj_
  { {0x0a390080,0xbea2182e,0x7bc50509,0x6f7a000a}},	//   очты_, _пашк, _dihu, _לְהו
  { {0x39460467,0x7d1b007c,0xc9aa0033,0x65aa01c0}},	//   ños_, õust, ёвае_, výho
  { {0x2bd80086,0xfc320015,0x3b0a03ae,0xa806575c}},	// [dc60] _بابک_, _أحب_, _лепо_, язал
  { {0xe6c60029,0x2d82575d,0xeb0602ed,0x7c24059d}},	//   ستطي, like_, _эпоп, _ipir
  { {0x443f0020,0x6b5b000a,0xbcfb0003,0xa96a002b}},	//   _aru_, _הדיפ, phét, _همدم_
  { {0x994a0029,0xe6930115,0xe80c000b,0x2d82575e}},	//   _الحل_, رلند, िंदा_, nike_
  { {0xdce60048,0x27ee02d5,0xe803005d,0x19bb000a}},	//   dokļ, álně_, _लिया_, _למטב
  { {0x27e00d25,0xfbd30008,0x8c1b039e,0xeb92000a}},	//   mpin_, עתו_, מוני, ךָ֔_
  { {0x443f09f0,0x2d82007c,0x2d8b002a,0x26ca575f}},	//   _eru_, kike_, ynce_, _igbo_
  { {0x8a17000a,0xb3ca004a,0xdc3f0045,0x66030046}},	//   לחצו_, _глаз_, nţăr, ánke
  { {0xb4660010,0x50660010,0xc05a017f,0x2348002b}},	//   _экал, ятка, сій_, _وسطی_
  { {0x138a0029,0x9df8000d,0xdf780036,0x69c65760}},	//   _اخرى_, онот_, ібні_, _like
  { {0x69c6022d,0x7bcd0007,0xdd950010,0xb2261ce2}},	//   _oike, _suau, даны, _хмел
  { {0x160d014e,0x06570008,0xa2250015,0x442401c2}},	//   ांतर_, פיכך_, _تركه, _kpm_
  { {0x7bc50020,0x7c670015,0x6ca70033,0x39590bbc}},	//   _pihu, ساحل, ярож, _ross_
  { {0xddda0014,0x7fb80086,0x60bb0008,0xe08500a2}},	//   sztő, _بهتر_, _הצדד, _تجمي
  { {0x8f1b000a,0x9f37000a,0x98a9002a,0xf96b0033}},	//   _הוות, _מנגד_, odać_, брай_
  { {0xfc4a0089,0x2492005c,0x6da40180,0x3f9e1164}},	//   _spíš_, żymy_, _пија, lotu_
  { {0xa2bc014e,0x69c60849,0x7d7c000a,0x2cfb000b}},	// [dc70] षेत्, _dike, _לנהו, ्लील_
  { {0x3f8c002e,0x3f9e5761,0x69c62043,0x9f44006f}},	//   nndu_, notu_, _eike, esmú_
  { {0xda670225,0x26070033,0x395900da,0x6d401d2c}},	//   _رادي, ячаг, _toss_, ômag
  { {0x443f00d9,0x3f9e0bf6,0xa4d400ce,0x984b009b}},	//   _pru_, hotu_, еоці, _ляга_
  { {0x98ab0440,0x24090191,0x3f9e0024,0x493a000a}},	//   _dacă_, інки_, kotu_, _וגרו
  { {0x8c1c01ac,0x5c38000a,0x2d822f84,0xdc6c000a}},	//   צווי, פרון_, zike_, מ֣וֹ
  { {0x98ab0011,0x3f9e0024,0xeab7000a,0x64405762}},	//   _facă_, dotu_, הִ֗י_, _ermi
  { {0xd179008f,0xe5340010,0x636f0595,0x316b002a}},	//   ўскі_, _песь, _sønd, ócz_
  { {0x7c2901e2,0x798d0035,0xd00e0015,0x3f8c001a}},	//   çerl, inaw, للي_, fndu_
  { {0x3f9e0024,0xd00e002b,0x752b0030,0x0e650248}},	//   gotu_, گلی_, legz, дкон
  { {0x442f0176,0x140d000b,0x7d1d0012,0xa2a4000b}},	//   lwg_, _समुह_, ffss, _चुप्
  { {0x27e000f2,0xd00e0086,0xf8bf000b,0x98bf000b}},	//   ypin_, دلی_, ्शाय, ्शाए
  { {0xe6aa000b,0xbcfb5763,0x3f9e5764,0x2d825765}},	//   _कर्ज, ckém, botu_, rike_
  { {0x69c60014,0xe80c000b,0x20180045,0x2d825766}},	//   _sike, िंसा_, ărit_, sike_
  { {0xc332013a,0x69c60fb2,0x8d760015,0x5ea50015}},	//   כום_, _pike, _يابا, _تمثل
  { {0x140d014e,0x2d95008f,0x1d950010,0xc9aa0010}},	//   _समूह_, _прыс, _прыё, івае_
  { {0x2fc75767,0x3cfb000a,0xacfb000a,0xbcfb0003}},	// [dc80] _king_, _ולפנ, _והפכ, phér
  { {0x3b830323,0x798d02f2,0x2fc726d0,0x4424225c}},	//   _альг, anaw, _jing_, _rpm_
  { {0x8f9a000a,0x7afa001a,0x44245768,0x962a0015}},	//   קיעי, óttu, _spm_, تكاك_
  { {0x34aa0054,0x2004006f,0xc48638ff,0x27e05769}},	//   овео_, yrmi_, млек, ppin_
  { {0xd24f0074,0x3f8c0084,0xf4870086,0x0000006a}},	//   ینه_, yndu_, واهی,
  { {0x33940010,0x2fc72028,0x2377002b,0xcc77000a}},	//   эалё, _ning_, ومند_, וגנת_
  { {0x3f9e576a,0x2eee00cb,0xdb0e02ad,0x98ab00d4}},	//   votu_, _reff_, mmbä, _tacă_
  { {0x60f80063,0x442400d9,0xc03400d7,0x867b000a}},	//   чния_, _tpm_, ениј, _ורלו
  { {0x3f9e4f7c,0x185b004c,0xf202000b,0xe58f0125}},	//   totu_, ַכטע, रूज़_, _úsáí
  { {0x798d005c,0x6d410024,0x836a0015,0x2d800003}},	//   znaw, ēlam, _بصرف_, _amie_
  { {0x3ea70026,0x3f9e0a78,0xa3bd000b,0x82660015}},	//   _cynt_, rotu_, ीआर_, _تهان
  { {0xbcfb0030,0xdd910015,0x28de0157,0x7d1d02ad}},	//   mkék, اوح_, _फ्लि, ufss
  { {0xb87b0014,0x91bb000a,0x2fc70012,0xfcab0015}},	//   _leír, _ומאי, _fing_, تادو_
  { {0x2fc7237b,0x798d002a,0x752b0030,0x0a6b04bb}},	//   _ging_, wnaw, zegz, орби_
  { {0x8fa30001,0x3ea7576b,0x4379000a,0x5e440015}},	//   _шаље, _gynt_, פְשׁ, _أَعْ
  { {0x69da002f,0x3dfb000a,0x8dfb000a,0x798402f2}},	//   ítea, _ולהד, _וההת, giiw
  { {0xdce60091,0x57b52354,0x798d0b13,0x5d8400c3}},	// [dc90] eikė, ебат, rnaw, _جليل
  { {0xb87b00dc,0xc017000a,0xa5f90033,0x798402f2}},	//   _beír, וקמו_, зежу_, aiiw
  { {0x7af50030,0x4a750015,0xfc3f1279,0x0000006a}},	//   mazt, _أُجر, lví_,
  { {0xa4d50191,0xceb300f3,0xe5730015,0x46df000b}},	//   ході, דיע_, خطط_, _प्रह
  { {0x24580010,0xd0060225,0xd8da000a,0xc8da000a}},	//   маць_, _حل_, _מקרר, _מקרט
  { {0x442f0026,0x35fb002b,0xb375002b,0xa5f90054}},	//   rwg_, _ورزد_, رگذش, _негу_
  { {0x91710092,0x7c3a0024,0xd2510002,0x2fc729da}},	//   _nợ_, ātri, انع_, _ring_
  { {0x690c000a,0x2fc71455,0x20550e41,0xfc3f005a}},	//   ַּחְ, _sing_, етор, kví_
  { {0x4419000a,0xbcfb0046,0x2fc7576c,0xb91a004f}},	//   _מוּס, akék, _ping_, הֵיט
  { {0xa2270015,0xf772004c,0xbcfb0046,0xa3d4000b}},	//   _يراه, ָקט_, lkéh, _संत_
  { {0xa90f000b,0x29c70034,0x8cc2000b,0x0ea90195}},	//   िलाफ_, _rŵan_, रेनो, якой_
  { {0x2fc7003e,0x20020007,0xc69200a3,0x2519000a}},	//   _wing_, škia_, ראט_, הוֹא
  { {0xf539002c,0xe572000a,0xa2c7000b,0x3ea70034}},	//   _mať_, רַת_, ाशक्, _wynt_
  { {0x212d01c2,0x547a004f,0x3ea70c4e,0x0000006a}},	//   leeh_, לטרו, _tynt_,
  { {0x3f8500e8,0xda660087,0x0000006a,0x0000006a}},	//   milu_, راسي,   ,
  { {0xe9a30033,0x8e740004,0x394b0016,0x2d80002a}},	//   гасп, _јушч, _cncs_, _umie_
  { {0xcc36003b,0xa3cb005d,0x3207005a,0xbcfb0de4}},	// [dca0] _أربع, _रंग_, hrny_, dkéh
  { {0xdce60007,0x8c1b000a,0xdc37004f,0x0000006a}},	//   tikė, _צויי, _טאפט_,
  { {0x9b17000a,0x0d3a000a,0x6d3a000a,0x69de0795}},	//   _אחיה_, ּגְב, ּתְנ, _utpe
  { {0xd9100086,0x66031a4b,0x3f85003d,0x89db004f}},	//   _خیر_, ánka, hilu_, _מחטי
  { {0xd4673aba,0xf539002c,0xd90d0086,0xdce60091}},	//   нице_, _dať_, _ذیل_, sikė
  { {0x68f60064,0x37760033,0x23370033,0xdced003d}},	//   layd, _чымс, епшы_, _skaļ
  { {0x3f8500bd,0xb97a009d,0xcb130008,0xf41f00f2}},	//   dilu_, ּנִי, אלו_, _ään_
  { {0x361b0008,0x46a30001,0xbcfb0107,0x7c290061}},	//   _מולד, _сасв, ckéh, çerk
  { {0x59d2014e,0x200d016e,0x91710016,0x318c0046}},	//   _दूसर, guei_, _sợ_, nězi_
  { {0x987b0008,0x23fb000a,0x6710000b,0x3207002a}},	//   פריק, _מהמא, ालिक_, brny_
  { {0x539b000f,0x4e8a004a,0xce94006b,0xf2cc000b}},	//   _ציבו, ящим_, танъ, ाशीघ
  { {0xfc3f02d5,0x9f5f002e,0xc693000a,0x3f85003d}},	//   tví_, stuð_, טאת_, ailu_
  { {0x69da00dc,0x5b270033,0x68f60061,0x3f853bdf}},	//   íten, ньва, dayd, bilu_
  { {0xdb1e0030,0x5fdb000a,0xfc3f5157,0xbf130040}},	//   _pipá, _צחוק, rví_, _موهب
  { {0x7ed50036,0xe919005e,0xf993002b,0xda090015}},	//   _річч, мові_, هبر_, ظيره_
  { {0x6c850029,0xad270015,0x9db90058,0x9e370058}},	//   _للعم, _أرثو, _تهبط_, _أسوء_
  { {0xa8980124,0x6d4d2d6a,0x7ce80008,0x98170015}},	// [dcb0] екту_, _inaa, _אַתֶ, عبرا
  { {0x81bc0024,0x600b000a,0x7641001a,0x69b30065}},	//   _spēl, לִבְ, _ályk, _आठवी
  { {0xf6530029,0x4b7c000a,0x8f9b000a,0xa615004a}},	//   دئذ_, _מאזו, לימי, тмеч
  { {0x96b8002b,0x64cb000b,0x3f8502d8,0x32070417}},	//   رالز_, िशेश, zilu_, vrny_
  { {0x58870010,0x9cd8000a,0xa3b90021,0x79a2002a}},	//   _чына, גודה_, واتر_, ływó
  { {0xa3bd005d,0xbcfb0107,0x9f5f2ea8,0xda8b004f}},	//   ीआइ_, skéh, truí_, ּנֵ֨
  { {0xe296017a,0xf2e4005e,0x3f853804,0xcb12000a}},	//   каш_, уючо, vilu_, ׁ֜ה_
  { {0x7fd90004,0x0000006a,0x0000006a,0x0000006a}},	//   мфот_,   ,   ,
  { {0xa3d50036,0x63740144,0x26c7006f,0x63090015}},	//   _розч, _bànd, ľnou_, _يقرّ_
  { {0x20030844,0x26c70107,0xfe45006b,0x6f65005e}},	//   čji_, žnou_, вноо, твоз
  { {0x4dd4008f,0xc7b20008,0x753b01b2,0xe732000a}},	//   ліяф, שבי_, _kauz, בֵר_
  { {0xd2560008,0x31350054,0x3f853f7b,0x63a3576d}},	//   _בשעה_, _једр, silu_, lonn
  { {0x753b003f,0xb4fa000a,0xa2d8000b,0x4f9505ab}},	//   _mauz, ופרי, नुक्, _ирку
  { {0x98a0005c,0x69d6021e,0xe3a70115,0x9ef5002b}},	//   leić_, _मंदी, شر_, _شستش
  { {0xfaa60d88,0xbb4303ae,0x60db576e,0x0000006a}},	//   таво, јеск, ocum,
  { {0xb903004a,0x63a343d6,0xd24f01f3,0x1c46576f}},	//   изск, honn, рцi_, _аним
  { {0x1c16005d,0x4c360010,0x63a35770,0x6b870079}},	// [dcc0] _तमिल_, _рэйт, konn, bijg
  { {0x1bba0115,0xeb9f00cb,0x66e6033d,0x68f60061}},	//   _تابع_, ktøy_, тожа, sayd
  { {0xa3bd005d,0x8b57004c,0x63a35771,0x5a96107c}},	//   ीआई_, _סיטס_, donn, _шриф
  { {0x753b04f9,0x56930036,0x73e60010,0x598303fc}},	//   _cauz, шаєт, водз, _влюб
  { {0xf4870086,0x07fa0015,0xb8f6000b,0x9cd7000a}},	//   پانی, _ترجع_, िख_, דונה_
  { {0x66e30010,0x7c290064,0xa3b40010,0x60db003d}},	//   _вора, çeri, ыблі, ecum
  { {0xbcfb00dc,0xc7b3000a,0xd2500015,0x753b01c2}},	//   mkév, _כבש_, صنة_, _fauz
  { {0xf1260036,0x673c1d83,0x1a9b004c,0xd6271ebd}},	//   тько, _harj, ויצע, _шосе_
  { {0xb4250070,0x6560002d,0xc953000a,0x83c60033}},	//   _معلو, _iomh, שמח_, _абаж
  { {0x63a31f10,0x753b016f,0x80c4000b,0x20020091}},	//   conn, _zauz, ाइबे, škio_
  { {0x43750036,0x69da0089,0x64420577,0x3eaa02de}},	//   _сутт, ítel, lvoi, æbt_
  { {0xd5fb000a,0x20190144,0xc27b05bd,0x60db2ac8}},	//   ופטר, àsic_, _קראי, ccum
  { {0x64425772,0x6b870079,0xda09009a,0x7c8404b5}},	//   nvoi, tijg, کيزه_, ауре
  { {0x636f0af5,0xfb870033,0x673c0085,0x6442005b}},	//   _lønn, тымн, _narj, ivoi
  { {0x5fb7013a,0xffb70008,0x6b870111,0x28c5000b}},	//   _שהוא_, _שלוש_, rijg, लेनि
  { {0x6d4d003f,0x81bc0024,0x261c0077,0x63a301ce}},	//   _unaa, _spēj, dío_, zonn
  { {0x3eb9005c,0x69d81f05,0xa2a4000b,0x63a35773}},	// [dcd0] ęste_, _éven, _चुस्, yonn
  { {0xf77300e5,0xa77402e1,0xcb99002b,0x261c0077}},	//   جار_, алуч, _سنجش_, fío_
  { {0x9f5900dc,0x64420045,0x63a35774,0x753b53ec}},	//   ésé_, evoi, vonn, _pauz
  { {0x6560017e,0x05b800e6,0x7a88000a,0x63a35775}},	//   _comh, ندنت_, _יָרַ, wonn
  { {0x6560002f,0x7d7c000a,0x4d7c004c,0xdcef003d}},	//   _domh, ונאו, וראע, licē
  { {0x63a300f2,0xd404006b,0x487a004f,0xe4500058}},	//   uonn, ряци, _טטרס, تضم_
  { {0x2bda005d,0x261c02c1,0x64420df1,0x38690413}},	//   _यूना, cío_, avoi, lyar_
  { {0xf2df0023,0xc6920008,0x63a31b3e,0x5694009c}},	//   _đâu_, _האל_, sonn, _таст
  { {0x20540010,0x05840010,0x38695776,0x60db5777}},	//   атэр, _турм, nyar_, rcum
  { {0x60db1358,0x8fa50004,0x0000006a,0x0000006a}},	//   scum, ѓане,   ,
  { {0xa3d9000b,0xfe71012c,0xd575000a,0x2f540033}},	//   _ठंड_, صدد_, ָתָה_, ртыс
  { {0x6458005c,0x8d561092,0xed5a4c31,0x2b460045}},	//   ścił, уточ, хом_, _şoc_
  { {0x9f4f0123,0x28c5000b,0x644f026a,0x0d831cd9}},	//   _avgå_, लेमि, _ácid, слян
  { {0x50b80074,0xdcef0048,0xe452000a,0x3b950099}},	//   _شدند_, ficē, צֶר_, ајст
  { {0xfb850033,0x201f5778,0xaaa40065,0x8f9a004f}},	//   рыўн, ltui_, _खुशक, _איסי
  { {0xb88602d5,0x261c02c1,0x80d50053,0x98a60248}},	//   hlíž, vío_, רוּװ_, гибе
  { {0x8d850074,0x81bc0024,0x6560002d,0x0b960031}},	// [dce0] _خشون, _spēk, _romh, _مجدد
  { {0x636f0293,0xcc57004c,0xd7ef0058,0x261c039f}},	//   _sønn, _עסיק_, سكم_, tío_
  { {0x673c0f37,0x201f00f2,0xa3c9000b,0xeef6004c}},	//   _varj, htui_, ोदन_, רמער_
  { {0x14c80086,0xb5a50036,0x44f6002b,0x261c0077}},	//   نهای_, арій, اساز, río_
  { {0x673c5779,0xc953000a,0x44f301f3,0x6442577a}},	//   _tarj, _המר_, спіс, uvoi
  { {0xd3b7005e,0x6442577b,0x3940577c,0x75d60040}},	//   глії_, rvoi, ldis_, _ميسا
  { {0x644200f2,0x65600cb1,0x39402f6d,0xcb13000a}},	//   svoi, _tomh, odis_, צלה_
  { {0xdced577d,0x200202c6,0xe6930015,0xe5a6009f}},	//   _plač, škim_, _الفد, _сиби
  { {0xb8860107,0x1f7400a4,0xe4760033,0x69da0046}},	//   blíž, илия, _сувэ, ítej
  { {0x7ccc003d,0x02d70015,0x7e6800aa,0xeb9f01de}},	//   _mērī, _موكب_, tydp, trøm_
  { {0x539b000a,0xaaa4000b,0x5757004c,0x9df70033}},	//   _טימו, _खुलक, אביע_, лнэт_
  { {0xdced0107,0x7bd6577e,0xc046009a,0x50d60058}},	//   _tlač, _buyu, _مختو, _إزار
  { {0x7d040176,0xdc870001,0x60180617,0xe571000a}},	//   _ddis, ућно, _роля_, חַם_
  { {0x200b032c,0x7bd60717,0x25a6577f,0xdcef003d}},	//   ácie_, _duyu, hool_, ticē
  { {0x25a6187b,0xeef7000a,0xb87b016e,0xda35004a}},	//   kool_, _גמור_, _ofíc, шевы
  { {0x53d4000b,0x79a73142,0x4ea500ce,0x7d000052}},	//   ददाश, урге, _тріа, ómst
  { {0x56f5000d,0x0cab005e,0x2d8b5780,0x5bb9024f}},	// [dcf0] ипаѓ, _ятки_, mice_, _илия_
  { {0x69d6000b,0x7c2d2472,0x6d5d5781,0x213f1bbc}},	//   _मूवी, _ipar, ljsa, zduh_
  { {0x6dbc0050,0x07080015,0x5f1c000b,0xe6950015}},	//   _właś, طيني_, _मान्_, جلاد
  { {0xe6040029,0x6d5d00c0,0x2d8b5782,0x4a5a000a}},	//   إِنَ, njsa, nice_, _סדרו
  { {0x78fa000a,0xbcfb00dc,0x15180029,0x4d7c0053}},	//   _בפרו, lkés, ازمة_, ערדע
  { {0x15f70029,0xd466057e,0x3e7b0030,0xe3c40015}},	//   _مسرح, рише_, _játé_, مْنَ
  { {0xe0d10029,0xe4e7017f,0xb2360015,0x3e7b0030}},	//   يزة_, _бізн, لكوا_, _máté_
  { {0x7c2d005c,0x59b5005d,0x201f1550,0xdfd10115}},	//   _opar, ंतिर, ttui_, ييع_
  { {0x646301e2,0x316d0064,0x201f00f2,0x7a2c00dc}},	//   çtiğ, rkez_, utui_, _kötö
  { {0x7e750029,0x5f05049d,0x69da001a,0x201f0620}},	//   لاجئ, јзна, ítek, rtui_
  { {0x6449002e,0x201f5783,0x2d8b248e,0xa155006b}},	//   _hrei, stui_, fice_, _вълш
  { {0x6da60191,0x2d8b0011,0xc616000a,0x61da000a}},	//   рима, gice_, סחרי_, _סקנד
  { {0x50d4002b,0x69d75784,0xaba60058,0xe0ce0138}},	//   _ازمر, _auxe, لإسه, _фв_
  { {0x69cf002d,0x03d6000a,0x68ed5785,0x4a9603ae}},	//   _aice, יושם_, ebad, ајбу
  { {0x75295786,0xb9c6006e,0x27e901c2,0xbcfb0030}},	//   _obez, لتره, epan_, gkés
  { {0xf1c6002e,0x64490152,0xac76002b,0x442d5787}},	//   _þátt_, _orei, _ناخش, _ope_
  { {0x6d410024,0x97da0036,0x778634c4,0x8d76002b}},	// [dd00] ēlat, тьбу_, алаз, _ماکا
  { {0x4bfb0053,0x1cbb000a,0x7bfb015b,0x68ed5788}},	//   _שליס, _במפע, _שפיצ, abad
  { {0xe73703a9,0xb4ce000b,0x68ed0123,0xbcfb0030}},	//   рех_, रश्_, bbad, mkér
  { {0x53e60010,0xba9b0008,0xbcfb00dc,0xceb2000a}},	//   ацка, _יסיי, lkér, חיב_
  { {0x25a60020,0x7afc0011,0x64495789,0x69c427fd}},	//   rool_, oart, _crei, mmie
  { {0xaaba014e,0x69c44c11,0x2d8b03f3,0x200d578a}},	//   _इराक, lmie, zice_, drei_
  { {0xcad7013a,0x6449578b,0x179b000a,0x25a6578c}},	//   בוצת_, _erei, _סילב, pool_
  { {0x65b80089,0x59c6000b,0x763b004c,0x6449578d}},	//   bíha, लगिर, _בעלג, _frei
  { {0x6449578e,0xc05a0036,0x2d8b259f,0xc173005e}},	//   _grei, тій_, vice_, ільщ
  { {0x2d8b08c2,0x69c45577,0x6437000a,0xdb071696}},	//   wice_, hmie, _דאמא_, kljá
  { {0x7c2d0876,0x9d55002b,0x2d8b578f,0x637b000a}},	//   _spar, مندت, tice_, _שנבד
  { {0xa0a6000d,0x200d5790,0x7af75791,0xbcfb0030}},	//   _каед, brei_, _sext, ekér
  { {0x69cf0ede,0x69c40a52,0x3e7b0046,0x61ea0012}},	//   _rice, dmie, _páté_, lpfl
  { {0xc90f014e,0x69cf00bd,0xbcfb0f87,0x7afc5792}},	//   िल्म_, _sice, gkér, gart
  { {0xd90f0086,0x61ea0012,0x27e90034,0xd357000a}},	//   وید_, npfl, wpan_, סילי_
  { {0x7c2901e2,0x29dc0467,0x69d700c0,0x79540015}},	//   çers, _día_, _vuxe, يَّا
  { {0xc8d80036,0x7afc5793,0x96e70015,0xf7730021}},	// [dd10] рмує_, bart, لثام, ياط_
  { {0x8ca0005d,0x69cf10ec,0x8754005e,0x6371001a}},	//   _गुटो, _wice, окує, iðnæ
  { {0x69cf0176,0x2002116e,0xeb9f0134,0x27e95794}},	//   _tice, ških_, esøg_, span_
  { {0x19590010,0x45180036,0xceb3000a,0xd1260015}},	//   _самы_, иція_, קיף_, _عم_
  { {0xf9560008,0xb956000a,0x9474002b,0x7dc60091}},	//   _הסרת_, _הירח_, يدها, _iųst
  { {0x083a0053,0x2c38000a,0xe057002b,0xb38401f3}},	//   _געשל, שָׁם_, ییات_, оліл
  { {0x64490026,0xbb78004c,0x0000006a,0x0000006a}},	//   _wrei, שעוו_,   ,
  { {0x3f8c0024,0x82340086,0xfa98000a,0x3cf1000b}},	//   eidu_, ترها, ידוש_, चरों_
  { {0x4499008f,0x33d4005e,0x60090054,0x64490012}},	//   _сваю_, _дієт, ћном_, _urei
  { {0x69c41332,0xdb240061,0x2d99050a,0x48b6000a}},	//   zmie, ürüt, éren_, מִין_
  { {0xf772000a,0x798d058a,0x69c42012,0xbea51ece}},	//   פקט_, kiaw, ymie, санк
  { {0xd656013a,0xc6920008,0x200d4a14,0x7afc5795}},	//   צירת_, לאי_, prei_, wart
  { {0x29dc002e,0x859a0053,0xaf490015,0x50da004c}},	//   _sía_, רשרו, _مشغل_, _עקסא
  { {0x69d800dc,0x7996002a,0xb80c000b,0x7afc5796}},	//   _évek, wnyw, िंघम_, uart
  { {0xf2d20053,0x798d0026,0x5f740031,0x3eaa0057}},	//   לעם_, fiaw, _ظاهر, čité_
  { {0xe803005d,0x29dc02c1,0x7afc5797,0x69c40535}},	//   _लिखा_, _vía_, sart, umie
  { {0xab9a0086,0x7afc44a3,0x79960034,0xf6d60015}},	// [dd20] _مخدر_, part, rnyw, مزاد
  { {0x2d8e002a,0xbcfb0030,0x29dc5798,0x7c3b0003}},	//   śleć_, lkép, _tía_, çure
  { {0xc86900b2,0x671e000b,0x69c4003d,0x29dc0077}},	//   ען_, _पाठक_, pmie, _uía_
  { {0xbcfb00dc,0x89360031,0xf221000b,0x61fc0723}},	//   nkép, _اعدا, _महज़_, _ærli
  { {0x2365018c,0xddc90007,0x25bf002d,0x9d1b000a}},	//   _bolj_, yzdž, _dhul_, רונט
  { {0xeb9f0134,0x230a0015,0x37e30054,0xd4670054}},	//   rsøg_, اتشي_, _хорг, сиље_
  { {0x39420020,0x7a432024,0xe2460015,0xf777000a}},	//   _kaks_, mítá, إختي, _פעלי_
  { {0x7a4303c0,0xf596003b,0x80c4005d,0x61ea00b8}},	//   lítá, _الرج, ाइले, rpfl
  { {0xe58b0008,0x61ea0012,0x2cb2007c,0x20020030}},	//   _עָלָ, spfl, _nyyd_, éki_
  { {0x200b15aa,0x74130002,0x7a430030,0x200a00bc}},	//   ácia_, _روما, nítá, čbi_
  { {0x4d99005e,0xfe6f0015,0x39a10091,0x394247eb}},	//   икою_, ّدُ_, lėse_, _oaks_
  { {0x02b7004c,0xa1c60459,0xbcfb0030,0x63aa0034}},	//   _פלאך_, _убед, gkép, lofn
  { {0x39a10007,0x7a4300dc,0x3f8c2b06,0xbcfb0030}},	//   nėse_, kítá, pidu_, tjéb
  { {0x7a430030,0xa0070015,0xab842565,0xdfd00058}},	//   jítá, _اقول_, пуск, _غيث_
  { {0x42db00b2,0x7a4300dc,0x7de600e6,0x798d01d7}},	//   רקלע, dítá, _استم, tiaw
  { {0x98750080,0xc171000a,0xbcfb0030,0x1e97004f}},	//   олбц, ֵ֗ן_, ckép, _לכול_
  { {0xc6f903e7,0x6b8e02f2,0xa9240046,0x798d297a}},	// [dd30] инах_, bibg, ížat, riaw
  { {0xfb150086,0x28c5005d,0x5a350004,0x87040033}},	//   _بودج, लेषि, _днот, зяце
  { {0xf7700029,0xb6350115,0xa51d0033,0xdb0e0125}},	//   راك_, تفاع, вялi, ambó
  { {0x6aba01e2,0xa5f80054,0xfe37000a,0x44b51079}},	//   ütfe, сецу_, מרבי_, обес
  { {0x2d99002d,0x28c5000b,0xe3ae0033,0x236500bc}},	//   inse_, लेशि, дб_, _polj_
  { {0x63aa0176,0xc5fb0002,0x7bfc000a,0x2c18000a}},	//   gofn, _معرض_, נפוצ, מקדש_
  { {0xe3b00015,0xd5bb009b,0x0000006a,0x0000006a}},	//   رره_, _бса_,   ,
  { {0xe87c01e2,0x212b206c,0xfa780008,0x2d990111}},	//   nüşü, ých_, מעות_, jnse_
  { {0x3dc00034,0x296c000a,0x85040015,0x44390006}},	//   _rhiw_, ר֣וּ, _رولن, _ès_
  { {0x93970225,0x443f0375,0xa858000a,0x2d995799}},	//   _اجرا, _isu_, מיחה_, ense_
  { {0x3eb9005c,0xbcfb0030,0xed5a07f7,0x229500c3}},	//   ęsto_, tkép, аон_, _بلاس
  { {0x7a4300dc,0x212a002b,0x76000030,0xfbef0046}},	//   zítá, _نيمی_, _házá, ěšné_
  { {0xbcfb00dc,0x31580015,0x0719000b,0x76000046}},	//   rkép, _دجلة_, दलाव_, _kázá
  { {0xbcfb00dc,0x2d990161,0x6008000a,0x4fc70033}},	//   skép, anse_, _הִקְ, _усеа
  { {0x7a4300dc,0x5a55006b,0xaa431aef,0x443f00da}},	//   vítá, пъту, мерл, _lsu_
  { {0xdb07008c,0xa9260033,0xee96002b,0xa96a067a}},	//   eljä, ўдал, _بدهک, шиба_
  { {0xa7660fbd,0xdd8f0021,0x7a430030,0x6d5600aa}},	// [dd40] окад, _جوي_, títá, _inya
  { {0x47c30036,0xeab20029,0x66760086,0xa6b60457}},	//   дбув, _يعد_, يدار, осещ
  { {0xff7a0053,0x85060029,0x7a4300dc,0x7f430291}},	//   סטעמ, قوان, rítá, _manq
  { {0x7a430014,0x39a10007,0x7c260079,0x199603ae}},	//   sítá, tėse_, otkr, _фјор
  { {0x63aa002e,0x7a4300dc,0x2937000a,0x29000045}},	//   tofn, pítá, _ואכן_, maia_
  { {0x6d440020,0xe1f20015,0xcc3b004c,0x39a10091}},	//   _laia, وسع_, שעסט, rėse_
  { {0x443f0007,0x26d800bc,0xeb9f02de,0x2d9900aa}},	//   _esu_, _igro_, prøv_, ynse_
  { {0x39a10007,0x2508002b,0x64a61de1,0x29001eff}},	//   pėse_, _درسی_, _даба, naia_
  { {0xfbbc005d,0x7f432c42,0x98b90045,0x2d992024}},	//   ोगाम, _banq, _iasă_, érem_
  { {0x543b00b2,0xdfd00086,0xb8570135,0x64401e8c}},	//   _דעמא, ژيک_, קייפ_, _ismi
  { {0x44260e68,0x6d460079,0x26db05bd,0xd36f0040}},	//   lto_, fdka, יקימ, _جهل_
  { {0x656200f2,0x2d9902b9,0xc0ca0054,0x443f0034}},	//   njoh, unse_, _куле_, _ysu_
  { {0x98b90011,0x4426579a,0x9b6b006b,0xcb47005e}},	//   _masă_, nto_, ашва_, охви
  { {0xf4130008,0x98b90011,0x4426579b,0xf09305bd}},	//   ופש_, _lasă_, ito_, _קנס_
  { {0x44264b86,0x298b0054,0x19590174,0x99671114}},	//   hto_, асао_, бавы_, отал
  { {0x2d9200dc,0x4426579c,0xc27b000a,0x9e7b000a}},	//   ézet_, kto_, ברלי, _כנופ
  { {0x4426002c,0xe87c0064,0x47d50115,0xac950054}},	// [dd50] jto_, rüşü, سيار, _хапш
  { {0xcb680001,0x44261256,0x7d1d0595,0xe7330015}},	//   _мање_, dto_, lgss, بصر_
  { {0x69da0014,0xbb3a0008,0xcdd5000a,0x26070033}},	//   ítet, _העתי, ִךְ_, ючаг
  { {0x20040024,0x98b90011,0xdcef0024,0x637d0003}},	//   ksmi_, _casă_, dicī, _mène
  { {0x764e0176,0x43750080,0xad1c000a,0x78bd003d}},	//   _erby, зуйт, שודר, _uzsv
  { {0x83880036,0x934209a7,0xdb1c001a,0x638501f3}},	//   обів_, енше, amræ, ягла
  { {0x4426579d,0x6b7c000a,0xc7b2000a,0x76000046}},	//   ato_, שרונ, _נבל_, _vázá
  { {0xf6520008,0x5a9c0008,0x200b3a96,0xba9c000a}},	//   _אצל_, ישוא, ácio_, יסוי
  { {0x44260a49,0xf8b9005d,0x443f0020,0xe4e40033}},	//   cto_, _आरोप, _usu_, _цісн
  { {0x7f740033,0x7d1d0012,0xb4c9000b,0x6d444a91}},	//   дуюц, egss, ैशी_, _saia
  { {0x2f540191,0x7f4300da,0x9d462143,0xa3d40065}},	//   єтьс, _vanq, пенд, _सूट_
  { {0xd00e0074,0xb2ba01e4,0xa2ba000a,0x68fd0046}},	//   خلی_, _המער, _המעט, _nesd
  { {0xe6b8005d,0x6564008c,0x50da000a,0xcfe9002b}},	//   _अर्ज, öihi, _הקנא, _افته_
  { {0x8cc2000b,0x4b55006b,0xbfb70058,0xea8a0058}},	//   रेगो, мъст, _بحصت, مخزن_
  { {0xa3cc005d,0x637d18b3,0xdce80064,0xa3d4021e}},	//   रगत_, _gène, şmıy, _संघ_
  { {0xd7f20029,0x4426579e,0xb87b1279,0x7c2602ad}},	//   فكر_, yto_, _efím, ptkr
  { {0x38c80074,0x68fd0e75,0x7d7b0008,0xd70a0010}},	// [dd60] زاری_, _desd, _לנקו, йнае_
  { {0x46a60063,0x68e4579f,0xbcfb0030,0x6f0157a0}},	//   пазв, scid, njén, nalc
  { {0xada5002c,0x7c650086,0xeb3b004c,0x98b90045}},	//   spĺň, _فایل, _פעטש, _pasă_
  { {0xe45a0036,0x5e9a0053,0x05660063,0x4426052a}},	//   йже_, זבעק, явен, tto_
  { {0xe8d70008,0x657b0089,0x6f0100bd,0x69de09de}},	//   _מוכר_, _dluh, kalc, _hupe
  { {0x656200f2,0x6f0100bd,0x69de0a9e,0x68fd0079}},	//   sjoh, jalc, _kupe, _zesd
  { {0x877b00b2,0xbb3b0053,0xb77b004c,0x644b0795}},	//   _פאלי, מעסי, _פאלש, avgi
  { {0x15430001,0xf487002b,0x44260bb6,0x657b0085}},	//   _песм, _کافی, pto_, _gluh
  { {0x60f7008f,0xf8be000b,0x60230054,0x6f0157a1}},	//   чныя_, ्धिय, едња, falc
  { {0x43860070,0x447b000a,0x547b000a,0x324624d2}},	//   _علاق, _הנמע, _הטמו, _незг
  { {0x62830050,0xdb1e0030,0xe8b90065,0x69de0073}},	//   czno, _lipó, _आर्च, _nupe
  { {0x06970008,0x2d9f007c,0x5155123e,0x4c9557a2}},	//   לדים_, õue_, _отчу, димс
  { {0x0cab010f,0xc0d30029,0xf1a90067,0x5c7404e5}},	//   стни_, _كيمب, _باله_, елят
  { {0xc214000a,0x6f0157a3,0x20020091,0x68fd00aa}},	//   ֽהּ_, calc, škis_, _sesd
  { {0x27e6017e,0x7afe57a4,0x539b000a,0x8f8b000a}},	//   íonn_, _dept, צילו, _לְהֵ
  { {0x3da40010,0x31970011,0x0e9b000a,0x7e9b000a}},	//   _прыб, tăzi_, _לשול, _לסוו
  { {0x2bbc000b,0xa3cc000b,0x69da16ee,0x57d5011e}},	// [dd70] ोगशा, रगा_, íter, доаѓ
  { {0x656900e8,0xf0930053,0x31970045,0xb883013f}},	//   _soeh, ײנע_, răzi_, vníč
  { {0xcb120008,0xe81e000b,0x69be000b,0x636f02de}},	//   _בלי_, यूबा_, _वीवी, _mønt
  { {0x7afe0b85,0x6f0100bc,0x7bdf00aa,0xdb0c001a}},	//   _zept, zalc, _kuqu, ðhön
  { {0x69de005c,0x442b0127,0x34ab0015,0xf8b1002b}},	//   _zupe, сцем_, حداً_, _شکر_
  { {0x8c1c0008,0xdb1e0144,0xd3d80015,0xdb0e0046}},	//   מודי, _hipò, سبها_, olbá
  { {0x6f01018c,0xb595004a,0xc5950054,0x7d0d57a5}},	//   valc, _живш, _живј, _odas
  { {0xc69200a3,0x8a7c000a,0x6f01002a,0x2a58000a}},	//   _סאן_, מאות, walc, לבון_
  { {0x628306e7,0xef19005e,0xcf39005e,0x394957a6}},	//   szno, омп_, очні_, idas_
  { {0x43940001,0x8e09014d,0x94040015,0x3949008c}},	//   _заус, онов_, _أوله, hdas_
  { {0xd1310029,0x7bdf0152,0xd019005c,0xd1b80086}},	//   _لما_, _auqu, suń_, _کالا_
  { {0xcb0901c8,0x82340074,0x92b40029,0x7bdf0077}},	//   _כל_, _سرما, _أحكا, _buqu
  { {0x394957a7,0xbcfb0030,0xa0690004,0x69de50e4}},	//   ddas_, pjén, _фала_, _supe
  { {0x7d0d0005,0x394957a8,0x5e450015,0xdb070046}},	//   _edas, edas_, _يَشْ, bojí
  { {0xab27006b,0x8cc20065,0x0000006a,0x0000006a}},	//   ьора_, रेजो,   ,
  { {0x636f02de,0x3dfa004f,0xfe700058,0x0000006a}},	//   _køns, _ולקד, _حده_,
  { {0xdb1e0251,0x0000006a,0x0000006a,0x0000006a}},	// [dd80] _dipò,   ,   ,
  { {0xdced010b,0x3949047e,0x636f01f0,0x39460cd4}},	//   _plać, adas_, _møns, žos_
  { {0xeb9f00cb,0xa526005e,0x35e50033,0xc7af0015}},	//   prør_, дмед, еців, جّل_
  { {0x0000006a,0x0000006a,0x0000006a,0x0000006a}},	//     ,   ,   ,
  { {0xe8f702e1,0xd4670054,0x66030030,0xe4a3011e}},	//   _юля_, мице_, ánkr, кршо
  { {0x661a01d1,0x68f60134,0x533303f1,0x073a0015}},	//   _åtko, lbyd, вешт, _بسحب_
  { {0xe3550010,0xd25000e6,0x28be000b,0x69d80030}},	//   этцэ, انب_, ्धवि, _éves
  { {0x3d18005d,0x497b004c,0x52730054,0x071e000b}},	//   थलों_, ַטיװ, ђују, _पाँव_
  { {0x20030015,0x032601ca,0x48a9004f,0x0000006a}},	//   نِيِ, _одан, ּיתְ,
  { {0x3e4c0089,0x39490007,0xc4c50029,0x637d0144}},	//   _pět_, zdas_, _ستقو, _vènc
  { {0x4e8a0080,0x81f70015,0xbcfb0030,0x39490091}},	//   ющим_, _يفكر_, mkéz, ydas_
  { {0xdb070046,0xc0460015,0xe2910015,0x3e4c0046}},	//   rojí, _يخشو, _إذْ_, _vět_
  { {0x3da4008f,0x68f60134,0x321c0264,0xf1a90067}},	//   трэб, dbyd, luvy_, _عامه_
  { {0x69c6008c,0x3033004a,0x600b000a,0xdb0701c0}},	//   _ahke, _решё, _וִהְ, pojí
  { {0x7e860089,0x3f9e00aa,0xf96b0033,0xc9770015}},	//   úspě, mntu_, орай_, وارث
  { {0xbda70029,0xf7700086,0x39494060,0x7d0d0030}},	//   _تحتو, یال_, udas_, _udas
  { {0xe894005f,0xcda80086,0x39491bc7,0x80c4000b}},	// [dd90] вать, _تهيه_, rdas_, ाइटे
  { {0x6bd70029,0x3f9e002e,0xbc380031,0x4bc70015}},	//   _تتعر, nntu_, _آسيا_, _تتبّ
  { {0xb6070092,0x261a000b,0x65150015,0xfbd2000a}},	//   _giớ, मूली_, فوائ, _תתי_
  { {0xcdd900b2,0x2a760008,0x95cb2f72,0xfa76004f}},	//   פֿער, _נערך_, цуза_, _נערת_
  { {0xc9160008,0x3eb90007,0x69cd0bfa,0x2409005e}},	//   _אחרת_, ęsti_, mmae, їнки_
  { {0xcc78009d,0x57fa000a,0x28be000b,0xd7fa000a}},	//   ועדה_, _מלשו, ्धरि, _מהשל
  { {0xd66900e6,0x60c20030,0xf52710a6,0x96180058}},	//   _عمرو_, _azom, _офан, _يغفر_
  { {0x3f9e3270,0x7dde0024,0x69cd0034,0x6ff509a0}},	//   entu_, _mūsd, nmae, нчох
  { {0xd00e0015,0x4f952bf2,0x2486002a,0x6b95003d}},	//   ملي_, ерну, czom_, kizg
  { {0x00820036,0xd3d80002,0x0e6540e5,0x6ade000b}},	//   ульо, _قبلا_, екон, _मलेर
  { {0xc7b20008,0x68f60026,0x7c3657a9,0xa3cc000b}},	//   רבי_, ybyd, _spyr, रगर_
  { {0xf2df00a7,0xf67a0053,0xf6520053,0x91f6000a}},	//   _đây_, פארמ, אצט_, _נמנו_
  { {0x61e10c8a,0x251a000a,0x41740015,0x5576004c}},	//   _hull, הורא, _جالس, גערן_
  { {0x61e10482,0xbea530d6,0xd00e009a,0x1bd30138}},	//   _kull, _палк, _الو_, лоўя
  { {0xfaa30010,0x61e14af7,0xfbc34729,0x539a000a}},	//   гаро, _jull, убро, לישו
  { {0x61e157aa,0xbd0304b2,0xb7da0015,0x57ea2cb0}},	//   _mull, žérs, كورا_, здам_
  { {0x7d063fa4,0x2d800045,0x02cb000b,0xeb9a004a}},	// [dda0] maks, _ilie_, ाधुन, _нии_
  { {0x4a460036,0x7d06388f,0xee490016,0x77460015}},	//   _знов, laks, _kẽ_, عَام
  { {0x8afb000a,0x461a0033,0x3eb9002a,0x064a00c3}},	//   _מפיק, яцаў_, ęstw_, ثلاً_
  { {0xee490092,0x84e6042b,0x5a17004c,0xeafa002b}},	//   _mẽ_, ходж, _אקטן_, _برکت_
  { {0xee490092,0xf8db000a,0x61e1039f,0x0000006a}},	//   _lẽ_, _מחכמ, _aull,
  { {0x7d060e95,0x8c1b000a,0xa2940484,0x61e12e1c}},	//   haks, פוצי, калі, _bull
  { {0xdbc70020,0x60c200dc,0x07a30342,0x248613c3}},	//   _tööj, _szom, _сарн, szom_
  { {0xb0340001,0xc0340001,0x7d062357,0x61e157ab}},	//   вниш, вниј, jaks, _dull
  { {0x41c30029,0x23e8002b,0xe1230054,0x7d062796}},	//   دقيق, _آذری_, умњи, daks
  { {0x75220014,0x3f9e016f,0xbed4000d,0x2fd8001a}},	//   lgoz, untu_, копј, örg_
  { {0xe0da000d,0x4256005e,0xf5ca000a,0x8717004c}},	//   _еве_, _ятат, ּזָּ, עקטע_
  { {0x7522000c,0xc27b0008,0x869b0053,0xf56e005e}},	//   ngoz, _מרבי, לייז, икiв_
  { {0x7984000c,0x61e10111,0xdcbb0063,0x80260086}},	//   dhiw, _zull, ящо_, _سرشم
  { {0x7d060bb5,0x661e57ac,0x2d8024bd,0x0000006a}},	//   aaks, kupk, _elie_,
  { {0x7dde00df,0x6d960048,0x5e260029,0xda340010}},	//   _būse, mšan, _أعتق, леры
  { {0xf7730074,0xdd910086,0x7d060064,0x6d960024}},	//   گار_, _خوب_, caks, lšan
  { {0xc7d90054,0x69cd57ad,0x7658006f,0x7f3a004f}},	// [ddb0] дмах_, rmae, ťvyl, ּע֣ו
  { {0xf7730225,0x200b002c,0x4c9c000a,0xaa890015}},	//   دار_, ácii_, _מבחו, _ينظم_
  { {0xcf9300b2,0x57a40180,0x4efb004c,0xee490016}},	//   נטע_, ушта, פלאג, _xẽ_
  { {0x7984005c,0x61e10c6b,0x74f9027a,0x765a005a}},	//   chiw, _rull, федр_, _štyc
  { {0x6d960048,0x04450b9c,0x61e157ae,0xb954034e}},	//   kšan, телн, _sull, _свящ
  { {0xf62b0036,0x6d9600bd,0x61e1353b,0x29020061}},	//   _ніби_, jšan, _pull, _zeka_
  { {0xc6d70029,0xeb92000f,0x85bb0002,0x7d060c48}},	//   _ستست, יָה_, _فارس_, yaks
  { {0x21270086,0xee490092,0x6d964f7c,0x61e157af}},	//   ريخی_, _rẽ_, ešan, _vull
  { {0xee4900a7,0x7d060604,0x7f190127,0x8fc4002b}},	//   _sẽ_, vaks, міну_, گزين
  { {0x7655005c,0x6d960024,0x8e750033,0x61e11c7e}},	//   _krzy, gšan, вумч, _tull
  { {0x7d061c23,0x4ed40036,0xbea51adc,0x3ea513d0}},	//   taks, люют, танк, тинг
  { {0xed572031,0xee490092,0xdb070227,0x82340015}},	//   вою_, _vẽ_, vojá, _حركا
  { {0x7d0603eb,0x290257b0,0xfebb002b,0x0d950033}},	//   raks, _reka_, _کاشت_, ушэў
  { {0xb09a000a,0xdee2005e,0x8c430099,0x29022ca2}},	//   _קיסר, _коши, јере, _seka_
  { {0x79840026,0x6442002a,0x7d0657b1,0x3a15030c}},	//   thiw, zwoi, paks, льтс
  { {0x6f03003e,0xc212000a,0x2d9901ce,0x7c960015}},	//   _henc, יהל_, éret_, _للعص
  { {0xc1720008,0x2902044c,0x6f030049,0x8bb60015}},	// [ddc0] בחן_, _veka_, _kenc, _لإدا
  { {0x2902000c,0x77830036,0xcc57000a,0x7655002a}},	//   _weka_, алуз, _יספק_, _brzy
  { {0xf74305cb,0x394b002d,0x7d0457b2,0x6f030c61}},	//   рехо, _facs_, _keis, _menc
  { {0x6f0357b3,0x0000006a,0x0000006a,0x0000006a}},	//   _lenc,   ,   ,
  { {0x7d0457b4,0xd7ca0015,0xd90d009a,0x0000006a}},	//   _meis, _يوجه_, _ریل_,
  { {0x93b3008f,0x37760010,0x66e600d7,0xd36f0015}},	//   абіц, _рымс, _јова, يهن_
  { {0xcb130008,0x7655005c,0xa3e2000b,0x4254002b}},	//   בלו_, _grzy, _नूर_, انبر
  { {0xd2590010,0x32530063,0x3ce002de,0x7d0457b5}},	//   эці_, рвър, _ngiv_, _neis
  { {0xf993011f,0x831a0015,0x30a6006b,0x73e6005e}},	//   ירה_, _يقرر_, ъркв, _розз
  { {0xd378016f,0x6d960024,0x394001d7,0x3dc957b6}},	//   _biće_, ušan, heis_, _shaw_
  { {0x82660074,0x7d04018b,0x471b0053,0x539b0008}},	//   _جهان, _beis, וויג, _קיבו
  { {0x61460124,0xac1918a9,0x7d040807,0x765800f2}},	//   _једа, ному_, _ceis, ävyy
  { {0x7d04130f,0x6d9657b7,0x6f0357b8,0xc013005e}},	//   _deis, pšan, _fenc, _вміщ
  { {0x7e540029,0xc4d3000a,0x7dde003d,0x3f85006f}},	//   _منتص, יגר_, _bīst, chlu_
  { {0x9e34005f,0x2e4a0063,0x6d96016f,0xeb9f00cb}},	//   _сейч, _цяло_, ošal, lsøk_
  { {0x7d044b08,0x6f030061,0x0000006a,0x0000006a}},	//   _geis, _zenc,   ,
  { {0x2d991c23,0x08550802,0x7793002b,0xe695002b}},	// [ddd0] mise_, ываю, لیحا, گلاد
  { {0x76550f9a,0x2d9946e0,0x4bdb0015,0xaac70015}},	//   _przy, lise_, _تبعد_, _لتجن
  { {0xc6e4005e,0x1995070c,0x6d960085,0x1b740021}},	//   ріуп, _баня, kšal, _خديج
  { {0xa9790053,0xeb9f003c,0x3940001c,0x6d9600bc}},	//   _נאָכ, ksøk_, ceis_, jšal
  { {0x6d4d025c,0x58870010,0xd91a000f,0xc952000a}},	//   _maaa, _рына, _אורל, _המכ_
  { {0x7655005c,0xa22902da,0x69dd57b9,0xeb9f00cb}},	//   _trzy, ежка_, _hise, dsøk_
  { {0xdb07002e,0xeb9f003c,0x68ed002d,0xc7b2000a}},	//   lljó, esøk_, ocad, _לבך_
  { {0x6d4d0035,0x52741a11,0xb2360015,0x6f0357ba}},	//   _naaa, рушу, اكيا_, _senc
  { {0x3f850026,0xd5b8005e,0x2d9957bb,0xeb9f00cb}},	//   thlu_, _рср_, dise_, gsøk_
  { {0xc2cb0086,0x6d960007,0x7d0457bc,0x2d9910cc}},	//   _قبال_, ašal, _seis, eise_
  { {0x69dd0152,0xbd460029,0x41e7005e,0xdb07001a}},	//   _oise, هندي, _різа, hljó
  { {0x63ad002d,0x69dd00bd,0xd1740010,0x7de80089}},	//   éanf, _nise, _вышы, _těsn
  { {0x394003af,0xd4790053,0xdb07008c,0x7d0457bd}},	//   veis_, גאָל, kojä, _veis
  { {0x200b032c,0xa09a0dab,0x7d0404b0,0x394000b8}},	//   áciu_, _אינט, _weis, weis_
  { {0x7d0457be,0x69dd0265,0x2d9957bf,0x394057c0}},	//   _teis, _bise, bise_, teis_
  { {0x5c960029,0xd24f0010,0x69dd57c1,0x2d994c8d}},	//   _مؤخر, сцi_, _cise, cise_
  { {0xd7f90036,0x6d96003d,0xdb0e001a,0x8c570015}},	// [dde0] вує_, nšam, ilbú, _مليء_
  { {0x394057c2,0x68ed4680,0x69dd57c3,0x2909096b}},	//   seis_, acad, _eise, aaaa_
  { {0x4b7b0053,0x6449008c,0xf496002b,0x06560033}},	//   _נאטו, _asei, گشاد, ытаў
  { {0xc4860080,0x1a9b0053,0x05ba0002,0xf525005e}},	//   ллек, _טייע, ردات_, ифін
  { {0x7bde57c4,0x6e210012,0x64a30054,0x0000006a}},	//   _kipu, hulb, баца,
  { {0x987b0053,0xd3700029,0xdced0064,0x66e34183}},	//   _טאכט, تهت_, _olağ, _гора
  { {0x6d960024,0xe2130029,0xf992000a,0xd2500015}},	//   ešam, مبيع, ֶר֙_, زنة_
  { {0x7bde57c5,0xeb9f00cb,0xb426006e,0x865b000a}},	//   _lipu, tsøk_, _معطو, _אדלי
  { {0x6560002d,0x859b000a,0x2d990aa0,0x9f5f001a}},	//   _inmh, _נשמו, vise_, truð_
  { {0xeb9f003c,0x1e340010,0x2d99003e,0xbe8a0054}},	//   rsøk_, аноў, wise_, есме_
  { {0x2d990005,0xb2290029,0xdd9100e6,0xeb9f00cb}},	//   tise_, _لأنك_, قود_, ssøk_
  { {0xc693000a,0xd83f0091,0xeb9f00cb,0x41aa009b}},	//   מאת_, ščiu_, psøk_, _явен_
  { {0x69dd57c6,0xdb0e0045,0x6d4f108d,0x2d9957c7}},	//   _rise, dobâ, rdca, rise_
  { {0x09bf014e,0x69dd0005,0xdfd000e5,0x7bde00e8}},	//   ्ष्य, _sise, _بيت_, _cipu
  { {0x5fbb0008,0xead5004a,0x8e230054,0x7bde145f}},	//   _רצונ, ровь, иjе_, _dipu
  { {0x2e13002b,0xd8f50054,0x9da70058,0xd8b50058}},	//   _ابوح, рзањ, _حصته, لمأخ
  { {0x69dd0293,0x3cf80015,0x5d840002,0x68ed4b02}},	// [ddf0] _vise, _صعيد_, _دليل, rcad
  { {0xe8ff0152,0xe7190115,0x78bd0057,0x6d9600bc}},	//   _août_, ئيات_, _vysv, jšaj
  { {0x8f1b000a,0xe7ea000b,0xdced0085,0x5eeb004f}},	//   תובת, _झूठा_, _hlađ, גַדְ
  { {0xe8ff0152,0xe4d90029,0x39a10091,0x6449003d}},	//   _coût_, نوات_, kėsi_, _psei
  { {0x24580010,0x88990053,0x28070046,0xe3b10021}},	//   лаць_, _סבֿי, átně_, يرت_
  { {0xdced016f,0x289a000a,0xf8b6000a,0x889a000a}},	//   _mlađ, _יירא, _כפרי_, _יברי
  { {0x45d5004a,0x0000006a,0x0000006a,0x0000006a}},	//   _вовс,   ,   ,
  { {0x200d0020,0x7de10024,0xc6920008,0xe8ff0152}},	//   tsei_, _mēst, _ואל_, _goût_
  { {0x6449022d,0xf8b5005d,0x60060010,0xa1560001}},	//   _usei, ंथिय, аным_, рању_
  { {0xa2950010,0x7f410003,0xdfce0067,0x6fb20040}},	//   _казі, uelq, ويي_, يميا
  { {0xe732000a,0xf1fb0015,0x8d6614dd,0x02a7030e}},	//   חֵר_, _أعطت_, авне, _срам
  { {0xdb0e0b7e,0x3035004a,0x200d0045,0x01fa000a}},	//   robí, _ведё, psei_, _יפעל
  { {0x0c230f13,0x317a004c,0xdb0e0046,0x9cb30015}},	//   омян, _שאנד, sobí, ْمُت
  { {0xc33200b2,0x7df30011,0xa0c40021,0x6e21007c}},	//   ֿון_, _răsf, _ايهو, pulb
  { {0x8f9a000a,0xa9280046,0x49960579,0xaa46004a}},	//   _שיצי, _nežá, ашат, шевл
  { {0xfaa3005e,0x7c96140a,0x0000006a,0x0000006a}},	//   іато, _вроц,   ,
  { {0x8c4605cb,0x7bde57c8,0xdcfd0091,0xe9d70137}},	// [de00] _тепе, _tipu, eisė, ркт_
  { {0x9b930015,0x46f60b9b,0x7d16008c,0x6abe3582}},	//   _وليت, рчат, _hdys, _typf
  { {0xdd8f0074,0xe9df03d9,0x8afb000a,0x7d160046}},	//   _روی_, _fiú_, _שהטי, _kdys
  { {0x2bb4005d,0x14c80086,0x7e360053,0x63740251}},	//   ंकवा, ههای_, יטעד_, _rànq
  { {0xd40309ef,0x9346194a,0x25e6000b,0x24800030}},	//   оящи, инде, _जूरी_, áim_
  { {0xd3360010,0xd3b70036,0xae06000b,0x6c57004c}},	//   рэды, алії_, वीडन_, יינא_
  { {0x75d600e6,0xcb13000a,0xe81e000b,0x6d960085}},	//   _نيسا, קלה_, यंका_, ršaj
  { {0x0f1e000b,0x7e7e0012,0x39a10091,0x395257c9}},	//   पल्स_, _üppi, tėsi_, ndys_
  { {0x251b000a,0x1fa6012f,0x351b000a,0x6d96013b}},	//   _שומא, ирог, _שומנ, pšaj
  { {0x30390086,0x1be1021e,0xf837000a,0xc837004c}},	//   اتيک_, _गूगल_, סנית_, סטיץ_
  { {0x4f670010,0x63b81cb2,0x6b9c57ca,0xb146011e}},	//   ршым_, movn, dirg, _внел
  { {0x25a60176,0x63b857cb,0xc27b000a,0xbf66002b}},	//   nnol_, lovn, _שראי, ادکو
  { {0x7d160176,0xcff4006b,0x395200a9,0x765a006f}},	//   _ddys, _уплъ, ddys_, _štyl
  { {0x63b8060b,0x49bb0086,0x4fb30015,0x207b015b}},	//   novn, چارد_, _وصور, _באדא
  { {0xda780063,0xb345001c,0xe9190036,0x99d700c3}},	//   аят_, leçã, лові_, لترا
  { {0x7de10048,0x6edb0008,0x7edb000a,0xcc890015}},	//   _vēst, _בחופ, _בקוצ, _منعه_
  { {0x63b8065d,0x6b9c00b8,0x97150010,0x26c50820}},	// [de10] kovn, birg, ймац, _šlo_
  { {0x25a60026,0x9cd8000a,0x38690144,0x9477002b}},	//   enol_, _דוחה_, rxar_, یدشا
  { {0xd6db010f,0x63b857cc,0x86080015,0x39520091}},	//   тта_, dovn, لقلق_, bdys_
  { {0xfe37013a,0x25a60152,0xe9450086,0x2509002b}},	//   שראי_, gnol_, _اردی, ارای_
  { {0xe5700015,0xb345016e,0xfd68000a,0x95540015}},	//   بطل_, jeçã, ישׁ֙_, تخلا
  { {0x63b800bd,0xf7850029,0xe800000b,0xd3780085}},	//   govn, _السَ, _लौटा_, _pića_
  { {0x65670054,0x0b18000a,0x0000006a,0x0000006a}},	//   _књаж, שַׂר_,   ,
  { {0x01650083,0xf3ff001c,0xf992000a,0x61e857cd}},	//   скио, _ção_, ּ֨ה_, _dudl
  { {0xdb0e00dc,0x68fb007c,0x63b857ce,0x4255009a}},	//   őkés, _õudu, bovn, _گنار
  { {0x2374003b,0x39520007,0x63b8099c,0x0309000a}},	//   _والح, zdys_, covn, _תִּֽ
  { {0x1d0a0c96,0x645e003d,0xfce6030c,0xdb0a0046}},	//   лени_, āpie, йоно, áním
  { {0x443f00e8,0x645b0150,0x463a004c,0xada60033}},	//   _kpu_, _krui, נערע, самл
  { {0xf00b0010,0xb345001c,0x7fd5005e,0xd5b10016}},	//   _рэек_, ceçã, _лікі, _ếu_
  { {0x0056039e,0x9056000a,0x443f01d7,0x69d80030}},	//   _לשנת_, _לבנו_, _mpu_, _évez
  { {0x25a60176,0x7df30011,0x753b0085,0x6b9c57cf}},	//   ynol_, _băse, _obuz, rirg
  { {0xfaa31006,0x69cf0bc5,0x63b81d94,0x6d96003d}},	//   часо, _chce, zovn, kšai
  { {0x8d760086,0xed59002c,0xf1df000b,0xe8ca0054}},	// [de20] _ناکا, ôže_, _पूछन, угал_
  { {0x4b2606b4,0x25a60026,0xdb240086,0x9b460087}},	//   _умов, wnol_, _بودی, _اندو
  { {0xe7370080,0xd94600a5,0x8f9a000a,0xe61a03b1}},	//   сех_, _лени, ניעי, уде_
  { {0x7df30011,0x7c260089,0x6eba004c,0xd5b9008b}},	//   _găse, oukr, אצעס, асі_
  { {0xe4e50036,0x645b0541,0x63b857d0,0x3957000a}},	//   цієн, _crui, tovn, _השכם_
  { {0x53e50036,0xdc37004c,0xcc3b004c,0x29001ed6}},	//   іціа, מאנט_, רעסט, lbia_
  { {0x6d5a0024,0x7c26003f,0x82330015,0x645b0079}},	//   ētaj, hukr, كريا, _erui
  { {0xa91b002e,0x6d46016f,0xb345001c,0x63b82f84}},	//   _alþj, jeka, teçã, sovn
  { {0xc9530008,0x6d4657d1,0x23e5005e,0x63ad0003}},	//   למה_, deka, _дієв, éanc
  { {0x69c4018b,0xb345001c,0x442657d2,0xdb07001a}},	//   hlie, reçã, muo_, lljö
  { {0xc1060087,0xdceb0796,0xa2bf000b,0x82850015}},	//   _هواي, žičn, _लुप्, _وجمل
  { {0x6d4657d3,0xade300ce,0xdcfd01ec,0x0000006a}},	//   geka, яцьк, misī,
  { {0x637d0144,0x69c457d4,0x7c260030,0x442657d5}},	//   _sèni, dlie, gukr, nuo_
  { {0x44260007,0xd24600e5,0x3f82003d,0x3e570045}},	//   iuo_, ون_, īkus_, _făt_
  { {0x4426003f,0x69c401f1,0x8f37000a,0x3f9e57d6}},	//   huo_, flie, _הנוף_, mitu_
  { {0x929b0008,0x69c457d7,0x3f9e57d8,0xb9250015}},	//   אילת, glie, litu_, تفري
  { {0xdcfd0091,0x7d7c000a,0x9775005e,0x7799018d}},	// [de30] nksč, _תנחו, олаї, акар_
  { {0x3ef80008,0x9715005e,0x7d0f0030,0x69c41f9c}},	//   שִּׁ, імец, lacs, alie
  { {0x64400024,0x290004ed,0x69c457d9,0xcb12000a}},	//   _apmi, bbia_, blie, _קלט_
  { {0x4426003f,0xd6d857da,0x645b0159,0x947920d1}},	//   fuo_, сту_, _prui, ислу_
  { {0x5c5c0053,0x442657db,0xd4690180,0x59380033}},	//   ָדוק, guo_, риле_, _узяў_
  { {0x6d4657dc,0xe81e005d,0xcec30089,0xfa34002b}},	//   zeka, _पिता_, _jiří_, _برید
  { {0xf1b90024,0x4b7c57dd,0x2d8201f0,0x6675002b}},	//   toš_, רטוג, ykke_, _بگذر
  { {0x44260035,0x91e20063,0xc517002b,0x6a9c004c}},	//   buo_, моще, _دبست, טשונ
  { {0x61e257de,0xd00e0015,0x44990033,0xd0580033}},	//   _diol, نلي_, _тваю_, брэі_
  { {0x764e0176,0x69c40024,0x7df30011,0x3f9e013c}},	//   _ysby, zlie, _născ, gitu_
  { {0x27e30298,0x798d00e8,0xa1190002,0x12e8000a}},	//   _mijn_, khaw, _نقاط_, _הַנּ
  { {0x68e200df,0x27e30111,0xd656000a,0x3f9e0509}},	//   žodi, _lijn_, קירת_, aitu_
  { {0xe6c6005d,0xef0e1853,0x69c457df,0x6d9632fc}},	//   _वर्ज, _ом_, vlie, kšav
  { {0xcff5002b,0xaae50015,0x6d9600bc,0x6d464d4d}},	//   _هيچک, كسفو, jšav, seka
  { {0x25bf0064,0x6d463591,0xb9760004,0xbad50033}},	//   _okul_, peka, оѓањ, зіты
  { {0xddc30404,0x6d960085,0x290b57e0,0x798d2a19}},	//   _общи, ešav, _ceca_, ghaw
  { {0x6bd60015,0x290057e1,0x290b1e90,0x91fc003d}},	// [de40] _وتخر, rbia_, _deca_, _grāf
  { {0x798d00d9,0x7d26002b,0xb6a6312e,0x69c457e2}},	//   ahaw, _افکن, оизл, slie
  { {0x69c457e3,0xcfb6000a,0x7c430085,0xfa6a1c7d}},	//   plie, קלעי_, čvrš, _танк_
  { {0x442657e4,0x2e3a0053,0xe45a0760,0x9b46002b}},	//   tuo_, יגענ, иже_, _انگو
  { {0x20190057,0x27e30079,0xe2f8008b,0x61e257e5}},	//   ásil_, _fijn_, белі_, _riol
  { {0x61e2002d,0xd3d70015,0x925a0015,0x7d0f0030}},	//   _siol, يبوا_, لشعر_, zacs
  { {0x63ad002f,0x018a005e,0x3f9e2398,0x61e257e6}},	//   éana, ищий_, vitu_, _piol
  { {0x27e30a9c,0xeb9f003c,0x3d04000b,0xa697000a}},	//   _zijn_, nsør_, लरों_, _וכלה_
  { {0xf5570015,0xa0670054,0x61e20d67,0x232a1c80}},	//   _بلقب_, жања_, _viol, _вози_
  { {0x60c2000c,0xdfd000e6,0xaac0000b,0x61ee0003}},	//   _vyom, عيد_, _शुभक, _éblo
  { {0x0dcb000d,0x7df30045,0xddc90091,0x61e257e7}},	//   иуми_, _răsc, rydž, _tiol
  { {0xc05a0127,0x2006002a,0x614601f3,0x3f9e4bdb}},	//   _вік_, _twoi_, _феда, situ_
  { {0x83fd00dc,0xff4f0086,0x9ccb0010,0x290b02b9}},	//   _erőf, رخی_, рына_, _reca_
  { {0x33f00251,0xc2140008,0x290b0d29,0xf36a004f}},	//   _màx_, ּהּ_, _seca_, ׁדָּ
  { {0xfe6f0029,0xd378016f,0x7ac40286,0x27e32322}},	//   _لدي_, _moć_, дсте, _rijn_
  { {0x27e30079,0x57f5009b,0x0000006a,0x0000006a}},	//   _sijn_, зпат,   ,
  { {0x3ce9007c,0x27e30079,0x8ae700fd,0x4dd40015}},	// [de50] _igav_, _pijn_, _мінл, _تتوس
  { {0xd378016f,0x7d0d007c,0x3ffb004c,0x99e4006f}},	//   _noć_, _heas, יפמע, ĺňat
  { {0x6e28018c,0x6da4016f,0x6d960729,0x7d0d088a}},	//   nudb, rđav, ršav, _keas
  { {0xa92700e5,0x85e8005e,0xe4510015,0x27e30079}},	//   _بعده, ідів_, فضت_, _wijn_
  { {0xdb150089,0x7af5005c,0x7d0d0541,0x26de0030}},	//   hozí, oczt, _meas, _úton_
  { {0xa87a013a,0x7df30011,0xceb80007,0x6d5a0024}},	//   _האשר, _lăsa, ngęs_, ētai
  { {0x51f50015,0xa91b001a,0x7c3a0045,0xeb92000a}},	//   أستر, _alþi, ătri, עָד_
  { {0xa0590015,0xe2900015,0xdb1c001a,0x6d96003d}},	//   مؤخر_, خذه_, ilrá, nšat
  { {0x7bc7065d,0x3dd20026,0x73c50015,0xb4670015}},	//   klju, _rhyw_, _فيرم, _بدأه
  { {0x3949002f,0x637d0251,0x5f450015,0x7bc707c4}},	//   heas_, _cènt, أندل, jlju
  { {0x7d0d065b,0xc7d8000a,0x6d960085,0x2258004a}},	//   _beas, חוזי_, kšat, _мифы_
  { {0x523a00b2,0x7d0d57e8,0x6d9600bc,0xd256000a}},	//   _לײענ, _ceas, jšat, _משעה_
  { {0xd1b80074,0x80690115,0x7d0d173e,0x394957e9}},	//   _بالا_, _دمشق_, _deas, deas_
  { {0x70520029,0xff510086,0xf092000a,0x98a00091}},	//   _أنوا, _سخت_, _אנד_, ngią_
  { {0x91fc0024,0x2a350010,0xa96a05b3,0x7d0d57ea}},	//   _grād, мэтр, бива_, _feas
  { {0x6d960007,0x7bc701bc,0xfe7000c3,0xceb2000a}},	//   tšau, alju, _جده_, _ריה_
  { {0xa2a2014e,0xb80a0015,0x57e701f3,0x3f850061}},	// [de60] _केन्, صيام_, здум_, oklu_
  { {0x7984005c,0x47c31a11,0x6d5647b5,0x3f850091}},	//   skiw, ебув, _haya, nklu_
  { {0x6b810064,0x4b7b0447,0x5b7b000a,0xc7af0015}},	//   ölge, _האיו, _הריא, دّل_
  { {0x63ad002d,0x394916ee,0x6d562bd5,0x6d9601ec}},	//   éann, ceas_, _jaya, pšau
  { {0x291211d0,0xe4e30127,0x14ba00e6,0x6d561c4f}},	//   maya_, нішн, حداث_, _maya
  { {0xcc3b0053,0x6d56064e,0x2d990140,0x291257eb}},	//   מענט, _laya, érez_, laya_
  { {0xe1d80010,0x3c3602de,0xed610046,0xe6433770}},	//   одкі_, hæv_, ížky_, _перп
  { {0x7de80089,0x6e280123,0x291257ec,0x91e30054}},	//   _měst, vudb, naya_, ноје
  { {0x7d0d3bd6,0x291200e8,0xd378002a,0x7df30045}},	//   _reas, iaya_, _toć_, _răsa
  { {0x74130029,0x7d0d0541,0x29120509,0xa857000a}},	//   _أولا, _seas, haya_, ליפה_
  { {0x7bc7010b,0x7d0d0100,0x6d562eed,0xf773000a}},	//   vlju, _peas, _baya, תקת_
  { {0x6e280134,0x29120375,0xadbd01f3,0x0000006a}},	//   rudb, jaya_, рамi,
  { {0xdb1c002e,0x21770008,0x2912013c,0x6d5657ed}},	//   ilræ, _מתאר_, daya_, _daya
  { {0x7d000061,0xdb15006f,0x629c001a,0x6fb40015}},	//   ımsa, pozí, _þros, _تمتا
  { {0xdcfd0024,0x29120064,0x39490ac5,0x2f3b000a}},	//   aksā, faya_, teas_, _הגוד
  { {0x291257ee,0x58bb0015,0xdd980033,0x7bc70123}},	//   gaya_, ماذج_, _ншы_, slju
  { {0x57790010,0xa40b000b,0x3eae003d,0x7bc70085}},	// [de70] обаў_, _सौंप_, šotā_, plju
  { {0xd87400e6,0x394957ef,0xc66b004a,0x6f1c0125}},	//   راقب, seas_, йшее_, órch
  { {0x4b7c0008,0xcdd50008,0x39490077,0x6d5a003d}},	//   _לאזו, ֵךְ_, peas_, ētav
  { {0x7ddf138a,0x210000bc,0x20190030,0x0596002b}},	//   _būsi, nčič_, ásik_, وانگ
  { {0xc9520008,0x87070033,0x43952df1,0x3f8557f0}},	//   _סמך_, _няве, мадс, yklu_
  { {0xcc58000a,0x43420033,0x0000006a,0x0000006a}},	//   פסוק_, вешв,   ,
  { {0xc7b2000a,0x91fc003d,0x2b8f0061,0x98a0002a}},	//   _סבל_, _arāb, _güce_, rgią_
  { {0xf652000a,0x806504b9,0xb5a401c6,0xa15600af}},	//   _בצל_, движ, _зруй, даћу_
  { {0x7ddf003d,0xb97c000a,0x6d560275,0x34940128}},	//   _gūsi, מנהי, _raya, _затр
  { {0xfe71002b,0x0ea90088,0x2b8f0061,0x29120061}},	//   ندج_, жкой_, _yüce_, zaya_
  { {0x291204a7,0x6d56043a,0x63a357f1,0x0000006a}},	//   yaya_, _paya, minn,
  { {0xb2ba0008,0x63a314bb,0x0d9a0033,0xdb07002a}},	//   _ומער, linn, ітны_, kojó
  { {0xd1b80029,0x63a3002d,0x4f95017c,0x628357f2}},	//   _عاما_, oinn, _орку, lyno
  { {0xa3cd014e,0xa3bf014e,0x7de80046,0x63a35643}},	//   रति_, ीति_, _pěst, ninn
  { {0x2912117f,0x6d5628fa,0x4efa000a,0x6e920015}},	//   taya_, _taya, _והצו, _للوا
  { {0xbbe9002b,0xe8560015,0x6da40085,0x63a357f3}},	//   _کريم_, ونزد, ađar, hinn
  { {0xa3cd005d,0x62830026,0xa3bf000b,0x60da004c}},	// [de80] रता_, hyno, ीता_, ַקענ
  { {0x6283002c,0x291257f4,0xc7af0015,0xf7190033}},	//   kyno, saya_, لّق_, зіцы_
  { {0x99d60029,0x98c30024,0x6f1c016e,0x29120fda}},	//   _يتجا, īvāk_, órci, paya_
  { {0xa2b1000b,0xdb150030,0xdb07002a,0xf8bf0144}},	//   _अख़्, mozá, bojó, _ccés_
  { {0x63a34297,0xe2f80033,0xdb150030,0xdb0e006f}},	//   finn, пелі_, lozá, dobú
  { {0xf6260292,0x42540015,0x80c1000b,0x62830034}},	//   _одго, فنتر, _लड़े, fyno
  { {0xc7b3000a,0x9757000a,0xd3b9005e,0x954a0015}},	//   _יבש_, _קילו_, чуці_, _وشرق_
  { {0xdb1c00c0,0x63a300e8,0x3cfa000b,0xf1a301b0}},	//   llrä, ainn, ूरों_, крын
  { {0xdb150014,0x65370053,0xcf26012c,0xdfda006b}},	//   hozá, _קאמף_, وردي, жън_
  { {0xdb150014,0x44260d5d,0xb23a0015,0xd497000a}},	//   kozá, mro_, _وكذا_, _חכמת_
  { {0xd12f061d,0xdb1c0003,0x9e140033,0x7c26352a}},	//   _их_, coré, эдні, erkr
  { {0x90460015,0xdb150307,0x44260ba6,0xdb1c0012}},	//   _يناه, dozá, oro_, hlrä
  { {0x5c74034e,0x41770015,0x210000bc,0x5c0701b0}},	//   влят, _تمنح_, rčič_, ьяна
  { {0x442603af,0xcf260086,0xdfa60087,0x9f34005e}},	//   iro_, _آرشي, _تحصي, _чекі
  { {0x44260026,0x2c09002b,0xdb150030,0x539b000a}},	//   hro_, _کعبی_, gozá, קילו
  { {0xceb30135,0xdce40057,0xc7f9005e,0xea000016}},	//   _שיק_, _znič, знає_, _giật_
  { {0x6283005c,0x657b005a,0xeb07112d,0x0000006a}},	// [de90] zyno, _rouh, _очно,
  { {0x657b34ff,0xdb150030,0x27e71ca2,0xdb07002a}},	//   _souh, bozá, önn_, rojó
  { {0xe6590029,0x657b0089,0x4439138a,0x442657f5}},	//   ثلاث_, _pouh, _ūs_, ero_
  { {0x63a3194b,0xfe06000b,0xaada000a,0x85040015}},	//   winn, वीएस_, _מחתר, نومن
  { {0x628306bd,0x78fa000a,0x442657f6,0xcd98000a}},	//   wyno, _מפרו, gro_, ודאת_
  { {0x63a3002d,0x6283002a,0x395951fe,0xdb1c2784}},	//   uinn, tyno, _hass_, toré
  { {0x63a35246,0xe7be000b,0x3959007c,0x7dd6006f}},	//   rinn, ्तरप, _kass_, láse
  { {0x63a357f7,0x3cf9000b,0x63a40125,0xc952000a}},	//   sinn, ंडों_, éinr, ָ֞ה_
  { {0x20190014,0x80a90142,0x395957f8,0x00c6006b}},	//   ési_, явив_, _mass_, нлък_
  { {0xeafb005d,0x82f80086,0x64a40054,0x7ddf003d}},	//   ्रोत_, _قرمز_, _рађа, _mūsu
  { {0xd131003b,0x1ee70086,0x398e002e,0xf772000a}},	//   _مما_, بودی_, _lýsa_, אקי_
  { {0xf2d20053,0x3f8e003f,0xdb0a0057,0xfbc9000a}},	//   _געב_, _elfu_, čník, _הת_
  { {0x70550015,0xe536004c,0x7c28002a,0x0d832fa0}},	//   _سنغا, עטשט_, ądro, улян
  { {0x207a0053,0xdb1500dc,0xdce400bd,0xe51f000b}},	//   _מאנא, tozá, _unič, मृति_
  { {0xfb85008f,0x1a660086,0xada6070e,0x6b81002e}},	//   тыўн, ریحی_, _пакл, ölga
  { {0x79a50001,0xdb154324,0x442654a4,0x39590f21}},	//   врђе, rozá, yro_, _cass_
  { {0x39590bcf,0xfc320029,0x6d0b000a,0xdd8f0015}},	// [dea0] _dass_, _صحة_, _מִיַ, _دوي_
  { {0x4426001c,0xdc3b0008,0x37c6002b,0x26de0107}},	//   vro_, _צעיר, رياف, _útok_
  { {0x39590012,0x4426028a,0xa52600eb,0xbd5a004f}},	//   _fass_, wro_, емед, ּכְש
  { {0x442636f9,0x7dd60030,0x395900cb,0xc7a9004f}},	//   tro_, lásb, _gass_, זב_
  { {0xe5e7002b,0x14170015,0x6fb1000b,0x69c601de}},	//   رزمی, فينة_, ीकां, _ikke
  { {0x77910086,0x8c1b0008,0xb6070092,0x25b20034}},	//   _پیما, לוני, _khớ, ŵyl_
  { {0x599a0008,0x6d4457f9,0x44260073,0x0000006a}},	//   ּשִׁ, _obia, sro_,
  { {0xd259008f,0xe5060015,0x2a3b000a,0x6626003d}},	//   ьці_, _سبري, לעצמ, īskā
  { {0xf9930008,0xdfa60b1e,0xcfa61119,0xf42a011e}},	//   טרה_, ејно, ешни, _хозл_
  { {0x389b01d8,0xf837000a,0x25a657fa,0x63060015}},	//   פיינ, ענית_, liol_, _أوال
  { {0xdd95008f,0x17970008,0xbcfb00dc,0xa3bf000b}},	//   ваны, גדיל_, ndég, ीतर_
  { {0x2e38002e,0x25a60d0c,0x222b002b,0xd1300015}},	//   réf_, niol_, _رزمی_, _ضمت_
  { {0x142a0008,0xdb1c0026,0x2175005e,0x4034006b}},	//   הוָ֑, gorï, _шуфр, _релс
  { {0x25a60026,0xbdf7002b,0x6298128d,0xc0a9002b}},	//   hiol_, بریا_, ozvo, _تامل_
  { {0x2d99038d,0xeef70008,0xaf5b000a,0x7ddf0091}},	//   ères_, _אמור_, _זכוכ, _būst
  { {0x6298052c,0x7dd610e5,0x7c950015,0xb886006f}},	//   izvo, táse, _للبص, zníž
  { {0x25a60176,0x2bd2005d,0xe8940142,0x6ca40033}},	// [deb0] diol_, _दीवा, гать, _брэж
  { {0x69c6002e,0x6d4f57fb,0xd6db012f,0xf8680015}},	//   _ekke, leca, пте_, عملي_
  { {0x765a002c,0xf7700115,0xe6130015,0x9f4f0123}},	//   _štyr, حاق_, اشط_, _utgå_
  { {0x2d8b0089,0xceb3000a,0x7ddf003d,0x6d5d57fc}},	//   nkce_, ניף_, _gūst, ndsa
  { {0x76550050,0x2909000c,0xc9160008,0x69cd0026}},	//   _wszy, mbaa_, _בחרת_, mlae
  { {0x1707002b,0x2bf8000a,0x71f90015,0x7c3d0012}},	//   _سفری_, עמון_, وربس_, itsr
  { {0xa9240089,0x69cd0026,0xf628005e,0x41b51e87}},	//   ůžet, olae, _піти_, ксит
  { {0xe2a8003b,0x6d4f016f,0x7dd600dc,0x6d5d57fd}},	//   عاون_, jeca, zásb, jdsa
  { {0x6d4f48a0,0x62980b28,0x4f95012e,0xe45f0030}},	//   deca, azvo, врну, _éö_
  { {0xe4480015,0x91fc003d,0x9f850190,0x2d8b0046}},	//   _سلمى_, _irān, тгод, ekce_
  { {0x9f470089,0xd37a0053,0x9f4f0003,0x3940001a}},	//   _jiné_, _קרעט, _jugé_, yfis_
  { {0xd1b80015,0xc2c40015,0x91fc003d,0x7dd60030}},	//   _كانا_, _صيني, _krān, dásc
  { {0x69cd0176,0x557600b2,0x7dd600dc,0x442f00b8}},	//   dlae, דערן_, tásb, nug_
  { {0x8fa503ec,0x69cd096b,0xfc030681,0x2bb40065}},	//   _шале, elae, рпро, ूकधा
  { {0xc33201e4,0x442f0125,0x7dd60030,0x7c3d0db6}},	//   יום_, hug_, rásb, atsr
  { {0x3a250084,0x61fc0030,0x5ee8000a,0x6d4f57fe}},	//   álpa_, _érle, _אַפְ, ceca
  { {0x61eb02d7,0x39404c71,0x09e34bee,0x57ea1111}},	// [dec0] _migl, rfis_, ротн, ддам_
  { {0x25a60026,0x386057ff,0xe7b300c3,0x442f52f8}},	//   wiol_, rvir_, لمقد, dug_
  { {0xe9da0124,0x60cb0007,0x6e4c000a,0xcb13000a}},	//   _око_, _lygm, ּׂדֶ, _דלת_
  { {0x8ab70008,0x75890036,0x2d800152,0x99f7000a}},	//   _יהיו_, нсів_, _joie_, _שזכה_
  { {0x25a60026,0x99980089,0xe70a0058,0xdb1c00d4}},	//   riol_, ltrů_, _يتسن_, morâ
  { {0xd7030063,0x61eb0003,0xdceb0085,0x25a60034}},	//   _взри, _aigl, žićn, siol_
  { {0x82330029,0x65c60033,0x6d4f0061,0x46a6004a}},	//   لريا, _абва, yeca, _равв
  { {0x6d4f0144,0xdb1c5800,0xd54a002b,0x69c4239d}},	//   xeca, norâ, _تجسم_, noie
  { {0xbcfb0003,0x443d002a,0x301301b0,0x6d4f0085}},	//   ndée, ctw_, адыр, veca
  { {0xd3460086,0x836a0002,0x236a0058,0x0000006a}},	//   _شیعه_, _تصرف_, _تحري_,
  { {0x61eb02d7,0xf8bf0152,0xdb1c5801,0xa2e609ef}},	//   _figl, _idée_, gorí, _рожд
  { {0x60260010,0xa1830892,0x3987007c,0x61eb5802}},	//   _адда, _вышл, _tõsi_, _gigl
  { {0x201902d5,0xada40010,0x709a0015,0x6d4f0490}},	//   ásit_, раўл, _تنشأ_, reca
  { {0x8fa30b18,0xaa59030c,0xdb1c19fe,0x7c3d5803}},	//   _каче, нигу_, borí, rtsr
  { {0x442f5804,0x63ad0003,0x60cb002a,0x61e50046}},	//   zug_, éani, _zygm, ůhle
  { {0x79960026,0xa8060064,0xe9b4005e,0x7bce5805}},	//   ghyw, ktığ, абсь, albu
  { {0x3dc900b6,0xcd340029,0x98140015,0x99850030}},	// [ded0] _ikaw_, _ضريب, لبلا, élő_
  { {0x8c1c000a,0x7f840144,0xd7590015,0x69cd5806}},	//   _חוזי, _tòqu, علات_, slae
  { {0xcf9300b2,0xd0060086,0x7dd600dc,0x9474002b}},	//   סטע_, _گل_, lása, یدها
  { {0x35b50080,0xceb3000f,0x442f0e05,0x453400ce}},	//   ыбер, ביע_, tug_, ихіт
  { {0x2458008f,0xef180024,0xd0060087,0xfc3f39a9}},	//   каць_, kaļ_, _دل_, ntí_
  { {0xa856013a,0xdb1c02c1,0x61eb5807,0x442f5808}},	//   _גישה_, yorí, _sigl, rug_
  { {0x05bb0074,0x443d005c,0x6b7c0008,0x61eb3536}},	//   _قدرت_, stw_, ורגנ, _pigl
  { {0xdb1c002c,0x7dd60030,0x61fe0046,0x9f46001a}},	//   vorí, kása, ípla, _stoð_
  { {0x11d60015,0x5184012e,0xf994004f,0xd434009a}},	//   دوية_, руја, ירק_, _نعلب
  { {0x2d990298,0x2f550036,0xaf050080,0x7dd600dc}},	//   ëren_, утис, ыпол, dása
  { {0x225b0015,0x5595000a,0x2229009a,0x0000006a}},	//   _تجذب_, ָדָע_, _سزای_,
  { {0xed570036,0xc1050015,0x20b9004a,0xc8840061}},	//   гою_, _صوتي, _пыль_, _yağı_
  { {0x711a013a,0x2d805809,0x808b0015,0xdb1c41d5}},	//   _נוספ, _voie_, _تضاف_, vorâ
  { {0xe50a000b,0xdb1c0030,0x798d002a,0x501a000a}},	//   _ह्नि_, porí, ekaw, _טונו
  { {0x69c4096f,0x7f3a000a,0x6eca0065,0x4f3a004f}},	//   toie, _נעקו, _सुपु, _נתקע
  { {0x7dd60030,0x798d02f2,0xceb2000a,0x6d4e0069}},	//   bása, gkaw, _ליו_, íhač
  { {0x79960026,0x3866002d,0x88c50015,0x78660033}},	// [dee0] rhyw, íor_, لتكل, ыказ
  { {0x386f00c0,0xf6d60086,0xdc9b000a,0xbcfb0003}},	//   ågra_, هزاد, _נסיכ, rdée
  { {0x80aa000b,0x41c3000b,0x8b57000a,0x452a01e1}},	//   _जेने, शवास, _גייס_, ежен_
  { {0xb5050029,0x29560063,0xa8060064,0xd5d50010}},	//   لظهو, _съор, ttığ, аючы
  { {0xd91b0008,0x7d16232a,0xd87600e5,0xbab3002b}},	//   _אוכל, _meys, _صاحب, _نمیب
  { {0x93260074,0xea000092,0x7d16002e,0xb907005d}},	//   ارشن, _ngẫu_, _leys, ये_
  { {0xe2460029,0x7dd600dc,0x92940033,0xd3350033}},	//   اختي, zása, райц, рэчы
  { {0x7df304f9,0xa8060064,0x75d60029,0xfc3f580a}},	//   _găsi, ptığ, _إيرا, ytí_
  { {0x2fc500b8,0x351b000f,0x251b000a,0xf8b4000b}},	//   folg_, _רומנ, _רומא, ंपिय
  { {0xa857013a,0x04930015,0x2002003d,0x0857000a}},	//   נייה_, _الكح, īki_, נבים_
  { {0x2019002e,0xbf66002b,0x479b000a,0xa206006b}},	//   ásir_, ندگو, גייס, _спед
  { {0x7dd60014,0xab620061,0xb2bb000a,0xb886006f}},	//   tása, çünc, _אמבר, _zvíť
  { {0x71d7000a,0x5b270c6e,0x61d7000a,0xfc3f0046}},	//   _עודד_, льва, _עודף_, utí_
  { {0xbe860086,0xfc3f1d98,0xdb0e002a,0x7dd6171f}},	//   _مجبو, rtí_, dobó, rása
  { {0xe9190036,0x0ef90010,0xfc3f52a3,0x7d160034}},	//   кові_, _рэчы_, stí_, _feys
  { {0x19580010,0x7dd6580b,0x798d02f2,0x7d1653f9}},	//   ласы_, lásn, ukaw, _geys
  { {0x2d99002d,0x798d14f1,0x6e2e0030,0x5dcc000a}},	// [def0] mhse_, rkaw, ábbf, _אֶזְ
  { {0x994e0046,0xef11000a,0x798d035b,0x6f1a470b}},	//   _výš_, ַּב_, skaw, natc
  { {0xb8cc005d,0xb510000b,0x8afa000a,0xe981005e}},	//   _के_, ारूप_, _בהתי, _данi_
  { {0xceb30053,0xa2ff000b,0xe4510015,0x7bc7580c}},	//   זיע_, ॉर्ज_, قضت_, loju
  { {0xd91a000a,0x399e0046,0x588701b0,0x6d5f5713}},	//   _שושל, růst_, _сына, _maqa
  { {0x7bc7121a,0xe28509c3,0xd795006b,0x6f1a01c0}},	//   noju, илли, _тигъ, jatc
  { {0xa80601e2,0x6f1a016f,0x2fc5049c,0x7dd60030}},	//   rtış, datc, volg_, dásn
  { {0x91fc0024,0xf9920053,0xd185006b,0x94050067}},	//   _grām, ַרי_, рлий, _نوره
  { {0xa4d4005e,0x70520015,0xd347002b,0x7bc7580d}},	//   _готі, قنيا, _میشه_, koju
  { {0x2054010f,0xff25000d,0xa858000a,0x5f76002b}},	//   стър, јмно, ריזה_, لاپر
  { {0x7bc7121a,0x4155007a,0x6d5f01c2,0x1d0a0912}},	//   doju, _ввес, _baqa, кени_
  { {0xc27a000a,0xdb070012,0xfce6580e,0x3519000a}},	//   _ברעי, hnjä, ионо, כוֹנ
  { {0x395200f2,0x7d1b001a,0x7bc70072,0x0000006a}},	//   veys_, ðusa, foju,
  { {0xae990015,0xe3a70040,0xdee508ad,0x7bc713b3}},	//   _لضبط_, زر_, _коли, goju
  { {0x395200f2,0xbea22c0c,0x9f470046,0xca750033}},	//   teys_, _машк, _jiní_, буты
  { {0x7dd600dc,0x2d9900b8,0x66760086,0xdc350264}},	//   máso, chse_, یدار, _zúčt
  { {0x7bc70024,0x7dd600dc,0xa88710cb,0xd7f9005e}},	// [df00] boju, láso, айта_, гує_
  { {0x753b0011,0x27ee002e,0x7bc70024,0x661b002a}},	//   _acuz, öfn_, coju, _łuka
  { {0xdb0e005c,0x85060087,0x645b008c,0x6b7b000a}},	//   sobó, لوان, _asui, _סרטנ
  { {0x3abb0008,0x7dd600dc,0xe5720015,0x84ea0015}},	//   _ימינ, zásn, غطا_, نفاق_
  { {0x66090089,0xf3e6004a,0x63aa013c,0x628a0034}},	//   _čeke, аждо, tifn, wyfo
  { {0x7dd600dc,0xbcfb002d,0xb4d6000b,0x9cd7000a}},	//   káso, idéa, _हरी_, בונה_
  { {0x2b4701e2,0xd2500029,0x7ddd00dc,0xcb13000a}},	//   _önce_, سنة_, lése, חלו_
  { {0x7dd600dc,0xd1300029,0x7bc7003f,0x29001309}},	//   dáso, أمة_, zoju, ncia_
  { {0x7ddd0014,0x7df304f9,0xd007000d,0x7dd600dc}},	//   nése, _măsu, аење_, tásn
  { {0x63ad0c1b,0xc43b000a,0x6fb40015,0x65600125}},	//   éant, _בתמי, إمدا, _hamh
  { {0x2900002c,0x36f70008,0x539b0008,0xa3e3021e}},	//   kcia_, יצים_, _שיבו, नगर_
  { {0x6560003f,0x6562003f,0xdb1c016e,0x6442008c}},	//   _jamh, ndoh, vorá, otoi
  { {0x7bc7580f,0xc19b000a,0x31ba003d,0x64425810}},	//   toju, _בשאי, cīza_, ntoi
  { {0x7ddd00dc,0x764e0134,0xc0a90002,0x8e37002b}},	//   dése, _opby, _حامل_, دسیر_
  { {0x7bc70048,0xdced016f,0x644200f2,0x39a7023e}},	//   roju, _inač, htoi, ашав
  { {0x7df30011,0x7dd60046,0x6ca70248,0xd90f002b}},	//   _căsu, násl, _врож, بیح_
  { {0xed59002c,0xc60f005d,0x7d1d5811,0x87070015}},	// [df10] ôžu_, ाठ्य_, mass, لبال
  { {0xe7190196,0x753b0011,0x290002c1,0xe7330115}},	//   ايات_, _scuz, acia_, تصر_
  { {0x6f1801e2,0x6442008c,0x66270015,0xcb12000a}},	//   _mevc, etoi, شراك, _מלי_
  { {0x290002d7,0x09e4000d,0x7d1d5812,0x7ddd0030}},	//   ccia_, _моќн, nass, lésb
  { {0x7dd60014,0x65600395,0x89da000a,0xe8160065}},	//   záso, _damh, _תחרי, दीदा_
  { {0xb3c8017f,0x7c2f00da,0x98a9002a,0x7d1d5813}},	//   аліз_, ircr, egać_, hass
  { {0xe695003b,0xcb140008,0x06850015,0xdb0e0030}},	//   _الأد, קלק_, _الزُ, ákér
  { {0x0f01000b,0xbf01000b,0xe5340033,0x78b80085}},	//   ोर्स_, ोर्न_, _месь, šavš
  { {0x64420152,0x81a40015,0x91690016,0xa1560054}},	//   ctoi, تحول, _cứu_, сању_
  { {0x7dd603c0,0x3f83002e,0xc0c80001,0x29195814}},	//   táso, ðju_, јуће_, _lesa_
  { {0x7ddd32c9,0x7d1d018b,0x201f001c,0x2900005c}},	//   zése, fass, ssui_, ycia_
  { {0x7d1d0014,0x7db60029,0x7dd600dc,0x29190026}},	//   gass, إصدا, ráso, _nesa_
  { {0x515a0008,0x2d9e0007,0x6d46108a,0x7df30045}},	//   _תכנו, ėte_, rfka, _răsu
  { {0x3b95049d,0xf412000a,0xef190004,0xcff6000a}},	//   ојст, הפך_, _смк_, _פצצה_
  { {0xdcfd0061,0x2900006f,0x699622ff,0x09fa0015}},	//   ansı, tcia_, брах, افرة_
  { {0x7ddd03c0,0xe9df0023,0xcc8a003b,0xac9a0015}},	//   tése, _chú_, _منبه_, _منعا_
  { {0xa9671660,0x2bba0029,0x06f60015,0x29195815}},	// [df20] щита_, _مادة_, مساج, _desa_
  { {0xc8b5008f,0x7ddd4a54,0x29005816,0xa510000b}},	//   істы, rése, scia_, ार्च_
  { {0x7ddd0014,0xd7ef0015,0x86c60015,0xe5060015}},	//   sése, ركم_, حيان, مبشي
  { {0x7ddd0014,0x4a5b0008,0x3eda0053,0x66030089}},	//   pése, _עדכו, אַדא, ínka
  { {0xf3f10023,0xfe670086,0xd4f50033,0xdb1c0144}},	//   _bị_, _کد_, іяцы, gorç
  { {0xd7960015,0x644225a2,0x66e60033,0x9cd7000a}},	//   _السخ, rtoi, _гога, זונה_
  { {0x64425817,0x171b000a,0x7d040aa5,0x2006002a}},	//   stoi, _תולע, _ofis, _stoi_
  { {0x7ddd00dc,0x60f80063,0x15431206,0x7c245818}},	//   zésb, шния_, _несм, _ovir
  { {0x6f1800bc,0x75d30015,0x7d1d5819,0xdb1c0144}},	//   _pevc, _ريكا, vass, corç
  { {0x8ff70029,0x2f140010,0x7d043b6d,0x63a40161}},	//   حرير_, ўднё, _afis, ëind
  { {0x7ddd00dc,0x34b8000b,0x8266002b,0x7d1d581a}},	//   vésb, _अशुद, _دهان, tass
  { {0xc6930053,0x7df30045,0x68e20091,0x71650058}},	//   פאר_, _răst, žody, _وانك
  { {0x3ced0020,0x7ddd00dc,0x0cab10a6,0x2919581b}},	//   äev_, tésb, утни_, _resa_
  { {0xa4b70008,0x7df30011,0xce940063,0x61fa1e8c}},	//   מלכה_, _păst, _малъ, _kutl
  { {0xe9df0092,0x99d70029,0x29190863,0xb927006b}},	//   _phú_, مترا, _pesa_, йфай
  { {0x442f002e,0x7ddd00dc,0xa815006b,0x661b002a}},	//   yrg_, sésb, ждаш, _łuko
  { {0x91690092,0x7ddd00dc,0x99d40002,0x8c240015}},	// [df30] _hữu_, pésb, ستفا, _ففيه
  { {0x6fdd0152,0x6fba005d,0x9c180008,0x2919003f}},	//   pèce, ैकिं, _החזק_, _wesa_
  { {0x9f470089,0x6ead005d,0xe9df581c,0x07080015}},	//   _jiná_, ुपयु, _thú_, صيني_
  { {0x2e3b0053,0x7bd500b8,0xc4f80015,0xa4d50054}},	//   רגאנ, llzu, معها_, ожељ
  { {0x442f2734,0x29d7016e,0x94040015,0x34ab012c}},	//   urg_, nçam_, كونه, دداً_
  { {0x9cd80008,0x8c1c0135,0xd61b0015,0x420916e7}},	//   צוגה_, נווי, _مترا_, анко_
  { {0xf3f10023,0x3869581d,0xadfd000b,0x35f5005e}},	//   _vị_, lvar_, _ईंधन_, _єпар
  { {0xdb1c016e,0x80dd000b,0x7dd60030,0x3949581e}},	//   porç, _परदे, tásm, nfas_
  { {0x71240015,0x93b50033,0x7ddd0030,0xd49b009b}},	//   سريل, _дбац, zésc, _срв_
  { {0xd00e0086,0x02450015,0x6fa90054,0xb6040091}},	//   کلی_, _وَذَ, рвог_, _ūšiu
  { {0x76450026,0x7c24581f,0x0eb901b0,0x05de000b}},	//   nthy, _svir, рупы_, _फीडब
  { {0xe2940053,0xcb09000a,0x763a004c,0xd5b2000a}},	//   _צװײ_, _יל_, סערג, ֵׁם_
  { {0x5d670080,0xf1d5000b,0xa0c50015,0xac930033}},	//   циям_, _डीएन, _بيشو, даўш
  { {0x7ddd0014,0x9f4300f2,0x6d4d007c,0xa088000a}},	//   tésc, öjä_, _ebaa, _לְצִ
  { {0x38690024,0x1be7005e,0x4229000a,0x29d70527}},	//   evar_, ідси_, יֵּ֣, açam_
  { {0x3946008f,0x7c240007,0x7ddd016e,0x17fa0058}},	//   ўнаг, _tvir, résc, لرئة_
  { {0x77860001,0x76450026,0x3f871cf9,0x66091b4b}},	// [df40] олаз, ethy, _konu_, _čeka
  { {0x3b0a0001,0x2d82044c,0xdaaa004a,0xcc09009a}},	//   _њено_, ljke_, _ввод_, _ازين_
  { {0xd6260029,0x4c050086,0x7dd6171f,0xa6c70054}},	//   تعذي, _وظیف, vásj, олфа_
  { {0xceb200f3,0x89360067,0x7dd60030,0x4424008c}},	//   ויב_, _بعدا, dásk, _pvm_
  { {0x19570008,0x5c37004c,0x53e61de1,0x7dd60030}},	//   _ובכל_, ַרקן_, оцка, tásj
  { {0x366a0010,0x9afa000a,0xe7320015,0xb6a60054}},	//   _каго_, ׁפְח, _تصح_, _дигл
  { {0xe2970124,0x1b7b004c,0xd627226f,0x7dd61ad6}},	//   жај_, יטסע, _море_, rásj
  { {0x76430144,0x99f7000a,0x6fd40144,0xf67b004f}},	//   ànye, חזקה_, màci, _דאלמ
  { {0xb145002b,0x83fd0030,0x0000006a,0x0000006a}},	//   سیوم_, _csőd,   ,
  { {0xff980124,0x7dd600dc,0x30170015,0x1877004c}},	//   ској_, lásh, آتية_, קעיר_
  { {0xb7db0053,0x41060010,0x6146042b,0xd252002b}},	//   שקיי, _дзев, _межа, _زنش_
  { {0xeda7005e,0xdb07006f,0xb1e50058,0xfe6d009a}},	//   ішно, rijí, _فأنه, اگو_
  { {0xed580010,0x7b67058b,0x3f875820,0x0000006a}},	//   цоў_, отве, _fonu_,
  { {0x60d70008,0x76450026,0x69d600dc,0xa00700c3}},	//   _וודא_, ythy, elye, _بقول_
  { {0xdb0e00dc,0xf99300c3,0x61e235aa,0x5a440033}},	//   ójáb, وبر_, _khol, мэта
  { {0x3f8732fc,0x2bdb0065,0x3869344c,0x0000006a}},	//   _zonu_, _मीरा, tvar_,
  { {0x61e2002d,0xbcfb3187,0x0bab0015,0x7dd60030}},	// [df50] _mhol, ndém, _نادى_, dásh
  { {0xe9450086,0x2b580045,0xd66b0054,0x76455821}},	//   _کردی, cerc_, ијел_, tthy
  { {0xd5750a7f,0xa3c0000b,0x96b80015,0x7c2a003d}},	//   зуль, ीवन_, يامز_, _āfri
  { {0x76450176,0xbc68002b,0x95c40015,0xea0000a1}},	//   rthy, _امین_, ويله, _hiết_
  { {0xa97a0008,0x397a000a,0xb97a000a,0x297a000a}},	//   _הארכ, _הטרנ, _הנרי, _הטרא
  { {0xd7fa0008,0x57f40080,0x7dd600dc,0x44640036}},	//   _להשל, _опят, tásk, ьвів
  { {0xdb1500dc,0x96080010,0x8b9c000a,0x6fd40144}},	//   lozó, _мэта_, שבות, càci
  { {0xd24e0070,0xe4e70036,0x3f872437,0x3abc00f3}},	//   اني_, _дізн, _sonu_, ימונ
  { {0x25ad00bd,0x600602bf,0xd00e0015,0x9627003d}},	//   _imel_, пным_, هلي_, saņē
  { {0x93970015,0x398e001a,0x7dd6016e,0x3f9e0046}},	//   _بجرا, _hýst_, mási, ghtu_
  { {0x80dd005d,0xc7b20008,0x59bd000b,0x53a40015}},	//   _परवे, תבי_, ्कार, _تملك
  { {0x6e2e00dc,0xdb1500dc,0x7ddd0030,0xc1040040}},	//   ábba, kozó, tésa, _قومي
  { {0xea000023,0x70fa0008,0x61e90b30,0xdb0e0003}},	//   _biết_, _ההנח, mmel, libé
  { {0x7dd600dc,0x398e002e,0x61e95822,0x3f81007c}},	//   zásh, _lýst_, lmel, _õhu_
  { {0x09e631f2,0xdb0e03a0,0x2b9402dc,0x0000006a}},	//   зовн, nibé, _häck_,
  { {0xf2d20053,0x61e95823,0x9b46002b,0x7ddd0030}},	//   געל_, nmel, _کندو, lésn
  { {0x6d8b000a,0x23cb000b,0x6d3b000a,0x7dd62ed5}},	// [df60] _הָיְ, िवाद, _התפנ, vásh
  { {0xea000092,0x4a460001,0x91fc0024,0x99f60033}},	//   _giết_, _енов, _krāt, _нямі
  { {0x7dd600dc,0xbafb0008,0x69c10152,0xeab200e6}},	//   tásh, _להיש, élec, _سعد_
  { {0x6f1c005c,0x6fd40144,0x7c2600bc,0x7d0602ad}},	//   órcz, ràci, oskr, ncks
  { {0x17fa0029,0x75d30086,0x7bce007c,0x7dd60030}},	//   _درجة_, ريها, oobu, rásh
  { {0x25ad0c76,0x53342923,0x03a3005e,0xf8db000a}},	//   _emel_, фект, ничо, _לחכמ
  { {0x9f4700f2,0x7d1b002e,0x61e2130f,0xcb37000a}},	//   _minä_, ðusk, _phol, לאסי_
  { {0xb6bb0008,0xdb1c00dc,0x78a406f2,0x61360061}},	//   _הצלי, gorú, oziv, dülü
  { {0x7df404f9,0xa0670054,0x78a41608,0x64a35824}},	//   _răsp, зања_, nziv, _зата
  { {0x61e2003e,0x81bc0024,0x2b940123,0x9f5f0144}},	//   _whol, _zvēl, _däck_, nquè_
  { {0xdb1c00dc,0xdd210091,0x7c262cb5,0x61e24a42}},	//   ború, rįžk, eskr, _thol
  { {0x753d00dc,0x7c26002e,0x61e2003f,0xc27b000a}},	//   _öszt, fskr, _uhol, _לרבי
  { {0x7054002b,0x9be7005e,0x44265825,0x7c265826}},	//   _آنتا, зівк, nso_, gskr
  { {0x44265827,0x200b5828,0x78a4006f,0x7d065829}},	//   iso_, ície_, dziv, acks
  { {0xea000023,0xbef70029,0xda7803fc,0x7ac438a1}},	//   _viết_, _عروض_, пят_, есте
  { {0xceb30008,0x5e430015,0xf1cc000b,0x59d90033}},	//   _ריק_, _أَيْ, ाविन, ідаў_
  { {0xea000023,0x91fc0048,0x69340010,0xb8d70015}},	// [df70] _tiết_, _krās, энту, سترش
  { {0x4c9c013a,0x307b0053,0x25ad00bc,0x61e90061}},	//   _לבחו, זאמנ, _smel_, zmel
  { {0x4426582a,0xcb12000a,0xcf93004c,0x78a40085}},	//   eso_, _שלט_, עטע_, aziv
  { {0x3ea10020,0x7ddd0030,0x7dd610e5,0xdb150030}},	//   _ühte_, zésn, tási, pozó
  { {0xf8c1014e,0xe4cb002b,0xe3650342,0xc867004a}},	//   _एशिय, حبان_, дкли, _этни
  { {0x6e3a4b0d,0x287a000a,0xe458005e,0xa87a000a}},	//   kutb, _ונשמ, яжі_, _ואשר
  { {0x7d060123,0x61e9582b,0x236500bc,0x9239008b}},	//   ycks, tmel, _valj_, ічку_
  { {0xd9e3005d,0x61e90045,0x7659002a,0xfa78000a}},	//   _कीमत_, umel, łwys, לעות_
  { {0x7ddd00dc,0xafe50004,0xaf35002b,0x8fa5058c}},	//   tésn, моил, وردت, дапе
  { {0xa8580008,0x91fc0024,0xd7bf000b,0x61360061}},	//   ליחה_, _prāt, ्विच, tülü
  { {0xdb1c002c,0x9f5f0003,0x83fd0030,0x61e90030}},	//   porú, nqué_, _erőt, pmel
  { {0x61360064,0x9f4700f2,0x0c260004,0x60e8001a}},	//   rülü, _sinä_, мммн, ármö
  { {0x4c830063,0x01340015,0x7bce582c,0x7196002b}},	//   вляв, _أعمد, tobu, _زنوز_
  { {0x6d4100dc,0x6ffa000a,0x7076002b,0xda6600c3}},	//   őlap, _והספ, _آموز_, وازي
  { {0xa3ce000b,0xfa671528,0x7bce582d,0x7c26582e}},	//   रवत_, марк_, robu, sskr
  { {0xe9da05fc,0x44260026,0xdd8f0015,0x09c8000b}},	//   іка_, yso_, _نوى_, लवेय
  { {0xeafa0015,0x68460033,0x798401c2,0xb9060065}},	// [df80] _وردت_, ьнаа, rjiw, _फर_
  { {0x386f001a,0x799600aa,0x0fa9004f,0x3c450058}},	//   ægra_, skyw, קֹּֽ, _أضيف
  { {0x9f5f08e0,0x5b7b0008,0x15460080,0x66250015}},	//   rquè_, _וריא, деем, فرنك
  { {0x4426104d,0xe57a055f,0x6fd403a0,0x0000006a}},	//   tso_, юзе_, làct,
  { {0x045a0029,0x4426582f,0x99830091,0xea000016}},	//   تجات_, uso_, aujų_, _khắt_
  { {0xa3a8005d,0x442625d5,0xf8b3000f,0x7dd60030}},	//   खों_, rso_, _ישר_, másu
  { {0x44265830,0x31ba0024,0x47d30015,0x7dd60030}},	//   sso_, līzi_, _شيفر, lásu
  { {0x3253010f,0x61430124,0xd25902e1,0x39405831}},	//   твър, већа, яці_, ngis_
  { {0xcfaa0029,0x39403f83,0xd46a0015,0x84370015}},	//   قادم_, igis_, _بحزم_, _يكفر_
  { {0x187b0008,0xada4005c,0x83fd00dc,0x39950123}},	//   קטיב, óźni, _erős, _påsk_
  { {0x07370008,0xd737000a,0x6fd40144,0x6db50138}},	//   ואים_, וטית_, dàct, ейну
  { {0x32170086,0x11da0015,0x6e3a0123,0x7ddd0003}},	//   _آيند_, _بوصة_, rutb, réso
  { {0xdb05002f,0x50e2005d,0x60230010,0x81430086}},	//   _amhá, _परिष, _адча, _شنون
  { {0x2124002d,0xa3ce000b,0x7dd60030,0x38600034}},	//   lamh_, रवि_, dásu, dwir_
  { {0x6fdd0003,0xbda70015,0x298b0054,0x2f3b000a}},	//   iècl, _يحبو, осао_, _וגוד
  { {0x2124002f,0x752000dc,0x2d840123,0xb0e20065}},	//   namh_, _nemz, ömet_, _पराग
  { {0x8b670029,0x9848006b,0x21240125,0x6d5d5832}},	// [df90] _قادم, дяха_, iamh_, mesa
  { {0xb7d50002,0x5838004a,0xb7140015,0x399c001a}},	//   رقاب, ьзуя_, نظمت, _vísa_
  { {0xa535000d,0xfbdf001c,0x8b88000a,0x7c3d014b}},	//   енеч, ntêm_, _חָרֶ, lusr
  { {0xfa960008,0x9f5f2038,0x2d990079,0xe98102a3}},	//   _נדרש_, rqué_, nkse_, _самi_
  { {0x31ba0024,0x6d5d0024,0xc9520008,0x21240125}},	//   cīzi_, iesa, _עמך_, damh_
  { {0xd7c90086,0x6d5d0c59,0x44290016,0xd37b0681}},	//   _روزه_, hesa, ĩa_, юче_
  { {0x7ddd00dc,0x6d5d0801,0xdd1f000b,0x6e2e0030}},	//   tésl, kesa, पराध_, ábbl
  { {0x2d990111,0xdb070f7a,0x6d5d20f6,0x6d4f0079}},	//   jkse_, lijä, jesa, jfca
  { {0x6d5d5833,0x89ec000a,0x83fd01d3,0x0000006a}},	//   desa, חַזֵ, _erőr,
  { {0x0ea90080,0x7c3d0db8,0x2d99016b,0xa283002b}},	//   зкой_, dusr, ekse_, _لیتو
  { {0xb1150033,0x7dd60030,0x443d1e8a,0x6d5d10c3}},	//   _змеш, zásu, luw_, fesa
  { {0xe20a002e,0x38600026,0x92940033,0x443d0079}},	//   slóð_, ywir_, _шахц, ouw_
  { {0xdb0700f2,0x67250020,0x7c3d0020,0x644b00dd}},	//   kijä, kahj, gusr, ntgi
  { {0x2d990020,0x91fc0024,0xf3e70015,0x7dd60030}},	//   akse_, _krāp, طأ_, vásu
  { {0x6fd408e0,0xc4dc005d,0x6e920086,0x6d5d0273}},	//   ràct, _बर्ख, _ملوا, besa
  { {0x7dd65834,0x6d5d5835,0x271d000b,0x7db50033}},	//   tásu, cesa, _फ़ॉर_, _асьц
  { {0x26de0955,0x38c80074,0xea000016,0x26d85836}},	// [dfa0] _što_, ذاری_, _thắt_, _syro_
  { {0x443d0079,0xd8770015,0x46a607c9,0x0000006a}},	//   duw_, عملت_, назв,
  { {0x443d0111,0xbb3b0053,0x394000cb,0x5dfa000a}},	//   euw_, _צעטי, pgis_, ִפְנ
  { {0xb5a90029,0x7ae10a55,0x6c9a000a,0x26d80091}},	//   وانك_, ülte, ּשַׂ, _vyro_
  { {0xc9530008,0x7dd61364,0xf71a0033,0x3cc9004f}},	//   _גמר_, láss, _нівы_, ֽלוּ_
  { {0xd62a007e,0x6d5d2409,0x2aba000a,0xdb150077}},	//   _ноге_, zesa, ּמֵא, onzá
  { {0x3afb0053,0x35a60342,0x6d5d2254,0x26de006f}},	//   פּגע, _завг, yesa, _áto_
  { {0xea000023,0x7ddd0030,0x24495837,0x6e2e0030}},	//   _nhật_, tésm, búm_, ábbm
  { {0x82fa0086,0x6d5d307e,0x74160058,0xdfda009b}},	//   _فراز_, vesa, _أوطا, зън_
  { {0x6e982f1e,0x04570015,0xa3c7000b,0x826a005e}},	//   двор_, _سلمة_, _उदय_, _назв_
  { {0x70540074,0x7dd60030,0xdd910040,0x63790033}},	//   رنگا, jáss, لود_, _ўсур_
  { {0x29d70251,0xa0a60010,0x10a6006b,0xea000016}},	//   nçat_, _паед, _пиен, _chật_
  { {0x6d5d5838,0xd00f002b,0x91e30033,0x2d9903f8}},	//   resa, _هلن_, _соце, rkse_
  { {0xcf260015,0x307b004c,0x207b000a,0xc4d3000a}},	//   _أرشي, _מאדנ, _מאדא, רגש_
  { {0xdb0700f2,0x8a970015,0x7ddd0046,0xdb0e010d}},	//   vijä, رؤسا, nésk, cibí
  { {0x7edb000a,0x59f8004a,0x6edb000a,0x99910030}},	//   _מקוצ, ееся_, _מחופ, tsző_
  { {0x7c080015,0xdb070601,0x7dd65839,0x65690072}},	// [dfb0] _كييف_, tijä, rást, _raeh
  { {0x7dd63445,0x7c2d583a,0xd7590058,0x0000006a}},	//   sást, _ivar, ظلات_,
  { {0x7dd625ce,0xc7c4147f,0xdb070bb5,0x7c2d583b}},	//   pást, усти, rijä, _hvar
  { {0x7dd600dc,0x7c2d583c,0x7ddd0030,0x19950033}},	//   lásr, _kvar, désk, _рамя
  { {0x644b3040,0x656b0125,0x7b8b000a,0x6d5a0030}},	//   utgi, rdgh, ּאֶ֥, őtag
  { {0x7dd60030,0x8c1c000a,0xdb1c016d,0x0000006a}},	//   násr, לודי, korý,
  { {0xd3d80015,0xfc3f0125,0x2449001a,0x97a8000a}},	//   ربها_, huí_, súm_, _נֹשֵ
  { {0x11d90015,0x36d4004a,0x96f80658,0x7c2d270b}},	//   بوعة_, _соср, _чест_, _ovar
  { {0xa1560001,0x7dd600dc,0x29d7016e,0x5f750021}},	//   тању_, záss, lças_, نادر
  { {0x7d0d535f,0xcf59005e,0x7ddd0030,0xfc3f0144}},	//   _afas, фрич_, lésh, duí_
  { {0xd1310074,0x29d703af,0xea000092,0x7dd600dc}},	//   _نما_, nças_, _phật_, dásr
  { {0xfbc90008,0x61cc000b,0x8f030054,0x7ddd0030}},	//   _ות_, ावृष, аjу_, nésh
  { {0xb87b0014,0xc5f2000f,0xfc3f583d,0x200f00cb}},	//   _szín, ידט_, szín_, _utgi_
  { {0x4fe80036,0x7dd600dc,0x8e850015,0x7d0d001a}},	//   _змін_, táss, _للته, _efas
  { {0xea000023,0xdb1500dc,0x7d0d0026,0x7f5605e6}},	//   _thật_, óbáb, _ffas, _рајс_
  { {0x7d1b0084,0x442d04a1,0x316d583e,0xaa430054}},	//   ðust, _ove_, ndez_, јетл
  { {0xa3e4014e,0x39460024,0x31ba0024,0x7de50015}},	// [dfc0] नतम_, ļos_, cīzu_, _حسوم
  { {0x6ff2002a,0xeb9f0789,0x0000006a,0x0000006a}},	//   _płci, spør_,   ,
  { {0x09f60015,0xb331005e,0xfb37000a,0xfaa63e28}},	//   _لأحد, _спiл, _באיש_, _рано
  { {0x25a0002d,0x08fa0015,0xf8bf0144,0xc7a9004f}},	//   óil_, _يرحب_, _adéu_, חב_
  { {0x29d7583f,0xa5330138,0xd46700af,0x0000006a}},	//   aças_, рніч, кице_,
  { {0x57250015,0x073a0015,0x7ddd0030,0x442d05e3}},	//   _مرفق, _تسحب_, tésk, _dve_
  { {0xdb1c005c,0x24800011,0x442d14a0,0xa1860174}},	//   loró, ţim_, _eve_, выпл
  { {0x7dd60014,0xd1300015,0xf1aa0015,0x80dd000b}},	//   zásr, حمة_, باته_, _परखे
  { {0x0326008f,0x6747002e,0x66095840,0x4fd40162}},	//   _адзн, _þrjá, _čeki, лжит
  { {0x29d70ae9,0xdb1c002c,0x1f730256,0x925a0015}},	//   nçar_, torý, алья, _يشار_
  { {0xc7b30008,0x25a632f4,0x7dd60030,0x03d7000a}},	//   שבת_, ohol_, vásr, _יומם_
  { {0x25a6379a,0x63b830fc,0xa1ba0015,0x60660015}},	//   nhol_, livn, _غطاء_, _لهؤل
  { {0x7dd600dc,0x40340608,0x4fc65841,0xdd0d002a}},	//   tásr, _селс, _иска, _półw
  { {0x7ddd00dc,0x8fa30054,0xf3f1000a,0xc0e31119}},	//   zésh, _ваље, ֶ֣ם_, _точк
  { {0x75fa0089,0x7ddd0152,0x7dd60030,0x99d70040}},	//   _různ, hési, rásr, نترا
  { {0x7c2d1aa1,0x39a40902,0xd257000a,0x7d0d002a}},	//   _tvar, ашув, כשלה_, _ufas
  { {0xfc3f1967,0x07090015,0x8b08002a,0x98750033}},	// [dfd0] quí_, فيذي_, _stęż, ылац
  { {0x0574002b,0x7dd60030,0x7ddd0f63,0x995c0046}},	//   یاند, lásp, dési, _víš_
  { {0x442d010b,0x9a870010,0xd6d10029,0x37040036}},	//   _sve_, _рупл, حقا_, рчув
  { {0xceb30008,0x29d75842,0x4eb50053,0xdb1c005c}},	//   סיף_, rças_, נהײב_, boró
  { {0x7ddd5843,0x493a000a,0xc4f80015,0xdb0e4842}},	//   résh, _אגרו, نعها_, libá
  { {0xbcfb0014,0x7ddd00dc,0x68d40001,0x63b840cf}},	//   ldés, sésh, _ђорђ, givn
  { {0x7ddd00dc,0xeb92000f,0x8b58000a,0x42520015}},	//   pésh, מָה_, דיוס_, منور
  { {0x200b03af,0x22560029,0xfac10092,0x45d50404}},	//   ício_, اليد_, _đầy_, _собс
  { {0x316d1d2c,0x65940c02,0x442d01e0,0x7dd601d3}},	//   rdez_, _тату, _uve_, dásp
  { {0x8fa50086,0x60e60033,0x9f850155,0xea0000a1}},	//   امده, ымым_, угод, _giặt_
  { {0xd2150054,0x6fdd0144,0xa3b80015,0x7bd50030}},	//   _смећ, nèci, _شاكر_, dozu
  { {0x25d50008,0xea000016,0x31580015,0x6da60054}},	//   רוֹן_, _nhạt_, _لجهة_, уима
  { {0xac9a0029,0xa3c7021e,0x91f6000a,0xc0a80015}},	//   رنسا_, _उदा_, _עמנו_, _لاول_
  { {0xd00e040b,0xfc0300f1,0x7bd50030,0x94ba000a}},	//   _على_, спро, gozu, תמשת
  { {0x15f5014e,0x3205003e,0xfaa31070,0xdf480015}},	//   ेदार_, _july_, баро, _شؤون_
  { {0xdb1c005c,0x63b82064,0x7dc80061,0x9d460004}},	//   toró, zivn, bısa, _сеид
  { {0x88e60afa,0x4ddb004c,0x2d8002f2,0x57ea06a6}},	// [dfe0] ужае, _אַזױ, _inie_, едам_
  { {0xab66116d,0x6d46064c,0x0000006a,0x0000006a}},	//   _свол, lgka,   ,
  { {0x25a60026,0xb9c60015,0xd7ef0015,0xdb1c002a}},	//   thol_, _مقدي, أكل_, soró
  { {0x6e2e00dc,0xb5da0029,0x6d46469f,0x7ddd0324}},	//   ábbi, رباء_, ngka, tési
  { {0x2d800050,0x63b825b6,0x69c45844,0x25a65845}},	//   _mnie_, tivn, mnie, rhol_
  { {0x7ddd0152,0x69c45846,0x62980091,0x69d65847}},	//   rési, lnie, tyvo, loye
  { {0xbb3b0053,0x63b85848,0x0ce1000b,0x645b0045}},	//   געצי, rivn, _नर्म, _epui
  { {0xc034050e,0xd01a0238,0x7dc80061,0x69d60f21}},	//   аниј, нфо_, yısa, noye
  { {0xf9930008,0x4f660015,0x99980091,0x69c45849}},	//   מרה_, هادف, ltrų_, inie
  { {0xbcfb00dc,0x6562007c,0x8f340054,0x6d461b8e}},	//   zdés, leoh, јенц, egka
  { {0x539b0008,0x9d190010,0x7bd50089,0x1757000a}},	//   _ריבו, конт_, vozu, נסטר_
  { {0x69d6003e,0x65620696,0x72ab000a,0xd00a0004}},	//   joye, neoh, _אֱדַ, _зеде_
  { {0x69c410f1,0x2d80002a,0x0000006a,0x0000006a}},	//   dnie, _dnie_,   ,
  { {0x6d4600b6,0xd2460225,0x69c4584a,0x7f960003}},	//   agka, ين_, enie, _pâqu
  { {0x9f470089,0xea000092,0xcfb70008,0x5fdb000a}},	//   _jiný_, _phạt_, _תלוי_, _רחוק
  { {0x5eeb000a,0x6442008c,0xf9930015,0x7dc80061}},	//   _אַחְ, kuoi, حبس_, pısa
  { {0xbcfb0014,0xa3e4005d,0x6562584b,0x0c7b0015}},	// [dff0] rdés, नता_, deoh, _أصعب_
  { {0xc8880015,0x1a65002b,0x7d0f0030,0xaab6002b}},	//   دخِل_, _پیری_, lccs, اگیر_
  { {0x69c43415,0xabfa000a,0x7f3b000a,0xf7480015}},	//   bnie, _שהתר, תעבו, المي_
  { {0xdb1c0084,0x16380029,0x69c4005c,0x6a9a000a}},	//   lorð, اسلة_, cnie, _ישתנ
  { {0x3f9e002e,0xd4d8005e,0xd4690659,0x7c2f4614}},	//   kktu_, льші_, тиле_, nscr
  { {0x32350036,0x47870010,0x6fdd0251,0x883a000a}},	//   ахис, _сымб, pèci, _בתשו
  { {0xfe090092,0x798d005c,0x6b7c000a,0xf1b90085}},	//   _mắc_, ojaw, תרונ, tiš_
  { {0x798d0375,0x3f9e002a,0xdc34006f,0x3968000a}},	//   njaw, ektu_, _súče, ָ֑הּ_
  { {0x7f19008b,0xf1b92f93,0x78ad01e0,0x0000006a}},	//   кіну_, riš_, nzav,
  { {0x04940029,0x81bc0024,0x7d1d00b8,0x69c4090f}},	//   _الْح, _svēt, ebss, znie
  { {0x7db60015,0x69c4584c,0x7c2f584d,0xdee501eb}},	//   لصحا, ynie, escr, рони
  { {0x67270030,0x7db6005e,0xbca60021,0x3f9e584e}},	//   _lejj, рсоц, لمجي, aktu_
  { {0xfe090023,0x69d6038d,0x69c40024,0x6e92002b}},	//   _bắc_, voye, vnie, ملیا
  { {0x69c40050,0xc4f6000a,0xb92b0016,0x67270046}},	//   wnie, יזרי_, _thuỷ_, _nejj
  { {0x6f7a013a,0x7f3a00b2,0x69d60152,0xaa4a0063}},	//   _יְהו, _סעקו, toye, ъпва_
  { {0x7c2f08a2,0x6995005e,0x2d80584f,0x6e3c0030}},	//   bscr, брух, _unie_, árbe

  { {0xdb1c002e,0x7ddd00dc,0x69d63d03,0x765c002a}},	// [e000] borð, tésv, roye, _spry
  { {0x69c40048,0x1783000d,0x998d07c4,0x4c9b000a}},	//   snie, огум, češ_, _סביו
  { {0x443d005c,0xbb3b0008,0x86c60015,0xb7d70015}},	//   erw_, _בעיי, جيان, جولا_
  { {0x1e560053,0xae56004c,0x644201be,0xda7b000a}},	//   ישער_, יסעס_, tuoi, _סנכר
  { {0x7ddd0a40,0x9f4f0077,0xbcfb0003,0x6fdd0144}},	//   mést, _jugó_, ndép, lècu
  { {0xd2500015,0x93b3022a,0xd25a053b,0x6562014b}},	//   كنت_, обіц, вци_, seoh
  { {0x200602d7,0xd6da0086,0xfe670031,0xdd210046}},	//   _suoi_, _شورش_, _بد_, _růžo
  { {0x200602d7,0x7416006e,0xe1ef00c3,0x7d0401d7}},	//   _puoi_, _نورا, وسي_, _ngis
  { {0x20060152,0x64a31c0c,0x653b000a,0x7cf1001a}},	//   _quoi_, _дата, _שעמד, iðré
  { {0x200602d7,0xa8570008,0x7d0423ba,0x386f001a}},	//   _vuoi_, סייה_, _agis, ægri_
  { {0x3f9e002e,0xfe090016,0x212601c2,0x78ad5802}},	//   rktu_, _rắc_, _teoh_, zzav
  { {0x200602d7,0xfe090092,0xc1070080,0xac1912ba}},	//   _tuoi_, _sắc_, _кэше_, лому_
  { {0xa2da000b,0x6ce7005e,0x85f7004c,0x7c3d0079}},	//   _पुत्, ріне, יצטע_, ursr
  { {0x69c81f0d,0x3d29002b,0xb07b000a,0xac182182}},	//   éden, ختگی_, _שנגז, рору_
  { {0xdb1c09f0,0xff170008,0x9f370008,0xba080063}},	//   rorð, _דקות_, _כנגד_, ихте_
  { {0xdce60064,0x442f0026,0x4efb009d,0x98170015}},	//   akkı, ysg_, _בלוג, لبطا
  { {0xfe090023,0x7c240176,0xbda70086,0x47350010}},	// [e010] _tắc_, _gwir, _محکو, йнас
  { {0x7dc80061,0xfc3f0125,0x36d5004a,0x7c220061}},	//   hısl, mrí_, бозр, _çora
  { {0x78ad0014,0x41d6005d,0x17f80029,0x995c0089}},	//   szav, डकास, شركة_, _síť_
  { {0xeef70008,0x7bc700bd,0xd4350087,0x66000030}},	//   במבר_, lnju, معتب, _cimk
  { {0x91fc0048,0x44240026,0x7ddd00dc,0x5552002b}},	//   _frāz, _cwm_, léss, سپور
  { {0xfc3f002f,0x9cd80008,0xd7955850,0xdb150011}},	//   irí_, בודה_, _الآخ, lizâ
  { {0x92640029,0x3949003d,0x356b4b4b,0x7ddd0030}},	//   قديم, ogas_, _иран_, néss
  { {0xe7eb005d,0x39495851,0xdb1500d4,0x0000006a}},	//   _जीता_, ngas_, nizâ,
  { {0xb1160015,0x44240034,0x30790015,0x39495852}},	//   حقًا_, _gwm_, احبة_, igas_
  { {0xf8b20008,0xdb150045,0x7ddd0030,0x399c001a}},	//   פשי_, hizâ, zést, _vísi_
  { {0x9f470251,0x59c7005d,0x02440015,0x7c245853}},	//   _sinó_, रचार, _وَكَ, _swir
  { {0xd00e0086,0xcb09000a,0x865a000a,0x41740015}},	//   بلی_, _טל_, נדרי, _وانس
  { {0x39490b14,0xfc3f5854,0xdfd502ed,0x7ddd005a}},	//   dgas_, grí_, _лоды, vést
  { {0x38690026,0xa0c4002b,0x69dd5244,0x7016000a}},	//   dwar_, _بيهو, _akse, _החסד_
  { {0x3a990036,0x7ddd0f87,0xfaa300d0,0x4f58002b}},	//   аттю_, tést, паро, _خجند_
  { {0xf2d20053,0x99f60036,0x394912f1,0x090640c9}},	//   פען_, сягі, ggas_, спан
  { {0xea000023,0xcc360029,0xad1b000a,0xe9d70033}},	// [e020] _nhất_, _اربع, _גופר, ёку_
  { {0xb226002e,0x69dd0293,0x39490091,0xe8f70724}},	//   nmæð, _ekse, agas_, слу_
  { {0xe3c80092,0x44240026,0x85060015,0xbebc003d}},	//   hực_, _swm_, موان, rbīg
  { {0x9986003b,0x7ddd00dc,0x1546009b,0xdb1500d4}},	//   _الحو, lésr, седм, cizâ
  { {0xea000023,0x74130015,0x4394004a,0x75290079}},	//   _chất_, كونا, жалс, _deez
  { {0x29de0026,0xd5b2002b,0x7ddd0030,0x69c10003}},	//   rïau_, _کفر_, nésr, élev
  { {0x52370029,0xdb15001c,0x29de0026,0xcb13000a}},	//   مسيح_, lizã, sïau_, הלו_
  { {0x29de0026,0xdb155855,0x82330015,0xa8060061}},	//   pïau_, vizí, أروا, arış
  { {0x7ddd00dc,0xa98b004c,0xd0070004,0x2eb2000b}},	//   zéss, אָיִ, бење_, ुप्त
  { {0xe3a4002b,0x39490091,0xfff5009a,0x75290546}},	//   _بشری, zgas_, يکوت_, _zeez
  { {0x7a15005c,0x11d6034e,0x39490091,0x7ddd0030}},	//   _kąte, _людя, ygas_, désr
  { {0xc693013a,0x69c800dc,0xfc3f002c,0xacf9005e}},	//   לאת_, édel, trí_, инну_
  { {0x2177000a,0x9f34005e,0xe0850015,0x909a002b}},	//   _לתאר_, _делі, _وجهي, _حضار_
  { {0x7ddd00dc,0xd0f7000a,0xdfcf0015,0x3ff40015}},	//   téss, _הצדק_, _كين_, _بكتر
  { {0x0f5701e4,0x79a70937,0x3a840033,0xfe090016}},	//   _היום_, брае, пытв, _hắn_
  { {0x3949430f,0xf919006b,0x7bc700bc,0x6ca70054}},	//   ugas_, ржащ_, snju, _грож
  { {0xa2da005d,0xad1c0008,0x87070029,0x7ddd00dc}},	// [e030] _पुस्, _עוזר, مبال, séss
  { {0xdb0f00f2,0xfe090092,0x9b590004,0x7ddd0030}},	//   äjät, _mắn_, _тиот_, péss
  { {0xa6c80015,0x8b88000a,0x19950138,0x0000006a}},	//   موكل_, _הָרֶ, _даня,
  { {0x0596002b,0x5eeb0447,0x69dd3051,0x3aba000a}},	//   يانگ, אַדְ, _ukse, _כמתנ
  { {0x15f40029,0x87e7006b,0xf1c90016,0x9976000a}},	//   أسلح, _гюве, hạc_, _ותרא_
  { {0x80dc005d,0x37e40033,0xe2995856,0x0000006a}},	//   _पड़े, _ноўг, иал_,
  { {0xa1890080,0x8b9c000a,0x23ab02de,0xdb9c004f}},	//   ибка_, רבות, _nøje_, רסור
  { {0x7ddd0014,0xd1790010,0xfe090092,0xea000092}},	//   zésr, рскі_, _bắn_, _thất_
  { {0x60060010,0x60090054,0xf9970016,0xfe090016}},	//   оным_, јном_, _đậm_, _cắn_
  { {0xe3c80092,0xa9280227,0xfe790033,0x53340785}},	//   rực_, ouží, аёмы_, _неут
  { {0xa6fb000a,0xcee90432,0x8d6600f4,0xa3c8000b}},	//   נִ֖י, рдне_, овне, ोकर_
  { {0x82d60053,0x7d090007,0x6e3c00dc,0x7dd600dc}},	//   _וועג_, žesn, árba, lász
  { {0x7ddd0014,0x22470014,0xfe090092,0x399c0089}},	//   tésr, lunk_, _gắn_, _míst_
  { {0x98a20048,0xbea506ac,0x23ab0134,0xe9df002c}},	//   _nekā_, _малк, _føje_, _akú_
  { {0xbb430004,0x7ddd0030,0x6996005e,0x3af5004a}},	//   ќеск, résr, орах, зятс
  { {0x7ddd00dc,0xdb0e001a,0x8cd50065,0xdce40160}},	//   sésr, nibú, _युको, _naić
  { {0x7ddd00dc,0xe9d7022a,0x08c601fe,0x48e320e6}},	// [e040] pésr, іку_, цбан, дотв
  { {0xaadb005d,0xe73a0036,0x7dd60030,0xda660a32}},	//   _मुवक, реж_, jász, _двои
  { {0xa6ca0029,0x7dd600dc,0x97c50015,0x55060054}},	//   جوال_, dász, ستكم, очла
  { {0xa2da014e,0x75d3003b,0xae5a0053,0x224700dc}},	//   _पुष्, ويلا, יכער, dunk_
  { {0xeafa0086,0xdb155857,0xb87b00dc,0x7bdc0171}},	//   _حرکت_, lizá, _szív, ooru
  { {0x7a15005c,0xfe090092,0x24523cb5,0x23b30015}},	//   _wąte, _rắn_, râm_, ومنس
  { {0x224700dc,0xb97a000a,0x4b7b004c,0xfe090016}},	//   gunk_, ֹנִי, שאצו, _sắn_
  { {0xf12613ae,0x4a9b000a,0xba9b004c,0x31c30033}},	//   цько, ייצג, יסצי, дсьв
  { {0xd5b9008f,0x54ee005d,0xa2da021e,0x91b70015}},	//   _усё_, _जरिए_, _पुर्, تطور_
  { {0x91820092,0x66ca000a,0xdb150030,0x8cd50065}},	//   iểu_, ֹמֹ֔, kizá, _युगो
  { {0xc2c60086,0x877b000a,0x977b000a,0x81a60015}},	//   _بياي, באיי, בריה, _وحصل
  { {0xd83f01c0,0xdb155858,0xdb1c02ad,0x0000006a}},	//   íčku_, dizá, hnrä,
  { {0xcce70015,0x7bdc2c2d,0xdd980138,0x0000006a}},	//   تسدي, foru, цшэ_,
  { {0xbebc0048,0xa92801c0,0x320c0046,0x7f7300ce}},	//   rbīb, yuží, _kudy_, _огіє
  { {0xbae50029,0x7e2a0036,0x5e430029,0xda7803fc}},	//   سكري, _тіла_, _قَوْ, оят_
  { {0x7dd600dc,0xca48006e,0x7bdc0085,0x3ea301d0}},	//   zász, تلفه_, aoru, øjte_
  { {0x224700dc,0x613500dc,0x718b000a,0x320c002a}},	// [e050] zunk_, lülí, סְלַ, _ludy_
  { {0x64424c68,0xa08b000a,0x501b000a,0x07e70033}},	//   droi, יְבִ, יומו, іцам
  { {0x69c100dc,0x6dab0046,0xdb7c000a,0x7dd60030}},	//   éles, dřaz, _כנזכ, vász
  { {0x64420003,0x22470030,0x0608004e,0x0000006a}},	//   froi, vunk_, інік_,
  { {0xf5560015,0x04c80015,0x64420696,0x63854b4b}},	//   سلوب_, يومي_, groi, згла
  { {0x224700dc,0x78fa0008,0xe3b80036,0x389a0008}},	//   tunk_, _לפרו, обі_, _הישנ
  { {0x3f890092,0x6442008c,0xe299134f,0x71a50033}},	//   _đau_, aroi, сай_, зайз
  { {0x237b002a,0x7dd60030,0x321600c3,0x2bd2000b}},	//   _żyją_, sász, أييد_, _सदभा
  { {0x7bdc01e2,0xdb0e002c,0x14770086,0x224700dc}},	//   yoru, ribú, _بازج, sunk_
  { {0xf207006b,0x22474cdb,0xdb1c0003,0x201901ec}},	//   _дядо, punk_, piré, īsi_
  { {0xc7b2000a,0x4d8a0015,0x69cf002a,0x7c360091}},	//   גבי_, مَدُ_, _ojce, _svyr
  { {0xdb1500dc,0x26b6000a,0xc2c40015,0x0000006a}},	//   vizá, פִים_, _تيمي,
  { {0x7bdc5859,0x3cda0033,0x20b8004a,0x4e95009a}},	//   toru, сьню_, _мышь_, زشگر
  { {0xe1f90007,0x201f003f,0x200b006f,0xdb15585a}},	//   lmų_, mpui_, íciu_, tizá
  { {0x753b016f,0xdee21e91,0xcaa50015,0x6b630174}},	//   _oduz, _поши, وصفي, экра
  { {0x7bdc0011,0x6e3a0008,0x7d760087,0xe1f90091}},	//   soru, _התקד, _رابط, nmų_
  { {0xfe090016,0x07a60004,0x7bdc0a30,0xf8c60065}},	// [e060] _mắm_, паан, poru, लपेप
  { {0xfe090092,0x6c7b000f,0x46f605b3,0x1cbb000a}},	//   _lắm_, _פריד, пчет, _למפע
  { {0x8b9b0008,0xdb9b0008,0xd63a0036,0x6b9b000a}},	//   _הבית, _הסיר, сязі_, _השיד
  { {0xfe090092,0xd5b9005e,0x644229eb,0x320c585b}},	//   _nắm_, осі_, troi, _rudy_
  { {0x397b0008,0x845a0054,0x14170015,0xd5af0015}},	//   _הטכנ, срет_, كينة_, دفن_
  { {0x64423c8e,0x75220077,0x995c0046,0xe1f90091}},	//   rroi, sboz, _jíž_, emų_
  { {0x27f70089,0xcb570008,0x3f98002e,0x92570015}},	//   řené_, פסקה_, örum_, كشير_
  { {0xd657013a,0x7ae100b8,0x764300dc,0xfe090016}},	//   _מילת_, ülti, ánye, _cắm_
  { {0xb4aa1aef,0xd0070004,0x04431440,0x4346174b}},	//   _указ_, пење_, _петн, _неав
  { {0x995c0089,0xe1f90007,0x389b000a,0x141b000a}},	//   _níž_, amų_, ציינ, _לומב
  { {0x1df90080,0x1757000a,0x1eaa0015,0xc106002b}},	//   жены_, הסיר_, صادي_, _فواي
  { {0x7ae500f2,0xddab0891,0x25a64ae0,0x61350030}},	//   _ryht, стол_, nkol_, rülí
  { {0xed580010,0xf1b3000a,0xa2c4000b,0xf1c90016}},	//   чоў_, _אסף_, िपक्, oạn_
  { {0x661c003d,0x70fb004f,0x9b450058,0x0000006a}},	//   _otrk, _ההדח, بنسو,
  { {0x79a7008f,0x1f5b0008,0xaf5b0008,0xdb050012}},	//   прае, _הדוא, _הכוכ, _umhü
  { {0xf7730074,0x19940063,0xf9930067,0x621b004f}},	//   کار_, нася, ربز_, מולק
  { {0x6d3c0008,0xa2be021e,0xcdf8000a,0x08550033}},	// [e070] _התחנ, _वेस्, _צמחי_, ьваю
  { {0x9715005e,0x501b004c,0xe1f90091,0x6d5d585c}},	//   ємец, צובו, zmų_, lfsa
  { {0xe1f900df,0x36340029,0xd6180015,0xfbd00040}},	//   ymų_, فرنس, كتنا_, _حتي_
  { {0xceb30008,0x25a60035,0xa3b1000b,0x6d4f585d}},	//   עיף_, gkol_, फ़ोन_, ngca
  { {0xb97a0008,0xe44e006b,0xa97a000a,0x54e70015}},	//   _ונרי, ъж_, _וארכ, أساق
  { {0xfe090016,0x61e2005b,0x0000006a,0x0000006a}},	//   _sắm_, _akol,   ,
  { {0xe296006b,0xe1f90091,0xe3b002be,0xa1f500af}},	//   дащ_, tmų_, درن_, мџиј
  { {0x6d5d0079,0x69cd585e,0x801507f8,0x83fd01d3}},	//   jfsa, nnae, мфоц, _csőr
  { {0xbf05014e,0x20540010,0xe1f90007,0xbcfb0003}},	//   रश्न_, нтэр, rmų_, nféd
  { {0xdb1e0152,0x6d480007,0xe1f90091,0x61e209df}},	//   _empê, ėdam, smų_, _ekol
  { {0xdb08038d,0x76450026,0x9d46091c,0xbd460015}},	//   _élém, nrhy, менд, وندي
  { {0x9f450152,0x6459005c,0x200b0125,0x201f51ec}},	//   illé_, otwi, ícis_, ppui_
  { {0xa1340086,0x753600f3,0xc1040015,0x6536004c}},	//   _سرنش, וארד_, _كومي, וארף_
  { {0x61e9585f,0x70fa000a,0x60fa000a,0x61fb127a}},	//   llel, _והנח, _והנק, lmul
  { {0xea000023,0x644b0084,0x61e900f2,0x25bf0011}},	//   _chết_, hugi, olel, _omul_
  { {0xf2d2004c,0xd910002b,0x61fb5860,0x0000006a}},	//   דעל_, طیس_, nmul,
  { {0x48060010,0x20070375,0xb87b0030,0x09e31070}},	// [e080] дпав, _kini_, _szír, тотн
  { {0x68e600df,0x1bfb000b,0x97da0033,0xa6ca07be}},	//   _vykd, _एओएल_, цьбу_, олза_
  { {0xfaf20015,0xceb2000a,0x463a056d,0x78780030}},	//   _جثة_, ֣יא_, ючая_, fúvá
  { {0xea000023,0x672e00dd,0xceb2000a,0x04460004}},	//   _đặc_, _webj, כיב_, дедн
  { {0x628140f0,0x3cc9000a,0x61e95861,0x61fb5862}},	//   _arlo, ּלוּ_, dlel, dmul
  { {0x2007000c,0x61fb0375,0x69c40012,0x61e20a3a}},	//   _nini_, emul, liie, _skol
  { {0x644b00df,0xa2be000b,0x6459002a,0x661c0085}},	//   augi, _वेश्, atwi, _utrk
  { {0x69c1005d,0x61e900f2,0x61fb5863,0x1bfb000b}},	//   रोपी, glel, gmul, _एओऍल_
  { {0xc05a0191,0x30140010,0xa06707c1,0xa50b000f}},	//   цій_, эдпр, дања_, _וּבִ
  { {0xb4aa000b,0xc49b000a,0x200f06f2,0x61e95864}},	//   खनी_, _ושמת, _dugi_, alel
  { {0x61e90007,0xe1960010,0xf773000a,0xdb07008c}},	//   blel, _ордэ, דקת_, lijö
  { {0x61e2010b,0x56370053,0x91360015,0xe811000b}},	//   _ukol, ואטע_, _آراؤ, ़दमा_
  { {0xd90f0086,0xada40010,0x6d5d002e,0x6ce40036}},	//   یید_, таўл, rfsa, віре
  { {0xaed40063,0x6d5d003f,0x7e9a0015,0xbed40004}},	//   _полш, sfsa, _ونشر_, _полј
  { {0x69cd0085,0xda070033,0xdb1c0077,0x69c401f6}},	//   tnae, дчап, cirí, fiie
  { {0xdb0700f2,0x82770053,0x929b000a,0x200f2cb2}},	//   kijö, ועלע_, חילת, _yugi_
  { {0x7d0d5865,0x656b1737,0x98140015,0x76450034}},	// [e090] _igas, vegh, نبلا, wrhy
  { {0x61e900dc,0x69cd5866,0x0057004f,0xbc68009a}},	//   zlel, snae, ושמת_, _کمین_
  { {0x87040010,0xa2be000b,0xdd120061,0x61e90061}},	//   вяце, _वेल्, nüşm, ylel
  { {0x4efb0053,0x9afa000a,0x8afa000a,0xe5e5002b}},	//   קלאג, _מפתח, _מהתי, رزای
  { {0xd46b0015,0x656b02b9,0x61e05867,0x8428005e}},	//   تحام_, regh, doml, джів_
  { {0x3f9c010b,0xa8560008,0xe66700a4,0x200f5868}},	//   _novu_, _אישה_, _отбо, _rugi_
  { {0x0614008f,0xd378005c,0x61e90061,0x644b02f2}},	//   _адсю, _dać_, tlel, sugi
  { {0xe1f1002b,0x27e10012,0x2007329c,0x61fb5869}},	//   دست_, lohn_, _sini_, umul
  { {0x61e9586a,0xdce600bf,0x9f5c04b2,0x7bce0dac}},	//   rlel, tekč, _sivá_, ynbu
  { {0x442d003f,0xa2950010,0xedfa000b,0xdb1c0077}},	//   _iwe_, _пазі, ृद्ध_, tirí
  { {0x66091739,0x7c2d2641,0x2007586b,0xb5f9000a}},	//   _kiek, _awar, _vini_, ּלָכ
  { {0x1d0a0063,0x799d0026,0xc27a000a,0x8d760015}},	//   яеми_, _nosw, _מרעי, راجا
  { {0x5e560086,0x9f05002b,0x4c8312ae,0x6609586c}},	//   ولیس_, بوگو, гляв, _miek
  { {0xb09a000a,0xdb1c016e,0x5f750040,0xbebc003d}},	//   _מינר, dirã, _ساتر, obīl
  { {0xf1c90016,0x69c40012,0x7bce586d,0x799d3504}},	//   hạm_, tiie, rnbu, _bosw
  { {0xa9280057,0x5e560015,0x3f9c0085,0x78a4008c}},	//   drží, _أليس_, _zovu_, tyiv
  { {0xf1b20053,0x7c2d586e,0x18672263,0x69c41341}},	// [e0a0] אסן_, _gwar, нати_, riie
  { {0xdb07586f,0x5c5b00a3,0x57e70004,0x7d0d002a}},	//   vijö, _צדיק, едум_, _zgas
  { {0xcb570008,0x4d7a0008,0x7c2d2f53,0xcbc5002b}},	//   _אסיה_, ּרְע, _zwar, _جزيي
  { {0x14c80074,0x6609005c,0x764300dc,0x85760015}},	//   وهای_, _ciek, ánya, عدائ
  { {0xb4aa005d,0xe4e30033,0x53e60033,0xf993000a}},	//   खने_, лішн, нцка, _ערש_
  { {0xd2500029,0x87f90033,0x4c3b004f,0x38720416}},	//   لنت_, _жэст_, לגנצ, mwyr_
  { {0x38720176,0x49ba000a,0x46160015,0x9294302e}},	//   lwyr_, ּמִס, _سوذر, тайц
  { {0xd1300029,0x39520026,0x865b000a,0x11d80015}},	//   جمة_, ngys_, _מדלי, بوبة_
  { {0x442d0176,0x38720026,0x6b9e00aa,0x211700c3}},	//   _gwe_, nwyr_, _oopg, رتيب_
  { {0x66090111,0xc43b000a,0xf43b000a,0x74130015}},	//   _ziek, _מתמי, _מתמש, _صوما
  { {0x38720176,0xc7b30008,0x7ddd00dc,0x7c2d5638}},	//   hwyr_, רבת_, mész, _swar
  { {0xdd120064,0x71730087,0x91ba002b,0xa1ba0021}},	//   rüşm, _مهما, _عطار_, _عطاء_
  { {0xc19b000a,0x69c10003,0x8fa6014d,0x0cab0015}},	//   _משאי, èlem, _паде, سطحي_
  { {0x38720176,0x9be40010,0x5e940015,0xa134002b}},	//   dwyr_, гіск, _للتط, _سرچش
  { {0x0f7b000a,0x998d0046,0xead4004a,0x6b9e00aa}},	//   _מרגל, čež_, горь, _dopg
  { {0x7c2d005c,0x38720026,0xfa34002b,0xdb1c016e}},	//   _twar, fwyr_, طرفد, tirã
  { {0x7ddd0014,0x38720176,0xdd040011,0x91820092}},	// [e0b0] kész, gwyr_, ărăt, iều_
  { {0x2cb30064,0x66091739,0xdb0500dc,0x68440015}},	//   ındı_, _siek, _elhá, اَلل
  { {0x66090048,0x442d005c,0x07080015,0x7ddd0030}},	//   _piek, _swe_, فيكي_, dész
  { {0x7a880008,0x38720026,0xdb070134,0xca96000a}},	//   _נָתַ, bwyr_, thjæ, _סדרי_
  { {0x38720026,0x6d400030,0x437500f4,0xdb1c19fe}},	//   cwyr_, ómai, вуйт, lirá
  { {0x7ddd0014,0x6609005c,0x63520001,0x64a215ce}},	//   gész, _wiek, ављу, раша
  { {0x22560086,0x66090f28,0x43720015,0x6e3a0079}},	//   نلود_, _tiek, شهير, jstb
  { {0xceb8005c,0x442d06ed,0x2019016e,0x0000006a}},	//   dzę_, _twe_, ísio_,
  { {0x04c80015,0x70520015,0x33750054,0xf1bf006f}},	//   _كوفي_, لنيا, _игар, žšom_
  { {0xa2830086,0x657b1dad,0x0ea9004a,0x273c0046}},	//   _میتو, _hauh, дкой_, mání_
  { {0x273c02d5,0x539a0053,0x657b008c,0xf776000a}},	//   lání_, _קיעו, _kauh, דעתי_
  { {0x30850029,0xdb1c0077,0xe612004c,0xdb0e007c}},	//   _للصف, dirá, יִש_, sibü
  { {0x273c0089,0x853a0008,0x6d410091,0x6b9e3582}},	//   nání_, וגרי, ėlap, _popg
  { {0x8fa20893,0xdb070123,0x245b0016,0x6ec50015}},	//   _ваше, khjä, iêm_, _لتعق
  { {0x245b0092,0xceb8002a,0x273c0046,0xdb1c0077}},	//   hêm_, czę_, hání_, girá
  { {0x273c02d5,0xc2120008,0xceb2000a,0x657b008c}},	//   kání_, שהן_, _כיו_, _nauh
  { {0x2d5a00bd,0x38c80086,0x38720034,0x61f90034}},	// [e0c0] _všeč_, راری_, uwyr_, _mhwl
  { {0x38720176,0x273c0089,0x7bc72823,0xdb1c0077}},	//   rwyr_, dání_, ciju, birá
  { {0x1dc6014e,0x7ddd00dc,0x38720026,0xdb230125}},	//   _लगात, vész, swyr_, _úrán
  { {0x38720026,0x85060021,0xe9a601cf,0x26090065}},	//   pwyr_, نوان, _рамп, िदगी_
  { {0xbcfb00dc,0x7791002b,0x94730015,0x7ddd0030}},	//   leér, _گیلا, لدوا, tész
  { {0xa3f40010,0xe2f8008b,0x7c220061,0xb8f60065}},	//   ыплі, нелі_, _çoru, िप_
  { {0x877b0053,0x7ddd00dc,0x03a30001,0xe6170afb}},	//   _קאלי, rész, ријо, _адс_
  { {0x28c7014e,0x16770008,0x7ddd0030,0x273c0046}},	//   _रेडि, _בגלל_, sész, bání_
  { {0x71e70021,0xdfda006b,0x7eab008c,0xb465002b}},	//   خفيف_, дън_, yöpö, _مدله
  { {0x94060086,0x6fb40018,0xdce40085,0x44265870}},	//   _شواه, امدا, _naiđ, mpo_
  { {0x03a30124,0xdd910225,0x9f5c0971,0x0737000a}},	//   _њихо, مود_, _nivå_, כאים_
  { {0x75f80089,0xaf030010,0x2369016f,0x442620fd}},	//   bíze, шчык, đaje_, opo_
  { {0xceb80050,0x7f860029,0xba74002b,0x7bc75871}},	//   szę_, _للإن, یافت, tiju
  { {0x44260467,0xfe6f002b,0xdb1c1aca,0xf413000a}},	//   ipo_, حدی_, tirá, יפש_
  { {0x273c0089,0xcb340063,0x31b10030,0x7bc75872}},	//   zání_, ресъ, _háza_, riju
  { {0x7bc70780,0x1e97013a,0x19b80029,0x99d40029}},	//   siju, _יכול_, نطقة_, لتقا
  { {0x7bc700df,0x657b08b1,0xadd8000a,0x7b19006b}},	// [e0d0] piju, _rauh, _שוחח_, _попр_
  { {0x7d1d03c0,0x273c0089,0x764300dc,0x57b4005e}},	//   lcss, vání_, ányo, абут
  { {0x442609de,0x29d50015,0x3958006f,0x645b4986}},	//   epo_, _ميدس, _šesť_, _squi
  { {0x273c0089,0x7d09003d,0x245b016e,0x7d1d0030}},	//   tání_, _tīrī, têm_, ncss
  { {0xc7cb0010,0x44260035,0x7544042b,0x657b008c}},	//   _жыве_, gpo_, рніз, _vauh
  { {0x273c0089,0xb4440010,0xdced003d,0x51f5002b}},	//   rání_, рэцк, _anaī, گستر
  { {0x82a40001,0x273c0046,0x44265873,0x16340174}},	//   ишће, sání_, apo_, _веся
  { {0xf1c90092,0x273c0046,0x31b1006f,0x51f5009a}},	//   oại_, pání_, _báza_, دستر
  { {0xfe0a0092,0x60090142,0x40940010,0x7bc50546}},	//   _mắt_, нним_, арэт, _omhu
  { {0x777c08e0,0x53b7021e,0xa2be000b,0xaf750054}},	//   _xarx, _अतिश, _वेक्, ућић
  { {0x6da613ab,0xdb1c002e,0xd13100e6,0x7fe80015}},	//   гина, gnrý, _هما_, خريف_
  { {0x7db60029,0x63a100dc,0x6139004c,0x31b1006f}},	//   اصدا, _holn, _װײַס, _fáza_
  { {0x90450015,0xde47002b,0xfc310015,0x55ba004f}},	//   _إنته, ریکو_, ْحِ_, תמרו
  { {0x8e850086,0xeb9a0004,0xca76004a,0x644b0a8a}},	//   _ملته, ѕив_, лубы, irgi
  { {0xfe0a0023,0xc3320008,0x0b170015,0xbda60021}},	//   _bắt_, מום_, اقفة_, _محظو
  { {0x443f010b,0xfe0a0092,0x7dc80030,0xbcfb08ae}},	//   _ovu_, _cắt_, műso, sféa
  { {0x22830064,0xb7d7002b,0xfe0a0016,0xf1c90016}},	// [e0e0] _lık_, گولا_, _dắt_, gại_
  { {0x7c240064,0x2618000b,0xa088000a,0x69da0030}},	//   _itir, _बंदी_, כְעִ, éteb
  { {0x86c60029,0xd757002b,0x98ab003d,0x46f60818}},	//   ديان, المت_, _vecā_, учат
  { {0x35e50191,0x25a0002e,0x1e56004c,0xfe0a0016}},	//   аців, ðil_, טשער_, _gắt_
  { {0x25b7002b,0x69c60012,0x660300aa,0x44265874}},	//   دهند_, _imke, ïnka, upo_
  { {0x9cdb0053,0xcc77000a,0x44264ec3,0x66e604bb}},	//   ײַדז, טענה_, rpo_, _бога
  { {0x36780008,0x66780008,0x656200b8,0x38791927}},	//   _בְּע, _בְּג, pfoh, _zssr_
  { {0x442602d7,0x6d44002f,0x7c3d00c0,0xe4360015}},	//   ppo_, _ndia, yssr, _مفرد
  { {0xc0960029,0xdb1c0125,0x60f8006b,0x628306c0}},	//   اجعت, nnró, ъния_, avno
  { {0xdb05008c,0x6d445875,0xc32a0015,0x8877000a}},	//   _ylhä, _adia, _أكان_, נתיב_
  { {0xbebc0024,0x7c243fcb,0x3f820046,0x8ff70015}},	//   icīg, _atir, ěku_, درير_
  { {0x386017e6,0x6fb40086,0x7a15005c,0x9cb50029}},	//   ktir_, امگا, _wątk, لمجت
  { {0x6d440026,0x91f7000a,0xa3c8000b,0x7cc7009a}},	//   _ddia, _עמדו_, _उषा_, ازجم
  { {0xfe0a0092,0x69c80003,0x6d440c2d,0x907b004f}},	//   _sắt_, èden, _edia, _נטוי
  { {0x387904c6,0x1f37000a,0xda35004a,0xf2d8000a}},	//   _sssr_, _גרור_, ребы, דַּל
  { {0x38600084,0x8e470029,0xbebc0024,0x6d5a00dc}},	//   ftir_, _إليك_, ecīg, őtar
  { {0x98170002,0xe877002b,0x89340015,0x6602002a}},	// [e0f0] ابرا, دازظ, إعفا, dmok
  { {0x3cfc000a,0xfc3f0125,0x62885876,0x7bc5001a}},	//   _אלחנ, msí_, _ordo, _umhu
  { {0xfe0a0092,0x7f3b0053,0x443f016f,0x63a11212}},	//   _tắt_, געבו, _svu_, _roln
  { {0xd5eb00c3,0xbdf7004f,0x63a15877,0x88170058}},	//   رعان_, נֶ֑ה_, _soln, _مبسط
  { {0x22830064,0xdb1c0020,0xfc3f002d,0x3cf3005d}},	//   _sık_, birä, nsí_, _घरों_
  { {0x8c1c0053,0x9888000a,0x7811000b,0xc7bb004a}},	//   עווי, _עָרֵ, ़दीक_, _чём_
  { {0x5b58013a,0xea000092,0xe2991aea,0x63a11724}},	//   אשון_, _chặt_, тай_, _voln
  { {0x63a1005c,0xe045017a,0x31b80030,0xc1b90015}},	//   _woln, ании, _nézd_, ضابط_
  { {0xf9940008,0x4f950174,0x24190088,0x62885878}},	//   מרק_, арну, _розы_, _erdo
  { {0xb068003b,0x9e6508fb,0x0e651ecc,0xdee5153d}},	//   اصيل_, авод, акон, иопи
  { {0xf7720008,0x42990087,0x93fa000a,0x7c24037e}},	//   חקי_, _جناح_, _סלעי, _stir
  { {0x60d60007,0x3860002e,0xee360142,0x5de6005e}},	//   _žyme, ytir_, шню_, ржма
  { {0xd1b80086,0x55760053,0x8cc0000b,0x0000006a}},	//   _حالا_, בערן_, _लेखो,
  { {0xbcfb0084,0x00ba004f,0x61e42803,0x0000006a}},	//   mfél, _שמסמ, čile,
  { {0xdb2500dc,0xfaa30004,0x9e6400c3,0xad9b001a}},	//   ásár, оаро, _هاين, mmún
  { {0xe206002e,0x386030e9,0xe9d73878,0x6d445879}},	//   _þótt_, ttir_, акс_, _udia
  { {0x47c60010,0xbcfb00dc,0xfbdf587a,0x98360033}},	// [e100] абав, nfél, guês_, рэбі
  { {0xf7720029,0x44240213,0xdb1c0125,0x4fd5000a}},	//   غاء_, _rtm_, rnró, ׁוּב_
  { {0x3860587b,0xf6d5005e,0xb9c6012c,0x2d800072}},	//   stir_, біця, _نقدي, _kaie_
  { {0x38603acc,0xf623005e,0x69c60012,0xbcfb0030}},	//   ptir_, ідчо, _umke, kfél
  { {0xdce40198,0xe12101f3,0x6602587c,0xbcfb0030}},	//   _obič, _усiм_, rmok, jfél
  { {0x026a0080,0x212d006f,0xd75a0058,0x44240546}},	//   вший_, ebeh_, _جلست_, _vtm_
  { {0x95960124,0x69d6000c,0xa5960036,0x66020007}},	//   _краљ, onye, _кращ, pmok
  { {0x51860d56,0x2369016f,0xa1860010,0xa2d7000b}},	//   рука, đaja_, рыкл, _बशर्
  { {0xdfa60029,0xe4ea0015,0x9097006b,0xe5d902d9}},	//   لحدي, _شعره_, ивът_, _сфрј_
  { {0x81460086,0xe2920015,0x628800bc,0xff06005e}},	//   _چنان, _وذا_, _trdo, иянн
  { {0x2d80587d,0x24860134,0xd3b90036,0x77f7000a}},	//   _baie_, lvom_, _суті_, שמיד_
  { {0x24860085,0x200e287c,0xd086004a,0xbcfb0030}},	//   ovom_, _wifi_, _выки, bfél
  { {0xa3ca005d,0xfc3f0057,0x2d850046,0x91bb000a}},	//   _लगा_, usí_, ěle_, _במאי
  { {0x2d85005c,0xfd1f04ed,0x9be7005e,0xde580033}},	//   śle_, scì_, рімк, _бакі_
  { {0xfb84008f,0xf9c7010f,0x6ffb000a,0x19950617}},	//   цыян, ащан, _שהופ, бавя
  { {0x2486016f,0x76430091,0x2489006f,0xe9b4005e}},	//   kvom_, šnyk, ťami_, обсь
  { {0xcbc70074,0x87270015,0x4993002b,0xa3d60065}},	// [e110] _نزدي, لعام, میگر, ाचा_
  { {0x5719005e,0x39540046,0xe70b012c,0x3b551114}},	//   ужжя_, _časů_, نتان_, _укор
  { {0x7515003b,0xf1c90092,0xd6180015,0x65150058}},	//   مواض, oạt_, لتنا_, موائ
  { {0xb9950029,0x241904ab,0xc9950015,0xd4d90033}},	//   _الحب, годы_, _الحظ, льлі_
  { {0x2489016e,0x0000006a,0x0000006a,0x0000006a}},	//   íam_,   ,   ,
  { {0x368b0001,0x69cd0026,0x6a140086,0xfe0a0092}},	//   _исбн_, liae, _دبیر, _lắp_
  { {0x0bb801e4,0x38750064,0xdd2c0007,0xfbb8000a}},	//   שלום_, şarı_, _lėšo, שפות_
  { {0x69cd0176,0x22490b6c,0x3a38000a,0x9477002b}},	//   niae, čak_, ברהם_, _پدرا
  { {0xf0a6006b,0x78ad1e0b,0x2d8043da,0x95c82c9e}},	//   йкъл_, nyav, _raie_, _тура_
  { {0x67f0022d,0x21270086,0xab64005c,0xbcfb001a}},	//   täji, ديکی_, ężki, rfél
  { {0xbebc0048,0x92b40029,0x76430030,0xfe0a0016}},	//   ecīb, _وحما, ányh, _bắp_
  { {0xea000092,0xed570a96,0xfe0a0016,0x02440015}},	//   _đắc_, бою_, _cắp_, _ذَهَ
  { {0x69cd0026,0x3f690289,0xd116000a,0xa026008c}},	//   diae, _било_, _הקנה_, rnöö
  { {0xb4fa000a,0xad9b0030,0x0000006a,0x0000006a}},	//   טפרי, lmúl,   ,
  { {0x2486002c,0x01f9004c,0x2d800045,0xcee8002b}},	//   zvom_, ָפּל, _taie_, _پرون_
  { {0x2ef80012,0xad26002b,0xfd12012c,0x69cd587e}},	//   ürfe_, _ارغو, _عجب_, giae
  { {0xb7160029,0x69d62835,0xdcfa0015,0x200501d7}},	// [e120] مباش, rnye, _حفظت_, omli_
  { {0x9aa6002b,0x63a50012,0x5907012e,0xdc9b004f}},	//   _همخو, öhnl, сеум_, _עייל
  { {0x7c360026,0x61e91024,0x6b7b00a3,0x69cd0034}},	//   _hwyr, koel, _גרינ, biae
  { {0x84460029,0x2486587f,0x7bce1c94,0x61e9008c}},	//   مختل, tvom_, libu, joel
  { {0x61e9016b,0x8d5b000a,0xc448002b,0xc53700ce}},	//   doel, רכני, شیان_, спіх_
  { {0x9f580064,0x6ac5002e,0x75f8006f,0x533308e8}},	//   örü_, _útfæ, cízn, пешт
  { {0xb286044e,0x9f4500f2,0x7d160026,0xb97a000a}},	//   сылк, illä_, _ogys, ָנִי
  { {0x75d604b6,0x673e0a6e,0x7bce0213,0xdb070030}},	//   _ايرا, lapj, hibu, nkjá
  { {0xf4840086,0x251b0008,0xf08a0015,0x7c360034}},	//   _بازی, _תומא, ائبه_, _nwyr
  { {0xfe0a0092,0x487b0053,0x187b000a,0x673e0030}},	//   _sắp_, נטיס, נטיב, napj
  { {0x7c360026,0xe2160029,0xa2d30015,0xa3e5000b}},	//   _awyr, _طباع, _فيكت, नवर_
  { {0x6442022d,0x8cb5005d,0x9f4500f2,0xc05a0036}},	//   osoi, उनलो, ellä_, _бік_
  { {0x79840026,0xd12f0015,0xa2650016,0x6ce701f3}},	//   ddiw, _أمه_, huộ, сіне
  { {0x7c360026,0x69cd0026,0x3f820024,0x69da1f0d}},	//   _dwyr, wiae, ēkus_, éten
  { {0x7f3b00b4,0x75f8002c,0xcff70008,0x8fc50086}},	//   _געוו, vízn, _הצגה_, _بزنن
  { {0x6442022d,0x3835009e,0x23ab0134,0x72ab0643}},	//   ksoi, жнар, _højt_, אֱמַ
  { {0x69cd0176,0xbc680074,0x7c360026,0x3ec80007}},	// [e130] riae, _همين_, _gwyr, žutė_
  { {0x161d000b,0x69cd00a6,0xf770012c,0x61e929c3}},	//   _बंदर_, siae, فام_, zoel
  { {0xb8f0014e,0x163b0029,0x61e9003f,0x64420003}},	//   _वे_, اسطة_, yoel, esoi
  { {0xc4d10015,0x7afa5880,0x89f40033,0xdb150030}},	//   وْا_, ütte, _няўц, pizó
  { {0x9f450152,0x61e9016b,0x7d7c004c,0xe4cb002b}},	//   solé_, voel, טראג, دبان_
  { {0xc7b80010,0xd2a90001,0xcc3c004c,0xe4a40033}},	//   _лёс_, икле_, רעגט, ярхо
  { {0x51550054,0x57fa000a,0xf3f00015,0x81bc003d}},	//   отпу, _כלשו, رأه_, _ttēl
  { {0xd9fb014e,0xd9f9005d,0x7d1a0046,0x60d60091}},	//   ्षित_, ंतित_, ětsk, _žyma
  { {0x9f4500f2,0xad9b001a,0x61e95881,0x0000006a}},	//   yllä_, rmúl, roel,
  { {0x3e7a0048,0x201100dc,0x6304002b,0x248d5882}},	//   _būt_, özi_, _کومل, _irem_
  { {0x753b0111,0xc332000a,0x41e70033,0xa2d50015}},	//   _keuz, _חוב_, _ліда, _بيات
  { {0x1d0a0ea6,0xed5a0175,0x8c96017f,0x8288000a}},	//   иени_, шом_, оргі, _לְנֶ
  { {0x645d0123,0xccfa01c6,0xbbea0058,0x0000006a}},	//   _åsid, рхні_, لرسم_,
  { {0xe3a70067,0x7016004f,0x141a004f,0x79840416}},	//   ذر_, _וחסד_, יושב, wdiw
  { {0x3e7a0024,0xdb1d00dc,0x9c870264,0x6b63005e}},	//   _gūt_, ózás, _počí, ькра
  { {0xaa570015,0x753b5883,0x6442008c,0x1cba0015}},	//   تلفا_, _neuz, ysoi, _ناخب_
  { {0x691e00bd,0x0319000b,0xc172000a,0xa88701b7}},	// [e140] všeč, दशाह_, וחן_, ойта_
  { {0x88c500e6,0x46f6109b,0x6fb9000b,0xd7f9005e}},	//   ستقل, очет, इसिं, бує_
  { {0xa96a0b1a,0x869a0b1e,0x2c645884,0x0000006a}},	//   _кина_, штат_, löd_,
  { {0x213f0049,0x673e0030,0x248d4bdb,0x94aa0c31}},	//   jauh_, sapj, _brem_, итла_
  { {0x64a30010,0x43940731,0x8433005e,0xa3d6000b}},	//   маца, залс, дніє, ाचल_
  { {0xf8b3000a,0xdc89000a,0xc5090021,0x39405885}},	//   _חשש_, מְצָ, حتمل_, lais_
  { {0x3f850176,0x96f90010,0x96635886,0xd2500015}},	//   ddlu_, _гэту_, _окре, رنة_
  { {0xe4760010,0x248d0293,0xcb13039e,0x753b1527}},	//   _музэ, _frem_, ולו_, _geuz
  { {0x673c0d25,0xb4250015,0x2c640123,0xcf9a02d9}},	//   _kerj, _فعلو, jöd_, ајн_
  { {0xd007000d,0x39405887,0x3faa0054,0x661c17f2}},	//   оење_, hais_, рњим_, _kurk
  { {0xee860010,0x3940138a,0x673c5888,0x1288002b}},	//   цыпо, kais_, _merj, _دمای_
  { {0x69da0014,0x39401cdb,0x63a80107,0xa06a01f3}},	//   étel, jais_, _hodn, _вада_
  { {0x6fb60015,0x661c17cd,0x0ca8131f,0x63a85889}},	//   _ومصا, _lurk, отри_, _kodn
  { {0x10a30001,0x0aeb0015,0xd0f7000a,0x673c07c4}},	//   _циљн, لرأي_, _וצדק_, _nerj
  { {0x19950010,0x39400026,0x0f57000a,0x9a88006b}},	//   павя, fais_, _ויום_, ощта_
  { {0x2d850024,0x4e930067,0x63a8013f,0x79940099}},	//   ēles_, _آشور, _lodn, мисф
  { {0xc7470029,0x673c0375,0x290f038a,0x08550033}},	// [e150] قضاي, _berj, äga_, яваю
  { {0xf773588a,0xc72b0036,0xd7f10015,0x65600125}},	//   بار_, ріал_, ركا_, _acmh
  { {0x3940588b,0xcb88000a,0x673c0012,0x4b7a000a}},	//   bais_, _וְרֹ, _derj, _האתו
  { {0x46380029,0xe6180036,0x3940588c,0x5eeb000a}},	//   تأكد_, іді_, cais_, בַדְ
  { {0x399a0008,0xc8640dd8,0xe5680015,0xe458005e}},	//   _הירד, _отри, تمنى_, жжі_
  { {0xcc7c000a,0x3c7c000a,0x248d0045,0x53c80033}},	//   שְׁר, שָׁב, _vrem_, огім_
  { {0x61e4018c,0x05770002,0x63a80107,0xdb070789}},	//   čiln, _وارد, _dodn, skjæ
  { {0xdb050003,0x91fc003d,0x248d588d,0x2055226f}},	//   _cohé, _spār, _trem_, птор
  { {0xb3670063,0x6579003e,0xdb1e00f2,0x2418005e}},	//   _мъжк, mewh, _ympä, _дією_
  { {0x63a8005c,0x3940003d,0x6d5d0012,0x201f030b}},	//   _godn, zais_, egsa, rqui_
  { {0xfe7100e5,0xa1150015,0xe247002b,0x39400003}},	//   ردد_, _فوات, _ذخاي, yais_
  { {0x12fa0008,0xdb1c002d,0x3f830796,0xc2c40015}},	//   _ההעב, mhré, žju_, _غيني
  { {0x7f950b08,0x1c43017f,0x611a000a,0x64590034}},	//   _надх, нням, _הונה, nuwi
  { {0xe81f005d,0x6d5d0035,0xe452004c,0x6488000a}},	//   _बढ़ा_, agsa, עֶר_, קְרְ
  { {0x3af50080,0x7f3a000a,0x64590079,0x8f9a000a}},	//   дятс, _העצו, huwi, _ליסי
  { {0x645900dd,0x31b10046,0xbda50015,0x661c002a}},	//   kuwi, _bázi_, _يحيو, _rurk
  { {0x673c588e,0x8d5b000a,0x2e21001a,0x27fa0015}},	// [e160] _perj, _הכפי, _hóf_, مفرد_
  { {0x661c28df,0x3940588f,0x6281528e,0x66e607f9}},	//   _purk, sais_, _oslo, поза
  { {0xcb0a0086,0x673c5890,0x6b7b000a,0xdb37000a}},	//   _ديدن_, _verj, _פרטנ, _מניח_
  { {0x27190089,0x63a803cd,0x7a15002a,0x31b10046}},	//   třní_, _sodn, _wątr, _fázi_
  { {0xc9530008,0x45190010,0x673c5891,0x05bd000b}},	//   _אמר_, іцця_, _terj, ्फ़ब
  { {0x60d60007,0x9cd7000a,0x661c1bcc,0x999f006f}},	//   _žymo, הונה_, _turk, čuť_
  { {0x66e35892,0x63a832f8,0x8b57004f,0x83690058}},	//   _зора, _vodn, ליסס_, تصنف_
  { {0xcb13013a,0x63a8005c,0x61e404c0,0xd6db000a}},	//   עלה_, _wodn, čilo, _החלל
  { {0xa41c0024,0xa99b000a,0xdcef0045,0x62812fcb}},	//   ādēļ_, מבקר, iecă, _eslo
  { {0xdfd00086,0x5f94006b,0xbcfb0003,0x94bb000a}},	//   ئيد_, фиот, ngée, _הממת
  { {0xdd910115,0xdb1c176a,0x798601f9,0xdb15007f}},	//   نود_, chré, _oakw, lizö
  { {0xf653000a,0x6d5d001a,0x420a0054,0x71650015}},	//   עצר_, ugsa, _унео_, _يانك
  { {0xdcef0011,0x5c074062,0xdb05006f,0x321e002a}},	//   decă, зява, _dlhý, _huty_
  { {0xea000016,0x28c7000b,0x23e7000a,0x6fb40040}},	//   _đạc_, _रेगि, ּֽךָ_, _زمبا
  { {0x6e940086,0x2cb30089,0x2fa50015,0x5ac80033}},	//   _آلبا, _řadě_, _تصنّ, плём_
  { {0x6edb000a,0xe945009a,0x0000006a,0x0000006a}},	//   _לחופ, برآی,   ,
  { {0x99d400e6,0x79860375,0x321e002a,0x48150174}},	// [e170] رتفا, _dakw, _luty_, дмас
  { {0xdc3c0008,0x7c2d003f,0x87d70015,0x6d08000a}},	//   _העזר, _itar, أغرا, _מִתַ
  { {0xf77000e6,0xdb07001a,0x36d40004,0xc5190138}},	//   طال_, rhjó, нофр, оўлі_
  { {0x25a90084,0xf6500070,0x64590035,0x9f450227}},	//   ðal_, ائل_, tuwi, volí_
  { {0x15180029,0xfc460089,0x0000006a,0x0000006a}},	//   أزمة_, říve_,   ,
  { {0x9f47002c,0x6579003e,0x321e005c,0x9f450251}},	//   _okná_, sewh, _buty_, tolí_
  { {0xf772000a,0x45f70015,0x6d4d0030,0x386906cb}},	//   _שקל_, _فأرس, _odaa, ltar_
  { {0xe1f10086,0x321e3bd6,0x7abc000a,0x38695893}},	//   خست_, _duty_, מצוו, otar_
  { {0xa93c004c,0xc5e9000b,0x25b20061,0xc5640015}},	//   צײזי, टकीय_, öyle_, _سُلي
  { {0x38695894,0x24800061,0x442d5895,0x7f410e51}},	//   itar_, çime_, _ite_, ualq
  { {0x38690482,0x90e70074,0x6281016f,0xdb1c001a}},	//   htar_, _کسان, _uslo, tirþ
  { {0x6449002e,0xadb70015,0x38695896,0x201d02f2}},	//   _kvei, ِهَا_, ktar_, _tuwi_
  { {0xac93008f,0xa1580010,0x7ae90061,0xe0ce41f8}},	//   ваўш, _хачу_, şetl, _рв_
  { {0x38695897,0xe0d00015,0xa0090021,0xf092000a}},	//   dtar_, _حزم_, _بقتل_, _שנג_
  { {0x38690011,0xca750139,0x75f80030,0x3a730033}},	//   etar_, нуты, bízh, клёр
  { {0x38690375,0x442d5898,0x5ee8000a,0x3f870e63}},	//   ftar_, _ote_, _מַפְ, _hanu_
  { {0x3869002f,0xe7aa05c4,0x3f870962,0x1867170d}},	// [e180] gtar_, овал_, _kanu_, мати_
  { {0x09030124,0x7a15005c,0xdb2400f2,0xdc8b000a}},	//   тпун, _wątp, ärät, _וְטָ
  { {0xe1f90007,0x80d4000b,0x3f875899,0xbcfb0003}},	//   klų_, _बेने, _manu_, rgée
  { {0x893603c4,0xd910002b,0xf769000a,0xd826012e}},	//   _تعدا, _میز_, יק_, _одми
  { {0x397b000a,0x38692b8e,0xa53300e2,0x6d3b004f}},	//   _וטכנ, ctar_, тніч, חֲוו
  { {0x36360015,0xa43d0033,0x28c7000b,0xf79a0015}},	//   _يرأس, сьцi, _रेटि, _بنسب_
  { {0xe2970431,0xf6230210,0xfd650016,0x64494061}},	//   дај_, _адсо, _chuố, _evei
  { {0xd130003b,0xe1f90007,0xa9bb0053,0xbbbb000b}},	//   دمة_, glų_, ַזיר, _उत्क
  { {0x75d30015,0xb145002b,0x67230796,0x301408df}},	//   _شيكا, ریوم_, žnje, ндир
  { {0xdefa0010,0x3f870026,0x389b000a,0xe1f90091}},	//   жым_, _canu_, קיינ, alų_
  { {0x1df90010,0x3f87016f,0x3eb800dc,0x32fc0092}},	//   зены_, _danu_, árt_, _ủy_
  { {0xd1300015,0xb1e50015,0x442d4222,0x25a618cc}},	//   _صمت_, _كأنه, _yte_, njol_
  { {0x38690123,0xfc64006b,0xfbd300c3,0xa0b60015}},	//   xtar_, кърн, نتس_, _تحاص
  { {0xb345001c,0x3f870026,0x0000006a,0x0000006a}},	//   maçã, _ganu_,   ,
  { {0xb34503af,0xa0070029,0x0a6807c1,0xf1b2000b}},	//   laçã, _تقول_, мрти_, _जवान
  { {0x2369016f,0x39150001,0x7de70029,0x3869589a}},	//   đaji_, ембр, _تستم, ttar_
  { {0xb345001c,0x28f80080,0x6d3c000a,0xcdf8000a}},	// [e190] naçã, деть_, _ותחנ, _קמחי_
  { {0x7d001ca8,0x3869589b,0x4ff8004f,0x0000006a}},	//   ümse, rtar_, פִּנ,
  { {0x7bd500df,0x8ac70010,0xfc460089,0x200c0064}},	//   mizu, _цёпл, říte_, imdi_
  { {0x28d0005d,0x38694ba7,0x3983002b,0x7bd5589c}},	//   _सेवि, ptar_, _جیرف, lizu
  { {0x442b0033,0x23290302,0xb956004f,0x05b20058}},	//   ццем_, поли_, _אירח_, طموح
  { {0xb345001c,0x3a2100e8,0xe7300115,0xd763002b}},	//   daçã, _kuhp_, _نصف_, _جنسی
  { {0xc5570015,0x4252002b,0xdb1c1ca8,0x3f873387}},	//   _يضرب, هنور, virü, _ranu_
  { {0x644905d8,0x04c90015,0x00850350,0x3206172e}},	//   _tvei, _فوزي_, елио, _choy_
  { {0xd3750124,0xb34503af,0xe0d93c2f,0x7bd52254}},	//   _плаћ, gaçã, яви_, kizu
  { {0x60061292,0xfd650092,0x09dc005d,0x75f8163c}},	//   нным_, _thuố, _यद्य, vízi
  { {0xf77200b2,0x645e005c,0x32550036,0x3f87007c}},	//   נקט_, ąpie, _чвер, _vanu_
  { {0x25d5000a,0x6cc60b9b,0x3f870046,0x25ad589d}},	//   תוֹן_, ейма, _wanu_, _joel_
  { {0xb34503af,0x5cf5008f,0x61fb0064,0x25ad589e}},	//   caçã, вяру, mlul, _moel_
  { {0x2056000a,0x6fb50015,0xdee50cab,0x61fb589f}},	//   _ניצל_, _سمعا, _поли, llul
  { {0x637301e2,0xbad50010,0x6e950029,0x61fb014b}},	//   mını, віты, _ألعا, olul
  { {0x63730064,0x61fb0064,0x3eb801f0,0xbc66005e}},	//   lını, nlul, ørte_, _звик
  { {0xa8061c44,0x61fb0af6,0x6d4603cf,0xa756006b}},	// [e1a0] езал, ilul, maka, етещ
  { {0x637301e2,0x6d46101b,0x25bf1814,0x2bca00ce}},	//   nını, laka, _alul_, _хлоп_
  { {0xb34503af,0xbb3b000a,0x1ae50015,0x61fb0061}},	//   zaçã, _מעיי, _لأََ, klul
  { {0x98a607be,0x1cba000a,0x6d46294a,0x1c04000b}},	//   _зиме, ּמַע, naka, _शीतल_
  { {0xb345001c,0x63730064,0x7ec600dc,0x25ad016b}},	//   xaçã, kını, _képé, _doel_
  { {0x69d601e2,0xb34503af,0xf1b90024,0x63730064}},	//   liye, vaçã, ekš_, jını
  { {0x63730064,0xbcfb0152,0x6d461636,0xc3270015}},	//   dını, nfér, kaka, ركين_
  { {0xb34503af,0x7ec60014,0x69d60064,0x7bd5003f}},	//   taçã, _lépé, niye, zizu
  { {0x75d30029,0x6d460d25,0xc05a0036,0x63730064}},	//   _إيقا, daka, чій_, fını
  { {0xb34503af,0x50b70029,0x7ec60030,0x2d8902de}},	//   raçã, عديد_, _népé, _saae_
  { {0xd3370008,0x48170053,0x69d60064,0x7bd5315e}},	//   _נראה_, ײַזן_, kiye, vizu
  { {0xd2460074,0xb345001c,0x92c20064,0xa3cc000b}},	//   ین_, paçã, ışın, शोर_
  { {0x637301e2,0x69d60064,0x5cb80033,0x7bd558a0}},	//   bını, diye, еляў_, tizu
  { {0xbcfb038d,0x637301e2,0x7d04005c,0x765e00f2}},	//   ffér, cını, _dzis, kupy
  { {0xda7802c8,0xdb240f3c,0x4e930021,0x69d60061}},	//   нят_, órás, _مشير, fiye
  { {0x4efb0008,0xceb3000a,0x929b000a,0x69c42908}},	//   _מהוו, _תיק_, הילת, ghie
  { {0x5c740033,0xdc140061,0x58190033,0xbcfb0030}},	// [e1b0] _блыт, aşıy, джаў_, rfés
  { {0x3f8c0034,0xa8a408f0,0xf6e71466,0xf64702ed}},	//   nddu_, ырск, нцен, ехдн
  { {0x3f8c001a,0x61fb0061,0x69d658a1,0x394201d0}},	//   iddu_, ylul, biye, _feks_
  { {0x63730064,0x69c458a2,0x94790cfe,0xdb1c001a}},	//   zını, chie, дску_, lirð
  { {0xc8670036,0x63730064,0xe3ae0010,0x25ad00dd}},	//   _ятни, yını, аб_, _voel_
  { {0x69da0030,0xad9b0247,0x6d4658a3,0xa224009a}},	//   étev, llúd, zaka, گروه
  { {0x02c20036,0x61fb062c,0x765e00da,0x25ad007c}},	//   ийшо, tlul, cupy, _toel_
  { {0xa2240086,0x6a9c000a,0x798d58a4,0xdb1c001a}},	//   دروه, לשונ, ndaw, hirð
  { {0x63730064,0x6d4628be,0x61fb58a5,0x8e20005e}},	//   tını, vaka, rlul, _рiк_
  { {0x661b008c,0xe0d6004a,0x69d60061,0xdb1c0125}},	//   _hiuk, твь_, ziye, thrí
  { {0x63730482,0x61fb01e2,0x7ec60152,0x661b003f}},	//   rını, plul, _répé, _kiuk
  { {0x637301e2,0x2369016f,0x7afa0030,0x645944b4}},	//   sını, đaju_, üttm, orwi
  { {0x69d60064,0xc8d0005d,0xdb1c002e,0x6d460375}},	//   viye, _सेंट, firð, raka
  { {0x661b4444,0x3c190033,0x799d2ff9,0x6d4658a6}},	//   _liuk, еўся_, _answ, saka
  { {0x69d60064,0x60c90064,0x6d462fa4,0xc332000a}},	//   tiye, lzem, paka, שול_
  { {0x60d60007,0xdc140064,0xbcfb0003,0x6459002a}},	//   _žymi, rşıy, rfér, krwi
  { {0x69d60064,0xa9230054,0xf1b2000a,0xbcfb58a7}},	// [e1c0] riye, рдул, בסן_, sfér
  { {0x61e400bd,0x47c3005e,0xac0a005e,0x798d002a}},	//   čili, абув, _інна_, adaw
  { {0x39424b2e,0x645958a8,0x15460004,0x6b550033}},	//   _teks_, erwi, веем, _стых
  { {0x7c24003f,0xd5b9005e,0x80c4000b,0xef18003d}},	//   _kuir, нсі_, िनमे, neļa_
  { {0x3f8c06ee,0x75d30015,0x6d44016e,0x672306c0}},	//   yddu_, جينا, _meia, žnja
  { {0xa3cc005d,0xe2a30092,0x93f30010,0xe3af0015}},	//   शों_, _trữ_, апіц, قرى_
  { {0x38600f14,0xb286004a,0x926a0004,0x87b9006b}},	//   luir_, тылк, фрла_, _чуят_
  { {0x31b800dc,0xe1ef0115,0x21670054,0xdb0700cb}},	//   _kézi_, يسي_, вићи_, rkjø
  { {0x7c240c1b,0xef18003d,0xf487002b,0x5ff40004}},	//   _nuir, deļa_, _لالی, лзиу
  { {0x798d002a,0xdb0700cb,0x6e2303a0,0x7ae958a9}},	//   zdaw, pkjø, _bunb, şeti
  { {0xa75b0053,0x3f8a002c,0xf1c90092,0x3860002d}},	//   ודיר, ľbu_, hạy_, huir_
  { {0xdb1c001a,0x7c24176a,0x40960015,0x9f4c0144}},	//   virð, _buir, _للصر, modí_
  { {0x7c24002f,0x70540029,0x442400e8,0xd037005e}},	//   _cuir, _إنتا, _jum_, _азії_
  { {0x386008e0,0x5ed60015,0xdb1c001a,0x6ec60015}},	//   duir_, _لتعز, tirð, _لتبق
  { {0x49bb0115,0xadbd0033,0x6e2300da,0x9f4505a4}},	//   وارد_, _накi, _gunb, alló_
  { {0x201c000c,0xef18003d,0x96570033,0x38600003}},	//   _hivi_, ceļa_, сiны_, fuir_
  { {0x442458aa,0x3860194d,0x7deb0091,0xdb1c001a}},	// [e1d0] _num_, guir_, ręsd, sirð
  { {0x6283005c,0xf7700115,0xfe6d002b,0x661b0fd8}},	//   ywno, قام_, _بگی_, _siuk
  { {0x98140015,0x2b5e002a,0x8bb400c3,0x6595012e}},	//   شبكا, ótce_, _خصيص, лажу
  { {0x44240a48,0x7aba000a,0x644b0123,0x69da0030}},	//   _bum_, _נצרו, tsgi, étet
  { {0xdb1c002f,0x442458ab,0x33d5042b,0x493a000a}},	//   mhrá, _cum_, лікт, _רגשו
  { {0x60c900bd,0x394945d6,0x442458ac,0x4cbc004f}},	//   vzem, laas_, _dum_, וזדו
  { {0xb3640063,0x92640029,0x661b008c,0x7bcb0091}},	//   ръчк, لديم, _tiuk, _įgul
  { {0x60c90251,0x394902f2,0x442458ad,0xf652004f}},	//   tzem, naas_, _fum_, _לצל_
  { {0x6d440251,0x6e2344df,0x317f58ae,0x53350fea}},	//   _reia, _sunb, reuz_, _безт
  { {0xe4e40036,0x2374002b,0xee393a2d,0x1e85005e}},	//   _тісн, _نامح, нно_, глом
  { {0x4424018b,0xd1750010,0x201c0024,0xb6d6000a}},	//   _zum_, _былы, _divi_, ָֽיו_
  { {0xb2ba00b2,0x9b960086,0x6455003d,0x865a015b}},	//   _אמער, گلست, _āzij, עדרי
  { {0x7c2458af,0xef18003d,0x6d44016e,0xbf88009a}},	//   _quir, reļa_, _veia, رئیل_
  { {0x70520031,0x8fa20c91,0xa0664db5,0x3f830072}},	//   _انوا, _гаше, _саша_, õjud_
  { {0x2d840003,0x7e79004c,0xdb0532c3,0x6d440ab2}},	//   ômes_, _טאַז, _pohá, _teia
  { {0x3b07000d,0xf2d20053,0x7c24002d,0x38c8002b}},	//   ѓето_, צען_, _tuir, پاری_
  { {0x09f70029,0x090622d7,0x98a304b9,0x475a00f4}},	// [e1e0] افقة_, упан, бите, ерея_
  { {0x9d1b0008,0xad1b0008,0xcc3b004c,0xdb1c013f}},	//   _אופט, _אופר, _רעיט, ahrá
  { {0x4fba0053,0x39490020,0x96960033,0x5fba004c}},	//   עזעצ, baas_, ыраш, עצענ
  { {0x39350010,0x75890036,0x44244a4d,0xdb1c0107}},	//   _вэрс, ксів_, _pum_, chrá
  { {0xf993000a,0x99f7000a,0x7e61141c,0x0000006a}},	//   _פרש_, _תזכה_, hulp,
  { {0xbc0d000a,0x3373005e,0xf8b3000a,0x741300c3}},	//   ֭הוָ, йгір, _השש_, مونا
  { {0x201c00f2,0x03a30054,0x63880091,0xc7d7000a}},	//   _rivi_, сијо, vūnė, _עולי_
  { {0xf4840086,0x2d82016f,0x315a0015,0xe617006b}},	//   _پاری, jeke_, رجعة_, _бдс_
  { {0x442401c2,0xc2070015,0x0000006a,0x0000006a}},	//   _uum_, دقين_,   ,
  { {0x30770029,0x8f860001,0x547b000a,0x53b8000b}},	//   احية_, ућил, _אטמו, _अविश
  { {0x20020024,0xb7db0008,0xf777004c,0x201c3eed}},	//   ēki_, תקיי, נעטי_, _vivi_
  { {0x3e4e002a,0x60d60091,0x113a0058,0xe231009a}},	//   ręt_, _žymu, _أثاث_, _بکوب
  { {0xdfda0063,0x5c740142,0x55bb000a,0x201c0016}},	//   _пък_, блят, תמכו, _tivi_
  { {0xd00f0029,0xaedc005e,0x6e940fea,0x93b50016}},	//   _فلن_, _облi, _вику, _lĩn
  { {0x394900b6,0x539b0008,0xa0070015,0xaba80033}},	//   taas_, עילו, _حقول_, ывёз_
  { {0x99d40029,0xc4c4000b,0xf99f0016,0x6935131f}},	//   متقا, वनाओ, _thèm_, рнау
  { {0x3949042f,0x9fbd002a,0xd7d500af,0x7ae101d3}},	// [e1f0] raas_, _głów_, ажањ, últb
  { {0xb8cd005d,0xd7590015,0x0596002b,0x69da1112}},	//   _कप_, ئلات_, یانگ, éter
  { {0x3707061e,0x17f80015,0x98140015,0x67230085}},	//   учав, ارقة_, إبقا, žnjo
  { {0x645d0123,0x28d0000b,0x15a8006b,0x04b504e7}},	//   _åsik, _सेकि, лъчи_, исля
  { {0xdcfd00df,0xdd3c000a,0x64a538fd,0xb5c8009a}},	//   kesč, תעדכ, рала, دونم_
  { {0x3438002b,0x4255016a,0x321d0535,0x0000006a}},	//   اسند_, атит, _siwy_,
  { {0xd3460086,0xfbb8000a,0x02d8000b,0x97a8000a}},	//   شینه_, רפות_, _भेदभ, _עֹשֵ
  { {0x02050083,0x0000006a,0x0000006a,0x0000006a}},	//   јзин,   ,   ,
  { {0x3d01000b,0x7dc60125,0x8367002b,0xc0e501f3}},	//   ोधों_, _lósc, _مدال, ропк
  { {0xd00e0029,0xd0090001,0x7e6126ce,0xdb050012}},	//   ولي_, ђене_, tulp, _kohä
  { {0x9fbd0050,0xe2330074,0xd5b9005d,0x4dd60029}},	//   _słów_, _اکتب, _आवाज, لتحس
  { {0x41e40010,0x6006001a,0xd256004f,0x0000006a}},	//   _ліча, rðma, _כשעה_,
  { {0x814c0053,0x91ba000a,0x7e6109cf,0xc212000a}},	//   _טעאַ, _שמני, sulp, _והא_
  { {0x9516000a,0x2d8258b0,0x6b6602d9,0x0000006a}},	//   יקרא_, seke_, јква,
  { {0x7ff40018,0x09d60010,0xaa462a44,0xd00e00c3}},	//   _اسنا, ацаў, ребл, _تلو_
  { {0xdb1c58b1,0xd24f0033,0x7bc501d3,0x7de40052}},	//   nkré, ццi_, _elhu, iđsk
  { {0x97360015,0xdc54002b,0xad9b006f,0x8dfb004f}},	// [e200] لعاص, _اربک, slúc, _שהפת
  { {0x7dd6003d,0x7d1b006f,0x86960054,0xe73a1bb1}},	//   kšsk, ľust, ијеч, теж_
  { {0x39ea008f,0xbbe90086,0xef12000a,0x85460033}},	//   _адно_, _حريم_, ַּע_, аэле
  { {0xc7a900f3,0x7bdc58b2,0x2486002a,0xb4660015}},	//   וב_, liru, twom_, لدته
  { {0x93b50092,0x69c658b3,0x645e002a,0x2ee2000b}},	//   _vĩn, _ilke, ąpio, _पश्त
  { {0x0666002b,0x5c97000a,0x7bdc46fe,0xe7370e40}},	//   _پاسپ, יכנע_, niru, _вер_
  { {0x877b0008,0x31c60001,0x7bdc014b,0x66e30daa}},	//   _שאלי, исив, iiru, _дора
  { {0x3f8e003f,0x7bdc58b4,0x51f30058,0x0000006a}},	//   _safu_, hiru, يسير,
  { {0x7bdc2254,0xdfa6009c,0x6602030a,0xcfa60c5b}},	//   kiru, ајно, mlok, ашни
  { {0x7bdc003f,0xc7b1000a,0xe809000b,0x66021856}},	//   jiru, ִ֑י_, वतया_, llok
  { {0x6e630a61,0x1797000a,0xadf5005e,0xd12f14fd}},	//   отяж, בדיל_, йпош, _мх_
  { {0xad670015,0x629a008c,0xd12f0015,0x660258b5}},	//   جاده, _irto, _قمم_, nlok
  { {0x9989005c,0xdcfd0007,0xdce60091,0x76430030}},	//   ymał_, pesč, iekė, ányz
  { {0xb09b000a,0x69da0003,0x7ff30040,0x307b000a}},	//   _שיגר, èten, _وسوا, _סאונ
  { {0x1ab400a4,0xf96b0c55,0x1f37000a,0x19590174}},	//   обря, край_, _דרור_, лавы_
  { {0x660200dc,0x39a4044a,0x4efb000a,0x7bdc003d}},	//   jlok, ошув, _שההו, airu
  { {0x286b006b,0x78f80015,0x58870033,0xdb5b004a}},	// [e210] ърво_, لعكس_, шыва, _июн_
  { {0x960f014e,0xc60f005d,0x69c60fe7,0x5fb8000a}},	//   िष्ट_, िष्य_, _elke, נֶּג
  { {0xb8fe005d,0x66022061,0xaa950021,0x29e80061}},	//   _थे_, flok, _الجث, oğal_
  { {0x4658005e,0xdce6003d,0xdb07001a,0x78a201c0}},	//   рацю_, žāņu_, skjó, ťova
  { {0xa8790053,0x24f8054f,0xdddb0030,0x746b1117}},	//   _גאָר, анцы_, nttő, трев_
  { {0x28d0005d,0x8c38000a,0xe2910015,0x8338006b}},	//   _सेटि, סטוס_, كذب_, ачът_
  { {0x95670063,0xdb1c00b8,0xeb92000f,0xd2680029}},	//   _възд, chrä, לָה_, لصين_
  { {0xc692000a,0x98a0002a,0x0000006a,0x0000006a}},	//   _צאן_, ecię_,   ,
  { {0xa9380008,0x2295002b,0x629a08cf,0x657b02f2}},	//   בטחה_, _گلاس, _erto, _ibuh
  { {0xdb1c01c0,0x9f540052,0x644d0073,0x0000006a}},	//   skré, æfða_, šais,
  { {0xe7fa000b,0x41e70033,0xb4e7000b,0xa29401c6}},	//   ्तता_, _кіда, _पशु_, _мафі
  { {0xb4f90053,0x26b6000a,0x667a000a,0x8d760015}},	//   ָפֿי, צִים_, נטרק, حادا
  { {0x248d0089,0x7dc6002d,0x213f0049,0x0468000a}},	//   _jsem_, _cósa, mbuh_, ֑יךָ_
  { {0x8cb5005e,0x96620033,0xa036004f,0x66020535}},	//   ісяч, сiль_, _האסה_, zlok
  { {0x657b016f,0xdd110227,0x4e350015,0xde350088}},	//   _obuh, _výšk, _اعتز, _уэль
  { {0x7ae1002d,0x3eb800b8,0x3e7158b6,0x7bdc58b7}},	//   últa, ärte_, mát_, siru
  { {0x69d800df,0x3e7100dc,0x7bdc58b8,0x600f0bfa}},	// [e220] _įved, lát_, piru, rømf
  { {0xbb860196,0xab6603fc,0x5fc0000b,0xc8650015}},	//   _الدي, _увол, एसएल, تطفي
  { {0x2bb7000a,0xdb9b004c,0x66270061,0xdce60091}},	//   _הפיך_, _עסטר, _ırkç, tekė
  { {0x660200f2,0xcb130008,0x5efa004c,0x7afa0012}},	//   ulok, _מלת_, אפעד, üttu
  { {0x6ba50084,0xdcf60264,0x3e7158b9,0xe7fa000b}},	//   _útgá, _obyč, hát_, ्तदा_
  { {0x39400007,0x3f850f8a,0xd7f20015,0x3e7158ba}},	//   lbis_, jelu_, _ركز_, kát_
  { {0x3e710014,0xe28f0015,0x660201ad,0x3f851cbd}},	//   ját_, فذي_, plok, delu_
  { {0xc0340e88,0x4a9b0053,0xb03407c1,0x2d92003f}},	//   ониј, ריקג, ониш, _naye_
  { {0x3940002d,0x0443006b,0xa5070b76,0xe5060015}},	//   ibis_, _нетн, _гета_, _طبري
  { {0xb7fa005d,0x3f850026,0xc4c50015,0x3e710030}},	//   ्तिम_, gelu_, _بتفو, fát_
  { {0xd3370008,0x3e7100dc,0x539b000f,0x57fb000a}},	//   _הרבה_, gát_, _תיבו, רליו
  { {0x3860001a,0x0000006a,0x0000006a,0x0000006a}},	//   krir_,   ,   ,
  { {0x3f850d5d,0x50ba012c,0x5c742fa0,0x317b004f}},	//   belu_, _حداد_, плят, _תרדמ
  { {0x3e710f49,0x3f850046,0x3860082b,0xc4d3004f}},	//   bát_, celu_, drir_, לגר_
  { {0x5e440029,0x3e710030,0x386058bb,0x99850058}},	//   _بَعْ, cát_, erir_, يلسو
  { {0xfe37000a,0x7dc60125,0x386000de,0xdb05006f}},	//   _פרחי_, _tósa, frir_, _kohú
  { {0xbbeb0074,0x57270029,0x8d740086,0x6d4f013c}},	// [e230] _مردم_, مراق, _رايا, maca
  { {0x6d4f48cf,0xe759005e,0x7d0d0085,0xbc380015}},	//   laca, рижі_, _izas, _اسيا_
  { {0xa3ac000b,0x3ebe00cb,0x2d9200aa,0x394058bc}},	//   गान_, nytt_, _yaye_, bbis_
  { {0x6d4f01e2,0xd6180015,0x7bc1001a,0x4efb05bd}},	//   naca, متنا_, öluf, נהאו
  { {0x998001e2,0x3e710030,0xd838055f,0x0000006a}},	//   lmiş_, zát_, _гэс_,
  { {0xcc780008,0xc4840010,0x248d00bd,0x3dc90026}},	//   צגות_, ялік, _vsem_, _llaw_
  { {0x998001e2,0x8b58000a,0xaabb000b,0x7de40030}},	//   nmiş_, זיוס_, ैनिक, lőse
  { {0x3e710014,0x20550ac7,0x213f00d9,0x4079005e}},	//   vát_, отор, ubuh_, ащою_
  { {0x6e2a00b8,0xf9940008,0x93470086,0x7dc6016e}},	//   _aufb, פרץ_, _هخام, _bósn
  { {0x3e7158bd,0x99800061,0x6d4f0125,0x3dc90034}},	//   tát_, kmiş_, eaca, _alaw_
  { {0x59c9014e,0x7dea005e,0x2d920003,0x9756000a}},	//   रसार, имог_, _paye_, חיתו_
  { {0x38600084,0xf6520053,0xc2c40021,0x6da603ae}},	//   yrir_, וצט_, _عيني, цима
  { {0x7d0d0050,0x3e715220,0x0468000a,0x2fd50015}},	//   _czas, sát_, ֖יךָ_, _وتتح
  { {0x38600152,0x24800064,0xcb6a0001,0x5f94004a}},	//   vrir_, çimi_, јаве_, _ничт
  { {0xdde90074,0xdcfd0024,0xab090015,0x3dc900da}},	//   _گروه_, resā, متفق_, _flaw_
  { {0x3e550024,0x3dc90026,0x69cd0034,0x6d4f58be}},	//   māt_, _glaw_, ghae, caca
  { {0x20c9014e,0x3e550024,0x38600152,0xde170015}},	// [e240] िनिध, lāt_, urir_, _بقيت_
  { {0x61e958bf,0x61fb003e,0x7d040061,0x39400034}},	//   hnel, houl, _iyis, sbis_
  { {0x3e5503eb,0x61fb1c5a,0x452a0658,0x6e24007c}},	//   nāt_, koul, ажен_, _kiib
  { {0x7a050010,0x80c9000b,0x69cd58c0,0x98a61a9d}},	//   _няўж, िनाइ, chae, _диме
  { {0xd38a005e,0x59bf000b,0x61e90085,0x6f03437e}},	//   ийде_, _एकतर, dnel, _lync
  { {0x3e550024,0x92940457,0xa294005e,0x3c8b000a}},	//   kāt_, закц, закі, שָׁ֑
  { {0x6d4f01e2,0x3e550048,0x599a0008,0x6ed9000b}},	//   yaca, jāt_, ֹשִׁ, _फेलु
  { {0x3e550048,0x61e958c1,0x394b0251,0x3e470030}},	//   dāt_, gnel, _xecs_, dőt_
  { {0xbfaa226a,0xf8bc000b,0xa87a000a,0xdb1e016e}},	//   атне_, ोनिय, ׁאֵר, _impõ
  { {0x187b000a,0xa4b7000a,0x6f030034,0x7bc0016e}},	//   סטיב, _ולמה_, _bync, êmul
  { {0xf0b70086,0x69c458c2,0xadbd0484,0x6d4f58c3}},	//   مایش_, kkie, ганi, taca
  { {0xd5a60087,0x61fb0003,0x7996002a,0x200558c4}},	//   رف_, coul, jdyw, alli_
  { {0x69c4005c,0xac19005e,0x6e2401c2,0x6d4f58c5}},	//   dkie, йому_, _diib, raca
  { {0x3e550048,0x60cc0064,0x61e00064,0x69c42c38}},	//   bāt_, ılmı, liml, ekie
  { {0x2e4a0063,0x6281482e,0x3e550024,0x6d4f17e3}},	//   _тяло_, _xplo, cāt_, paca
  { {0x99800064,0x7de40030,0x7c3d0123,0x61e058c6}},	//   rmiş_, tőse, ppsr, niml
  { {0x69cd0026,0x247e003d,0x7d0d58c7,0x394b003d}},	// [e250] rhae, nāmā_, _uzas, _vecs_
  { {0x7de400dc,0x69c4005c,0xf8070033,0x98b2002a}},	//   rőse, akie, ічан, zbyć_
  { {0x61fb003f,0x61e00061,0x69c4002a,0x61e958c8}},	//   youl, kiml, bkie, ynel
  { {0xdcfd0011,0x69c44d79,0x8afa0008,0x60c01581}},	//   cesă, ckie, _להתי, kymm
  { {0x183500b2,0x6281018c,0x3e550024,0x3e4700dc}},	//   _מאָל_, _splo, zāt_, zőt_
  { {0xfc3f002f,0x7c2d363d,0x61e00034,0x4c3c000a}},	//   ipí_, _muar, eiml, סתוב
  { {0xf5e7005e,0x386958c9,0xc225002b,0x7c2d58ca}},	//   _діам, luar_, سکاو, _luar
  { {0x3e550024,0xdb1e0d92,0x3e470030,0xdb1c0125}},	//   vāt_, _impô, vőt_, thrú
  { {0x61fb0590,0xafe50850,0x7c2d0125,0x386918c4}},	//   roul, зопл, _nuar, nuar_
  { {0xa2950010,0xe0d60010,0x3e550024,0x6f030026}},	//   _назі, явы_, tāt_, _pync
  { {0x69c4005c,0x7d0400f2,0xbea54085,0xb4d6000b}},	//   ykie, _syis, чанк, ाज़ी_
  { {0x3e550024,0x3eb800c0,0xc27a000a,0x442d01d7}},	//   rāt_, ärta_, _לרעי, _kue_
  { {0x7c2d017e,0x6e240020,0x3e550024,0x3e4700dc}},	//   _cuar, _viib, sāt_, sőt_
  { {0x69dd0176,0x442500e8,0xb4fa0008,0x38690144}},	//   _amse, _jil_, מפרי, duar_
  { {0x442d0df4,0xfe710029,0x69c458cb,0x442558af}},	//   _lue_, _أدت_, tkie, _mil_
  { {0x7c2d002d,0x75290297,0x316d0003,0x6d4d0079}},	//   _fuar, _ngez, ngez_, _geaa
  { {0x442508b8,0x9f450064,0x7c2d240d,0x442d0003}},	// [e260] _oil_, kolü_, _guar, _nue_
  { {0xf7720029,0x61e00064,0x69c458cc,0xdc9b20c1}},	//   عاء_, ziml, skie, _פסיכ
  { {0x3bbb013a,0x3a060086,0x61e00064,0x9bbb000a}},	//   _המיד, _فکری_, yiml, _הציפ
  { {0x14c80086,0x442558cd,0xca37000a,0x442d58ce}},	//   يهای_, _ail_, _מנטה_, _bue_
  { {0x442558cf,0x299b000f,0x339402bf,0x499b000a}},	//   _bil_, _הסכמ, далё, _השכב
  { {0x442d58d0,0x395258d1,0x249f58d2,0x44250da5}},	//   _due_, lays_, _drum_, _cil_
  { {0x44250064,0x249f002e,0x61e00064,0x2d80527c}},	//   _dil_, _erum_, timl, _obie_
  { {0x442d0467,0x32530063,0x7c3b0011,0x11d80015}},	//   _fue_, хвър, ţuri, توبة_
  { {0x64490176,0x61e001e2,0xa8060064,0x442d00e8}},	//   _gwei, riml, apış, _gue_
  { {0x61e001e2,0x30130010,0x60c000c0,0xbfaa03fc}},	//   siml, ндыр, rymm, стие_
  { {0x6449018b,0x6d4d0020,0x7c2d013c,0xc7b3000a}},	//   _zwei, _peaa, _suar, תבת_
  { {0x6006001a,0x77fa000b,0x7c250085,0x7bde58d3}},	//   iðmi, ्तुक_, _sihr, _ampu
  { {0xc19b000a,0x395258d4,0xf1a9000b,0x310a0004}},	//   _לשאי, days_, कारन, _ундп_
  { {0xe10b00b2,0x92020024,0x711b000a,0xbcfb0003}},	//   _פּאָ, žādo, _הודפ, dgét
  { {0x9f7b0008,0x7c2500f2,0x0f7b000a,0x3f7b039e}},	//   _הנוח, _vihr, _האוב, _האוס
  { {0x63ba005c,0xde930015,0x38692fcb,0xfe780091}},	//   _lotn, _أجوب, tuar_, mtį_
  { {0x290f00c0,0x2d8b5697,0xe7b90004,0xfe780091}},	// [e270] åga_, mece_, огаш_, ltį_
  { {0x29070024,0x442d2730,0x64490012,0x2d8b58d5}},	//   āna_, _rue_, _rwei, lece_
  { {0xfe7800df,0xf55900b0,0x26c70089,0x442d052a}},	//   ntį_, قلاب_, áno_, _sue_
  { {0x28de014e,0xdce4005c,0xddc20011,0x63a80f38}},	//   _नेवि, _wcią, mulţ, _andn
  { {0x674800dc,0x26c70198,0x399a000a,0xed58004c}},	//   érjü, šno_, _וירד, לבאר_
  { {0x442d0152,0x9cd80008,0x6578002c,0xb8e3000b}},	//   _vue_, הודה_, _ľahš, ौन_
  { {0x994d002c,0xf1a9005d,0x9f451295,0xdd10002c}},	//   _môžu_, कालन, zoló_, ižši
  { {0xbcfb0014,0x44251786,0x63a80b8d,0xc6920135}},	//   ngés, _wil_, _endn, _באל_
  { {0x2d8b01e2,0x442d0005,0x932703c4,0x11d60015}},	//   dece_, _uue_, _فران, بوية_
  { {0xcee90080,0x69da00dc,0x600604ab,0xd3740054}},	//   ждое_, étez, мным_, _плућ
  { {0xaf090115,0xd1750033,0x2778004c,0xe1390033}},	//   تقدم_, _жылы, לעזש_, _дзеі_
  { {0xfbc90008,0xa1150029,0xfce60142,0x12fa000a}},	//   _דת_, _قوات, домо, _והעב
  { {0xef18003d,0x61fc001a,0xfe780091,0x717202be}},	//   deļu_, _írla, atį_, _شهوا
  { {0x39520041,0xe9df002d,0x9f4510e5,0x5e450015}},	//   ways_, _amú_, roló_, _قَتْ
  { {0x7f3a000a,0x8a060033,0xab270555,0xb9c6009a}},	//   _ועצו, дзве, дора_, وتره
  { {0xbcfb00dc,0x9f4502b9,0x0000006a,0x0000006a}},	//   ggés, colò_,   ,
  { {0x6ec5000b,0x39520ba4,0x48e33e28,0x0000006a}},	// [e280] ानकु, rays_, вотв,
  { {0x2cad0134,0xbe39000a,0x39521abc,0x2cbf0012}},	//   åede_, ַעְת, says_, äude_
  { {0xcb8b0008,0x8b57000a,0xf1cd000b,0xdcfd0091}},	//   _וְכֹ, _קיטס_, ़सान, resą
  { {0xe5c50036,0x5ee8000a,0xba9b000a,0xdb1c00bf}},	//   нсіо, הַנְ, _וסטי, ckrá
  { {0xc95300f3,0x63ba00bc,0x6d4601c2,0xe76a0015}},	//   _שמש_, _potn, ibka, _وحسن_
  { {0x9cd70008,0x2d8b0045,0x7deb0091,0x7413006e}},	//   וונה_, zece_, tęsk, نونا
  { {0x2d991869,0x926a00fd,0x02a8000b,0xe3af012c}},	//   ydse_, ірка_, कमेन, شرو_
  { {0xa3ac005d,0xcb130008,0x7deb0091,0x0000006a}},	//   गाह_, כלו_, ręsk,
  { {0x2d8b04ed,0x0000006a,0x0000006a,0x0000006a}},	//   vece_,   ,   ,
  { {0x9ed8000d,0xdfd00002,0x94bb000a,0xbcfb01d3}},	//   змот_, ايد_, _וממת, zgés
  { {0x644200f2,0xdd910115,0x81a60015,0xddc20046}},	//   lpoi, هود_, _يحصل, oplň
  { {0xfe780007,0x656f0012,0xf657004f,0xa3ac0065}},	//   rtį_, _öcht, וסטי_, गाव_
  { {0x5c070063,0x621b0053,0xfe780007,0xbcfb00dc}},	//   дява, _וואק, stį_, egér
  { {0x7df20024,0xfe6f002b,0x0a95006b,0xab8424cc}},	//   rāsa, ددی_, нагю, куск
  { {0x7bc7002e,0x8ae40036,0xbcfb0152,0x6e940015}},	//   rkju, вітл, ggér, _ألبا
  { {0x3e780014,0x3f8c16dc,0x99d40115,0x9980002a}},	//   mét_, ledu_, نتقا, elił_
  { {0xb8150124,0x2aff005d,0x3e7800dc,0xa8150477}},	// [e290] едај, _शुरु_, lét_, едаш
  { {0xdb1c0084,0xdc3c000a,0xa8a4006b,0x644200da}},	//   skrá, _ועזר, ърск, dpoi
  { {0xdb1c0134,0x6442016e,0xf77000c3,0x3e781945}},	//   ekræ, epoi, شال_, nét_
  { {0x25a902c1,0xdb1c0052,0x0000006a,0x0000006a}},	//   ñal_, fkræ,   ,
  { {0xa9280089,0x15080015,0x638558d6,0x4c9a004f}},	//   _vyžá, وْمٍ_, егла, ּ֑נו
  { {0x3e7800dc,0x58050015,0xb4440033,0x3f8c00b3}},	//   két_, _أوسك, тэцк, jedu_
  { {0x45d50036,0x3e7800dc,0x4255002b,0x69330046}},	//   _зовс, jét_, رنظر, přeč
  { {0x41a9000b,0xf992000a,0x69da0003,0x34950033}},	//   काइस, ָ֨ה_, étex, _пабр
  { {0x60e9005e,0x3f8c0034,0x80c9000b,0x602514b5}},	//   ямим_, fedu_, िनें, ндиа
  { {0x443f013c,0xf2c7212d,0xfe45009b,0x64595401}},	//   _itu_, _осен, нноо, mswi
  { {0x3e780014,0xa3ac005d,0xc7b2000a,0x4f090033}},	//   gét_, गार_, אבי_, янон_
  { {0xadb70015,0xe29a000a,0x6d460073,0x0000006a}},	//   ّهَا_, _משער, ubka,
  { {0x2d9e02d5,0x707500b2,0x315600f3,0x1c39004a}},	//   ěte_, _נײַע_, _ניסן_, дясь_
  { {0x443f000c,0x2ba7000b,0x7f840015,0x3f8c0e63}},	//   _mtu_, खागा, _للهن, cedu_
  { {0xc332000a,0x5f05005e,0x7deb002a,0x7bc1001a}},	//   רול_, _язка, zęsi, ölua
  { {0x69260124,0x60140251,0xda650015,0x17fa0065}},	//   емба, ràme, ضافي, ्त्व_
  { {0x7c960015,0x64590079,0x9582002a,0xdb050077}},	// [e2a0] _أشبا, jswi, łąka, _bohó
  { {0xacfb0008,0x317f00d9,0x3cfb000a,0x46f617b6}},	//   _מהפכ, hfuz_, _מלפנ, нчет
  { {0xd9100086,0xa3b3000b,0x644200da,0x65640030}},	//   _چیز_, टान_, wpoi, óiho
  { {0xd9100074,0x2e3a0053,0x67360024,0x7deb0091}},	//   _نیز_, לגענ, _šajā, tęsi
  { {0xa3ac005d,0x3e7800dc,0x41a9000b,0x64a301f3}},	//   गाल_, zét_, काईस, лаца
  { {0xddc20089,0x7deb0007,0xd7f20015,0x3e780030}},	//   splň, ręsi, _إكس_, yét_
  { {0x68290007,0xfe6700e5,0x89da000a,0x443f008c}},	//   _užda, _حد_, ּחִי, _etu_
  { {0x3e7800dc,0x644258d7,0x8233002b,0x7dc60077}},	//   vét_, ppoi, دروا, _fósi
  { {0x63ab02d5,0xa4490015,0xd0d4006b,0xdb1c038f}},	//   ální, _يشكك_, топъ, lkrä
  { {0x3e780014,0x289b0053,0xd0070004,0x629c0046}},	//   tét_, ליפא, нење_, _šrou
  { {0xe0cf0086,0x1df90080,0xd6d3000a,0x3f8c58d8}},	//   لزی_, дены_, ָׂר_, redu_
  { {0x3e7858d9,0x61560015,0xc1060015,0x3f8c58da}},	//   rét_, _أنشئ, _كواي, sedu_
  { {0x3e780014,0x0ca80442,0xc5f3000a,0x01630015}},	//   sét_, нтри_, רדר_, _صُوَ
  { {0x6fe60152,0x3e7800dc,0xb113005e,0x8eb40015}},	//   _décè, pét_, _сміш, _لمتش
  { {0x39a70010,0x5fa6000b,0x1f37000a,0xce94006b}},	//   ншав, _कोयल, _ארור_, _райъ
  { {0x5eeb000a,0x6602007c,0x9ab40033,0x64400085}},	//   _מַחְ, jook, ыйсц, _otmi
  { {0xdb1c00c0,0x89340015,0xa065000a,0x8dfc000a}},	// [e2b0] ekrä, اعفا, ֻׁעַ_, _מההת
  { {0x0c780015,0x7dc6001a,0x65600125,0xf7730015}},	//   _أصيب_, _rósi, _admh, طاط_
  { {0x644404f9,0xf6530029,0x201e0007,0x64400095}},	//   ţiil, ائط_, imti_, _atmi
  { {0xcb1201e4,0x3704000d,0x4a5a000a,0x645902f7}},	//   _כלי_, учув, _קדרו, tswi
  { {0x62880007,0xdb1c002d,0x1956000a,0x64590012}},	//   _apdo, bhró, _שבשל_, uswi
  { {0x394958db,0x0a58002b,0xdb1c58dc,0x386958dd}},	//   lbas_, _تشیع_, chró, mrar_
  { {0xe2960063,0x660258de,0x64402701,0x9f5e008c}},	//   ващ_, book, _etmi, iltä_
  { {0x569428ff,0xd24e0058,0x201e01ec,0x0000006a}},	//   _щаст, آني_, emti_,
  { {0x7fd500e2,0x0584006b,0xa5f80054,0x6fd509a0}},	//   віні, _щурм, _чету_, вінц
  { {0x22910007,0x3f83001a,0xee3904bb,0x8ff90058}},	//   _tšk_, ýju_, мно_, بربر_
  { {0x2bb0000b,0x81890015,0xef190b9b,0x9d46030e}},	//   ञासा, _ينطق_, ьмо_, кенд
  { {0x386901e2,0x9f5e008c,0x0d8302a3,0x200c001a}},	//   krar_, eltä_, алюн, aldi_
  { {0x7de400dc,0x4b56006b,0x5cf6004a,0x7e680079}},	//   sőso, къвт, тяну, ardp
  { {0x394902c1,0x386939d5,0x320d2fe1,0x7ed50015}},	//   ebas_, drar_, lley_, _لزبا
  { {0x3b0758df,0x6dfa0004,0xbad50033,0x09e600f4}},	//   веро_, _охис_, гіты, вовн
  { {0x25bf0011,0xb222002e,0xf2d2000a,0x320d0b62}},	//   _noul_, _þætt, בעל_, nley_
  { {0x7e7d0011,0xdb1c0125,0xdd1f0046,0x09290015}},	// [e2c0] ăspu, thró, píšo, فسكي_
  { {0x46a6510d,0x7bd500b8,0xdb1c00b8,0x7bc8007c}},	//   казв, chzu, tkrä, ödud
  { {0xe57a0558,0x38693d33,0x320d58e0,0x394958e1}},	//   дзе_, arar_, kley_, bbas_
  { {0x91820092,0xceb2039e,0x04461c59,0x600f079b}},	//   iệu_, ייב_, ведн, dømm
  { {0x320d02e7,0x200c001a,0xdb1c58e2,0x200700bc}},	//   dley_, yldi_, phró, _okni_
  { {0x3dd20034,0x8afa000a,0x25ad58e3,0xf74320f0}},	//   _llyw_, ֽהֵי, _enel_, _веро
  { {0x37e3087a,0xfbd30008,0xa3de000b,0x92570015}},	//   _торг, שתו_, दोष_, نشير_
  { {0x2b58002f,0x31c30080,0x30a63878,0x76580091}},	//   harc_, исыв, вров, švys
  { {0xa0670292,0x2eca005d,0xd1b70015,0x25d7000a}},	//   вања_, ान्त, ضايا_, _סומן_
  { {0x0eea03e7,0xd9bf000b,0xb4ce000b,0xfc3f0077}},	//   дьми_, _एक्ट, शनी_, nvíe_
  { {0xf773000a,0x320d0f21,0x8cdb000b,0x39490091}},	//   בקת_, bley_, _पेजो, ybas_
  { {0x442c0b95,0x61461664,0x3dd20034,0x386902dc}},	//   _hid_, _реда, _clyw_, yrar_
  { {0x7d16005c,0xf993002b,0x257d0030,0x442c3d41}},	//   _czys, یبر_, láló_, _kid_
  { {0x7e9a0015,0x7d08001a,0x84a9000a,0x386958e4}},	//   _ينشر_, _sérþ, ׂירִ, vrar_
  { {0x257d0014,0x10150010,0xc2140008,0x442c2fa8}},	//   náló_, _сьця, ָהּ_, _mid_
  { {0x320458e5,0x429b000a,0x442c58e6,0x38692568}},	//   nomy_, וסלב, _lid_, trar_
  { {0x78a6016f,0x39460077,0x394958e7,0x3f9c58e8}},	// [e2d0] _crkv, ñosa_, rbas_, _kavu_
  { {0x442c0176,0xb8db005d,0x25ad3f92,0x25bf0e35}},	//   _nid_, _अप_, _snel_, _soul_
  { {0xa3ac000b,0x6da4002b,0x87040033,0x25bf58e9}},	//   गाई_, _صمیم, аяце, _poul_
  { {0x442c1a5b,0xbc68002b,0x65150015,0x3204002a}},	//   _aid_, _ثمین_, هوائ, jomy_
  { {0xd838008f,0x442c58ea,0x056400fd,0x89da004f}},	//   _аэс_, _bid_, рвін, _נחשי
  { {0x6e2d0541,0x69cd008c,0x320d58eb,0x442c0f98}},	//   _liab, lkae, wley_, _cid_
  { {0x442c003e,0x36d50860,0x799d02f2,0xc2450054}},	//   _did_, _совр, _kasw, ћник
  { {0x2c1a005d,0x600f0293,0x69cd030f,0x9f4c0030}},	//   _मीनू_, rømm, nkae, kodó_
  { {0xe4e70191,0x799d000c,0x320d58ec,0x7d0d58ed}},	//   _рівн, _masw, rley_, _nyas
  { {0x7deb005c,0xe0d6004a,0x83870033,0x320d3ff4}},	//   zęst, увь_, _шыбе, sley_
  { {0xc7d60008,0x80240029,0x9f520046,0x7d16002a}},	//   רותי_, جريم, ádám_, _szys
  { {0xe8e00016,0x8c4607ec,0x30751045,0x442c58ee}},	//   êịm_, леме, _букс, _zid_
  { {0x407900b2,0xd196000a,0x4c830323,0xd12e002b}},	//   _נאַװ, _תכני_, бляв, _عمو_
  { {0x61e90048,0x5ea50015,0x7d000046,0xa3ac000b}},	//   liel, _ممتل, _nárů, गाए_
  { {0xd0060063,0x7deb0007,0x311f000b,0x7dc6002a}},	//   _щеше_, tęst, मेरः_, _bóst
  { {0xf9d50010,0xa2a4005d,0xf2d20053,0x7dc60125}},	//   ацую, कित्, זעל_, _cóst
  { {0x7d160050,0x7deb0007,0x257d00dc,0x18671b07}},	// [e2e0] _uzys, ręst, záló_, лати_
  { {0x20050026,0x60c90035,0x61e9059b,0x8cdb000a}},	//   noli_, iyem, hiel, _נחית
  { {0x5b7b0008,0x61e929ea,0x6d560049,0xcf56000a}},	//   _אריא, kiel, _keya, רבעת_
  { {0xf1a3005d,0x257d00dc,0x200558ef,0xf992002b}},	//   _खोलन, váló_, holi_, _ابد_
  { {0x1003005d,0x20050820,0x6d56013c,0x8d5b000a}},	//   रकाश_, koli_, _meya, תכני
  { {0xa3de014e,0x60db0024,0xe3af0015,0x33f6004a}},	//   दों_, dzum, كرى_, ычес
  { {0x442c58f0,0x20050026,0x320458f1,0x7349005e}},	//   _vid_, doli_, tomy_, тчів_
  { {0x3f9c03eb,0xb3a4005d,0x61e9005c,0x80a40015}},	//   _savu_, _गोरख, giel, لمعن
  { {0xdcef0024,0xf487002b,0x361b000a,0x442c18e0}},	//   recī, _مالی, _טולד, _tid_
  { {0x987b00b2,0xe8d7000a,0x61e958f2,0x200558f3}},	//   עריק, טופר_, aiel, goli_
  { {0x6d560064,0x61e900f6,0xb7db0053,0x50b70086}},	//   _beya, biel, גקיי, ندید_
  { {0x0136003b,0x90a60115,0xad670002,0x629a547b}},	//   _إعاد, _محتم, داده, _isto
  { {0x00da0086,0x200558f4,0x3f9c58f5,0x6e2d5421}},	//   _ثبات_, boli_, _tavu_, _viab
  { {0x200502d7,0xa09b000a,0x9be40033,0x6ec60015}},	//   coli_, _ניוט, біск, _متبق
  { {0x7dc6164c,0x19590010,0xe57f0024,0x2f3b00f3}},	//   _póst, кавы_, šķir_, _אגוד
  { {0xbce70015,0x6e43006e,0x69da13b3,0x0000006a}},	//   _مأخو, _انيم, ūten,
  { {0x7c970029,0x7d0d003f,0xe9f8005e,0x8755005e}},	// [e2f0] _إشعا, _uyas, унті_, икає
  { {0xf7700029,0x61e90b70,0x6d41005c,0x661b0553}},	//   كام_, ziel, ślad, _shuk
  { {0xa3d8005d,0xbb3a0008,0x799d003f,0x569505c4}},	//   ासन_, _בעתי, _tasw, рает
  { {0x78870024,0x14750015,0x07080015,0xa3e7000b}},	//   tīvā, لاتج, ديمي_, मोन_
  { {0x25b60015,0x629a0ab9,0x1bb8002b,0x61e93e12}},	//   شهود_, _asto, _شایع_, viel
  { {0x61e9005c,0x600f0293,0x98de000b,0xcc58000a}},	//   wiel, rømk, _नेटए, רבגי_
  { {0x5fc8000b,0x9265002b,0x200558f6,0x02450015}},	//   ाउनल, شگام, voli_, جَبَ
  { {0x2005005c,0x41a90342,0x60c902f2,0x61450099}},	//   woli_, твин_, tyem, јепа
  { {0x20d50036,0x20052e01,0x629a0dd3,0x3f8701d7}},	//   рійс, toli_, _esto, _pbnu_
  { {0x09d2005d,0x00e20010,0x6d560064,0x0ea90080}},	//   _सत्य, іжэн, _seya, вкой_
  { {0x612b01e2,0x61e958f7,0x20053415,0x72b90029}},	//   _bölü, piel, roli_, _جهاز_
  { {0xb2ba0008,0xf2c40036,0x6df30015,0xb7c40045}},	//   _במער, _усун, ْكَا, ăţit
  { {0x7df20048,0x7c380b6c,0x200558f8,0xfd120015}},	//   nāsi, _čvrs, poli_, تجد_
  { {0x629a0176,0x9dd6002b,0x78a402b9,0x765e008c}},	//   _ysto, ازگش, vviv, yspy
  { {0x3956000d,0x993a0033,0x497a0033,0x39460077}},	//   ињат, вязу_, ксаў_, ñoso_
  { {0xf2d200b2,0x39460010,0x4efa000a,0x3eaa02de}},	//   קען_, рнаг, _שהקו, æbte_
  { {0xc7b20029,0xe73a009c,0xf1b2000a,0x79840034}},	// [e300] يّر_, вез_, חסן_, rfiw
  { {0x78a41915,0x076a0015,0x7df2003d,0x23a40157}},	//   rviv, ئماً_, dāsi, _गोंद
  { {0x56930036,0x765e00f2,0xab2a03ae,0xa2b10065}},	//   жаєт, uspy, _јона_, _अपग्
  { {0xa2a4014e,0xd6250029,0x86990010,0xbef6000a}},	//   किस्, معني, ытут_, בצעו_
  { {0x94260054,0x998c0091,0x0000006a,0x0000006a}},	//   амде, ūdų_,   ,
  { {0xb4b6000b,0xfc3f0077,0xf8b3000a,0x3860385f}},	//   _छपी_, nvía_, _ושש_, msir_
  { {0xd257008f,0x4e06005d,0xd57600fd,0x27ef1157}},	//   ацы_, रवाई_, _вузь, ègne_
  { {0xdb2500dc,0x7df20024,0x394030ac,0x629a0820}},	//   ísér, bāsi, ncis_, _vsto
  { {0xdfda0063,0x3940002d,0xc1b70033,0x80b0000b}},	//   вън_, icis_, рлых_, जमें
  { {0x38600152,0x4ea60010,0x4fc6024f,0x60230054}},	//   isir_, арма, рсиа, одња
  { {0xd7370008,0xa3b3005d,0x6fcd002d,0x0737039e}},	//   יטית_, टार_, _múch, יאים_
  { {0x7de70036,0xadd9004a,0x0e330033,0x386058f9}},	//   ріод, умму_, ўняю, ksir_
  { {0xed58008f,0xc0d30015,0x91bb000a,0x5c74058c}},	//   шоў_, _ويمب, _שמדי, олят
  { {0xdb1e0026,0x30db000a,0x7f5810b2,0x0000006a}},	//   _copï, _שַׁע, _сакс_,
  { {0x29e80061,0x9b5801e1,0x9a8700af,0x0000006a}},	//   aşam_, рист_, југл,
  { {0x3860013c,0x2ca958fa,0x68290073,0x79c902be}},	//   fsir_, _trad_, _iždi, دورف_
  { {0x290f002e,0xe838005e,0xe8550015,0xd197000a}},	// [e310] æga_, ипті_, صناد, סכמי_
  { {0xf7730225,0xcb990036,0x87d70029,0xd7590806}},	//   تار_, _свої_, جغرا, الات_
  { {0x6fcd002d,0x2907005c,0x16380015,0x07080015}},	//   _dúch, łna_, لسنة_, ليكي_
  { {0x6d5d4597,0xdb05006f,0x9567006b,0x7df201ec}},	//   nasa, _dohô, ръжд, tāsi
  { {0x7bc50005,0xdff8005d,0x6d5d0213,0xa3b3000b}},	//   _kohu, ुवाद_, iasa, टाल_
  { {0xf6770086,0x6fa6000b,0xe3c40015,0x3387006b}},	//   _پاسخ, _कोलं, يْنَ, рудв
  { {0x6d5d00b6,0xc2930086,0x321d0034,0x7bc501c0}},	//   kasa, تیاب, _phwy_, _mohu
  { {0x25d50053,0xd1790010,0xfaf8000a,0x9af8000a}},	//   _פוּן_, ускі_, יצוי_, יזוק_
  { {0x6009057e,0x63b20089,0xd498018f,0x4fb50015}},	//   лним_, ádní, _врх_, مصدر
  { {0x3959003e,0xe81d000b,0x1fb5004a,0x6d5d4b3d}},	//   _less_, _बीमा_, ссир, easa
  { {0xd1310029,0xcee90920,0xed5a3770,0x6d5d58fb}},	//   _فما_, удне_, лон_, fasa
  { {0xfbc901c8,0xfc460089,0x7052002b,0xc2cc004c}},	//   _את_, říme_, _کنوا, _שמאָ
  { {0x22810014,0x904506e4,0x63a12233,0x9596000a}},	//   lók_, _انته, _kaln, זכרו_
  { {0x8fa40029,0xad9b0046,0xa142003d,0x39400034}},	//   _ومنه, hoúh, _ēķin, wcis_
  { {0xc332011f,0xf1db005d,0x15f7000b,0x6d5d58fc}},	//   לום_, _बतान, ंचार_, basa
  { {0x228100dc,0xdb0700dc,0x62830234,0x1a2a06fe}},	//   iók_, ámáv, itno, ужби_
  { {0x395901d1,0x6c860029,0xadd70008,0x99160010}},	// [e320] _dess_, _الخم, _לוקח_, сьві
  { {0x38cb002b,0x22810030,0x62831d94,0xccf3004f}},	//   دافی_, kók_, ktno, _מכח_
  { {0x3e630064,0x386058fd,0xdb1e0227,0xfb37000a}},	//   nıt_, ssir_, _kopí, _לאיש_
  { {0x228100dc,0x250b0086,0x499a0195,0x80a70065}},	//   dók_, گرمی_, _стоя_, कटाइ
  { {0x77940074,0x3ea2003d,0x62832402,0x63a158fe}},	//   _ویرا, ākti_, etno, _baln
  { {0xd3700029,0x3e630061,0x25a00768,0x6d5d58ff}},	//   ذهب_, kıt_, žil_, zasa
  { {0x69c6022d,0x6d44005c,0xf6d50036,0x599a000a}},	//   _koke, _ofia, _дітя, ָשִׁ
  { {0x66f70008,0x69c634f1,0x36f7000a,0x0000006a}},	//   _המלא_, _joke, _הצלם_,
  { {0x69c600df,0x9f45002d,0x7413002b,0x6d5d5900}},	//   _moke, ailí_, _کولا, vasa
  { {0x389b0008,0x2e4a0063,0x2281002e,0x69c6055a}},	//   ניינ, лямо_, bók_, _loke
  { {0x66fa005d,0xd36f0029,0x9df9000d,0x9f5e0896}},	//   ्थिक_, _أهم_, инот_, gotá_
  { {0x7bc80020,0xe717000a,0xc237000a,0x3f820046}},	//   ödun, מחיר_, _הראו_, řku_
  { {0x63a101e2,0x6d5d0375,0xf1a9006e,0xdb1e00bf}},	//   _yaln, rasa, _خاله_, _dopí
  { {0x6d5d5901,0x3eb80a83,0xda35004a,0x9be40033}},	//   sasa, ärts_, жевы, піск
  { {0xcf260029,0x68290007,0x69c602d2,0x3b840033}},	//   _ارشي, _uždi, _boke, ялёг
  { {0x8e470029,0x5c750080,0x9e77000a,0x08550033}},	//   _اليك_, _длит, _הגהה_, жваю
  { {0x228100dc,0xa3d8000b,0xdc55002b,0x08f80015}},	// [e330] zók_, ासा_, _برعک, مركب_
  { {0x62830089,0x711b004c,0x7bdc25e3,0xd6db0788}},	//   ytno, רומפ, chru, лте_
  { {0xa935017f,0x569414c2,0x39594174,0xe7fa0065}},	//   _менш, захт, _tess_, ौक़ा_
  { {0xd56b0036,0xfc3f0077,0x15150a32,0x0000006a}},	//   рiал, nvío_, одея,
  { {0xa5bd00df,0xd7fb0191,0xa8790053,0x44640010}},	//   _siųs, _був_, _דאָר, звів
  { {0x22810014,0x3e6301e2,0x22494459,0x5c5c000a}},	//   tók_, yıt_, апки_, נדוק
  { {0x657a002f,0x23760015,0x6b7c000a,0x62830046}},	//   úchá, زميد_, ארונ, utno
  { {0x644b00c0,0x22810030,0x63a11a0b,0xc6920643}},	//   ppgi, rók_, _waln, _קאן_
  { {0x63a1002e,0x9f450089,0x10a5006b,0x22810030}},	//   _taln, silí_, ципн, sók_
  { {0x289c01ac,0x8fa5002b,0x9e650840,0x660b01ee}},	//   ריזא, آمده, овод, logk
  { {0xf7720008,0xdb1e0264,0x02440015,0xf2070033}},	//   וקי_, _popí, _فَلَ, _лядо
  { {0xee360010,0xc1e60086,0x26b6000a,0x60b50015}},	//   ўня_, _وکيل_, קִים_, _ومائ
  { {0x7bdc002d,0xa0690054,0x3a3a4969,0x69c65902}},	//   thru, _ђака_, _supp_, _roke
  { {0xe1f90091,0x69c65903,0x0000006a,0x0000006a}},	//   lnų_, _soke,   ,
  { {0xd00e0086,0x69c63b16,0xe95a006b,0x65690046}},	//   _جلو_, _poke, иращ_, _odeh
  { {0x69d800df,0x6e920015,0x6d400061,0xae56000a}},	//   _įves, _آليا, ımas, _וסקס_
  { {0x57ea2103,0x2fc75904,0x9f450003,0xe1f90091}},	// [e340] адам_, _kong_, oilà_, inų_
  { {0x95f4005d,0xf6d6002b,0xddc20091,0x2fc72f4e}},	//   ेक्ट_, يزاد, kslū, _jong_
  { {0x2fc74100,0x9bb70008,0x64495905,0xa3b3000b}},	//   _mong_, _והיה_, _atei, टाई_
  { {0x2fc74799,0x9990002a,0x34aa0054,0xdcfd003d}},	//   _long_, łało_, ивео_, cesē
  { {0x7de400dc,0xf4960015,0x3dfb000a,0x65690034}},	//   lőss, تشاد, סלנד, _ddeh
  { {0x66e623dd,0x6449002d,0x8236002b,0x395200cb}},	//   _дога, _dtei, يرعا, lbys_
  { {0xbb3b004c,0x8c1b000a,0x7243002b,0x249f0144}},	//   בעצי, סוצי, وپول, _esum_
  { {0x442700c0,0x0607006b,0xe5770484,0xc1b818c3}},	//   amn_, _днск_, _мзс_, слих_
  { {0xdfd0003b,0x9f4c0003,0x22a30046,0x60140144}},	//   فية_, lidé_, téká_, làmi
  { {0x388e0024,0xd3e4002b,0x749b004c,0x2fc75906}},	//   mērā_, _عقای, _דימפ, _cong_
  { {0xa2a1005d,0x60140251,0x25a60026,0x2fc75907}},	//   _कैप्, nàmi, odol_, _dong_
  { {0x7125002b,0x24860fd0,0x25a65908,0xe29b004f}},	//   _کرمل, otom_, ndol_, _כשבר
  { {0x8fe60015,0x24865909,0xe571000a,0x3bf6000b}},	//   _وأتم, ntom_, עַט_, ँचूँ_
  { {0x61ed002c,0xa3b3000b,0x2fc7590a,0x7deb0046}},	//   ďale, टाए_, _gong_, ořsk
  { {0x69d80007,0xcb34006b,0x600f0595,0x6fcd0077}},	//   _įver, деръ, rømt, _cúcu
  { {0x24862692,0x2fc7198a,0xc7b90030,0x200c590b}},	//   ktom_, _zong_, _őő_, lodi_
  { {0x25a60176,0xdcfd0024,0xed580008,0x7d58000a}},	// [e350] ddol_, resē, _ובחר_, _ויחד_
  { {0x2fc70092,0x200c14d8,0x2a7800da,0x25a6590c}},	//   _xong_, nodi_, burb_, edol_
  { {0x6449590d,0x96350033,0xe607005e,0x8f9b000a}},	//   _stei, чнец, оїдн, שיבי
  { {0x1a9a0053,0xa7140036,0x2d991350,0x200c0b28}},	//   _פירע, ємці, nese_, hodi_
  { {0xd7770029,0x2d9900b8,0x19ba0008,0x200c003f}},	//   _واسع, iese_, _המרב, kodi_
  { {0xf1a3005d,0xe1f10086,0x25a60026,0x883a000a}},	//   _खोजन, کست_, adol_, _לתשו
  { {0x5b580c44,0x9f4c0152,0x2d99558e,0xfa6b000a}},	//   חיוב_, cidé_, kese_, ׁכַּ
  { {0x0165000d,0x2fc7162b,0x41a6006b,0x261c0125}},	//   чкио, _song_, звън_, líon_
  { {0x1015008f,0x2fc70505,0x200c0034,0xf8bd000b}},	//   зьня, _pong_, fodi_, ोहिय
  { {0xb4d7014e,0x60e6004a,0x200c01a3,0xdb1e0030}},	//   ानी_, ямым_, godi_, _lopá
  { {0xf7720053,0x68290007,0x9f4a00dc,0x2fc70092}},	//   עקט_, _uždu, émák_, _vong_
  { {0x6d41005c,0xdb160046,0xa3e7000b,0x6b7e002a}},	//   ślan, ícíc, मोर_, iągł
  { {0x659a0053,0x61fb0011,0x621a00f3,0x913a000a}},	//   זירק, mnul, _פונק, _הענק
  { {0x2fc702f2,0x2d9902b9,0x69cb0dca,0xfe45067a}},	//   _uong_, aese_, ögen, _енко
  { {0x25a606f1,0xa2a1000b,0xcf92000a,0x141a000a}},	//   ydol_, _कैम्, _נטה_, מושב
  { {0x68460004,0x61fb590e,0x7de40030,0x2d99590f}},	//   знаа, nnul, rőss, cese_
  { {0x7d7b0008,0x5d7b0008,0x2486002c,0x4ddb000a}},	// [e360] _הנפו, _האפק, xtom_, _לחקו
  { {0x7bd500b8,0x7b0700dc,0x39520026,0x386f00dc}},	//   ckzu, érté, sbys_, ágra_
  { {0xbb3b0008,0x61fb0237,0x91db000b,0x501a000a}},	//   _לעיי, knul, बसाई, צועו
  { {0x8e5601ac,0x24860abe,0x2abb000a,0x60140144}},	//   פינג_, ttom_, _המטא, ràmi
  { {0x293700b2,0x69c40024,0xc448002b,0x8884002b}},	//   _מאכן_, mjie, زیان_, _زیان
  { {0x54970010,0x9d1b0053,0xdb1e006f,0xa3e7000b}},	//   явіў_, זונט, _zopá, मोल_
  { {0x200c0b6c,0x8f0b000b,0x24865910,0xbf0b0065}},	//   vodi_, _सुलझ_, stom_, _सुलभ_
  { {0x61fb1bbc,0x24862f93,0xf1aa0058,0x68e45911}},	//   gnul, ptom_, صابه_, ozid
  { {0xa4f80086,0xfc3f0089,0x09ca000b,0xc05a005e}},	//   _بکار_, tvím_, _रवैय, щій_
  { {0x2d9900dd,0x6d460123,0x61fb5912,0x9fb40046}},	//   wese_, ecka, anul, _tříd_
  { {0x200c4c25,0xdfd0002b,0x2d995913,0xc7d7004f}},	//   rodi_, فيک_, tese_, פוטי_
  { {0x36f70008,0x67e000c0,0x9c870107,0xf1a90015}},	//   לצים_, _höjd, _načí, _وانه_
  { {0xa2a4014e,0x160d005d,0x31e50015,0x2d995914}},	//   किक्, िकतर_, _تسلّ, rese_
  { {0x60b70008,0x2d995915,0x69c4003d,0x6d465916}},	//   _מהדף_, sese_, ejie, acka
  { {0x2d990161,0x28df000b,0x501b000a,0x8fa30054}},	//   pese_, पैनि, _הוגו, _чаје
  { {0x4efb000a,0x7d1601be,0x8b04002a,0x656201be}},	//   _להוו, _fyys, _łęcz, jaoh
  { {0xe894004a,0x7bc1001a,0x383502a3,0x0000006a}},	// [e370] нать, ölus, днар,
  { {0x6143002e,0xba99005e,0xbb55002b,0xa8a40033}},	//   _kíló, _двоє_, _تندب, эрск
  { {0xdb1e002c,0xda670015,0x2905002a,0x61fb43d6}},	//   _topá, _عادي, _ślad_, ynul
  { {0x68f80014,0x7e9b0053,0xd6d80080,0x6b7e002a}},	//   áadá, מסבו, чту_, rągł
  { {0xb4d7005d,0xfc3f0046,0x03a5058c,0xa4d400ce}},	//   ाने_, dvík_, дило, ноці
  { {0xa3e7014e,0x9c870107,0xe3b30015,0xcaf4002b}},	//   मों_, _začí, عرش_, _آسیب
  { {0x78ad0020,0x83640086,0x6d4600c0,0x61fb0085}},	//   lvav, ردول, ycka, tnul
  { {0x20d5005e,0x4a5c000a,0x2003036d,0x798d0034}},	//   діос, זדהו, čjim_, nfaw
  { {0x61fb0ee0,0x6d410089,0x8f75042b,0x36040015}},	//   rnul, ělal, муні, _أوقف
  { {0x26280011,0x798d0026,0xdb2400dc,0x0eb8000b}},	//   _uşor_, hfaw, űrés, इमंड
  { {0x443f0f4d,0x7d1600f2,0xc5f9004c,0xd3e6002b}},	//   _huu_, _syys, ַפֿט, _تقلی
  { {0x02440029,0x443f20cd,0x7d16008c,0x29e80045}},	//   _أَنَ, _kuu_, _pyys, nşat_
  { {0x443f000c,0x67e00123,0xe3b80061,0x8ff8009a}},	//   _juu_, _höje, _ynı_, _کرنر_
  { {0x443f0458,0x7dc60030,0xc0e20004,0x0000006a}},	//   _muu_, _jósz, _јошк,
  { {0xfebb0074,0x160d014e,0x2a360010,0x69c400dd}},	//   _داشت_, िकार_, дэар, tjie
  { {0x753b003f,0x69c4231a,0x7deb002a,0x7bc1001a}},	//   _nguz, ujie, zęsz, ölur
  { {0x6b9300c0,0x77ca0033,0xf1c30091,0x656201be}},	// [e380] ädgå, олаг_, mušė_, vaoh
  { {0x46f60608,0x69c45917,0xac97002b,0x69dd4844}},	//   мчет, sjie, _کنیا_, _else
  { {0x3a260124,0x3bbb0008,0x6562008c,0x67e00123}},	//   _омог, _ומיד, taoh, _nöje
  { {0x93bc0092,0x397a0015,0xe5060015,0x6b9c5918}},	//   _chăn, _بصدد_, وبشي, lerg
  { {0x249a03c4,0x64b60015,0xa99b000a,0x240a41f8}},	//   تخاب_, بحار, _ובכר, онди_
  { {0x443f0144,0x6b9c5919,0x4393004a,0x938a008b}},	//   _duu_, nerg, вашс, ісла_
  { {0xdced0061,0x067501c5,0xfe6700c3,0x92940033}},	//   _ocağ, _путя, _جد_, хайц
  { {0x68290007,0x6b9c0012,0xb06a00c2,0x44252ed9}},	//   _uždr, herg, орож_, _ehl_
  { {0x6b9c020e,0x60f80457,0x60630015,0x31570015}},	//   kerg, яния_, نهيل, ذجية_
  { {0x60f7008f,0x22ba0067,0x7e7a02f2,0xd0070099}},	//   ьныя_, _وداع_, tutp, мење_
  { {0x179b0008,0xa1860010,0x6440591a,0x2777000a}},	//   חייב, _жылл, _humi, וגין_
  { {0x2cb20176,0x6b9c0991,0x78ad0007,0xc33300f3}},	//   _bryd_, eerg, yvav, _סוף_
  { {0xe6110008,0x64400a6f,0x20530033,0x7c84030e}},	//   רִי_, _jumi, _акія, куре
  { {0x64400007,0x6b9c591b,0xc4d3000a,0x7e7a02de}},	//   _mumi, gerg, דגש_, putp
  { {0x628a591c,0x7ee30015,0x4e1b0015,0x19bb0015}},	//   ntfo, _لكون, _وتعد_, يطرة_
  { {0x7bde00dc,0xba740015,0xdb070030,0x2cb20034}},	//   _elpu, ضافت, ndjé, _fryd_
  { {0x9be70036,0x64400011,0x63ba0079,0x6b9c591d}},	// [e390] _жінк, _numi, _ontn, berg
  { {0xa7740083,0xf77004c9,0x443f00e8,0x798d0034}},	//   клуч, لام_, _ruu_, sfaw
  { {0xe47d0064,0xb4d7000b,0x7bc8000a,0xf5590015}},	//   ştüğ, ान्_, _חֶרֶ, كلاب_
  { {0xcad6000a,0xd7c9002b,0xe6bf000b,0xceb3004c}},	//   _נורת_, _کوسه_, _एपीज, כיע_
  { {0xf99205af,0xe4580036,0xe534005e,0xc4f80015}},	//   _ערך_, джі_, вець, وعها_
  { {0x64400011,0xe3b10015,0x51f5002b,0x34b2002b}},	//   _dumi, طرت_, کستر, اموز
  { {0x93bc0092,0xae0f000b,0x05770015,0x765c0034}},	//   _thăn, सवान_, _يارد, _gwry
  { {0x05bb0086,0x6d41005c,0x22920018,0x443f003f}},	//   _بدست_, ślaj, اليس, _tuu_
  { {0xdff50010,0x20540010,0x43950033,0x0584005e}},	//   еянь, ктэр, _паас, _шурм
  { {0x3869591e,0xc8fa000a,0x6b9c016e,0x8ee900f4}},	//   isar_, לִיכ, xerg, змов_
  { {0x644000b8,0x415502e1,0x6fd60003,0xef190965}},	//   _zumi, _звес, _mâch, ямо_
  { {0xed570191,0x2cb20026,0xd256000a,0xf1a7005e}},	//   ною_, _pryd_, _נשנה_, _ірен
  { {0xd4790053,0x30840015,0x80e40015,0x38690123}},	//   האָל, _للنف, _لأول, jsar_
  { {0xdce60048,0xc0580086,0x39490024,0xd0f6000a}},	//   mekļ, _آشنا_, ecas_, _אמנת_
  { {0x501a0053,0x3af5004a,0x3869591f,0xdce6003d}},	//   _צוצו, вятс, esar_, lekļ
  { {0xe9df002d,0x4c86005e,0x6b9c393c,0x4229004f}},	//   _clú_, _злив, serg, לֵּ֣
  { {0x48e3017a,0xb7d7002b,0xdce6003d,0x6b9c2bd5}},	// [e3a0] готв, کولا_, nekļ, perg
  { {0xdce60024,0x4c060015,0x08090015,0x64400d1b}},	//   iekļ, _سِجل, وزلي_, _rumi
  { {0x200300bd,0x63a804c6,0x83fd0030,0x38695920}},	//   čjih_, _radn, _evők, asar_
  { {0x644000b6,0xceb20008,0x9f4c0089,0x96750033}},	//   _pumi, טיב_, vidí_, тыфі
  { {0xfba4005d,0x7c2e5921,0x6fd60003,0xf993000a}},	//   _ओसाम, ombr, _fâch, _גרר_
  { {0x7a050007,0x988b000a,0x628a1c14,0xd574004a}},	//   mėta, _מָלֵ, ttfo, рaвл
  { {0xfbd30008,0x628a003c,0xd2500029,0x764e0cbf}},	//   רתו_, utfo, جنب_, _utby
  { {0x644021a0,0x64a60010,0x6b83001a,0x8cb3000b}},	//   _tumi, _паба, _öngv, इटमो
  { {0xa98b000a,0x7a050091,0xe092002b,0x628a4ca0}},	//   הָיִ, nėta, ایتخ, stfo
  { {0xddc9005c,0x4f6a004a,0xc0930015,0x39490077}},	//   łożo, чшим_, اجيت, zcas_
  { {0x11d60036,0xb7db0008,0x03d7000a,0x02d70015}},	//   _підр, פקטי, _רובם_, _كوكب_
  { {0x7a050007,0xa3d8000b,0xc693000a,0x29dc001a}},	//   kėta, ासक_, נאר_, _sían_
  { {0x91a60092,0x25d70008,0x20d30087,0x68fb002c}},	//   _nhỏ_, תוכן_, _متوج, _ľudo
  { {0x7a050007,0x3a75006b,0x7ac70004,0x60bb004f}},	//   dėta, клгр, нсбе, _מצדד
  { {0x9b440021,0x3f9e5922,0xbea301ca,0x0000006a}},	//   انفو, metu_, _бајк,
  { {0xee830010,0xdcfd0024,0x3f9e2e0c,0x8f1b000a}},	//   _сышо, nesī, letu_, _מוות
  { {0xa898017f,0x39490656,0xdcfd003d,0x1d080054}},	// [e3b0] нкту_, rcas_, iesī, _пећи_
  { {0xc9140001,0x3949047e,0xc051000a,0x3f9e5923}},	//   удућ, scas_, ׁ֖ב_, netu_
  { {0xf7700196,0xddc90007,0xbcfb00dc,0xa3d4005d}},	//   صال_, iudž, zaél, _हक़_
  { {0x3f9e007c,0x07080015,0x38695924,0x7bc80072}},	//   hetu_, ريني_, psar_, öduv
  { {0x6fd60152,0x25a9006f,0xf486002b,0xd49b0033}},	//   _tâch, ľal_, ناوی, ярж_
  { {0x3f9e016f,0x72950080,0xe2990329,0x58f6000a}},	//   jetu_, вших, дак_, _יצרן_
  { {0xdb1c002e,0xfbb800f3,0xa2a1000b,0x69cf1418}},	//   skrö, תפות_, _कैश्, _koce
  { {0xb147002b,0x32d40033,0x3abc000a,0xd1790138}},	//   ریتم_, ыціс, למונ, фскі_
  { {0x3c2400c0,0x69cf4d27,0x743504b4,0x3f9e0160}},	//   höva_, _moce, _анаф, fetu_
  { {0xd00e00e6,0xd4370015,0xe3b30015,0xbcfb0003}},	//   يلي_, _أعرب, _حرر_, raél
  { {0x236700bd,0x52740015,0xc7b2000a,0x13b6000a}},	//   manj_, _مانز, בבי_, _שהעל_
  { {0x11f90086,0x8d66006b,0x25d5000a,0x40951c4d}},	//   _کوچک_, ъвме, דוֹן_, _аркт
  { {0x2010002e,0xddc90024,0xe0ce02b0,0x3f9e5925}},	//   ólið_, budž, _тв_, betu_
  { {0xab2a0010,0xa0090015,0x8007004a,0xe0d8005e}},	//   дога_, _تقتل_, _ячее, _яві_
  { {0xf412000a,0xaf76004c,0x6a86006b,0xbea5194c}},	//   יפך_, _סעקס_, ълва, _райк
  { {0xaea80015,0xa3b3000b,0xddea0058,0x69cf53a6}},	//   _أطول_, _जोस_, _زرعه_, _coce
  { {0x236700bd,0x69cf037f,0x18670a6c,0xa3e1000b}},	// [e3c0] kanj_, _doce, кати_, दसा_
  { {0xd7f90036,0x236700bd,0xd7640086,0x291c003d}},	//   нує_, janj_, انای, āva_
  { {0x26dc0107,0xa2a1000b,0x7a050091,0x7bdc0e1e}},	//   ávo_, _कैल्, sėta, mkru
  { {0xa95a0015,0x7a050091,0xe729009a,0x0000006a}},	//   _تجدر_, pėta, رسلو_,
  { {0x04940029,0xb8f60015,0x3957004f,0x0000006a}},	//   التح, _شكسب, _בשכם_,
  { {0xdb0e0084,0x9cd70008,0x2348002b,0xf79a0015}},	//   _þjón, כונה_, رستی_, _تنسب_
  { {0xe297049d,0x32630256,0xe3550033,0x3f9e2389}},	//   вај_, атыв, утчэ, vetu_
  { {0x7984003f,0x7bdc007c,0x33290033,0x161a0065}},	//   ngiw, hkru, хцін_, _फीचर_
  { {0x7bdc002e,0x69360089,0x3f9e5926,0x04461092}},	//   kkru, břež, tetu_, _резн
  { {0xa3e6005d,0xdefa08f0,0xcec1002a,0x66025927}},	//   _पति_, дым_, kręć_, lnok
  { {0xfe780007,0xddc9132a,0xdef4054f,0x877b000a}},	//   urį_, rudž, упны, ואיי
  { {0xe0da0124,0x660200f2,0x92e40064,0xe1fa004a}},	//   _ове_, nnok, ışıl, _юге_
  { {0xa3e6014e,0x5f940180,0x1bbb0015,0x660204f8}},	//   _पता_, _билт, واسع_, inok
  { {0xe4ab000a,0x5c040033,0xdee60015,0x7bdc042f}},	//   וֹלָ, аяса, _لأبي, gkru
  { {0xa3e7000b,0x8a170067,0x1af40121,0x69cf03d8}},	//   मोट_, نظرا, апря, _poce
  { {0x1f370008,0xddc80011,0x660200dc,0x201e1f9f}},	//   _ברור_, ălţi, jnok, llti_
  { {0x7bdc00dd,0x69cf5928,0x9f5e0003,0x201e02b9}},	// [e3d0] bkru, _voce, enté_, olti_
  { {0xb8cb014e,0x629a1959,0xf77300c3,0x7e7a19bd}},	//   _कई_, _opto, شاط_, ortp
  { {0xd5750484,0x23670796,0x95990054,0x201e05ff}},	//   гуль, vanj_, етлу_, ilti_
  { {0x7a050007,0x960d000b,0x25a9002b,0x39150015}},	//   mėto, िकेट_, عضای_, _موجز
  { {0x15140036,0x41b6000b,0x297a004c,0xb97a000a}},	//   адця, _अफ़स, _אטרא, _אנרי
  { {0xa3b3000b,0x240902ed,0x67e002dc,0x0000006a}},	//   _जोश_, энли_, _höjn,
  { {0x7a050007,0xe2992b41,0xe296006b,0x33840033}},	//   nėto, хай_, гащ_, ручв
  { {0x42d40036,0xa3b3000b,0x2ca95929,0xd24e0015}},	//   рішу, _जोर_, _osad_, أني_
  { {0xe4a4049d,0x601d0144,0xd517002b,0x2367592a}},	//   _врхо, lèmi, _شبرغ, panj_
  { {0x61e200dc,0xbfc50080,0x7a050007,0x6006004a}},	//   _elol, убок, kėto, лным_
  { {0xe3b00086,0xa2d50115,0x3255007a,0xdb05010d}},	//   _برق_, _حيات, _свер, _bahí
  { {0x8d76003b,0x7de400dc,0x7a050091,0x201e007c}},	//   دادا, lősz, dėto, alti_
  { {0xe1f90007,0x2245592b,0x7e7a0079,0x23650030}},	//   mių_, _hulk_, artp, _kelj_
  { {0xe1f900df,0xf0a80036,0x8c430142,0x0ffb0067}},	//   lių_, _шкіл_, сере, _تعصب_
  { {0x2ca906d1,0x1ad50033,0x19960004,0x7bdc4c5a}},	//   _esad_, аўтр, лјар, rkru
  { {0xe1f90780,0x601d0251,0x3eb804d1,0x7bdc592c}},	//   nių_, dèmi, ærte_, skru
  { {0xa764006b,0xa9260bbe,0x3f8500bc,0x7c850004}},	// [e3e0] ижаr, удал, oglu_, _куќе
  { {0x25bf4f46,0x3dd20026,0x5c5b000a,0x38cb002b}},	//   _anul_, _hoyw_, _רדיק, راقی_
  { {0xe1f900df,0x7de400dc,0x9f29000a,0xe57a0cab}},	//   kių_, dősz, תֵּ֖, езе_
  { {0x25ad0b7c,0xda7b05bd,0xdb23002b,0x0000006a}},	//   _cael_, _אנטר, _دوپی,
  { {0x7c3e592d,0x44f6002b,0x6602592e,0xe1f90073}},	//   _kipr, دساز, rnok, dių_
  { {0x6602592f,0x0666002b,0xf7432850,0x22455930}},	//   snok, _مارپ, _геро, _bulk_
  { {0xe81d005d,0xe7270aed,0x66e63903,0x9989007f}},	//   _बीटा_, _борд_, _сова, nlaş_
  { {0x85b50124,0x25ad0176,0xe1f90007,0xb6bb000a}},	//   _кључ, _gael_, gių_, _אצלי
  { {0xdfd0003b,0x55060010,0x75d30029,0x2edc000b}},	//   قية_, _спаб, _ايقا, मन्त
  { {0x749b00f3,0xd0970015,0xb4e0000b,0x201e04da}},	//   _אימפ, ائيا_, दनी_, ulti_
  { {0x38170008,0xe1f90007,0x629a27a0,0x3a205931}},	//   רקים_, bių_, _upto, klip_
  { {0x1df90080,0x0737000a,0x2ff9002b,0x56b7004c}},	//   темы_, טאים_, _یونگ_, אפטן_
  { {0x22450079,0x443e13be,0x50a8000b,0x205613d0}},	//   _zulk_, _kit_, _कनिष, _стер
  { {0x113b000a,0x442c0012,0x7c3e4589,0x9f3409a0}},	//   _נתגל, _jhd_, _cipr, _келі
  { {0x443e5932,0xda78010f,0x682b0064,0x7c3e013c}},	//   _mit_, лят_, nüde, _dipr
  { {0x2ddb0029,0xb955006b,0x99553698,0x7a050091}},	//   _سبعة_, рващ, ркац, rėto
  { {0xc7f50054,0x443e5933,0x57f55934,0x6e2d02f2}},	// [e3f0] азаћ, _oit_, апат, _ihab
  { {0xe1f90007,0x4af6002b,0x443e5935,0xdc8c004f}},	//   zių_, اکید_, _nit_, _נְחָ
  { {0x6e2d5936,0xdb050026,0x4c3a000a,0x199512ae}},	//   _khab, _wahâ, _שתתב, _каня
  { {0x4efb0053,0x4a5a000f,0x659548c6,0xa5670067}},	//   עלאג, _שדרו, раду, ادان
  { {0xe1f900df,0xe3ae0036,0x442c00d9,0x7de400dc}},	//   vių_, об_, _bhd_, tősz
  { {0xd7e40036,0x987a0053,0x25ad0026,0xa87a01ac}},	//   _лісо, _באשט, _wael_, _באשר
  { {0x67e001d1,0x3cfc014e,0x3bbc0008,0xfa340086}},	//   _möjl, _लेने_, תמוד, _خرید
  { {0x25bf04f9,0x409515ce,0x9f5e0030,0x7de40030}},	//   _unul_, арот, kotó_, sősz
  { {0xe1f900df,0x68ed02c1,0xb3870087,0x443e0493}},	//   rių_, nzad, _مجاه, _fit_
  { {0xe1f900df,0x443e0064,0x1e00000b,0x99890061}},	//   sių_, _git_, ोक्ष_, ylaş_
  { {0xe1f900df,0x7c3e02d7,0x63a35937,0x68ed0061}},	//   pių_, _ripr, menn, hzad
  { {0x3f850026,0x443e0111,0x6e2d2314,0x63a35938}},	//   sglu_, _zit_, _chab, lenn
  { {0x4c830063,0x63c400dc,0x30790053,0x61e90230}},	//   оляв, _átné, _סאַנ, mhel
  { {0x61fb0011,0x8d76002b,0x66090085,0x7536000a}},	//   liul, داگا, _ljek, יארד_
  { {0xa96a0063,0xcb671886,0x0309000a,0x69cd001a}},	//   кива_, расе_, דִּֽ, fjae
  { {0x6e2d002d,0xdb08002e,0x61fb2162,0xdd8f0015}},	//   _ghab, _ólík, niul, _قوى_

  { {0x67560029,0x3e330015,0x63a332b6,0x60db34a0}},	// [e400] لخار, _بفير, kenn, nyum
  { {0x47c309a7,0x60c90251,0x63a35939,0x6283008c}},	//   обув, ixem, jenn, kuno
  { {0x5b7b0008,0x22b50024,0x22a700dc,0x4b7b000a}},	//   _בריא, _nāk_, _nők_, _באיו
  { {0xdcf60064,0xe7290029,0x6996042b,0xd5b900fd}},	//   _hayı, اسكو_, _трох, лсі_
  { {0x63a30176,0xdcf601e2,0x61fb0011,0xb4e0000b}},	//   fenn, _kayı, diul, दने_
  { {0x7bce00c0,0x4b7a004c,0x60db0061,0x6283233b}},	//   njbu, דאַו, dyum, funo
  { {0x62830467,0x98b201e2,0xdcf60064,0x68fb002c}},	//   guno, mayı_, _mayı, _ľudi
  { {0x98b20064,0xd62a0054,0x61fb0045,0xdb070030}},	//   layı_, _робе_, giul, ndjá
  { {0x63a30176,0xb3760074,0x73c60086,0x4fc6593a}},	//   benn, _نداش, _پيام, асна
  { {0x443e0ec6,0xd48b000a,0x61e9007c,0x98b20061}},	//   _uit_, _יָבֹ, ahel, nayı_
  { {0x62830011,0x61fb00d9,0x3eb800dc,0x76400064}},	//   cuno, biul, írt_, _kimy
  { {0x61fb0011,0x51830c45,0x61e9593b,0x0000006a}},	//   ciul, _душа, chel,
  { {0x98b20064,0x705400a2,0x3eb9003d,0xdcf60061}},	//   kayı_, _انتا, āsta_, _bayı
  { {0xb09b000a,0x6fb30021,0x5fb30021,0x8fa31971}},	//   _סיור, _ومنا, _ومنط, _маче
  { {0x6e2d3ed5,0xec340036,0x8e840029,0xde66006b}},	//   _thab, інсь, _العه, _тълп
  { {0x827700b2,0x68ed08e0,0x2f3b0008,0x63a3002a}},	//   יעלע_, tzad, _בגוד, zenn
  { {0x7c95003b,0x98b20064,0x63a31a8b,0x261c002d}},	// [e410] _الخص, fayı_, yenn, híos_
  { {0x6609003c,0x207b0053,0xad1c000a,0x7d1a0012}},	//   _sjek, כאמא, _בוחר, ßtse
  { {0x56950080,0xd8380010,0xf7700021,0x63a3593c}},	//   сает, рэт_, باق_, venn
  { {0x36180191,0xdcf60064,0x261c02c1,0x63a30f50}},	//   ацію_, _zayı, díos_, wenn
  { {0xdcf601e2,0x22b50024,0x656b593d,0xe578005e}},	//   _yayı, _sāk_, ragh, рзі_
  { {0xdb050107,0x6283593e,0x261c0077,0x8388005e}},	//   _zahá, tuno, fíos_, ибів_
  { {0x6609593f,0x63a35940,0x61e90b20,0x656b09cf}},	//   _tjek, renn, thel, pagh
  { {0xc69200b2,0x61e90604,0x91fc003d,0x244b0789}},	//   _מאל_, uhel, _svār, _tøm_
  { {0x62835941,0x20d506b4,0x61fb1f5f,0x61e95942}},	//   suno, сійс, riul, rhel
  { {0xe3b80004,0x0ea9004a,0x60db0061,0x3e630030}},	//   _клуч_, гкой_, ryum, tűt_
  { {0x261c0467,0x66f9005d,0xee3a28ae,0x61fb0045}},	//   cíos_, ्पिक_, лно_, piul
  { {0xdcf601e2,0xd12e0086,0x68290089,0xad5a0033}},	//   _sayı, ظمی_, _vždy, ырох_
  { {0x64413249,0xf532000a,0x98b20061,0xdcf60061}},	//   _kili, ּ֥ר_, yayı_, _payı
  { {0x9516000a,0x6619002a,0x41c5000b,0x644104cb}},	//   מקרא_, howk, वावस, _jili
  { {0x499a004a,0x98b20061,0x64411aa7,0x0000006a}},	//   лтая_, vayı_, _mili,
  { {0x644121a0,0x7f3a0053,0x5e760008,0x39460210}},	//   _lili, _געצו, _התקן_, снаг
  { {0xdce40007,0x64490007,0x6441002d,0x98b20064}},	// [e420] _keič, _nuei, _oili, tayı_
  { {0x14c80086,0x076a00a2,0x3b86049d,0x644144c3}},	//   یهای_, اماً_, _улог, _nili
  { {0x98b201e2,0x3cfc005d,0x45460029,0xc6f5005e}},	//   rayı_, _लेते_, مناق, оїць
  { {0x7589005e,0x261c0077,0x7d7b004c,0x98b20061}},	//   исів_, víos_, ָנסו, sayı_
  { {0x999e0007,0x644128f8,0x44fa0015,0x64491d2c}},	//   ūtų_, _bili, دراج_, _cuei
  { {0xdc9b0053,0x261c0125,0x64415943,0x0000006a}},	//   רױסש, tíos_, _cili,
  { {0xd379005e,0x64412127,0xd257055f,0xd7e70302}},	//   рчі_, _dili, бцы_, _умре_
  { {0x3b09000a,0x90540709,0x64415944,0x38770046}},	//   ימוּ_, овиц, _eili, žerů_
  { {0xc1b70256,0x644126e7,0x38720034,0xdfda006b}},	//   слых_, _fili, nsyr_, гън_
  { {0xad9b0084,0x25a60026,0x5457000a,0x2fca0015}},	//   rnúm, leol_, _לסמן_, ابةً_
  { {0xa3ad005d,0xad9b002e,0x200b001c,0x64490012}},	//   _औसत_, snúm, écia_, _zuei
  { {0x6441000c,0xddeb0018,0x68300123,0x3e350015}},	//   _zili, ارده_, lädd, تفجر
  { {0x24c7000a,0x81430015,0x00da0015,0xc19b004f}},	//   ֶּךָ_, _عنون, _حبات_, _תשדי
  { {0x25a6002d,0x7125002b,0xad9b006f,0x7a050091}},	//   heol_, _برمل, onúk, mėti
  { {0x6ffb000a,0x6df50015,0x7a050091,0x9b580f82}},	//   _תפוג, _وكتا, lėti, сист_
  { {0xd2570008,0x7de70086,0x99850058,0x0000006a}},	//   משלה_, _دستم, تلرو,
  { {0x4d780008,0x02a5000b,0xc7470015,0x7a050091}},	// [e430] _התחל_, _खन्न, مضاي, nėti
  { {0xdd31005c,0xe9df002d,0x8af9068e,0xcb99005e}},	//   _mężc, _siúd_, _внос_, _твої_
  { {0x81c80024,0xdb1e005c,0x8f9b000a,0x64490091}},	//   orēķ, _dopó, ריבי, _suei
  { {0x95670063,0x7a050007,0x64415945,0x78ae0123}},	//   съжд, kėti, _sili, änvä
  { {0x25090086,0xdb050064,0x64490341,0x64415946}},	//   جرای_, _bahç, _quei, _pili
  { {0x7a050007,0xdc8c000a,0x24180033,0xf8b2000a}},	//   dėti, רְאָ, бочы_, _חשך_
  { {0xc7b20008,0x64411298,0xd346002b,0x7bdc05bd}},	//   _קבל_, _vili, زینه_, רקוו
  { {0xef18003d,0x96f8006b,0x65941155,0x9397002b}},	//   ngļu_, _уест_, _насу, _گجرا
  { {0x64410945,0x63c40089,0x53a50015,0x9f5e016e}},	//   _tili, átní, _ومرك, mitê_
  { {0xcf390036,0x6441002d,0xdb1e0064,0x7ff50029}},	//   ичні_, _uili, _popü, تسبا
  { {0x63c40046,0x2374006f,0x63040015,0xd3d8002b}},	//   štní, šajú_, _فوكل, _ابقا_
  { {0xcdf6008f,0xfbc90008,0x22140036,0x24800fcb}},	//   ічны, _בת_, _ефір, šime_
  { {0x7ff50015,0x7fd50033,0x387e003d,0x8d550033}},	//   _وستا, _мікі, _ātro_, ятэч
  { {0x653a0053,0xdee55947,0x28c8000b,0x853a0643}},	//   יערד, _моли, रमसि, יגרי
  { {0xe7ff005d,0xed5a0063,0x501a000a,0xbb435478}},	//   ोचना_, _кой_, _דוסו, дерк
  { {0x7db50033,0x7bc5016e,0x0000006a,0x0000006a}},	//   _есьц, _enhu,   ,
  { {0x683000b8,0x6fdf0152,0x6fcd000b,0x7c660015}},	// [e440] häde, _pêch, तापू, _باعل
  { {0xbb860029,0x5d86002b,0xfc320015,0x2cad0061}},	//   _بلدي, _الکل, _تحب_, çede_
  { {0xba760031,0xd9461440,0x47d3002b,0x056a0004}},	//   _باخت, _мени, بيلر, ајли_
  { {0xa5260063,0x64a602e1,0x0e9a004c,0xee4900a1}},	//   омед, жада, ישעל, _lẽo_
  { {0xc4530021,0xad9b0125,0xda0a002b,0xdb1e5948}},	//   وضوع, liúc, _ميگه_, _topó
  { {0x0598002b,0x1cbb000a,0xd3a3006b,0x68300dca}},	//   _گمرک_, ימנע, дръп, fäde
  { {0x683000c0,0xfbd3000a,0x53330054,0x41c5000b}},	//   rädd, ותג_, мешт, वांस
  { {0xe6170063,0x672e016f,0x66f7000a,0x2242001a}},	//   _ддс_, _izbj, _ומלא_, ökk_
  { {0xc05a0036,0xa0a6005e,0xdfa602d9,0x7d00001a}},	//   шій_, ішил, ојно, úmsl
  { {0x33d5022a,0xceb80091,0x389b000a,0x7a050091}},	//   _ніхт, tvę_, סיינ, rėti
  { {0x24500092,0xc43b000a,0x6ff30015,0xc16f005e}},	//   _hàm_, _כתמי, بسيط, _ої_
  { {0xaf030033,0x7bda5949,0xbed700ce,0x7cd90058}},	//   ьчык, ötun, ідях_, موجز_
  { {0x8cf40010,0xfd440010,0x81c80024,0xc19b000a}},	//   дзяц, дэрн, rrēķ, _כשאי
  { {0x212b00b8,0x99800091,0x69c6594a,0xdfd002be}},	//   üche_, kmių_, _anke, _سيب_
  { {0x245000a7,0xf96b0063,0xcfa90086,0x81c80024}},	//   _làm_, ирай_, _دانم_, prēķ
  { {0xdce60048,0x3f8c002e,0x08550010,0x527b00a3}},	//   sakā, lgdu_, зваю, ינלא
  { {0x68fb002c,0xe894004a,0xdce6003d,0xcd370058}},	// [e450] _ľuds, мать, pakā, _برغب
  { {0x3f8c002e,0xcb350063,0x69c6382c,0x98140015}},	//   ngdu_, _непъ, _enke, وبلا
  { {0xac380015,0xf1b90046,0x6d480046,0xe71900c3}},	//   _بسيط_, loše_, ědav, حيات_
  { {0x29dc0467,0xdb36000a,0x4d8a000a,0xdb1e0144}},	//   _días_, _מנתח_, ֶאצַ, _topò
  { {0x24f80010,0x8cbe005d,0xa4d400fd,0xd7e7005e}},	//   онцы_, शियो, моці, _діво
  { {0x493a0008,0xf8da0008,0xd8da000a,0x68300123}},	//   _לגרו, _החשמ, _הקשר, täde
  { {0x5b7c039e,0xe613002b,0x9f5e0144,0x4b7c015b}},	//   ברוא, _قشر_, mitè_, באוו
  { {0x798d013c,0x683004d4,0x9a37000a,0xf1b90085}},	//   ngaw, räde, חָ֖ד_, koše_
  { {0x24580080,0xa1560054,0x200b059d,0xbcfb01d3}},	//   _мать_, чању_, écio_, zaér
  { {0x7a050007,0xf1b90085,0x683004d2,0x7757000a}},	//   mėtu, doše_, päde, קֹ֖ב_
  { {0x7a0500df,0xa3b80115,0xd00e0015,0xd1cb002b}},	//   lėtu, _باقر_, الٍ_, _پبام_
  { {0xcfe90074,0xd1b80015,0x92b4002b,0x20d70015}},	//   _گفته_, _وانا_, _زحما, _وتشج
  { {0x9980002a,0x7a050091,0xf1b90085,0x660b4a9c}},	//   ynił_, nėtu, goše_, ingk
  { {0xeb9a0054,0x251a000a,0x798d07c8,0xdb1c006f}},	//   љив_, מורא, egaw, ajrý
  { {0xab2a594b,0xee4900a1,0x0000006a,0x0000006a}},	//   сова_, _kẽm_,   ,
  { {0xad9b002f,0x8b660086,0x798d0035,0xc332000a}},	//   riúc, _کاظم, ggaw, תול_
  { {0x62830089,0x05bf000b,0x98a308b0,0x2bc30065}},	// [e460] hrno, _एफ़ब, ните, शाखा
  { {0x798d0035,0x7a050007,0xe3b80061,0xdb86004a}},	//   agaw, dėtu, _akın_, _эгои
  { {0x2bf70008,0xc869000a,0x7bdb000a,0xba7600c3}},	//   _זמין_, רן_, _הקיו, _عادت
  { {0x29dc0077,0xe5980033,0x69c60383,0x2a57004f}},	//   _vías_, іклі_, _unke, _מבטן_
  { {0xa9bb000a,0x49bb000a,0xf8bf0003,0x19bb000a}},	//   _הזכר, _המכס, _gré_, _המכב
  { {0xa53306b4,0x38600849,0x14590010,0x645b002d}},	//   хніч, mpir_, ішчы_, _dtui
  { {0xa6a90029,0x02a30033,0xd2570174,0x32180015}},	//   _وافق_, ерым, пцы_, ييتد_
  { {0xd6eb000f,0xab0d000a,0x9f5e594c,0x2fc702f2}},	//   _הַמָ, יהוֹ, mité_, _anng_
  { {0x9f5e038d,0xb0340a86,0x6283136b,0xc0340099}},	//   lité_, мниш, arno, мниј
  { {0xb4d8005d,0x66021437,0x7bda007c,0x60f70033}},	//   ाही_, liok, ötul, яныя_
  { {0xe0cf0086,0x23890089,0x9f5e594d,0x81460015}},	//   نزی_, ňují_, nité_, _فنان
  { {0x63aa002e,0xa225002b,0x3f820061,0x6602594e}},	//   lefn, _قرنه, şku_, niok
  { {0xc5f3000a,0x629815e7,0x628a594f,0x0000006a}},	//   תדר_, ltvo, lufo,
  { {0xb0330010,0x63aa001a,0xdb070030,0xdce90061}},	//   _зніш, nefn, lejé, çlıy
  { {0x9f9b0008,0x798d00dd,0xbf9b000a,0x6dd50015}},	//   _הסופ, tgaw, _היוש, _يقتض
  { {0x9f5e0152,0xf8bf06be,0x201e5950,0x5eeb000a}},	//   dité_, _pré_, loti_, _לַחְ
  { {0x798d020a,0x2c270036,0x7d7c0008,0x765c005c}},	// [e470] rgaw, _ньог, _הנחו, _atry
  { {0x201e02fd,0x7c940015,0x9f470107,0x200c001a}},	//   noti_, _أشيا, _plné_, nndi_
  { {0x200c00b6,0xd6db0063,0x63aa0026,0x4a750015}},	//   indi_, щта_, defn, _تُجر
  { {0xf8bf23d1,0xb4d8000b,0x660b0ad4,0xa2c0000b}},	//   _tré_, ाहू_, ungk, विन्
  { {0x62830176,0x3e4c0089,0x201e2f6d,0x33d5005e}},	//   wrno, _děti_, koti_, дійт
  { {0x7a0500df,0xf8b2000a,0xdc9c000a,0xd7c9002b}},	//   rėtu, _ששם_, ציול, _بوسه_
  { {0x201e18a6,0x9f5e1e14,0x4e1d005d,0xe29902c5}},	//   doti_, cité_, नवाई_, цай_
  { {0x200c1bcb,0x3a2920d7,0xc692000a,0x80b1000b}},	//   endi_, nlap_, _שאן_, _अनदे
  { {0x6b9c0026,0xf3470086,0x85040015,0x00c9005e}},	//   yfrg, _فضاپ, _كوفن, ілок_
  { {0x201e0c80,0xff510029,0xb4e9000b,0x200c001a}},	//   goti_, خخة_, मनी_, gndi_
  { {0x93940029,0xe7f5005d,0x6830007c,0x628500bf}},	//   _سجلا, _इतना_, näda, áhod
  { {0xed570036,0x7bc00024,0x200c5951,0x3c2402dc}},	//   мою_, ēmum, andi_, hövt_
  { {0x41740086,0x55760053,0xee370210,0x0468000a}},	//   _سانس, וערן_, ьню_, ֔יךָ_
  { {0xa022007c,0xfaa60612,0x201e00d4,0xdfd40138}},	//   öötu, маго, coti_, _почы
  { {0x60080008,0x9f5e0003,0x320d5436,0x8c431068}},	//   _מִקְ, xité_, oney_, тере
  { {0x9f5e5952,0x8e3a002b,0x9f450046,0xe3b80061}},	//   vité_, _بستر_, chlá_, _akıl_
  { {0xd378016f,0x6cd30015,0xd7c9000b,0x765c5953}},	// [e480] _hoće_, _لقيا, रांच, _stry
  { {0x62980227,0x40e8000a,0xba56006b,0x9f5e1d2c}},	//   ytvo, הַעֲ, _отмъ, tité_
  { {0x86c60029,0x4e02005d,0x3e4c0089,0xb7d70015}},	//   بيان, _लगाई_, _pěti_, بولا_
  { {0x9f5e038d,0x7d7b0053,0x35e5005e,0x3860001a}},	//   rité_, ַנצו, нців, ppir_
  { {0x63aa002e,0x9f5e2045,0xc448002b,0x320d1e72}},	//   tefn, sité_, سیان_, dney_
  { {0x6846017f,0xd25a02b0,0x9f5e0003,0x66025954}},	//   _інва, оци_, pité_, siok
  { {0xe28f003b,0xdb0700dc,0x765c01a7,0x63aa0b10}},	//   لذي_, tejé, _utry, refn
  { {0x63aa002e,0x62985955,0x80b4006b,0x7a050091}},	//   sefn, rtvo, ебих, lėtr
  { {0x201e121a,0x68e400e8,0x629823ed,0x9f5e008c}},	//   toti_, nyid, stvo, yntä_
  { {0xff980001,0x2486003c,0x201e0007,0x200c0913}},	//   чкој_, mrom_, uoti_, undi_
  { {0xdef70010,0x3c2400c0,0xdd950010,0x68e401c2}},	//   дыя_, hövs_, наны, hyid
  { {0x6e360107,0x644800da,0x93250015,0x80a60015}},	//   _chyb, _hidi, _أركن, _يمان
  { {0x6448003f,0xe6110008,0x3204005c,0x40940015}},	//   _kidi, אִם_, mimy_, _ألتر
  { {0x7fb80074,0x6e2401e2,0xd0100015,0x3204002a}},	//   _رهبر_, _ekib, _حلت_, limy_
  { {0x7ed30029,0x60c20480,0xf1b90085,0x64485956}},	//   _لزيا, _hrom, loša_, _midi
  { {0xd2b70008,0x2d8f0134,0x3204005c,0x60c25957}},	//   וללת_, _øge_, nimy_, _krom
  { {0x5a440010,0x7b6703fc,0x66d5002b,0xf1b915e9}},	// [e490] тэра, _отне, کيائ, noša_
  { {0xc617005d,0x24865958,0x3b270015,0x3a2919f0}},	//   तव्य_, drom_, _يعدّ, slap_
  { {0x6c180029,0xd7c8002b,0x9f45008c,0x9f4c0077}},	//   _تتيح_, ظومه_, silö_, lidó_
  { {0x35f80086,0x683000c0,0x64485959,0x7ae802de}},	//   ورند_, räda, _aidi, ødte
  { {0xfdf80008,0xb4e9021e,0x64480863,0xf1b9003d}},	//   וצאת_, मने_, _bidi, joša_
  { {0x320d595a,0xc6a720e6,0x69dd595b,0xad1c004f}},	//   wney_, _орби, _hose, קוגר
  { {0x387e0024,0xf7940033,0x69dd595c,0x8bd8000a}},	//   _ātri_, _шарэ, _kose, ווגו_
  { {0x9e48002c,0x27fb002a,0xe0d92d90,0x64480034}},	//   _keďž, żyną_, зви_, _eidi
  { {0x6e360026,0x7bda0020,0x320d43f3,0x6448233b}},	//   _rhyb, ötuk, rney_, _fidi
  { {0x64480064,0xf8b20008,0x6e24595d,0x320d595e}},	//   _gidi, נשי_, _skib, sney_
  { {0xad9b002d,0x3204002a,0xc7d6004f,0xddcd007f}},	//   riún, bimy_, תותי_, ükşe
  { {0xad9b002f,0xb2ba000a,0xc332000a,0xd3780085}},	//   siún, _ממער, _גוב_, _voće_
  { {0x2e32002e,0x60c2595f,0x3c3602de,0xad9b412e}},	//   gáfa_, _grom, hæve_, miúl
  { {0x4c350033,0xda6600c3,0xad9b0125,0xf092000a}},	//   вэст, فاري, liúl, _ענו_
  { {0xf1d3005d,0x20055960,0x161f000b,0xa3e7000b}},	//   थापन, mili_, यकार_, _पवन_
  { {0xf2d200b4,0x6e24003f,0x61e95961,0x4efa000a}},	//   נען_, _ukib, nkel, _מהצו
  { {0xa84a06e4,0x61e93e0c,0x69dd5962,0x0d830033}},	// [e4a0] سلام_, ikel, _dose, _слын
  { {0x68f6005c,0xd7f90036,0xdc9b0053,0xad1b0008}},	//   rzyd, мує_, _צייל, _מופר
  { {0x64480939,0xabfb000a,0xeb97000a,0x6f7a000a}},	//   _ridi, _זהיר, _אדיר_, לְאו
  { {0xe5720029,0x20055963,0x7ae153be,0xe7170015}},	//   اطا_, hili_, älte, رينت_
  { {0x43942352,0x339401b0,0x0585005e,0xad9b0125}},	//   валс, валё, туєм, diúl
  { {0x20055964,0x24804ba8,0x3204002a,0x74330033}},	//   jili_, šimo_, wimy_, гніф
  { {0x8c1b000a,0x64485965,0x32b70015,0x69dd5966}},	//   הוסי, _vidi, فدية_, _yose
  { {0x7bde022d,0xf1b90024,0xad9b002d,0x60c25967}},	//   _lopu, toša_, giúl, _prom
  { {0x3157003b,0x644801d1,0xd4690015,0x53a60033}},	//   رجية_, _tidi, _يحكم_, _пааб
  { {0x32040050,0x20053464,0x547b0008,0x78fb0053}},	//   simy_, gili_, _מטמו, פליפ
  { {0x211a0074,0x179b0053,0x3f9e002e,0x479b0053}},	//   _کتاب_, הייב, rftu_, הייס
  { {0xad9b002d,0x61e95968,0xc333000a,0xa257000a}},	//   ciúl, ckel, _עוף_, _נבדק_
  { {0x9ccb0010,0x20054585,0xafe60df0,0x69dd505e}},	//   чына_, bili_, _подл, _rose
  { {0x6f0b0030,0x20055969,0x61434729,0x69dd596a}},	//   álcá, cili_, _сеча, _sose
  { {0x7ee30029,0xcf5700a3,0x0f57000a,0x63ba0a5f}},	//   _مكون, _אבות_, _איום_, _matn
  { {0x8e830029,0x8cbe000b,0x8e97000a,0xf1a6000b}},	//   _إليه, शिशो, _נדחו_, _कॉमन
  { {0x18980015,0x3e4c0046,0x9be700fd,0x6fb7000b}},	// [e4b0] فضلة_, _větu_, _зінк, _असमं
  { {0xd7c90086,0xf77000e5,0xdb070046,0x7c2501c2}},	//   بوطه_, مام_, lejí, _ukhr
  { {0x56950080,0x57a40010,0x501b000a,0x8ae40033}},	//   тает, ышта, לומו, _біял
  { {0xd6270015,0x14750015,0x200555a3,0xcad6004f}},	//   رعاي, ناتج, zili_, _סורת_
  { {0xe4580036,0x63ba001a,0x44250cc1,0x997605bd}},	//   ежі_, _batn, _pkl_, _בתרא_
  { {0xec720053,0xe3b10021,0xcc58000a,0x03a5165a}},	//   בֿה_, شرت_, עסוק_, тико
  { {0x61e9022d,0x63ba0048,0xb5a702e5,0x53e40010}},	//   tkel, _datn, _прай, ыцца
  { {0xb5c90086,0x2005596b,0x1022002b,0x68300012}},	//   _تورم_, wili_, یکوپ, hädl
  { {0xdb070046,0x20d5005e,0x61e9596c,0x2005596d}},	//   dejí, тійс, rkel, tili_
  { {0xe9df002f,0xad9b002d,0x9f5e013f,0x61e9596e}},	//   _siúl_, siúl, bití_, skel
  { {0x61ec00dc,0x8e85006b,0x41e700fd,0x179c000a}},	//   álló, ъгне, _піда, ליזב
  { {0x249d0026,0xed5a0fea,0x7bde008c,0x7a0c0045}},	//   otwm_, ьом_, _sopu, oşte
  { {0x2005596f,0xc212000a,0x7bde5970,0x5ff5012b}},	//   pili_, _דהא_, _popu, _изду
  { {0xafe20080,0x0000006a,0x0000006a,0x0000006a}},	//   _вошл,   ,   ,
  { {0xadfa0015,0xab272124,0xf1b9003d,0x6ec40058}},	//   _يربط_, вора_, nošo_, _متيق
  { {0x2a360010,0x0000006a,0x0000006a,0x0000006a}},	//   тэгр,   ,   ,
  { {0x25bd0176,0x39460010,0x2bba0029,0x9cb3002b}},	// [e4c0] ddwl_, тнаг, _قادة_, _نميت
  { {0xf1b90024,0x3c77000a,0x8c460342,0x4759005e}},	//   košo_, _שתים_, _шепе, ерця_
  { {0xc8150191,0xf1b90024,0x63ba2b81,0x387e003d}},	//   уєть, jošo_, _ratn, _ātru_
  { {0xd5d50010,0x9f5e0046,0xf1b9003d,0x63ba0085}},	//   лючы, vití_, došo_, _satn
  { {0x2b06005d,0xe76a0029,0x63ba5971,0xa87a009a}},	//   _हेतु_, _يحسن_, _patn, _تحجر_
  { {0xdb070089,0x82a60080,0x88f7000a,0x87b90e4d}},	//   zejí, вшие, _יזכו_, _пуст_
  { {0xfba4005d,0x2ba4005d,0x63ba05d8,0x1db2000b}},	//   ख्यम, ख्या, _vatn, ज़ात
  { {0xcb1305af,0x31c30033,0xdce60091,0xa021007c}},	//   ילו_, асьв, sakę, öönd
  { {0xa4461adc,0x44a50369,0x64a600af,0x27370073}},	//   _анад, _محلّ, _јаза, ažnį_
  { {0x9ed8000d,0xef1f0061,0x0000006a,0x0000006a}},	//   емот_, ğün_,   ,
  { {0xd36f0086,0xf1b90024,0xef1f0061,0xeeaa005e}},	//   _ذهن_, cošo_, şün_, єток_
  { {0x067b0053,0x867b0008,0x11ea0015,0x9e66002b}},	//   ונטל, ורטו, _تعطي_, _یابن
  { {0x5c07010f,0x6fb60029,0x71d7004f,0xa3d90065}},	//   вява, _لمشا, _שודד_, डॉक_
  { {0xdb0702d5,0xa077004c,0xce94006b,0x628a5972}},	//   sejí, _יעדנ_, _бакъ, orfo
  { {0x9f5e04ed,0x20190152,0x2bd5000b,0xdee30054}},	//   mità_, ésie_, दाबा, _воји
  { {0x9f5e02d7,0x628a52ba,0x99642de5,0x20b60065}},	//   lità_, irfo, итул, _अनाध
  { {0xdb0700dc,0xb8950087,0x6d5d00dc,0xa81509c3}},	// [e4d0] ldjü, طلاع, mcsa, гдаш
  { {0x9f5e02d7,0x109b0008,0xd9440001,0xe10b000a}},	//   nità_, ובמב, ређи, וּבָ
  { {0xa3b6005d,0xf77000e6,0x628a02de,0x6d5d0030}},	//   ज़न_, زال_, jrfo, ocsa
  { {0xf5950015,0x95c50015,0x6d5d0030,0x442e5973}},	//   الإج, طيته, ncsa, elf_
  { {0x45840036,0x6594209b,0x05740086,0x1da5005d}},	//   ргів, рачу, شاند, ग्यत
  { {0xf1b90024,0x59d1005d,0x8235002b,0x1424005e}},	//   tošo_, हावर, گرتا, адім
  { {0x36d40080,0xa2c0005d,0x9f5e04ed,0x232607d9}},	//   _корр, विष्, dità_, лоши_
  { {0xf1b9003d,0xd3780085,0x442e4b14,0x0000006a}},	//   rošo_, _voća_, alf_,
  { {0x49d6000a,0x628a0003,0xf1b9003d,0xbcfb0140}},	//   אֵין_, arfo, sošo_, ncéd
  { {0x5fcd000b,0xa2c0000b,0x7655002a,0x9f450125}},	//   ़ाइल, विश्, _kuzy, mhlú_
  { {0xdb050046,0xa3d0000b,0x5f051d8a,0x51950058}},	//   _pahý, षार_, узна, _ملاذ
  { {0x7655005c,0x24590092,0x26b60008,0xb226001a}},	//   _muzy, _kèm_, נִים_, rhæð
  { {0x2d9e005c,0xe0ce1c3f,0x8fa53771,0x7c99009b}},	//   ęte_, _ув_, _бале, кърс_
  { {0x9f5e02d7,0x2d9e0089,0xb226002e,0x6c360015}},	//   cità_, řte_, phæð, افسا
  { {0xcf240086,0x8f9a000a,0xf8bf0030,0x9980006f}},	//   _پروي, _ניקי, _szép_, hliť_
  { {0x5cd6005e,0x7ae10123,0xdb1c0a8b,0xda650058}},	//   _біох, älta, ndré, شافي
  { {0x59750010,0xd884002b,0x6e260030,0x387e003d}},	// [e4e0] рысу, شهای, mokb, _ātrs_
  { {0xb8dc000b,0x46f6006b,0x9989002a,0x67f2001a}},	//   _आन_, лчет, gnał_, _bæja
  { {0xdb9b000a,0x0bb7000a,0x9980006f,0x8b9b000a}},	//   _אסיר, _גלים_, eliť_, _אבית
  { {0xd5b90127,0x05ba0015,0x9989002a,0xd49a0245}},	//   ксі_, عدات_, anał_, ерк_
  { {0xbcfb0152,0xa4d40036,0x73e60033,0xb97b000a}},	//   ccéd, ролі, лодз, _אנכי
  { {0xdb070030,0xdc89000a,0xd7f20015,0x6d5d0030}},	//   lejá, דְקָ, _اكس_, zcsa
  { {0x9f5e02d7,0x2bd5005d,0x7584002b,0xdced0061}},	//   vità_, दाता, _نیام, _odağ
  { {0xbcfb002d,0x2ba40065,0x0000006a,0x0000006a}},	//   sbéi, ख्ता,   ,
  { {0x463b00b2,0xe45f0064,0x9f5e04ed,0x0396006e}},	//   _טעלע, _çöp_, tità_, _مشاج
  { {0x1600005d,0xbcfb0152,0xad9b002d,0x244a0015}},	//   लोरर_, ncée, miúi, _أجري_
  { {0x9f5e4a3a,0x9f340036,0xad9b002d,0x8f3418ba}},	//   rità_, рені, liúi, ренц
  { {0x867b0008,0x9f5e04ed,0x9989005c,0xf1a9002b}},	//   ערכו, sità_, znał_, _لاهه_
  { {0xae04005d,0xad9b002d,0xcd0718ba,0xab87006b}},	//   शोधन_, niúi, учни, лувк
  { {0xab951cf5,0x61e20005,0x30830029,0x6d5d0030}},	//   јављ, _hool, _الوف, scsa
  { {0xf1b8005d,0x1f5b0008,0x61e20100,0x2f5b000a}},	//   _आसान, _אדוא, _kool, _אדונ
  { {0x76550046,0x391500af,0x61e20072,0x0000006a}},	//   _ruzy, амбр, _jool,
  { {0xe8950010,0x9da8006b,0xa7750054,0x478b100f}},	// [e4f0] разь, _съща_, илач, есем_
  { {0xad9b002d,0x7bda007c,0xd7f801c5,0xbcfb01f6}},	//   diúi, ötut, лух_, rcéd
  { {0xbb76000a,0x9f450046,0xf7700040,0x26c74f78}},	//   _דעתו_, yklí_, ثاق_, íno_
  { {0xe60e0191,0x69cf003e,0x9980006f,0x61e2007c}},	//   ід_, _unce, tliť_, _nool
  { {0xad9b002d,0xa97a0008,0xf1e7000b,0xb97a004f}},	//   giúi, _בארכ, टॉफ़_, _שנשי
  { {0x626509fd,0x38695974,0xcc78004f,0xc6770369}},	//   авка, mpar_, נגות_, _مطرب
  { {0x93940015,0xbcfb0030,0x61e25975,0x38695976}},	//   إجها, ncéb, _bool, lpar_
  { {0x11e5005f,0x7a0c0045,0xc2c80015,0x61e22084}},	//   ржим, oşta, ابول_, _cool
  { {0xe5340036,0xad9b002d,0xffd50033,0x660b0012}},	//   _геть, ciúi, аўня, migk
  { {0xef1f01e2,0x93940029,0x25bf0335,0xd0a80021}},	//   şüm_, _هجما, _haul_, اطين_
  { {0xc7b20008,0x6e2600dc,0x61e2003e,0x02d90002}},	//   חבי_, tokb, _fool, _جواب_
  { {0xc1050086,0x09e1000b,0x3f8b0045,0x44275977}},	//   _پوتي, _नवगठ, şcu_, lon_
  { {0x7ae100b8,0x44275978,0x200b0152,0x5cf50033}},	//   ältn, oon_, écis_, бяру
  { {0x70fa0008,0x660b00b8,0x6e2600dc,0x6443002d}},	//   _בהנח, higk, sokb, nmni
  { {0x6e2600dc,0xa3b6000b,0xbad50033,0x6443003d}},	//   pokb, ज़त_, біты, imni
  { {0x44275979,0xf6d6002b,0xc966006b,0xba55006b}},	//   hon_, یزاد, рвай, стръ
  { {0x97560124,0xd9100086,0x7bda0020,0x660b00b8}},	// [e500] атељ, سیس_, ötus, digk
  { {0x64430050,0xbc7b0008,0x4427597a,0x6b9b00dc}},	//   jmni, _שנית, jon_, őugr
  { {0x660b00b8,0x1dda000b,0xb6070016,0x6f1d0012}},	//   figk, _बचात, _trờ, ßsch
  { {0xad9b002f,0x44270026,0x660b00b8,0xf484002b}},	//   tiúi, eon_, gigk, ماتی
  { {0x683000b8,0x8d5b0008,0x2480002d,0x044605b3}},	//   hädi, דכני, éim_, аедн
  { {0xad9b002d,0x442708d4,0x6822006f,0x61e21e68}},	//   riúi, gon_, hôdz, _sool
  { {0xad9b002d,0x61e20100,0x66e61310,0x660b597b}},	//   siúi, _pool, _това, bigk
  { {0x24890024,0xd6cf0015,0x442702f2,0xb6bb000a}},	//   šama_, _تقف_, aon_, _בצלי
  { {0xdfd0003b,0x61e20020,0x4427597c,0x94a9012c}},	//   كية_, _vool, bon_, _مطلق_
  { {0x2378000a,0x3378000a,0x61e22356,0x4427597d}},	//   _תָּמ, _תְּב, _wool, con_
  { {0x3fc80086,0x20190251,0x93fb0008,0x200b0251}},	//   ندگی_, ésia_, _שלבי, ècia_
  { {0xb6d90053,0xc2c40086,0xe1f90091,0x10a601e3}},	//   אַשט, _پيچي, chų_, _видн
  { {0x5cb80033,0x2cad00aa,0x01fb004f,0xd1300058}},	//   аляў_, ïed_, _בפאל, _عمت_
  { {0x9ce4005e,0x9989002a,0x8fa30054,0x0b88004a}},	//   іцял, znań_, _даље, исси_
  { {0xaae80036,0x70b6005d,0x403b0008,0x7ac41310}},	//   аєте_, _अनुल, _שגוג, осте
  { {0x7bda0020,0x200c08c7,0x5d850029,0x4427597e}},	//   ötur, lidi_, _الظل, zon_
  { {0x4427025c,0xa3b6014e,0x443e0020,0x5e440015}},	// [e510] yon_, ज़ा_, _oht_, _بَيْ
  { {0xc7f80036,0x9cd8000a,0xf74b002b,0x66c70054}},	//   анує_, _כוחה_, نجاه_, иљеж
  { {0xe9450086,0x660b00b8,0x44390007,0x17540036}},	//   _گردی, tigk, _ės_, івця
  { {0x2d99020a,0x200c003f,0x7ae800b8,0x4427597f}},	//   ngse_, hidi_, ädte, won_
  { {0x660b00b8,0x4498005e,0xd49b0317,0xaa3a000a}},	//   rigk, ивцю_, тре_, _תתרח
  { {0x660b00b8,0x84280036,0x44274abd,0xe3c50015}},	//   sigk, ажів_, uon_, صْبَ
  { {0x9f5e00f2,0x68ed11ac,0x44275980,0xe3b0006e}},	//   iitä_, lyad, ron_, ظره_
  { {0xef1f0064,0x442712af,0xdb07007c,0x4095080e}},	//   şük_, son_, mejä, брот
  { {0x6609003f,0x91fc0024,0x44275981,0xf1b920c0}},	//   _imek, _itāl, pon_, noši_
  { {0x753b016f,0x41020080,0x2d991de9,0x9472009a}},	//   _izuz, языв, egse_, _رگها
  { {0x539a0008,0xa3c40065,0xdb07005b,0x0000006a}},	//   _תיעו, एयर_, nejä,
  { {0xc69200b2,0x200c0c60,0xd336000a,0x9f5e008c}},	//   האט_, aidi_, _הרעה_, eitä_
  { {0x200c003f,0x661b00c0,0x9f4c00f2,0xf236000a}},	//   bidi_, _mjuk, ehdä_, _פרנץ_
  { {0x3c19008f,0x653a0053,0x61fb1325,0x6b63106d}},	//   аўся_, טערד, lhul, зкра
  { {0x6e95040b,0xa3a9005d,0x254b0007,0xa03a0053}},	//   _العا, ग्य_, lėlį_, _געספ
  { {0x9e6400c3,0x61b50065,0x0000006a,0x0000006a}},	//   _باون, _अघोष,   ,
  { {0xed620007,0xd9431377,0x6d5602f2,0x67560058}},	// [e520] ąžą_, зети, _igya, مخار
  { {0x66092e80,0xa3a9005d,0xdb1c2880,0x9cdb000a}},	//   _amek, ग्म_, ldrí, _עקיפ
  { {0x5b570135,0xceb2000a,0x66760015,0xc68f0015}},	//   _לייב_, ּיד_, صدار, ِّم_
  { {0x200c003f,0xdb1c02c1,0x765a0003,0xe5e50015}},	//   zidi_, ndrí, _étym, يثني
  { {0xceb8005c,0x53e60033,0x25a60034,0xd3780085}},	//   zwę_, йцка, rfol_, _peć_
  { {0x66090064,0x69c42e0f,0x2937004c,0x25a600aa}},	//   _emek, ldie, _לאכן_, sfol_
  { {0xd378010b,0xbcfb002d,0xc6d8000a,0x6d560030}},	//   _već_, icéa, _דַּר, _ogya
  { {0x61fb000c,0xda7b0053,0x200c003f,0x599a000a}},	//   ghul, אנקר, widi_, אשֵׁ
  { {0x29005982,0xf487002b,0x2bcb000b,0xc1040015}},	//   nzia_, _هالی, ायमा, توظي
  { {0x6e2d00fb,0xe7ce000b,0x6ee60015,0xceb8002a}},	//   _skab, _होमप, مسجل, twę_
  { {0x9f5e022d,0x5f380036,0x78a4267f,0xdb0700dc}},	//   vitä_, рпня_, htiv, ldjö
  { {0xd7370008,0x61fb0b8e,0x0737000a,0xa9b2000b}},	//   מטית_, chul, מאים_, ँजोए
  { {0x013600e6,0x200c5983,0x1c39004a,0x29001945}},	//   _اعاد, pidi_, измы_, jzia_
  { {0x69c44f7c,0x29001332,0x3174002a,0x909b000a}},	//   edie, dzia_, ńczą_, _עסוק
  { {0xec340191,0xcfa90074,0x9f5e00f2,0x5f440015}},	//   їнсь, _خانم_, ritä_, _بنغل
  { {0xf1b90024,0xc27b0008,0x6e2d0573,0xff17000a}},	//   toši_, טרלי, _ukab, _לקות_
  { {0x7c970002,0x89340015,0x1dd6000b,0x6c840015}},	// [e530] _اشعا, كعكا, धारत, _فليم
  { {0x660900c0,0x661b02ce,0x5fdb000b,0xab2b0021}},	//   _smek, _sjuk, बायल, _مسجل_
  { {0xd6d10029,0x69c40024,0x68ed11d3,0xe7190015}},	//   بقا_, bdie, syad, جيات_
  { {0xd2460074,0x999900df,0x7e9b0008,0x3f8a005c}},	//   _زن_, _visų_, רסאו, óbuj_
  { {0xc4840033,0x0395003d,0xdb07007c,0x78a45984}},	//   злік, žīmā_, sejä, ctiv
  { {0xdb0e0046,0x24895985,0xd7f10016,0x254b0091}},	//   zebí, šamo_, _ỗ_, vėlį_
  { {0xe9450086,0x7a330064,0x41c4000b,0xdb1e016e}},	//   _درگی, eçti, वयंस, _papé
  { {0x6609003f,0x52a60033,0x254b0091,0xa5f808f0}},	//   _umek, івым_, tėlį_, _лесу_
  { {0xcfb5004a,0x4105005e,0xad9b0030,0x61fb5986}},	//   ощны, юзив, hiús, rhul
  { {0x69c4002c,0x60090760,0x94040015,0x0ea9055f}},	//   zdie, рном_, _فوقه, акой_
  { {0x20f40023,0xa3b6005d,0x60c40007,0x61fb00dd}},	//   ài_, ज़र_, _šimt, phul
  { {0x9f450107,0xf8bf0003,0x20d50058,0x0000006a}},	//   chlý_, _osé_, _وقاس,
  { {0x21580015,0x290f001a,0xc0e5080e,0x7d030033}},	//   _اجمع_, úgal_, _фолк, дзяж
  { {0xda660029,0xcfe9002b,0x317f0030,0x0000006a}},	//   قاري, _خفته_, lauz_,
  { {0x1ea8002b,0xdcfa002b,0x60c9074e,0x69c45016}},	//   _هايي_, _چرخش_, lvem, tdie
  { {0xbcfb5987,0x78a45988,0x69c41d7f,0x628c0264}},	//   scéa, ttiv, udie, _úlož
  { {0x6c360015,0x69c45989,0xd7f20015,0x59b9000b}},	// [e540] _وفعا, rdie, وكر_, उज़र
  { {0x2900002c,0x9cb30086,0x69c4598a,0x6283598b}},	//   rzia_, _کمیت, sdie, ksno
  { {0x56930036,0x78a4029e,0xbb46006b,0xfc3f006f}},	//   даєт, stiv, _фенк, stíc_
  { {0x1ddd005d,0xdb1c001c,0xad9b002d,0x6441172e}},	//   यायत, adrã, liúr, _ahli
  { {0x6441002f,0x58d30010,0x21f800dc,0x64b60031}},	//   _bhli, _жоўт, _néha_, تحار
  { {0xb8e0005d,0x644122e8,0x20190003,0x2caf0123}},	//   ूट_, _chli, ésil_, _ägde_
  { {0xa3a9005d,0xfc3f02c1,0x92940010,0xab8b000a}},	//   ग्ध_, ntía_, чайц, שָׂ֖
  { {0xd378016f,0x54a60015,0x317f598c,0x6441007f}},	//   _moći_, _وحذف, gauz_, _ehli
  { {0xef180024,0xf1b90024,0xc4c60015,0xefea0015}},	//   daļa_, jošu_, _بتزو, لعدو_
  { {0xb4d6005d,0xdb0e002e,0x10160015,0xf3f8000a}},	//   िमी_, ndbó, تبعد, _פִּל
  { {0xd378016f,0x2bde000b,0x883b000a,0x1dd6000b}},	//   _noći_, माना, שתיו, धांत
  { {0x1687004f,0x0000006a,0x0000006a,0x0000006a}},	//   חֲךָ_,   ,   ,
  { {0xe6110008,0xdb1500dc,0x2029001a,0xfbd30021}},	//   תִי_, mezé, ótið_, وتس_
  { {0xdb1500dc,0xc04f022a,0x62980003,0x63b81d11}},	//   lezé, _іі_, ouvo, nevn
  { {0xc1ee014e,0xa2c0000b,0x99d70067,0x0000006a}},	//   _जवाब_, विट्, يترا,
  { {0xd378016f,0xee0800d0,0xbd6b0054,0x91fc003d}},	//   _doći_, _мејл_, _трке_, _stāj
  { {0x2e32002e,0xe8550021,0x7c67006e,0xf1bd000b}},	// [e550] gáfu_, سناد, _بابل, ्यतन
  { {0xf7700002,0x63b80796,0x6283008c,0x3018000a}},	//   نام_, jevn, ysno, צֵּב
  { {0xdb150014,0x35b51ad3,0x5a470033,0xd6db598d}},	//   kezé, збер, _мэма, шта_
  { {0xdb150014,0x9f47006f,0x644101b3,0x80bc000b}},	//   jezé, _plnú_, _shli, ्टाइ
  { {0x7bc50035,0xdb1500dc,0x683000b8,0x89da000a}},	//   _kahu, dezé, tädt, _החרי
  { {0x187600a3,0x2cbc000a,0x7bc5007c,0xf8b2000a}},	//   _מעשר_, שֶׁב, _jahu, _רשם_
  { {0x4bfc004c,0xd2990033,0x7bc5598e,0xe1f10015}},	//   שלוס, ёткі_, _mahu, فسة_
  { {0x7bc50020,0xdb1c598f,0xc692015b,0xa2c0000b}},	//   _lahu, ndrá, _ראן_, विज्
  { {0x60090036,0xe0d60010,0x2519000a,0x765c0535}},	//   йним_, звы_, _הוּא, _zury
  { {0xaf05010f,0x64410069,0x60c95990,0x777c5991}},	//   зпол, _uhli, rvem, _xerx
  { {0x82f80015,0x91f70015,0x7bc707a3,0xed5a0840}},	//   _ورمز_, _وأصا, ddju, йон_
  { {0xd131003b,0xf1b90024,0x333a000a,0x24920091}},	//   _كما_, tošu_, _התעמ, šyme_
  { {0x62080029,0x515a000a,0xef18003d,0x7bc55992}},	//   _بْنِ_, _הכנו, raļa_, _bahu
  { {0xf1b9003d,0xd3780085,0x7bc70123,0xcb67012f}},	//   rošu_, _poći_, gdju, заре_
  { {0x7bc50375,0x9f7a000a,0x0f7a000a,0x34b8000b}},	//   _dahu, _הנצח, _הרצל, _इन्द
  { {0xc3320008,0x78660758,0xfc3f0077,0x7bd7016e}},	//   גול_, зказ, rtía_, _enxu
  { {0x60d50008,0x765c00e8,0xfc3f02c1,0x2d823cdc}},	// [e560] הוּא_, _sury, stía_, make_
  { {0x765c002a,0xdb1c0030,0xdb150030,0x2d825993}},	//   _pury, adrá, zezé, lake_
  { {0x41bd000b,0xdb1e001a,0x7c2e16ad,0x3e610030}},	//   ्यास, _kapí, mobr, _jót_
  { {0x2d8202c6,0xa3a9000b,0x64a602bb,0x15460004}},	//   nake_, ग्स_, зада, пеем
  { {0xdb1500dc,0xf95700f3,0x63b80107,0x3e610016}},	//   vezé, _מסכת_, tevn, _lót_
  { {0x69c6022d,0x629800df,0x765c005c,0x13f302a3}},	//   _hake, tuvo, _tury, нзія
  { {0xdb1500dc,0xf1b9003d,0x69c61c0f,0x63b85994}},	//   tezé, jošs_, _kake, revn
  { {0x05660063,0xdb1e01c9,0x69c65995,0x60f8006b}},	//   _хван, _napí, _jake, жния_
  { {0xbcfb00dc,0x69c605d6,0x32f70092,0x2d82007c}},	//   gcél, _make, ãy_, dake_
  { {0xe9df0092,0x7c2e005c,0x3cf2000b,0xdb1c0046}},	//   _khúc_, jobr, ुनने_, zdrá
  { {0x7bc50005,0xdd9502bf,0x7c2e2064,0xdb150030}},	//   _rahu, маны, dobr, pezé
  { {0x71a60010,0x38a6002c,0xf1b901c9,0x91f50016}},	//   _хадз, kôr_, ceš_, _hún
  { {0xc5f30008,0x11540010,0xdb1c002e,0xdb0e00cb}},	//   גדר_, _ўклю, ndræ, nebæ
  { {0xf1da005d,0x99800007,0x60bb000a,0x7bc70030}},	//   भावन, klių_, _לצדד, udju
  { {0x2d82003c,0x600b000a,0x7bc5007c,0x69c65996}},	//   bake_, _לִהְ, _vahu, _bake
  { {0x21f80089,0x7bc700c0,0x7bc5003f,0x442e186c}},	//   _mého_, sdju, _wahu, hof_
  { {0x08550010,0x7bc5013c,0xbd450031,0xd3780085}},	// [e570] дваю, _tahu, _تنظي, _hoću_
  { {0x60c2003f,0xd6db3a2d,0xdb1e01c9,0x2bde000b}},	//   _msom, йте_, _zapí, माणा
  { {0xe9df0092,0xa3b6005d,0xcdd5000a,0x3e610016}},	//   _chúc_, ज़ई_, ֽךְ_, _xót_
  { {0xe9df0023,0x3618005e,0x2bcb000b,0xa2bd0065}},	//   _giúp_, пцію_, ायवा, _वैष्
  { {0x8cd0014e,0x99800007,0xb464005e,0x94ab012e}},	//   दियो, alių_, екіл, стеа_
  { {0x69c60111,0xc952000a,0x3e4d0046,0x2d820079}},	//   _zake, _שמך_, _věty_, zake_
  { {0xea000023,0xddcd0050,0xa2bd000b,0xa3bc000b}},	//   _hoạt_, _miał, _वैश्, इज़_
  { {0x3f9e0024,0xe57300e6,0x7c2e2943,0xcad8000a}},	//   egtu_, _سطر_, zobr, לוות_
  { {0x60c200dc,0x64a4000d,0x34942981,0x15150010}},	//   _csom, _паѓа, _патр, _ўдзя
  { {0xdb1e001c,0x2d82003f,0x7f740010,0xf1b90024}},	//   _japã, wake_, нуюц, tošs_
  { {0x9f5e00f2,0xea000092,0xdb1e1724,0x93190021}},	//   yntö_, _loạt_, _papí, _بقاء_
  { {0xa3a9000b,0xf1b9003d,0x63a40030,0x7c2e0dac}},	//   ग्र_, rošs_, őint, wobr
  { {0xddcd0050,0x522a0053,0x69c65997,0xfc3f5998}},	//   _biał, _ווײַ, _rake, rtín_
  { {0xddcd005c,0x41bd005d,0x2bde000b,0x69c65999}},	//   _ciał, ्यवस, माधा, _sake
  { {0x69c64098,0x2d82599a,0xfaa312a2,0xef1f0061}},	//   _pake, pake_, каро, ğüs_
  { {0xc9aa0010,0xc8c9000b,0x6ec40015,0xe8fa0a86}},	//   ўвае_, रिंट, _أتوق, олб_
  { {0x7a0c0011,0x2fc71640,0x69c60fe3,0xfc320015}},	// [e580] nşti, _kang_, _vake, _لحد_
  { {0xe9df0092,0x35c6005d,0xdce40024,0x26d106e6}},	//   _phúc_, _रोज़, _ediģ, _brzo_
  { {0x99800007,0x69c6069b,0x4a460956,0x24860335}},	//   ulių_, _take, _онов, wsom_
  { {0x61eb00fb,0x2fc7599b,0xa5da0015,0x24862123}},	//   _nogl, _lang_, غبار_, tsom_
  { {0x2d800005,0x99800091,0x19bb000a,0xa9bb000a}},	//   _meie_, slių_, _ומכב, _וזכר
  { {0x2fc708e6,0xe9df0023,0x9989005c,0xb8f2005d}},	//   _nang_, _thúc_, ciał_, वि_
  { {0x9989032c,0x61eb0134,0xf1da000b,0xa5760015}},	//   slať_, _bogl, भालन, _يُست
  { {0x75d60087,0x61eb02b9,0x69fb004c,0x442e4666}},	//   _تيرا, _cogl, ַליק, sof_
  { {0xc2070015,0x2fc7599c,0xd0d4006b,0x61eb599d}},	//   بقين_, _bang_, хопъ, _dogl
  { {0x2fc700a1,0x0000006a,0x0000006a,0x0000006a}},	//   _cang_,   ,   ,
  { {0xa3bd005d,0xdb0e00c0,0x61eb3816,0xb7970008}},	//   ेयर_, nebä, _fogl, וכיח_
  { {0x61eb0176,0x9989005c,0x2fc70112,0x72160021}},	//   _gogl, ział_, _eang_, _غذائ
  { {0x2bbb0029,0x60c2003f,0x9fe60029,0x28d2000b}},	//   ياسة_, _usom, _يسته, सिफि
  { {0xa08b01d8,0x6fb40015,0x6fb30015,0x2fc70223}},	//   _וְהִ, _أمثا, _لمها, _gang_
  { {0x0057000a,0xbf9b000a,0x9f9b000a,0x62a20107}},	//   _קשות_, _ויוש, _וסופ, _útoč
  { {0x5e270029,0x2014005c,0x9989005c,0x2489121a}},	//   _تعتق, ścić_, wiał_, šami_
  { {0xe9df0092,0x2fc7013c,0x201e599e,0xdcff003d}},	// [e590] _chúa_, _yang_, onti_, āvēj
  { {0x1ddd005d,0x660200f2,0x201e001a,0xb9070065}},	//   यावत, ehok, nnti_, _मऊ_
  { {0x201e022d,0xa3e2005d,0xda670086,0xdb0e0012}},	//   inti_, धान_, _تاخي, gebä
  { {0x9989005c,0xff17000a,0x660201d7,0x0000006a}},	//   siał_, וקבת_, ghok,
  { {0xc976000a,0x9989002a,0xa3b90015,0x2e24007f}},	//   _רגשי_, piał_, كاثر_, nıfa_
  { {0xa87a000a,0x3cf2000b,0xc2c50015,0xdb150030}},	//   _מאשר, ुनते_, فيتي, hezí
  { {0x6b7c013a,0xa3b80029,0xe299076c,0x61eb18e6}},	//   חרונ, ظاهر_, чай_, _pogl
  { {0xdb1c03af,0xfc3f0089,0x6602003f,0xdb1e00dc}},	//   ferê, dtím_, chok, _japá
  { {0x2fc700b6,0xfa0d0023,0x61eb04ed,0x04950002}},	//   _pang_, _đấu_, _vogl, _سلاح
  { {0xe3b00086,0xdb1e0030,0x2d80599f,0xb91a004f}},	//   _نرم_, _lapá, _seie_, לֵיט
  { {0x6da60ea6,0x11d70015,0x2fc759a0,0x61eb59a1}},	//   нина, _يتصد, _vang_, _togl
  { {0x2fc758de,0x91fc0024,0x8276000a,0xdb1e0069}},	//   _wang_, _stāv, _נענע_, _napá
  { {0x51840484,0xdb0e59a2,0xfc3f0046,0xed350033}},	//   _руха, ndbö, atím_, вэрэ
  { {0x3ced0020,0x224d31ad,0x2fc700e8,0x21f101c0}},	//   äeva_, lmek_, _uang_, _váhu_
  { {0x2d800005,0x6ffa000a,0x3f8559a3,0x6008000a}},	//   _teie_, _מהספ, malu_, _קִנְ
  { {0x224d01e2,0xe1f90007,0x3f85064e,0x6e9259a4}},	//   nmek_, nkų_, lalu_, _إليا
  { {0x87ba0080,0xdb0500b8,0x63ad016f,0xcc8a0029}},	// [e5a0] зует_, _abhä, đanj, _عنده_
  { {0xfd470892,0x08c30033,0x4aaa005e,0x3f8559a5}},	//   _язык_, ыбун, _екон_, nalu_
  { {0x869a0063,0x224d0064,0x6b7b000a,0x5b7b000a}},	//   ятат_, kmek_, _מרינ, _מריא
  { {0xf539002c,0x14ca0080,0xdb1c079c,0xdcfd003d}},	//   _byť_, зыки_, rdrä, lasā
  { {0xc955008f,0x201e00f2,0x6e24003f,0x3f8559a6}},	//   _атры, ynti_, _mjib, kalu_
  { {0xc0490092,0xdce60007,0x98160015,0x44f30033}},	//   _vườn_, sakė, _أبحا, ыпіс
  { {0x53330004,0xe28f0015,0x85b603ae,0x6e360091}},	//   лешт, مذي_, _пљач, _okyb
  { {0xcb13000a,0xdb1c39a7,0xf1aa0015,0xe2970054}},	//   טלו_, terê, سابه_, хаћ_
  { {0xdfd0040b,0xc8c9005d,0xcfa60063,0xbddb0152}},	//   لية_, रिएट, ншни, llèg
  { {0x201e000c,0x24530015,0xa2e60459,0x68e40144}},	//   unti_, _منقس, _позд, ixid
  { {0x38170008,0xc7b3000a,0x645a008c,0x3a2000aa}},	//   תקים_, אבת_, _iiti, knip_
  { {0x645a59a7,0x68f6008c,0x628a59a8,0xc1760058}},	//   _hiti, kyyd, msfo, _أدات
  { {0x2c660026,0x3f8559a9,0xbea7002b,0x645a59aa}},	//   _côd_, balu_, وهین_, _kiti
  { {0x6d440050,0x645a003f,0x3157000a,0x62980079}},	//   _dzia, _jiti, _ניגן_, orvo
  { {0x03d70008,0x600b000a,0xe9df0125,0x628a24a8}},	//   עולם_, _צִדְ, _dhún_, nsfo
  { {0x645a59ab,0x7f3b000a,0x4f3b000a,0x79a70033}},	//   _liti, _מעוו, _מתוע, эрге
  { {0xb9550063,0x7e0c000a,0xe894004a,0xdb1c0144}},	// [e5b0] тващ, _מִזֶ, лать, herè
  { {0x224d0064,0x6e3d1b62,0x7ae10123,0x628a59ac}},	//   zmek_, llsb, älts, ksfo
  { {0x9f5e0077,0xcc56000a,0xa7fb0077,0xdb150012}},	//   litó_, _שבתי_, _cuña, ndzü
  { {0xd9150010,0xf6500087,0x7afa0af5,0x2a76000a}},	//   _адмы, مئن_, øtte, _שערך_
  { {0x645a0064,0x69dd59ad,0xb5c80015,0x629859ae}},	//   _biti, _inse, عوهم_, ervo
  { {0xdb1c08e0,0x74150031,0x645a59af,0x80bc0065}},	//   ferè, ضوعا, _citi, ्टैं
  { {0x224d0064,0x9f4d0064,0x645a0049,0x78ad59b0}},	//   tmek_, ünün_, _diti, ltav
  { {0xe4e70036,0xe1f90007,0x645a1a28,0x9adc000a}},	//   _пізн, ukų_, _eiti, לחוט
  { {0x224d01e2,0x8f990063,0x6298043c,0xe1f90091}},	//   rmek_, мънт_, arvo, rkų_
  { {0x24550074,0x78ad3ce5,0xe1f90091,0x224d0061}},	//   _شناس, itav, skų_, smek_
  { {0x248d0293,0x78ad0044,0x94040015,0xa3e6000b}},	//   _hvem_, htav, _حوله, _बचत_
  { {0x645a00b8,0xc1150180,0x3f85007c,0xc33205bd}},	//   _ziti, _имеј, salu_, _דוב_
  { {0xf65200b2,0x6448022d,0x91f6000a,0xf1b2000a}},	//   יצט_, _yhdi, _שמנו_, _כסא_
  { {0x69dd59b1,0x68f6008c,0x6d44006f,0x61e959b2}},	//   _anse, vyyd, _vzia, ljel
  { {0x83a8000a,0x3e860046,0x61e9008c,0x78ad59b3}},	//   עֱשֶ, _vítá_, ojel, etav
  { {0xf2d20053,0x3eaa01b2,0x61e959b4,0x248d00bc}},	//   סען_, žití_, njel, _ovem_
  { {0x753b003f,0x9f5e265b,0x20050107,0x1d0a033d}},	// [e5c0] _nyuz, citó_, ohli_, _цепи_
  { {0x61e959b5,0x4803000d,0x69cd0026,0x69dd1915}},	//   hjel, апув, adae, _ense
  { {0x61e9003c,0x68f600f2,0x248d0011,0x61fb59b6}},	//   kjel, syyd, _avem_, kkul
  { {0x645a0467,0xa2d5014e,0xceb20008,0xc1bd005d}},	//   _siti, भिन्, שיא_, ्योग
  { {0x0836008f,0x61e9010b,0xdb050152,0x34b401b0}},	//   _ахвя, djel, _achè, ублё
  { {0x61e90014,0x24920007,0xdb1c0251,0x84330036}},	//   ejel, šymo_, terè, аніє
  { {0xb3850015,0xdb1c0077,0x66e3144f,0xf365005e}},	//   اجهه, feré, _кора, утін
  { {0x61e903c0,0x527300c3,0x04960015,0x442502de}},	//   gjel, جاوز, _للرح, _ejl_
  { {0x91fc0024,0x13b60015,0x7058006b,0xe5770004}},	//   _stās, _لصاح, наир_, _јзу_
  { {0xc949000f,0x2937004c,0x645a0079,0x9f5e0077}},	//   עֲקֹ, כאפן_, _uiti, vitó_
  { {0xdfd0002b,0x179b000a,0xfc3f006f,0xdb1c0030}},	//   ليک_, וייב, stík_, beré
  { {0xc0d60015,0x1317000a,0x2005006f,0xe9df0125}},	//   _ليصب, _בחבל_, ahli_, _chúl_
  { {0xa3e6005d,0x6e3d59b7,0xfc330058,0x21670302}},	//   _बचा_, rlsb, لحس_, _ричи_
  { {0x3ed40029,0xd0f70447,0xdfcf006e,0xac24013d}},	//   _مقتر, _בצדק_, _وين_, афск
  { {0xaf330086,0xdeef044e,0x9f5e0077,0xdb1e006f}},	//   _پروت, _ты_, sitó_, _napä
  { {0x78ad59b8,0x0f570008,0x8f450036,0x63ad0085}},	//   ttav, _ביום_, _схід, đani
  { {0x69dd0012,0xc9840076,0x6d48002a,0x57b516b2}},	// [e5d0] _vnse, руси, ędac, лбат
  { {0x673c05d8,0xdb1c0030,0x8cd0000b,0xa77400f4}},	//   _byrj, zeré, दिरो, илуч
  { {0xd838008f,0xcf9300b2,0xa3d6021e,0x7c35006f}},	//   тэт_, שטע_, ियन_, mozr
  { {0x78ad0084,0xa3b0005d,0xfad60008,0x69dd04b0}},	//   ptav, ट्स_, _עורך_, _unse
  { {0xe9df002c,0x61e9016f,0xd4c40015,0x24f90033}},	//   _inú_, vjel, لغوي, энды_
  { {0x80d6000b,0xe3b10015,0xee3f0247,0xdb051d2c}},	//   बिने, صرت_, hlý_, _aché
  { {0xfbb8013a,0x3f83002e,0xdb1c59b9,0xe3b0012c}},	//   דפות_, ðjum_, teré, ترن_
  { {0xc692000a,0x7ae80012,0x61fb59ba,0x00c9012f}},	//   _לאל_, ädti, ukul, елик_
  { {0x28c9005d,0x61e959bb,0x7a0c0045,0x205501c5}},	//   रिटि, rjel, oştr, лтор
  { {0x24890048,0xdb1c00dc,0xdb050003,0xa7fb010d}},	//   šams_, seré, _tchè, _muño
  { {0x61e9016f,0x7c353827,0x02a70323,0x2005013f}},	//   pjel, dozr, _шрам, rhli_
  { {0xf3f10023,0xfbc90008,0x02fa0053,0xcf490061}},	//   _họ_, _מת_, _אלעמ, _ışık_
  { {0x3e680152,0xed570142,0xf1f80015,0x6fd5005e}},	//   _eût_, лою_, _جعلت_, _бійц
  { {0x40920029,0x75160053,0x3e680152,0xf092000a}},	//   _الور, אַלע_, _fût_, _פנו_
  { {0x4e950029,0xfe710015,0x9ec40015,0xab271e50}},	//   _إشتر, _ادت_, _نزيه, гора_
  { {0x38cb002b,0x316d5809,0x8a430015,0x0000006a}},	//   کافی_, ncez_, مَّن,
  { {0x48e30063,0xa3d6005d,0x673c008c,0xcb6a098b}},	// [e5e0] ботв, ियम_, _syrj, _папе_
  { {0x7bde00da,0x66e60133,0x5aca03ca,0xe9df039f}},	//   _unpu, лоза, _злом_, _enú_
  { {0x9f45005a,0x0000006a,0x0000006a,0x0000006a}},	//   yklý_,   ,   ,
  { {0xc9760087,0xf7690008,0x1f360053,0x94aa4baf}},	//   _حادث, לק_, ארער_, етка_
  { {0x4e3700b2,0xdb1c063b,0x64b30058,0x0000006a}},	//   אָגן_, edrø, محور,
  { {0xdb054c8b,0xf3f100a1,0x79860546,0x0000006a}},	//   _sché, _cọ_, _hekw,
  { {0x02930015,0xd379005e,0xd25a0cab,0x798601c2}},	//   مؤيد, тчі_, нци_, _kekw
  { {0x6619005c,0x98a7005c,0xe73716bb,0x28c90065}},	//   ciwk, łną_, _сес_, रिचि
  { {0x4a5b0008,0xbfaa018f,0x15431bdf,0x3e6801f6}},	//   עדפו, нтне_, _гетм, _sût_
  { {0xdfd0002b,0x3e680003,0x50b70067,0x5f94012e}},	//   آيد_, _pût_, اديد_, јинт
  { {0xf8370008,0x6d400064,0xd36f0015,0xdb050003}},	//   רנית_, üman, _رهن_, _tché
  { {0xa3b0014e,0x21670001,0xa2c1000b,0x9f47431f}},	//   ट्र_, _бици_, लबर्, _donà_
  { {0xec150015,0xf237004f,0xd01a009b,0x50d3009a}},	//   لوحد, _גראץ_, _пфк_, _هزور
  { {0xee3f0069,0x3a75009b,0xe9df0052,0x0000006a}},	//   slý_, илгр, _snú_,
  { {0x3ffb00b2,0xfc3f0eed,0xda4b004a,0x798608cf}},	//   _אפגע, ktív_, ечал_, _bekw
  { {0xb9250029,0x6f4b000a,0xfe780091,0x6ce7005e}},	//   لفزي, _אֲחַ, mpį_, _біое
  { {0xb8150001,0xa3d7000b,0x6e040015,0x481501f3}},	// [e5f0] адај, ़एम_, _دِين, амас
  { {0xf7950010,0x7b15004a,0x64460091,0x2d8b59bc}},	//   ражэ, _вдох, _ūkin, lace_
  { {0xf77004c9,0x2575002b,0x8f9b000a,0x9f47013f}},	//   سال_, لهاس, תיבי, _koná_
  { {0x8f370053,0x7986016b,0x2d8b59bd,0xb4d5006b}},	//   נטאג_, _gekw, nace_, ижещ
  { {0x26d803af,0xa2bd005d,0xb5c20036,0x63851d9f}},	//   _erro_, _वैज्, ійшл, агла
  { {0x69cf0467,0xe29908a3,0x38af0061,0xfc3f1945}},	//   _hace, вак_, mür_, atív_
  { {0x2d8b02d5,0x2bf80008,0x38af0064,0x5c38000a}},	//   kace_, רמון_, lür_, ארגן_
  { {0x0165000d,0xc245023e,0xc8b7000a,0xa0c50015}},	//   шкио, јник, ָּ֗ה_, ليبو
  { {0x38af0064,0x25f4000b,0x22560015,0x2d8b59be}},	//   nür_, ूसरी_, جليد_, dace_
  { {0x41a7000b,0xa3d6000b,0x2d8b2e9d,0x045b0015}},	//   _गावस, ियण_, eace_, _أجرت_
  { {0xa3e2005d,0xe39a000a,0xcce9000a,0x25d5000a}},	//   धार_, _יֹאש, _קכ_, ֑וֹן_
  { {0x2d8b0089,0x24800011,0x26b6000a,0x9e620033}},	//   gace_, ţime_, סִים_, ўвяд
  { {0xef180048,0x8c460063,0xa508004f,0x79860535}},	//   daļu_, иеме, ָּרִ, _rekw
  { {0x38af0064,0xef670063,0xab2a0329,0x7986002a}},	//   dür_, _съдо, вога_, _sekw
  { {0x25a60026,0x78bd138a,0xa3d6000b,0x8f9a000a}},	//   ygol_, _apsv, ियत_, _סיקי
  { {0x38af00b8,0x6926302b,0x2d8b59bf,0x69cf59c0}},	//   für_, амба, cace_, _cace
  { {0x38c80086,0x77860001,0x38af0061,0x18a62797}},	// [e600] دازی_, илаз, gür_, разм
  { {0xdb1c20a9,0xb8ee000b,0xa7850015,0x8b962dfa}},	//   lerí, _शन_, مشمو, _трич
  { {0xa3e9014e,0x8b9b0008,0x69cf1ae0,0x6b9b000a}},	//   यान_, _בבית, _face, _בשיד
  { {0xe61a0063,0x6cd3002b,0xdb1c0077,0xa755030c}},	//   ъде_, _اقیا, nerí, стущ
  { {0x8cd9005d,0x397b0008,0x6e260030,0x7589005e}},	//   मियो, _בטכנ, inkb, усєв_
  { {0x2d8b02d5,0x25a60176,0x9cd70008,0xdb1c0026}},	//   zace_, sgol_, יונה_, merâ
  { {0x03a30001,0x3f98002e,0x4420016f,0xdb1c2439}},	//   цијо, órum_, đi_, lerâ
  { {0x1a9b0053,0xc4c6002b,0xdb1c0077,0x80e60015}},	//   דיקע, _پترو, jerí, لأخل
  { {0x2d8b4843,0xdb1c335d,0x865b000a,0x03a60c02}},	//   vace_, derí, _ידלי, _визо
  { {0x6abe06f5,0x250b0086,0xf8b30008,0xdefa044e}},	//   _oppf, _شرقی_, קשת_, вым_
  { {0x3f870026,0x2d8b0089,0x1e350033,0x38af0061}},	//   _denu_, tace_, йноў, zür_
  { {0xfe780007,0xf1a9002b,0xdb1c0077,0xfc3f0046}},	//   rpį_, _ماهه_, gerí, htít_
  { {0x61e202d7,0xfd47008f,0xf6570008,0x2d8b59c1}},	//   _inol, рэнн, יסטי_, race_
  { {0xa3e9005d,0xdb1c084a,0x2d8b5434,0xe4f9000b}},	//   याय_, derâ, sace_, ्नति_
  { {0x6e94003b,0x5e940029,0xdb1c5801,0xa3ae000b}},	//   _البا, _البط, berí, _कान_
  { {0x1f5b0008,0x38af03ba,0xdb1c59c2,0xaf5b000a}},	//   _בדוא, tür_, cerí, _בכוכ
  { {0xa3e9005d,0xa3d6021e,0x478b03ad,0x78a402b9}},	// [e610] याम_, िया_, всем_, guiv
  { {0x38af0064,0x6d3c000a,0xb5fd0085,0xad9b0125}},	//   rür_, _בתחנ, _miše, dhúi
  { {0xe71900a2,0x61e20085,0xf1b90085,0x387e0045}},	//   ديات_, _onol, liše_, _ătre_
  { {0x249d0026,0xdb36000a,0xe610002b,0xd6d80800}},	//   trwm_, _לנתח_, وشن_, шту_
  { {0xf1b9016f,0xe4c80015,0xd9440b1e,0xa43d0033}},	//   niše_, لبون_, _меџи, нькi
  { {0x66fc0024,0x61e200e7,0x3c78000a,0x3f8c0085}},	//   _sākš, _anol, סתום_, jadu_
  { {0x76420064,0xe7300029,0xeb98000a,0xa3e9000b}},	//   bloy, _قصف_, בדור_, याब_
  { {0x1634034e,0x8189002b,0x008515d5,0xdb0e0030}},	//   _деся, اچاق_, блио, ékér
  { {0x03c70080,0xc1050015,0x66fc003d,0x3f8c0034}},	//   _всем, صودي, _vākš, fadu_
  { {0x63ad016f,0x600604ab,0xf1b90085,0x61e210ac}},	//   đans, йным_, diše_, _enol
  { {0x3f870152,0xdb1c396d,0x25d5000a,0xc7b2004f}},	//   _venu_, terí, ֖וֹן_, הבי_
  { {0x644301d1,0x2d9e00b8,0x83fc59c3,0x41ae000b}},	//   llni, ßte_, _viđe, _टायस
  { {0xa3ae014e,0x4427002d,0x3f870152,0x69c459c4}},	//   _काम_, onn_, _tenu_, veie
  { {0x2d9e4cfb,0x7f850015,0xdc19002a,0xdb1c19b8}},	//   şte_, _الثن, _kłęb, serí
  { {0xdb1c001c,0x69c400b8,0x442759c5,0x1014002b}},	//   derã, teie, inn_, _ببند
  { {0xc33204dc,0x896612a2,0xbcfb0003,0xf1b900b3}},	//   פון_, скаж, rcér, biše_
  { {0xc0440092,0x986a0029,0x69c459c6,0x3ea5007c}},	// [e620] _đoạt_, احرف_, reie, lult_
  { {0x25ad0011,0x64430085,0x69c459c7,0xb5fd0073}},	//   _acel_, jlni, seie, _nišb
  { {0x3ea54d4c,0x6abe59c8,0x2bf70008,0x501a000a}},	//   nult_, _uppf, _המין_, נועו
  { {0x442700b8,0xad9b002d,0x644359c9,0x78a4008c}},	//   enn_, thúi, elni, puiv
  { {0x78a403af,0xe4d30015,0xdb1c1702,0x04b60088}},	//   quiv, كتوب, berã, ссея
  { {0x6aa10084,0x3ea54d4c,0xdb1c001c,0xdb070030}},	//   álfg, kult_, cerã, rejö
  { {0xd25000b0,0x76420493,0x3ea50293,0x3678000a}},	//   ونت_, ploy, jult_, _כְּע
  { {0x90980080,0x442759ca,0xb5fd0796,0xa07403ad}},	//   авит_, ann_, _piše, огич
  { {0xdb1c002a,0xa0670099,0xc05a00fd,0x94a90058}},	//   odró, бања_, ліо_, _نطلق_
  { {0xf1b9016f,0xb5fd016f,0xdb1c59cb,0x660259cc}},	//   više_, _više, ndró, lkok
  { {0x50d60074,0x28cf014e,0xdc19005c,0x883b000a}},	//   _گزار, _सैनि, _głęb, רתיו
  { {0xb66202e1,0xf1b90085,0x760b000a,0x660259cd}},	//   омiк, tiše_, ָּטַ, nkok
  { {0x80e50015,0x3f8c59ce,0x5cb80033,0xdddb1147}},	//   _وأهل, padu_, бляў_, lptū
  { {0xf1b9044c,0x70540015,0x205605ab,0xfe6f002b}},	//   riše_, _بنتا, _утер, بدی_
  { {0x3ea5003e,0x62550007,0x5fb70008,0xcee70001}},	//   cult_, _išor, _ההוא_, _гдје_
  { {0xddc4005c,0xdd91002b,0xf1b90796,0x26df0085}},	//   _chiń, _کوک_, piše_, _čuo_
  { {0x481904f5,0x58190033,0xe66f001a,0x443e59cf}},	// [e630] ажаю_, ажаў_, ðaþý, _okt_
  { {0x5f780008,0x0c780015,0x201e59d0,0xd014000a}},	//   שָּׂ, _اصيب_, niti_, קַּח_
  { {0xd6db0139,0xb87b07dd,0xd6ab0015,0xa3e20065}},	//   ыта_, _oríg, طدام_, धाई_
  { {0xa9c70086,0x7bd50012,0x7bc719e7,0x94790249}},	//   _ازدو, ldzu, leju, аску_
  { {0x7ae00024,0xd49b0175,0x2bde000b,0x64a5005e}},	//   āmte, уре_, माचा, іака
  { {0x87070010,0xc7c7085d,0x3a2900dc,0xd75b002b}},	//   _лябе, _усми, lnap_, _مجزا_
  { {0xdb070020,0x201e59d1,0x4bfc004c,0xf1da000b}},	//   pejõ, diti_, רלוס, _मोहन
  { {0x201e0cdd,0x1dd9000b,0x409521e9,0xe1f921e9}},	//   eiti_, _बोलत, орот, рги_
  { {0x201e000c,0x64430057,0xa3e9000b,0x14740015}},	//   fiti_, plni, याद_, _فالج
  { {0x3ea51091,0x6609002e,0x70520040,0xb0680040}},	//   tult_, _hlek, ونيا, حصيل_
  { {0xa3d6000b,0x93940015,0x3a2902de,0x6d48002a}},	//   ियर_, _رجلا, knap_, ędam
  { {0xb87b002c,0xdb1c00b8,0xd5b2000a,0xc6920643}},	//   _kríd, rdrü, ֽׁם_, ואט_
  { {0xdb1c59d2,0x3ea559d3,0x201e59d4,0x7e78007c}},	//   sdrü, sult_, biti_, _etvp
  { {0xbddb0152,0x201e59d5,0x8c560015,0xa156000a}},	//   llèl, citi_, تئجا, _ובנה_
  { {0x66090005,0x60080008,0xdb1c00dc,0x8c4318ba}},	//   _olek, _לִקְ, ferá, фере
  { {0x4a460010,0xf2d2000f,0xaa030015,0xceb2000f}},	//   інав, ועל_, وِّي, _חיה_
  { {0x2bb2005d,0x7afa02dc,0xeb9a0117,0x0000006a}},	// [e640] _जापा, ättb, _кип_,
  { {0x7f8c0053,0xba760021,0x7e64008c,0x39420091}},	//   ָנאַ, _واجت, _hiip, _vyks_
  { {0x660200f2,0x8f9a000a,0x6676002b,0xdb24002b}},	//   tkok, שיעי, زدار, _روحی
  { {0xdb1c02c1,0x201e01a3,0x850600c3,0x7c3c3057}},	//   cerá, ziti_, يوان, lorr
  { {0xa3d6000b,0x443e002a,0xf98300fd,0xf53f01f0}},	//   ियल_, _pkt_, _ігро, _øål_
  { {0x38b404d4,0x2ccb000a,0x2be3000b,0x8463006b}},	//   mär_, שֶׁ֑, खाएं_, мъще
  { {0x78b600f2,0x38b404d4,0x201e59d6,0x66090218}},	//   ltyv, lär_, viti_, _flek
  { {0xa1860010,0x7e640020,0x11ea0029,0x75350030}},	//   цыкл, _niip, شعبي_, égzé
  { {0x60f7008f,0x201e052c,0x7c3c59d7,0x290059d8}},	//   жныя_, titi_, korr, nyia_
  { {0x6e2d0111,0xdb1c04af,0xdfd00115,0x1f140033}},	//   _sjab, zerá, ريج_, змоў
  { {0xf7730008,0x443c12d7,0xc7d70135,0x7bc70091}},	//   וקת_, mov_, קוטי_, veju
  { {0x78b600df,0xae16005d,0xb2a50015,0x443c59d9}},	//   ktyv, दोलन_, _رحمه, lov_
  { {0x3cf7005d,0x98b30024,0x32170067,0x7c3c59da}},	//   ुनें_, ādīs_, _بيند_, forr
  { {0xc0460031,0x443c59db,0x7c3c59dc,0x0000006a}},	//   _بخصو, nov_, gorr,
  { {0x298b0001,0x7bd52af0,0x2bca000b,0xf1b90085}},	//   исао_, rdzu, ाज़ा, liša_
  { {0x38b400c0,0xee770015,0xda27005e,0x7bc759dd}},	//   fär_, _بصوت_, ієво, seju
  { {0x7c3c08e0,0x27f8003e,0xa3bc005d,0x38b400c0}},	// [e650] borr, _born_, ेजा_, gär_
  { {0x443c002c,0x69d60035,0x27f80541,0x907b000a}},	//   jov_, adye, _corn_, יטמי
  { {0xa3ae005d,0xa3e9005d,0x3c3b0089,0xcdd50008}},	//   कलन_, यास_, rávě_, ּךְ_
  { {0xbb3a0008,0x38b400c0,0xe9df0092,0x35f80086}},	//   _לעתי, bär_, _chút_, يرند_
  { {0xd1260029,0xfe380008,0xf976000a,0x3cde000b}},	//   _أم_, חראי_, _מגרש_, खिये_
  { {0x97c70029,0x78fa000a,0x443c1058,0x0000006a}},	//   _بتحم, _הפשו, gov_,
  { {0xa3bc005d,0x21f10046,0xe62b0054,0xad9b001a}},	//   ेज़_, _záhy_, _кôд_, nhús
  { {0xddc40011,0x7ae1008c,0x32d40033,0x64b70015}},	//   _munţ, älty, ьціс, _وحذر
  { {0x7e6400f2,0xd24e00e6,0x443c59de,0xdce4003d}},	//   _riip, دني_, bov_, _meiģ
  { {0x443c2bc6,0xf8b2000a,0x60090175,0x142b0033}},	//   cov_, עשי_, сном_, _тібо_
  { {0x2615002c,0xcf8e0086,0xee3a0de5,0xddc40045}},	//   sťou_, اژه_, йно_, _nunţ
  { {0xd12e0074,0xbddb038d,0xb2ba0008,0x0dba0029}},	//   ئمی_, blèm, _למער, حادث_
  { {0xeb04005d,0xdc750033,0x7e6459df,0x7c3c59e0}},	//   रन्त_, дысь, _viip, torr
  { {0xc1040086,0xa088000a,0xda660015,0x38b40123}},	//   _توهي, _וְקִ, كاري, vär_
  { {0x63bc01e2,0x09e60191,0x60c20089,0x0f7a000a}},	//   _örne, повн, _zpom, _פרקל
  { {0x78b6022d,0xe9da0001,0x443c12d7,0x7e9a000a}},	//   ttyv, љка_, zov_, _הסקו
  { {0x7c3c23b8,0x644159e1,0x38c8002b,0x07a60920}},	// [e660] porr, _okli, غاری_, зазн
  { {0x9d1b0135,0x1cb7000a,0x20050061,0x78b6008c}},	//   _לופט, _צליל_, nkli_, rtyv
  { {0xe9df0092,0x78b600f2,0xabfb009d,0x443c0cca}},	//   _phút_, styv, _הפיז, vov_
  { {0x27f8003e,0x2bca000b,0x7e9a000a,0xa2a2000b}},	//   _worn_, ाजवा, מסעו, _गिब्
  { {0xd4e30080,0x443c59e2,0x6f010034,0x27f82f36}},	//   еющи, tov_, hylc, _torn_
  { {0x74690036,0x74140015,0x33f60a32,0xb5fd0b28}},	//   ірів_, بوتا, ячес, _viša
  { {0x05bb005d,0x443c22b0,0xfbd3000a,0x60c205fb}},	//   ोजशब, rov_, גתו_, _spom
  { {0x443c12d7,0xb5fd00bc,0x30a60840,0x61f959e3}},	//   sov_, _hišn, пров, _cowl
  { {0x443c12d7,0xe1ef0015,0xb5fd0085,0xa0670099}},	//   pov_, اسى_, _kišn, пања_
  { {0xdcef0024,0xdb1e02c1,0xc917000a,0xe018005e}},	//   sacī, _japó, פחית_, іжні_
  { {0x6f010176,0xa3e9005d,0xe37b000a,0xde59005e}},	//   gylc, यार_, _הרבר, жані_
  { {0x4c95004a,0xac990067,0x3f83001a,0x644120c0}},	//   мимс, ينجا_, ðjur_, _zkli
  { {0x6e3d00dc,0xc05a0033,0x463b004c,0x60c208c1}},	//   rosb, _лік_, מעטע, _upom
  { {0x515b0008,0xa09b000a,0x909b039e,0x95f9000b}},	//   _הכדו, _פיוט, _פסוק, _ऍक्ट_
  { {0x76590026,0xdb23002b,0x78a459e4,0x6e3d00aa}},	//   ymwy, روری, eriv, posb
  { {0x7afa00c0,0x25a0002d,0x7ed30015,0x6e4402d9}},	//   ätta, óill_, _أزوا, _пејз
  { {0xb87b002d,0xd8790015,0x394f0123,0x693415d2}},	// [e670] _sríb, زمات_, ågs_, енту
  { {0x6d410064,0xb87b002c,0xf7700225,0x2be3005d}},	//   ğlad, _príb, هام_, खाओं_
  { {0x59f90063,0x6d410064,0xc5d50036,0xdb1c00b8}},	//   _деня_, şlad, діль, gerä
  { {0x60db00df,0xceb80091,0xab280b1e,0x644159e5}},	//   yvum, itę_, _хоџа_, _skli
  { {0x99f60008,0x76590026,0x98740010,0xa3e9005d}},	//   _חזרה_, rmwy, _пляц, याल_
  { {0xb4ad005d,0x03a50001,0x1d0c000a,0xdb1c0123}},	//   _कमी_, фико, מּוּ, berä
  { {0xa3ae005d,0x52b20029,0x626300dc,0xdb9c000a}},	//   _कार_, نموذ, _főol, מסגר
  { {0x35f50010,0x35d40080,0x60db0020,0xdb1c016e}},	//   _ўпар, _посё, tvum, serç
  { {0x9f5e002d,0xceb82aad,0x1634006b,0x0f05000b}},	//   chtú_, etę_, _четя, शन्स_
  { {0x20190029,0x14190015,0x64410046,0x20050091}},	//   تتبع_, _بيئة_, _ukli, ukli_
  { {0x60c40024,0x82870015,0x2127002b,0x60db007c}},	//   _ģime, _رجال, تيکی_, svum
  { {0x200559e6,0x9f640046,0x333a004f,0x0000006a}},	//   skli_, ítám_, _ותעמ,
  { {0x6ff50029,0xceb8002a,0xdb0e0123,0x8596004f}},	//   _يستط, atę_, nebö, ודרג_
  { {0xdff5005e,0x515a004f,0x0000006a,0x0000006a}},	//   _іяль, _וכנו,   ,
  { {0x3f850011,0xc052000a,0xbb43009f,0xce3a0058}},	//   mblu_, _שזו_, верк, _وأبا_
  { {0xa3e9014e,0x78a404f9,0xc332013a,0x8d760015}},	//   याँ_, triv, דול_, _غابا
  { {0x7c950010,0xa3ae005d,0x78660484,0xf1b2000a}},	// [e680] _прэц, _काल_, дказ, כסן_
  { {0x07a3005f,0x1c43004a,0xa3dc000b,0xabaa0058}},	//   каун, _иным, _तों_, _بهدم_
  { {0xf986000d,0x78a401a0,0xb87b006f,0xf1ae000b}},	//   _огно, sriv, _príc, _टालन
  { {0xeef60053,0xbef60008,0x68e90046,0x78a459e7}},	//   ומער_, וצעו_, _šede, priv
  { {0xa3e9005d,0xd78a0015,0xceb8002a,0xf993004f}},	//   यां_, _ونحو_, ztę_, _ברר_
  { {0xdb1c022d,0xcc3b0053,0xceb81e7f,0xdc89004f}},	//   perä, ֿעקט, ytę_, פְנָ
  { {0xb87b59e8,0x3f8e003f,0x07a300d7,0x2bc0000b}},	//   _tríc, _refu_, _јасн, श्या
  { {0x92570015,0x471b000a,0x60f8006b,0x7c2e0012}},	//   وشير_, _וולג, зния_, hnbr
  { {0xb5fd044c,0xe5060015,0xfa1c0016,0x9655006b}},	//   _mišl, _غبري, _đất_, _чърч
  { {0xf9570008,0x34fb0008,0x33f60010,0xa4fb000a}},	//   וספת_, _והמד, _ўчас, _ולמט
  { {0xad9b006f,0xa2d30015,0x80d3000b,0xe29700e2}},	//   skúm, _ليلت, _बैठे, _жах_
  { {0xfc3f0467,0xceb810da,0x644a59e9,0x7bd759ea}},	//   dría_, rtę_, llfi, _saxu
  { {0x7afa01d1,0xceb81501,0x1169002b,0xfc3f0077}},	//   ättn, stę_, _علوی_, ería_
  { {0xce940063,0xceb8002a,0x2f18004a,0xfc3f0077}},	//   _закъ, ptę_, _ноль_, fría_
  { {0x27ed0092,0xaa590001,0x629838f5,0xfc3f0077}},	//   _đen_, зиву_, nsvo, gría_
  { {0x992b004a,0xdb0e0046,0x7c2e03f8,0x5e9b004f}},	//   оюза_, ékár, anbr, _ובהק
  { {0xdb0500b8,0xa3ae021e,0x0855004a,0x2a64006b}},	// [e690] _schä, कला_, еваю, търг
  { {0xfc3f02c1,0x644a0134,0xdd0d005c,0xad38000a}},	//   bría_, jlfi, półr, _קנזס_
  { {0x23d9014e,0x19950010,0xcc56000a,0xc72b005e}},	//   _योगद, _паня, _רבתי_, ціал_
  { {0x78a228cc,0x4974006b,0x2f5b004c,0xf1b90091}},	//   šova, _илюс, קדאנ, višo_
  { {0x629a018c,0x09e40010,0x43750036,0xcc34002b}},	//   _avto, _роўн, нуйт, _سریع
  { {0xdb1c59eb,0xb4640036,0xdb150030,0x3eac01d0}},	//   rdrö, вкіл, kezü, kudt_
  { {0x4429016f,0x78ad00f2,0xd3d80058,0xf3f100a1}},	//   đa_, luav, ببنا_, _dịp_
  { {0xa4d5005e,0x69cd007c,0x64460091,0x1dc1000b}},	//   _побі, neae, _ūkit, ष्मत
  { {0x84350036,0xb2460086,0x9f47002d,0xa0c500c3}},	//   _знає, ریهٔ_, _inné_, ريدو
  { {0x69cd0020,0x764b0034,0x0ea9004a,0xc2eb0058}},	//   heae, llgy, пкой_, _وعام_
  { {0x9980002c,0xb659000a,0x12b40015,0x8659000a}},	//   lniť_, ּדָש, _لإنج, ּדָי
  { {0x66190064,0x26b6000a,0xc3280015,0x78ad007c}},	//   _çakı, עִים_, _تكمن_, kuav
  { {0x61eb03b8,0x764b0034,0x8fa51e84,0xd196000a}},	//   _ingl, ilgy, _зале, _נכסי_
  { {0x6b9500dc,0xfc3f0077,0xddcd002a,0x29dc0016}},	//   gazg, tría_, _chał, _ửa_
  { {0xca560001,0xcf92000a,0xde88002b,0x2fd60015}},	//   етањ, _גטו_, _قضيه_, _سويد_
  { {0x2bb2005d,0x69cd0020,0xfc3f0077,0x76580091}},	//   _जावा, geae, rría_, įvyk
  { {0x9980002c,0xc212004c,0xf8aa0033,0x656d006f}},	// [e6a0] jniť_, אהן_, явак_, ľahl
  { {0x7d06022d,0x9980006f,0x4cbb000a,0x1dc1000b}},	//   myks, dniť_, _צמיג, ष्ठत
  { {0xa3e9005d,0x39ea06ac,0x44f60086,0x70bd005d}},	//   याई_, _едно_, کساز, ्बुल
  { {0xceb200a3,0x186a03e7,0x7bce595b,0xda7b004f}},	//   ריא_, _нами_, lebu, _מנטר
  { {0xc4f70015,0xa507006b,0x7bdc06f2,0xb87b01a8}},	//   فعوا_, неца_, odru, _tría
  { {0x7bdc00df,0x6e260298,0x9989005c,0x229a0024}},	//   ndru, hikb, chał_, tīk_
  { {0x53340080,0x7d0600f2,0x02a30010,0xdb070030}},	//   ъект, hyks, грым, ogjá
  { {0x20bd005d,0x7bce00b8,0xb6bb000f,0xd25704ab}},	//   ्बंध, hebu, _מצלי, нцы_
  { {0xe3b20086,0x7bce3d7a,0xf993000a,0x62830046}},	//   _مرا_, kebu, ארח_, apno
  { {0xd91b015b,0x4ab2000b,0x61eb2b1d,0xcf9a03ae}},	//   פויל, ुझाव, _engl, чји_
  { {0x50b7002b,0x9f34005e,0x60c70045,0xd36f0021}},	//   ودید_, тені, ăjma, _اهم_
  { {0x12eb000a,0x3eac02de,0xd337004f,0xadeb0065}},	//   _מַדּ, rudt_, _ארבה_, टाइन_
  { {0xdb1c002c,0x81fb000a,0xc8cf000b,0x621b000a}},	//   zdrô, _מהאז, _सैंट, _צודק
  { {0x7bce00b8,0x41530033,0x6fb40015,0xc05a02ed}},	//   gebu, _свіс, _شمبا, _эрец_
  { {0xc9870001,0x8ff70018,0x61eb1862,0x9980002c}},	//   еузи, _سرور_, _yngl, zniť_
  { {0x7bdc59ec,0x7bce007c,0x5e590015,0x78ad0f85}},	//   adru, aebu, _تلبس_, tuav
  { {0x97a70036,0x9c390063,0x7bce0007,0xc7d9004a}},	// [e6b0] ерел, _опит_, bebu, ммах_
  { {0xc02e0016,0x7bce0dd4,0xdb070030,0x628350dd}},	//   _điệu_, cebu, agjá, ypno
  { {0xcf9300b2,0x8c1c011f,0x2d92003f,0x224600dc}},	//   רטע_, _מוזי, _yeye_, _okok_
  { {0xa6470086,0x9980002c,0x4a9a0135,0xdb07001a}},	//   رخان, tniť_, _קירג, sfjó
  { {0x33d5005e,0x78ad01e0,0x0000006a,0x0000006a}},	//   війт, quav,   ,
  { {0x9980002c,0x24180033,0xb5fd0091,0x8365002b}},	//   rniť_, ночы_, _kišk, نگال
  { {0x939400a2,0x52a9005e,0x9980006f,0x07090015}},	//   اجها, євим_, sniť_, _غيري_
  { {0x7bce005c,0x9980002c,0xa2a2000b,0x6612002b}},	//   zebu, pniť_, _गिर्, _پژما
  { {0x0ee9000b,0x682b002a,0x7bdc3ded,0x27210157}},	//   टम्स_, ażde, ydru, _मधुर_
  { {0xa2a9005d,0x95540029,0x7d060007,0x2ecc000b}},	//   _टिप्, _إخفا, vyks, ़बूत
  { {0xc2c403c4,0xdcfd0024,0x442759ed,0xf772000f}},	//   _ميلي, kasē, min_, יקי_
  { {0x7d06022d,0x61eb59ee,0x442759ef,0xdb240030}},	//   tyks, _ungl, lin_, árít
  { {0x64430005,0xed570191,0x5184008f,0xb5fd0007}},	//   ooni, кою_, _суха, _aišk
  { {0x442759f0,0xd116000a,0xfaa60033,0xaec50033}},	//   nin_, _בקנה_, каго, _абкл
  { {0xae1f005d,0xb5fd00bd,0x7d0600f2,0x44270044}},	//   मोहन_, _višj, syks, iin_
  { {0x442759f1,0x7bdc00b8,0xb87b002d,0x7bce0375}},	//   hin_, sdru, _crío, sebu
  { {0x87ba004a,0xc966006b,0x644305fb,0x6e2400aa}},	// [e6c0] дует_, твай, koni, _imib
  { {0xb87b59f2,0x6b680030,0x644359f3,0x17790033}},	//   _trín, _cégü, joni, есць_
  { {0xd6cf0015,0xa3d5000b,0xdb9b000a,0x0a5a0015}},	//   يقك_, िजन_, _קסטר, _يشجع_
  { {0x442759f4,0x95c70033,0x225f01c2,0xb87b0125}},	//   ein_, вуша_, jmuk_, _grío
  { {0xcd770053,0x442759f5,0x644359f6,0xe4d30058}},	//   דענק_, fin_, foni, لتوب
  { {0x9d1b013a,0xe1f90007,0xc4480086,0x2a600020}},	//   וונט, ejų_, ریان_, lmib_
  { {0xb4170015,0x92b30015,0xd7f90033,0x25aa0015}},	//   ضغوط_, لحيا, _чуў_, _يدري_
  { {0xc4c60015,0x75d60015,0x442759f7,0xbb3b004f}},	//   _لتطو, _جيرا, ain_, ועצי
  { {0xdfd0003b,0x3d0c005d,0xe3ba111b,0x644359f8}},	//   مية_, हनों_, _оба_, boni
  { {0xbddb0003,0x6e240030,0xe286153d,0x442759f9}},	//   hlèt, _amib, _алжи, cin_
  { {0xdef7008f,0x64480048,0x645a01e2,0xdd950033}},	//   выя_, _ikdi, _ihti, ланы
  { {0xa2060004,0xd3780085,0xa3bc0065,0x1df902ed}},	//   _шпед, _daće_, ेजक_, хемы_
  { {0xf1b30008,0x1e340033,0x624503a0,0x0000006a}},	//   _כסף_, рняў, póor,
  { {0xb5fd00bd,0x69c60012,0x2bc80004,0xd01000c3}},	//   _pišk, _abke, кусо_, _دلت_
  { {0xb87b002f,0xdb2301e2,0x9ee80015,0xbddb0003}},	//   _prío, _ürün, _أفعل_, flèt
  { {0x442701e2,0x9f5c0156,0xd337000a,0x644359fa}},	//   zin_, _nové_, דרלה_, zoni
  { {0x99554e8c,0x4427376d,0xb9550063,0xce38000a}},	// [e6d0] укац, yin_, уващ, _שאחת_
  { {0x1b4b0029,0x2d990deb,0x442759fb,0xb5fd0091}},	//   _يؤدي_, lase_, xin_, _tišk
  { {0x6b6800dc,0xb87b002d,0x2b29002b,0x2d990045}},	//   _végü, _trío, _سغدی_, oase_
  { {0x442759fc,0xe3b80061,0x644359fd,0x645a59fe}},	//   win_, _acı_, woni, _ahti
  { {0x2bc0005d,0x94750086,0xae1c0053,0x442759ff}},	//   श्वा, اگرا, וואכ, tin_
  { {0x44270df4,0x54680033,0xa44401f3,0x69dd5a00}},	//   uin_, ваім_, анід, _hase
  { {0x44275a01,0xc7b2000a,0x64435a02,0x56940033}},	//   rin_, _לבם_, roni, _васт
  { {0x442744cc,0x64434aeb,0x645a01be,0xe0d9011a}},	//   sin_, soni, _ehti, еви_
  { {0xa5350080,0x224d4740,0x44275a03,0x7bc8007c}},	//   _снач, rlek_, pin_, õduk
  { {0xbf0e005d,0x14ca002b,0x9f850174,0x224d3032}},	//   ानून_, _سهمی_, ыгод, slek_
  { {0x765b0023,0xa347008f,0xddc40011,0x224d00dd}},	//   _khuy, _рэал, _chiş, plek_
  { {0x6d4101e2,0xb87b002c,0x69dd5a04,0x7c25130f}},	//   ğlan, _príl, _nase, _amhr
  { {0x6d4101e2,0x249d0026,0x645a00f2,0x61fb003f}},	//   şlan, nswm_, _yhti, mjul
  { {0x9ad6008f,0xa09a000a,0xb87b0077,0x0468000a}},	//   любі, _טינט, _crím, ֛יךָ_
  { {0x2d995a05,0xa4ef000b,0x69dd4c92,0x99800045}},	//   base_, चमुच_, _base, ghiş_
  { {0xceb2013a,0x61fb0084,0x7e6d04ed,0xa3e5000b}},	//   _היה_, njul, _giap, _बोस_
  { {0x6222004c,0x69dd0eb3,0x09290015,0xfce61e2e}},	// [e6e0] גנאָר, _dase, نسكي_, _сопо
  { {0x93bc0011,0x9d1b0053,0xd7f9005e,0xad1b000a}},	//   _amăn, _נויט, кує_, _נויר
  { {0x07b70029,0x2ca002de,0xfbd3000a,0x55e60719}},	//   اهمة_, _hvid_, _התת_, ложб
  { {0x765b00a7,0x44250026,0x7e7e00dc,0x249d0026}},	//   _chuy, _aml_, _éppe, fswm_
  { {0xa4260c6e,0x98a70045,0x7bde5a06,0x80d30065}},	//   лькл, ănă_, _kapu, _बैले
  { {0x69dd1422,0x98160015,0x9cd7000a,0x69c40bbc}},	//   _zase, _إبحا, טונה_, lfie
  { {0x0cb1005d,0x68e45a07,0xa3e9000b,0x026a005e}},	//   _जम्म, lvid, याज_, нший_
  { {0x68e45a08,0xcb13000a,0x44255a09,0x320d36c3}},	//   ovid, מלו_, _eml_, gkey_
  { {0x13b60086,0xd1300015,0x93b60015,0x7e6d02b9}},	//   _مصاح, تمة_, _محاض, _riap
  { {0x6aa10084,0xd0730029,0x7bde5a0a,0x7e6d013c}},	//   álfk, حديث, _napu, _siap
  { {0x630600e6,0x68e421fa,0xe7c6000b,0xbe19005e}},	//   _حوال, hvid, र्यप, вжнє_
  { {0x90e603c4,0xb5fd0844,0x320d0376,0x68e45a0b}},	//   _مستن, _piši, ckey_, kvid
  { {0x7bde0026,0x69dd5a0c,0xb87b0428,0x6f1a0030}},	//   _bapu, _rase, _prím, sztc
  { {0x8f760036,0x3ed40029,0xb5fd0796,0x68e45a0d}},	//   _суді, _نقتر, _viši, dvid
  { {0xff7b0008,0x3a29013c,0x7bde0375,0x6016016e}},	//   _אטומ, tiap_, _dapu, _câme
  { {0x8e830029,0xfb340033,0xb5fd1129,0x59df0065}},	//   _اليه, ёнтэ, _tiši, _पोखर
  { {0x290f0097,0x37ab017a,0x69dd5a0e,0x4877002b}},	// [e6f0] ága_, етен_, _vase, ادرس
  { {0x3eac0298,0x69dd003f,0x7649002e,0xf1b902c6}},	//   ordt_, _wase, _skey, riši_
  { {0x69dd1b97,0xd6d10067,0x4b7a000a,0xa3ae000b}},	//   _tase, تقا_, _באתו, _काज_
  { {0xc64b0029,0xd6d804f7,0x7bde10a4,0x7c20003d}},	//   رجال_, ыту_, _zapu, īmre
  { {0xe5780036,0x2ed1005d,0xae1c0008,0x798d30e7}},	//   узі_, _तन्त, עודכ, mbaw
  { {0x2329059c,0xf3e50142,0xad9b006f,0xe2851e2e}},	//   коли_, ржко, okús, алки
  { {0x765b0023,0x41b50029,0x3dc9002a,0xdced003d}},	//   _thuy, لمغر, _obaw_, _adaļ
  { {0xa490002b,0x0205058f,0x212b016e,0x7afa0d8f}},	//   _کیوت, рзин, úcho_, ätti
  { {0x320d003e,0x36040015,0x4425003d,0xdff501b0}},	//   rkey_, _اوقف, _tml_, аянь
  { {0xb87b002c,0x60090164,0x6006004a,0x8fa50004}},	//   _príj, тном_, иным_, јане
  { {0x68e407c4,0x26c10573,0xfe710015,0x9ea9006b}},	//   zvid, ntho_, غدد_, ъвна_
  { {0x12fa000a,0x6016016e,0x39a20030,0x3e330015}},	//   _בהעב, _câmb, _késő_, ْفَر
  { {0x25d6000a,0x7bde5a0f,0xdced003d,0x629e0247}},	//   בורן_, _papu, _reaģ, ápov
  { {0xa1360053,0x711a000a,0x68e402b9,0x78ad5a10}},	//   _דאנק_, _בונפ, vvid, drav
  { {0x69960063,0x1996009c,0xb87b001a,0x6b6615f1}},	//   ирах, ијар, _frík, рква
  { {0xdb1c5a11,0x798d0035,0xada6004a,0x4acb000b}},	//   cerý, gbaw, _таил, ाबजव
  { {0x48e30080,0x2ca00085,0x58260033,0x6e3d0030}},	// [e700] оотв, _uvid_, амаб, érbe
  { {0x69c40b00,0xa3e5000b,0x4c9b0447,0x8d5b000a}},	//   sfie, _बोल_, _ששיע, _בכפי
  { {0xcb6a0004,0x69c40012,0xf1b90085,0x8b8b000a}},	//   _јане_, pfie, lišu_, _בָכֶ
  { {0x3eb9005c,0x78ad5a12,0x6b9c14dc,0x1a9b004c}},	//   ństw_, brav, larg, _ביטע
  { {0x78ad001c,0x5d7b004c,0xf1b90085,0x0000006a}},	//   crav, דאנק, nišu_,
  { {0x66e6010f,0xdb1c0014,0x7d570053,0xd91b0008}},	//   _кога, kerü, בינד_, _יוכל
  { {0xdb07002e,0x32b70015,0xdb1c002a,0xa3d5000b}},	//   sfjö, لدية_, meró, िज़_
  { {0x41e6005e,0x6aa1001a,0xbebc003d,0xe7370fea}},	//   ріка, álfi, lzīg, _тес_
  { {0x6b9c0ad5,0x33d60033,0xc05a00fd,0x0000006a}},	//   karg, _віет, кіо_,
  { {0xdb1c005c,0x23890089,0x798d005c,0x60160045}},	//   neró, čují_, zbaw, _sâmb
  { {0x6d4101e2,0x08570008,0xb87b002c,0xa8570008}},	//   ğlam, שבים_, _prík, שייה_
  { {0x3ce9018c,0x6d4101e2,0xd2520015,0x78ad0091}},	//   _prav_, şlam, _بنص_, yrav
  { {0x6b9c003c,0xc5f3039e,0xfbd300e6,0xec150015}},	//   farg, קדש_, يتس_, موحد
  { {0x26c10176,0x7f840029,0xeafb0086,0xab940036}},	//   ytho_, _الغن, پرست_, жирі
  { {0xda78010f,0xbebc0048,0x905b000a,0xb5fd0091}},	//   ият_, dzīg, _שכות, _kišt
  { {0x9dab0063,0xf9930015,0x4a550033,0x4efb000a}},	//   _ръка_, تبس_, ёкас, _יהוו
  { {0x6b9c0467,0x32d80092,0x718b000a,0xdb1c08f8}},	// [e710] barg, _lũy_, דְבַ, feró
  { {0xb5fd28cc,0x6b9c0896,0x8c240015,0x798d01d7}},	//   _lišt, carg, _وفيه, sbaw
  { {0x8ae40191,0xdc3c0008,0x7bd52015,0x78ad5a13}},	//   _діял, _בעזר, mezu, srav
  { {0xb5fd016f,0xcad6000a,0x95c5006e,0x78ad5a14}},	//   _ništ, _פורת_, صيته, prav
  { {0x8b670086,0xdb1c00dc,0x0574002b,0x98ab003d}},	//   _حاکم, zerü, زاند, īmēt_
  { {0xe3b8005e,0xdb1c5a15,0x7bd557f6,0x0cd8000a}},	//   ибі_, ceró, nezu, שֵׁר_
  { {0xd2980010,0x07340342,0xc3d40033,0xe4f3000b}},	//   атыі_, _дерю, іўшы, _आपकि_
  { {0x20190024,0x91d50010,0xcb38000a,0x7bd53bbc}},	//   īsim_, сцкі, ינוק_, hezu
  { {0xa9fa000a,0x2127002b,0x7bca001a,0x6b9c0061}},	//   אִית, شيدی_, _öfug, yarg
  { {0x04590029,0x2003002e,0xaffe0016,0x73d5000a}},	//   _صلاة_, ðji_, _phướ, _לֵ֣ב_
  { {0x5f45003b,0x2eb6000b,0x6b9c5a16,0x66f90065}},	//   إنجل, _अमृत, varg, ूहिक_
  { {0xd5b2000a,0xe9df0016,0x6b9c0cc1,0xdb1c002a}},	//   ּׁם_, _thúy_, warg, zeró
  { {0x3085003b,0xafe5007a,0x20850015,0x6b9c5a17}},	//   _التف, _голл, _التّ, targ
  { {0x3f790053,0xaffe0092,0x1c390080,0xf1b90085}},	//   _גאַס, _thướ, аясь_, rišu_
  { {0xe456004c,0x2ef80012,0xad9b001a,0x6b9c5a18}},	//   מישט_, ärft_, rkúr, rarg
  { {0xb87b0107,0x6b9c5a19,0x4d16006b,0xdb1c002a}},	//   _osíd, sarg, _гьот, weró
  { {0xdb1c5a1a,0xd884002b,0xe9d70054,0x7bd509b9}},	// [e720] teró, زهای, љку_, bezu
  { {0x3cfb0008,0xca290053,0x46f6006b,0xf7461079}},	//   _עלינ, ײם_, йчет, безо
  { {0x20560053,0x8f9a000a,0x3b0a5a1b,0x0000006a}},	//   ציעל_, ריעי, _сено_,
  { {0xceb200b2,0xc869000a,0x98f60033,0xd5b9005e}},	//   ליב_, גן_, _лягч, исі_
  { {0x6aa10084,0x69d601e2,0xdb1c002a,0xdb050003}},	//   álfv, meye, peró, _adhè
  { {0x69d601e2,0xa5070124,0x04430484,0xdc89000a}},	//   leye, сеља_, печн, בְקָ
  { {0x3f98002e,0xfbd3000a,0x8cda000b,0xa6f8000a}},	//   ðrum_, פתה_, _पैसो, _דִּי
  { {0x69d64f28,0xd737000a,0xc173006b,0xf1b9003d}},	//   neye, _הטלת_, плъщ, dišs_
  { {0xdb0500b8,0x24f60054,0x99800091,0x82330015}},	//   _schü, _учвр, lnių_, ثروا
  { {0xa2080064,0xc6940053,0x3f9813d8,0xff980054}},	//   ılış_, ֿאָ_, úru_, шкој_
  { {0xdb1c0084,0x6016001c,0x7bd5116e,0x57fb0008}},	//   lfræ, _câma, vezu, אליו
  { {0x442e3f14,0xb1e50015,0x6d5a002a,0x5757004c}},	//   lif_, _وأنه, ętan, מביע_
  { {0x644a00aa,0x69d6068c,0x7bd51036,0x7c2e5a1c}},	//   oofi, deye, tezu, fibr
  { {0x4e930074,0xdcfd0048,0xf537000a,0x60d7000a}},	//   _کشور, lasī, מרכז_, _לודא_
  { {0x0057000a,0x3f9e5a1d,0xb5fd0091,0x8025002b}},	//   _השגת_, matu_, _mišr, _برنم
  { {0x3f9e016f,0x442e0026,0xc211000a,0x20c2001a}},	//   latu_, hif_, ֵ֔ן_, oði_
  { {0x61e2002d,0x779910a6,0x63a8001a,0x644a5a1e}},	// [e730] _maol, икар_, _oddn, kofi
  { {0x20c2002e,0xf7730021,0x9989006f,0x61e219e7}},	//   iði_, ساط_, dnať_, _laol
  { {0xb6d50021,0xaa590888,0x7ac70cab,0x644a5a1f}},	//   تقاع, _вину_, _успе, dofi
  { {0x6aa1002e,0xdebb01ac,0xeb05000b,0xef11000a}},	//   álfu, רמאל, रहीत_, וּד_
  { {0x3f9e45a5,0x78930086,0xdb1c002e,0x442e0064}},	//   katu_, _ریاض, gfræ, fif_
  { {0x644a0026,0xdb050152,0xd7fb5a20,0xd4690180}},	//   gofi, _adhé, _сум_, шиле_
  { {0xdc3800b2,0x61e2002d,0xe4500115,0x28dd000b}},	//   זאגט_, _baol, رضه_, _नैति
  { {0x20c2002e,0x80a95a21,0x70851079,0xc8b7004f}},	//   fði_, авив_, огиз, ֶּ֖ה_
  { {0x20c20084,0x349407f2,0xe7c6000b,0x629e013f}},	//   gði_, _натр, र्वप, ápor
  { {0xbebc0048,0xc2c50015,0xa2ab000b,0x602501f3}},	//   dzīb, _ويذي, ींद्, ідна
  { {0xc7b20008,0x02d90086,0x25d5000a,0xcce9000a}},	//   ובי_, _خواب_, ֗וֹן_, _שכ_
  { {0x61e2002f,0x92b40086,0x69c9000b,0xbe660015}},	//   _gaol, _رحما, _हॉली, تهجي
  { {0x8fa55a22,0x9980002a,0x9e3d01c0,0x3f9e08c6}},	//   _дале, akiś_, vrďt, batu_
  { {0xdb1c0084,0x99800091,0xaf350015,0x5d430015}},	//   ferð, ynių_, _ورثت, ذَّك
  { {0xdb1c0084,0x69d60064,0x9989002c,0x499a004a}},	//   gerð, teye, znať_, итая_
  { {0x01f90053,0xe9da00d7,0xaea80015,0xba1a0015}},	//   ספּל, јка_, _اطول_, جيرا_
  { {0xd9100086,0x3c460015,0xf9c5004a,0x99160033}},	// [e740] ریس_, _وَبِ, ящён, цьві
  { {0x9989002c,0x3b83006d,0xe7320115,0x7afa0123}},	//   vnať_, _ольг, وصا_, ätts
  { {0x764b0026,0xf1d9000b,0x200743ae,0x2bf7000a}},	//   fogy, ढ़ान, _moni_, _ומין_
  { {0x20073d78,0xdb0700cb,0x99800091,0xdb1c001a}},	//   _loni_, vgjø, rnių_, tfræ
  { {0x99800007,0x644a073c,0xbebc003d,0x626a0046}},	//   snių_, tofi, ozīc, _křov
  { {0xdb1c0084,0x8afa000a,0xb87b006f,0x61e20125}},	//   rfræ, ֹהֵי, _prív, _saol
  { {0x61e20182,0xdb1c001a,0xff470067,0x442e5a23}},	//   _paol, sfræ, _آخ_, rif_
  { {0xdb07003c,0xdd14002c,0x9f5c0264,0xd4d60033}},	//   rgjø, pĺňa, _nová_, _мізэ
  { {0xd0100029,0x2508002b,0xdcfd003d,0xd1b70015}},	//   فلة_, _ارزی_, rasī, زايا_
  { {0x20c20084,0x2018002e,0xc953000a,0x78a40209}},	//   rði_, óri_, ומח_, isiv
  { {0x61e20fb2,0x877b000a,0xb77b004c,0x9f5401f3}},	//   _taol, יאיי, יאיש, явоч
  { {0x62650029,0x9e27005e,0xdb1c001a,0x78a401be}},	//   _فانق, ієнк, verð, ksiv
  { {0x9ccb0010,0x3f9e386b,0xdce60061,0xa136002b}},	//   шына_, patu_, fakı, _براش
  { {0x68fb0251,0xa0670286,0xbebc003d,0x69ca0030}},	//   _àudi, _дача_, rzīb, őfel
  { {0x5fb7013a,0xeaf8002b,0x764b01d7,0x19950033}},	//   _והוא_, يرفت_, yogy, забя
  { {0xeab00015,0x9ef3002b,0xa9970015,0x7bda0003}},	//   ضعف_, _آسوش, تشست, ôtur
  { {0x7afa01d1,0xdd150086,0x9989002a,0x201e01be}},	// [e750] ättr, _رودخ, tkał_, ohti_
  { {0xc7f80036,0x6aa1002e,0xb8d3000b,0x998f002a}},	//   онує_, álfs, _टि_, ógł_
  { {0x7bda000a,0x87280033,0x201e007c,0x78a45a24}},	//   _הקתו, оўца_, ihti_, asiv
  { {0x94790010,0x9989002a,0x78a4008c,0xae1f000b}},	//   бску_, skał_, bsiv, मोचन_
  { {0x25a00084,0xc4db0054,0x6b600030,0xf9fa000a}},	//   ðila_, рђе_, _tágí, _ההרמ
  { {0x2a690020,0xc2c50015,0xa87a000a,0x942502bb}},	//   lmab_, كيتي, _לאשר, ямле
  { {0x6595008f,0x8c1c00f3,0x2bc00065,0xe299009b}},	//   _наву, שווי, श्टा, щай_
  { {0xb87b001a,0x4105006b,0x80bc0065,0x20070160}},	//   _frít, ззив, _शमशे, _soni_
  { {0x661b007c,0xdce60061,0x63f70058,0x88cb004f}},	//   _iluk, yakı, _وأطر, ׁמֵ֖
  { {0x66092514,0x7984005c,0xd12e0015,0x4f250c91}},	//   _hoek, zciw, امٌ_, здоб
  { {0x661b002e,0x6609099a,0x8e85042b,0xc7b2004c}},	//   _kluk, _koek, ягне, עבט_
  { {0xdd850033,0x78a4008c,0x201e014b,0x0000006a}},	//   дыёп, ysiv, ahti_,
  { {0xe0ce0036,0x317a0135,0x8d5604f7,0xdd4a0054}},	//   _яв_, _האנד, яточ, стнa_
  { {0x21580015,0xd0110015,0x20130016,0x600d001a}},	//   _بجمع_, _سلع_, _ôxi_, _púmu
  { {0xdb1c01d1,0x661b0005,0x8f9a0008,0xdce60064}},	//   kfrå, _oluk, _היצי, rakı
  { {0xddd2002a,0x2d850046,0x88861923,0x78a40ad6}},	//   łgło, ělec_, злаж, tsiv
  { {0x799d00b8,0x6aa1001a,0xdb1c0123,0xe7aa0033}},	// [e760] _desw, álfr, dfrå, йвал_
  { {0x9f47003c,0xb8e4005d,0x661b24d3,0xa3cd000b}},	//   _ennå_, _एम_, _aluk, ष्म_
  { {0x660909f2,0x66760086,0x6beb000a,0x3c450015}},	//   _boek, سدار, _הַכַ, _تضيف
  { {0xb87b002c,0x66250015,0x6b9e0034,0x799d00aa}},	//   _prít, ورنك, _hepg, _gesw
  { {0x7ded0053,0x1dc1000b,0x5fbd000b,0x66090079}},	//   יקאַ, ष्टत, ्भाल, _doek
  { {0x661b0020,0x2bc0000b,0x78a20069,0xd71a00fd}},	//   _eluk, श्चा, šovs, _любі_
  { {0xe29707c1,0x1ddc000b,0x3f9c16c3,0xb87b5a25}},	//   пај_, _बसंत, _revu_, _frís
  { {0x6d5a002a,0x11d60021,0xb87b001a,0x8cad000b}},	//   ętaj, ستعد, _grís, _जिलो
  { {0xdfd0040b,0x60f70010,0x764300dc,0x0ef4000b}},	//   نية_, зныя_, énye, इम्स_
  { {0x66090a9c,0x351b000a,0x251b0643,0xe0cf00c3}},	//   _zoek, _הומנ, _הומא, ازي_
  { {0x224d0234,0x6d5600da,0xadd90098,0x6d445a26}},	//   boek_, _ayya, омну_, _axia
  { {0xf27b013a,0xa3cd005d,0x07370008,0xc27b000a}},	//   _הראש, ष्ठ_, לאים_, _הראי
  { {0x799d0026,0xfc3f0077,0x64585a27,0x63bc0123}},	//   _resw, esía_, olvi, _örns
  { {0x648b000a,0x7bc8007c,0xba770015,0x9a871cd9}},	//   מְלְ, õdup, كارت, зуал
  { {0xdb1c0152,0xcb69002b,0xe457004c,0x64585a28}},	//   ngrè, زمره_, פילט_, ilvi
  { {0x6e2d0035,0x0f570008,0x79a70010,0x2f3b000a}},	//   _umab, _מיום_, ярге, _לגוד
  { {0xa3e5000b,0x2da2002a,0xdb1c0123,0x28f802ed}},	// [e770] _बोझ_, óreś_, vfrå, петь_
  { {0x66090f75,0x224d0111,0x3a200064,0x661b0bfa}},	//   _soek, zoek_, ahip_, _sluk
  { {0x2ca900fb,0xb87b002c,0x9989002a,0x59ce000b}},	//   _hvad_, _prís, tkań_, _हॉवर
  { {0x3a205a29,0x6e3d5a2a,0x601f016e,0x64585a2b}},	//   chip_, nnsb, _iême, elvi
  { {0xdb1c01d1,0x629a0d03,0xd54b0015,0xc484008b}},	//   rfrå, _awto, حجام_, елік
  { {0x69cd0026,0x78fa000a,0xdb1c5a2c,0xd7e4005e}},	//   lfae, _ופשו, sfrå, _пісо
  { {0x6609049c,0xdb1c007c,0x629a0034,0x68ed2ec8}},	//   _toek, berõ, _cwto, lvad
  { {0x601f0152,0x661b007c,0x64582e4f,0xd2290058}},	//   _même, _uluk, alvi, تكبه_
  { {0xf1a80086,0x682000c0,0xb145005e,0x3c0d000b}},	//   سايه_, _född, ьнил, _सकूँ_
  { {0x224d020a,0x76590026,0xc87f00b8,0x7e645a2d}},	//   soek_, llwy, _muß_, _ship
  { {0xa2940036,0x1f650036,0x76590026,0xa3cd021e}},	//   _захі, ьком, olwy, ष्ण_
  { {0xd12e0074,0xc332000a,0xf2040033,0x63a35a2e}},	//   امی_, _בוב_, _пячо, lann
  { {0x61e90bad,0x76590034,0x7568004f,0x8d760369}},	//   mdel, ilwy, ּ֣רְ, بادا
  { {0x90450029,0xddcd0011,0x63a35a2f,0x61e95a30}},	//   _تنته, _piaţ, nann, ldel
  { {0x68ed121a,0x60c95a31,0xc87f0012,0x61e90e27}},	//   evad, ltem, _auß_, odel
  { {0xda650029,0xddcd0011,0x7e9a000a,0xdb1c3bab}},	//   فاقي, _viaţ, _וסקו, ngré
  { {0x76590026,0x98a30080,0x6b670152,0xe80a005e}},	// [e780] dlwy, ките, tégé, онад_
  { {0x3a200041,0xdd0c005c,0x61e900f2,0xb87b5a32}},	//   ship_, półc, hdel, _prír
  { {0x76590176,0x6d4101e2,0x56930036,0xdb05059b}},	//   flwy, şlat, ваєт, _schö
  { {0x6b670014,0x76590026,0xc87f00b8,0x61e94bfe}},	//   ségé, glwy, _fuß_, jdel
  { {0xfc3f002d,0x63a35a33,0xdb1c007c,0x394f0012}},	//   isín_, fann, rerõ, ügst_
  { {0x9f98002e,0x63a35a34,0x68200012,0x7bdc5a35}},	//   _náðu_, gann, _böde, neru
  { {0xfbd30008,0xe61a0004,0x76590034,0x61e95a36}},	//   דתו_, _ддв_, blwy, fdel
  { {0xdb2500dc,0x7bdc00b8,0x321d0026,0xd25704ab}},	//   ésér, heru, _clwy_, мцы_
  { {0x83c60063,0x3014250c,0xc4c60015,0x9f98001a}},	//   _обаж, едпр, _تتزو, _báðu_
  { {0x7bdc0962,0xdfd0002b,0x63a35a37,0x224906f2}},	//   jeru, چيک_, cann, čaka_
  { {0xdfd00086,0x57b70053,0x7bdc5a38,0x87b7000a}},	//   نيک_, וליב_, deru, וליס_
  { {0xd378016f,0x7d090020,0x7bdc007c,0x78b60046}},	//   _naći_, äeso, eeru, kryv
  { {0x60c90152,0x9f98002e,0x7996002a,0x7bdc5a39}},	//   ctem, _fáðu_, dbyw, feru
  { {0x6abc0026,0x515b0008,0x9f98001a,0x7bdc5a3a}},	//   furf, _וכדו, _gáðu_, geru
  { {0x76590026,0xcf260029,0x02dc000b,0x2019003d}},	//   ylwy, _ترشي, _मनोन, īsit_
  { {0xda700029,0x25a0002e,0x7bca001a,0x63a35a3b}},	//   لُّ_, ðill_, _öfun, zann
  { {0x7d0000c0,0xee3f0264,0xd8790015,0x7bdc5a3c}},	// [e790] ämst, mný_, سمات_, beru
  { {0x9c380080,0x7c670086,0xee3f0057,0x61e95a3d}},	//   _опыт_, _تابل, lný_, zdel
  { {0x63a339fd,0x28080015,0xc7c4006b,0x248d2f50}},	//   vann, بْلَ_, ъсти, _stem_
  { {0xee3f099c,0x94790001,0x56940033,0x8ddc004c}},	//   nný_, пску_, тацт, ַקוק
  { {0x682000c0,0xd1260015,0xc4c40015,0xee3f0046}},	//   _söde, _إم_, نتوو, iný_
  { {0x5faf005d,0xf3f10015,0x02c502da,0x76590034}},	//   _फ़ाइल, طأت_, ейко, slwy
  { {0x248d002a,0x93bc0045,0x321d0034,0x61e902d6}},	//   _wtem_, _rmăt, _plwy_, tdel
  { {0x35fb0086,0xee3f0107,0x61e90f80,0x7ae50573}},	//   _برسد_, jný_, udel, _msht
  { {0x40940010,0xee3f0107,0xe0d602bf,0x6d480061}},	//   крэт, dný_, евы_, ğdak
  { {0x63f40029,0x93bc0011,0xf958000a,0x60c95a3e}},	//   _لأمر, _clăd, וסחת_, rtem
  { {0x74280015,0x97a8000a,0x2d850046,0xc2c50015}},	//   _تكلف_, וֹרֵ, ělen_, _سيشي
  { {0x7bc50026,0x61550015,0x11d40015,0xf772000a}},	//   _achu, _كنائ, _لتهد, טקי_
  { {0x55ba000a,0xb23a004c,0x39590123,0x7bdc5a3f}},	//   המרו, _צענז, _nyss_, teru
  { {0x7bdc00b8,0x1bec000b,0x8c1a0015,0x63a10030}},	//   ueru, फ़ाइल_, أيسر_, _jeln
  { {0xcf880029,0x63a10024,0xdbdd002e,0xee3f0264}},	//   _غضون_, _meln, ráðu, bný_
  { {0xb87b002c,0x2caa0063,0x6d410064,0xc3320008}},	//   _príp, _екип_, ğlar, אול_
  { {0x6d4101e2,0xba17003b,0x6e3b0008,0x39465a40}},	// [e7a0] şlar, ريكا_, _מתקד, ços_
  { {0x999f0024,0xe108000a,0x1ae63de5,0xdb1c02de}},	//   ārša_, וּעָ, _зоом, kfrø
  { {0x31ba0064,0x28ac005d,0xdb9b000a,0x8b9b000a}},	//   nüzü_, _चिकि, _מסיר, _מבית
  { {0x25a0002f,0x5ab70053,0xc7a9004f,0xb87b202e}},	//   úil_, _אלטע_, מב_, _tríp
  { {0xb97b0008,0x69c658e1,0xb60801c0,0x76430030}},	//   _מרכז, _icke, _nešť, énya
  { {0xbb3a0008,0xee3f01b2,0x93bc0045,0x62812411}},	//   ּעֵי, zný_, _amăr, _bulo
  { {0xc8430036,0x62815a41,0x2bd2005d,0xfbd2000b}},	//   _серй, _culo, द्या, द्यम
  { {0x63a10005,0x60f80063,0x62810035,0x36f7000a}},	//   _eeln, дния_, _dulo, _אצלם_
  { {0xc05a008f,0x63a100dc,0xee3f0264,0x937a0015}},	//   зін_, _feln, vný_, _فصار_
  { {0x20d30029,0xb6080046,0xf8b3004f,0x63a1016d}},	//   اتيج, _dešť, נשת_, _geln
  { {0xee3f04af,0xf837000a,0xdd950033,0xa2d300c3}},	//   tný_, תנית_, каны, _ميلت
  { {0x7bc55a42,0xe29b004c,0xe7c70065,0x0000006a}},	//   _schu, _זשאר, _लाभप,
  { {0xee3f0107,0xd24f002b,0xdb15001a,0x6016016e}},	//   rný_, _انن_, _íbúa, _lâmi
  { {0x7a230020,0x25a60026,0xee3f0057,0x69c60ccc}},	//   _mõte, haol_, sný_, _acke
  { {0xdb22002e,0x22ac0089,0xbebc0024,0x0057000f}},	//   ðuðu, něk_, ozīm, _רשות_
  { {0x9b580036,0x7a3b008c,0x1f5b004f,0xaf5b004f}},	//   хист_, dätä, _מדוא, _מכוכ
  { {0x9f5c002c,0x3ebe2c35,0x4975042d,0x5e440015}},	// [e7b0] _novú_, lutt_, тлас, _حَيْ
  { {0x7bc5003f,0xb909005d,0xc6a7006d,0xb8d9000b}},	//   _uchu, _मन_, ерди, _घट_
  { {0xf3ff00a7,0x3ebe003c,0xfbd20008,0x25a60034}},	//   _đã_, nutt_, _דתי_, faol_
  { {0x3618005e,0xb4950054,0x2575002b,0xbebc003d}},	//   нцію_, видљ, نهاس, jzīm
  { {0xe56e000d,0x63a10095,0x93bc0045,0x3605002b}},	//   рз_, _peln, _rmăr, _یوسف
  { {0xe3b30074,0x293600b2,0x31ba0061,0xbebc003d}},	//   ارش_, _יארן_, yüzü_, ezīm
  { {0x92e80029,0xf5950015,0xe1f10015,0x0735006b}},	//   فريق_, _للأج, لسة_, _ревю
  { {0x75e70010,0xc692000a,0x25a60034,0xceb8002a}},	//   _яўге, _כאל_, caol_, drę_
  { {0xe0d90036,0xe3b300e6,0x7ff50015,0xfa0f00a1}},	//   єво_, _مرض_, نسدا, _đậu_
  { {0x62815a43,0x200e0034,0x94770015,0xceb8002a}},	//   _tulo, _cofi_, _أدرا, frę_
  { {0x3e7b003d,0x779a004f,0xa2b40065,0x0000006a}},	//   _sūta_, וֹכו, ैंण्,
  { {0x237400e5,0x51870174,0x93bc0045,0xa19500ce}},	//   _صالح, _чужа, _umăr, _радч
  { {0xceb8002a,0xf532000a,0x0000006a,0x0000006a}},	//   arę_, ֹ֥ר_,   ,
  { {0x0c790080,0x3ebe003c,0x9f0500c3,0x1d070099}},	//   ессы_, butt_, _لوتو, њери_
  { {0xe805005d,0xdaba0015,0x601f0034,0xfe460fd5}},	//   राना_, ظهرت_, _gêma, _инко
  { {0x4a4306bf,0x7db50138,0x0000006a,0x0000006a}},	//   ансв, _йсьц,   ,
  { {0x61eb5a44,0x991502e1,0xc212000a,0x0e57000a}},	// [e7c0] _magl, льфі, בהן_, _בשקט_
  { {0xe3b80064,0x61eb04d6,0xbebc03e9,0xdb1c001a}},	//   _alın_, _lagl, dzīj, lgrí
  { {0xf7190010,0xba760015,0x37e30033,0x25a60034}},	//   ніцы_, _لاحت, рохг, taol_
  { {0x22ac0089,0x1a9b0053,0x682000c0,0x61eb5a45}},	//   věk_, _קיכע, _döda, _nagl
  { {0x7a3b00f2,0x9f470107,0xe4c3006b,0x0000006a}},	//   sätä, _dané_, ийци,
  { {0xa7da0074,0xa5070001,0x54530484,0xb2c60015}},	//   _توسط_, теља_, авіт, نغبو
  { {0xb6a30036,0xbebc0024,0xcc3b0053,0x96b90001}},	//   _висл, tzīm, ועסט, _путу_
  { {0xe3b20074,0xcb130008,0x78b1002e,0x408a0054}},	//   _چرا_, שלה_, _ákvæ, мљом_
  { {0x2054006b,0xbebc003d,0x3039002b,0x4a5b000a}},	//   лкия, rzīm, کتيک_, ודקו
  { {0xe805005d,0x61eb0541,0xdfd000e6,0x7bda007c}},	//   राया_, _eagl, حيد_, õtul
  { {0x539b0008,0xd7bb0053,0x38170008,0xa1c60010}},	//   _חיבו, וציר, דקים_, _абед
  { {0x68e41316,0x12a90015,0xddcd002a,0x93bc0045}},	//   kwid, _أدلى_, _skał, _flăc
  { {0x224600d9,0x23c9000b,0x621b000a,0xe805000b}},	//   _ijok_, _रामद, _קודק, रामा_
  { {0x61e001e2,0x68e4003e,0x61eb136b,0xaf33002b}},	//   leml, dwid, _zagl, اریت
  { {0x2bd2005d,0x60c000f2,0x68e40026,0xdd030064}},	//   द्धा, lumm, ewid, ırıd
  { {0x1da7005d,0xe18f0092,0x61e05a46,0x69c45a47}},	//   _ख़ित, hẳng_, neml, ggie
  { {0x52bf000b,0xaa5809c2,0x60c0220e,0x61e002ad}},	// [e7d0] _एम्स, титу_, numm, ieml
  { {0x7d580008,0x2bd2000b,0x7e81003d,0x61e05a48}},	//   _ביחד_, द्दा, _sēpi, heml
  { {0xdcef0064,0x1da7000b,0xa647002b,0x5ba40033}},	//   macı, _ख़ात, پخان, _трыз
  { {0x61e000bd,0xfb1a0008,0xe610012c,0x60c05a49}},	//   jeml, _נורמ, يشن_, kumm
  { {0xe8df0023,0xa8a40083,0x61eb0026,0x61e05a4a}},	//   _thực_, _врск, _ragl, deml
  { {0x61eb0048,0x24840012,0xe787105a,0xad1c004f}},	//   _sagl, _dumm_, _шумо, וודר
  { {0x61eb00b6,0x78ad0007,0x55bb0015,0x42550663}},	//   _pagl, lsav, _يطرح_, лтит
  { {0x93bc0011,0xe4d70015,0x6b7c000a,0x61e00101}},	//   _plăc, _لتطب, ורונ, geml
  { {0xdcef0061,0x26c102f2,0x30750170,0x61eb02b9}},	//   kacı, luho_, луос, _vagl
  { {0x6fd4005e,0x798d0034,0xa5c2001a,0x4f09012f}},	//   ацює, hcaw, _þóri, енон_
  { {0x2ba7005d,0x54560053,0x2baa000b,0x6da605aa}},	//   _औज़ा, _עסען_, _क़बा, лина
  { {0xa2d8014e,0x68e4002a,0x2d9601b0,0x60c05a4b}},	//   _महत्, ywid, ырос, bumm
  { {0x25a0002e,0xb87b0030,0x44271419,0x64435a4c}},	//   ðili_, _csík, ohn_, onni
  { {0x613a0053,0x313a0053,0x78ad3040,0xc172000a}},	//   _אײנס, _אײנב, dsav, _החד_
  { {0xe6d2014e,0x64435a4d,0xab2a5a4e,0xfaf10015}},	//   _सहेज, inni, хова_, يثِ_
  { {0xfaa5005f,0x6e920029,0x01f90053,0x225f0064}},	//   ршён, _اليا, עפּל, nluk_
  { {0xc9660063,0x6d5a005c,0x5fa7000b,0x78ad0795}},	// [e7e0] увай, ętas, _ग़ाल, gsav
  { {0xebe60083,0x225f01d7,0xdc9b000a,0x61e05a4f}},	//   _сооп, hluk_, _רייל, zeml
  { {0x8c1b000a,0x68e40012,0x78ad008c,0x8f88000a}},	//   _נוטי, swid, asav, דְנֵ
  { {0x69d0000b,0x64435a50,0x44270359,0x34aa0a1f}},	//   ड्शी, enni, ehn_, евдо_
  { {0x69ca00dc,0xe3b20086,0x8e57000a,0x2a6001d7}},	//   őfes, مرغ_, נינג_, mlib_
  { {0x6e2408e0,0x2a600020,0x76a60015,0xdb07001a}},	//   _llib, llib_, _محرك, rgjö
  { {0xd62a0001,0xd25000a2,0xca32000a,0x82b30015}},	//   _зове_, ينت_, ֶם֙_, محيط
  { {0x7afa00f2,0xc4c60015,0xdcef0061,0x710a004a}},	//   ätty, _متطو, zacı, ехов_
  { {0x463b00b2,0xdcef0064,0x89370053,0x61e00198}},	//   _נעמע, yacı, ָריע_, reml
  { {0x44385a51,0x00d7006e,0xb03409c2,0x403416cf}},	//   _ör_, ابيت_, рнош, реос
  { {0x08570008,0xa8570008,0xdcef0061,0x60c05a52}},	//   רבים_, רייה_, vacı, summ
  { {0xfe550010,0x27e10012,0x786b0030,0x6298019f}},	//   ркмэ, zehn_, müve, mpvo
  { {0x40960180,0x50960054,0xa3e8000b,0x0e340b9b}},	//   _срет, _сређ, _बसा_, сняю
  { {0x63aa002e,0x6e245a53,0xf093000a,0xb1170015}},	//   nafn, _elib, _הנס_, _حقها_
  { {0x501b0008,0xfe700086,0xdcef0064,0x786b0030}},	//   _אוגו, تدی_, racı, nüve
  { {0x5eeb000a,0x201e0091,0xa327000a,0xda090067}},	//   _רַגְ, lkti_, רַךְ_, خيره_
  { {0x64435a54,0xa92b0033,0xa91b001a,0x200c00bc}},	// [e7f0] ynni, хіве_, _afþr, ojdi_
  { {0x201e305d,0x225f0064,0xf77300c3,0x7c94012c}},	//   nkti_, zluk_, ماض_, _اشيا
  { {0xd6db008f,0x1bf40010,0x201e0095,0xd5b10015}},	//   эта_, _упэў, ikti_, قفا_
  { {0x78ad0048,0x7afa0134,0xeef70008,0x7bc7002e}},	//   psav, ætte, טמבר_, lgju
  { {0x2bd2000b,0x53a50015,0x7bc70030,0x9e4c000a}},	//   द्वा, لمشك, ogju, עֲבִ
  { {0x24960029,0x493a000a,0xe5700015,0xc2c50021}},	//   جنود_, _יגרו, سطن_, ليتي
  { {0xa349010f,0x7bfc000a,0x786b0061,0x9c18000a}},	//   ъзка_, תפוצ, güve, רחוק_
  { {0x201e44de,0xe1ff0077,0x5b7c004c,0x4b38000a}},	//   ekti_, ñó_, ערהא, טרול_
  { {0xdd14002c,0xaaa5000b,0x225f0f0a,0x9f4b0046}},	//   kúša, गीतक, rluk_, ěcí_
  { {0x70520002,0x6e24239e,0xe8df0016,0xa0690054}},	//   ينيا, _slib, _giục_, ђана_
  { {0x4384003b,0x11d70015,0x93fa000a,0x33fa000a}},	//   _المق, _متشد, _שלעי, _שהענ
  { {0x97560008,0x59d5000b,0x92670021,0x7e6d595e}},	//   ייתו_, _डॉलर, _صدام, _chap
  { {0xed52002b,0xfbaa000b,0xd167006b,0x7af50046}},	//   زپس_, _क़दम, _съжи, evzt
  { {0xbf350086,0x7bc7002e,0x55760053,0xd576000a}},	//   _پرتغ, ggju, יערן_, יתרה_
  { {0x765b0064,0xfaa609a6,0x68200123,0xab630061}},	//   _okuy, рабо, _dödl, şüns
  { {0x6e24003f,0xfe720015,0xceb8002a,0xba230ecd}},	//   _ulib, _بدت_, rzęt_, одск

  { {0x44253c93,0x09060033,0x2888002b,0xe9d70099}},	// [e800] _oll_, шпан, اصری_, јку_
  { {0x7a230020,0x6c330029,0xacfb000a,0x28c8000b}},	//   _võta, _وفيا, _יהפכ, िंबि
  { {0x3bbb013a,0xab2a301e,0x9bbb000a,0x98a0002a}},	//   _במיד, _рона_, _בציפ, dzią_
  { {0x3a295a55,0x05ba0029,0x9f5c0107,0x4425268a}},	//   chap_, ئدات_, _nový_, _all_
  { {0x499b000a,0x201e0091,0x45b7008b,0xfbaa000b}},	//   _בשכב, ykti_, ргію_, _क़ाम
  { {0x94730086,0x741300e6,0x92f60015,0x7433005e}},	//   يدوا, يونا, لأعض, оніф
  { {0x69ad005d,0x7c3c00f2,0xe5a60036,0x44255a56}},	//   _ज़मी, iirr, _виби, _dll_
  { {0x63aa002e,0x44252cbf,0xe61700af,0x0000006a}},	//   safn, _ell_, _кдс_,
  { {0x914a006b,0x9f470107,0xdfd4004a,0x55bb000a}},	//   ъчка_, _daní_, бопы, _שממו
  { {0x7e6d003e,0x201e0095,0xd0070004,0xdb1c02de}},	//   _shap, ukti_, иење_, mgræ
  { {0xc7b30008,0x7c3c002e,0x201e0007,0x5fb7000b}},	//   חבת_, dirr, rkti_, _आयरल
  { {0x7c3c002e,0x4ea30010,0x443c5a57,0xd1c9002b}},	//   eirr, ўрэа, liv_, _مبهم_
  { {0x4094003b,0x64580020,0x3e4f005c,0x62885a58}},	//   _التر, oovi, jęte_, _hudo
  { {0xbebc0024,0x28b7005d,0x62885a59,0x611b000a}},	//   dzīv, ेंसि, _kudo, _בודה
  { {0x1a5b003b,0xaf070029,0x63a800bd,0x39a7097d}},	//   نشرة_, _نقوم_, _medn, ишав
  { {0xddcd0024,0x7e6d016f,0x63a83e32,0x62885a5a}},	//   _skaņ, _uhap, _ledn, _mudo
  { {0xdb1c002e,0x628840e0,0x68200012,0x5a440033}},	// [e810] rgrá, _ludo, _tödl, цэра
  { {0xfda7005d,0x35f80086,0x443c01a3,0x3a200061}},	//   _ख़ुफ, یرند_, jiv_, akip_
  { {0x7d1d1581,0x64585a5b,0x93bc0045,0x62880077}},	//   lyss, dovi, _plăn, _nudo
  { {0x3f790053,0xdb0500dc,0x25a90086,0x64b50015}},	//   אָנע, _nehé, اضای_, محتر
  { {0x65600026,0x62880007,0x24e70925,0x20110030}},	//   _cymh, _audo, рцег, özik_
  { {0x443c00fb,0xb4e7005d,0xe3b10086,0x628816e6}},	//   giv_, _बनी_, سرت_, _budo
  { {0xdb1c002e,0x9f470089,0x6288002a,0x0bb8000a}},	//   agræ, _paní_, _cudo, בלום_
  { {0xf2e4005e,0x62885a5c,0xe3b8007f,0xdb1c01d0}},	//   юючо, _dudo, _ylık_, bgræ
  { {0x7659005c,0x65600026,0x443c0abb,0xa1e80015}},	//   mowy, _gymh, biv_, شريك_
  { {0x7659005c,0x44255a5d,0x80f8006b,0x60094b79}},	//   lowy, _ull_, рхът_, уном_
  { {0xc2c4003b,0xdb0500dc,0x3eb10046,0xcce9000a}},	//   _ويكي, _fehé, ézt_, _רכ_
  { {0x7659005c,0x51f40015,0x8e4a0015,0x2d8400cb}},	//   nowy, _وسنر, الحك_, øme_
  { {0xee371e98,0x61450054,0x30750317,0x7c3c5a5e}},	//   сня_, _ћела, _лукс, tirr
  { {0x6f950015,0xfbfa0058,0x76590535,0x0000006a}},	//   _الغض, دّسة_, howy,
  { {0xff530074,0x7659005c,0x7a230020,0x4e9500e5}},	//   _بخش_, kowy, _võtn, _اشتر
  { {0xbb430b18,0x443c052c,0x7659005c,0x64580d80}},	//   ческ, ziv_, jowy, zovi
  { {0x7659005c,0xe8fa04ab,0x7d09008c,0xc8ca0058}},	// [e820] dowy, ыла_, äest, طوان_
  { {0xc8b50033,0xf209000b,0x3a205a5f,0x443c5a60}},	//   ўсты, वाड़_, skip_, xiv_
  { {0x63a85a61,0x403a004c,0x443c5a62,0x68f60091}},	//   _redn, נגעג, viv_, svyd
  { {0x452a15b3,0x4eaa0053,0xdb1c0134,0x7659005c}},	//   лжен_, רבײַ, tgræ, gowy
  { {0x98a00050,0x7a230020,0xf3f10092,0x28030089}},	//   dzić_, _mõtl, _bạ_, ární_
  { {0x9cd7013a,0xccf30008,0x62882c3e,0xdb1c0134}},	//   מונה_, פכו_, _pudo, rgræ
  { {0x63a8018c,0x7659005c,0xa3e7000b,0x64585a63}},	//   _vedn, bowy, यज़_, rovi
  { {0x7659005c,0x92b30029,0x443c5a64,0x63a800da}},	//   cowy, أحوا, siv_, _wedn
  { {0x361b0008,0x63a800bd,0xc4c50015,0x64a35a65}},	//   _עומד, _tedn, _وتكو, _ната
  { {0x601604f9,0xac99002b,0x62885a66,0x20740033}},	//   _câmp, ینجا_, _tudo, ўлоў
  { {0xe0cf0086,0x6d40006f,0xdb1c0b14,0xe283009b}},	//   وزی_, úman, ngrä, _елхи
  { {0x2bdb005d,0x80a30086,0x7d1d00f2,0x6e3d00dd}},	//   म्ना, _کمون, tyss, uisb
  { {0x25d70053,0x5c070063,0x463b0053,0x20d30015}},	//   זוכן_, бява, רעכע, _فتوج
  { {0x71650015,0x7659002a,0xe165002b,0x7d1d5a67}},	//   _بامك, zowy, _بدمي, ryss
  { {0xa3cd014e,0xa03b0008,0x2baa000b,0x5ea40015}},	//   ष्ट_, _תעופ, _क़रा, _بمعل
  { {0x6e440083,0xb9c5003b,0x7d0900f2,0x7afa001a}},	//   _нејз, تقري, äess, ætta
  { {0xb4e7005d,0xb8150001,0x9be7017f,0x9cb50015}},	// [e830] _बने_, одај, _лінк, _بمخت
  { {0x7659005c,0x2cb40089,0x3707006b,0xdb074c6d}},	//   wowy, řadí_, йчев, lají
  { {0x76590050,0x57a40010,0x9c18000a,0xf7480015}},	//   towy, яшта, _לחזק_, ملكي_
  { {0x3e7b00df,0xe3b801e2,0xf7700031,0xdb07013f}},	//   _būti_, _adı_, رال_, nají
  { {0x7659005c,0xe4c5005e,0x9f4500aa,0xe4a7004a}},	//   rowy, ійки, gelê_, ёрдо
  { {0x7659005c,0x14190029,0x9cd8000a,0xdb070046}},	//   sowy, شيعة_, צווה_, hají
  { {0x6d4101e2,0xe299008f,0xdb070089,0x8c1c00a3}},	//   ğlay, шай_, kají, רווי
  { {0x6d4101e2,0x7791002b,0xb5c9002b,0x20181288}},	//   şlay, _ریچا, _خورم_, örin_
  { {0x41050036,0xdb070089,0xa5070036,0xd9fa000a}},	//   ізов, dají, _уявл, בִיך
  { {0xc7ac000a,0xdb1c0123,0x0000006a,0x0000006a}},	//   ְׁכָ, mfrö,   ,
  { {0x69dd2ad0,0xbebc003d,0x5de61ab5,0x3f691411}},	//   _obse, dzīs, ожна, рино_
  { {0xbe3a0036,0x0356000a,0xbebc003d,0xb2ba004f}},	//   рчої_, _ויעש_, ezīs, _כמער
  { {0x3cf4005d,0xac930033,0x2bdb000b,0x9f470069}},	//   इटें_, маўш, म्भा, _daná_
  { {0xbebc003d,0x02dd000b,0x69dd010c,0x69cf05ef}},	//   tzīt, _महाभ, _abse, _acce
  { {0xdb1c0123,0x4e2a0a32,0xc058002b,0x920801ec}},	//   xgrä, _войн_, _اشنا_, brāķ
  { {0xbebc003d,0x2bdb000b,0xdb1c0123,0x69261246}},	//   rzīt, म्बा, vgrä, омба
  { {0xe79a0029,0x3ea70026,0xd87a00e5,0xd884002b}},	// [e840] لخاص_, _hwnt_, لمرت_, سهای
  { {0x7d1b00b8,0x69cf1f30,0xdb1c00c0,0xfc370015}},	//   äuse, _ecce, tgrä, _وكيع_
  { {0xf9860080,0x9056000a,0x3e7b003d,0x46ea0658}},	//   _мгно, קבעו_, _sūti_, рден_
  { {0x09060083,0xdb1c00c0,0xd5e90092,0x15ba0033}},	//   _дпмн, rgrä, _chè, рыжы_
  { {0xdb1c00c0,0xe8f71db0,0x97c60015,0x62820079}},	//   sgrä, _для_, _وتسم, _rioo
  { {0xb6a6006b,0xdb070046,0xad9b001a,0x9ceb000a}},	//   _мигл, zají, hjúp, שַׁ֖
  { {0x78700123,0x0000006a,0x0000006a,0x0000006a}},	//   rävd,   ,   ,
  { {0x92570029,0xb1141d90,0xd2500015,0xaae20065}},	//   يشير_, змиш, عنة_, _पहनक
  { {0x3cf4005d,0xdb070089,0x3e4f002a,0xc0e70015}},	//   इटों_, vají, jęta_, قفين_
  { {0xf3ca006e,0xd01a1d8a,0xb4260058,0xa2e602ed}},	//   _خبره_, рфи_, _بعرو, _мозд
  { {0x57fb000a,0xdb070046,0xddcd006f,0x4999004a}},	//   בליו, tají, _viaž, ́тся_
  { {0xa3ba000b,0x82360015,0xc1060015,0x32170015}},	//   _आएँ_, _برئا, _وواي, _ويلد_
  { {0x867b0008,0x067b0c44,0xbebc003d,0xdb0701c0}},	//   ירטו, ינטל, tzīs, rají
  { {0x7a230020,0x69ad000b,0x7c2e00da,0xd010006e}},	//   _võtm, _ज़ही, ghbr, _سلب_
  { {0x644a002d,0xb4e7000b,0xb0240016,0x539b000a}},	//   infi, _बन्_, _giườ, שילו
  { {0xe70b0086,0xddeb0018,0x2f130033,0x0000006a}},	//   یتان_, _ضربه_, _ідыё,
  { {0x9cb50086,0xfbd3000b,0xa2ca000b,0xa3ba000b}},	// [e850] _عمدت, _तापम, सूत्, _आएं_
  { {0xc7c80033,0x629a5a68,0x7c2e0028,0xe61600bc}},	//   жыце_, _otto, chbr, _čišč
  { {0x98ac0024,0xfbd2000a,0x9f4e0030,0xfc3f0144}},	//   ālās_, _אתי_, _infó_, ssís_
  { {0x69cf5a69,0xd6180015,0xa6150033,0x7870008c}},	//   _ucce, يتنا_, ямеч, väve
  { {0xd5e90092,0xa3e7005d,0xe44e005e,0x629a5a6a}},	//   _ché, यजल_, еж_, _atto
  { {0xd91a0008,0x787000c0,0x3e720057,0xa97a000a}},	//   _הושל, täve, máte_, _לארכ
  { {0x68ed0176,0x20090092,0x3e4f005c,0x82f40010}},	//   lwad, _đai_, zęta_, дчыц
  { {0x69cd568f,0x11d50015,0x42090054,0x78700400}},	//   ngae, ستبد, снио_, räve
  { {0xd5fb0023,0x68ed0026,0x787000f2,0x629a02f5}},	//   _giú, nwad, säve, _etto
  { {0xe8df0023,0x25ad5019,0x4423006f,0xb87b0030}},	//   _chức_, _heel_, _ôj_, _zsír
  { {0x961d0024,0x764b0026,0x25ad592b,0x25d5000a}},	//   _ziņa, ongy, _keel_, ֔וֹן_
  { {0xfce60191,0xfe7200e5,0x3e720107,0xe9df0046}},	//   помо, عدد_, káte_, _nbú_
  { {0xc1040029,0x59b2005d,0x61e91325,0xa3d2000b}},	//   _يومي, _ज़बर, meel, _वाम_
  { {0xa09a05af,0x68ed0026,0x70fa0008,0x3e720057}},	//   _היסט, dwad, _להנח, dáte_
  { {0xbad50033,0xba6a0015,0xcf92000a,0xcb6a1886}},	//   міты, محرك_, _אטו_, саве_
  { {0x3e7b0048,0x9989005c,0xdeba000a,0xdcf60015}},	//   _būtu_, ciaż_, _המקל, _فأخب
  { {0x2edb000b,0xd24f0033,0x08c60033,0x48e30a1f}},	// [e860] _बहुत, эцi_, ябан, нотв
  { {0xdbca0036,0x61e95a6b,0x7e930045,0x3cfb000a}},	//   _угод_, heel, _zăpa, _פלינ
  { {0x61e90209,0xce35002b,0x9f450030,0x7c3e2ee9}},	//   keel, _رویک, felé_, _impr
  { {0xd6cf0074,0xd5e90023,0x682000c0,0x644d002d}},	//   طقه_, _phé, _nödv, éain
  { {0xd5af00b0,0x25ad00f6,0x61e93699,0x44f70015}},	//   افه_, _deel_, deel, كروج_
  { {0x02a60229,0x764b0035,0x961d0024,0x7bdc0011}},	//   прим, angy, _viņa, nfru
  { {0x25ad003e,0x66e30b97,0xff470015,0x6d40006f}},	//   _feel_, _пора, _أخ_, úmaj
  { {0x200702d7,0xc1ea0036,0xa6e2002e,0x764300dc}},	//   _anni_, ське_, öðum, ényt
  { {0xe8df0092,0x24855125,0x78b60091,0x75d3006e}},	//   _phức_, _film_, nsyv, _سيلا
  { {0xb0330080,0x2018002e,0xe3b70805,0xd48b000a}},	//   еньш, ðri_, _нбу_, _הָאֹ
  { {0x61e90384,0x75220030,0x9293005e,0xc7d7000a}},	//   beel, lyoz, _заєц, הויי_
  { {0xa2260029,0x7a23007c,0x78b6008c,0x7c3e19e7}},	//   _عرضه, _võtk, ksyv, _ampr
  { {0xe8df0023,0xdb0502c1,0x81fb000a,0x5c0736bb}},	//   _thức_, _vehí, _להאז, пява
  { {0x3e720089,0x68fb001c,0x717b0008,0xa097000a}},	//   váte_, _áudi, _הנדס, _צדוק_
  { {0x3fdb0008,0x5fdb0008,0x7e860089,0x6fdb000a}},	//   _הקוב, _החוק, íspě, _הקוס
  { {0xda7b0036,0x34dc005d,0x9ef30015,0x3e720227}},	//   сяг_, _यहूद, _أسوش, táte_
  { {0x442c003e,0x20070026,0xa954005e,0x1dd80021}},	// [e870] _old_, _ynni_, екті, _ربيع_
  { {0x3e7201c9,0x7a23007c,0x7a2a0046,0xb87b3057}},	//   ráte_, _mõti, _výta, _psíq
  { {0x9f4502d5,0x25ad5a6c,0xabda004f,0x28080058}},	//   telé_, _peel_, _וחתכ, ثْلَ_
  { {0x8aa80008,0x443e5a6d,0xd7740067,0x2485007c}},	//   _מֹשֶ, _amt_, رالع, _silm_
  { {0x248d03af,0x25ad3f98,0xf9fa000a,0xd56b005e}},	//   _quem_, _veel_, _והרמ, цiал
  { {0xd7f50033,0xad38000a,0xe3c50058,0x9f450de4}},	//   _ўзвы, הנדס_, ذْبَ, selé_
  { {0x6e2d01e2,0xe3b003c4,0x35b5000d,0x25ad0020}},	//   _olab, اره_, _обвр, _teel_
  { {0x02dd014e,0x754800dc,0x443e0020,0x360500c3}},	//   _महीन, ászá, _emt_, _تورف
  { {0x61e95a6e,0xdb0e5a6f,0x4900000b,0x9525002b}},	//   reel, rabé, रियो_, _تکام
  { {0x661b00f2,0x6e2d17e3,0x04f4005e,0x61e95a70}},	//   _houk, _alab, _язую, seel
  { {0xc7b20008,0xf2070033,0x61e916f3,0x2a6902f2}},	//   כבי_, _нядо, peel, klab_
  { {0x661b022d,0x64435a71,0x92b40015,0x78b6008c}},	//   _jouk, lini, _أحلا, ysyv
  { {0x224d00dc,0x60c95a72,0x30150004,0xc236004f}},	//   mnek_, quem, _оддр, _קרנו_
  { {0x3b0a005f,0x224d0014,0x6e2d49ad,0x64435a73}},	//   оего_, lnek_, _elab, nini
  { {0x70760029,0xa3df005d,0x660916d3,0x8f9a000a}},	//   _تموز_, ध्य_, _onek, _ויצי
  { {0x224d0014,0xe9da008f,0xe1f90007,0x6e2d5a74}},	//   nnek_, ўка_, ndų_, _glab
  { {0xb17a00b2,0xe1f90007,0x224d00dc,0x64435a75}},	// [e880] ַטער, idų_, inek_, kini
  { {0xcb6a0001,0x7522003f,0x64435a76,0xc7950033}},	//   _мапе_, vyoz, jini, ерцы
  { {0x224d0014,0x64435a77,0x7642008c,0xdb070030}},	//   knek_, dini, tioy, pajá
  { {0x8afb000a,0x442c051e,0x64435a78,0x28a9000b}},	//   _והטי, _sld_, eini, _चौकि
  { {0x224d00dc,0x54970015,0x64435a79,0xa3d20065}},	//   dnek_, وضوح_, fini, _वाद_
  { {0xe3b80064,0x224d005c,0x64435a7a,0xe1f90091}},	//   _alır_, enek_, gini, edų_
  { {0x25080086,0x54330029,0xbddb0251,0x59b2000b}},	//   _کرزی_, ضرور, dièn, _ज़ार
  { {0x20000064,0x224d00dc,0x6443029d,0x27f80012}},	//   _şii_, gnek_, aini, _harn_
  { {0x961d0048,0x60f7008f,0xdfd00029,0x32530063}},	//   _ziņo, дныя_, هية_, ъвър
  { {0x3f140b18,0x443e01c2,0x64435a7b,0xf487002b}},	//   едос, _umt_, cini, _قالی
  { {0x3eb80014,0x6d5a0011,0xdeb40010,0x25a60026}},	//   ért_, ştal, эбны, obol_
  { {0x26c7016f,0x7e760003,0x60e70123,0xd337000a}},	//   šnog_, _chyp, örmå, _קראה_
  { {0xe0d400b2,0x2bd3000b,0xf27b000a,0xc27b000a}},	//   _נײַ_, _तादा, _וראש, _וראי
  { {0x7a31003c,0xbddb0251,0x7e640cff,0x0000006a}},	//   _måte, cièn, _ekip,
  { {0x29020064,0x7a3101a7,0x9a87307f,0x2a6901f9}},	//   _arka_, _låte, дуал, tlab_
  { {0x3e560024,0x64435a7c,0xbddb0144,0x0000006a}},	//   tāte_, zini, gnèt,
  { {0xa9550001,0x64430064,0xa92b0010,0xb9550063}},	// [e890] хваљ, yini, ціве_, хващ
  { {0xc9840124,0x661b0089,0xe1f90007,0x3e72002e}},	//   ђути, _souk, zdų_, máta_
  { {0x27f80026,0x61e2044c,0x07080015,0xceb8002a}},	//   _darn_, _obol, ويكي_, nsę_
  { {0xdce4005c,0x64435a7d,0x2bdb000b,0x27f83a74}},	//   _wzią, wini, म्रा, _earn_
  { {0x64431637,0x27f80026,0x3a36000a,0x7870008c}},	//   tini, _farn_, _נרשם_, säva
  { {0x97c70029,0x201c0a00,0xe8d60008,0xc952000a}},	//   _تتحم, _novi_, _אושר_, _עמם_
  { {0x224d0014,0x64435a7e,0x661b00f2,0xc7b2000a}},	//   tnek_, rini, _touk, _תבל_
  { {0x6443088e,0x64b70015,0xdb0705ff,0xe1f90091}},	//   sini, _يحذر, majä, udų_
  { {0x60250063,0xe1f90007,0x25bf00e8,0x224d0548}},	//   едпа, rdų_, _idul_, rnek_
  { {0x7e6454bb,0x224d00dc,0x919f000b,0x644300aa}},	//   _skip, snek_, _ग्रै, qini
  { {0xbddb0251,0xfe4605ae,0x224d00dc,0xd24e0086}},	//   rièn, енно, pnek_, شنی_
  { {0x6ec0005d,0x12fa000a,0x42fa000a,0xed5a126d}},	//   _विरु, _מהעב, _מהעס, зом_
  { {0xdb070020,0x61fb0375,0xf532000a,0xd14b0015}},	//   hajä, mdul, ָ֥ר_, _بشان_
  { {0x61f90026,0x653a0053,0x853a00f3,0x59b2000b}},	//   _hawl, לערד, לגרי, _ज़हर
  { {0x60db5a7f,0xa3d2000b,0xdbd2007c,0x9b93006e}},	//   ltum, _वास_, müük, الفت
  { {0x7e64003f,0x2c640123,0x60db46d0,0x3a295a80}},	//   _ukip, töds_, otum, gkap_
  { {0x0d86005e,0x321d002a,0xbd46002b,0x64415a81}},	// [e8a0] _ялин, _mowy_, _سندي, _omli
  { {0x8d5b000a,0xace9002b,0x7d0458e5,0x3a2901c2}},	//   _מכפי, _آريل_, _iris, akap_
  { {0x56930036,0xdb070020,0xdb0500dc,0x60db0356}},	//   гаєт, gajä, _tehá, htum
  { {0x4a9b00b2,0x321d0050,0x60db24ab,0x27f800da}},	//   _מיטג, _nowy_, ktum, _warn_
  { {0x61fb0034,0x25a61e57,0x27f85a82,0x3d1e0065}},	//   ddul, rbol_, _tarn_, _पथों_
  { {0xb8e6014e,0xbddb0003,0x9f47006f,0x61fb0547}},	//   ैं_, nnèr, _danú_, edul
  { {0x46f401d8,0xfbd3000a,0x60db01ad,0x29005a83}},	//   _בֶּן_, אתו_, etum, lvia_
  { {0x93bc0011,0xcb130008,0x28c7000b,0x3afb004c}},	//   _alăt, רלה_, _लिमि, פּוע
  { {0x29001732,0x905403ae,0x60db5a84,0x61f94d60}},	//   nvia_, квиц, gtum, _dawl
  { {0x53a60029,0xd57505d1,0xe813000b,0x41c2000b}},	//   _أماك, _русь, ठाया_, _षयवस
  { {0xde590036,0x9837004c,0xf837000a,0x5457000a}},	//   дані_, גריף_, גנית_, _טסמן_
  { {0xd13a02bf,0x11d60015,0xd357000a,0x7d0421d6}},	//   _нхл_, _ستؤد, _איבי_, _bris
  { {0x463b00b2,0x7a230005,0x9be7005e,0x7e7d509b}},	//   לעטע, _mõtt, нівк, rmsp
  { {0x00f70008,0xb09b000a,0x2056005e,0x7d045a85}},	//   _נמוך_, _ציור, _ятер, _dris
  { {0xdb580080,0x2cea005d,0x7d040e95,0xba2b005e}},	//   еют_, टबॉल_, _eris, піад_
  { {0xb5fd00bd,0x7d040c0a,0x3377000a,0xbeec000b}},	//   _akšn, _fris, תעלם_, जबीन_
  { {0xc8c8000b,0xd795006b,0x7d045a86,0x52dd0065}},	// [e8b0] िंगट, визъ, _gris, _मह्स
  { {0x682000c0,0x3e560024,0x61fb0030,0x3a295a87}},	//   _södr, māta_, zdul, skap_
  { {0xdcfd01e2,0x7bc80008,0xc5d5017f,0x29005a88}},	//   ması, _אֶרֶ, віль, avia_
  { {0xd6d80010,0x69c30007,0x60db0007,0xdcfd0064}},	//   эту_, ėnes, ytum, lası
  { {0x3e560048,0x98a9005c,0x786b0020,0x09b6000a}},	//   nāta_, dzać_, hüvi, _בפרט_
  { {0xdcfd0064,0x1d0c000a,0xf3f10015,0xd5c5005e}},	//   nası, לּוּ, شأت_, рiвн
  { {0xdce40050,0x4255017a,0xa3d2000b,0x61f9157b}},	//   _dzię, ктит, _वार_, _pawl
  { {0x00e50036,0xdcfd0061,0x3e56003d,0x7afa001a}},	//   вжин, hası, kāta_, ætti
  { {0x93bc04f9,0xdcfd0064,0x60db5384,0x3495058b}},	//   _plăt, kası, utum, _разр
  { {0x601e0089,0x3e560024,0xb97c000a,0x64410012}},	//   _námě, dāta_, הנחי, _umli
  { {0x34d1005d,0xdcfd0061,0x6da6096d,0x60db5a89}},	//   _समुद, dası, кина, stum
  { {0x98a9005c,0x27010007,0x32b80015,0x7d040eb7}},	//   czać_, _mėn_, _أدلة_, _pris
  { {0xee370036,0xdcfd0064,0x55ba0008,0x3e560024}},	//   тня_, fası, ומרו, gāta_
  { {0x290002b9,0xa136004c,0xdca317b6,0x6fd80065}},	//   vvia_, _באנק_, рари, _मायू
  { {0x5b350010,0x2bd3005d,0xda660029,0x0ef90010}},	//   гэту, _तारा, ناري, _цэлы_
  { {0xc3320008,0x3e560024,0x60c95a8a,0x29005a8b}},	//   בול_, bāta_, orem, tvia_
  { {0xf1b200b2,0xa3c3005d,0xdcfd0064,0x290000f2}},	// [e8c0] יסן_, ्ला_, bası, uvia_
  { {0x60c90d92,0xecb7004c,0xdcfd0061,0x628b5a8c}},	//   irem, _שפיץ_, cası, _ligo
  { {0x99990014,0xbd460086,0x98b30024,0xe7b30086}},	//   _első_, _سنگي, ādās_, شمند
  { {0x601e0089,0xe6c50015,0x64a65a8d,0x60c95a8e}},	//   _zámě, اتلي, вада, krem
  { {0x7a230005,0xbddb0152,0x34d1000b,0x9975008b}},	//   _võtt, xièm, _समृद, _бурш
  { {0x07a3010f,0x24580010,0xbddb0003,0x07ba0015}},	//   _варн, эаль_, vièm, _زهرة_
  { {0x7a230020,0x32b70029,0xdb0500b8,0x7791002b}},	//   _tõtt, ندية_, _gehä, _ایما
  { {0x60f819e2,0xdce4005c,0xdcfd0064,0xf5060718}},	//   ения_, _wzię, zası, _избо
  { {0x628b0304,0x2bd3000b,0xfbd3000b,0xc05a005e}},	//   _digo, _ताला, _तालम, дін_
  { {0x98a9005c,0x3e56003d,0x628b0d91,0x20f2000b}},	//   szać_, vāta_, _eigo, _अनीश_
  { {0x3fc80086,0x7a310123,0xdcfd0061,0xf1b9003d}},	//   ودگی_, _låta, vası, ekšu_
  { {0x8143243c,0x71a60010,0xd36f0115,0xc0aa0087}},	//   اپیم, _радз, _بهم_, _قاتل_
  { {0xecc70063,0xdcfd0064,0x60c95a8f,0x9d18006b}},	//   ъщно, tası, crem, воят_
  { {0x229800dc,0x63b801f0,0x5c240015,0xd9cb000b}},	//   _kék_, navn, لُّم, िल्ट
  { {0xdcfd01e2,0xdb07006f,0x62805a90,0x9fd70058}},	//   rası, lajú, ommo, _شذوذ_
  { {0x79a4005f,0x39a4000d,0xdcfd0064,0x7a315a91}},	//   ируе, ишув, sası, _båta
  { {0xa3d2000b,0xdb07006f,0x5967006b,0x49751e98}},	// [e8d0] वला_, najú, тъва, улас
  { {0x63b8018c,0x98170029,0xc6a7009c,0x6ca4006b}},	//   javn, خبرا, врди, _тръж
  { {0xad270086,0xdb0500c0,0x588402bf,0x63b80263}},	//   _سرکو, _behå, рыта, davn
  { {0xdb07002c,0x7a230020,0x95c40015,0xa535004a}},	//   kajú, _võts, ليمه, лнеч
  { {0xd4350015,0xc98701ca,0x628b543f,0x0000006a}},	//   ُعتب, _јуни, _rigo,
  { {0x60c95a92,0xdb07002c,0x442b5a93,0xf773002b}},	//   vrem, dajú, ьцем_, _ناز_
  { {0xe1f10029,0x8c1c000a,0x82a40054,0xa2ca000b}},	//   مسة_, ווגי, ашње, संग्
  { {0xc1b90029,0x60c905fe,0xd1b90015,0x91d50033}},	//   رابط_, trem, رابا_, уцкі
  { {0x31140010,0x60c90291,0x7fb50033,0x628b0490}},	//   афэс, urem, лёні, _vigo
  { {0xa2ca005d,0xef193c3b,0xa3ba000b,0x0ea9004a}},	//   संख्, емо_, _अजय_, нкой_
  { {0xe7f6014e,0x5f450029,0xdce80061,0xce4a0a9d}},	//   ीयता_, انجل, _ılım, езне_
  { {0xe80a005d,0x23df005d,0xa3df005d,0x60c95a94}},	//   _होना_, प्रद, ध्र_, prem
  { {0xd6560008,0xb4f90053,0xdb1c0012,0x51870937}},	//   רירת_, עפֿי, sgrü, _ружа
  { {0x55760053,0x9f050087,0x2018005b,0x0000006a}},	//   טערן_, _موتو, örit_,
  { {0xc016004f,0x5fda004f,0x0000006a,0x0000006a}},	//   _תקצו_, _נחקק,   ,
  { {0xc332000a,0xdb0e0030,0x63b8036d,0x7a310ebd}},	//   זול_, gabá, zavn, _påta
  { {0x3cfa0058,0x09f70058,0x0906066a,0x0000006a}},	// [e8e0] _أعبد_, دفقة_, ыпан,
  { {0x27eb01cb,0x6d3b000a,0xe61f00bc,0xe73a37c6}},	//   _činí_, _נתינ, _čašč, нез_
  { {0xf9890008,0xdb07002c,0x3e560024,0x7a2a001a}},	//   פר_, zajú, nāto_, _lýti
  { {0x7afa002e,0x7e930045,0xf1b9036d,0xe9a6009b}},	//   ættu, _căpi, jaš_, _щамп
  { {0xa3b4008f,0x7a2a001a,0xa507006b,0x63b804a6}},	//   аблі, _nýti, леца_, tavn
  { {0xdb07002c,0x7c2e0546,0x9f4c005a,0x3e5601ec}},	//   vajú, nkbr, sedé_, kāto_
  { {0x68f60176,0x533405cb,0xa6f80008,0xd6f80008}},	//   lwyd, рейт, _בִּי, _בִּש
  { {0xf7530225,0xd6eb000a,0xd2570033,0x3e56003d}},	//   _انفج, _אַמָ, лцы_, dāto_
  { {0x69d600dc,0x68f60026,0xc034009c,0x25fd000b}},	//   igye, nwyd, иниј, _रोटी_
  { {0xdb0e0097,0xa3ba0015,0xdb07006f,0x68f60034}},	//   zabá, _سائر_, rajú, iwyd
  { {0x3393003b,0x74130029,0xd24f0086,0x9e15017f}},	//   _المز, _دولا, _کنن_, адні
  { {0x2cb20026,0xdd9100a2,0x7c2e0079,0x644a5a95}},	//   _bwyd_, توح_, ekbr, lifi
  { {0x3d0f0065,0xad9b016d,0x0000006a,0x0000006a}},	//   ामें_, edúc,   ,
  { {0x961d0024,0x68f60026,0x3e56003d,0x201a007c}},	//   _viņi, dwyd, bāto_, _õpi_
  { {0x68f60176,0xf8bf0089,0xddd00064,0xdb0e0107}},	//   ewyd, _své_, _çeşm, tabá
  { {0x2cb20026,0xf9930015,0x644a0034,0xceb3000a}},	//   _fwyd_, صبر_, hifi, _פיפ_
  { {0x68f60176,0x7e930011,0x391515fb,0xcce70058}},	// [e8f0] gwyd, _răpi, шмар, _إسبي
  { {0x57b40036,0x683202de,0x25fd0157,0x7c2e0ba4}},	//   йбут, _pæda, _रोजी_, ckbr
  { {0x2611005d,0xf1b900bd,0x644a0738,0xdb050030}},	//   णाली_, ljše_, difi, _lehú
  { {0xe4d50015,0xf8bf0046,0x23d20065,0x6aa50416}},	//   لتتب, _tvé_, _साउद, _ithf
  { {0xdb0e002e,0xf1b95a96,0xe9d60053,0x19ba000a}},	//   gabæ, njše_, _דורכ_, _במרב
  { {0xf7940010,0x3944001a,0x4c9c000a,0x644a3ff1}},	//   _гарэ, _ýmsa_, עשוע, gifi
  { {0x1bfc000a,0xf1b91129,0x1876004f,0x07e40138}},	//   גלוב, taš_, _כעשר_, _уцям
  { {0x3e560024,0xd25100e6,0xdb050030,0xb22501d2}},	//   vāto_, تنع_, _behú, рмил
  { {0x3d0f014e,0xf1b902d8,0x7a310123,0x9f4701c0}},	//   ामों_, raš_, _låto, _daný_
  { {0x09b2014e,0x9989002c,0x94770029,0xe3b00086}},	//   _ज़्य, chať_, _إدرا, _فرم_
  { {0xc2c40015,0xc7d6000a,0x8e760004,0x1ec9006b}},	//   _هيلي, בותי_, иумч, ълни_
  { {0x68f60026,0x764b0035,0xe5670115,0x929a000a}},	//   ywyd, nigy, قط_, _סינת
  { {0x6aa5002d,0x0d760010,0x7c6600a2,0x361a000a}},	//   _athf, рыня, لاسل, דורד
  { {0xdddd005c,0x913a0c44,0xb87b0046,0x69cb0533}},	//   gosł, _שעסק, _zpív, ógen
  { {0xc9b60001,0x290f00c0,0xae1e000b,0xad9b006f}},	//   исањ, ågan_, _बचपन_, udúc
  { {0xc3320008,0x644a05a5,0xb716002b,0xba1a00c3}},	//   קון_, zifi, یباش, خيرا_
  { {0x87ba0080,0xe8fa0063,0xada900e6,0xb7960054}},	// [e900] вует_, ъла_, _صديق_, арећ
  { {0x68f65a97,0x6e24002d,0x30f8000b,0x1cbb000a}},	//   rwyd, _hoib, ्टतः_, _שמיע
  { {0x103600b2,0x68f60026,0x6fd8000b,0x09e6120a}},	//   סטעם_, swyd, _मासू, _конн
  { {0x644a0034,0x5b5b000a,0x14ca004a,0x6a9b000a}},	//   wifi, _ידיה, выки_, _ששכנ
  { {0xb903008f,0x25a902c1,0xad9b001a,0x644a5a98}},	//   _дзяк, ñala_, ndúa, tifi
  { {0x0ec5005d,0x04430001,0x61ae000b,0x2f54004a}},	//   _विंड, жељн, घर्ष, ́тьс
  { {0x764b00b6,0xc5d60036,0x15e7000b,0x644a5a99}},	//   bigy, _візь, _टॉवर_, rifi
  { {0xe80a005d,0xd6270054,0x9f45008c,0x75d60021}},	//   _होता_, _косе_, ielä_, _خيرا
  { {0xd0100029,0x1da7005d,0xca37000a,0x100a0015}},	//   كلة_, _क्षत, ינקה_, نتدى_
  { {0x91a6014e,0xe0530015,0x44e002b9,0x66000273}},	//   _ट्रै, ْخَب, mò_, _hamk
  { {0x44e20092,0x66020024,0x01da0029,0x645a0273}},	//   _hư_, odok, _لوضع_, _ijti
  { {0x3e72002d,0x6e360026,0xdddd005c,0x66020a38}},	//   náth_, _clyb, wosł, ndok
  { {0x51170029,0x44e004ed,0x66020fcd,0x70f60015}},	//   _نزوح_, nò_, idok, _خسائ
  { {0x78a90064,0xf093000a,0x44e002b9,0x6602008c}},	//   _çevi, _ונס_, iò_, hdok
  { {0x600b0008,0x807b0008,0xdddd005c,0x78a6002e}},	//   _יִהְ, _שנוצ, rosł, _atkv
  { {0xbdb5009c,0x0dcb034e,0xda7b005e,0x6e360034}},	//   _убиј, _руки_, тяг_, _glyb
  { {0x5fdd014e,0xe7f5000b,0x3835033d,0x64483af2}},	// [e910] _मामल, ुएला_, бнар, _omdi
  { {0x9f4702c1,0x44e002b9,0x3e4f002a,0xe8df0016}},	//   _ganó_, dò_, rętu_, _nhục_
  { {0x2bf60008,0xda6700e5,0xf77000e5,0xd5b70015}},	//   _המתן_, _ناحي, وام_, لإشع
  { {0x60c2016f,0x9f4c02b9,0x66020926,0xff57004f}},	//   _ovom, vedì_, gdok, סבאך_
  { {0x44e20092,0x5a16000a,0x588701b0,0x44e002b9}},	//   _cư_, _הקרן_, _выва, gò_
  { {0x44e20092,0x7a380089,0xe8df0092,0xa4440036}},	//   _dư_, _víte, _chục_, онід
  { {0x97250074,0x5c38000a,0x7a2a01c0,0x66025149}},	//   _افزو, שרון_, _výtv, bdok
  { {0x6b7c000a,0x5b58000a,0xe1f905a7,0x5b7c000a}},	//   כרונ, ישון_, уги_, כרוא
  { {0xe534004a,0x44e002b9,0xe6040015,0xa5350033}},	//   _деть, cò_, _بِقَ, _унач
  { {0x7870022d,0x12e70036,0x660009f9,0x3e72002e}},	//   tävi, _відг, _zamk, máti_
  { {0xfeb90086,0x6e24002d,0x9e66006b,0xa3470033}},	//   داخت_, _poib, йвод, _тэал
  { {0x5195003b,0x44255a9a,0xdb153bdd,0x201e00bc}},	//   _الإذ, _hol_, gazí, ajti_
  { {0x442500df,0xc203005d,0x7c2500d5,0x865a015b}},	//   _kol_, _शोएब_, _bohr, רדרי
  { {0xd12e0015,0x9f45008c,0x0d830033,0x224d5a9b}},	//   _سمى_, telä_, ялян, liek_
  { {0x9f950020,0x28da000b,0xbddb5a9c,0x7c25013f}},	//   _müük_, यूनि, vièv, _dohr
  { {0x3e790003,0xb87b006f,0x7a2a001a,0xfd3a0015}},	//   péta_, _opís, _nýtt, _مكعب_
  { {0x19b9008f,0x6600005c,0xc7960015,0xf8760015}},	// [e920] русь_, _ramk, مشاب, مهرج
  { {0x66000084,0x44e004ed,0xc172039e,0x80cf021e}},	//   _samk, vò_, לחן_, _दिने
  { {0x44e20023,0x4fba0053,0xdce40085,0x9f5c0003}},	//   _sư_, רזעצ, _iziđ, _pavé_
  { {0x3f7a00b2,0x05ba0196,0x75d30015,0x44e002b9}},	//   אָדע, ادات_, كيما, tò_
  { {0xe8df0023,0x4425002c,0x44e004ed,0x6fd8000b}},	//   _phục_, _bol_, uò_, _मालू
  { {0xa5c6005c,0x96960010,0x44e05a9d,0x44255a9e}},	//   dróż, _граш, rò_, _col_
  { {0x02a30010,0x224d0150,0x44e002b9,0x60c20085}},	//   прым, fiek_, sò_, _svom
  { {0x44e20023,0xcb130008,0x4425002d,0x644d0152}},	//   _tư_, ללו_, _eol_, éair
  { {0x8a170008,0x859b000a,0xb113004a,0x9f4c006f}},	//   מחקו_, _תשמו, змыш, redí_
  { {0xd4910023,0xb3e90029,0xe29a0010,0x7e6d02ce}},	//   _gì_, _نعمل_, _баж_, _skap
  { {0x68e40020,0xb4e8005d,0xc7b3000a,0x2d9e0046}},	//   htid, _बहु_, הבת_, ěten_
  { {0x90e60074,0x68e40005,0xad9b002d,0xdb1c134b}},	//   _هستن, ktid, adún, parê
  { {0x412a0191,0x442501e2,0x626506e4,0x7e930011}},	//   _щодо_, _yol_, _بالق, _săpt
  { {0x629a0f4d,0x80a40074,0x39400024,0x64585a9f}},	//   _kuto, _همچن, dzis_, nnvi
  { {0x63ba01e2,0xf1b90844,0x629a5aa0,0xe81c000b}},	//   _metn, ljša_, _juto, नाना_
  { {0x0f570008,0x3179005c,0x26c7006f,0x63ba5aa1}},	//   _ליום_, ższe_, ánom_, _letn
  { {0xe9180036,0xf1b900bd,0x68e402ce,0x189b0015}},	// [e930] боті_, njša_, gtid, اضرة_
  { {0x629a020a,0x224d0111,0xa09b000a,0xa8480015}},	//   _outo, ziek_, טימט, ملقم_
  { {0x2baf021e,0xd7590015,0xf62b005e,0x68e4007c}},	//   _ज्या, جلات_, ліди_, atid
  { {0x44254e5e,0x6f79000a,0xa5c6002a,0x63820030}},	//   _sol_, בְנו, yróż, zíné
  { {0x224d002c,0xa5670067,0x99870091,0x290b0045}},	//   viek_, حدان, ėnų_, _urca_
  { {0xb87b002c,0x224d005c,0x9cd80008,0xdb1c00b8}},	//   _vpís, wiek_, מודה_, rgrö
  { {0xd4910023,0x16350080,0x3e720089,0x224d4aa5}},	//   _vì_, _девя, sáti_, tiek_
  { {0xa4d50036,0xd7d9005d,0x645818b3,0x442504de}},	//   _мобі, _ढाँच, anvi, _wol_
  { {0x2369005c,0x5455017a,0x00190033,0x224d5aa2}},	//   łaj_, _дват, аўны_, riek_
  { {0xe0450036,0xe81c005d,0x224d5aa3,0x3e56003d}},	//   інни, नाया_, siek_, māti_
  { {0x7d0d01e2,0xfbd3000b,0xa6fb000a,0x629a02f2}},	//   _aras, _ताजम, רִ֖י, _guto
  { {0x76590176,0x1d0a0063,0x7d0d56d7,0xdb070e8c}},	//   nnwy, аеми_, _bras, hajó
  { {0x1ddb005d,0x3e560024,0xbddb0251,0x3dc90026}},	//   _भारत, nāti_, vièt, _ddaw_
  { {0xf064005e,0x61e925cc,0x0b5a0033,0xdb0d013f}},	//   _екіп, lfel, арбы_, _škál
  { {0x78ad0007,0x7d0d3bfd,0x6e460015,0xf412000a}},	//   epav, _eras, _ونتم, ופם_
  { {0x6e3d0028,0x3e56003d,0x39400865,0xd5d8000b}},	//   chsb, kāti_, tzis_, _डाइज
  { {0x60250089,0xe9d70010,0x61e900b8,0xd24f0010}},	// [e940] _témě, ўку_, ifel, ьцi_
  { {0x6366002c,0x39400011,0x88830033,0x61e90012}},	//   nčné, rzis_, длуж, hfel
  { {0xbddb038d,0x63ba169b,0x76590026,0x290900f2}},	//   mièr, _retn, fnwy, avaa_
  { {0xbddb038d,0xac970086,0x63ba3af6,0x61e90079}},	//   lièr, _دنیا_, _setn, jfel
  { {0x3e560024,0xdb0700dc,0xdb152cac,0x99f7000a}},	//   gāti_, mbjá, mazá, _וזכה_
  { {0x48f900b2,0xbddb0152,0x765919c3,0xc6d60015}},	//   _פּרא, nièr, anwy, _وتأت
  { {0x75d60015,0x9bcb000a,0x61e933cd,0xeab6004f}},	//   _ويسا, שֶׂ֖, ffel, חִ֥י_
  { {0x61e90014,0xa2260029,0x3e560024,0x20050a52}},	//   gfel, ترته, bāti_, edli_
  { {0x3202002c,0x3ea90024,0x3e7201b2,0x7bdc01c1}},	//   ľky_, _čata_, nátu_, kgru
  { {0x32020156,0xdb1c1e83,0xc0460015,0x30830015}},	//   žky_, parè, تخبو, وليف
  { {0xe423002b,0xc7f7000a,0xe29a0151,0xa87b000a}},	//   _تکني, חזית_, _тае_, שאיר
  { {0x98b20050,0xde590010,0xd2520015,0xdb07002a}},	//   czyć_, самі_, _تنص_, zajó
  { {0x7bdc00b8,0x5c07106d,0xed580033,0xbddb01f6}},	//   fgru, оява, жоў_, fièr
  { {0x212b018b,0x26c7002c,0xc4d3000a,0x7bdc5aa4}},	//   äche_, ánok_, וגש_, ggru
  { {0x76590026,0x2bdc005d,0x9e670015,0x0dcb0c96}},	//   ynwy, _बारा, _وابن, _купи_
  { {0x99990063,0x7d0d5aa5,0x5e440015,0x7f830015}},	//   скат_, _tras, _يَوْ, _غلين
  { {0x7afc0026,0x2909008c,0xf807005e,0x7d0d5aa6}},	// [e950] awrt, uvaa_, жчен, _uras
  { {0x57f40010,0x290900f2,0x07e70033,0xbddb0003}},	//   мпут, rvaa_, ўцам, cièr
  { {0x56950080,0xabfa0008,0x290900f2,0x35f50805}},	//   чает, _ההתר, svaa_, зпер
  { {0x3e560048,0xfad60008,0xcad60008,0x78ad5aa7}},	//   tāti_, _צורך_, _צורת_, ppav
  { {0x06080010,0x76590034,0xd5380015,0x7a3100cb}},	//   ўнік_, rnwy, يثها_, _nåti
  { {0x03a50a61,0xe2992103,0x9cd8000a,0x15180015}},	//   чико, бак_, קווה_, تزمة_
  { {0x68f90064,0x61e95aa8,0x45f70015,0x3e56003d}},	//   şadı, tfel, _وأرس, sāti_
  { {0x628214dc,0xc1050015,0xdb0e001a,0xbddb0f24}},	//   _choo, كوبي, tabú, zièr
  { {0x98b20050,0x9f4c002c,0xc3cb00e5,0x2bdc000b}},	//   rzyć_, vedá_, _نظام_, _बाला
  { {0x98b2005c,0x2d9e0089,0x41ab000b,0x61e9001f}},	//   szyć_, ětem_, _ट्रस, sfel
  { {0xfd4d0023,0xe2980036,0xbddb0152,0xdb1c0152}},	//   _triệ, _дає_, vièr, paré
  { {0x6282002d,0x20030796,0x6d07000b,0xd2280015}},	//   _ghoo, žji_, शिंग_, _وكله_
  { {0xc19a013a,0xbddb038d,0xf1b900bd,0xdb1500dc}},	//   _השני, tièr, ljšo_, vazá
  { {0xc0040036,0xb06800e6,0xab2a0937,0xe3a7012c}},	//   _опік, _وصول_, бога_, عر_
  { {0xbddb0152,0xf4120053,0x68330061,0xf1b900bc}},	//   rièr, עפל_, _mıdı, njšo_
  { {0x3e725aa9,0x28c7005d,0xee3f0227,0xbddb0003}},	//   gátt_, _लिखि, chý_, sièr
  { {0x3946008f,0xbddb0003,0x0d76002b,0x8cc60015}},	// [e960] чнаг, pièr, _ریسک_, _عقده
  { {0x3e72099c,0xb7da0040,0xa80302d9,0x3eb9004f}},	//   rátu_, صوصا_, нзул, ֶצְב
  { {0xbf790092,0x7c650002,0x8b9b000a,0x0bb7000a}},	//   _đuốc_, _تايل, _לבית, _מלים_
  { {0xc869000f,0x6aa30077,0x998900bc,0xfb1b004f}},	//   אן_, _énfa, skaš_, _הוטמ
  { {0x539801c5,0xa4d8008b,0x95c30058,0x25a90058}},	//   овля_, ідку_, ريوه, آدمي_
  { {0xd4990036,0x9cd70008,0x628208b8,0x443a2431}},	//   ірі_, פוצה_, _shoo, óp_
  { {0x78a901e2,0xb0240016,0xdc89004f,0xdb0e0c4e}},	//   _çevr, _nhườ, קְנָ, gabø
  { {0x85e70063,0x7146006b,0x7a380030,0xea16000a}},	//   _ндсв_, зхож, _míto, לַ֥י_
  { {0x3e560048,0xe811000b,0x7a38005a,0x0000006a}},	//   nātu_, _डोडा_, _líto,
  { {0xdefa065e,0x73e30001,0x320a005c,0x653b000a}},	//   бым_, _поуз, śby_, _העמד
  { {0xedd50015,0x62820125,0xc686000a,0x1df9055f}},	//   ويدد, _thoo, ּךָ֥_, оены_
  { {0x3179005c,0x29020020,0xd37b0053,0xee3f0089}},	//   ższa_, _oska_, _פראט, uhý_
  { {0xe2450087,0xa06a1d8a,0x0000006a,0x0000006a}},	//   _تخلي, _лада_,   ,
  { {0x2d80002a,0x3e56003d,0xbef60015,0x8aa72f6a}},	//   _dzie_, dātu_, _فأعت, зрад
  { {0x7a38002d,0x207b000a,0xb07b000a,0x7b6402db}},	//   _vítn, _האגא, _הנגז, етте
  { {0x1f5b000a,0xaf5b000a,0x9b58011e,0x0000006a}},	//   _לדוא, _לכוכ, чист_,
  { {0x7e6e002a,0x3e72001a,0xdb260003,0x3e56003d}},	// [e970] łopó, rátt_, _épît, gātu_
  { {0xf9900115,0xed58000a,0x718b000a,0x6d3c000a}},	//   طبق_, _מבחר_, זְבַ, _לתחנ
  { {0xa3c2005d,0x26c70089,0x48f9005d,0xfbd2000f}},	//   ्णन_, éno_, _उनको_, _בתי_
  { {0xcf930053,0x3e560024,0xe919005e,0xd5750248}},	//   גטע_, bātu_, _домі_, муль
  { {0xd5fb00a7,0xe5340036,0x1e58004f,0x28c70065}},	//   _chú, нець, השאר_, _लिटि
  { {0x3e480014,0x61e25aaa,0xdb0701d0,0x0000006a}},	//   lőtt_, _acol, rbjæ,
  { {0x94740086,0xd5fb0092,0x82f40033,0xdc8c000a}},	//   ردها, _thù, ечыц, צְדָ
  { {0x394d0084,0x80a90286,0x9f4c008c,0xbb3c000a}},	//   _þess_, овив_, iedä_, מעוי
  { {0xa4d40036,0x7fd506b4,0x62890125,0xa9fa000a}},	//   _поті, міні, rmeo, חִית
  { {0x60250036,0xb0240016,0x61e24e89,0xd91c004f}},	//   єдна, _phườ, _ecol, מוחל
  { {0x73c40087,0x3f91006f,0x200b0046,0x63bc007c}},	//   _سينم, äzu_, ěci_, _õrna
  { {0x200b0f9a,0x7bc1002e,0xfbc9000a,0x249f007c}},	//   ści_, ðlun, _כת_, _kuum_
  { {0x61fb003f,0x0000006a,0x0000006a,0x0000006a}},	//   meul,   ,   ,
  { {0xb0240023,0xb4fa0008,0x8c950484,0x3e560024}},	//   _thườ, חפשי, ерсі, vātu_
  { {0x09e60036,0xfc030063,0x60db008c,0x3af5004a}},	//   мовн, ъпро, luum, нятс
  { {0x3e56003d,0xed5a32b3,0xdeba000a,0x20075aab}},	//   tātu_, _мой_, _ומקל, _hani_
  { {0x7bc800dc,0x2baf000b,0x48060033,0x200716ad}},	// [e980] ódus, _ज्वा, мпав, _kani_
  { {0x7a3808e0,0xf9910015,0xdb1c0533,0x3e56003d}},	//   _títo, ابِ_, larí, rātu_
  { {0x8c1b00b4,0x49ba0070,0x2ca00079,0x20075aac}},	//   _וויי, _واحد_, _huid_, _mani_
  { {0x2ca00005,0xd5fb0092,0xdb1c0077,0x3e56003d}},	//   _kuid_, _phú, narí, māts_
  { {0x64a30484,0x69c410ee,0x6d460012,0x04460342}},	//   вача, maie, nzka, медн
  { {0x2ca05aad,0x69c45aae,0xdb1e0003,0xdb1c05a4}},	//   _muid_, laie, _repê, harí
  { {0xae0e014e,0x3e560048,0x4e0e005d,0x38a40bc2}},	//   ियान_, nāts_, ियाई_, _hör_
  { {0xd5fb0092,0x69c40152,0x38a4379f,0xdb1c0077}},	//   _thú, naie, _kör_, jarí
  { {0x3d18000b,0x20072153,0x26c7006f,0xdb1c5aaf}},	//   दमों_, _bani_, ánov_, darí
  { {0xdfd00806,0xa067023e,0x69c40003,0x331a0015}},	//   ديد_, мања_, haie, _وزاد_
  { {0xdb1c002e,0x99800007,0xc7d70135,0x7d045ab0}},	//   farí, okių_, וויי_, _asis
  { {0x998000df,0x3e560024,0x20180030,0xdb1c08f3}},	//   nkių_, dāts_, űri_, garí
  { {0x2ca0002f,0xad9b002d,0x6026000d,0x442c5ab1}},	//   _cuid_, ndúi, _одда, _kod_
  { {0x2007000c,0x20560036,0x3ff40015,0xd0070054}},	//   _gani_, _ютер, _أكثر, _жеље_
  { {0x7d0402d7,0xc1080092,0x7ac42c4f,0x5fdb000a}},	//   _esis, _hỗ_, ксте, _וחוק
  { {0x38a401d1,0xdb2400dc,0x442c01ee,0x99d70015}},	//   _bör_, úrás, _lod_, بتسا
  { {0x20070064,0x764200e8,0x6d46002a,0x5c7513d0}},	// [e990] _yani_, dhoy, czka, _плит
  { {0x25bf0152,0x3e560024,0x442c1a62,0x249f007c}},	//   _seul_, bāts_, _nod_, _ruum_
  { {0x2ca00111,0x44390024,0xc1080092,0x8c28004f}},	//   _zuid_, _ēs_, _lỗ_, _חֵרֵ
  { {0x38a427a9,0xb8820089,0x443e5ab2,0xcf57000a}},	//   _för_, řípa, _alt_, ובבת_
  { {0x442c0b7c,0x38a401d1,0xc1080092,0x443e1839}},	//   _bod_, _gör_, _nỗ_, _blt_
  { {0xd3780050,0x25b20064,0x442c5ab3,0xe2991cf3}},	//   _być_, ıyla_, _cod_, пак_
  { {0x12870086,0x442c5ab4,0xc5fb0015,0xdb1c016e}},	//   ومتی_, _dod_, _وعرض_, marã
  { {0xdb1e0251,0xeb98000a,0x45f70015,0x41050054}},	//   _depè, ודור_, _تأسس, езив
  { {0x442c0b7c,0xd49b0036,0xdb1c0077,0x79a8000a}},	//   _fod_, _єра_, varí, וֹתַ
  { {0x60db0020,0x26c70107,0xa3ab000b,0x44e90f06}},	//   ruum, šnou_, कुश_, mú_
  { {0x6443002f,0x2ca0020a,0x44e90f45,0xdb1c5ab5}},	//   mhni, _suid_, lú_, tarí
  { {0x82f80015,0xa3ab000b,0xd336000a,0x6609007c}},	//   _تركز_, कुर_, _ארעה_, _jaek
  { {0x69c40152,0xa2940036,0x91ba000f,0xc1080092}},	//   vaie, _раці, _זמני, _gỗ_
  { {0x31560008,0x44e9002d,0x38a400c0,0x6609187b}},	//   _אינן_, iú_, _rör_, _laek
  { {0x44270298,0x6d460050,0xe80a005d,0x8b040089}},	//   ijn_, szka, _होगा_, ěřov
  { {0xdb2600dc,0x7d040007,0x60c9003f,0x2900002a}},	//   _épít, _tsis, osem, twia_
  { {0x44e9002c,0x69c40291,0x8c960036,0x38c8002b}},	// [e9a0] jú_, raie, _проі, بازی_
  { {0x69c40152,0x44e90f45,0xb908000b,0x60c95ab6}},	//   saie, dú_, _यम_, isem
  { {0x9b460015,0x69c45ab7,0x442c245e,0x76420034}},	//   _أنجو, paie, _rod_, thoy
  { {0x66760086,0x8b57000a,0xdb1e0003,0x5b57015b}},	//   ردار, _טייס_, _repè, _טייב_
  { {0x65940001,0xd250002b,0x442c05d9,0x99800091}},	//   њалу, ینت_, _pod_, rkių_
  { {0xa3ab005d,0xa2a4005d,0x8d5b000a,0xdb1c016e}},	//   कुल_, _चंद्, הכני, carã
  { {0xf7460004,0xa3e6000b,0x442c5ab8,0x60c92e15}},	//   _џебо, य्ग_, _vod_, esem
  { {0x9989002c,0xe2970180,0x6fdd000b,0x2a60007c}},	//   skať_, нај_, _माउं, nnib_
  { {0x60f7008f,0xe2130029,0x442c00b8,0xd5af00e6}},	//   еныя_, طبيع, _tod_, _طفل_
  { {0x63b30227,0x64435ab9,0x3944001a,0xb0345856}},	//   čení, chni, _ýmsu_, тнош
  { {0x08570008,0xa2e50029,0x268a000a,0xa857000a}},	//   תבים_, _لأنن, ּנָּ, תייה_
  { {0x11e90029,0xdb1c016e,0x10a60054,0xee38011e}},	//   _يعني_, zarã, _зидн, енџ_
  { {0xe0d40053,0x0cab006b,0x60c92b9b,0x0000006a}},	//   _סײַ_, ятни_, csem,
  { {0xb3e0005d,0x711b000a,0x205402bb,0xdb1c016e}},	//   नलिख, _מודפ, _шкля, xarã
  { {0xad9b016e,0xfa870054,0xdb1c016e,0x9b680da9}},	//   teúd, ећам, varã, ешта_
  { {0xa8a70c9c,0x0f7b0008,0x8f7b000a,0x9f7b000a}},	//   ержк, _מאוב, _מנוק, _מנוח
  { {0xd7fb0010,0xb4df000b,0xdb1c016e,0x66095aba}},	// [e9b0] зуе_, _थमे_, tarã, _raek
  { {0x44e9002c,0x200c0026,0x7d7c000a,0xf9880015}},	//   vú_, nddi_, _צנזו, رنلي_
  { {0xd6db5abb,0xe7190002,0xd5b10015,0xdb1c016e}},	//   ята_, بيات_, لفا_, rarã
  { {0xdb051893,0x74f90010,0x44e9163c,0xc5d80015}},	//   _behö, дэкс_, tú_, فظها_
  { {0xdb1e0003,0x2907003d,0x64435abc,0xdb1c2ec6}},	//   _repé, ānas_, thni, mará
  { {0x60c9007c,0x44e95abd,0xc2c50015,0xf2c50015}},	//   vsem, rú_, نيتي, نْتُ
  { {0x68ed06d4,0xf1b900bd,0x2fc50293,0x4909000b}},	//   ltad, ljši_, valg_, सिको_
  { {0x60c90356,0x44e900dc,0x200c0026,0x22b7005c}},	//   tsem, pú_, eddi_, _rękę_
  { {0xdb05018b,0x60c90152,0xf1b900bd,0xe6643a2d}},	//   _gehö, usem, njši_, _стро
  { {0x7bc75abe,0x60c9309f,0x68ed0532,0x04c80015}},	//   jaju, rsem, itad, _أولي_
  { {0x7bc7016f,0x68ed5abf,0x60c95ac0,0x9f450077}},	//   daju, htad, ssem, veló_
  { {0x60c90020,0x68ed5ac1,0xdb1c010d,0xed5a45d3}},	//   psem, ktad, jará, дом_
  { {0xdb1c5ac2,0xc0e5009b,0x0000006a,0x0000006a}},	//   dará, _ролк,   ,
  { {0x407900b2,0x30790053,0x39490024,0x2bba0015}},	//   _קאַװ, _קאַנ, dzas_, باحة_
  { {0xbad5008f,0x8f32000d,0x2056004c,0x629c0003}},	//   літы, _вејц, _ביסל_, _érot
  { {0x3b070083,0xf2d200f3,0xdb1c0533,0xdced0061}},	//   њето_, יעל_, gará, _uzağ
  { {0x07a60010,0x3e4f005c,0xa3d1000b,0xfd120015}},	// [e9c0] вазн, jęty_, _वयं_, _ضجة_
  { {0xfd5f0092,0xd943023e,0x47960067,0x9f4c006f}},	//   huyể, јефи, نجاس, vedú_
  { {0x76a90036,0x7a38002e,0x46a30010,0xd62a2d90}},	//   етів_, _líti, аахв, може_
  { {0x75d30029,0x94730086,0xdb1c0896,0x99860015}},	//   ليما, یدوا, cará, _للجو
  { {0xd4e3005f,0x200c0176,0x3949005c,0x7a380426}},	//   ающи, yddi_, czas_, _ríth
  { {0x07a60e88,0x27fa0015,0x7d160034,0xbcb7004f}},	//   _јавн, _تفسد_, _mrys, דפסו_
  { {0xfbd30008,0xd4090015,0x5c5b000a,0x6832063b}},	//   בתו_, عتهم_, ודסק, _fædr
  { {0x2281002e,0xd7e2005d,0x64410495,0x7bc709bb}},	//   sókn_, _पाँच, _elli, zaju
  { {0x64a60d56,0x7a380264,0xa697000a,0x25d7000a}},	//   _раза, _cíti, _יכלה_, _שומן_
  { {0xd5750010,0xdb1c5ac3,0x9f4502b9,0x0000006a}},	//   _сусь, zará, velò_,
  { {0x48150053,0x200c0026,0xb7db0008,0x7bc71cff}},	//   אַרן_, rddi_, וקיי, vaju
  { {0xf7730008,0x200a01a3,0xd337000a,0x64585ac4}},	//   יקת_, žbi_, _שראה_, livi
  { {0xd7e2000b,0x7d160574,0xadf4000b,0x24f6000a}},	//   _पांच, _crys, ेज़न_, כֶ֜ם_
  { {0xd00f0029,0x7d160026,0x00f70008,0xc19b004c}},	//   _ولن_, _drys, _סמוך_, _חשדי
  { {0x7bc75ac5,0x3378000a,0xa3e0000b,0xdb1c5ac6}},	//   raju, גְּב, _थाई_, tará
  { {0x7bc704f9,0x68ed5ac7,0x7d164518,0x64585ac8}},	//   saju, ttad, _frys, hivi
  { {0xdb1c02c1,0x3ea9003d,0xc9740015,0x19580174}},	// [e9d0] rará, _čati_, لاكث, ваты_
  { {0x57b40036,0x394902c1,0xad1a0008,0x68ed54e6}},	//   ибут, rzas_, _נותר, rtad
  { {0x95d90080,0x3dd20026,0xc5d5008b,0x64581cc2}},	//   едет_, _ydyw_, гіль, divi
  { {0xe7ff005d,0xd2460015,0xbb3a000a,0x7bc500aa}},	//   _उसका_, _طن_, _נערי, _hehu
  { {0x89da013a,0x58d4010f,0x94790d56,0xd12603c4}},	//   _אחרי, _коят, нску_, _ام_
  { {0x645800c0,0xc4f80015,0xc6d70015,0x3e4f002a}},	//   givi, ضعها_, _لترت, ręty_
  { {0x6e3d003c,0x7a38001c,0x2bf8000a,0xa5db0015}},	//   kksb, _síti, דמון_, _يبرر_
  { {0x8b9c000a,0x96f8053b,0x02050818,0x35fb002b}},	//   ובות, _шест_, узин, _ترسد_
  { {0x64580020,0xd0590036,0x16340036,0x51f5002b}},	//   bivi, ерні_, _тетя, نسکر
  { {0x7a38001c,0xb97c0008,0x90450086,0x765909bf}},	//   _víti, ונחי, انده, liwy
  { {0x8eb2002b,0x339b0058,0x0000006a,0x0000006a}},	//   یمیش, _آخذة_,   ,
  { {0x76590034,0x7d165ac9,0x0000006a,0x0000006a}},	//   niwy, _prys,   ,
  { {0x463a00b2,0x681b0024,0x7bc55aca,0xa0c400c3}},	//   גערע, _kādē, _behu, _نينو
  { {0xd006066c,0x3b0a0080,0x7d1600dd,0x9600000b}},	//   _беше_, него_, _vrys, _ईस्ट_
  { {0x6008000a,0xdea1002b,0xbb431977,0x6b6615b8}},	//   _יִקְ, _دیجی, берк, уква
  { {0x6e3d5acb,0x60db5acc,0x7d165acd,0x64580085}},	//   cksb, orum, _trys, zivi
  { {0x7afb0011,0x76590026,0x3e79002e,0xe8fa0174}},	// [e9e0] ăuta, diwy, rétt_, эла_
  { {0x9cbb000a,0x2ca4001a,0x7bc54a5a,0x60db5ace}},	//   _רציח, ímdu_, _gehu, irum
  { {0x98c50024,0xe7f5000b,0x64585acf,0x76590034}},	//   ātās_, ीज़ा_, vivi, fiwy
  { {0x442200dc,0x8f9a000a,0xc7a9000a,0x75d6002b}},	//   _ők_, גיעי, לב_, ايشا
  { {0x39360010,0x6c9a000a,0x89360015,0x4254002b}},	//   _сэнс, ֲשֶׂ, _إعجا, ینتر
  { {0x60db5ad0,0x07a30a96,0x64580003,0x83f80ffe}},	//   drum, _гарн, uivi, текс_
  { {0x69c6064e,0x2b0d000b,0xa857000a,0x76590034}},	//   _keke, हिएँ_, _עילה_, biwy
  { {0x80cf005d,0x60f80063,0x7e0e000b,0xdb0700cb}},	//   _दिखे, вния_, ियोग_, rbjø
  { {0x19570053,0x64580604,0xc4860484,0xa566002b}},	//   ָביל_, pivi, _блак, _صدرن
  { {0xddd6006f,0x9f5e5ad1,0x69c65ad2,0xb4fb004f}},	//   _chyž, leté_, _leke, _אלמר
  { {0xe0cf0086,0xb7db0053,0x04930029,0x69c60079}},	//   يزی_, עקטי, _اللح, _oeke
  { {0xde590010,0x71a60010,0x6ce70484,0x9f5e0003}},	//   тамі_, _садз, ліге, neté_
  { {0xd24f003b,0xd6570008,0x2be9000b,0xfd440033}},	//   _عنه_, ריכת_, _जादू_, бэрн
  { {0x9f5e0003,0x7659002a,0x62805ad3,0xb478004f}},	//   heté_, ziwy, llmo, דָֽי
  { {0xab955ad4,0x7a38001a,0x69c65ad5,0x307b000a}},	//   рављ, _lítu, _beke, _ראונ
  { {0x200e002e,0xceb82aad,0x9f5e0003,0x3e790034}},	//   _hafi_, mpę_, jeté_, réts_
  { {0x18550010,0x2bcb0001,0x62805ad6,0xb999021a}},	// [e9f0] аваў, _пуно_, ilmo, твах_
  { {0xee3f0089,0xf9880015,0x67d500fd,0x9848006b}},	//   lký_, انكي_, рожу, ляха_
  { {0x4c9a0008,0xcdd50008,0x69c600dc,0xb8680001}},	//   _שבתו, ֹךְ_, _feke, ујте_
  { {0x7982005c,0x3aba000a,0x69c60c8f,0x95c400c3}},	//   żowa, _שמרנ, _geke, ميمه
  { {0x76590026,0x8e98004c,0xa50930d1,0x2a6c0030}},	//   riwy, אדאו_, тела_, édbe_
  { {0x69c60298,0x200e00d9,0x32d54630,0x76590216}},	//   _zeke, _nafi_, ацис, siwy
  { {0x76590034,0x8c1c000a,0x8c38004f,0xe8df00a1}},	//   piwy, תווי, רטוס_, _biệc_
  { {0xd5f900b2,0xa3e7000b,0x8b58000a,0xc1050021}},	//   _שפּר, _भाव_, טיוס_, لوبي
  { {0x681b0048,0x60db0064,0x66040020,0xd24e0015}},	//   _tādē, urum, õike, بني_
  { {0x60db5ad7,0x60c2002a,0xb97c004c,0x28da000b}},	//   rrum, _dwom, ענזי, यूटि
  { {0x0e6609ac,0x9e6601e3,0xf3670788,0x3f690658}},	//   икон, ивод, _стан, тино_
  { {0x6fa7005d,0x81a70029,0x9045002b,0x60db52ac}},	//   _फ़्रू, _إحال, انگه, prum
  { {0x69c65ad8,0x200e008c,0x3ea9003d,0x72040015}},	//   _reke, ömiä_, _čatu_, _دونم
  { {0x8b660029,0x70b20015,0x69c65ad9,0x1d070054}},	//   لازم, _بموض, _seke, јери_
  { {0x3f790053,0x69c60d27,0xca560054,0x2fc75154}},	//   _באַס, _peke, атањ, _ieng_
  { {0xee3f04af,0xc3320008,0x6b630033,0xe9d719cc}},	//   cký_, חול_, ікта, икс_
  { {0x3ea75ada,0x61f60061,0x6602007c,0x9e650021}},	// [ea00] _hunt_, _öyle, veok, _داون
  { {0x3ea70a9c,0x69c60111,0x4999004a,0xa7b603ae}},	//   _kunt_, _weke, утся_, рсај
  { {0xf7190010,0xdb050134,0x3ea70251,0x7bdb000a}},	//   ліцы_, _afhæ, _junt_, _בקיו
  { {0x3ea70084,0xeef60053,0xbef6000a,0xe0c7009a}},	//   _munt_, ימער_, יצעו_, _وز_
  { {0x24e70001,0x9f5e0152,0x49bb000a,0x96270015}},	//   имци_, reté_, _במכס, شكوك_
  { {0x2baf014e,0x3ea00020,0x54530036,0x62800079}},	//   _ज्ञा, _liit_, овіт, wlmo
  { {0x96ba0001,0xa3e7000b,0xfbd3000a,0x68e45adb}},	//   _југу_, _भार_, קתה_, luid
  { {0x7a3806d4,0x8556002b,0xa6950099,0x91b7006b}},	//   _títu, _پیتر_, _груј, агът_
  { {0xe8df00a7,0xddd4005c,0x3ea7003e,0x51860484}},	//   _việc_, łaśc, _aunt_, шука
  { {0x7afe003c,0x249e00d9,0x7870008c,0xceea002b}},	//   _oppt, _uitm_, tävy, پردن_
  { {0x3817000a,0xe8df0016,0x2d8001c2,0x3ea0007c}},	//   בקים_, _tiệc_, _ayie_, _biit_
  { {0x333b000a,0x68e45adc,0x16190065,0x0000006a}},	//   _שתאמ, kuid, नएयर_,
  { {0xa116002b,0x7870008c,0xc5f3000a,0xceb8002a}},	//   _خوشت, sävy, חדר_, spę_
  { {0xcc890074,0x2fc700d9,0xe0fb0008,0xee3f0107}},	//   انسه_, _geng_, _סלול, ský_
  { {0xa3ab000b,0xfaa90015,0x22462453,0x442e0079}},	//   कुट_, اهري_, _klok_, ijf_
  { {0x9f9b0008,0x4379000a,0xbae40015,0xbdfb0021}},	//   _בסופ, רְשׁ, تكفي, _شرعا_
  { {0x68e400be,0x97a71d9f,0xddc6007f,0x79820535}},	// [ea10] guid, арел, likş, żown
  { {0x29d70023,0x7d0d166f,0x3e720046,0x25bd0034}},	//   ủa_, _isas, dáty_, wbwl_
  { {0x78ba0089,0xd7590021,0xd7f80054,0x224601d7}},	//   _čtve, دلات_, јуу_, _olok_
  { {0x32040050,0x68e40c98,0xf650002b,0x9989002a}},	//   jemy_, buid, وئن_, okaż_
  { {0x38c90086,0x32042384,0x69cd007c,0x22ae002a}},	//   _حاجی_, demy_, maae, _ręka_
  { {0x22460035,0x1cb80008,0x8936000a,0xc3050015}},	//   _alok_, סלול_, _הרשע_, مبعو
  { {0x68330089,0x36d401c5,0x82f9006e,0xebd8000a}},	//   _výdě, _морр, ارتز_, שֵׂי_
  { {0x3ea700c0,0x20190024,0x7d0d0201,0x80d8000b}},	//   _runt_, ēsim_, _osas, _मिशे
  { {0x3ea70440,0xca2a0053,0x0f1f000b,0x2fc75713}},	//   _sunt_, רופֿ, यम्स_, _peng_
  { {0x3ea00020,0xd0090001,0x644a01f1,0x3ea75add}},	//   _siit_, ћене_, chfi, _punt_
  { {0xa3ac005d,0x3ea90024,0x69cd007c,0x224602de}},	//   _गलत_, _čats_, kaae, _flok_
  { {0x3204005c,0x2909003f,0xce4a0054,0x9756000a}},	//   cemy_, kwaa_, узме_, מיתו_
  { {0xdb15005c,0x361a0008,0x52740029,0x42740015}},	//   kazó, אורד, _بالز, _بالآ
  { {0x557600b2,0x711a0008,0xaf490002,0x61e95ade}},	//   מערן_, _תוספ, _مشعل_, lgel
  { {0x3ea00020,0xdb1c2a6e,0x7d0d33e1,0x61e95adf}},	//   _tiit_, larú, _esas, ogel
  { {0x68e40896,0x61e95ae0,0x200505ba,0x9989002a}},	//   tuid, ngel, leli_, ddał_
  { {0xf8aa006e,0x61e951fe,0x6e245ae1,0x9a9d00ce}},	// [ea20] ادره_, igel, _inib, турi
  { {0x07ba0015,0x68e45ae2,0x7a385ae3,0x20055ae4}},	//   اهضة_, ruid, _píts, neli_
  { {0x1779008f,0x7afe362a,0xd63a0036,0x7bce5ae5}},	//   асць_, _uppt, ляді_, mabu
  { {0x80d8005d,0x8f880008,0x61e90111,0x7bce0375}},	//   _मिले, בְנֵ, jgel, labu
  { {0xdb050092,0x4e7b0053,0x644a5ae6,0xc4f70015}},	//   _nghê, נאנצ, thfi, معوا_
  { {0xed59002c,0x2005065d,0x3e720107,0xdb1c0030}},	//   úži_, jeli_, ráty_, darú
  { {0x386f00dc,0x8c1b000a,0xca32000a,0x20055ae7}},	//   égre_, טוסי, ִם֙_, deli_
  { {0x764b0026,0xd7570015,0x7a380046,0xc3050015}},	//   chgy, _طلقت_, _zítr, تبهو
  { {0x7bce139a,0x754603ae,0x32041495,0x50b7002b}},	//   kabu, _уназ, remy_, یدید_
  { {0x20055983,0xa054005e,0x6e245ae8,0xf993000a}},	//   geli_, івні, _anib, הרח_
  { {0x8f340124,0x4386003b,0x487b0008,0x01da00e5}},	//   ценц, _الاق, רטיס, _موضع_
  { {0x3f820024,0x9cf50036,0x479b004f,0x0000006a}},	//   āku_, озмі, טייס,
  { {0x91e303e7,0xa3ac000b,0x2ca9183a,0x20055ae9}},	//   _хоче, _गला_, _quad_, beli_
  { {0x50960124,0x9f5e5aea,0x20053f00,0xfc67006b}},	//   _уређ, letí_, celi_, съмн
  { {0x10130086,0x7ff7000a,0xdb150030,0xa3d0000b}},	//   _ربود, _הזוג_, vazó, _वजन_
  { {0x7f830029,0xeda7005e,0x7bce007c,0x2aa8159d}},	//   _علين, _ушко, aabu, стро_
  { {0x2dd80029,0xec790054,0x6c850015,0x64484ede}},	// [ea30] _طبية_, упâ_, _ولعم, _oldi
  { {0xb3de0033,0x7bce5aeb,0x4fb8004f,0x0000006a}},	//   _жнiў, cabu, שֶּׂ,
  { {0xdc380053,0x69cd00f2,0xdb1523c9,0x2bf6000a}},	//   _לאזט_, paae, razó, _ומתן_
  { {0xceb30053,0x9f5e0089,0x2281005c,0xa5f91017}},	//   ליע_, jetí_, póki_, реду_
  { {0x25fa005d,0xfdf80008,0x7ae704af,0x20050061}},	//   ोज़ी_, מצאת_, lujt, yeli_
  { {0x20050011,0x61b3005d,0x42d909ef,0xa97a000a}},	//   xeli_, ीर्ष, афия_, _כארכ
  { {0xdc3c000a,0x2c7b0046,0x42d5005e,0x20055aec}},	//   רעור, mádě_, цілу, veli_
  { {0x2a690020,0x7bce01c9,0x2c7b0046,0xdb1c001a}},	//   nnab_, zabu, ládě_, tarú
  { {0xdb1c002e,0x61e95aed,0xca1a000a,0x91ad000b}},	//   rbré, rgel, בֵיכ, ीडबै
  { {0xe5880008,0x1f65005e,0x61e95aee,0x7e6d007c}},	//   _הָעָ, жком, sgel, _ajap
  { {0x6443005c,0x32b80015,0x2bbf000b,0xf3f00015}},	//   mkni, _هدنة_, ्रना, _سأل_
  { {0x8e560036,0x7ae75aef,0x3619000a,0x7c250034}},	//   ітні, dujt, בוֹד, _anhr
  { {0x7af500b8,0x20055af0,0x7bce5af1,0x64485af2}},	//   etzt, peli_, tabu, _yldi
  { {0xd59a000a,0x644316a9,0x859a000a,0x459a004c}},	//   יברל, nkni, ישרו, יסרע
  { {0xa3e7005d,0xea5a00d0,0xeb9a10a1,0xf21e000b}},	//   _भाई_, арај_, рив_, _मोड़_
  { {0x3eb8006f,0x225f0e8c,0x08c60a31,0x6e245af3}},	//   írte_, niuk_, жбан, _unib
  { {0x7bce00b6,0x38cb002b,0x7cc60058,0x4c360138}},	// [ea40] pabu, لالی_, _بزعم, _дэнт
  { {0xb902000b,0xfbd2002b,0x76490061,0x4425007c}},	//   _धि_, _کتک_, _aley, _nnl_
  { {0xdb050092,0x870a004a,0xd70a0088,0x95ca004a}},	//   _nghè, реев_, рнее_, аула_
  { {0x5efa0053,0xd5b00002,0x13b4000b,0x9f5e0144}},	//   יפעד, رفت_, ुर्भ, xetí_
  { {0x37c60015,0x0000006a,0x0000006a,0x0000006a}},	//   _ويحف,   ,   ,
  { {0xd3720086,0x2bbf005d,0x68f600aa,0xad1b000a}},	//   وهش_, ्रया, mtyd, יונר
  { {0x68f600dd,0xdc9b004c,0x9989002a,0x7649199a}},	//   ltyd, ביסל, adań_, _fley
  { {0xcad70008,0x7649002e,0xb8820089,0x44250020}},	//   קופת_, _gley, řída, _enl_
  { {0x661d002e,0x32180089,0x2bbf000b,0x68f63cfe}},	//   _óska, ěry_, ्रमा, ntyd
  { {0x644301d1,0x3faa0054,0xdced0061,0x6448005b}},	//   ckni, шњим_, _ayağ, _uldi
  { {0xc7b3013a,0xa6e70092,0xc49b000a,0xc431002b}},	//   ובת_, _ngừ, _כשמת, _سکوت
  { {0x68f600dd,0x7ae70227,0x2bbf000b,0xdb250003}},	//   ktyd, vujt, ्रभा, _épée
  { {0xa06a0124,0x22570086,0x212b0012,0xa0b805ab}},	//   _када_, _بلند_, ächt_, _углу_
  { {0x7ae706db,0x2bb80015,0x2d85003d,0x2bb70046}},	//   tujt, قافة_, āle_, děcí_
  { {0x9ee80029,0x68f62035,0xaa95009b,0x22a701d3}},	//   _افعل_, etyd, зивч, _tőke_
  { {0x42db00b2,0x7ae70227,0x49bb00c3,0xbda70058}},	//   יקלע, rujt, شارد_, _بحثو
  { {0xb9550063,0x37ab4ed9,0x7e7d0043,0x4e940015}},	// [ea50] чващ, атен_, mosp, _تشور
  { {0x7e7d00f2,0x7ae70057,0x6604007c,0x0000006a}},	//   losp, pujt, õikn,
  { {0xcd34002b,0x108b004f,0x9848004e,0x68f60073}},	//   _فریب, בָאֽ, цята_, atyd
  { {0x8f9b000a,0x4efb004c,0xbddb0003,0x7e7d5af4}},	//   ביבי, שלאג, chèt, nosp
  { {0xe5340127,0x4425028d,0x09b6000a,0xe5070015}},	//   мець, _pnl_, _מפרט_, تباي
  { {0xe458005e,0xe3b10015,0x7e7d5af5,0xa8490015}},	//   ожі_, ررت_, hosp, _السم_
  { {0x33190033,0x03a2067a,0xdb1e0012,0x6443236b}},	//   сіля_, нишо, _gepä, rkni
  { {0x765b0064,0x27e90045,0xdbd7008c,0x64435af6}},	//   _umuy, şină_, lääk, skni
  { {0xf4870001,0xc6920053,0xa1120015,0x225f01c2}},	//   _дужн, _טאל_, فويت, riuk_
  { {0x8f750036,0xc4d2000a,0x0000006a,0x0000006a}},	//   зумі, _נגב_,   ,
  { {0xd498005e,0xa695000a,0x0695000a,0x20190046}},	//   _єру_, ּכָה_, ּדָם_, ěsi_
  { {0x12fa0008,0x3ea40bc2,0x3952002a,0x7e7d5af7}},	//   _להעב, ömt_, yzys_, gosp
  { {0xe1670029,0xaf35002b,0x0000006a,0x0000006a}},	//   _بداي, زرگت,   ,
  { {0x00ba0008,0x7ff5002b,0xd479004c,0x1d07012e}},	//   _המסמ, _رستا, מאָל, џери_
  { {0xd00e040b,0xe452000a,0x3af5004a,0x5f770015}},	//   _إلى_, תֶר_, мятс, _باشر
  { {0x7f3a000a,0xcf24002b,0x68f600aa,0x61fb0ffa}},	//   _לעצו, _آروي, ttyd, nful
  { {0xdb1c0077,0xfd120015,0xf8a7009b,0x0000006a}},	// [ea60] mbrí, _أجب_, звук_,
  { {0xa3e7014e,0x2bbf005d,0x2c22000b,0x67ba0015}},	//   _भाग_, ्रणा, माओं_, صائح_
  { {0x4c3b0008,0xd7ef0029,0x39461d7f,0xdc3b0008}},	//   _התיב, اكم_, šos_, _העיר
  { {0x8b8b000f,0xcb8b000a,0x3a390160,0x68f60535}},	//   _לָכֶ, _לְכֹ, _gosp_, ptyd
  { {0xdb1c5af8,0x1a9b0053,0x69c45af9,0x5c36004f}},	//   ibrí, _ליטע, mbie, ּרֶן_
  { {0xf8bf0084,0x9cd7000a,0x94230054,0xdb1c0034}},	//   _bréf_, לונה_, емље, mbrâ
  { {0xd25a0063,0x6ada000b,0xeab6000a,0x2bbf000b}},	//   йци_, _बटोर, הִ֥י_, ्रता
  { {0x66f700a3,0x7d0405e3,0x68e45afa,0xd6db000a}},	//   _ממלא_, _opis, orid, _לחלל
  { {0xc4c50015,0x68e400da,0x0000006a,0x0000006a}},	//   _يتكو, nrid,   ,
  { {0x39570008,0x645d0007,0x9ed8000d,0x68e45afb}},	//   פשים_, _įsig, омот_, irid
  { {0x68e4002d,0x7d041dda,0xa2d6002b,0xddcd0046}},	//   hrid, _apis, _ريشت, _zmař
  { {0x648d002f,0x33050015,0x68e42e25,0xd5cc0065}},	//   núin, _تذكّ, krid, ारिज
  { {0xed580010,0x127b0053,0x6282253c,0xd657000a}},	//   зоў_, _פאדע, _ikoo, ליטת_
  { {0xe1650029,0xbddb0152,0xb9110092,0x2bbf000b}},	//   _تدمي, thès, _thoả_, ्रधा
  { {0x3ffb0008,0x6ffb009d,0xdddd0024,0x68e45afc}},	//   _הפוע, _ההופ, nosū, erid
  { {0xaa5812c9,0x69c40012,0x68e45afd,0x1f130058}},	//   пису_, gbie, frid, _أبوج
  { {0x2bbf005d,0xdbd700f2,0x58d9004a,0xddc40046}},	// [ea70] ्रदा, tääk, юдая_, _ujiš
  { {0xbddb0152,0x37ab0299,0xb8140054,0x5c7401b0}},	//   chèr, стан_, ндуј, _плыт
  { {0x212b0023,0x68e40020,0xdbd70020,0xdc3c0008}},	//   ̣ch_, arid, rääk, _לעזר
  { {0x6f79000a,0xceb3000a,0xd24600c3,0xcad6000a}},	//   חְנו, גיף_, _شن_, _קורת_
  { {0x5dfc0053,0x1c22000b,0x2509002b,0x3eae5612}},	//   מפאנ, माचल_, ترای_, _luft_
  { {0x05740086,0x3cfc000a,0x18a40033,0x61fb03e1}},	//   راند, צלונ, _паўм, wful
  { {0x645d0007,0x69cf08c0,0xb8830089,0x2bb8000a}},	//   _įsid, _kece, řísp, הפוך_
  { {0x4254004a,0x0000006a,0x0000006a,0x0000006a}},	//   етьт,   ,   ,
  { {0xfbbf000b,0xf4090015,0x660b0030,0xe4d90015}},	//   ्राम, _ويرى_, megk, _ذوات_
  { {0x69c425b5,0x09aa000b,0xc0c80054,0x3e79006f}},	//   zbie, _कल्य, чуће_, méty_
  { {0x69c4005c,0x2d8c005c,0xd4360008,0x7d045afe}},	//   ybie, ędem_, _קטעי_, _spis
  { {0xf38c0053,0xdb1c002e,0xd2d40015,0x7982002a}},	//   _פראָ, tarþ, _أغلب, żowi
  { {0x76ac0061,0x3e79006f,0xae0d000b,0x20551119}},	//   _işye, néty_, िज़न_, _откр
  { {0x7d0400bd,0xac930010,0xc19a000a,0xe8df0016}},	//   _vpis, каўш, _ושני, _chọc_
  { {0x7d040050,0xde8a0015,0xddcb0085,0x78bd18df}},	//   _wpis, _وضعه_, žišn, _atsv
  { {0x7ae10014,0xe7f0000b,0x629b008c,0x26dc006f}},	//   álta, _चाहा_, nmuo, ávom_
  { {0x78a70298,0x7d04016f,0xda650115,0x68e45aff}},	// [ea80] _bijv, _upis, رافي, urid
  { {0xb8f6014e,0xd8840086,0x9f88002e,0x88c50015}},	//   _सब_, رهای, _kóði_, عتقل
  { {0x907a000a,0x86c30015,0x7986002a,0xbd46002b}},	//   קטעי, َيْن, _wykw, _رنگي
  { {0xa3d0005d,0xceb20135,0x69cf464a,0xc869000a}},	//   _वजह_, דיא_, _gece, בן_
  { {0xe5a30477,0x15ff000b,0xd49a2815,0x0000006a}},	//   вици, ोज़र_, орк_,
  { {0x22b50024,0x62822c46,0x33940033,0xdb070a88}},	//   _sāka_, _skoo, налё, rbjö
  { {0x62890176,0xdb050092,0xdb0e0030,0xdb0702dc}},	//   fleo, _nghì, mbbó, sbjö
  { {0x32630010,0xdb1c005c,0x6114000d,0xc114049d}},	//   ктыв, laró, едиу, емиј
  { {0x12770015,0x22ae002a,0x95830317,0xddd6002a}},	//   بحوث_, _męki_, _алте, _omył
  { {0x8006006b,0x653b000a,0x629b5b00,0x853b004f}},	//   фчие, _ועמד, amuo, _וגמי
  { {0x2bbf005d,0x3fc80086,0x6148001a,0xdb1c5313}},	//   ्रसा, يدگی_, félö, tarý
  { {0x752d002c,0xe2460015,0xbddb0003,0x96fb000a}},	//   ťaze, _تخطي, thèq, חלטת
  { {0xdc3a01e2,0xbd450029,0x69cf23d9,0x61560015}},	//   _açıl, رنسي, _rece, _تنشئ
  { {0xe167002b,0x28b5000b,0x7d1d02de,0x3f870034}},	//   _تضمی, _अंबि, rvss, _fynu_
  { {0xe515000b,0x200c5b01,0x8aa701f3,0x2019003d}},	//   _दैनि_, medi_, драд, ēsit_
  { {0xdb12002d,0x8e380015,0x200c5b02,0x9e380015}},	//   ógái, _يسير_, ledi_, _يسيء_
  { {0x69cf02c1,0x0bab0015,0x386f0003,0x28f8004a}},	// [ea90] _vece, _وادى_, égro_, меть_
  { {0x9cd8000f,0x200c57a5,0x478b0033,0xaab6009a}},	//   _חוזה_, nedi_, осем_, بگیر_
  { {0xd6db085d,0xe7190015,0x0c780015,0xe7f0000b}},	//   юта_, ثيات_, _تصيب_, _चारा_
  { {0xb9350083,0x2bbf005d,0x69dd0134,0x6280005c}},	//   _земј, ्रवा, _udse, jomo
  { {0x62805b03,0x660b0ffd,0x9585002a,0xc50b0015}},	//   domo, regk, knął, تتال_
  { {0x200c016f,0xf8bf0152,0x7bc700c0,0x37c50029}},	//   jedi_, _crée_, nbju, _سيرف
  { {0x22920074,0xe7840124,0x27f8099c,0x11d50036}},	//   گليس, _ауто, žený_, ніпр
  { {0x3ea90509,0xb9c8000a,0x6b6e0030,0x62805b04}},	//   _niat_, ֵּחַ_, lőgé, gomo
  { {0x9f5e022d,0x629b0007,0xdb1c0144,0x3f872402}},	//   hetä_, rmuo, narò, _synu_
  { {0x629b00f2,0x200c227c,0xaec5009b,0x95850535}},	//   smuo, gedi_, нбол, gnął
  { {0x62890077,0x62805b05,0x0000006a,0x0000006a}},	//   pleo, bomo,   ,
  { {0x531a0008,0x76590061,0x6fbf000b,0x9f5e008c}},	//   _מועצ, _çayı, _श्रं, detä_
  { {0x61d6013a,0xc6920053,0x71d6000a,0xa3b3000b}},	//   _נוסף_, טאט_, _נוסד_, _टला_
  { {0x200c5b06,0x26dc006f,0x3f870034,0xdb050030}},	//   cedi_, ávok_, _tynu_, _eghí
  { {0xf8bf03af,0xa3c2005d,0xdb1c0030,0x68ed0034}},	//   _até_, ूरत_, varó, euad
  { {0xc332011f,0xf2d20053,0x1e1a0015,0xdb1c002a}},	//   נון_, טעל_, _رغبة_, waró
  { {0x2bbf000b,0xdb1c002a,0xe9660015,0x4c8605f8}},	// [eaa0] ्रशा, taró, رارً, _плив
  { {0x7d570008,0x6d461ed9,0x986a0015,0xdd7b000a}},	//   _נייד_, myka, أحرف_, _מטפל
  { {0x2bf70008,0x75d60015,0xf989000a,0xd7760015}},	//   _אמין_, فيضا, צר_, رائع
  { {0xc8690008,0xdeba000a,0x1e1b004f,0xd6cf0058}},	//   זן_, למעל, ּֽאמ, صقه_
  { {0x68ed0896,0x628012fb,0x3a23004a,0x200c078e}},	//   cuad, vomo, _смяг, yedi_
  { {0x7c3e0048,0x28b5005d,0x69d60b51,0x64a32f16}},	//   _jopr, _अंति, laye, гача
  { {0x6fd6005d,0xf4870086,0x38b60293,0xd3d70015}},	//   _मजबू, راهی, _hær_, ربوا_
  { {0x69d60064,0xd257042b,0x62800091,0xc104012c}},	//   naye, ець_, uomo, نوعي
  { {0x200c1e8c,0x25d7000a,0xc1b7002b,0x50665b07}},	//   tedi_, _רומן_, رايط_, етна
  { {0x14d70008,0x752d002c,0x73c60015,0x69d60061}},	//   _נובל_, ťazc, _أيام, haye
  { {0x62802026,0x69d60064,0x442c5b08,0xe802005d}},	//   pomo, kaye, _ind_, र्या_
  { {0x200c0844,0xddcd002a,0x443e5b09,0xa25a0015}},	//   sedi_, _ukaż, _hot_, _عشاء_
  { {0x443e0e6d,0x5c07010f,0x2262002a,0x7afc00bc}},	//   _kot_, нява, ęską_, etrt
  { {0x7ae10014,0x315700b2,0x90970036,0x9f5e00f2}},	//   álto, _אידן_, _звіт_, tetä_
  { {0x7bc700c0,0xe814005d,0x443e5b0a,0x7c3e1e01}},	//   rbju, ड़ना_, _mot_, _dopr
  { {0x7bd50046,0xda090015,0x68ed0f9e,0x25a9125b}},	//   sazu, بيره_, tuad, žali_
  { {0x442c0b7c,0x5dc80008,0xa3c2005d,0x6e2d2dec}},	// [eab0] _ond_, _אֶתְ, ूरा_, _inab
  { {0x443e03c2,0x2bee005d,0x3cf80015,0x75eb0030}},	//   _not_, _जाएं_, _أعيد_, közü
  { {0xbbbf005d,0x6e2d0012,0x207b004c,0x0c740015}},	//   ्रीक, _knab, לאמא, _حديد
  { {0x442c36cb,0x38b6002e,0x75cf0030,0x6b6e0030}},	//   _and_, _fær_, dőzó, sőgé
  { {0xcc34002b,0xd7e7005e,0x38b6001a,0x94791923}},	//   _شریع, _піво, _gær_, мску_
  { {0xdddd005c,0xe7871560,0x1cb8004f,0x22ae0535}},	//   nisł, _зубо, עלול_, _lęku_
  { {0x6d46005c,0x3bbc000a,0x35b5004a,0x92f60040}},	//   zyka, המוד, _аббр, نفوذ_
  { {0xd36e0029,0x442c5b0b,0xd2980033,0x02d1000b}},	//   تهى_, _end_, нтыі_, _सबीन
  { {0x03f90001,0x84150063,0x443e5b0c,0x409501e8}},	//   _онај_, _имах, _fot_, крот
  { {0x443e0708,0x6e2d0335,0x661b1437,0x644a53d4}},	//   _got_, _anab, _hauk, ckfi
  { {0xc7b2000f,0xdb1c001a,0x7e660012,0x44fb5b0d}},	//   יבי_, jarð, tikp, lê_
  { {0x7c3e5b0e,0x6d461212,0x2f54034e,0x3f8b003d}},	//   _sopr, tyka, утьс, ācu_
  { {0x7c3e5b0f,0x614503ae,0x69d60061,0x0d99056d}},	//   _popr, _јела, vaye, етры_
  { {0x6d46005c,0x2d8c0024,0x661b571f,0xbf650015}},	//   ryka, āde_, _lauk, _لدعو
  { {0x2fd60086,0x6b6304f7,0x80d5000b,0x7f19005e}},	//   _شويد_, акра, _मौते, _цілу_
  { {0x661b5b10,0x3eb7003d,0x6e960015,0x6d4653c3}},	//   _nauk, ēgtā_, _جلعا, pyka
  { {0x7c3e0064,0x69d63396,0xa3c1000b,0x7aee0045}},	// [eac0] _topr, raye, ंडा_, subt
  { {0x69d6038d,0x38b60293,0x47c3005e,0x0b460e71}},	//   saye, _vær_, ибув, _анон
  { {0xd5af0268,0x5c37000a,0x443e5b11,0x5b360033}},	//   ис_, _סרטן_, _rot_, _рэпу
  { {0x60db0020,0x88c60015,0x44380034,0x443e5b12}},	//   ksum, _لتسل, _ŵr_, _sot_
  { {0xad6d000a,0x34b30015,0x443e0b8b,0xc4f70015}},	//   ּכוֹ, لمنز, _pot_, نعوا_
  { {0x8d5b013a,0x60db0305,0x7d090064,0xd4c50015}},	//   וכני, dsum, çesi, اغني
  { {0x442c018b,0xdbcd001a,0x6353004a,0xe802000b}},	//   _vnd_, _móðu, ившу, र्णा_
  { {0x661b14bd,0x3f98001a,0xdddd002a,0xa19402a3}},	//   _gauk, ýrum_, zisł, лайч
  { {0xd010003b,0x6fd6000b,0x44fb016e,0x22ae002a}},	//   ملة_, _मजदू, cê_, _ręku_
  { {0x442c0bcf,0x6e2d5b13,0x70540086,0x67210085}},	//   _und_, _snab, اندا, _šlji
  { {0x1df9054f,0x60db0abb,0x76400297,0xc7d7000a}},	//   нены_, asum, _komy, כויי_
  { {0xe802014e,0xdd0e005d,0xdb1c002e,0xdddd002a}},	//   र्ता_, िबंध_, varð, wisł
  { {0xb8840089,0x3f82005c,0xc237000a,0x61e25b14}},	//   _zvíř, łku_, _שרדו_, _idol
  { {0xfc67006b,0xdb1c001a,0x1dc3000b,0xbbbf000b}},	//   тъмн, tarð, _व्रत, ्रेक
  { {0x0ff70015,0x8ff70067,0x1bd430db,0xb097004f}},	//   _شعوب_, _شرور_, рося, _שדוח_
  { {0x201c00dc,0xba740029,0x6e2d5b15,0xbdf50004}},	//   _havi_, لاقت, _unab, _спиј
  { {0xd8b8002b,0x5e440015,0x1da7000b,0x661d001a}},	// [ead0] ندلا_, _خَيْ, _गणित, _óski
  { {0xdbcd002e,0x44fb016e,0xf8bf0003,0xa8540033}},	//   _góðu, vê_, _créa_, акуч
  { {0x201c0064,0xf7700115,0xe802000b,0xcdd5000a}},	//   _mavi_, يام_, र्धा_, ָךְ_
  { {0x36180036,0x60c20943,0x44fb016e,0x764001f9}},	//   кцію_, _otom, tê_, _comy
  { {0x7640005c,0xda5a0008,0x97c70015,0x35f8002b}},	//   _domy, _נכשל, _لتأم, ضرند_
  { {0x201c04ed,0xd7c90086,0x61e25518,0xc48402a3}},	//   _navi_, _سوره_, _adol, алік
  { {0x9f9a007c,0x60c25b16,0x661b5b17,0x22d40138}},	//   _jääk_, _atom, _tauk, ацыё
  { {0xf772000a,0x60db5b18,0xdb1e006f,0x1fbd0065}},	//   _הקל_, tsum, _nepý, ोर्ड
  { {0x61e20176,0xe0d10029,0x00850080,0x39490035}},	//   _ddol, حزب_, ллио, nyas_
  { {0xbfc50010,0x04950031,0x201c02b9,0xb4c1000b}},	//   ыбок, _صلاح, _cavi_, ूठी_
  { {0xe814014e,0x481600b2,0xbbbf005d,0xd24e002b}},	//   ड़ता_, אַכן_, ्रैक, زنی_
  { {0xc332000a,0x64412675,0xed5a0054,0xf15907be}},	//   _לוב_, _holi, еом_, _пиеш_
  { {0x9e630033,0x64415b19,0xe216004f,0x865a004f}},	//   свяд, _koli, _תקנח_, תדרי
  { {0x61e21ed9,0xfba5000b,0xa134002b,0x394909cf}},	//   _zdol, _गृहम, _خرمش, dyas_
  { {0x6441010b,0x09e65b1a,0x4fd6000a,0x8f99004c}},	//   _moli, ловн, _עוקב_, _איַי
  { {0x224d00dc,0x7e6402f2,0x64415b1b,0x9d560369}},	//   nkek_, _umip, _loli, _منعت
  { {0x0e9b000a,0x7e9b000a,0xa9260033,0x1e57000a}},	// [eae0] _אשקל, _אסקו, ыдал, _תשפר_
  { {0x69cb002e,0x64411acf,0x6ab80030,0x764000aa}},	//   ðger, _noli, _évfo, _somy
  { {0x224d0014,0x29195b1c,0x7bfb0053,0x76401212}},	//   kkek_, _essa_, _אפיצ, _pomy
  { {0x3179005c,0x56930036,0xeef60053,0xe9df0125}},	//   ższy_, баєт, טמער_, _dlús_
  { {0xcdf70008,0xe5340a61,0x752d006f,0x27ef0247}},	//   רמני_, рель, ťazn, álné_
  { {0xd92b0008,0xcd97000a,0x98360033,0x644140a1}},	//   _אֵלָ, נדסת_, _сэмі, _coli
  { {0x3d16005d,0x29005b1d,0x644152a5,0x59b8000b}},	//   _पैसे_, ltia_, _doli, _अलार
  { {0x77910086,0xe5a62f14,0x99891d56,0x201c5b1e}},	//   _بیما, _биби, ndaş_, _savi_
  { {0x3014008f,0x29005b1f,0xe3f6002b,0x64410220}},	//   адпр, ntia_, _مثاب, _foli
  { {0x68fb000a,0xa0670099,0x93b50016,0x64415b20}},	//   עליה, лања_, _hãn, _goli
  { {0xde590036,0xa3c1005d,0x290000f2,0xf8370008}},	//   вані_, ंडर_, htia_, אנית_
  { {0x7054002b,0x2900008c,0xe731004f,0x0000006a}},	//   انگا, ktia_, קֵי_,
  { {0x71e700e6,0x24c7000a,0x9be7005e,0xe2970033}},	//   _صفوف_, ְּךָ_, лівк, _сац_
  { {0x93b50092,0x29190781,0xb6050030,0x645804d1}},	//   _lãn, _rssa_, ováí, nhvi
  { {0xce950063,0x2d8400b8,0x7ac40286,0x3378000a}},	//   _какъ, ümer_, йсте, דְּב
  { {0x0000006a,0x0000006a,0x0000006a,0x0000006a}},	//     ,   ,   ,
  { {0x52d1000b,0x99d40015,0xae05000b,0x19580174}},	// [eaf0] _सब्स, إتفا, ष्णन_, гаты_
  { {0x7d0d00b6,0xad1a000a,0x6458006f,0x0000006a}},	//   _ipas, _סותר, jhvi,
  { {0x35b50124,0xdb1e0a40,0xfbab005e,0xd7590015}},	//   абер, _depó, _ятий_, خلات_
  { {0x2bbf014e,0xbb3a004c,0x644103b8,0x6d5d0069}},	//   ्रका, _סערי, _soli, ozsa
  { {0xa3c1005d,0x89da000a,0xb4c1000b,0x8cb8000a}},	//   ंडल_, _בחרי, ूठे_, ָּׂא_
  { {0x6d5d003d,0x752d006f,0x68ed2e83,0x9cd8000a}},	//   izsa, ťazo, mrad, נווה_
  { {0xd3d80115,0x64415b21,0x23d40033,0x8c1c000a}},	//   ابها_, _voli, сцір, גווי
  { {0x645800f2,0xdb1e00dc,0x6441002a,0x7cec001a}},	//   ahvi, _repü, _woli, _jörð
  { {0xe0d6044e,0x76590026,0x6441357e,0x6ec1003d}},	//   авы_, mhwy, _toli, _mēbe
  { {0x3e6f00f2,0xd0090001,0x6d5d0030,0x80f8006b}},	//   yötä_, њене_, dzsa, ухът_
  { {0xd371003b,0x68ed0107,0x7d0d5b22,0x7f750ded}},	//   _بها_, hrad, _apas, рупц
  { {0xd1310029,0x76590026,0x2229002b,0x3f8e0034}},	//   _وما_, nhwy, _جزئی_, _dyfu_
  { {0x463a0053,0x52840029,0x763a004c,0x661d001a}},	//   דערע, _النك, דערג, _ósku
  { {0xcee8002b,0x75290085,0xd12e002b,0x68ed5b23}},	//   خرین_, _mrez, _آمو_, drad
  { {0x7d0d0024,0x05d5005d,0xdb1e016e,0xb8820046}},	//   _epas, दराब, _repó, říka
  { {0x29001550,0x60c9003f,0x0f7a0447,0xdb1c0003}},	//   ttia_, opem, _ברצל, ncré
  { {0x78660c1d,0x68ed5b24,0x98e60015,0xf8660432}},	// [eb00] аказ, grad, شكاو, авао
  { {0x60c934ae,0x8cdb000a,0x29005b25,0x9cdb000a}},	//   ipem, _שחית, rtia_, _שקיפ
  { {0x48790080,0x7bdc5b26,0x68ed5b27,0xa2f4000b}},	//   устя_, maru, arad, _इमेज_
  { {0x75293e75,0x8f9a000a,0x6445008c,0x7bdc5b28}},	//   _brez, דיעי, öhin, laru
  { {0x752941d5,0x68ed3057,0xbcfb0003,0x6aa45b29}},	//   _crez, crad, rzég, mmif
  { {0x3ce9005d,0x2c6d016f,0xd90d002b,0x7bdc4535}},	//   _जिसे_, ožda_, _سیم_, naru
  { {0xfbd30008,0x66e30cec,0x6604007c,0x60c9088a}},	//   חתו_, _мора, õiks, epem
  { {0x76591817,0x7bdc064e,0x471b00f3,0x7aee0091}},	//   chwy, haru, _בולג, irbt
  { {0xba57000a,0xdb1c0003,0x69c3002a,0x60cd0061}},	//   יסקו_, scrè, śneg, _çaml
  { {0x7bdc003f,0x5038005e,0xc7b1000a,0xcfa60c96}},	//   jaru, упою_, ּ֑י_, ишни
  { {0xb7db0053,0x75291e32,0xbf660015,0xc897004c}},	//   כקיי, _zrez, شددو, שכיז_
  { {0xe4db0089,0x6d22000b,0xd36f0015,0x6e6741f8}},	//   zšíř, मिंग_, _تهم_, ртож
  { {0x224b0012,0x8cf40033,0xd23b004f,0x71a60138}},	//   öcke_, озяц, _שגדל, _тадз
  { {0x3f8e0026,0xf3f1000a,0xe8e00016,0xa067006b}},	//   _tyfu_, ּ֣ם_, _nuốt_, _кача_
  { {0xaa671c55,0xab95247d,0xb09b000a,0xa09b000a}},	//   атак, сиві, _שיור, _שיוט
  { {0x0f570008,0x645d0007,0x68ed35ec,0x25a00046}},	//   _כיום_, _įsim, trad, žily_
  { {0x7d0d0293,0x97c70015,0x6e95002b,0xb999006b}},	// [eb10] _upas, لتام, _پلکا, увах_
  { {0x68ed5b2a,0x7bdc3d32,0x27c700ce,0xd7c9009a}},	//   rrad, caru, рщаг, اوضه_
  { {0xd1260074,0x76590176,0xfbd20008,0xbcfb00dc}},	//   _کم_, thwy, _מתי_, széd
  { {0x56950080,0x68ed5b2b,0x752934f6,0x0000006a}},	//   щает, prad, _prez,
  { {0x95090029,0xe5700002,0xba9a000a,0x24f8004a}},	//   اقتك_, وطه_, _תסרי, инцы_
  { {0x63c80015,0x65340015,0x4464005e,0x04b402a3}},	//   لِهِ_, ترمذ, овів, ісія
  { {0x03a50080,0xcb14004c,0xbcfb0030,0x4345009b}},	//   щико, ַלץ_, nzéb, сейв
  { {0xa1150029,0xeb780008,0x1306004a,0x3e720796}},	//   موعت, יעוץ_, ёный_, ošte_
  { {0x0fd901d9,0x7583002b,0x60c90003,0x75290085}},	//   льны_, _بیشم, upem, _urez
  { {0xdb1c0f63,0xddc60046,0xa988000a,0x60c901f6}},	//   scré, tiků, יָתִ, rpem
  { {0x339500a2,0x8659000a,0x0eaa004a,0x7bdc5b2c}},	//   _الاز, ָדָי, лкой_, varu
  { {0x02440029,0xf7720008,0x07360008,0x60c95b2d}},	//   _وَلَ, לקי_, צטרך_, ppem
  { {0xd0090001,0x645d0091,0x51870b1e,0x7af5003d}},	//   _беле_, _įsij, _тужа, euzt
  { {0x0c79004a,0x9f5e0046,0xe1f90091,0xfbc320b9}},	//   ассы_, letý_, lgų_, збро
  { {0x4fd6000a,0x648d0125,0x2bbf0065,0x7bdc5b2e}},	//   _הוצב_, lúis, ्रजा, raru
  { {0xe1f900df,0xc3320008,0x6ec40029,0xe8e00092}},	//   ngų_, הול_, _بتوق, _suốt_
  { {0x61e60030,0xfdf7000a,0xc7b60015,0x7bdc5b2f}},	// [eb20] ókli, _הצפת_, مصاع, paru
  { {0x6aa4007c,0xe73a5b30,0x0000006a,0x0000006a}},	//   smif, лез_,   ,
  { {0x46ea0254,0xa3cb000b,0x076a0015,0x2b500045}},	//   уден_, लडन_, دماً_, âncă_
  { {0x54e60029,0xf8a9000a,0xb5da0058,0x569300ce}},	//   مستق, גש_, اباء_, паєт
  { {0xd625003b,0x6fe20046,0x3dfb000a,0x2bbf000b}},	//   تعلي, nící, רלנד, ्रचा
  { {0x68460254,0x5334110d,0xe856006e,0x5997004f}},	//   _унга, жект, _انسد, _לככב_
  { {0xdc9b0053,0xb7db0008,0x8c1b000a,0x6d40008c}},	//   װיקל, _תקלי, רוצי, ämaj
  { {0x3ce9005d,0xd25704ab,0x34b6009a,0x0000006a}},	//   _जिले_, йцы_, _همرز,
  { {0x6fe202d5,0xdfd0003b,0xe3b20086,0x0446070e}},	//   jící, وية_, _فرا_, _леан
  { {0x50b70029,0x661d002e,0x6fe20046,0xdce4003d}},	//   حديد_, _óskr, dící, _dziļ
  { {0xe2ca010f,0x20020050,0xbfaa0080,0x9e15017f}},	//   _след_, ęki_, ытие_, одні
  { {0x91ba0029,0x539b0008,0x3e720046,0x44d6002a}},	//   _إطار_, _גיבו, yšte_, oł_
  { {0xc5f3000a,0xbd6b09c2,0x216700af,0x0000006a}},	//   הדר_, урне_, _лици_,
  { {0xe0fb0008,0x645d0007,0x6fb40015,0xa0c4002b}},	//   _עלול, _įsik, _بمثا, _هيچو
  { {0x600b004f,0x0000006a,0x0000006a,0x0000006a}},	//   _תִדְ,   ,   ,
  { {0x78ba0089,0x44d6005c,0x2246007c,0xd357000a}},	//   _čtvr, kł_, _jook_, זילי_
  { {0xbcfb0030,0xd8bb0015,0xcce70058,0xddcf00d4}},	// [eb30] széb, ادرا_, _اسبي, ancţ
  { {0x22460041,0x44d6005c,0x8b670015,0x97a701c5}},	//   _look_, dł_, _هاجم, брел
  { {0xb09b0008,0x625c0152,0xe1f90007,0x28b5000b}},	//   ניבר, _géog, ygų_, _अंकि
  { {0x3e72016f,0x4efb004c,0x7ae10030,0xc6d400c3}},	//   pšte_, רהאו, áltu, ستمت
  { {0x44d6005c,0x47d50015,0x04450004,0x26c71147}},	//   gł_, _ويحر, желн, ūno_
  { {0xe3b100a2,0xf7b8002b,0xd83b0088,0xa349011e}},	//   ورث_, _هدفش_, _сэм_, изла_
  { {0x44d60050,0x22465b31,0xf7700015,0x889a000a}},	//   ał_, _book_, _كاف_, _כבשי
  { {0xe1f900df,0x04c90015,0x22465b32,0x90c50740}},	//   ugų_, _نوري_, _cook_, обие
  { {0x80390036,0x212b5b33,0x8467006b,0xe1f90091}},	//   аїну_, ích_, _лъже, rgų_
  { {0x648d002d,0x22b5003d,0x94770040,0x6fe20046}},	//   rúis, _sāku_, _ادرا, vící
  { {0xe80b005d,0x53340457,0xe3b00015,0xdef80033}},	//   स्या_, _нефт, _كرم_, быў_
  { {0x59a9000b,0xfbc9000a,0x9992002a,0xa6e2001a}},	//   कधार, _ית_, gdyś_, æðil
  { {0xafe50080,0xe1f00015,0xdb0a006f,0x0d9a0033}},	//   _долл, _أسم_, ľník, ртны_
  { {0xf1b200a3,0xb87b001a,0xdb0a013f,0x61fb0a63}},	//   _חסד_, _svín, žník, lgul
  { {0x3ce6005d,0x6fe20089,0x3ea0002d,0x625c0003}},	//   _झटके_, sící, _thit_, _féod
  { {0x44d6005c,0x6d4f0034,0x3ced0085,0x625c0003}},	//   ył_, byca, ševa_, _géod
  { {0x8bb60015,0xc212000a,0x68460033,0xe8fa024f}},	// [eb40] _وإدا, והן_, онаа, рлз_
  { {0x40e8000a,0xb79600af,0x0000006a,0x0000006a}},	//   מַעֲ, орећ,   ,
  { {0x6e2400b6,0x2bd0021e,0xf6e5005e,0x99d60015}},	//   _kaib, _त्या, зцін, _وتحا
  { {0xb87b0084,0x452a0740,0x0000006a,0x0000006a}},	//   _hvíl, ижен_,   ,
  { {0x6e240035,0xa4d4005e,0xe4a61d8c,0x224629ba}},	//   _maib, чолі, орко, _rook_
  { {0xd4d9008f,0xc9530008,0x44d6005c,0xf2c60a6c}},	//   сьці_, _חמש_, rł_, осин
  { {0xd2a6005e,0xd25a0718,0x68e4157d,0xdddd006f}},	//   _тiль, ици_, lsid, losť
  { {0xd378010b,0x61fb2c17,0x69c42d24,0xdb9b004c}},	//   _neće_, ggul, ncie, ױספר
  { {0x22b50024,0x601f0007,0xb97a000a,0xdddd006f}},	//   _sākt_, kšmė, ינֵי, nosť
  { {0xbfaa018f,0xf993000a,0x6e3600da,0x73360015}},	//   итне_, ורח_, _anyb, _ورائ
  { {0x2246003e,0x38170008,0x389b0053,0xd7bb00a3}},	//   _took_, חקים_, שיינ, יציר
  { {0x28db014e,0x69c4005c,0x64480107,0x2d850061}},	//   मीडि, jcie, _hodi, şlem_
  { {0x61e001e2,0x9999006f,0x70560015,0x12a90015}},	//   maml, _kosť_, _ونصا, _ادلى_
  { {0xd00f0029,0x61e05b34,0xd1490086,0xdddd002c}},	//   _لله_, laml, _دشمن_, dosť
  { {0x6e240152,0x64480738,0x9f5e0077,0x4e970015}},	//   _faib, _modi, retó_, _وشعر
  { {0xddc401e2,0x1f5b000a,0xaf5b004f,0xbe640058}},	//   _iliş, _כדוא, _ככוכ, _يهوي
  { {0xed580001,0x79c80115,0xaa580098,0x8e840015}},	// [eb50] _моћ_, توقف_, циту_, _تليه
  { {0xf72b0080,0x69c45b35,0xf8070033,0x64485b36}},	//   ицей_, acie, ўчан, _nodi
  { {0x87e4005f,0xddc65b37,0x61fb0064,0x501b0008}},	//   ьюте, likš, ygul, שובו
  { {0xfb1a0008,0x8f8b000a,0x645a12fe,0x3e7205ba}},	//   _פורמ, בְדֵ, _alti, ošta_
  { {0x6a3a0008,0x672e00c0,0xaa3a0008,0x27f60089}},	//   _הגרפ, _erbj, _התרח, ádné_
  { {0x7c25018b,0x4914005d,0x32d5000d,0x644825d5}},	//   _jahr, _नैटो_, пцис, _codi
  { {0xd6c30074,0x62840007,0x9999002c,0x69dd0375}},	//   _آمری, čion, _dosť_, _kese
  { {0x6b7c103d,0x22b50024,0xe0d90080,0x645a234c}},	//   ירונ, _sāks_, бви_, _elti
  { {0x6e24002f,0xe80b014e,0x5155017f,0x36040021}},	//   _raib, स्था_, ятку, _توقف
  { {0x6448010b,0x6e242cdd,0x7c255b38,0xd9b8000b}},	//   _godi, _saib, _nahr, _अल्ट
  { {0x69c4005c,0xa2070064,0xe803000b,0xe456004c}},	//   ycie, şmış_, _लाना_, _ציעט_
  { {0xe80b005d,0x4427003e,0x4425013c,0x53140015}},	//   स्ता_, ldn_, _hal_, _تذكر
  { {0xd378016f,0x128a0086,0x91ba0008,0x98b40046}},	//   _veće_, _امنی_, _המני, _řeči_
  { {0xb0420092,0x8b080089,0xdb1c5b39,0x7e6d007c}},	//   _thưở, jdří, scrí, _emap
  { {0x765b0064,0x69dd5b3a,0x09b4000b,0xf092000a}},	//   _oluy, _bese, ंख्य, _רנו_
  { {0x78b50048,0x7db6002b,0xdddd006f,0x69c45b3b}},	//   _aizv, _عصبا, tosť, ucie
  { {0x7c255b3c,0x38cb0086,0xd7ea0010,0x68e40007}},	// [eb60] _fahr, مالی_, ймае_, usid
  { {0x39790191,0xc0790092,0x68e45b3d,0x69c45b3e}},	//   істю_, _điệp_, rsid, scie
  { {0x3bbb0008,0x9bbb000a,0x1ae3004a,0xb802000b}},	//   _למיד, _לציפ, _поэм, र्गम_
  { {0x7d560008,0x7c250107,0xed56000a,0x69dd5135}},	//   ּיַד_, _zahr, ּבַר_, _gese
  { {0x7bde0d25,0x27e15b3f,0x61e00061,0x44255b40}},	//   _kepu, bahn_, vaml, _bal_
  { {0x442508e0,0x7bde00d9,0x33940010,0x6abe00b8}},	//   _cal_, _jepu, малё, _kupf
  { {0x212f002d,0x44255b41,0x026a004a,0x8c1b000a}},	//   _argh_, _dal_, йший_, מוסי
  { {0xcb130008,0x877b000f,0x442511c5,0xd2500015}},	//   גלה_, _האלי, _eal_, ئنة_
  { {0xe803000b,0x64485b42,0x645d0091,0x3952008c}},	//   _लामा_, _todi, _įsiv, nyys_
  { {0x05770015,0x61e05544,0xd3e4002b,0xdbf10046}},	//   _عملة_, saml, _آقای, tříd
  { {0xd9a9000b,0xdb1c02ad,0x0000006a,0x0000006a}},	//   _कण्ट, gbrü,   ,
  { {0x44255b43,0xb2bb000a,0xc333004c,0x7982002a}},	//   _zal_, _המאר, _רוף_, żowy
  { {0x02430015,0x69dd2ee9,0x7d1d0079,0x220b004f}},	//   _سَوَ, _rese, uwss, _ה֤וּ
  { {0x69dd0375,0xddc60091,0x7bde003d,0x3e720091}},	//   _sese, rikš, _cepu, ršta_
  { {0x9f6200f2,0x5f9300d0,0xcb34006b,0x7bde5b44}},	//   ävän_, _пишт, неръ, _depu
  { {0x7c25018b,0x58d903a9,0x2f97000a,0x0f7b000a}},	//   _wahr, ждая_, _מכון_, _לאוב
  { {0x7c255b45,0xba740067,0x6443002a,0x69dd5b46}},	// [eb70] _tahr, رافت, yjni, _vese
  { {0x69dd0746,0x7bde49c0,0x17f80015,0x7af20061}},	//   _wese, _gepu, كرمة_, üktü
  { {0xc05301ac,0x182a002b,0xe7190015,0x7e7d4b8a}},	//   עזע_, تقلی_, تيات_, onsp
  { {0x44250f75,0xf1c20091,0x7e7d05b0,0xd5b10058}},	//   _sal_, nešę_, nnsp, نفا_
  { {0x04c80015,0x7e7d32e1,0x44250673,0xdb1c0030}},	//   كوني_, insp, _pal_, bbró
  { {0x87070033,0x7bc7002a,0xe3b1002b,0x9cd8004f}},	//   _нябе, ncju, پرت_, לודה_
  { {0x290900f2,0xc3e40015,0xd5fb0016,0x64430123}},	//   ltaa_, رثوو, _chụ, rjni
  { {0xe2910015,0x44255b47,0xcb140643,0x3a29058a}},	//   خذت_, _wal_, תלק_, ndap_
  { {0x2909022d,0x00190010,0x44255b48,0xca1a000a}},	//   ntaa_, оўны_, _tal_, חֵיכ
  { {0x8ee9058f,0xe045005e,0x78600061,0xe47b0015}},	//   омов_, єнни, _gövd, _احرص_
  { {0x290900f2,0x7bde5b49,0xf48402a3,0xe8020065}},	//   htaa_, _repu, _чутн, र्टा_
  { {0x2242002e,0x7bde145f,0xdb1c0028,0x7e7d07a3}},	//   ökkt_, _sepu, rbrü, gnsp
  { {0x2d840064,0xdb1c0012,0xbcfb0030,0x0000006a}},	//   çme_, sbrü, szén,
  { {0x786003c0,0x2bba0015,0x3952008c,0x00ba000a}},	//   _köve, تاحة_, vyys_, _ומסמ
  { {0x786000dc,0x6e460029,0xa3c5000b,0xab270076}},	//   _jöve, _ينتم, _एलन_, мора_
  { {0xe80b005d,0x3e720091,0xf9fa0058,0x8db600ce}},	//   स्सा_, mšto_, تفرع_, _оспі
  { {0x7bde0375,0x7ae700aa,0x7860025d,0x4c86027c}},	// [eb80] _tepu, asjt, _löve, _олив
  { {0x3e720796,0x80d5000b,0x60cd0061,0x786002dc}},	//   ošto_, _मौज़ू, _çamu, _oöve
  { {0x78600014,0xc606008f,0x395200f2,0xb6c5017f}},	//   _növe, дзей, syys_, есій
  { {0xe802000b,0xf8bf0077,0x99d60015,0x7afc5b4a}},	//   र्जा_, _fué_, _تتدا, murt
  { {0x051a0015,0xc5360015,0x94aa0725,0xf8bf01f6}},	//   تزاع_, بعاث, отка_, _gué_
  { {0xd5fb0092,0x62840007,0x3e720091,0xa6e2001a}},	//   _phụ, čiom, kšto_, æðsl
  { {0x645d00df,0xa29402a3,0xe803000b,0x320d2ff3}},	//   _įsit, накі, _लाता_, ffey_
  { {0x72170063,0xc7a303ad,0xee3f006f,0xe617006b}},	//   джър_, _риск, tmým_, _одс_
  { {0xf503010f,0x23cf000b,0x3e720085,0x84060054}},	//   _изто, _स्वद, ešto_, _опаж
  { {0x7afc00df,0xc0570036,0xe802000b,0x68f60034}},	//   kurt, дію_, र्चा_, iryd
  { {0x68f60034,0x77f7000a,0xddc40085,0xb87b001a}},	//   hryd, ומיד_, _smiš, _svík
  { {0xc7b30008,0x68f60134,0x7afc5b4b,0x0e34005e}},	//   כבת_, kryd, durt, внюю
  { {0xed58008f,0x106a0029,0x3e722823,0x5c07006b}},	//   доў_, _وحتى_, ašto_, мява
  { {0x40eb0008,0xe57100a3,0xd6df002a,0x7afc3fda}},	//   _וַהֲ, אַל_, ółka_, furt
  { {0x6ffb009d,0x3ffb000a,0x9e67002b,0xbe9b0015}},	//   _והופ, _ופוע, _يابن, _وضعا_
  { {0x29090945,0x68f60026,0xda090015,0xda7b005e}},	//   ttaa_, fryd, ثيره_, іяв_
  { {0xf8bf0467,0xa3cf005d,0xf9900015,0xf807005e}},	// [eb90] _qué_, वुड_, لبك_, дчен
  { {0x290900f2,0x7afc5b4c,0x98a00091,0xfeca000a}},	//   rtaa_, burt, yvią_, ַמְּ
  { {0x8bd6013a,0x2909022d,0x628400df,0x0c740070}},	//   _אותו_, staa_, čioj, _جديد
  { {0xfe100092,0xf8bf0152,0x95c50021,0x8afa000a}},	//   _lắng_, _tué_, ريته, _צהרי
  { {0xceb40008,0xfc30002b,0xe5040015,0x24e9005e}},	//   דיף_, _صحی_, نبوي, їмки_
  { {0x3cfc0053,0xd8da0008,0xacda004c,0xfe100016}},	//   קלונ, _מקשר, פֿני, _nắng_
  { {0x2607004a,0xf7730369,0x0000006a,0x0000006a}},	//   _очаг, _شاس_,   ,
  { {0xfbb80008,0x5999000a,0x65950a96,0x64585b4d}},	//   ופות_, ּשֻׁ, _забу, akvi
  { {0xd378016f,0xf1b90085,0xafe50974,0x0000006a}},	//   _veća_, ješe_, нопл,
  { {0x60090164,0x752d006f,0x64585b4e,0xd5b800ce}},	//   чном_, ťazs, ckvi, _іст_
  { {0xbcfb0014,0x7d1600dd,0xe3b30031,0x4f79006b}},	//   szél, _spys, _شرط_, ящия_
  { {0x371600b2,0x3f990024,0xc7b2000a,0x2d96004a}},	//   ײַטל_, āsu_, טבי_, ергс
  { {0x916c0023,0xd656000a,0xd5b2000a,0xee371c31}},	//   _gồm_, גירת_, ָׁם_, хня_
  { {0x629b0176,0xe006005d,0xc4d20008,0xfe100092}},	//   lluo, _शायद_, רגם_, _gắng_
  { {0x6a860063,0x6fd5000b,0x7b9a002b,0x1e961466}},	//   елва, _म्यू, سپرس_, _прир
  { {0x7afc00b8,0x2bd0000b,0x629b008c,0x625c442f}},	//   rurt, _त्रा, nluo, _léon
  { {0x2cab0046,0x6a8306a6,0xe8fa1fdd,0x7afc5b4f}},	// [eba0] _židů_, улта, яла_, surt
  { {0xb8820264,0x68f60034,0x4b2601c6,0x69d601de}},	//   _čísl, rryd, _змов, sbye
  { {0xe61a1f5c,0x629b0091,0x7bdb004f,0x0000006a}},	//   зде_, kluo, _מקיו,
  { {0xcf920053,0xd94607be,0x55065b50,0x68f65b51}},	//   נטא_, _земи, ечка, pryd
  { {0xceb3004c,0x645d0091,0xa9bb000a,0x49bb004f}},	//   איא_, _įsir, _מזכר, _ממכס
  { {0xa5d0000b,0xd4670a0b,0xdceb0085,0x64c30040}},	//   _ड्रौ, ниче_, šićn, ديول
  { {0xc795008f,0xfbd30008,0x27950010,0xe6c50015}},	//   _арты, נתה_, _аштр, _لتقي
  { {0x179b0135,0x2d9e005c,0x93770015,0x41e602a3}},	//   _זילב, ętej_, عصور_, хіка
  { {0xe0cf0086,0x320a002a,0xc48600c2,0x0000006a}},	//   یزی_, ęby_, _злак,
  { {0x66020030,0xbf3400ce,0x649600d4,0x0000006a}},	//   lgok, внощ, tâiu,
  { {0x1df9054f,0xfe100016,0x3f98001a,0x66020030}},	//   мены_, _vắng_, æru_, ogok
  { {0x877b0135,0xde590033,0x6602222d,0x0000006a}},	//   לטיז, фамі_, ngok,
  { {0xfe6e0074,0xc05a01c6,0x7c87008a,0x4237004f}},	//   تگو_, _нік_, еуве, _רנדל_
  { {0x61e2130f,0xd12f0015,0xac2400af,0x0000006a}},	//   _heol, _دمه_, лфск,
  { {0x60c240c6,0xab950185,0xe451000a,0x8aa70897}},	//   _huom, тиві, בֶן_, ерад
  { {0x9f9b0008,0x66e70089,0xbf9b0008,0x1f370008}},	//   _מסופ, _léká, _מיוש, _טרור_
  { {0x60c2008c,0x6aad5b52,0xad270058,0xe91800ce}},	// [ebb0] _juom, rmaf, _أربو, ноті_
  { {0x61e20026,0xb9940015,0x7522002a,0x7d7c0643}},	//   _leol, الْب, dwoz, _מנחו
  { {0x60c2022d,0xf8bf0f1c,0x3ea901c2,0x36d40004}},	//   _luom, _prés_, _khat_, гохр
  { {0x201e0014,0xcad60008,0xa4d5005e,0xcf93004c}},	//   heti_, _שורת_, воді, אטע_
  { {0x60c20007,0x5a340146,0x201e5b53,0xe534005e}},	//   _nuom, _снят, keti_, лець
  { {0x201e0a00,0x66020030,0x2ba80065,0x61e201f9}},	//   jeti_, agok, _गरमा, _aeol
  { {0xe7840063,0x5c380008,0x61e200dc,0x201e50cd}},	//   _буто, תרון_, _beol, deti_
  { {0x61e2002d,0xc10500a2,0x629b0da3,0xe296009b}},	//   _ceol, نوبي, uluo, кащ_
  { {0xd24e0029,0x74f8004a,0xd5140040,0x6fd5005e}},	//   تني_, _петр_, _مبلغ, кінц
  { {0x60c200df,0x3ea902f2,0x62802cd2,0x857408f7}},	//   _duom, _ahat_, anmo, _слух
  { {0x200b005c,0xd4360053,0xf1d2005d,0x41d2000b}},	//   ęci_, _שרעק_, _ध्वन, _ध्वस
  { {0x32550180,0x74d8000b,0xf1bb000b,0x7172002b}},	//   _швер, नीकृ, _उलटन, اهیا
  { {0x26fe005d,0x1e830010,0xd0090001,0x7ebe0095}},	//   _उम्र_, рлям, _желе_, _rūpe
  { {0xb4fa013a,0xac970015,0xaf490015,0x201e5b54}},	//   ופשי, َنَا_, _يشغل_, ceti_
  { {0xfe0a014e,0x3af5004a,0x67cf0030,0xeb973cda}},	//   _वापस_, лятс, zőjü, вир_
  { {0xc0b90089,0xc33201d8,0xba1a0015,0xad9b0046}},	//   řádá, סון_, بيرا_, rfúr
  { {0x8e97000a,0xbebc003d,0x661d001a,0xb4e0000b}},	// [ebc0] _בדקו_, svīt, _ósky, _दबे_
  { {0xbc6a0086,0xed570008,0x7d5701ac,0x3cfb00a3}},	//   _آمدن_, _סביר_, _סייד_, _קלינ
  { {0xe803005d,0xf62a0036,0x26c3001c,0x645d0007}},	//   _लारा_, діли_, _cujo_, _įsip
  { {0x66020091,0x201e5b55,0x7c2e5b56,0x0000006a}},	//   ugok, zeti_, ldbr,
  { {0x201e0064,0x61e20026,0x2d8f0134,0xd46a0054}},	//   yeti_, _reol, _øget_, миде_
  { {0x61e25b57,0x2900000c,0x12ca0015,0x7c2e0aa0}},	//   _seol, muia_, وظبي_, ndbr
  { {0x60c25b58,0x53ac000b,0x65c601c5,0xf7431098}},	//   _suom, टेंश, _абба, _керо
  { {0x75d30015,0x625c0003,0x78bc5b59,0x3b09004f}},	//   _نيفا, _géol, _hirv, ׂמוּ_
  { {0xba9b0008,0x41180015,0x1a9b004c,0xbcfb0030}},	//   וסקי, ريدج_, ויקע, rzék
  { {0xb4250086,0xb033004a,0xa0670099,0x14d7000a}},	//   _معمو, аньш, кања_, _סובל_
  { {0x442c002f,0x57fb000a,0x201e5b5a,0x0857000a}},	//   _iad_, וליו, reti_, דבים_
  { {0xb87b002e,0xc2e90029,0x442c069b,0x60c20b9f}},	//   _hvít, _أعلم_, _had_, _tuom
  { {0xc6930008,0x4ea40010,0x442c5b5b,0xa7d8000b}},	//   שאר_, ррэа, _kad_, यरफ़ॉ
  { {0x3ea9003e,0xd3660086,0xd0100070,0x5cb80033}},	//   _what_, مه_, _طلب_, кляў_
  { {0x3ea903c2,0x3b840010,0x1fa30063,0xefb00086}},	//   _that_, алёг, _кръг, _دیدگ
  { {0xfe0a005d,0x442c38b7,0xcfb7004c,0xaa64006b}},	//   _वायस_, _lad_, _בלוי_, атук
  { {0x443e038d,0x8d740074,0x2d8f0152,0xa954005e}},	// [ebd0] _ont_, _پايا, _âge_, акті
  { {0xf1b90cd4,0xfcab002b,0x442c5b5c,0x6e2d5b5d}},	//   neša_, _تابو_, _nad_, _haab
  { {0xcc3a00b2,0x442e0026,0x2bd9000b,0x6e2d5b5e}},	//   _װערט, ddf_, _ब्या, _kaab
  { {0x29000011,0x443e1a37,0x41b4000b,0x2d8f02de}},	//   buia_, _ant_, ुशास, _øges_
  { {0x6e2d1a5d,0x442c5b5f,0x7d0f0030,0x7a88000a}},	//   _maab, _bad_, ntcs, _יָשַ
  { {0x442c002f,0x07f80015,0x2608000b,0x25a0016e}},	//   _cad_, _لرفع_, _हाथी_, üila_
  { {0xc5fb0029,0x442c0495,0xe2995b60,0x68ed129e}},	//   _يعرض_, _dad_, нак_, lsad
  { {0x78bc0064,0x6e2d0019,0x83160015,0x68ed5b61}},	//   _zirv, _naab, اقير_, osad
  { {0x442c002f,0x64b501e2,0x3e62002d,0x625c0152}},	//   _fad_, eğiş, _nóta_, _géom
  { {0xc952000a,0x68ed5b62,0x442c5b63,0x66f5004f}},	//   צמי_, isad, _gad_, ְמָא_
  { {0x5f05008f,0x8ff90086,0x2900003f,0xdb240061}},	//   ызна, ورگر_, zuia_, örür
  { {0x43760053,0x8e860015,0xb87b0046,0x3e725b64}},	//   _גײען_, الحه, _zvít, ošti_
  { {0x92940010,0x865a000a,0xe2900021,0x27250034}},	//   _тацц, גדרי, _بذل_, _lŷn_
  { {0x68ed0134,0xbf650029,0xd9dc000b,0x6abd0125}},	//   dsad, _مدعو, बर्ट, _aisf
  { {0x6eca014e,0x7c2e5b65,0x68ed5b66,0xcb6a0138}},	//   _संयु, rdbr, esad, хаве_
  { {0xddcf0011,0x78bc5b67,0x29000045,0x3e720091}},	//   ricţ, _sirv, tuia_, kšti_
  { {0x799d0176,0x2d850064,0x7e641a5d,0x68ed2d55}},	// [ebe0] _cysw, şler_, _ilip, gsad
  { {0x29000011,0x20c90016,0x7c3e5b68,0xb3e7005e}},	//   ruia_, _múi_, _unpr, _змiс
  { {0xf7720029,0x2d8f0134,0x7e645b69,0x68ed5b6a}},	//   حاء_, _øger_, _klip, asad
  { {0x9980002c,0x89d50036,0x442c0398,0x61e90c59}},	//   ediť_, _вірш, _sad_, jael
  { {0x20c90092,0x68ed00dc,0x799d0026,0x442c5b6b}},	//   _núi_, csad, _gysw, _pad_
  { {0xe2f80033,0x6f015b6c,0xf3ca0015,0x7bdc0194}},	//   векі_, kulc, ربته_, nbru
  { {0x442c5b6d,0x78630036,0xd4330015,0xf1cf0016}},	//   _vad_, _укрз, صعوب, rạng_
  { {0x82a60080,0x200504ed,0xe2970180,0x9757000a}},	//   ышле, egli_, лај_, _גילו_
  { {0x442c5b6e,0x0657000a,0x71740015,0x2abb004c}},	//   _tad_, _עימך_, شهدا, עמפא
  { {0xdefa03be,0x6e2d0020,0x251b0053,0x1f140010}},	//   ным_, _saab, _אומא, амоў
  { {0x61e90030,0x7bdc02cd,0x2897000a,0x68ed0535}},	//   bael, dbru, רדין_, zsad
  { {0x6e950191,0x7bdc00f6,0x1eab0029,0xbfa7004a}},	//   риму, ebru, عادي_, ытые_
  { {0x2293003b,0xcd07004a,0x7bdc5b6f,0xe283116f}},	//   _النس, ычни, fbru, _улци
  { {0x3e62002d,0x69ba005d,0x6f010089,0x6e2d003f}},	//   _vóta_, ्शनी, bulc, _waab
  { {0x309b0008,0x7e64099b,0x2aab0054,0x6f015b70}},	//   _רשומ, _flip, етао_, culc
  { {0x5bb80080,0x539b000a,0x9ef300c3,0x7e6438b8}},	//   улся_, גילו, _اسوش, _glip
  { {0x9f4501b2,0x28f8004a,0x7c66002b,0x20c90016}},	// [ebf0] valé_, леть_, _چاپل, _xúi_
  { {0xdb1f00dc,0x2c6616af,0x7c66002b,0x68ed4b9c}},	//   ívój, _pôde_, _ناپل, rsad
  { {0x68ed5b71,0x1cba000a,0x57a70004,0x7e64008c}},	//   ssad, _שמתע, ушаа, _ylip
  { {0xaa59017c,0x85c80015,0x25b9002b,0x5695004a}},	//   _риму_, هِمْ_, نهاد_, шает
  { {0xd1260018,0x5887054f,0x61e9143f,0x2005001a}},	//   _بم_, _быва, vael, ygli_
  { {0xc484009e,0xe80b000b,0xa879004c,0x82f50054}},	//   блік, स्खा_, _יאָר, ачиц
  { {0x9980002c,0x9f510064,0xdc3c000a,0xd466110d}},	//   rdiť_, üzü_, תעור, рище_
  { {0xb87b001a,0xf7840015,0xe7840004,0xf772000a}},	//   _tvís, _الفَ, _ѓуро, _וקל_
  { {0x60250033,0xf065025f,0x72b60015,0x7bdc5b72}},	//   адпа, икип, جهيز_, ybru
  { {0x3949016e,0x200502b9,0x3245002b,0x7e640223}},	//   ixas_, ugli_, انکف, _slip
  { {0xfe46005f,0x200504ed,0xd24e0086,0xd1480086}},	//   анно, rgli_, سنی_, نشین_
  { {0xed5a5b73,0x20c90016,0xd1cb01b7,0xddcd00d4}},	//   вом_, _túi_, _чужд_, _rmaţ
  { {0xc0e51a56,0x92b40015,0x7bdc30ce,0xa696000a}},	//   _толк, _احلا, tbru, שכרה_
  { {0xdde50024,0x224d00bd,0x5f75002b,0xddc40091}},	//   āpša, ljek_, _پاتر, _kliū
  { {0xddcd01e2,0x7bdc3b59,0xeb9a165a,0xf092004f}},	//   _ulaş, rbru, тив_, _ונג_
  { {0x3b07000d,0x7e64003f,0x6eca005d,0x8a430015}},	//   јето_, _ulip, _संतु, يَّن

  { {0x7bdc003c,0x64415b74,0xf1b9003d,0x39460033}},	// [ec00] pbru, _onli, iešo_, шнаг
  { {0xddcd0085,0x6d3b004f,0xb87b005a,0x0000006a}},	//   _imaš, _יתפנ, _svír,
  { {0x75e65b75,0xbb46009c,0xabfb000a,0x1bfb000a}},	//   аўле, _тенк, _בהיר, _בליב
  { {0xeabf02b9,0x7ae2002a,0x25a0016e,0x64410a3a}},	//   _giù_, _łotw, üilo_, _anli
  { {0x9633008f,0xe5340418,0xf9920021,0xad9b0030}},	//   ўніц, сель, _ذبح_, egúj
  { {0xb6020089,0x54970010,0x04580015,0x2608000b}},	//   _řádk, авіў_, طلبة_, _हावी_
  { {0xdc370053,0xc3270015,0x24800085,0x3266012b}},	//   שאצט_, لكون_, đim_, итив
  { {0xd257005f,0x64410876,0xfbb7000a,0x5b57000a}},	//   ицы_, _enli, ספקת_, ייצב_
  { {0x26da00f2,0x15fb000a,0xb6bb000a,0x26c704b2}},	//   lppo_, _שהמע, _יצלי, ínov_
  { {0x32ca0023,0xd7aa005d,0x200a007c,0x2a6901c2}},	//   _tùy_, _कराच, übi_, zhab_
  { {0x50b7003b,0xf8370008,0xb80b005d,0xde5900fd}},	//   جديد_, בנית_, स्टम_, гані_
  { {0x62840007,0xe37b000a,0x3e720091,0x0000006a}},	//   čios, _ברבר, kštu_,
  { {0x56b7004c,0x20d40058,0xeda700af,0x0e340138}},	//   יפטן_, _اقتس, ршно, цняю
  { {0x515b0008,0xa0670054,0x2a60007c,0x0000006a}},	//   _בכדו, _ваља_, ekib_,
  { {0xeabf02d7,0xee87005f,0xdb58005f,0xaab70015}},	//   _più_, _выпо, ают_, لإرش
  { {0x8f9b0008,0x59f80080,0xe819005d,0x7afa002e}},	//   _שיהי, иеся_, न्ना_, átta
  { {0x7e7d5978,0x27c7004a,0xfce40054,0x69340a1f}},	// [ec10] misp, ащег, _доњо, онту
  { {0x7e7d5b76,0xe918005e,0x1c390033,0x0000006a}},	//   lisp, рофі_, _ёзны_,
  { {0xc5d506b4,0x3e720091,0x6d5d5b77,0x0000006a}},	//   біль, aštu_, lysa,
  { {0xee32000a,0x8708005e,0x7e7d5b78,0x0000006a}},	//   ּֽא_, реїв_, nisp,
  { {0x224d016f,0xbcfb00dc,0x46120015,0x2608000b}},	//   vjek_, mzés, سوور, _हारी_
  { {0xbcfb00dc,0x24090286,0x7e7d2e65,0x09b6000a}},	//   lzés, унки_, hisp, _לפרט_
  { {0x7ebf0024,0xf8b200f3,0x8c1c000f,0x7e7d008c}},	//   _rūpn, _משך_, דווי, kisp
  { {0x5694078f,0xc2450cec,0x41b4000b,0x06850015}},	//   _даст, сник, ुशंस, _الرُ
  { {0xa1120029,0x224d00aa,0x661b015a,0xf1b9003d}},	//   كويت, rjek_, _ibuk, rešo_
  { {0x442303c0,0x316d0050,0x6441003e,0x7cfe002e}},	//   _új_, rzez_, _unli, _lærð
  { {0x54340086,0x20540063,0xbcfb0f87,0x0219005e}},	//   _برقر, ютър, zzét, _біль_
  { {0x6ed30011,0xf776000a,0x867a004c,0x63bc0030}},	//   _răbd, מעתי_, ָרשו, _úrna
  { {0xd378016f,0xd148002b,0x5f75002b,0x20b50033}},	//   _reći_, _نشون_, شاگر, _лёкс
  { {0xc0b20092,0x7e7d002d,0x9596000a,0xc57a004c}},	//   _mười_, aisp, מכרו_, אָלט
  { {0xcaa60029,0x7fd6000a,0x661b0085,0x4ab4000b}},	//   مصري, _פוקס_, _obuk, ंगलव
  { {0xbcfb00dc,0x88c60015,0x60db003d,0xe78a0046}},	//   gzés, متطل, opum, tíží
  { {0xd378016f,0x2f1100dc,0x3946001c,0xe83b0046}},	// [ec20] _veći_, lág_, ãos_, _řeší
  { {0x7d06022d,0x6e2600dc,0x7188000a,0x2a605b79}},	//   muks, lekb, בְעַ, skib_
  { {0x7cfe0084,0x99560024,0x7d065b7a,0x473a0033}},	//   _færð, _kļūt_, luks, ычаў_
  { {0x4ecc0053,0x69da0011,0x66d4006f,0xfb1b000a}},	//   דזאַ, _ştef, eľký, _גוטמ
  { {0xc0b20092,0x65960015,0xba9b000a,0x753b5b7b}},	//   _cười_, حجار, _תסכי, _cruz
  { {0x6aa40084,0xc1e0000b,0x86ea0040,0x9d1b000a}},	//   llif, नर्ग, _معرف_, רוסט
  { {0xf487002b,0x7d06007c,0x753b02b9,0xf756002b}},	//   حانی, huks, _eruz, _انزج
  { {0x32540036,0x60f80b18,0x66f70008,0x29005b7c}},	//   івпр, ания_, _למלא_, oria_
  { {0xc05a0127,0x26ca26c6,0x3134017a,0xc0b20016}},	//   гін_, _hubo_, цепр, _gười_
  { {0x7d065b7d,0x6aa40012,0x2ef40de9,0x2c1a000b}},	//   duks, hlif, озор, म्मू_
  { {0x6aa43464,0x889b00a3,0x389b00a3,0xa2d30002}},	//   klif, רביי, ריינ, _فيلت
  { {0x6d5d00f2,0x6e670063,0x6e260030,0x02a500ce}},	//   tysa, стож, gekb, _дрім
  { {0xbcfb00dc,0xa3cf000b,0x26ca002a,0x7e7d5b7e}},	//   ezér, वुक_, _lubo_, risp
  { {0x26d85b7f,0x29000251,0x7e7d0938,0x81a50015}},	//   _otro_, dria_, sisp, _بحمل
  { {0xf3f10092,0x60170008,0x307b000a,0x3ec20046}},	//   _học_, _החוף_, _תאונ, ístě_
  { {0x2bd9014e,0xbb840015,0x38c9002b,0x29005b80}},	//   _ब्रा, ألفي, لائی_, fria_
  { {0xbcfb0014,0xdd910086,0x18550033,0x29005b81}},	// [ec30] rzés, _زود_, оваў, gria_
  { {0xd8770015,0xbcfb0030,0x26ca5b82,0x6aa45b83}},	//   حارب, szés, _bubo_, alif
  { {0xf3f10092,0x628501c9,0x501b000a,0x7c3a0003}},	//   _lọc_, éhok, רובו, ôtre
  { {0xadfb000b,0x7c2702de,0x753b5b84,0x29005b85}},	//   ्लिन_, lejr, _pruz, bria_
  { {0x2f110014,0x9f45013f,0x29005b86,0xca36004f}},	//   zág_, valí_, cria_, _ונרה_
  { {0xf7730115,0x18a40033,0x6e260030,0x63c80015}},	//   _فاز_, _наўм, zekb, مِهِ_
  { {0x6bec000a,0x2bf8000a,0x8505002b,0x4dfb000b}},	//   אַחַ, זמון_, _ژورن, ्लाई_
  { {0x6b7c0008,0x9782002b,0x5b7c000a,0xd3780085}},	//   טרונ, _تیمه, טרוא, _neću_
  { {0x7e8b005c,0xb145005e,0x6e260030,0x22560015}},	//   tępn, інол, vekb, تليد_
  { {0x2bd9005d,0x63a1005c,0xe3b300e5,0xef1902c4}},	//   _ब्ला, _tyln, _فرض_, амо_
  { {0x6e2600dc,0x7c27005c,0x8fa50015,0xce4a0054}},	//   tekb, dejr, تمده, азне_
  { {0x7d060945,0x60db0f7a,0x6da60a61,0xe819000b}},	//   tuks, ppum, жима, न्ता_
  { {0x2f110014,0x9f470003,0x6e260030,0x32b80015}},	//   ság_, _mené_, rekb, _ادلة_
  { {0x6e2600dc,0x7d065b87,0x6aa40034,0x61eb0542}},	//   sekb, ruks, wlif, _hegl
  { {0xa09a0053,0x60cb002e,0x7bc80091,0x6fb50015}},	//   _דיסט, _hugm, žduo, _بمغا
  { {0x6289002f,0x44275b88,0x61eb00b8,0x7d063b8e}},	//   nneo, hen_, _jegl, puks
  { {0xbcfb00dc,0x44271bbb,0x61eb5b89,0x7c27002a}},	// [ec40] szér, ken_, _megl, bejr
  { {0xb8060015,0x44275b8a,0xf7e90015,0x62890125}},	//   تبره, jen_, مرمى_, hneo
  { {0xbc6a0074,0xd6cf0029,0x96fa00e6,0x97260115}},	//   _ممکن_, نقل_, شعار_, تفاو
  { {0xf8a90008,0x61eb052a,0x29005b8b,0xd9460076}},	//   דש_, _negl, pria_, _деми
  { {0x44275b8c,0x6fc9000b,0x28c3000b,0x1fa6000b}},	//   fen_, रशां, _वंचि, _ऑर्ड
  { {0x66e63b6a,0x61eb0020,0xe3b20015,0xa5330033}},	//   _мога, _aegl, ورغ_, ьніч
  { {0x61eb00b8,0x60cb0c90,0x07a30937,0x8bad000a}},	//   _begl, _augm, _жарн, ְׁחִ
  { {0xdfd00086,0xa7a70036,0x7c27005c,0x60c3002d}},	//   کيد_, _єкта_, zejr, _ainm
  { {0x61eb02d7,0x3fc80086,0x44275b8d,0x91b7006b}},	//   _degl, یدگی_, ben_, огът_
  { {0x60cb016f,0x70540087,0x44275b8e,0x3ea05b8f}},	//   _dugm, سنجا, cen_, _akit_
  { {0x26c4003f,0x60c35b90,0x625c1bc4,0x883b004f}},	//   _kimo_, _dinm, _séou, בתיו
  { {0x6289002f,0x60c300b8,0x539b000a,0x81460015}},	//   cneo, _einm, _דיבו, _ونان
  { {0xd378016f,0x5d850015,0xf3f10016,0x02b7000a}},	//   _veću_, سلسل, _họa_, _והאם_
  { {0x27170089,0x35cc000b,0x62805b91,0x40340912}},	//   něná_, ़खड़, limo, _хекс
  { {0xf2d8000a,0xcb34006b,0xead40033,0x60cb0012}},	//   מַּל, меръ, дось, _zugm
  { {0x8cf50063,0x7c2702de,0x8ed70015,0x200c001a}},	//   _езиц, sejr, _بذور_, lgdi_
  { {0x44275b92,0x9f475b93,0x5bc70015,0x3eb90012}},	// [ec50] yen_, _rené_, _وتدف, mmst_
  { {0x17fb003b,0x44275b94,0x2988005e,0x96fb0015}},	//   شرطة_, xen_, істо_, لعصر_
  { {0xc5d50036,0x44275b95,0xaab6002b,0x27170046}},	//   піль, ven_, تگیر_, děná_
  { {0xcfb7000a,0x44275b96,0x35b50054,0x628010f7}},	//   קלאי_, wen_, пбер, jimo
  { {0x62805b97,0x61eb5b98,0x7af51116,0x44273bf5}},	//   dimo, _regl, lszt, ten_
  { {0x61eb5b99,0x44275b9a,0x7af50eba,0x19ba000a}},	//   _segl, uen_, oszt, _למרב
  { {0x290900f2,0x29ff002a,0x96f80054,0xe7840054}},	//   luaa_, ałał_, _мерт_, _жуто
  { {0x786000dc,0x7af500dc,0xae0a000b,0x44274502}},	//   _rövi, iszt, _वाइन_, sen_
  { {0x44275b9b,0x61eb02b9,0x25ad0046,0xda7c000a}},	//   pen_, _vegl, _uzel_, ינהר
  { {0xe5c413ae,0xd0090001,0x7af5005c,0x9f455b9c}},	//   _істо, љене_, kszt, talà_
  { {0xf1b9003d,0x62805b9d,0x3ea62341,0x60c30c4e}},	//   ieši_, bimo, зинг, _vinm
  { {0x60cb0035,0x831a000a,0x5e460015,0x82380015}},	//   _tugm, _לועז, أَحْ, _وأنس_
  { {0x7af506e7,0x91870015,0x0d9a004a,0x60cb02f2}},	//   eszt, _بجام, стны_, _uugm
  { {0xc172013a,0x3e620084,0x6ab4005d,0xa1560008}},	//   _אחד_, _móti_, ंग्र, _מבנה_
  { {0xe9df002e,0x09e62372,0xbb4328e9,0xcb6700af}},	//   _snúa_, зобн, нерк, паре_
  { {0x32d10023,0x5efa0008,0xc332000f,0x7f76000a}},	//   _máy_, _הפקד, עון_, _מעצב_
  { {0x090601f3,0x7af513c3,0x09290015,0x0000006a}},	// [ec60] япан, aszt, يسكي_,
  { {0x44e90050,0xe8f70033,0x7d7b000a,0x62805b9e}},	//   dź_, ялу_, _לנפו, zimo
  { {0x6e360064,0x25a40026,0xfc5b000a,0x212d0f21}},	//   _kayb, _syml_, _הכימ, hweh_
  { {0x69b4000b,0x62805b9f,0xcad7004f,0xfb25009a}},	//   _आरपी, ximo, _מוטת_, _کریپ
  { {0x75460010,0xe819000b,0x27170046,0x38b4007c}},	//   яндз, न्हा_, těná_, järg_
  { {0x1c1f000b,0x9d1b000a,0x0000006a,0x0000006a}},	//   म्पल_, מונט,   ,
  { {0x6611022d,0x9f580064,0x29ff005c,0x62805ba0}},	//   ähkö, ürü_, słał_, timo
  { {0xe6170080,0x46a328e5,0x38b40123,0x8717000a}},	//   _ндс_, _засв, färg_, _מקלע_
  { {0xc5d50033,0x62805ba1,0x05660174,0x9f4501c0}},	//   _цісь, rimo, _эван, valá_
  { {0xc4c50029,0x7af5002a,0x2937004c,0xf3f10016}},	//   _قتلو, yszt, לאפן_, _họn_
  { {0x3817000a,0x6562008c,0x6e3637c8,0x4abe000b}},	//   הקים_, lyoh, _bayb, ्दाव
  { {0x20020061,0x93250015,0x2c6f0012,0x645a5ba2}},	//   şki_, _تركن, _müde_, _hoti
  { {0xfd47008f,0x645a0604,0xd366002b,0x3da70033}},	//   чэнн, _koti, چه_, яроб
  { {0x91bb013a,0xd3660029,0x625c0003,0xb17d0107}},	//   _המדי, نه_, _géor, raťt
  { {0x9ee80015,0x7af50030,0x645a04da,0xe810000b}},	//   _بفعل_, uszt, _moti, ालना_
  { {0xbf650015,0x5eeb000a,0x7af51022,0x645a5ba3}},	//   _تدهو, _הַזְ, rszt, _loti
  { {0xa3cc005d,0x02b7000a,0x986f003d,0x7af50030}},	// [ec70] रखा_, להלם_, eļā_, sszt
  { {0x645a5ba4,0x7d280030,0x7e6d07c4,0x8078004f}},	//   _noti, őssé, _hlap, קְּה
  { {0xcdd5000a,0xe6c7002b,0x06f40067,0xab95005e}},	//   ֥ךְ_, ستاي, فسنج, _цині
  { {0x64482e59,0x5694006b,0x68f6002a,0x0000006a}},	//   _andi, нахт, bsyd,
  { {0xd7e70010,0x645a5ba5,0x6a3a000a,0x66040030}},	//   _ніво, _boti, _וגרפ, óika
  { {0xdfc60029,0x38b400c0,0x85b80018,0x42d901b7}},	//   _لي_, gärd_, سانس_, офия_
  { {0xf7940010,0x8bd80135,0x645a191e,0x24960015}},	//   _зарэ, לוגו_, _doti, بنود_
  { {0x9989002c,0xa3be000b,0xb1450342,0xf3f10016}},	//   adať_, ीख़_, днил, _gọn_
  { {0x31140033,0x320d5ba6,0x03c7009b,0xa5355ba7}},	//   нфэс, rgey_, _есем, _юнач
  { {0x7e6d22e1,0x95080015,0x7e840030,0x1f650a1f}},	//   _alap, _رقمك_, dőpa, дком
  { {0x6fa90029,0x68080030,0xc7d6000a,0xf3670132}},	//   تهدف_, léjü, וותי_, _этан
  { {0x68f60026,0xd1b8002b,0x38b40012,0x41b5002b}},	//   ysyd, _کاما_, märe_, _قمار
  { {0xe1f00029,0x20180251,0x38b400b8,0xe0550015}},	//   _إسم_, òric_, läre_, _يختب
  { {0x4e0a005d,0x2489002d,0x91ba000a,0x5399000a}},	//   _वाकई_, éamh_, _ומני, ַיּו
  { {0xfaa60010,0x38b400b8,0xda660115,0x2d9e002a}},	//   даво, näre_, واري, łte_
  { {0x1e950010,0x4e960015,0xfeba0015,0x786002dc}},	//   _прыр, _تشتر, _باتت_, _lövt
  { {0x38b400b8,0x9f47002c,0x08c60127,0xfaa329ca}},	// [ec80] häre_, _mení_, дбан, тато
  { {0x6562003f,0x7ebf0095,0x625c5ba8,0xa84a0015}},	//   vyoh, _rūpi, _léop, غلام_
  { {0xdb2400f2,0xb09a004c,0x38b40b1f,0xfbd3000a}},	//   äräs, קיער, värd_, _בתת_
  { {0x9f470089,0x645a00f2,0x26dc0024,0x75d400e5}},	//   _není_, _soti, īvo_, ريتا
  { {0x28af000b,0x645a5ba9,0x6aa3016e,0x80c9000b}},	//   _जीवि, _poti, _ênfa, _हंगे
  { {0xd4670eb0,0xf1b9231a,0x38b40012,0xcd77000a}},	//   миче_, nešu_, färe_, וענק_
  { {0x645a5baa,0x99820046,0xb87b001a,0x2a72013f}},	//   _voti, _jakž_, _stíg, ohyb_
  { {0x32b7003b,0xd2500029,0xcb130008,0x877b000a}},	//   ودية_, انة_, דלה_, _ואלי
  { {0xd0100029,0x645a5bab,0xb4260015,0x902a3f13}},	//   هلة_, _toti, _يعطو, оцна_
  { {0x7e6d00df,0xf9930008,0x15f8005d,0x64483abe}},	//   _slap, כרח_, ुलकर_, _undi
  { {0xd9ee005d,0xc4c50029,0xa0670004,0xfff5002b}},	//   जरात_, _ستكو, фаќа_, رکوت_
  { {0xe73101d8,0xa40e000b,0x787202de,0x625c0003}},	//   נֵי_, _साँप_, _hævd, _géop
  { {0x6eca000b,0xb17d006f,0xb2bb000a,0x0dc818c3}},	//   _संकु, saťr, _ומאר, дури_
  { {0x212600d9,0xdddd0046,0x60dd2957,0x0000006a}},	//   _ipoh_, pisů, ísme,
  { {0x260f005d,0x69da0011,0xdeef0033,0x7d065bac}},	//   _डाली_, _ştea, _шы_, arks
  { {0x4efb009d,0xda7b0010,0x1efb000a,0x2d9e0045}},	//   _ולהג, цяг_, _ולהע, ştea_
  { {0xf7700086,0xe77c0046,0x63a807a3,0xdff20065}},	// [ec90] یام_, výší, _lydn, _आजाद_
  { {0x37ab017a,0xd117000a,0xd7f10015,0x48ab01f3}},	//   отен_, וקמה_, اكا_, ітам_
  { {0x96fb0058,0x07f80058,0xee3f005a,0x0000006a}},	//   تعذر_, برقع_, hlým_,
  { {0xd7df005d,0xe7df000b,0x645e5bad,0x76750033}},	//   _प्रच, _प्रप, öpin, элеф
  { {0x58870010,0x286b0180,0x2a6901d7,0x94252440}},	//   _жыва, _дрво_, mkab_, емле
  { {0x94750074,0x344b0457,0x0596002b,0x38b40012}},	//   رگذا, ючен_, رانگ, täre_
  { {0x63a80026,0xe3c40015,0x03a2005e,0xf7950033}},	//   _cydn, نْهَ, лишо, _чавэ
  { {0xda0f005d,0x682e005c,0x98a0002a,0x38b40012}},	//   िलित_, ródł, twić_, räre_
  { {0x1015008f,0xca1a000a,0x34950a31,0xf6c80033}},	//   ньня, הֵיכ, _заар, _цырк_
  { {0x2a690072,0x0000006a,0x0000006a,0x0000006a}},	//   hkab_,   ,   ,
  { {0x201808e0,0x2a690020,0x1fa9006b,0x63a80034}},	//   òria_, kkab_, якои_, _gydn
  { {0x3619000a,0x02440015,0x3e62001a,0x333a004f}},	//   הוֹד, _لَمَ, _nótt_, _מתעמ
  { {0x8c9600fd,0x787202de,0xf1ad0065,0x0000006a}},	//   ерві, _hæve, फ़ेशन,
  { {0x7dfb000b,0x2f180030,0x99990535,0x0000006a}},	//   ्लॉग_, bég_, _obsł_,
  { {0xd00e003b,0xfe720029,0xf1b90024,0xf3f10016}},	//   _الى_, _مدة_, rešu_, _mẹ_
  { {0x9f7a000a,0xba1a0015,0xddc4005a,0x0000006a}},	//   _מנצח, ثيرا_, _eliš,
  { {0x6e240505,0xc8ca0369,0x0000006a,0x0000006a}},	// [eca0] _ibib, سوان_,   ,
  { {0x9f4c0107,0x6d445bae,0xad1b004f,0x0000006a}},	//   zadí_, _iria, _צויר,
  { {0xdbc7007c,0x6d44006f,0xbe3a000a,0x2e3a004f}},	//   _söök, _hria, ּעְת, ּגְנ
  { {0x7e8b002a,0x6d440091,0x75d30015,0x63a8063b}},	//   tępi, _kria, هيما, _rydn
  { {0xe5340a2c,0x63a81e72,0x9f4c013f,0xaa432331}},	//   тель, _sydn, vadí_, _сеял
  { {0xf71a0010,0x68e44c4d,0x39402d55,0x7c2e0d29}},	//   _нібы_, mpid, mvis_, nebr
  { {0x68e45baf,0x39402e1f,0xf743006b,0x97c60015}},	//   lpid, lvis_, _йеро, _ستسم
  { {0xdbc70005,0x62d30086,0x6d440026,0x7e8400dc}},	//   _töök, دآور, _oria, dőpo
  { {0x394008e0,0x68e400f2,0x9f4c01c9,0x7c2e5bb0}},	//   nvis_, npid, radí_, kebr
  { {0xd2500086,0x34fb000a,0xb97b000a,0xd0100015}},	//   انک_, _מהמד, פניי, جلد_
  { {0xdef70558,0x6d44184d,0x39400020,0x2d9e0012}},	//   ныя_, _aria, hvis_, ßten_
  { {0x63a401e2,0x52d70008,0xddc400bd,0x7c2e007c}},	//   ğind, _נודע_, _sliš, eebr
  { {0x6d4403af,0x2f180014,0xc6930053,0x63a40064}},	//   _cria, ség_, ראר_, şind
  { {0x3e62002e,0xab95005e,0x0137000a,0xf1b90085}},	//   _sótt_, вигі, _נרות_, rešt_
  { {0xa6e70092,0x6d440020,0x2a69007c,0x2ba4000b}},	//   _chứ, _eria, tkab_, _खुदा
  { {0x5d850029,0x673b003d,0xaa58007e,0x6d445bb1}},	//   _للعل, _ņujo, нису_, _fria
  { {0x99d40029,0x394002e9,0x6d441a28,0xf80703e8}},	// [ecb0] اتفا, gvis_, _gria, ечен
  { {0xf8b90029,0xa9c40146,0x2a6903f6,0x6f080079}},	//   ذهاب_, усск, skab_, ordc
  { {0x442e01e2,0x9f4c0251,0x17f80015,0xa09b000a}},	//   def_, nadà_, عركة_, לימט
  { {0x442e0111,0x5b56000a,0xc8f5006b,0x68f2001a}},	//   eef_, _סירב_, _измъ, úkdó
  { {0xddec00b2,0x9f47002c,0x6e3d0409,0x64cb000b}},	//   פֿאָ, _mená_, idsb, ादेश
  { {0x7d1d00b8,0x26d1003f,0x6aad5bb2,0x7b8b004f}},	//   itss, _tuzo_, llaf, ּאֵ֥
  { {0xfbd4000a,0x1309005e,0xe2995bb3,0x04560058}},	//   נתק_, єний_, мак_, ضلية_
  { {0x38b400c0,0x3125006b,0xc2450120,0x7c2e5bb4}},	//   mära_, вдиг, тник, zebr
  { {0xd179008f,0x6e3d003c,0xa4d50036,0x38b400c0}},	//   ьскі_, ddsb, _розі, lära_
  { {0x6aad00b8,0xa4d4005e,0x25b20061,0x7e840030}},	//   hlaf, _софі, üyle_, tőpo
  { {0x5f050063,0x8f750210,0x9e0a0029,0x38b400c0}},	//   ъзна, тупі, ويدك_, nära_
  { {0x6d44002c,0xd6e80008,0xaf980033,0xa3dd000b}},	//   _pria, עַתָ, этых_, थुर_
  { {0xc5fa000a,0xed57110d,0x127a004c,0x427a004c}},	//   ופרט, воя_, _קאנע, _קאנג
  { {0x69dd5bb5,0x9176000a,0xab2a468c,0xa6e70016}},	//   _afse, _בענף_, мога_, _phứ
  { {0xaed20004,0xcaa60015,0xf412000a,0x7d1d5bb6}},	//   _којш, نصري, יפם_, atss
  { {0xf2d20053,0x6d442b0b,0x9986002b,0x39405bb7}},	//   שען_, _tria, پلئو, tvis_
  { {0x61e90d89,0x6d445bb8,0xba230054,0x69a20065}},	// [ecc0] ibel, _uria, јдук, _कुशी
  { {0xa6e70092,0x9f4c002c,0x68e45bb9,0x39405bba}},	//   _thứ, ladá_, rpid, rvis_
  { {0xf7720029,0xd6d90036,0x68e45512,0x38b400c0}},	//   جاء_, еті_, spid, gära_
  { {0x442e0026,0x7afa002e,0x68e406ef,0x84e6005e}},	//   wef_, áttu, ppid, водж
  { {0xceb3000f,0x7bdc002d,0xfd8d004f,0x8353009a}},	//   ביא_, ocru, ּטוּ, یپها
  { {0x62824216,0x7d7b000a,0x7659002a,0x37e30033}},	//   _smoo, וננו, ajwy, _ворг
  { {0x442e4e73,0xfbd3000a,0x23270054,0x4a5c000a}},	//   ref_, סתה_, воји_, ּד֖ו
  { {0x32630080,0xddcd0089,0x442e5bbb,0xf992000a}},	//   итыв, _smaž, sef_, ֹר֙_
  { {0x28d8005d,0x361b000a,0x50f30033,0x8233006e}},	//   _भूमि, _קומד, азыт, شريا
  { {0x244a0029,0xdefa0139,0x9f4c0144,0x61e95bbc}},	//   _تجري_, мым_, tadà_, abel
  { {0xc7f7000a,0x2f140033,0xbebd003d,0x61e95bbd}},	//   כזית_, ыднё, ntīg, bbel
  { {0x83fc0085,0x91e609dd,0xde590033,0x7d1d5bbe}},	//   _dođe, _роде, хамі_, ttss
  { {0xcd07006b,0x9da8006b,0x6e3d5bbf,0xd257004f}},	//   ъчни, въра_, rdsb, _ששדה_
  { {0xd2d1005d,0xbebd0024,0x6d340054,0x3e72013f}},	//   _ढूँढ़, ktīg, јерф, išty_
  { {0x7b640286,0x7d1d001a,0x8aa7005e,0xe0b7004f}},	//   атте, stss, врад, _שלוט_
  { {0x7e8b005c,0x63bc002d,0x6a78001a,0xbcfb0030}},	//   tępu, _úrnu, _líff, nyék
  { {0xadf8003b,0xd7590074,0x98f40029,0x98b9000d}},	// [ecd0] _شريط_, کلات_, لثلا, елат_
  { {0xc6e70036,0x38b40123,0x5e59002b,0xb76702da}},	//   відп, tära_, _آلکس_, ктей
  { {0x75295bc0,0xb5fd0085,0xdd91002b,0x7afa001a}},	//   _spez, _loše, _خوک_, áttt
  { {0xb9e40036,0x69080064,0x9f450003,0x38b40123}},	//   _віри, ürdü, ublé_, rära_
  { {0x7bc80007,0x1514005e,0xfd1f02b9,0xd6180015}},	//   ždut, идця, ntì_, ضتنا_
  { {0x38b4007c,0x8339004a,0x0000006a,0x0000006a}},	//   pära_, ечит_,   ,
  { {0x82f4008f,0xc7c40036,0xe73000e6,0x3ea90030}},	//   ачыц, _всти, _وصف_, _okat_
  { {0x83fc010b,0xf3f10092,0x6d410024,0x3634002b}},	//   _rođe, _mọi_, ālaj, _پرفس
  { {0x90d50086,0xdff5027a,0x61e95bc1,0xd5140058}},	//   دآبا, лянь, rbel, _نبلغ
  { {0x61e601e2,0x3fe50033,0x61e95bc2,0xb5fd0046}},	//   ıkla, ыжов, sbel, _doše
  { {0x63a40064,0x821500a2,0x20540033,0x3e8a4ceb}},	//   ğinc, _مواص, ртыр, ейно_
  { {0x83fc016f,0x35a8000b,0xc7b2000a,0xee3700fd}},	//   _vođe, _छुड़, מבי_, гню_
  { {0x01fa000a,0xe7c3000b,0x78a5007c,0xd0090190}},	//   _נפסל, वेतप, kohv, _зеле_
  { {0x6abe000b,0xddcb0045,0x7bdc0045,0x9cb600c3}},	//   ्द्र, ţişa, ucru, امست
  { {0x9f4c01b2,0xa09a000a,0xa3a9000b,0xcbc50015}},	//   padá_, _איסט, _गुम_, لزفي
  { {0x62890079,0x7bdc53bf,0x6a713be0,0x0000006a}},	//   nieo, scru, _påfa,
  { {0x39465bc3,0x2ba4000b,0xcec00535,0x0000006a}},	// [ece0] íos_, _खुरा, łęsy_,
  { {0x7b090064,0xdd7b000a,0x6d57004f,0xbb76009b}},	//   üstü, _נטיל, _עייף_, _бумъ
  { {0xf3f10092,0x6aa4003f,0x7bdb000a,0x160a0015}},	//   _gọi_, poif, _רקטו, فياً_
  { {0xc8690008,0xbebd0024,0xceb3000a,0x0000006a}},	//   הן_, rtīg, ֖יא_,
  { {0x2418004a,0x59830033,0xbebd003d,0x35f300e2}},	//   волы_, _гляб, stīg, спір
  { {0x9f470064,0x64a30484,0xe4b70033,0x29120061}},	//   _genç_, бача, гліі_, muya_
  { {0x7eb60057,0x93260067,0x7c3e5bc4,0x29125bc5}},	//   zápa, ارتن, _mapr, luya_
  { {0x7c3e00dc,0x626600a2,0xc3270015,0xd7930015}},	//   _lapr, طابق, اكين_, _الفخ
  { {0x92370001,0x29121622,0x854a005e,0xdfd00058}},	//   учју_, nuya_, _язав_, يية_
  { {0x15b90033,0x2018007c,0x7c3e377c,0xc1b70033}},	//   _рысы_, üri_, _napr, ылых_
  { {0x08570008,0xa2e60da6,0x2ba4000b,0x2c1b000b}},	//   אבים_, _соед, _खुला, _बाबू_
  { {0xd3370008,0x443e0334,0x7c3e02f2,0x1df9004a}},	//   _תראה_, _hat_, _aapr, ъемы_
  { {0x51180010,0x5c074b8e,0xa06a0f09,0xee3f013f}},	//   _ролю_, лява, _пада_, rdý_
  { {0xdfcf003b,0xfd1f02b9,0x41b3002b,0xa3a9000b}},	//   _فيه_, rtì_, _امهر, _गुड_
  { {0x8cd5005d,0x6fdb000a,0xfd1f02b9,0x443e5bc6}},	//   _यूरो, _אקוס, stì_, _mat_
  { {0x5a35000d,0x443e1d74,0x25a9002a,0xe9d30015}},	//   јнат, _lat_, żali_, صغر_
  { {0x57f50180,0x3da40033,0x7c8707f9,0x0000006a}},	// [ecf0] ипат, _грэб, _буне,
  { {0x2907065d,0x95ff005d,0x443e5bc7,0x6ed300d4}},	//   čna_, ॉल्ट_, _nat_, _săbi
  { {0x7fd7004c,0xa5d502ed,0x07470138,0x0000006a}},	//   אובס_, ажеш, ыхам,
  { {0x7c3e5b0f,0xd6ab012c,0x29125bc8,0x443e5bc9}},	//   _zapr, ردام_, buya_, _aat_
  { {0x26cd003f,0x5967006b,0x2c74007c,0x7c3e0061}},	//   _vieo_, _съна, _häda_, _yapr
  { {0xe3b10015,0x443e5bca,0xe3652f04,0x0445027c}},	//   يرث_, _cat_, икли, рекн
  { {0xc3040029,0x289a000a,0x443e1c87,0xe3b30015}},	//   مبيو, _יישא, _dat_, حرش_
  { {0x41050124,0xa3a9005d,0xaab5005d,0x443e003e}},	//   азив, _गुण_, ंतिक, _eat_
  { {0x54550010,0x443e0276,0xa1160015,0x3d11000b}},	//   _кват, _fat_, لقيط_, _तमगे_
  { {0x443e5bcb,0x7085005e,0x04440054,0x63a40045}},	//   _gat_, ргоз, _леђн, şina
  { {0x6a78016e,0x0000006a,0x0000006a,0x0000006a}},	//   _hífe,   ,   ,
  { {0x78720134,0x7c3e36dd,0x25d5000a,0xbebd003d}},	//   _nævn, _sapr, יוֹן_, etīb
  { {0x7c3e00df,0xa0750010,0x86360053,0x7ae50125}},	//   _papr, _выйш, בארג_, _atht
  { {0x443e0251,0xd0090175,0xa06644fc,0xbf650015}},	//   _xat_, _реке_, _ваша_, _ندعو
  { {0x9ad6005e,0x1a66002b,0x645e007c,0x68000046}},	//   рюгі, لیدی_, öpii, hájí
  { {0x8f9a0008,0x99e60036,0x7c3e00e8,0x29125bcc}},	//   _ביצי, ржад, _wapr, tuya_
  { {0x61fb0091,0x88860cfe,0xe9d704ca,0xe8fa09b1}},	// [ed00] iaul, алаж, рку_, тлз_
  { {0xb87b0125,0x29121c2e,0x3b860663,0x61fb5bcd}},	//   _dtío, ruya_, _влог, haul
  { {0x443e3be5,0x7eb64509,0xb87b202e,0xfaaa0058}},	//   _rat_, nápo, _etío, _لهدي_
  { {0x0bb7013a,0x89d5005e,0x8afb000a,0x443e5bce}},	//   _כלים_, _гірш, _בהטי, _sat_
  { {0xceb30008,0x443e02fd,0x88c60015,0x61fb0509}},	//   קיד_, _pat_, _نتسل, daul
  { {0x84380015,0xb5a90015,0xa2da000b,0xddc4002a}},	//   اكثر_, دامك_, _पंद्, _bliź
  { {0xd4670124,0x6d410024,0x7ebd00dc,0x443e0153}},	//   рије_, ālai, lépe, _vat_
  { {0x443e5ad8,0x44200089,0x61fb1634,0x27f80012}},	//   _wat_, ři_, gaul, _hern_
  { {0xb5aa003b,0xb2730191,0x60f7008f,0xe4760010}},	//   _شارك_, ільш, аныя_, _кужэ
  { {0x2900022d,0x20740010,0x80a30015,0x27f801f0}},	//   isia_, слоў, يمين, _jern_
  { {0x752203c0,0x72060074,0x290000d9,0x1df9054f}},	//   ltoz, _نوام, hsia_, лены_
  { {0x29000945,0x7ebd00dc,0xb5fd0263,0x6e951114}},	//   ksia_, képe, _koša, симу
  { {0x752200dc,0xf27b000f,0xc27b000a,0xa183004a}},	//   ntoz, _בראש, _בראי, _мышл
  { {0x7ebd0152,0x017b0008,0x26d8001c,0xf411000a}},	//   dépe, _שָׁל, _ouro_, ּ֤ם_
  { {0xbebd0048,0x7e76038b,0x00bb000a,0x6d465bcf}},	//   rtīb, _flyp, _שמומ, avka
  { {0x98a9005c,0xbebd0024,0xadf50001,0x5ea40015}},	//   ować_, stīb, _упиш, _ومول
  { {0xdebc013a,0x7ebd00dc,0x87e70029,0x6a6a001a}},	// [ed10] _במהל, gépe, لثال, _nýfu
  { {0x08540036,0x6c840015,0x2bde000b,0x68e20125}},	//   овую, _وليم, _मलया, íoda
  { {0xec36013a,0xddcd0011,0x26d80034,0x6a78001a}},	//   _האתר_, _flaţ, _curo_, _sífe
  { {0x36180036,0x69a2000b,0x83fc0085,0x76400034}},	//   ицію_, _कुकी, _rođa, _camy
  { {0x45450015,0x06080033,0x27f80383,0x7857002b}},	//   إنتق, рнік_, _fern_, _پیاز_
  { {0xe81e005d,0xb5fd016f,0x27f800b8,0xc484017f}},	//   _पाया_, _doša, _gern_, олік
  { {0x96f80b1a,0xf7940010,0x61fb5bd0,0x98a9002a}},	//   _вест_, _дарэ, taul, ewać_
  { {0xeb980008,0xc7b20008,0x7b980008,0x76402bf8}},	//   ידור_, _זבל_, יכוד_, _gamy
  { {0x61fb0b4c,0x753b005a,0x71580138,0x0000006a}},	//   raul, _usuz, арэс_,
  { {0xcea900b2,0x76400448,0xd3a712bd,0x627b002a}},	//   _װי_, _zamy, _креп, dłoś
  { {0x61e20176,0x50580010,0x5f750029,0x141a000a}},	//   _ffol, ршыя_, صادر, _תועב
  { {0x29005bd1,0x550b005d,0x64415043,0xb87b4724}},	//   ysia_, _हटाए_, _hali, _stíl
  { {0x627b005c,0x3f8b005c,0xdd920002,0xa059006e}},	//   głoś, ńcu_, سوس_, _مؤثر_
  { {0x225f0014,0x64435bd2,0x9f470a33,0x28db000b}},	//   ljuk_, ndni, _menú_, _बढ़ि
  { {0x28bd000b,0x64415bd3,0x627b002a,0x5f2901f3}},	//   ्गनि, _mali, ałoś, _сойм_
  { {0x225f0375,0xda0a0015,0x316d0003,0x29005bd4}},	//   njuk_, طيئه_, oyez_, tsia_
  { {0x5e770008,0x29005bd5,0xbebd003d,0x76400091}},	// [ed20] _לתקן_, usia_, stīc, _ramy
  { {0x7640005c,0xbddb0251,0x38b40f38,0x64415bd6}},	//   _samy, ndèn, märk_, _nali
  { {0x644300c0,0xcc3b004c,0x98a9002a,0x9b460021}},	//   ddni, _געיט, zwać_, _انجو
  { {0xb5fd010b,0x76a90036,0x5b57009d,0x98a9005c}},	//   _poša, атів_, _היטב_, ywać_
  { {0x225f0014,0x9f450264,0x64415bd7,0xda5901b0}},	//   djuk_, valý_, _bali, _трэш_
  { {0x75220014,0x64a30010,0x644108ab,0x26d802f2}},	//   rtoz, пача, _cali, _turo_
  { {0x08770053,0x64415bd8,0x7eb60030,0x7e840030}},	//   _פעלט_, _dali, tápl, lőpu
  { {0x7d04016f,0x225f00dc,0xe6960029,0x4427002e}},	//   _ovis, gjuk_, _الرد, afn_
  { {0x315a003b,0x61fd002e,0x64415bd9,0xb5fd06f2}},	//   اجعة_, ðsla, _fali, _košn
  { {0x0eea0036,0x64410472,0x225f00d9,0xa93b000a}},	//   льми_, _gali, ajuk_, נתיפ
  { {0x6fb40086,0x7d045bda,0xdfd00040,0x739a0323}},	//   تمدا, _avis, بيد_, _стас_
  { {0xc3b70053,0x7e92003d,0xe357000a,0x64415bdb}},	//   _פלאץ_, kāpu, _לשבח_, _zali
  { {0x6441000c,0x2d9f0003,0x02430015,0x0000006a}},	//   _yali, çue_, _رَوَ,
  { {0x0137000a,0xe58b000a,0x63ad0012,0xb5fd06c0}},	//   _לרדת_, אָלָ, ßang, _nošn
  { {0x2d840084,0xeabf0092,0x6ee600e6,0x5f9300d7}},	//   úmer_, _phù_, _استل, _ништ
  { {0xb9250029,0xda090015,0x7d0402de,0x9ed7006b}},	//   يفزي, شيطه_, _fvis, _умът_
  { {0x6e2d00b6,0x7d040029,0x7e7d002d,0xb5fd044c}},	// [ed30] _ibab, _فِيه, mhsp, _bošn
  { {0x27c7004a,0x2a600375,0xee3f001a,0x6d4d13f3}},	//   бщег, ajib_, plýs_, _iraa
  { {0xeabf0092,0x7d04006f,0x95d9004a,0xc7350058}},	//   _thù_, _zvis, адет_, تفاظ
  { {0xe815005d,0x64415bdc,0x442c5bdd,0x5f37000a}},	//   _ढाका_, _sali, _abd_, מטבע_
  { {0xa3cb005d,0xe3e9002b,0x64415bde,0xd90f002b}},	//   रेन_, لکان_, _pali, _سیا_
  { {0x1956000a,0xd49b004a,0x7c12004c,0x83fc0085}},	//   _ובשל_, ыре_, _פּראב, _dođo
  { {0x225f0014,0x8c1c0135,0xe81e000b,0x64413923}},	//   tjuk_, אווי, _पाता_, _vali
  { {0x644136bf,0x6265005e,0x00e53014,0x39495bdf}},	//   _wali, івпа, ожин, ovas_
  { {0xe0d6008f,0x225f00dc,0xc692000a,0x39491e20}},	//   овы_, rjuk_, _חאן_, nvas_
  { {0xd0090001,0xa988000a,0x6e2d5be0,0x63f40015}},	//   јене_, מָתִ, _abab, _فأمر
  { {0x39490020,0x225f00dc,0x66090107,0x9f450030}},	//   hvas_, pjuk_, _kdek, való_
  { {0x61550015,0x12e8000a,0x63ad0061,0x93940015}},	//   _ونائ, _הַסּ, ğand, _عجلا
  { {0x763a00b2,0xddcd0048,0x63ad0064,0x9dba0033}},	//   בערג, _plaš, şand, рыну_
  { {0xdfdb0063,0xa0c40015,0x55ba000a,0x6d4d528f}},	//   _съд_, _فينو, שמשו, _draa
  { {0xbb43008f,0x68ed08c0,0x0309000a,0xbddb0003}},	//   мерк, epad, יִּֽ, odèl
  { {0x7e7d00b8,0x66095be1,0xa3cb000b,0x629c0030}},	//   chsp, _ndek, रेय_, _írot
  { {0x68ed00b6,0x6bd60015,0x6d4d0438,0xbca60015}},	// [ed40] gpad, _وتدر, _graa, _ومبي
  { {0xdd0f0061,0xbebd003d,0x48b6005e,0x66095be2}},	//   lışv, ntīn, іщат, _adek
  { {0x39490024,0xa3cb005d,0xe73a0e1a,0x09f60015}},	//   avas_, रेम_, рее_, _وأحد
  { {0x8f9a0008,0xcf920008,0xd62a12d2,0xd7570015}},	//   ביעי, וטב_, роде_, تلمت_
  { {0x44f3008f,0x14f30010,0x65360015,0x68ed003d}},	//   дпіс, дзіў, تراذ, cpad
  { {0x628b0026,0x86ea0029,0x83fc0085,0x6ab62bef}},	//   _amgo, _نعرف_, _vođo, llyf
  { {0xa6960099,0x66150030,0x96960bdb,0x8c0b004f}},	//   _драј, ágké, _драш, שִׂ֤
  { {0xfbd3013a,0xf484002b,0x60f8006b,0xf7530015}},	//   ותו_, _کاری, бния_, _تنفج
  { {0xc05a0010,0xca7b0053,0xa2da021e,0x93bc0011}},	//   аін_, ינקט, _पूर्, _scăd
  { {0x39570008,0x19570008,0x54780008,0xa3560029}},	//   קשים_, קביל_, _פְּנ, _وخاص
  { {0xe7db0008,0xb7db00f3,0xf837000a,0x3ce932d9}},	//   יקיש, יקיי, חנית_, _stav_
  { {0xe2920086,0x39490007,0x68ed0e23,0xc2ed0046}},	//   _غذا_, yvas_, ypad, žící
  { {0xe018000b,0x60660015,0xa3cb000b,0xfd440033}},	//   _दाऊद_, _وهؤل, रेठ_, мэрн
  { {0x6d4d0161,0x73f8000a,0x69b4000b,0x68ed013b}},	//   _vraa, מּֽו, _आरजी, vpad
  { {0x6d4d0079,0x628b0034,0xbcfb0030,0xaa670e76}},	//   _wraa, _ymgo, gyér, отак
  { {0xd37b000a,0x68ed0085,0x6ab65be3,0x6d4d5be4}},	//   ברלט, tpad, glyf, _traa
  { {0xdd910086,0x987504c2,0xb5fd06db,0x38c9002b}},	// [ed50] _سود_, плац, _došl, مائی_
  { {0xdb0500f2,0xa3cb021e,0x68ed013c,0x98170040}},	//   _pyhä, रेड_, rpad, تبرا
  { {0x37070afb,0xc6a7227a,0xe70b002b,0x39490327}},	//   ючав, орди, شتان_, svas_
  { {0xcb120053,0x68ed1b62,0xc987007e,0xaa5d01f3}},	//   _אלט_, ppad, _дуги, _семi
  { {0xd126003b,0x73e5010f,0x4a5a0008,0x98170067}},	//   _ثم_, полз, _הדרו, _وبسا
  { {0x82f5006b,0xe4c80040,0xd8da004f,0x1bf40065}},	//   пчиц, يبون_, _לקשר, अरएल_
  { {0xbc7c000a,0xe6130058,0x0000006a,0x0000006a}},	//   שנות, _يشر_,   ,
  { {0xb87b0107,0x8b9c000a,0xdb9c000a,0x38b4008c}},	//   _stíh, יבות, יסור, väri_
  { {0xe1f1002b,0xa63401c6,0x0000006a,0x0000006a}},	//   وسک_, _інфі,   ,
  { {0x5059006b,0xe4530015,0x38b4007c,0x57d6000a}},	//   сшия_, _تضر_, täri_, ּ֥ין_
  { {0x0eaa004a,0x8caf000b,0x5f450015,0x4adb000b}},	//   йкой_, ंकनो, أنجل, _मूलव
  { {0x6da61179,0xbebd003d,0x0000006a,0x0000006a}},	//   зима, stīn,   ,
  { {0x31580029,0xee3712ba,0x91f6000a,0x1c20000b}},	//   _وجهة_, чня_, _זמנו_, _बादल_
  { {0x38b400f2,0x7ebd0003,0x629c0030,0x629b3349}},	//   päri_, répa, _íror, lnuo
  { {0xb5fd550e,0x5ffa000a,0xab64002a,0x6ffa000a}},	//   _pošl, _ההצה, ążow, _ההצפ
  { {0x7ebd00dc,0x6d40002e,0xcee80067,0xada60baf}},	//   lépn, æmas, _برون_, _найл
  { {0xfc320029,0x6ec50029,0xae1b0008,0x6ab60034}},	// [ed60] _كحد_, _تتوق, _הופכ, rlyf
  { {0x49990036,0x07a649a2,0x80c1000b,0xb9040065}},	//   іття_, пазн, _रीमे, _पं_
  { {0x25bf0656,0x7bdb000a,0xa6ca002b,0xbb4a0015}},	//   _azul_, _לקיו, موئل_, _الجن_
  { {0x56930036,0xf8a9000a,0x36890033,0xe6c60015}},	//   наєт, אש_, осін_, ستضي
  { {0x48e31725,0x27ef0046,0xddcd002a,0x60c30012}},	//   _появ, ílné_, _znał, _ohnm
  { {0xa9bb000a,0xd7f20015,0x0666002b,0xd8380069}},	//   _לזכר, _سكر_, _کاسپ, _úč_
  { {0x43670180,0x987b004c,0xeb92000a,0xebd6004f}},	//   зајн_, _פאלט, ךָ֗_, הֵ֤י_
  { {0xddc4005c,0xd6d20015,0xfbd3000a,0xd6eb000a}},	//   _bliż, _أقر_, עתה_, _לַמָ
  { {0xc5eb000a,0x798400aa,0x9f5e0046,0xdfda006b}},	//   _הַבֹ, nziw, maté_, йън_
  { {0x44e2002e,0x44385be5,0x2fd80bfa,0x757b000a}},	//   _ið_, _úr_, ørg_, _הטמפ
  { {0xdfd00002,0x74130015,0xc4d3000a,0xd9b90065}},	//   ضيح_, _أوما, _נגע_, _आर्ट
  { {0x59be005d,0xde590010,0x6602003f,0x5186029f}},	//   ्धार, цамі_, naok, _нула
  { {0x91ba0015,0xc0ca0054,0x0000006a,0x0000006a}},	//   _اطار_, _луке_,   ,
  { {0x6ab5014e,0x55770053,0x7984005c,0xdcb10016}},	//   ंत्र, לעכן_, dziw, ổ_
  { {0x6d40002e,0x3942003e,0xa08b000a,0x00bb000a}},	//   æmar, _asks_, _לְהִ, _המגמ
  { {0x69da04f9,0xd3570053,0x201e0007,0xe7b0005d}},	//   _şter, הילי_, lgti_, _झड़प
  { {0xf9930086,0x19580033,0xc4cc000b,0xe9e80015}},	// [ed70] ربر_, паты_, ाषाओ, سفلى_
  { {0x201e00df,0x7d7c000a,0x6e19002b,0x3eb95be6}},	//   ngti_, _לנחו, _ايکس_, llst_
  { {0x44e25be7,0x629b005c,0xb87b016e,0x201e0091}},	//   _að_, ynuo, _ruíd, igti_
  { {0x19590174,0x78730061,0x6b9a001a,0x0000006a}},	//   _дамы_, _sıvı, útge,
  { {0xa5090010,0x0445017a,0xd46922c9,0x152b0b1e}},	//   цела_, делн, жиле_, сцеп_
  { {0x629e0152,0xad1c000a,0x7eb61756,0x6a78001a}},	//   épon, מודר, rápi, _lífl
  { {0x44e2002e,0x4919000b,0xc2c50015,0xe695004a}},	//   _eð_, यूरो_, ويتي, _живы
  { {0xb5fd00bd,0x201e2233,0x8b58000a,0x5b58000a}},	//   _mošk, egti_, ליוס_, לשון_
  { {0x25bf0045,0xb5fd00bc,0x90c53343,0x629b0073}},	//   _uzul_, _lošk, мбие, rnuo
  { {0x2089005e,0xbebd003d,0xf484004e,0x62805be8}},	//   ійни_, stīl, _пухн, ahmo
  { {0xbea60010,0xaabf000b,0x0fc5005e,0xa77a004c}},	//   данк, ्षाक, ьйон, ַרשפ
  { {0x62805be9,0x38b40b12,0xbebd003d,0xc2c40058}},	//   chmo, lärt_, ltīj, _كيلي
  { {0xd0090760,0x614512a2,0xc212000a,0xf2d2000a}},	//   _деле_, _цела, _יהא_, _סעד_
  { {0x7188000a,0x38b40123,0xb5fd0085,0x0468004f}},	//   _מְצַ, närt_, _bošk, ֜יךָ_
  { {0x2018002c,0xbebd0024,0xe048002b,0x6488000a}},	//   órie_, itīj, _رشوه_, פְשְ
  { {0xc3320008,0x25b2005c,0x4efa000a,0x9f475bea}},	//   כול_, żyli_, _והקו, _menü_
  { {0x63a40482,0xee290015,0xddcd01c0,0x9f5e5157}},	// [ed80] ğini, _رأيه_, _plať, vaté_
  { {0x63a45beb,0x6d440ef3,0x40e8000a,0x38b40123}},	//   şini, _isia, לַעֲ, järt_
  { {0x9f5e0152,0x78830046,0x07f90033,0xf6e501c6}},	//   taté_, důvě, яхты_, ецін
  { {0x386a0026,0x7c2e5bec,0x3ce0007c,0x99d60058}},	//   _wobr_, lfbr, _kuiv_, _يتحا
  { {0xa3cb014e,0x39350010,0x9f5e2784,0x66025bed}},	//   रेस_, _пэрс, raté_, raok
  { {0x38b400c0,0x7c3c5bee,0x94d30138,0xe8e000a1}},	//   gärt_, nerr, воіц, _quỵt_
  { {0xf743004a,0x7c3c5bef,0x628057b9,0x0000006a}},	//   _иеро, ierr, thmo,
  { {0xda7b0053,0x7c3c2c6f,0x9695008b,0x6d442f6c}},	//   ַניר, herr, _зруш, _osia
  { {0xa2da005d,0xe4e90029,0x7c3c5bf0,0x14260004}},	//   _पंक्, _فعله_, kerr, _одам
  { {0x63ad0064,0xcf260015,0x66000123,0x7c3c5bf1}},	//   şana, ورجي, _hemk, jerr
  { {0xdef70010,0xdb0b0064,0x3817000f,0x6d440ae5}},	//   мыя_, ünüz, וקים_, _asia
  { {0xbe8b00fd,0x64480332,0x442e215a,0x443c5bf2}},	//   існе_, _hadi, lff_, lev_
  { {0x8d870001,0x7c3c5bf3,0xe5f7000a,0x3204002a}},	//   фунд, ferr, וזכר_, mamy_
  { {0x91bb0008,0x443c5bf4,0x9f5c117e,0xd5c5005e}},	//   _ומדי, nev_, _levé_, цiйн
  { {0xe207005c,0x39400026,0x442e0026,0xcfaa0086}},	//   spół_, ewis_, iff_, _باشم_
  { {0x6e450029,0x83fc0085,0x64485bf5,0x443c5bf6}},	//   _أنظم, _dođi, _ladi, hev_
  { {0xceb4004c,0x08550033,0x5cc7011d,0xda080015}},	// [ed90] _ביק_, нваю, _осоз, بيقه_
  { {0x7c3c0a40,0xbc680015,0x443c1cbc,0xd1480016}},	//   cerr, _يمين_, jev_, _mễ_
  { {0xd1480092,0x443c5bf7,0x38b40123,0x9f4c0030}},	//   _lễ_, dev_, värt_, madó_
  { {0x9f4c00dc,0xb5fd5bf8,0x7d1d5bf9,0x645a0ebc}},	//   ladó_, _koši, ouss, _anti
  { {0x3204005c,0xe3b80064,0x64485bfa,0x38b40123}},	//   damy_, _ayı_, _badi, gärs_
  { {0xdfc60074,0x64c9005d,0x443c0abb,0x74150015}},	//   _مي_, िगेश, gev_, روعا
  { {0xd4040036,0x28d8000b,0x7d1d0012,0x65790061}},	//   тячи, _भूटि, huss, _şahı
  { {0x7e6d3003,0xbebd0024,0x320408c2,0x23760015}},	//   _noap, stīj, gamy_, عميد_
  { {0x05770015,0x7c251827,0x12a80015,0x31790030}},	//   _غارد, _ochr, بدوى_, ász_
  { {0xd1480023,0x53c70086,0xf94a0053,0x443c00bd}},	//   _dễ_, _قزاق, לעפֿ, cev_
  { {0xf8b20008,0xaf99005e,0xa3cb000b,0x3ce00003}},	//   רשי_, ятих_, रेश_, _suiv_
  { {0x3204005c,0x290900f2,0xa2f6000a,0xf1c90015}},	//   camy_, ksaa_, _נמנה_, _فوضى_
  { {0x7d1d187b,0x361a000a,0xd2b80021,0x7059005e}},	//   guss, הורד, _غامض_, _надр_
  { {0x9f4c00dc,0x2cb10030,0x6564008c,0xddc40061}},	//   gadó_, gozd_, äihi, _eniş
  { {0xdd99002c,0xe3a70002,0x7fe80015,0xf092000a}},	//   ĺňa_, ار_, _غروف_, _תנו_
  { {0x443c0089,0x61e95bfb,0x394000aa,0xda6600c3}},	//   zev_, ncel, twis_, رازي
  { {0xf2d20053,0x0e9b000a,0xc9a70004,0xfaa3005e}},	// [eda0] רען_, _משקל, евте_, уато
  { {0x68460029,0x20055bfc,0x3940002a,0x3204002a}},	//   عَال, nali_, rwis_, zamy_
  { {0xabfb0008,0xf7720029,0x66e50007,0x8c1b0053}},	//   _מהיר, داء_, _dėko, _צוטי
  { {0x20050455,0x6d7a000a,0x75d4002b,0x38b40012}},	//   hali_, ּאַח, پيتا, tärs_
  { {0x443c0e6d,0x644800df,0x66da0089,0x89db000a}},	//   tev_, _padi, _důka, _מחכי
  { {0x20051658,0x3204002a,0xd1480016,0x2c66006f}},	//   jali_, wamy_, _rễ_, _pôdy_
  { {0x442e1f4d,0x8c1b0008,0x3204005c,0x64485bfd}},	//   rff_, לוסי, tamy_, _vadi
  { {0x97570008,0x9f58002d,0xcb13000f,0xe6c60015}},	//   _אילו_, úrí_, אלה_, _ستزي
  { {0x3204005c,0x91b7006b,0x64485bfe,0x34ba002b}},	//   ramy_, нгът_, _tadi, _فهرج_
  { {0x645a10df,0x7d1d0209,0x20055bff,0xb5fd0085}},	//   _unti, vuss, gali_, _roši
  { {0x6e3d0134,0x7d1d0303,0xd80b000a,0xb4cc000b}},	//   tesb, wuss, הִכָ, रगी_
  { {0xb5fd116e,0xd36f0086,0xa3a9005d,0x6e950286}},	//   _poši, _دهم_, _गुट_, тиму
  { {0x20055c00,0xa1130002,0x9ccb004a,0x7d1d008c}},	//   bali_, _مونت, зыва_, uuss
  { {0x2005141b,0x515b000a,0x7d1d5c01,0x71d7004f}},	//   cali_, _מכדו, russ, _נוגד_
  { {0x9f4c00dc,0x0ac7006b,0x2ac70054,0x7d1d5c02}},	//   radó_, ещам, ељав, suss
  { {0x7d1d5c03,0x66e50091,0x7fbb000a,0x9f4c0030}},	//   puss, _dėkl, _מזוז, sadó_
  { {0x38b400c0,0x26c30091,0xf8b1002b,0xe502000b}},	// [edb0] värr_, _ėjo_, لکس_, रीमि_
  { {0xd6d9005c,0x7d1b0144,0x61e95c04,0x588408f0}},	//   _sił_, àusu, zcel, лыха
  { {0xd7590015,0xfb19000a,0x61e90034,0x9cd6000a}},	//   بلات_, _קוֹמ, ycel, _שותה_
  { {0x9f5e002c,0xd61800e6,0x81c2003d,0x20055c05}},	//   jatí_, فتها_, ģējo, zali_
  { {0xaa540033,0x3d1f000b,0xd8770015,0x49740239}},	//   _свяш, _बमों_, _كاسب, _бляс
  { {0xc87f0012,0xf916004f,0xe3b92815,0x61e90546}},	//   _buße_, _בחשך_, мбл_, wcel
  { {0xa3cb005d,0x61e90024,0xb87b0077,0xd466070c}},	//   रें_, tcel, _guía, тище_
  { {0xa5620086,0x20055c06,0x46b70015,0x2a692f01}},	//   _چگون, wali_, _أحسس, njab_
  { {0x4102005f,0xd5c5005e,0xa1e80015,0x61e90390}},	//   азыв, хiдн, رريك_, rcel
  { {0x7ebd1f05,0x200502b9,0xe4530021,0xc87f0012}},	//   léph, uali_, _حضر_, _fuße_
  { {0x201833e3,0xf484022a,0xf456000a,0x7d0d5c07}},	//   ória_, _сутн, _שיער_, _avas
  { {0xc7d6000a,0x2c740012,0xdb240030,0x717901c5}},	//   כותי_, _lädt_, érít, _обер_
  { {0x5d67004a,0xfd1f02b9,0x66e50091,0x20055c08}},	//   виям_, guì_, _sėkl, pali_
  { {0xe1f90007,0x7d0d0007,0x8c460054,0x2f550054}},	//   lbų_, _dvas, њеве, _атис
  { {0x3ab60001,0x2b150449,0xd83e00bc,0x6008000a}},	//   вљат, льтр, ščke_, _נִסְ
  { {0x5d860015,0x8f1a000a,0x6a7102de,0xb5fd0085}},	//   _للبل, _חוקת, _såfr, _košu
  { {0x2d950010,0x7ebd00dc,0x290c0024,0xdea2002b}},	// [edc0] _брэс, zépk, _ādas_, _میگی
  { {0x8883005e,0x7bde02f2,0x2a69007c,0xcec0002a}},	//   алуж, _ugpu, ajab_, łędy_
  { {0xc5fe0024,0x7d0906cf,0xd5c5005e,0x8d76002b}},	//   ņēma_, šest, цiон, _ساکا
  { {0x63ad0061,0xa3d4000b,0x0000006a,0x0000006a}},	//   ğanl, सेफ_,   ,
  { {0x63ad0064,0xa3d4000b,0xa61300fd,0xe8f7006b}},	//   şanl, सेन_, рміч, _иля_
  { {0x44b30010,0xc448002b,0x94230054,0x224d0061}},	//   абіс, عیان_, амље, edek_
  { {0x2c20000b,0xe7b6002b,0xc3270015,0xdc9b004c}},	//   _बाईं_, _شمرد, نكون_, ויסל
  { {0xc7a303e3,0x7ebd0003,0xe3af0058,0x224d0546}},	//   _тиск, céph, غرو_, gdek_
  { {0x21630010,0x52730054,0xb4260015,0x63ba002a}},	//   атэг, рују, _لعضو, _wytn
  { {0x84450067,0x224d1022,0xc05702a3,0x0000006a}},	//   _مخمل, adek_, вію_,
  { {0x50d30115,0x9f5e0046,0x6d565c09,0xb2261adc}},	//   جزير, patí_, _arya, _амел
  { {0xc7b3011f,0xddd60089,0x5f93005e,0xfd1f02b9}},	//   יבת_, _slyš, риют, tuì_
  { {0xbebd0048,0xddc400bd,0xc27b000a,0x40340033}},	//   ktīv, _poiš, _קרדי, _белс
  { {0x66e500df,0x8f5400b0,0xfd1f02b9,0xb5fd0046}},	//   _sėkm, _منتش, ruì_, _hošt
  { {0xdee30124,0xb5fd016f,0xe502000b,0x6bd40015}},	//   _који, _košt, रीति_, لتفر
  { {0x9f5c0046,0x4da70015,0xcfb7004f,0xb87b12cf}},	//   _jeví_, _لإخف, _שלהי_, _atíp
  { {0xf8070191,0xead40142,0xb5fd0844,0x59390033}},	// [edd0] вчен, роть, _mošt, эзаў_
  { {0xf8b90029,0x7e7d54d5,0x4ac30065,0x09c30065}},	//   رهاب_, lksp, _वीरव, _शरीय
  { {0x97150010,0xe1f90091,0x6c740058,0x5ba4009b}},	//   умец, ybų_, _خطيئ, _вряз
  { {0xf7700002,0x8f9b000a,0x9f5c0046,0x4b7a05bd}},	//   غال_, ויבי, _neví_, _נארו
  { {0x7ae500f2,0xa8250086,0x7e7d00aa,0x74b90302}},	//   _huht, _مکان, iksp, нукс_
  { {0xd7f40080,0x7d7c0008,0x94750086,0x04c800e6}},	//   _взры, ונדו, دگرا, نوني_
  { {0x7ae50005,0xf8b20008,0x7d0000dc,0x6282014c}},	//   _juht, _השם_, ámsz, _bloo
  { {0x2369016f,0x7ae53466,0x4374009c,0x7e7d0079}},	//   ćaj_, _muht, рушт, jksp
  { {0x20c20084,0xe1f90007,0xc692000a,0x98a0002a}},	//   rðin_, rbų_, _האן_, stią_
  { {0x25a0002d,0xeef50033,0x442302de,0x30850015}},	//   úile_, лямэ, _øj_, الدف
  { {0x6282003e,0xa2f50063,0x4f640015,0xb87b0125}},	//   _floo, _спеч, لاَف, _luío
  { {0xd6d2000a,0xf38c004c,0x62825c0a,0xddcd013f}},	//   ֶׂם_, _קראָ, _gloo, _dlaž
  { {0x61fd0084,0x26b60008,0xe167002b,0xd24e002b}},	//   ðslu, רִים_, _جداي, _رنو_
  { {0xb19a000a,0xfce306f3,0x61fb5c0b,0xb87b059d}},	//   _אינכ, соро, lbul, _suín
  { {0x30da00b2,0x69c60030,0x7ebd01ce,0x61fb0091}},	//   _אַהע, _szke, zépi, obul
  { {0xb87b5c0c,0x8f9a000a,0x7aa50015,0xd7b7000b}},	//   _buío, _ריקי, لإقل, _अड़च
  { {0xa81a0086,0xc4c3000b,0x4e96002b,0x2d8b002a}},	// [ede0] فتار_, षताओ, _لشکر, czce_
  { {0xa84a0002,0x0000006a,0x0000006a,0x0000006a}},	//   علام_,   ,   ,
  { {0x907a004c,0x807a004c,0x61fb2755,0xeb9a1a9d}},	//   עטעי, ענעצ, kbul, _чин_
  { {0x84e60036,0x80ca000b,0xd6d9005e,0x95ca08f7}},	//   годж, _सीने, вті_, нула_
  { {0x6aa44d31,0xe5a30719,0xed16004f,0xf487009a}},	//   mnif, бици, רַ֣ת_, گانی
  { {0x25a90015,0x399b004c,0xbebd003d,0x62822932}},	//   خدمي_, _װילד, ltīt, _sloo
  { {0x6aa40020,0xf4870086,0x78ab00dc,0xb5fd25b6}},	//   onif, دانی, égve, _pošt
  { {0x75d60070,0xcb13000a,0x9f5e01c9,0xcb57000a}},	//   _ميزا, צלח_, jatá_, רסקה_
  { {0xbebd0048,0xddcd016f,0x2018001c,0xae08000b}},	//   itīt, _slaž, ório_, _वज़न_
  { {0xe4d70086,0x290f00dc,0xddeb002b,0x83fc0085}},	//   _موقت_, ágai_, کرده_, _vođs
  { {0x2fd800c0,0xe4750033,0x831a0015,0x6aa42c7e}},	//   ärg_, _тутэ, _أقصر_, knif
  { {0x91e6005f,0xc7d7000a,0x877b004c,0x1757000a}},	//   _соде, טויי_, גאטי, אסטר_
  { {0x7ae50458,0x729b004c,0x7e7d5c0d,0xf2d3004f}},	//   _suht, _אסאס, rksp, _העף_
  { {0x7ae50209,0xa3cb000b,0xe571000a,0xdfd4004a}},	//   _puht, रेक_, חַל_, _колы
  { {0xb87b002f,0xc87904f9,0xddcd0085,0x4f57006e}},	//   _suío, _îşi_, _ulaž, _مجيد_
  { {0x6e95002b,0xdb0c0046,0x6aa45421,0x1f1302be}},	//   _خلبا, íhán, gnif, _ابوج
  { {0xe918005e,0x76420061,0x38c9002b,0x3ea901c2}},	// [edf0] лоті_, deoy, نائی_, _ijat_
  { {0xa81b0015,0xf9900021,0x61fb0915,0x80ca000b}},	//   عتذر_, سبق_, zbul, _सीमे
  { {0x501b0008,0x0000006a,0x0000006a,0x0000006a}},	//   תובו,   ,   ,
  { {0x635c0011,0x1635006b,0xbafa000a,0x9607006e}},	//   _mănă, редя, _שהרש, ابام
  { {0x85e8005e,0xe44e005e,0x0000006a,0x0000006a}},	//   удів_, ож_,   ,
  { {0x4d7c0053,0x6579003e,0x0000006a,0x0000006a}},	//   ערגע, rywh,   ,
  { {0xf4840001,0x95c50086,0xbebd0024,0xcc78000a}},	//   ључн, _چيزه, ntīs, רגות_
  { {0xbb3c0053,0xbebd0024,0xa3cb000b,0x43040015}},	//   געהי, itīs, रेग_, حذوف
  { {0xb4270002,0xd53800e5,0x44270021,0x62720015}},	//   _معاو, _مثلا_, _مراف, تهيئ
  { {0x90e40015,0x61e202b9,0x3ea95c0e,0x660b0a5c}},	//   حسين, _egol, _ajat_, lagk
  { {0x61e60007,0x78a5002e,0x20540139,0x64435c0f}},	//   žkla, inhv, стыр, meni
  { {0x1e960080,0x660b0035,0x44eb0595,0x644327eb}},	//   ррор, nagk, _kø_, leni
  { {0x6cc60036,0xd2d40021,0x66e50091,0x62890125}},	//   ийма, _اغلب, _dėki, mheo
  { {0x629b00df,0xceb90050,0x64435c10,0x61e200bc}},	//   liuo, stęp_, neni, _zgol
  { {0xb09a0008,0x44275c11,0x501a000a,0x68e602f2}},	//   _שיצר, ign_, _סוקו, _sukd
  { {0x629b0007,0xbddb0003,0xab27012e,0x20190091}},	//   niuo, rdèr, јота_, ėsiu_
  { {0x64435c12,0xdebb000a,0xf7f60021,0x673c0085}},	// [ee00] keni, _במקל, لساد, _sprj
  { {0xbebd0048,0x97560001,0x64435c13,0x97c6070c}},	//   stīt, итељ, jeni, айзе
  { {0x629b0007,0x64435c14,0xa6ca002b,0x26cd0125}},	//   kiuo, deni, نوئل_, _bheo_
  { {0xc86900b4,0x1f3600b2,0x26cd003f,0x64430020}},	//   ון_, ירער_, _cheo_, eeni
  { {0x2cb80234,0x798d002a,0xd62704b4,0x64435c15}},	//   oord_, czaw, роче_, feni
  { {0x7d04000c,0xd7f20029,0x7d570053,0xe4b70010}},	//   _mwis, _ذكر_, יינד_, аліі_
  { {0xd4090029,0x07ba0015,0x07a30098,0x9cd7000a}},	//   اتهم_, _شهرة_, _дарн, בוסה_
  { {0xd2570558,0x66e30010,0x92b30067,0xddcd002a}},	//   аць_, _фота, يحيا, _plaż
  { {0x30a615ed,0x044a0001,0x635c0011,0x2cb85c16}},	//   иров, _ипак_, _sănă, kord_
  { {0x64435c17,0x20070796,0xa937000a,0xb4fb000a}},	//   ceni, _ceni_, סטיה_, _סלבר
  { {0x9ed9000d,0xa857000a,0x0857000a,0x62890125}},	//   лмот_, בייה_, בבים_, bheo
  { {0x5ea40015,0xefcc0061,0x98a0002a,0x628909ad}},	//   ْمَل, _ışığ, rtię_, cheo
  { {0xb87b002d,0x10a600d0,0x2cb85c18,0x98a0002a}},	//   _suím, _кидн, ford_, stię_
  { {0x20075c19,0xbebd003d,0x7ea80061,0x2cb85c1a}},	//   _geni_, ttīs, lıpl, gord_
  { {0xe451000a,0x7d042004,0xb87b2b8e,0x8fa30054}},	//   הֶן_, _ewis, _quím, _маље
  { {0xeaf80086,0x3fdb0008,0xa3cb021e,0x64435c1b}},	//   شرفت_, _בקוב, रेट_, zeni
  { {0x200701e2,0x3eb90041,0x7d040026,0xbebd15e5}},	// [ee10] _yeni_, most_, _gwis, erīg
  { {0xf7730021,0x3eb90ea1,0xe7330021,0x798d002a}},	//   ياض_, lost_, قصص_, rzaw
  { {0x7d04018b,0x64435c1c,0x8c1a000a,0xdc3c000a}},	//   _zwis, veni, _גותי, _יעזר
  { {0x4fd90053,0x9694005e,0xc6a41017,0x200c01d7}},	//   אַנד, оріш, орчи, hadi_
  { {0x200c16d3,0x1e58000a,0xa3d4000b,0xe618005e}},	//   kadi_, ישאר_, सेस_, рді_
  { {0x6d4d000c,0x200c0049,0xa976000a,0x89da000a}},	//   _msaa, jadi_, _התשנ_, _תחשי
  { {0x26cd00a7,0x660b00b6,0x62895c1d,0xa3550015}},	//   _theo_, pagk, theo, إختص
  { {0x3a295901,0x6d4d0f7a,0xf5330015,0x3eb906f2}},	//   ngap_, _osaa, _وإذ_, jost_
  { {0x629b00df,0x3eb906d5,0xa3cb000b,0x3a2901c2}},	//   riuo, dost_, रेज_, igap_
  { {0x14740029,0xf992000f,0x6289002d,0x629b0091}},	//   _والج, פרי_, sheo, siuo
  { {0x629b00df,0x20070011,0x187800f3,0x160b000b}},	//   piuo, _veni_, יעזר_, _हजार_
  { {0xd3360008,0x6609007c,0x2cb85c1e,0x3eb9036d}},	//   _לרעה_, _jeek, word_, gost_
  { {0x200c0509,0x0d9902bf,0xc6920643,0x20110030}},	//   badi_, атры_, לאט_, ózis_
  { {0x00f60008,0xa156000a,0xab2a5c1f,0x66095c20}},	//   _המסך_, _לבנה_, лога_, _leek
  { {0x9ef5003b,0x3eb90176,0x7f190010,0xc052000a}},	//   _استش, bost_, _сілу_, _מזג_
  { {0x4f1600b4,0x66092b4d,0x7f76000a,0x7d041747}},	//   _פֿון_, _neek, _לעצב_, _twis
  { {0xc4b9005d,0xba170015,0x7e6401d7,0x2cb802de}},	// [ee20] ेताओ, صيلا_, _inip, pord_
  { {0xb80a0029,0x7a310030,0xe9d736b7,0x3b860597}},	//   ايام_, tótó, ску_, _глог
  { {0x9cdb000a,0xfaaa0015,0x86e90015,0x7ea80061}},	//   _תקיפ, _مهدي_, لعنف_, yıpl
  { {0x5fba00b2,0x6b8101f0,0x4639005e,0x7a314971}},	//   אצענ, ølge, иччя_, rótó
  { {0x1513005e,0x4a57000a,0x200c0bc7,0x0000006a}},	//   здія, _השכל_, yadi_,
  { {0x6d48002a,0x7aed0030,0xe4d7012c,0x442c5c21}},	//   łdaw, _öltö, مونت_, _qcd_
  { {0x3317003b,0xd4670001,0xf7860029,0xa6f8000a}},	//   مزيد_, сије_, _الأَ, _כִּי
  { {0x96950292,0x32530063,0x877b00a3,0x200c0297}},	//   _друш, звър, _גאלי, wadi_
  { {0x60f70010,0x29120035,0xe1ef0115,0x200c4de1}},	//   бныя_, nsya_, رسي_, tadi_
  { {0xdefa04ab,0xf484002b,0x26dc0046,0x66090079}},	//   лым_, _باری, ůvod_, _zeek
  { {0x93f70008,0x200c59d4,0x3eb94e14,0x0857000a}},	//   _הצבא_, radi_, tost_, זבים_
  { {0xddc40024,0xf7730008,0xb7db0053,0x7afc00bd}},	//   _maiņ, לקת_, טקיי, dprt
  { {0xa1330086,0xc05a005e,0x3eb95c22,0x200c5c23}},	//   _فروش, _бій_, rost_, padi_
  { {0xc0d30015,0x7ebd0030,0xf1a7000a,0x66c3007c}},	//   _فينب, gépr, _ל֛וֹ_, tõkk
  { {0x3eb95c24,0x309b0008,0x409b000a,0x6e95002b}},	//   post_, _תשומ, _תבוס, _ولتا
  { {0x139b0053,0x9f5e005c,0x39490012,0xfd1f02b9}},	//   אבלע, śród_, twas_, prì_
  { {0xaa580080,0x66090161,0x87e70015,0x66e50091}},	// [ee30] щиту_, _reek, مثال, _lėkt
  { {0x07e70010,0x4af90086,0x66095c25,0x39140033}},	//   сцам, _نکرد_, _seek, ямур
  { {0x46150015,0xec36000a,0x96750033,0x291202f2}},	//   قوار, _ואתר_, жылі, asya_
  { {0x67253d8a,0xfdf9000b,0xaa590054,0xb4c3000b}},	//   ruhj, ंडिस_, _тиму_, ृष्_
  { {0xd126003b,0x06080010,0x66090020,0xe6640010}},	//   _تم_, снік_, _veek, ятфо
  { {0x22ac0089,0xf7950010,0x66093812,0xfb57000a}},	//   věka_, _дагэ, _week, ֶׁ֥ר_
  { {0x0ec9000b,0x66095c26,0xa3d4000b,0x96f8012e}},	//   रताड, _teek, सेल_, _гест_
  { {0xc7b20008,0x23080029,0x7ebd0030,0xab0c000a}},	//   _חבל_, حتوي_, zépr, נ֔וֹ
  { {0xc42b0031,0x5ba6000b,0xe5730067,0x60e6056d}},	//   _مثال_, _ऐश्व, _عطر_, омым_
  { {0x08760053,0xd5c8000a,0x7e641bea,0x60090a3e}},	//   ַערט_, _הֶעָ, _snip, шном_
  { {0xbebd0024,0xcdc900a3,0xfe462923,0x0eaa03a9}},	//   drīb, _סך_, онно, икой_
  { {0x3f8b005c,0x13b6000a,0x0000006a,0x0000006a}},	//   ącu_, _והעל_,   ,
  { {0x2d840057,0xbc850016,0x224b006f,0x3f8300bc}},	//   áme_, ưỡn, ôcku_, šju_
  { {0x83b50053,0x6b660080,0x030d0065,0x0000006a}},	//   ַפּע_, окга, _सबाह_,
  { {0x4a9a0010,0xda660015,0x6ec60015,0xda9a0054}},	//   атаў_, ياري, _وتعق, ађај_
  { {0x0ae90015,0xb9060033,0x7e645c27,0x3946059d}},	//   صرفي_, жзак, _unip, çoso_
  { {0xdc760033,0x29120061,0xfaa3011e,0x0000006a}},	// [ee40] _дынь, usya_, фато,
  { {0x07a6009b,0x0000006a,0x0000006a,0x0000006a}},	//   оазн,   ,   ,
  { {0x75e60010,0x2018002c,0x501a004f,0x3ce30065}},	//   оўле, órii_, שועו, _टूटे_
  { {0x56930036,0xcb13000a,0x46a306eb,0x0000006a}},	//   маєт, _קלר_, махв,
  { {0x83f803ae,0xa924005a,0x0000006a,0x0000006a}},	//   белс_, ěžst,   ,
  { {0x54970033,0x04580015,0x0000006a,0x0000006a}},	//   овіў_, صلبة_,   ,
  { {0x442001e2,0x7ebd00dc,0x2bc0000b,0xa3d40065}},	//   ği_, képp, _शुमा, सें_
  { {0x32b70029,0x442019a0,0x32d3002b,0xf2060033}},	//   يدية_, şi_, وزيس, цяко
  { {0xdcea0089,0x66021d65,0x41530033,0x61430b1e}},	//   čněj, mbok, двыс, дења
  { {0x04170015,0xdfda006b,0xb0340054,0x2bc0000b}},	//   _ويقع_, иън_, чнош, _शुभा
  { {0x44f00023,0xf1c60089,0xde5900fd,0x6d4b0030}},	//   _hà_, _řádu_, бані_, _ágaz
  { {0xd2500086,0x660229e2,0x66d10804,0x75225c28}},	//   _سنت_, nbok, råkg, oroz
  { {0x61a5014e,0xd12f0029,0x260b000b,0x82d7004c}},	//   खपृष, _لمن_, ारती_, _וואג_
  { {0x44f000a7,0xbf140086,0x387800c0,0xee3f0264}},	//   _mà_, _فوتب, _norr_, mným_
  { {0x44f05c29,0x660200ad,0xee3f0107,0x5adb0015}},	//   _là_, kbok, lným_, لبرج_
  { {0x9a680004,0x0000006a,0x0000006a,0x0000006a}},	//   ојуз_,   ,   ,
  { {0xee3f0227,0xc4ca000b,0x3eb20030,0x9be700e2}},	// [ee50] nným_, िताओ, ézte_, _мінк
  { {0xa7870086,0x27e7003c,0x98c70033,0xee3f0046}},	//   يشاو, ønn_, ісал, iným_
  { {0x17f80015,0x387c0123,0x752208c6,0x0000006a}},	//   ترقة_, övra_, eroz,
  { {0x44f00023,0x8bd60008,0xd6180015,0x7afa0030}},	//   _bà_, _מותו_, قتها_, ítte
  { {0x9479008f,0x44f00092,0xee3f0107,0xe3e9002b}},	//   йску_, _cà_, jným_, مکان_
  { {0xb97a0008,0x69cf0024,0xee3f0264,0x44f05c2a}},	//   _הנשי, _izce, dným_, _dà_
  { {0xf62b005e,0x75220046,0x443e04ce,0x0000006a}},	//   _візи_, aroz, _dbt_,
  { {0x75225c2b,0xc7b2004f,0x44f001e0,0x0000006a}},	//   broz, _נבן_, _fà_,
  { {0x44f00092,0xa5670015,0xa1560054,0x74f803a7}},	//   _gà_, _بدأن, зању_, _метр_
  { {0x320b0535,0x0000006a,0x0000006a,0x0000006a}},	//   źcy_,   ,   ,
  { {0xe8d8004f,0xd4340058,0x7bc55c2c,0x0000006a}},	//   חוזר_, _تعقب, _nyhu,
  { {0xe3b200b2,0xee3f0069,0x62d90138,0x0000006a}},	//   _אױב_, bným_, _умеў_,
  { {0x82340086,0x81a70015,0x44f00016,0x0d830354}},	//   _آرما, _بحال, _xà_, елян
  { {0x515a000a,0xf1b901ec,0x0000006a,0x0000006a}},	//   _לכנו, ugšu_,   ,
  { {0x7bc50026,0x9f5e0030,0x70520067,0x6b6317b1}},	//   _cyhu, zatú_, _سنيا, нкра
  { {0x64860084,0x2a790034,0x5aca0033,0x1ae30238}},	//   _aðil, _cosb_, ёлам_, еосм
  { {0xad9b002e,0xa9260484,0xaec3006b,0xb9c6002b}},	// [ee60] lbún, ядал, _ябъл, ستره
  { {0x44f00016,0x628b0034,0x3ea25c2d,0xb4d50065}},	//   _rà_, _llgo, likt_, सगो_
  { {0xb8f30372,0x2d82020a,0xe73a0001,0xbc7b0008}},	//   _ही_, lyke_, сее_, _הנית
  { {0xe7b30086,0x2a790026,0xeef6004c,0x6445007c}},	//   رمند, _gosb_, למער_, õhin
  { {0x443e00d9,0x44f30033,0x05ba00c3,0x48e60249}},	//   _pbt_, епіс, حدات_, _хогв
  { {0x44f000a7,0x29005c2e,0x3ea20111,0x66020293}},	//   _và_, mpia_, hikt_, sbok
  { {0xca96000a,0x96f90033,0x75220046,0x6ac7016e}},	//   ּדִי_, _мэту_, sroz, _órfã
  { {0x43830029,0x69c600f2,0x60f803ad,0xee3f0227}},	//   عليق, _kyke, ония_, tným_
  { {0x7ae601e2,0xf1a30010,0x85060002,0xa507006b}},	//   _mikt, ерэн, _روان, _нета_
  { {0xf8be005d,0x6723044c,0x3ea20024,0x66d102d2}},	//   ्तिय, šnje, eikt_, råke
  { {0xad9b002e,0x74130086,0x11e605c4,0x644a0410}},	//   gbún, _سونا, _ежем, mefi
  { {0x27200045,0x7ae60ddc,0xd24f002b,0x2003001a}},	//   mănă_, _nikt, _منم_, ðjir_
  { {0xc6930008,0x6018024e,0x644a5c2f,0x0000006a}},	//   תאר_, _доля_, oefi,
  { {0x644a03fe,0x64585b98,0x81a500c3,0x9ce407c9}},	//   nefi, ndvi, _تحمل, ецсл
  { {0x2018002c,0x403b000a,0xa057000a,0x64580123}},	//   óriu_, _הגוג, _מסגד_, idvi
  { {0x644a0026,0x273500c0,0xcfa9002b,0x200e001a}},	//   hefi, vån_, _باهم_, _hefi_
  { {0x260b000b,0xacb50054,0x69c65229,0x08550033}},	// [ee70] ारसी_, _обиљ, _cyke, мваю
  { {0xed600007,0x189b0015,0x69c610ad,0x6e3d2075}},	//   įžti_, حضرة_, _dyke, lfsb
  { {0x35fb0015,0xf3f10016,0x644a5c30,0xa08b000a}},	//   مرشد_, _lạc_, defi, צְמִ
  { {0x273501d1,0x395200f2,0xcb12000a,0xbcfb0030}},	//   rån_, änsä_, _בלט_, gvég
  { {0x4a5a000a,0xd7fb2fa0,0x69cf003d,0x273502dc}},	//   _ודרו, _губ_, _uzce, sån_
  { {0xc952000a,0x0d3c000a,0xe1f7000b,0x8548005e}},	//   _שמם_, צגוב, ीर्ण_, язів_
  { {0xe2990010,0xf4100029,0x0325005e,0x3605002b}},	//   жай_, اؤه_, єдин, _يوسف
  { {0xfbd4000a,0x5165005e,0xf3f10016,0x6aad5c31}},	//   עתק_, двиб, _bạc_, nnaf
  { {0xd12e0029,0x2eee00b8,0xc4f800e5,0xbcfb0030}},	//   لمي_, _auff_, _فعلا_, nvéd
  { {0x76591dc6,0xd12e002b,0x2eee00c7,0xad9b001a}},	//   ldwy, گمی_, _buff_, tbún
  { {0x6d4404ed,0xa252002b,0x752b0012,0xc2eb0021}},	//   _spia, رپیش, lugz, _طعام_
  { {0xada6008f,0xd12e0086,0x68e70079,0xaf980139}},	//   дамл, دمی_, _lijd, ятых_
  { {0x7ae61edc,0x66ec0064,0x90890015,0xad9b001a}},	//   _rikt, _işke, _ونصك_, sbún
  { {0x3ea202d2,0x61da000a,0x2d8200aa,0xe588000a}},	//   sikt_, _וקנד, ryke_, פָרָ
  { {0x7ae60007,0x6441002d,0xfce301a2,0xb87b016e}},	//   _pikt, _mbli, торо, _luís
  { {0x764b00dc,0x5aca01f3,0x6d400061,0x645801c0}},	//   jegy, ілам_, çmas, zdvi
  { {0x76590176,0x61da0053,0x68e70111,0x88e60010}},	// [ee80] ddwy, ַקעד, _bijd, джае
  { {0xcce60029,0x2fc700da,0x7ae65c32,0x76590034}},	//   _تسعي, _kyng_, _wikt, edwy
  { {0x7ae60cd4,0xf989000a,0xf7720015,0xbcfb0030}},	//   _tikt, סר_, خاء_, tvég
  { {0x98a9005c,0xe1e70086,0x29005c33,0xd910002b}},	//   ytać_, _لس_, ppia_, _میر_
  { {0x20c2002e,0xb5da0015,0x1fba000b,0xa5da0015}},	//   iðir_, آباء_, _उड्ड, آبار_
  { {0x74140087,0xe1ff010d,0x7659028a,0x9583006b}},	//   روبا, ñón_, adwy, ълче
  { {0x1779005f,0xb6a6005e,0x764b01f0,0x64581d3e}},	//   _есть_, _живл, begy, rdvi
  { {0x68e70111,0xfbd3000a,0x479b000a,0x85060015}},	//   _zijd, כתו_, _וילס, _يوأن
  { {0x321d0026,0xb97b0053,0x3cfa000b,0x248c01c2}},	//   _ddwy_, ַנטי, ्ठों_, _tldm_
  { {0x3ea00014,0x942315ec,0x2eee00c7,0x0000006a}},	//   _amit_, _амфе, _puff_,
  { {0x98a90050,0x93460036,0xe80f000b,0x20c2001a}},	//   stać_, _інде, िरता_, fðir_
  { {0x2ca30111,0x644112e1,0xde590010,0x8717004c}},	//   wijd_, _zbli, чамі_, וקטע_
  { {0x2ca30298,0x7dc40010,0x6aad006f,0x3d0a0065}},	//   tijd_, вёрд, vnaf, ़ीले_
  { {0xdbfb000b,0x2eee10ad,0x3ea00a1c,0x20c24be8}},	//   ्रेड_, _tuff_, _emit_, rðis_
  { {0x2ca30111,0x68e70111,0x5f730015,0x8ff7002b}},	//   rijd_, _rijd, _لاير, _غرور_
  { {0xbcfb00dc,0xd357000a,0x7afa0030,0xc9870fac}},	//   tvéd, וילי_, ítta, музи
  { {0x127b004c,0x6aad5c34,0x5ea400c3,0x1dd30065}},	// [ee90] קאמע, rnaf, _جميل, _सरित
  { {0x7d0d0035,0x6aad002e,0xd7950063,0x98a40001}},	//   _iwas, snaf, низъ, виђе
  { {0x64450020,0x229a0024,0x7996002a,0x764b0034}},	//   õhim, lūku_, azyw, tegy
  { {0x7d0d12d1,0x68e70079,0x6fd1000b,0x5eeb000a}},	//   _kwas, _wijd, _हरसं, קַבְ
  { {0x68e70298,0x7996005c,0x93bc0011,0xa509023e}},	//   _tijd, czyw, _scăp, чела_
  { {0x7d0d003f,0x752b0079,0xd259003d,0x8805009a}},	//   _mwas, rugz, doņa_, _سِرو
  { {0x28be005d,0x569503e7,0x6d5a003d,0x20c2001a}},	//   ्तरि, _завт, ātai, yðir_
  { {0xe3b00086,0xd24e0029,0x67d40c9a,0x35f80058}},	//   جره_, منى_, _росу, _يرقد_
  { {0x04c90015,0x95540015,0xbebd003d,0x11450058}},	//   _فوري_, _لخلا, trīn, رَدُ
  { {0xc952000a,0x3ea05c35,0x64415c36,0x94040058}},	//   נמי_, _smit_, _ubli, _لوكه
  { {0x3dc90035,0xd6d9000a,0x20050bfd,0x7d0d172e}},	//   _ayaw_, ּחָל, rbli_, _awas
  { {0xdd1e04f9,0x2018001a,0x61eb186f,0x35a40065}},	//   _câşt, órir_, _uggl, _खेड़
  { {0x20c20084,0x61140010,0xb80f000b,0x0216000a}},	//   rðir_, _адчу, िराम_, _נחסם_
  { {0xc4d20053,0x7afe00d9,0x317a015b,0xdb090046}},	//   ָגל_, _ptpt, _מאנד, _žláz
  { {0xcbc50015,0x6286007c,0xcb67012f,0xbb431534}},	//   نزفي, ökog, наре_, лерк
  { {0x8f9a000a,0xa3d4000b,0xa3d7000b,0x9f5e0069}},	//   _מיצי, सेट_, _सरन_, natý_
  { {0x7d0d0176,0x6aa404f6,0x61fd001a,0x39460033}},	// [eea0] _gwas, riif, ðsly, энаг
  { {0x224d0111,0x7996005c,0xbcfb0003,0x6d563e82}},	//   heek_, rzyw, uvée, _isya
  { {0x160a0029,0x0e5a000a,0xae5a000a,0xbcfb0003}},	//   كياً_, ּדְב, ּכְר, rvée
  { {0x60c15c37,0x040f0016,0xe6120067,0x9f5e00bf}},	//   holm, _đêị_, اشا_, jatý_
  { {0xe89b0064,0x64a602c5,0x35f30033,0x88c70046}},	//   _çağı, нада, упір, _směš
  { {0x672301a3,0x66d1156a,0x39520034,0xe44f0015}},	//   šnja, råka, mwys_, مضى_
  { {0x851c005d,0x39520026,0xba9a000a,0xcc3b004c}},	//   _निकट_, lwys_, ּסִי, פעקט
  { {0x66e3049d,0xd1080015,0x39520034,0x6d560061}},	//   _боса, وقعه_, owys_, _osya
  { {0x39520026,0xc05a00e2,0xa3d40065,0xc617004f}},	//   nwys_, пін_, सेज_, _רחמי_
  { {0xf3f10023,0x89370053,0x80ca000b,0x351b000a}},	//   _hạn_, עריע_, _सीखे, _מומנ
  { {0xbfaa05c4,0x23690015,0x7d0d0852,0x6e953b00}},	//   ятие_, _يحمي_, _swas, вину
  { {0x60c1002d,0xf3ff0016,0xe2970033,0x645a1416}},	//   aolm, _đãi_, _пах_, _hati
  { {0x645a0f4d,0x22510089,0xf27b000a,0xc27b000a}},	//   _kati, ánků_, _מראש, _מראי
  { {0x614307c1,0x645a0273,0x91e305c4,0x39520034}},	//   _сеља, _jati, _соче, dwys_
  { {0x5b243626,0x905b000a,0x645a5c38,0x395200aa}},	//   льта, _זכות, _mati, ewys_
  { {0x9ee90029,0x7d0d003f,0x645a5c39,0x8d950015}},	//   _تفعل_, _twas, _lati, _للبش
  { {0x7d0d003f,0x7ebd00dc,0xaffa000a,0x6445007c}},	// [eeb0] _uwas, képz, ִּ֑י, õhik
  { {0x7e6d0084,0x6f0d005c,0x645a5441,0xb5fd016d}},	//   _hnap, _łaci, _nati, _inši
  { {0xf3f100a7,0x78a5016f,0x2bf6000a,0x7e6d405d}},	//   _bạn_, rihv, _במתן_, _knap
  { {0x6f1a002d,0xfd8b000a,0xf7480015,0x39520034}},	//   istc, ּטַּ, علني_, bwys_
  { {0xddc404f9,0x0c740086,0x8a16000a,0xe3b3002b}},	//   _iniţ, _شدید, _בחרו_, گرش_
  { {0x04450180,0x6722003d,0x85b8006e,0x6f1a0079}},	//   текн, ņoja, رانس_, kstc
  { {0x224d2c46,0xe3b3002b,0x60c14974,0x645a0642}},	//   teek_, درش_, volm, _dati
  { {0x9f5e0014,0x645a003e,0xcb140053,0xb145005e}},	//   ható_, _eati, אלק_, внил
  { {0xb3eb00b0,0x224d0234,0x75d50015,0x645a2195}},	//   _فعال_, reek_, _شيئا, _fati
  { {0x7e6d559f,0x2011006f,0x7eab008c,0x3f85220c}},	//   _anap, úzi_, yöpä, tylu_
  { {0xb4cd005d,0x93270086,0x64940016,0x60c15c3a}},	//   रती_, _سران, _sàig, rolm
  { {0xdc0a005d,0x645a049f,0xf772000a,0x41750015}},	//   वर्ड_, _zati, ׁ֧ר_, _لاتس
  { {0xe1f00070,0x361a0008,0x69cb00b8,0x645a0375}},	//   _اسم_, וורד, ügel, _yati
  { {0x9f5e00dc,0x23650085,0x7eab008c,0x61fb5c3b}},	//   gató_, _krlj_, töpä, lcul
  { {0xaac603c4,0x80ca005d,0xd00e0015,0x7ff40015}},	//   نترن, _सीटे, _بلى_, _إسها
  { {0x61fb5c3c,0xbdfa0015,0x6e46012e,0xba2300f1}},	//   ncul, _غربا_, _реиз, идск
  { {0xc2120008,0x3eb900dc,0x66d80089,0xbcfb0003}},	// [eec0] יהן_, érte_, níke, rvéc
  { {0x7c850292,0x395219c3,0x6bd60015,0xa3e2000b}},	//   _буџе, rwys_, _لتجر, नेड_
  { {0xe3b80061,0xc8b50174,0x645a5a26,0x8c1b004f}},	//   _adın_, усты, _rati, _קוטי
  { {0x68ed0780,0x9bb7013a,0xff7a000a,0x6f1c0030}},	//   _žodž, _יהיה_, וטעמ, árci
  { {0x645a0472,0x95530040,0x0000006a,0x0000006a}},	//   _pati, لخوا,   ,
  { {0x14180015,0x66d80046,0xf746004a,0x61fb5c3d}},	//   ريبة_, díke, _иего, ecul
  { {0xd4670001,0x03960063,0xe6060015,0x18a30033}},	//   тије_, ърдя, _لِأَ, _тарм
  { {0xcb130008,0x1dd3000b,0x645a172e,0x21660850}},	//   בלה_, _सरलत, _wati, втог
  { {0x645a1298,0xdb1e008c,0x273c5c3e,0xa114009a}},	//   _tati, _hypä, lín_, دوخت
  { {0xd46a0015,0x859b000a,0xf3ca0040,0xf993000a}},	//   _تحرم_, _חשמו, _قبضه_, ירח_
  { {0xd4970008,0x273c5c3f,0x8f340033,0x6f730015}},	//   _שכבת_, nín_, ыенц, لاَء
  { {0xad9b002e,0xd337000a,0x61fb0d3a,0xb283066a}},	//   lbúi, _ירבה_, ccul, _вышк
  { {0x9f5e0014,0x7e6d00bd,0x273c2a6e,0xf653000a}},	//   tató_, _vnap, hín_, בצר_
  { {0x273c0077,0xac2402ed,0x2d9901d3,0x0000006a}},	//   kín_, ифск, rzse_,
  { {0x273c002c,0x54390008,0x290200f2,0x60d7000a}},	//   jín_, עֲשׂ, _atka_, _שווא_
  { {0x3166010b,0x9ab40010,0x7e6d2b8b,0x273c5c40}},	//   _kroz_, айсц, _unap, dín_
  { {0x49bb0086,0xc8d9005e,0xaa640004,0x79c8009a}},	// [eed0] ذارد_, емає_, јтск, پولف_
  { {0x20b4005d,0xad1c0008,0xb60200dc,0x7d1b0c98}},	//   ुविध, _חוזר, őáll, áusu
  { {0x2246005c,0x27e700c0,0xb8fa005d,0x8b670086}},	//   _obok_, änn_, _डी_, _شادم
  { {0xbebd0048,0x6723016f,0x05bb002b,0xb76400ce}},	//   drīk, šnjo, ودشت_, штуй
  { {0x961d0048,0x45450029,0x06080010,0xcad6000f}},	//   _noņe, انتق, тнік_, _תורת_
  { {0xb4cd005d,0x26110092,0x85b80029,0xf1c6005d}},	//   रते_, ạo_, خامس_, _लड़न
  { {0x44290064,0xbebd0024,0xf6e70033,0xddc40046}},	//   ğa_, grīk, _ацан, _mniš
  { {0xf3f10023,0x442915e4,0xc7b2000a,0x31665c41}},	//   _tạo_, şa_, _הבל_, _broz_
  { {0xddc6005c,0x10150484,0x2174004a,0x61fb0d28}},	//   zekł, льня, ауэр, rcul
  { {0x20551e48,0x26cf0034,0x61fb1e5e,0x4f0902ed}},	//   утир, llgo_, scul, ннон_
  { {0x7c3800c0,0x44f90092,0x8fa50015,0xa695000a}},	//   _övri, _hè_, امجه, ָכָה_
  { {0xe28e0004,0x02a403ae,0x44f900a1,0x0000006a}},	//   _ѓа_, _крчм, _kè_,
  { {0x721a0008,0xf3f10092,0xd256000a,0x25e6000b}},	//   _נוסח, _lạm_, _תשנה_, जेपी_
  { {0x25d60053,0xc1740115,0x6f650015,0x225f0061}},	//   טורן_, _خدمت, _مهتم, lduk_
  { {0xeb9a031e,0x66190535,0x0000006a,0x0000006a}},	//   хив_, kawk,   ,
  { {0xcb670001,0x273c0b7e,0x225f0509,0xfaa301c5}},	//   ћате_, vín_, nduk_, басо
  { {0x27ff0064,0x213f0509,0x44f95c42,0xbcfb0030}},	// [eee0] _şuna_, ntuh_, _nè_, lvén
  { {0x78250029,0xc8ca0087,0x273c5c43,0x888300eb}},	//   لعمل, روان_, tín_, блуж
  { {0xa6e90023,0xbcfb0003,0xfaa60555,0xfc57004f}},	//   _thự, nvén, _бано, _גביש_
  { {0x44f90023,0x6619002a,0xb6c50033,0x6722003d}},	//   _bè_, gawk, асій, ņojo
  { {0xa613017f,0x273c0ac5,0xa6a90015,0x99750658}},	//   сміч, sín_, خالق_, _курш
  { {0x273c002c,0x2a600020,0x39400007,0xb8f8021e}},	//   pín_, ldib_, mtis_, ात_
  { {0x43940010,0xad9b001a,0xa346004a,0x6619002a}},	//   райс, rbúi, уэлл, bawk
  { {0x6b81003c,0xc7a3006b,0x6443001a,0x39401bab}},	//   ølgi, _уиск, afni, otis_
  { {0x41c60010,0x3940439e,0x54360015,0x31c60033}},	//   ыёка, ntis_, _مرار, ыскв
  { {0x39570008,0x39400007,0xc057022a,0xc953000a}},	//   נשים_, itis_, гію_, צמת_
  { {0xdfd00074,0xdef70010,0x39400020,0xed650091}},	//   تيد_, лыя_, htis_, _mažų_
  { {0x61f60015,0x39401035,0x4094002b,0x93960061}},	//   _إساء, ktis_, الگر, ışır
  { {0xb5fd328b,0x6e240026,0xed580033,0xeda71c4c}},	//   _inšt, _ddib, гоў_, ушно
  { {0x3137011f,0x6e2400da,0xdff600ce,0x656f00a1}},	//   _ערוך_, _edib, _сядь, _áche
  { {0x40eb0008,0x6bd40015,0x7f581111,0x77775c44}},	//   _אַהֲ, متفر, _райс_, xxxx
  { {0x5a3424cc,0xaa580054,0x34b1000b,0x4a5503ae}},	//   йнст, лису_, _जद्द, јкас
  { {0xf807004a,0x39400091,0x9f64001a,0xb8150054}},	// [eef0] гчен, gtis_, ðtæk_, идај
  { {0x6d4d00b6,0xe3b80064,0xddc4016f,0x3eab5c45}},	//   _ipaa, _adım_, _uniš, lict_
  { {0xd6390010,0x6619005c,0x501b000a,0x44f902b9}},	//   вялі_, tawk, גובו, _sè_
  { {0xfd1f02b9,0x1b7a004c,0x44f90144,0xb4cd000b}},	//   osì_, _סטרע, _pè_, रत्_
  { {0xa3e2000b,0xfd1f02b9,0x6619002a,0x39405c46}},	//   नेस_, nsì_, rawk, ctis_
  { {0x3cfc00b2,0x6385005f,0xd4d80036,0xf3f10092}},	//   עלונ, игла, льщі_, _tạm_
  { {0xe1f10029,0x290900f2,0x88ba0053,0xf8b20008}},	//   يسة_, lpaa_, _יזשי, _ושם_
  { {0x31250238,0x44f95c42,0x569405b5,0x225f088a}},	//   адиг, _tè_, _ласт, uduk_
  { {0x225f0064,0xc6920008,0x70550015,0xdbe2000b}},	//   rduk_, _ואן_, لنظا, _खण्ड_
  { {0xe8e00023,0xa3570029,0xdd3d002a,0x69cf2385}},	//   _địa_, _مخصص, _dąży, _myce
  { {0x6d4d0035,0x32550146,0x7d040fde,0x6b4c0030}},	//   _apaa, _ввер, _stis, _mögö
  { {0xd37a0053,0xbcfb00dc,0x39403a0c,0x2129006f}},	//   _ברעט, rvén, ytis_, _ťahu_
  { {0xbca60015,0xd656000a,0x4656004c,0x4dd600fd}},	//   لمحي, בירת_, בױרן_, рінф
  { {0xc19a0008,0xafe50080,0x5f75002b,0xab2a5c47}},	//   _בשני, _колл, _نابر, кога_
  { {0x93bc0011,0x764900da,0x6a863903,0x8f32011e}},	//   _scăz, _obey, алва, _дејц
  { {0xeab710a0,0x39405c48,0x25e6000b,0xb9b60015}},	//   айс_, ttis_, जेडी_, لمزع
  { {0xdc0c0007,0x7aef16c8,0x7d041870,0x4425028a}},	// [ef00] lėči, _dict, _utis, _odl_
  { {0xed4f0086,0xd82600a4,0x39405c49,0xdce43f7b}},	//   _کپی_, рджи, rtis_, _krič
  { {0x39405c4a,0x7aef0b62,0x2909008c,0xe61a0099}},	//   stis_, _fict, apaa_, вде_
  { {0x8afb000a,0x05660a6c,0x656932f4,0x5506030e}},	//   _שהכי, ивен, _breh, ачка
  { {0x7ae42ba0,0xa5330033,0x0000006a,0x0000006a}},	//   mmit, жніч,   ,
  { {0x656900b8,0xd70600e5,0x7ae44299,0x04580015}},	//   _dreh, _نظري, lmit, الثة_
  { {0x23480086,0x83fc016f,0x2d8b037f,0x8c1b004c}},	//   استی_, _nađe, zyce_, דוצי
  { {0xc27407c1,0x59ba000b,0x6b830144,0x71461706}},	//   слиј, _इशार, _ànge, ахож
  { {0xe0860029,0x2291002e,0x7ae45c4b,0x3134004a}},	//   لجدي, _tákn_, imit, щепр
  { {0x653b000a,0x40340054,0x7ae45c4c,0xceb90091}},	//   _בעמד, љенс, hmit, yręs_
  { {0xa3e2021e,0x6d4d0150,0xc7f7000a,0x1073005e}},	//   नेश_, _spaa, יזית_, ілюю
  { {0x6146008f,0x2d8b005c,0x7ae403cd,0x41e60033}},	//   _веда, tyce_, jmit, _кіла
  { {0xfd47008f,0x3eab5c4d,0xe29b000a,0xa3e2000b}},	//   шэнн, rict_, _בשאר, नेर_
  { {0x69cf005c,0x2d8b005c,0x9097005e,0x6f1c0030}},	//   _ryce, ryce_, _квіт_, árcs
  { {0x207b0053,0x8aa75c4e,0x7ce0002e,0x7aef1160}},	//   _באגא, арад, körf, _pict
  { {0xbea400d7,0xc211000a,0x7e2b005e,0x66d10bfd}},	//   _мајк, ּ֔ן_, _ріка_, råkk
  { {0xdd9100b0,0x6b5c0971,0x38c9002b,0x7aef2678}},	// [ef10] _رود_, _pågå, هائی_, _vict
  { {0xa3d7005d,0x89340086,0x7ae40019,0x201a007c}},	//   _सरल_, تعفا, amit, _õpid_
  { {0x7ae4003e,0x7ce000c0,0xe787000d,0x38c4005e}},	//   bmit, förf, јузо, іщув
  { {0xd246040b,0xe7380036,0x65695c4f,0x8f9b000a}},	//   _عن_, реї_, _preh, כיבי
  { {0x2a76013a,0xbebd0024,0xfa76000a,0xfe38000a}},	//   _הערך_, brīv, _הערת_, שרדי_
  { {0x58d40063,0xd5ae0029,0x66d81faa,0xb4470033}},	//   _моят, عفو_, ríka, рэдк
  { {0xd795003b,0xd7630086,0x3ea900f2,0x98a00007}},	//   _الأخ, _بنزی, _omat_, urią_
  { {0xfbb80008,0xda17005d,0xf3f10092,0x1634044e}},	//   יפות_, तरित_, _mại_, _меся
  { {0xf3f10023,0x65940292,0xdce40007,0x6445007c}},	//   _lại_, _дату, _srič, õhis
  { {0xf1b9016f,0xbcfb002e,0x3ea908c0,0xdce405e3}},	//   jaše_, rvél, _amat_, _prič
  { {0xaec60a8c,0x3f910b7e,0x93940015,0x60840015}},	//   йбол, ázu_, _وجما, تشيك
  { {0xbebd0024,0xdc0c0007,0xc7b20008,0xf3f10092}},	//   esīb, rėči, לבי_, _nại_
  { {0x24850020,0x25d5000a,0x9f8d007c,0x212a002b}},	//   _kolm_, מוֹן_, _rõõm_, _مينی_
  { {0xfc031ac7,0xc172000a,0xfce60342,0xdce400bf}},	//   зпро, _מחד_, сого, _trič
  { {0xdca3387e,0x7ae400d5,0xeb971c80,0xab2700f4}},	//   чари, tmit, бир_, йора_
  { {0x629b008c,0x6d410045,0xfaa31e2e,0x6aad5c50}},	//   nhuo, ălar, пасо, giaf
  { {0x7c960074,0xe9da012b,0x7ae4167d,0x0000006a}},	// [ef20] _هشدا, ука_, rmit,
  { {0xc610005d,0xaa7b002c,0x9610000b,0x7ae45c51}},	//   ार्य_, _chýb, ार्ट_, smit
  { {0xf9890b7b,0x91c9005d,0x501a000a,0x2bf7000a}},	//   ער_, _हुसै, רועו, _למין_
  { {0x26df003f,0x798d02f2,0xceb3004f,0x66e3009b}},	//   _chuo_, byaw, ֔יא_, поха
  { {0xceb30008,0xa3f402a3,0xd6cf012c,0xabfa004f}},	//   היא_, оплі, رقه_, ְהֵר
  { {0xb896003b,0x8d5b000a,0xe4b70033,0xb5fd4b6a}},	//   _السع, טכני, бліі_, _raše
  { {0xa3e2014e,0xa2780080,0x6286019a,0xe4e5005e}},	//   नें_, ибку_, ökoo, ціїн
  { {0xe81c000b,0x67b7000a,0x66d83e08,0xf1b90085}},	//   _पड़ता_, _הפלמ_, míko, zaše_
  { {0xd010003b,0xb5fd08a9,0xf0ea005e,0xbebd003d}},	//   ولة_, _inšp, льок_, irīt
  { {0x30a3005e,0x212b0125,0x44380723,0xb5fd125b}},	//   зрюв, ácha_, _ør_, _vaše
  { {0xbebd0024,0x752200b8,0x66d80264,0x443e1180}},	//   krīt, lsoz, níko, _ict_
  { {0xa2f7013a,0x7d160176,0x05dc005d,0x62650029}},	//   _המאה_, _bwys, _बराब, _وانق
  { {0x3f9e005c,0xf1b90085,0xdceb006f,0xf0b7002b}},	//   sztu_, taše_, žičo, شایش_
  { {0xfaf30029,0xc0aa0087,0x67230263,0x3ff40015}},	//   كثر_, _حاصل_, šnji, _بكثر
  { {0xf1b900f0,0xe451000a,0xda4b033d,0x69c30061}},	//   raše_, וֶן_, лчал_, ğnem
  { {0x3ea9013c,0x201a007c,0x201e5c52,0x66d800bf}},	//   _umat_, _õpib_, lati_, díko
  { {0xfe700029,0x7ce00b1c,0xc4ba000b,0xaa040015}},	// [ef30] _أدى_, förd, ेवाओ, سِلي
  { {0x7ce000dc,0x6902005c,0x798d0049,0x201e5c53}},	//   görd, _żydó, ryaw, nati_
  { {0x23a7014e,0xf3f10023,0x69c10050,0x58840010}},	//   _केंद, _tại_, _śled, чыта
  { {0x3eb91220,0x91790092,0x201e5c54,0x443e5c55}},	//   nnst_, hất_, hati_, _act_
  { {0x3eb90041,0x2a3a0053,0x201e5c56,0x7ce00123}},	//   inst_, _דערמ, kati_, börd
  { {0x69dd5c57,0xbcfb00dc,0x201e1001,0x4ddc000a}},	//   _izse, evék, jati_, אחדו
  { {0xd6db0063,0xa5c3005c,0x201e59d1,0xf2c50015}},	//   _бта_, _łódz, dati_, يْتُ
  { {0x5999000a,0xe5090067,0x6586001a,0x410507bd}},	//   ֹשֻׁ, _نيرو_, ðuhó, озив
  { {0x2ee00026,0xa9fa000a,0x05bb0015,0x201e0363}},	//   _rhif_, יִית, _صدرت_, fati_
  { {0x7d160026,0x3eb90b8e,0x629b008c,0x6fca000b}},	//   _rwys, enst_, shuo, _सुहू
  { {0x56b50053,0x661b0079,0x7ce00123,0xe167009a}},	//   ַפֿן_, _keuk, nöre, _گداي
  { {0x7d160176,0x7af800dc,0x25f0000b,0x201e50d0}},	//   _pwys, _évti, ुँची_, aati_
  { {0x7ce000b8,0xe2c8002b,0x201e5c58,0xb224005e}},	//   höre, _اونو_, bati_, _хміл
  { {0x67220024,0x201e457d,0x661b529b,0x7188000a}},	//   ņoji, cati_, _leuk, _לְצַ
  { {0xe519005d,0x28bf000b,0xc052004f,0x9f050058}},	//   नीति_, ्वनि, _חזו_, _بوبو
  { {0x83fc016f,0x29d6002b,0xba0a0015,0x4a460033}},	//   _mađa, قيزس, شترك_, ўнав
  { {0xd94302a7,0xa926004a,0x88860054,0xf8aa0329}},	// [ef40] мети, юдал, олаж, авак_
  { {0x7ce000c0,0x7e64003f,0x69dd0030,0x7c96029b}},	//   före, _haip, _dzse, _фриц
  { {0xc8150036,0x160a0029,0x7e64008c,0x7ce05c59}},	//   яєть, لياً_, _kaip, rörd
  { {0xc8690008,0x0eca005d,0x7bde00bd,0x201e5c5a}},	//   כן_, रविड, _izpu, zati_
  { {0x7e6400b6,0xe4c601c5,0xe5720015,0xddcd0061}},	//   _maip, ойди, بطا_, _maaş
  { {0x6c7a00b2,0xf993000a,0x4ddb000a,0x6d5a002a}},	//   שאַפ, _חרש_, בחנו, łtaw
  { {0x201e5c5b,0xd4c50015,0x6d46007c,0x64c30015}},	//   vati_, أغني, htka, بيول
  { {0x7e645c5c,0x09de021e,0x3253006b,0x201e0cc4}},	//   _naip, _मराठ, двър, wati_
  { {0x60f70010,0xa507366a,0xba9b000a,0x98ab002a}},	//   оныя_, _мета_, יסקי, śląc_
  { {0xdb1e0152,0x91790092,0xf487002b,0x05770015}},	//   _expé, uất_, _والی, _بمكة_
  { {0x0206008f,0x57fb0008,0x6e950029,0xa857000a}},	//   _дзен, יליו, كلدا, חייה_
  { {0xeeab21ec,0x201e5c5d,0x4ea70033,0x644a00a6}},	//   рток_, sati_, ірна, lffi
  { {0x201e330c,0xc2e900c3,0xa2c7000b,0xb2bb000a}},	//   pati_, _اعلم_, ावर्, _דמאר
  { {0xcce70029,0x64580e08,0x9ccb01b0,0x0000006a}},	//   تسجي, nevi, рыма_,
  { {0x64580024,0x386d0064,0x7ce000c0,0xba770015}},	//   ievi, _ğer_, förb, يارت
  { {0x539b000a,0xbf9b000a,0x9f9b000a,0x80a6000b}},	//   בילו, _כיוש, _כסופ, टोरे
  { {0x66d8002c,0xb5fd016f,0x1ec40015,0xbce70015}},	// [ef50] ríkl, _naša, _تقيّ, _وأخو
  { {0xa3cd005d,0x7ce004d4,0xf1b90844,0xe76b0054}},	//   रथम_, töre, naša_, ијек_
  { {0x46150015,0x96750033,0x64585c5e,0x661b005b}},	//   كوار, зылі, devi, _peuk
  { {0x83fc0085,0x7ce0203a,0x201c5c5f,0x644a0dca}},	//   _rađa, röre, _levi_, effi
  { {0xa4d50036,0x260a005d,0x3a7a000a,0x4c4b004f}},	//   поді, ाड़ी_, _הטרד, ֹתֶ֑
  { {0x05640033,0xfaf8002b,0x64585c60,0x78fa004f}},	//   ьвін, _دریغ_, gevi, _לפשו
  { {0xe2910029,0xa357002b,0x68fd02d6,0x250b009a}},	//   فذة_, تیاط_, _husd, ارچی_
  { {0x3bbc0008,0x7d00013f,0x0000006a,0x0000006a}},	//   ימוד, ímsk,   ,
  { {0xdb0a099c,0x20d50210,0xe2a80015,0x65150015}},	//   čnéh, зінс, تاون_, _روائ
  { {0x76590026,0xd24e0086,0x64585c61,0xf497002b}},	//   lewy, پنی_, cevi, _بشرد
  { {0x201c04ed,0x5f050010,0x80880015,0x04c80058}},	//   _devi_, язна, تضيف_, _بولي_
  { {0x76590026,0xc3320dab,0xd12e002b,0x290b006f}},	//   newy, _טוב_, خمی_, _otca_
  { {0x0d760010,0xdd920031,0xf2d2004c,0x7659002a}},	//   чыня, روس_, _װעג_, iewy
  { {0xe0d80036,0x8fa50605,0x68f50061,0xa3e2000b}},	//   _дві_, _нале, _nizd, नेक_
  { {0x7d0f0014,0x68fd00b8,0xf0920008,0x244f0064}},	//   apcs, _ausd, _אנג_, mımı_
  { {0x244f0064,0xdb0f00dc,0x68f50cd4,0x6b630033}},	//   lımı_, ójár, _aizd, экса
  { {0x7e9b0008,0x68f50064,0xceb3000a,0x2caa006b}},	// [ef60] _לסקו, _bizd, _ריח_, _гкпп_
  { {0x244f0064,0xf7ea0015,0x321d002a,0x6725001a}},	//   nımı_, مرضى_, _lewy_, fshj
  { {0x3b0a0001,0xb5fd0024,0xabfb009d,0x9bfb000a}},	//   _ћемо_, _saša, _להיר, _להיט
  { {0xb5fd18a6,0x61f90026,0x765900dd,0x4b7b000a}},	//   _paša, _ngwl, gewy, _האטו
  { {0x244f0064,0x64585c62,0x20073c9c,0xf44001f3}},	//   kımı_, tevi, _ofni_, волi_
  { {0xb4d6000b,0xd5af0015,0xb5fd0816,0xa3d4011d}},	//   सते_, دفه_, _vaša, молч
  { {0xd4d90010,0x644a0026,0x289b01ac,0x244f0061}},	//   цьці_, rffi, _פילא, dımı_
  { {0x64585c63,0x77bb0008,0x201c0024,0x6441052a}},	//   sevi, _המלח, _sevi_, _ecli
  { {0x7afe0011,0x4153004a,0xb5fd1129,0xbcfb0030}},	//   _lupt, евыс, _kašn, lvév
  { {0x67220048,0x859b0008,0x2f01005c,0xf8cc005d}},	//   ņoju, _השמו, _bóg_, ़किय
  { {0x82fa0021,0xf1b9036d,0x442c0030,0x0f2302ed}},	//   _طراز_, raša_, _idd_, ньям
  { {0x20070084,0xbfa7004a,0x321d00aa,0x02fb004f}},	//   _efni_, ятые_, _gewy_, _הלאמ
  { {0xd12f0029,0x2bd2005d,0x244f0064,0xcd07005e}},	//   _ممن_, _दुबा, bımı_, ячни
  { {0xe7be005d,0x515b000a,0x7659002a,0xcfb4006b}},	//   ्थाप, _לכדו, zewy, _облъ
  { {0x66d8002e,0xe0850015,0x2cb10030,0x7afe0045}},	//   ríkj, _تجني, rizd_, _cupt
  { {0x68f50064,0x62860e95,0xf8b1002b,0x2014002a}},	//   _sizd, ökoh, چکس_, łcić_
  { {0xa9540036,0x99d70115,0xda08002b,0x5c070033}},	// [ef70] нкті, سترا, سيله_, _няна
  { {0x7d0d2822,0xd795006b,0xd7fb0b9b,0x3157004f}},	//   _itas, мизъ, суа_, הימן_
  { {0xf09300b2,0x59f9005f,0x7bc00012,0x765900aa}},	//   ענע_, _меня_, ßmut, tewy
  { {0xddcd00bd,0xe7300115,0x442c5c64,0xd6180015}},	//   _znaš, اصل_, _add_, كتها_
  { {0x290b00dc,0x244f0061,0xc5680015,0xd126006e}},	//   _utca_, yımı_, كحول_, _جم_
  { {0x2a690005,0xe3b00086,0xb97a000a,0xc4f80015}},	//   ldab_, گره_, _ונשי, سعها_
  { {0x6e2d010b,0x42e9004a,0xc6d70015,0x394930c2}},	//   _odab, омко_, _فترت, ltas_
  { {0x2a690005,0xdb9c000a,0x8235002b,0x8505002b}},	//   ndab_, מסור, ذربا, _يوزن
  { {0x244f0064,0x7ce000c0,0xa1560001,0xd059005e}},	//   tımı_, höra, дању_, орні_
  { {0x39495c65,0xf8bf000b,0xaf050342,0x26cf5c66}},	//   itas_, ्विय, мпол, logo_
  { {0xd2510029,0x244f0064,0x7d0d439e,0x09ba000b}},	//   _لنا_, rımı_, _atas, _इश्य
  { {0x66d8002e,0x656d002c,0x39495c67,0x63040015}},	//   víkk, ťahu, ktas_, _أونل
  { {0x5045000d,0x0d83005e,0x71240015,0x244f0061}},	//   _желб, влян, _كرول, pımı_
  { {0x2f01002d,0x7ce000c0,0xa283002b,0xf1b9003d}},	//   _tóg_, föra, _آیکو, lašo_
  { {0xcee90074,0x9f4300f2,0x316d534a,0xb5fd049f}},	//   ترین_, äjä_, lvez_, _našo
  { {0xa3e2014e,0x3b07000d,0x628b5c68,0x39495c69}},	//   नेट_, ќето_, _jogo, ftas_
  { {0x628b018c,0x3946008f,0x26cf003f,0x09290015}},	// [ef80] _mogo, ьнаг, dogo_, كسلي_
  { {0xddc401c9,0xe73a005e,0xbca6002b,0xe6b8000b}},	//   _kniž, жеж_, _آمدي, ेक्ज
  { {0xfaa60010,0xbc7b0008,0x628b16f3,0x26cf5c6a}},	//   _жано, _ונית, _oogo, fogo_
  { {0x628b01a3,0x0000006a,0x0000006a,0x0000006a}},	//   _nogo,   ,   ,
  { {0x39490896,0x6fcf000b,0xdb1e002a,0x85760015}},	//   ctas_, _सुसं, _typó, بدائ
  { {0xe2f80010,0x430a024f,0x316d0030,0x66095c6b}},	//   пекі_, охим_, dvez_, _efek
  { {0xbcfb0014,0xf626049d,0x73070015,0x628b5832}},	//   lvét, _одво, وقوف_, _bogo
  { {0xa686008f,0x6a9b004c,0x291237c8,0x2242007c}},	//   _ўлад, ַשינ, opya_, ükk_
  { {0x628b477c,0x52730054,0x50f40588,0x0000006a}},	//   _dogo, тују, нзит,
  { {0x497b0053,0x2912003f,0x74130029,0x937a0015}},	//   קטיװ, ipya_, _لوكا, _وصار_
  { {0xf837013a,0x7529116e,0xa8370008,0xdeb50080}},	//   ונית_, _zvez, וריד_, ебны
  { {0xe7e6005d,0x39490007,0x7d0d002a,0xb5fd3e73}},	//   _करना_, ytas_, _ptas, _našl
  { {0x41e2005d,0xa06a0001,0x35b6000b,0x3034004a}},	//   _परिस, _мада_, _आइफ़, _зелё
  { {0xa3e5000b,0x70530015,0x6efe003d,0x7ce0186f}},	//   _नरम_, _لنها, _lībi, töra
  { {0xdfd0003b,0xbcfb00dc,0x46ce000b,0xf3f1000a}},	//   _حيث_, evét, ़वाह, ָ֣ם_
  { {0xdb0e00dc,0xb5fd0007,0x39490cbf,0xdced0735}},	//   ájáb, _rašo, ttas_, _irač
  { {0x7d0d5c6c,0xddc412d7,0x2a69007c,0x39495c6d}},	// [ef90] _utas, _zniž, rdab_, utas_
  { {0xf84b0033,0x7bc00061,0x3949386d,0xb5fd5c6e}},	//   ўчай_, ğmur, rtas_, _pašo
  { {0x87040036,0x2912003f,0xf77300e5,0x752959d5}},	//   вяче, apya_, خاذ_, _svez
  { {0xb5fd5c6f,0x26cf02b9,0x39495c70,0xdced5c71}},	//   _vašo, uogo_, ptas_, _mrač
  { {0x27ff0064,0xd90f002b,0x7aed5c72,0x26cf5c73}},	//   _şunu_, _ضیا_, mmat, rogo_
  { {0xd91a0008,0xcd98000a,0x04590015,0xb5fd3670}},	//   _מושל, ודדת_, سلعة_, _zašl
  { {0x628b1981,0xe299134f,0x8c1c000a,0x7aed1110}},	//   _pogo, зай_, חווי, omat
  { {0x7ce0002e,0x2bf8000a,0x7aed5c74,0xe6670033}},	//   jörn, ומון_, nmat, _ўтво
  { {0xf1b90007,0xddc404c6,0x316d0003,0x75290085}},	//   rašo_, _sniž, uvez_, _uvez
  { {0x93bc04f9,0x79ba000a,0x3cf9000b,0xdced0e1d}},	//   _adău, לֶיה, ंदों_, _brač
  { {0xbcfb00dc,0xc0a80018,0x7aed5c75,0xdddd04b2}},	//   zvét, بايل_, kmat, lesň
  { {0xf7720053,0xed5a2e79,0x7aed1253,0xe2ab0058}},	//   אקט_, пом_, jmat, _بائن_
  { {0xdb0a0089,0x6fcf000b,0x8d760021,0x26b6000a}},	//   čníh, _सुरं, راحا, תִים_
  { {0x66d8002e,0xbcfb0030,0xd1b80015,0x7aed3b81}},	//   ríki, evés, _تاما_, emat
  { {0xb5fd0024,0xdced0085,0x60c60030,0xa09a05bd}},	//   _pašl, _grač, ékme, _מיסט
  { {0xba170015,0xbcfb0030,0x7aed5c76,0xda170065}},	//   فيفا_, tvét, gmat, तरगत_
  { {0x6e2600b6,0x510c0053,0xc9aa0010,0xdced02c6}},	// [efa0] makb, ַהאַ, чвае_, _zrač
  { {0x38a4002e,0xe9df0251,0x6e2647bb,0xd706024f}},	//   _mörg_, _abús_, lakb, езжи
  { {0x6f0b04f9,0x96fa0015,0x7aed4cff,0xbcfb0030}},	//   _încă, سعار_, bmat, svét
  { {0xd7ef003b,0xd7570015,0xf6d6002b,0x98c00061}},	//   حكم_, علنت_, رزاد, ırıp_
  { {0xf9fb000a,0x54fa0065,0x96270058,0xbcfb01f6}},	//   _מהכמ, एआइए_, ركوك_, lvér
  { {0x34ca000b,0xf3660499,0x3ea00144,0xd4e3030c}},	//   ाकेद, етин, _llit_, лющи
  { {0x61e20014,0xcc3b0053,0x37e30036,0x35dc000b}},	//   _szol, לעסט, _борг, _बरक़
  { {0x754900dc,0x29023ff5,0xc27402d9,0x7ea60052}},	//   öszö, _kuka_, тлиј, _hópf
  { {0x5bbd000b,0x912a0015,0x7ce0001a,0x6e2601d7}},	//   _ईश्व, أسبق_, vörn, dakb
  { {0x29020b71,0x2369002a,0x7aed5c77,0xf3f10016}},	//   _muka_, łaja_, zmat, _tạp_
  { {0xd4970008,0xdfd00029,0x289b004c,0x93aa0021}},	//   _רכבת_, شيح_, פיטא, _عاطف_
  { {0x71a60010,0xdced10ca,0x65620012,0x7ce00123}},	//   _паез, _vrač, owoh, föro
  { {0xf8bf0089,0x656200b8,0x7aed5c78,0xbcfb0030}},	//   _svém_, nwoh, vmat, evér
  { {0xe04a0086,0x659b0053,0xb1e50015,0xbddb0003}},	//   _رشته_, ליכק, _شأنه, ffèr
  { {0x75f60064,0x290205d8,0x2057000a,0x7aed5c79}},	//   _yüzü, _auka_, _ניהל_, tmat
  { {0x28d9005d,0x5fdb0008,0x3fdb000f,0x29020509}},	//   _बीजि, _מחוק, _מקוב, _buka_
  { {0x200b0050,0x19580256,0x7aed27f4,0xdd040045}},	// [efb0] ście_, наты_, rmat, ărăs
  { {0x290f0024,0x58d8004a,0xc619000b,0x29025c7a}},	//   īga_, едуя_, दर्य_, _duka_
  { {0x65620012,0x7aed5c7b,0x0000006a,0x0000006a}},	//   ewoh, pmat,   ,
  { {0xe6040015,0x6aa45c7c,0x7ce00dca,0xd7c8012c}},	//   هِمَ, chif, hörl, رونه_
  { {0xb5fd016f,0x250a002b,0xd46901ca,0x38a402dc}},	//   _hašk, وروی_, диле_, _börd_
  { {0x6e2600dc,0x5fb2005d,0x2298002e,0x34cb000b}},	//   zakb, ुपाल, _fékk_, िवेद
  { {0x98a9005c,0x64a20457,0x753c003d,0xf8bf0065}},	//   erać_, раща, _ārze, ्वीप
  { {0xe7e6014e,0xb1190015,0x67d4004a,0x4b7c000a}},	//   _करता_, وقعا_, _сосу, לאוו
  { {0x7ce03ce7,0x44f50033,0x98a9002a,0x6e260030}},	//   förl, _апас, grać_, vakb
  { {0x2ebc014e,0xc952000a,0x30750054,0x3ea000c7}},	//   ोक्त, סמי_, туис, _slit_
  { {0x6e2600b6,0x75f60061,0x3cfa003d,0x00e20033}},	//   takb, _tüzü, _ripv_, ржэн
  { {0x98a90050,0x644341a5,0x2018001a,0x44275c7d}},	//   brać_, lgni, ðrir_, lan_
  { {0x7ce00123,0x38a40012,0x61451797,0x44275c7e}},	//   börl, _höre_, _рела, oan_
  { {0x7f850029,0x29025c7f,0xdd0c002a,0x629b27cb}},	//   _للتن, _ruka_, _półg, lkuo
  { {0x29020509,0xab2a005e,0x44271ba0,0x64435c80}},	//   _suka_, ьова_, ian_, igni
  { {0x3ea00035,0xdd920806,0x62895c81,0x6aa4003f}},	//   _ulit_, _نوع_, njeo, uhif
  { {0x44270be7,0x3cca006b,0x2cba0015,0xbddb0144}},	// [efc0] kan_, _олио_, _يُعد_, sfèr
  { {0xb7960001,0x6e240026,0x38cb0086,0x44275c82}},	//   крећ, _heib, والی_, jan_
  { {0xdc9b0008,0x91820092,0x5c37000a,0x6f0318b4}},	//   _חייל, iết_, _ברין_, _junc
  { {0x7d041437,0x6f035c83,0x442740b0,0x656202ad}},	//   _kuis, _munc, ean_, twoh
  { {0x7d040111,0x96330010,0x44270f48,0xb5fd0227}},	//   _juis, рніц, fan_, _zašk
  { {0x7d04022d,0x644301d1,0xec360053,0x44271830}},	//   _muis, ggni, דאַר_, gan_
  { {0x3d19000b,0x4374002b,0xa857000a,0x6f030f9f}},	//   _बढ़ने_, اهبر, _שילה_, _nunc
  { {0x68fc03c0,0x2cb800da,0x66e60033,0x44275c84}},	//   _hird, hird_, _роба, aan_
  { {0x60f80063,0x7ce00399,0x44271ee9,0x81430015}},	//   нния_, törl, ban_, لنين
  { {0x38a400c0,0x66d8002e,0x44275c85,0x6f031895}},	//   _före_, ríku, can_, _bunc
  { {0x38a401e2,0x883b0008,0x141b000a,0x3940016b}},	//   _göre_, ותיו, _חובב, huis_
  { {0x52760029,0x7ce00064,0x32ba0015,0x83fc0085}},	//   _جائز, sörl, _غداة_, _nađi
  { {0x61430010,0xc2370008,0x7d0419b0,0x68fc0125}},	//   _веча, _יראו_, _cuis, _oird
  { {0xd197013a,0x6abd005d,0x31570135,0x7d042dcc}},	//   _בכדי_, ्क्र, _סיון_, _duis
  { {0xeb040080,0xcf8f0001,0xda350892,0x6e240034}},	//   ичто, _тј_, левы, _feib
  { {0x68fc06f8,0x44275c86,0x5a3408b0,0x6443002a}},	//   _aird, zan_, инст, zgni
  { {0x3eb91c23,0x49750010,0x44275c87,0x68fc17e3}},	// [efd0] mist_, ылас, yan_, _bird
  { {0x48140036,0xb5fd1f07,0xa8140850,0x7e6d05ff}},	//   имус, _tašk, идуш, _haap
  { {0x3eb9002d,0x44275c88,0x8c1a039e,0xab95005e}},	//   oist_, van_, _אותי, _сині
  { {0x4427294a,0x7e6d0fd8,0xb5fd00b3,0x3eb95c89}},	//   wan_, _jaap, _kaši, nist_
  { {0x91820092,0x7c250a83,0x2d990007,0xd5480015}},	//   yết_, _kehr, nyse_, نجوم_
  { {0xdfc6003b,0x68fc17e3,0xbddb0003,0x3eb91844}},	//   _هي_, _gird, ygèn, hist_
  { {0x7c25018b,0x3eb93785,0xa3550015,0xb4440033}},	//   _mehr, kist_, اختص, рэчк
  { {0x69dd022d,0x7afd0089,0x7c2500b8,0x36d55c8a}},	//   _kyse, _jist, _lehr, _собр
  { {0x6f03016f,0x3eb90100,0x4427469f,0x6e240012}},	//   _sunc, dist_, pan_, _reib
  { {0xf992013a,0x69dd04d0,0x62862b60,0x6e2413ec}},	//   צרי_, _myse, ökor, _seib
  { {0x7ce000c0,0x3eb9002e,0x7afd00f2,0xb7b6000a}},	//   börj, fist_, _oist, ָּיו_
  { {0x7d045c8b,0x8756000a,0x7afd55aa,0x3eb95c8c}},	//   _puis, נברג_, _nist, gist_
  { {0x386100b8,0x6e24003c,0x7d040a40,0x44255c8d}},	//   kehr_, _veib, _quis, _kel_
  { {0x7afd002f,0x3ebe0014,0xe8bf005d,0x6e2400b8}},	//   _aist, őtt_, ्वोच, _weib
  { {0x7afd0a00,0xc0520008,0xfaa60010,0x3eb9007c}},	//   _bist, _הזו_, гаво, bist_
  { {0x7d045c8e,0xaf020063,0x69dd0026,0x442519fb}},	//   _tuis, _упъл, _byse, _lel_
  { {0x3edb0053,0xceb30008,0x7afd270b,0x69dd0034}},	// [efe0] _אַזא, _ליה_, _dist, _cyse
  { {0x44250ede,0x7afd214f,0x9d1b01ac,0x7e6d002a}},	//   _nel_, _eist, _רויט, _zaap
  { {0x96ba0001,0x9fa2002e,0x6ac60031,0x66e60b76}},	//   нуду_, níða_, _مقدم, гожа
  { {0x3940038d,0xfbd30008,0xd7ef0015,0xe20a002a}},	//   puis_, _לתת_, سكن_, _któż_
  { {0x68fc0024,0xe7e6000b,0x1fd0000b,0x93bc0045}},	//   _tird, _करवा_, _हड्ड, _adăp
  { {0x7afd002c,0x44255c8f,0xf993000a,0x3eb95c90}},	//   _zist, _cel_, _הרש_, zist_
  { {0x07d80086,0x44252741,0xd4910016,0x02440015}},	//   _شهرک_, _del_, _dò_, لَغَ
  { {0x63030015,0xe20a002a,0x7ce00123,0xd1340054}},	//   حويل, _otóż_, förk, анић
  { {0xe693003b,0x2bdb005d,0x44255c91,0xb273004a}},	//   _القد, _मुना, _fel_, слыш
  { {0x2e240023,0x7e6d00f2,0x31570015,0x7ce00123}},	//   _đườn, _saap, اجية_, sörj
  { {0x2d9900dd,0xd8d70135,0x32460031,0xe4090067}},	//   wyse_, רויט_, _مناف, _شغله_
  { {0x2d990007,0xadbd0033,0x2f2e002a,0x7c250b85}},	//   tyse_, дамi, ręg_, _sehr
  { {0xa2d30086,0x9cb50029,0x41730086,0x212b002d}},	//   _اينت, لمحت, _هاوس, ácht_
  { {0x30760001,0x3eb90100,0xf1a9002b,0xdbdf001a}},	//   _људс, sist_, _جامه_, _bíði
  { {0x709b0053,0xab840036,0x447b0053,0xb09b000a}},	//   _אױגו, бутк, ענלע, _איגר
  { {0x7c254024,0x38610ccc,0xc9870076,0x69351e60}},	//   _wehr, wehr_, лузи, инбу
  { {0x7afd3303,0xf1b9036d,0x7c255c92,0x99d70058}},	// [eff0] _vist, taši_, _tehr, اتزا
  { {0x9c470036,0x7afd198a,0x69dd005a,0xa83500af}},	//   _схил, _wist, _vyse, режљ
  { {0x7afd018c,0x3d19000b,0xa9240091,0xacfa000a}},	//   _tist, _बढ़ते_, _įžei, _שהתכ
  { {0x7afd122c,0xaa6706a6,0x442541ca,0xd246006e}},	//   _uist, _сток, _sel_, _ظن_
  { {0x442508e0,0x94250010,0x7ce00123,0xf1b9003d}},	//   _pel_, амле, förh, paši_
  { {0xd4910023,0xb9ba0008,0x5437002b,0xa4d4005e}},	//   _tìm_, _יצרת, ارشر, бочі
  { {0x98a00007,0x44255c93,0x03a5005e,0x8ccd000b}},	//   usią_, _vel_, рийо, _सदनो
  { {0xddc40780,0xd6c30086,0x527505d1,0x44255b36}},	//   _laiš, _امری, руку, _wel_
  { {0x844703c4,0x38a40123,0x97420033,0x16b3000b}},	//   _مخال, _höra_, сiць_, ूचीब
  { {0x40950080,0x38a400c0,0xf5940015,0xddc40085}},	//   ррит, _köra_, _الْج, _naiš
  { {0xaec60080,0x8e862dc2,0x92160157,0xd37b00ce}},	//   ибол, агне, _ध्वज_, _яча_
  { {0x6da60029,0x5336000a,0x531a000a,0xdef90033}},	//   لمجم, _כנען_, _יועצ, лыў_
  { {0x9fa2002e,0xee37006d,0x2bdb000b,0x929a000a}},	//   síða_, шня_, _मुबा, _שינת
  { {0x61e601e2,0x659a0053,0x99920535,0x8c4600af}},	//   ükle, דישק, ybył_, јеве
  { {0x00ba000a,0x8a060734,0xdee601cf,0x0000006a}},	//   _במסמ, изве, _коки,
  { {0x7bde0107,0x6f0d006f,0x0000006a,0x0000006a}},	//   _vypu, _čach,   ,

  { {0x7ce00b1c,0x7bde002a,0xd94603a8,0xfaa3004a}},	// [f000] höri, _wypu, рези, цато
  { {0xf8a70033,0xdbdf001a,0xddc42647,0x7bde2059}},	//   авук_, _tíði, _gaiš, _typu
  { {0x4c3b0008,0x6e360089,0xdc3b000a,0xcc3b000a}},	//   _בתיב, _kdyb, _בעיר, _בעיט
  { {0xe7371068,0xcf56004f,0xee09004f,0x0000006a}},	//   рец_, יבעת_, ְמוֹ_,
  { {0x25a0017e,0xa8060080,0x68eb00dc,0x3a37000a}},	//   áil_, _взгл, üldé, _דרכם_
  { {0x7ce000c0,0xb5fd0007,0xe71a0196,0x38a40123}},	//   föri, _našu, _ليست_, _föra_
  { {0x38a401d1,0xb7da0086,0x02a60555,0x25a04952}},	//   _göra_, _شورا_, ирим, šil_
  { {0xcb130008,0xd62200ce,0x01640058,0x9377009b}},	//   חלה_, сiда, مُعَ, рбът_
  { {0x395200df,0xe5a30036,0x044603de,0xe63b000a}},	//   ntys_, _дити, _везн, _שתמכ
  { {0xc9530008,0x39520091,0xe4330015,0x251b004f}},	//   קמת_, itys_, _وفقد, _סובא
  { {0x4fc6008f,0xbebd0024,0x78790135,0xddc40091}},	//   рспа, ksīt, אָרו, _raiš
  { {0xddc40024,0x32930015,0x94b6000b,0x539b000a}},	//   _saiš, _وللأ, _अगुआ, _שיאו
  { {0x1cbb0115,0x6dcb0033,0x91e30973,0x6e360034}},	//   ناسب_, тынг_, _доце, _ddyb
  { {0x20d30015,0x417b000a,0x9d184ceb,0xb19b004f}},	//   _وتوج, _שנגב, рорт_, _בידכ
  { {0x501b000a,0x6017000a,0x907b000a,0x62820079}},	//   _יוגו, _דחוף_, _שְׂפ, _knoo
  { {0x3ffb0008,0xb345001c,0x6e36005c,0x201e0007}},	//   _בפוע, luçã, _gdyb, lbti_
  { {0xf8071328,0x645a5c94,0x6ce7008b,0xc4d60065}},	// [f010] ачен, _obti, _віне, धवाओ
  { {0x645e0020,0x2bd2005d,0xb0650020,0xb9240015}},	//   õpil, _दुका, mmää, تفكي
  { {0x7ea6002e,0xb06500f2,0x39520091,0xd7fb00af}},	//   _hópa, lmää, atys_, туа_
  { {0xd6180115,0x02f00061,0xcb12000a,0x0000006a}},	//   لتها_, üçlü_, _מלט_,
  { {0x2bdb005d,0xb06500f2,0xb5fd40ca,0x6c78002b}},	//   _मुता, nmää, _našt, _صحیح_
  { {0x1d18000a,0x8365002b,0x04590015,0x38a40123}},	//   סקור_, مدعل, الغة_, _hörn_
  { {0xb34503af,0xb06500f2,0xddc40011,0x04560015}},	//   duçã, hmää, _obiş, صلية_
  { {0x224b00b8,0x86c50086,0x85050021,0x36d40e3f}},	//   ück_, _ايرن, _هورن, _доср
  { {0xb5fd20c0,0x200307c4,0x04670004,0x30755c95}},	//   _pašu, žjim_, _втем, бунс
  { {0xa0690054,0x10a508d7,0xf739004f,0x0000006a}},	//   ћана_, сион, ְעָם,
  { {0x1fb50174,0x4e2a02ed,0x0000006a,0x0000006a}},	//   сспр, лонн_,   ,
  { {0x975a0008,0x3952008c,0xa2f50054,0x657b01df}},	//   נדרט, ytys_, _упеч, _kruh
  { {0xc1080092,0xe167002b,0xee3f0069,0x6b9c0034}},	//   _hỗn_, _خداي, chým_, wyrg
  { {0x98a70089,0xb345001c,0x61eb5c96,0x1d073142}},	//   čně_, cuçã, _izgl, сери_
  { {0xb5fd010b,0xf1b90007,0x38a4001a,0xaae60015}},	//   _zašt, rašu_, _börn_, مسرو
  { {0x8f9a0008,0xbebd003d,0x1a0601b0,0xad9b016e}},	//   _תיקי, usīt, спам, rcúr
  { {0x6d400f11,0x09fa0015,0x99160033,0x8c460ea8}},	// [f020] ámad, افذة_, сьбі, _лепе
  { {0x6d460b91,0x765b01d7,0x39523def,0x673e0085}},	//   muka, _abuy, rtys_, trpj
  { {0xc8150036,0x36060029,0x6d4b00c0,0x395209e2}},	//   юєть, مواف, _ägar, stys_
  { {0x7c2e5c97,0xd6d90036,0x657b013b,0x69ca02ad}},	//   labr, аті_, _bruh, ßfes
  { {0x3edb004c,0xa5330033,0x05ba0015,0xe5340174}},	//   אַגא, зніч, ددات_, цель
  { {0x657b0156,0xb5fd0963,0x7ae445db,0xe0c7002b}},	//   _druh, _rašt, llit, _رز_
  { {0x3e7f00f2,0xd7960015,0x6d465c98,0x8afa000a}},	//   _jätä_, _الزخ, huka, ְהִי
  { {0xb5fd0780,0xc1140e88,0xb06500f2,0x6b8302c1}},	//   _pašt, омиј, ymää, _ánge
  { {0xba9b01ac,0x1a9b0053,0x82330015,0x2a9b004c}},	//   טסקי, טיקע, سريا, טיקײ
  { {0x307a003b,0x3940002d,0x7ae45c99,0x7bc00061}},	//   احظة_, iris_, hlit, şmuy
  { {0xb4e4005d,0x201e0007,0x7ae45c9a,0xb345016e}},	//   नती_, rbti_, klit, ruçã
  { {0xdced016f,0x6458507d,0x57fb000a,0x442e2dc3}},	//   _krać, lfvi, טליו, laf_
  { {0xf194005f,0x644a02de,0xd012002b,0x6d465c9b}},	//   _филь, ogfi, _فلش_, guka
  { {0xb0650fb2,0xd366002b,0x7ae45c9c,0x442e5c9d}},	//   rmää, وه_, elit, naf_
  { {0x442e0026,0xb0650201,0x39405c9e,0x9057000a}},	//   iaf_, smää, eris_, _הסוף_
  { {0x6d4600b6,0x7ea6002e,0xfa190001,0x442e5c9f}},	//   buka, _hópn, ржај_, haf_
  { {0x127b0053,0x442e5ca0,0xce38000a,0x60da007c}},	// [f030] נאמע, kaf_, _האחת_, ootm
  { {0x40180008,0x37ab00d0,0xc19b000a,0xf8071a2f}},	//   שֵּׁ, лтен_, אשמי, счан
  { {0x39405ca1,0xcc56000a,0x442e0034,0xaa590432}},	//   aris_, _ובתי_, daf_, _кину_
  { {0xc5190010,0xdced12da,0xa6ab0015,0xa3be000b}},	//   аўкі_, _brać, دائق_, ीपन_
  { {0x4efc0053,0x2a76000a,0xdddd002a,0x6aad0012}},	//   אלאג, _וערך_, lesł, mhaf
  { {0x83390080,0x644a2a8e,0x6aad00b8,0xed58000a}},	//   ачит_, ggfi, lhaf, צבור_
  { {0x3ea20084,0x6d46005c,0x6ec40030,0xa3160054}},	//   ykkt_, zuka, lőbe, ожју_
  { {0x3f7704f9,0x290302c1,0x6aad00b8,0x7c2e0237}},	//   _rău_, _hija_, nhaf, zabr
  { {0xd9fb005d,0x3f770011,0x2bdb000b,0x290b13e3}},	//   ्शित_, _său_, _मुसा, _juca_
  { {0x3f510026,0x442e0026,0x60250033,0x629d007c}},	//   táu_, caf_, ўдна, ösob
  { {0x61eb0050,0x7ae400f2,0x5f050010,0x6ecb002a}},	//   _wzgl, ylit, юзна, rębn
  { {0x60c80020,0x7ce000b8,0x212a0086,0x29190020}},	//   andm, hört, _چينی_, _otsa_
  { {0xd6560008,0x7c2e021b,0x61eb0024,0x6d46008c}},	//   חירת_, tabr, _uzgl, uuka
  { {0x3f770011,0x2bdb005d,0x6ae2000b,0x6ec40030}},	//   _tău_, _मुहा, पत्र, dőbe
  { {0x3ea95ca2,0x6d465ca3,0x7c2e5ca4,0xdee60015}},	//   _flat_, suka, rabr, _وأعي
  { {0x7ce00084,0x7d0a007a,0x78be00dd,0x7ae40913}},	//   vöru, _книг_, wipv, ulit
  { {0x29030048,0x442e0176,0xdcf60015,0x7ae45ca5}},	// [f040] _bija_, yaf_, _وأخب, rlit
  { {0x3e7f022d,0x7ce000b8,0x290b1c0d,0x7bda007c}},	//   _tätä_, töru, _duca_, ütus
  { {0x6aad0012,0x76590034,0xd8770015,0x060a0350}},	//   bhaf, ffwy, تملت_, анек_
  { {0xdced010b,0x2f5a00b2,0x6aad04ec,0x77910086}},	//   _prać, ידענ, chaf, ریقا
  { {0x200702d7,0x4ecb0053,0x29030077,0x200307c4}},	//   _ogni_, בזײַ, _fija_, žjih_
  { {0xb5fd0048,0xb4e4005d,0xdced016f,0x54b7022a}},	//   _pašr, नते_, _vrać, огія_
  { {0xb6a60036,0xe73712ba,0x442e5ca6,0x0000006a}},	//   _дивл, _мер_, raf_,
  { {0x442e0176,0xd2570010,0x751a0015,0x7d1d0123}},	//   saf_, оць_, _نقرأ_, ypss
  { {0xdddd0050,0x2104005d,0x506615ce,0xb08a0033}},	//   zesł, रदेश_, отна, аёне_
  { {0x95970008,0x3f9e1ed6,0x75d30015,0x3ea95ca7}},	//   _וכמו_, tytu_, _غيلا, _slat_
  { {0x6ec400dc,0x4fd30010,0x73c6002b,0xf8db000b}},	//   zőbe, джэт, _بيام, भवतय
  { {0x20070026,0x7eb6003d,0x442c5ca8,0x6f040034}},	//   _egni_, kšpu, _hed_, _ciic
  { {0x2176000d,0x442c006f,0xcd070342,0xada40033}},	//   _фуер, _ked_, ючни, даўл
  { {0x255e0048,0xc3340008,0xa0670063,0x6ec400dc}},	//   mālā_, ּוּ_, _мача_, vőbe
  { {0x442c0a3a,0x6f040045,0x2bdb000b,0x141b000a}},	//   _med_, _fiic, _मुशा, שולב
  { {0x3ea900b6,0x7ce00b1c,0x6ec400dc,0x442c5ca9}},	//   _ulat_, förs, tőbe, _led_
  { {0x442c0176,0x7eb60024,0x255e0024,0x6aad1430}},	// [f050] _oed_, gšpu, nālā_, rhaf
  { {0xab8706b4,0x718b000a,0x442c11ef,0x6aad5caa}},	//   _думк, יְבַ, _ned_, shaf
  { {0x6aad002e,0x3cf80031,0x6ec40030,0xfd1f02b9}},	//   phaf, _بعيد_, sőbe, lpì_
  { {0x7d0d0375,0xcb88000a,0x255e003d,0xf1ca000b}},	//   _kuas, _וְשֹ, kālā_, ापान
  { {0x6e2d002d,0x442c1d40,0xa524005e,0x29030144}},	//   _meab, _bed_, дмід, _tija_
  { {0x6e2d002f,0xd5ae0029,0x7d0d5cab,0xd259003d}},	//   _leab, طفى_, _muas, diņa_
  { {0x99820024,0x39490049,0x2392002b,0x200b002a}},	//   _iekš_, luas_, فلوآ, ścik_
  { {0xe3b00018,0x6e2d20db,0x442c5cac,0xdb1201d3}},	//   خره_, _neab, _eed_, égéh
  { {0x05770074,0x7d0d002d,0x442c3f46,0x39495cad}},	//   _بازد, _nuas, _fed_, nuas_
  { {0xdce40050,0xa3b6005d,0x7fd50010,0x7529003f}},	//   _ksią, _चेक_, зімі, _iwez
  { {0x2bdb005d,0x69c30061,0x6e2d0012,0x7d0d007c}},	//   _मुला, ğney, _beab, _auas
  { {0x7d0d02e4,0x26dd002a,0x752900aa,0xfe720058}},	//   _buas, nowo_, _kwez, ردج_
  { {0xd259003d,0x41290004,0x7cf20013,0xd0090302}},	//   ciņa_, _ѓоко_, hære, _леле_
  { {0x711a0008,0xdce4005c,0x7529003f,0x317a0135}},	//   _הוספ, _osią, _mwez, _לאנד
  { {0x6e2d002f,0x7cf20bfa,0x26dd005c,0xdb83004a}},	//   _feab, værd, kowo_, нгри
  { {0x7ce001d1,0xdc3d0048,0x8f9a0008,0x6ec400dc}},	//   törs, kšķu, _ליצי, sőbb
  { {0xf2d200b2,0x26dd005c,0x39490896,0x7d0d5cae}},	// [f060] גען_, dowo_, guas_, _guas
  { {0x4d7b0053,0x60c107d2,0x7d57000a,0x7d7b000a}},	//   _פריע, nilm, _צייד_, _פריג
  { {0xc5f6005d,0xdc9b00a3,0x7529003f,0x442c14d9}},	//   ेश्य_, _הסיכ, _awez, _red_
  { {0x6299005c,0x27f7002b,0x6b8102de,0xb5fd003d}},	//   _nowo, سفند_, ælge, _pašp
  { {0x4a7b0008,0xb3a90064,0x8afb000a,0xc955004a}},	//   _הרכב, çını, _להטי, _отры
  { {0x7cf20293,0x8d5b000a,0x38a415ca,0xd259003d}},	//   bære, מכני, _mörk_, viņa_
  { {0x60c10064,0x92940010,0x442c0293,0x26dd047a}},	//   dilm, дайц, _ved_, bowo_
  { {0xb9090023,0x32530063,0xfa970135,0x4b7b004c}},	//   _nghị_, евър, ִדיש_, מאצו
  { {0x62990050,0x15430004,0xe2130021,0x442c5caf}},	//   _dowo, _петм, ربيع, _ted_
  { {0xf4840074,0xd2590024,0xe58b000a,0x255e003d}},	//   _تاری, riņa_, _לָבָ, rālā_
  { {0x0857000a,0xa857000a,0xb857000a,0x441b000a}},	//   הבים_, הייה_, השיג_, _הובס
  { {0x7d0d0509,0xdd91002b,0x60c1019a,0x2d805cb0}},	//   _puas, نوج_, ailm, _brie_
  { {0x60c15cb1,0xf27b0008,0x12eb0008,0x2d800466}},	//   bilm, _לראש, _הַגּ, _crie_
  { {0x2d800384,0x26dd002a,0x60c15cb2,0x113b004f}},	//   _drie_, zowo_, cilm, _פתול
  { {0x905b0008,0xc0530008,0x6e2d0100,0x8aa71c64}},	//   _הכות, _נזק_, _teab, прад
  { {0x7cf201ab,0xaac70015,0x5a350004,0x2d8001de}},	//   være, ستأن, ќнат, _frie_
  { {0x59390033,0x6e3c000a,0xdebc004f,0x0000006a}},	// [f070] юзаў_, _התחד, _למהל,
  { {0xd7fb0010,0x35b6000b,0x26dd002a,0x7cf20723}},	//   буе_, _आइज़, wowo_, tære
  { {0x8d180074,0xc7c80010,0xc6e7005e,0x26dd002a}},	//   _وزیر_, пыце_, підп, towo_
  { {0xff17000a,0x60c10061,0xcb36000a,0x79a70923}},	//   פקדת_, zilm, _קארי_, _ерге
  { {0xb6090048,0xf65000e5,0xca96000a,0x26dd002a}},	//   višķ, ائم_, _חדרי_, rowo_
  { {0x629900b8,0x26dd005c,0xd0060015,0x04c90015}},	//   _sowo, sowo_, _لل_, غوثي_
  { {0x62990050,0x26dd002a,0xb609003d,0xdce40535}},	//   _powo, powo_, tišķ, _usią
  { {0x82f40033,0x0000006a,0x0000006a,0x0000006a}},	//   нчыц,   ,   ,
  { {0x7529000c,0x7ce000b8,0x60c12701,0x54550004}},	//   _uwez, körp, tilm, _оват
  { {0x6299000c,0x4fa52c63,0x0000006a,0x0000006a}},	//   _wowo, диов,   ,
  { {0x60c101e2,0xa858000a,0x6e4600d7,0x7e765cb3}},	//   rilm, ליזה_, менз, _payp
  { {0x2d8000df,0xf6790053,0x5fd40033,0xed5a012e}},	//   _prie_, קאָמ, эцыф, оом_
  { {0xdc130064,0x86360053,0x63a30034,0xf2d8002b}},	//   _ağım, וארג_, lynn, _عظمت_
  { {0x51fa000a,0x3b0a01e9,0x0000006a,0x0000006a}},	//   _והנצ, жево_,   ,
  { {0x6fb20029,0x3bd50080,0xf092000a,0x1ae60004}},	//   _لموا, еютс, _בנג_, довм
  { {0x0aea02a3,0x2d8001f6,0x0000006a,0x0000006a}},	//   ідай_, _trie_,   ,
  { {0x2b55002b,0x7cd60015,0x63a30034,0xb90604d7}},	// [f080] ویید_, _يتخذ, hynn, дзак
  { {0xfc060080,0xd90d0086,0xc8660015,0x63a31288}},	//   _оппо, صیف_, بطري, kynn
  { {0xb3a90061,0x076a0058,0x373a09a0,0x0000006a}},	//   çılı, تماً_, ючаю_,
  { {0x9f96013a,0x5693005e,0x63a30e42,0xe7d5002b}},	//   ודעה_, каєт, dynn, رمنگ
  { {0xb3c3000b,0x9553002b,0x0000006a,0x0000006a}},	//   _वेबख, نخوا,   ,
  { {0x63a30026,0xf1e1000b,0xcdb7000a,0xad1b000a}},	//   fynn, _पड़न, ופנה_, קוצר
  { {0xbddb0152,0x3878002d,0x63a33040,0xd4670001}},	//   ngèr, _iarr_, gynn, фије_
  { {0xd13a0080,0x77bb000a,0xc7d7000a,0xf1a60bc0}},	//   охо_, _ומלח, _חולי_, дрон
  { {0x7c3e13f7,0x760b0008,0x38785cb4,0xd657004f}},	//   _odpr, _וּבַ, _karr_, _קימת_
  { {0x63a30026,0x859b000a,0x94aa0015,0xd59b000a}},	//   bynn, _ושמו, _بطرق_, _ובמל
  { {0xc1080023,0x63a30026,0x6d464689,0x38783422}},	//   _mỗi_, cynn, erka, _marr_
  { {0xc1080023,0x6d48005c,0xd12f002b,0x0000006a}},	//   _lỗi_, ądan, _چمن_,
  { {0xddeb0086,0xc05a0036,0x6ce70036,0x6aa30011}},	//   ترده_, _дій_, діве, _înfi
  { {0xdce40050,0xfc640063,0x61fd0227,0xbf140015}},	//   _księ, късн, ýsle, _كوتب
  { {0xad9b002c,0xc1080092,0xbddb0003,0x3d29002b}},	//   ncúz, _nỗi_, ggèr, _کتبی_
  { {0x539b000a,0x3fcb002b,0x0000006a,0x0000006a}},	//   חילו, _بدهی_,   ,
  { {0x63a3005c,0x3878002d,0x752206e6,0x429b000a}},	// [f090] zynn, _barr_, jpoz, קסמב
  { {0x63a300f2,0x6d5a0011,0x29070ca0,0xc157000a}},	//   yynn, ătat, öna_, ושמו_
  { {0xdb55004a,0x2c14000b,0x75224560,0x0000006a}},	//   _явны, तुओं_, epoz,
  { {0xe5e70015,0xf7700021,0x19953ce8,0xabfa000a}},	//   وثإي, ؤال_, _замя, _מהתר
  { {0x63a30026,0xc56b0015,0x66360015,0x38780702}},	//   wynn, تحال_, ركوس_, _farr_
  { {0x443e2a26,0xc9b60643,0x63a35cb5,0x0000006a}},	//   _cdt_, _טהרת_, tynn,
  { {0x25a903cd,0xf8b2000a,0xe3c50015,0x9f4b3045}},	//   šal_, _גשם_, عْبَ, ülük_
  { {0x63a30034,0x249b0091,0x443e1f63,0x6d464514}},	//   rynn, _žymą_, _edt_, yrka
  { {0x2a7901d7,0x4105030e,0x64c50015,0x63a35cb6}},	//   _masb_, нзив, _كيرل, synn
  { {0x44f40010,0x3f58016e,0xa81b004f,0x0000006a}},	//   _апус, féu_, קֵ֖י,
  { {0xd2510029,0x7ea6002e,0x96f9000a,0x8fa51adc}},	//   _منا_, _hópi, ּלָת, хане
  { {0x7ea6002c,0x52840015,0x0378002b,0xa3be000b}},	//   _kópi, _للمك, _زحمت_, ीपर_
  { {0x81a70029,0x0d830f5c,0x628b5cb7,0x6d465cb8}},	//   _تحال, глян, _ingo, urka
  { {0xd1b80029,0x7cf2002e,0xc19a00f3,0xb19a000a}},	//   _غانا_, færa, _משני, _מינכ
  { {0xfaf60146,0xeb9a0fe4,0xf412000a,0x75224dd4}},	//   ечаю, чив_, רפל_, zpoz
  { {0x8a06050e,0xc332039e,0x993a0033,0xc1080016}},	//   езбе, טול_, зяжу_, _rỗi_
  { {0x200b005c,0xcb09000a,0xa90a002b,0xd9430b44}},	// [f0a0] ściu_, ֶל_, سيال_, лети
  { {0xe73a0010,0x2bdb005d,0xd5c0000b,0x7c3e01d0}},	//   зеж_, _मुका, _शेषज, _udpr
  { {0xd70a004a,0x628b5cb9,0x9e7a000a,0xe6660709}},	//   чнее_, _ongo, ּנְפ, етло
  { {0x7c960086,0xdce40007,0x6ef600dc,0xb7d700c3}},	//   _آشکا, _priė, lább, رونا_
  { {0x1a9b00b2,0xf9920086,0x7ea60f14,0xe4e60010}},	//   _זיכע, _صبح_, _cópi, нікн
  { {0x6ecb005c,0x9dd7000a,0x628b5cba,0x75224c99}},	//   rębi, עוסק_, _ango, rpoz
  { {0xd62a12c9,0x75225cbb,0x290a02f2,0x439414dd}},	//   _нове_, spoz, _iiba_, тайс
  { {0x290a0014,0xd379005e,0xf700004a,0xe60a002b}},	//   _hiba_, ьчі_, ниeм_, _رزرو_
  { {0x60f8006b,0xc0c60054,0x6ef60030,0x7ae31a2a}},	//   мния_, ељни, kább, _ínte
  { {0xe5060029,0xdfda0063,0xd53b0008,0x60f70010}},	//   _أبري, зъм_, _מתמט, нныя_
  { {0xf8b30008,0x4f660015,0x6ecb0046,0xbcfb0030}},	//   רשת_, رادف, hřbe, ltég
  { {0x234b0074,0x9325002b,0x2bdb000b,0x92e90058}},	//   _رسمی_, _شرمن, _मुगा, _قرنق_
  { {0xf2370053,0xbcfb0003,0x3166006f,0x0e340033}},	//   _טראץ_, ntég, _upoz_, ыняю
  { {0x3f58016e,0x6f940015,0xe58b000a,0xfe795cbc}},	//   péu_, _للتض, הָלָ, žů_
  { {0xdd910086,0x207b0053,0xee3f0089,0x307b000a}},	//   _چوب_, _מאגא, lkým_, _מאגנ
  { {0x290a001c,0x6d5a0045,0xda780033,0xd877002b}},	//   _aiba_, ătar, няу_, کارب
  { {0x6a14002b,0x7e7d0012,0x7cf200cb,0x08550033}},	// [f0b0] ابفر, mdsp, mærn, кваю
  { {0x5b150b9c,0x18680054,0x7e7d5cbd,0x0000006a}},	//   _имот, нађи_, ldsp,
  { {0xe70b4257,0x5bc70015,0x6d5d5cbe,0x6d4f5cbf}},	//   ستان_, _ستدف, ltsa, luca
  { {0x46a4005e,0xbb840015,0x26cf5cc0,0x7e7d2b6c}},	//   лаєв, _إلَي, ungo_, ndsp
  { {0x3a2901c2,0xba9a000a,0x3a36000a,0x7aed5cc1}},	//   mbap_, _חסרי, _שרשם_, mlat
  { {0xe7330070,0x84580063,0xd4660001,0x7aed514c}},	//   _مصر_, ерът_, више_, llat
  { {0x6d5d0005,0x8c1c0008,0xbcfb0152,0x43720015}},	//   htsa, לוגי, atég, لهور
  { {0x7ea65cc2,0x6d4f0085,0x7aed5cc3,0x7e7d3ba0}},	//   _tópi, kuca, nlat, jdsp
  { {0x442700e8,0xb246002b,0x6aa30045,0x7e7d311f}},	//   pbn_, ئیهٔ_, _înfu, ddsp
  { {0x3949001c,0xc954000a,0x9f85005e,0xe1640015}},	//   iras_, אמץ_, вгод, اديي
  { {0x6ef60014,0x645e0251,0xaa7b002c,0x22980089}},	//   vább, òpie, _akým, _léky_
  { {0x394928a2,0xff050010,0xa2270015,0x7aed1086}},	//   kras_, ляўн, _أراه, jlat
  { {0xdcb70092,0xee3f0057,0x463a004c,0x2d843d73}},	//   ẳng_, ckým_, וערע, íme_
  { {0xc05b005e,0x39495cc4,0xcb6a004a,0x10a2058c}},	//   _хід_, dras_, маге_, _вишн
  { {0x6ef60014,0x6e960029,0xebe6005e,0x6d5d5cc5}},	//   rább, _للغا, товп, atsa
  { {0x39490fc9,0xe7e5000b,0x2b450030,0x7aed5cc6}},	//   fras_, _कड़ा_, álca_, glat
  { {0x39495cc7,0x6e3b001a,0x6441125b,0x0000006a}},	// [f0c0] gras_, ðube, _odli,
  { {0xfbd20015,0x61e604d2,0x7aed5cc8,0xfdf7004f}},	//   _نتج_, ükli, alat, _בצפת_
  { {0xdced016f,0x3ea0007c,0xee3f0046,0x78a3008c}},	//   _građ, _koit_, zkým_, önva
  { {0x76a90191,0x39491ad7,0x36060029,0xcf92000a}},	//   нтів_, bras_, نواف, יטב_
  { {0x7ae4022d,0x2ab60046,0x290a5cc9,0x39431100}},	//   moit, ržbě_, _tiba_, _княг
  { {0x7ae43467,0x54530036,0x3ea0008c,0x75d30021}},	//   loit, ивіт, _loit_, جيها
  { {0x38a40064,0x7ea6002e,0x987b0053,0x3ea00150}},	//   _dört_, _hópu, _קאלט, _ooit_
  { {0xf777011f,0xfbd30008,0x38a4002e,0xee3f002c}},	//   _בעלי_, יתו_, _vöru_, tkým_
  { {0xb6a30063,0x865b000a,0xbcfb0003,0x38a40123}},	//   _титл, _קדמי, ltée, _fört_
  { {0x7ae42193,0xff980004,0xddc4002a,0x1f74004a}},	//   hoit, екој_, _wciś, глоя
  { {0xf837013a,0x7ae400f2,0xbcfb0152,0xde590036}},	//   כנית_, koit, ntée, нані_
  { {0x7ae4022d,0x38a400c0,0xbcfb0003,0x6d5d5bbe}},	//   joit, _körs_, itée, ttsa
  { {0x3ea0038d,0x2bdb000b,0x7ae40983,0x30860015}},	//   _doit_, _मुजा, doit, _للإف
  { {0x394903af,0x6d5d02cd,0x6d4f5cca,0x40341068}},	//   vras_, rtsa, ruca, _секс
  { {0x9f58022d,0xc3390089,0xcb340063,0xd0f7000f}},	//   ärä_, žívá, иеръ, _שמות_
  { {0x6ab60026,0xba77002b,0x39490d0d,0x6d5d0012}},	//   ghyf, خاست, tras_, ptsa
  { {0x89340029,0xa3c9005d,0x3949121a,0x60c8007c}},	// [f0d0] لعلا, _लेन_, uras_, oidm
  { {0x6ef600dc,0xd7950063,0x67bb0015,0x39495ccb}},	//   mába, лизъ, واضح_, rras_
  { {0x6ef60014,0xd1260086,0x64570144,0xdced0085}},	//   lába, _گم_, òxim, _urađ
  { {0x60c81521,0xc6a7006b,0x38a43268,0x39495ccc}},	//   hidm, ързи, _börs_, pras_
  { {0x6ef61043,0xd1260002,0x5fa9000b,0x7cf202de}},	//   nába, _دم_, _चॅनल, kærl
  { {0x61eb002a,0x7cf20c4e,0x6ef601d3,0x0000006a}},	//   _rygl, jærl, iába,
  { {0xf7940010,0xd5bf0024,0x2ca100d9,0x60c8003f}},	//   _карэ, _šādu_, _mohd_, didm
  { {0x6ef600dc,0x92f50033,0x38a40123,0xdb0e0030}},	//   kába, ычлі, _förs_, ókép
  { {0x6ef60014,0x38a4379f,0xaa7b002c,0x00e50608}},	//   jába, _görs_, _akýk, лжин
  { {0x3ea0038d,0x94770015,0x68e510fd,0x6ef610e5}},	//   _soit_, _جدرا, nohd, dába
  { {0xb5fd00df,0x61eb005c,0x1eca06ac,0xf8b60008}},	//   _rašy, _wygl, елни_, רפתי_
  { {0x60c80091,0x1e9643e4,0x3135226f,0x9f62005a}},	//   aidm, урор, _бедр, áván_
  { {0x7ae4022d,0x3ea05ccd,0x68e500f2,0x6ef600dc}},	//   voit, _voit_, kohd, gába
  { {0x3cd50010,0x38b60134,0xd1b80015,0x705500c3}},	//   аўст, _kære_, _جاما_, _صنعا
  { {0x2ca50084,0x7ae4019a,0x2aa7007c,0x3ea05cce}},	//   ölda_, toit, _lõbu_, _toit_
  { {0x2d960080,0x6f0d5ccf,0x6ef60030,0xdb230030}},	//   _брос, _giac, bába, áráb
  { {0x7ae40df1,0x38b6079b,0x6ef610e5,0x6b810013}},	// [f0e0] roit, _lære_, cába, ålgr
  { {0x7ae4022d,0x4b260036,0x6e36007f,0x6aad01ec}},	//   soit, _ймов, _heyb, akaf
  { {0xf7190010,0xe7320015,0xbcfb0003,0xbc1b000a}},	//   вічы_, صصا_, utée, _רוטש
  { {0xbcfb0152,0xf6e50033,0x97130033,0x44380091}},	//   rtée, ацін, ёміц, _žr_
  { {0x8e5700b2,0x96330010,0xd2590024,0x64a617be}},	//   רינג_, сніц, ciņi_, лада
  { {0x6aa30011,0x0d170053,0xbcfb0003,0x7cf202de}},	//   _înfr, אקסט_, ptée, kærm
  { {0xb778000a,0x38a40123,0x38b602de,0xe778000a}},	//   _בָּת, _förr_, _værd_, _בָּך
  { {0x57e70083,0x60c80012,0xd6d20015,0x66e61372}},	//   _сдсм_, widm, _اقر_, _соба
  { {0xd010003b,0xc05a02e1,0x6f0d5cd0,0xd54a0015}},	//   يلة_, нін_, _riac, _سلاو_
  { {0xbcfb00dc,0x6ef610e5,0x6f0d0034,0xb0340054}},	//   ztéb, vába, _siac, шнош
  { {0x6f0d5cd1,0xc4d3000a,0x3f870085,0x2897000a}},	//   _piac, _פגע_, _crnu_, אדין_
  { {0x91860115,0x6ef61063,0xb5fd00bc,0x539b000a}},	//   _مجتم, tába, _obšl, _ריאו
  { {0x6f0d002c,0xa2f70008,0x69090085,0xe1f2006e}},	//   _viac, _עמדה_, _džej, _اسا_
  { {0x31570008,0xd00f0021,0xb17b015b,0x91e30054}},	//   _עיון_, _فله_, _נטור, _уоче
  { {0x6ef600dc,0xa037004f,0x6280013b,0x0000006a}},	//   sába, _גאוה_, odmo,
  { {0x6ef600dc,0x600b000a,0x8aa40219,0x6280389c}},	//   pába, _נִגְ, бруд, ndmo
  { {0x38350709,0xbcfb0003,0x63aa0034,0x99d40015}},	// [f0f0] инар, rtéb, hyfn, متكا
  { {0x673e001a,0x6aad2ecb,0x6e36007f,0x0000006a}},	//   fspj, skaf, _zeyb,
  { {0x0615004a,0xa615056d,0xd25901ec,0x0000006a}},	//   адею, амеч, siņi_,
  { {0x17f8003b,0xd5b10029,0xe5710015,0x2b4c0046}},	//   اركة_, يفا_, قطت_, ádce_
  { {0xa5640029,0xd5480029,0x9a3a000a,0xe618005e}},	//   مدون, هجوم_, _שתשק, уді_
  { {0xd4690164,0xa988000a,0xddd6002a,0x6d400030}},	//   тике_, _עָרִ, _abyś, ámai
  { {0x3e860030,0x93440015,0x63aa0034,0x645e0144}},	//   lítő_, مخيم, gyfn, òpia
  { {0xe8e00092,0x38b60293,0x85570015,0xb14521a4}},	//   _đứa_, _være_, _مخطط, анил
  { {0x3e8600dc,0x34950010,0x69cb000b,0xe0d907d5}},	//   nítő_, _каар, _सेमी, кви_
  { {0x05de005d,0xf992000f,0x1f6502a7,0xa0690054}},	//   _फुटब, קרי_, аком, њана_
  { {0xa856000a,0xb4fa004c,0xaac6000b,0x0000006a}},	//   ביתה_, _ספעי, रोडक,
  { {0x9756000a,0x8756000a,0xdee62dfa,0xde060973}},	//   סירו_, סברג_, роми, ипни
  { {0xbce60015,0x91840021,0xd0d5006b,0x0000006a}},	//   لأسو, _هجوم, _кодъ,
  { {0x7cf20b99,0x91ba000a,0xb7e5000b,0xc4d2004c}},	//   mærk, _במני, कथाम_, ַגן_
  { {0xea5a0083,0xc052000a,0xbb43013e,0x46b50065}},	//   крај_, _וזו_, жеск, ंसाह
  { {0x3eb9018b,0x3a261ece,0x7ff4009a,0xc796009a}},	//   chst_, рмаг, _اسها, یشاب
  { {0xa96a0029,0x3e8600dc,0x3b07017a,0x7d770015}},	// [f100] ضمام_, gítő_, рето_, _نمير_
  { {0xa2c5000b,0xd259003d,0x5d3b000a,0xa967123e}},	//   ़ोत्, miņu_, _שתיא, рифа_
  { {0x62870024,0x7c3c5cd2,0xd259003d,0x657b088a}},	//   ējoj, marr, liņu_, _asuh
  { {0x9f470089,0x160a0015,0x95ca19af,0x2bf7000a}},	//   _nyní_, نياً_, кула_, _כמין_
  { {0x6ef600dc,0x9784002b,0x27e6002a,0xbcfb0125}},	//   hábo, _گیاه, łon_, ltéa
  { {0x7c3c0084,0x88540008,0xa3b40010,0x7ce03842}},	//   narr, _לֹֽא_, йблі, töry
  { {0x6ef6002e,0x6efd00dc,0xa69603f1,0xf743014d}},	//   jábo, lébe, _крај, _меро
  { {0xa3c7005d,0x877b00f3,0x7c3c5cd3,0xd7570015}},	//   _उधर_, _באלי, harr, _خلفت_
  { {0xb1130080,0x6efd0030,0xc5690015,0x39405cd4}},	//   омыш, nébe, _محلل_, nsis_
  { {0xc8490008,0x39405cd5,0x20d30015,0x645a00bf}},	//   ְׂרָ, isis_, ْتَج, _ucti
  { {0x381704dc,0x72460086,0x6ec70029,0xa8570008}},	//   יקים_, _نپال, لتحق, סיטה_
  { {0x6efd0014,0xa186065e,0x0377000a,0x51860660}},	//   kébe, _выкл, _כתבת_, _вука
  { {0x6efd00dc,0xb2bb000a,0x82d7000a,0x5197002b}},	//   jébe, _במאר, _דואג_, _نخود_
  { {0x2d89020a,0xba3b0003,0xa157000a,0x64585cd6}},	//   _vrae_, _coïn, _כבדה_, ngvi
  { {0x60fb0008,0x0c840010,0x70fb000a,0x0ac7006b}},	//   _שהוק, цыям, _שהוח, ащам
  { {0xead80010,0xbf9b000a,0x4f9b000a,0xddc40045}},	//   амсі_, _ייוש, _יבוצ, _uciş
  { {0x443c016f,0x78270029,0xae03005d,0x6efd00dc}},	// [f110] kav_, لعال, रेशन_, gébe
  { {0x1a650086,0xdca40001,0x443c12d7,0x68400046}},	//   _گیری_, _мањи, jav_, vádí
  { {0x3e860014,0x443c0020,0x46150115,0x69d80012}},	//   sítő_, dav_, موار, ßver
  { {0x3e8600dc,0x98b30061,0x64580030,0x65d90033}},	//   pítő_, ğdır_, egvi, льлё_
  { {0x69d80061,0x39400416,0x0000006a,0x0000006a}},	//   şver, csis_,   ,
  { {0x7cf20134,0xa9340004,0x6d4f00da,0x22460030}},	//   værk, _ферш, irca, _adok_
  { {0x67d40036,0xd2590024,0xf486002b,0x63800030}},	//   _дору, ziņu_, صاوی, váná
  { {0x4bfc0008,0xcb140008,0x6b830077,0x7cf20013}},	//   כלוס, חלק_, _ángu, tærk
  { {0x443c5cd7,0x65150015,0x76590034,0x63800030}},	//   bav_, _طوائ, mgwy, táná
  { {0x23e70010,0x291934e7,0x998d002a,0xb3a90061}},	//   _кіев, _musa_, _żeś_, çısı
  { {0x14d60008,0xf8b2000a,0x6efd0030,0x6d4f5cd8}},	//   _פועל_, פשט_, zébe, erca
  { {0xd2590024,0x76590026,0x63800030,0x39405cd9}},	//   tiņu_, ngwy, sáná, ysis_
  { {0xe7f4005d,0x291900e8,0x76590026,0x621a0008}},	//   _अर्थ_, _nusa_, igwy, _עוסק
  { {0x6efd00dc,0x80e40015,0xd259003d,0x91f40015}},	//   vébe, _وأول, riņu_, _بأما
  { {0xe0d00086,0x7cf201de,0x29195cda,0x6d4f5cdb}},	//   _غزه_, næri, _ausa_, arca
  { {0x6b63008f,0x7c3c5cdc,0x6efd00dc,0xcb670001}},	//   якса, sarr, tébe, љате_
  { {0xbcfb002d,0xdeb7000a,0xfaa30e37,0x7c3c311c}},	// [f120] stéa, _לפקח_, чато, parr
  { {0xeb9a0124,0x6efd00dc,0xb8650015,0x39405cdd}},	//   _био_, rébe, قامو, rsis_
  { {0xbb86003b,0x6efd00dc,0x403a0053,0x39405cde}},	//   _الجي, sébe, רגעג, ssis_
  { {0xef120053,0xb6c50036,0xfa54002b,0x6562008c}},	//   פּע_, осій, _بردگ, ttoh
  { {0x6b800048,0x6bd70086,0x443c5cdf,0x14ca004a}},	//   āmgu, _نویس_, tav_, лыки_
  { {0x38b60084,0x7cf2002e,0x9d1b05bd,0x6562008c}},	//   _færa_, færi, אוסט, rtoh
  { {0x961d0048,0xdb150014,0xb7da0015,0xf626006b}},	//   _saņe, ozzá, _صورا_, _гдбо
  { {0xcb1300a3,0x443c5ce0,0x961d003d,0xda5a000a}},	//   הלה_, sav_, _paņe, אכֵל
  { {0xd9fa005d,0xb3a90064,0x5a9b004c,0x9054005e}},	//   ्धित_, çırı, רשפא, овпц
  { {0xf9930008,0x54a50015,0x6aa60012,0x7644001a}},	//   פרת_, _وحلف, _lokf, ðiyf
  { {0xd0100029,0xb89b0053,0x64480567,0x389b01ac}},	//   بلد_, אביש, _iddi, איינ
  { {0xb7db000a,0xa3d5000b,0xde590033,0x11460058}},	//   רקטי, सपर_, шамі_, _هَؤُ
  { {0xed580010,0xfe03000b,0x51f6002b,0x61f60015}},	//   боў_, रेंस_, _اسار, _اساء
  { {0x9f340036,0x3f980020,0x29195ce1,0x25d7004f}},	//   _декі, ärus_, _rusa_, מוכן_
  { {0xdddd0014,0x671d005d,0xa0a3009c,0xcf260015}},	//   reső, _बंधक_, _хајд, _ارتي
  { {0xeafb0086,0x83ab000a,0x29195ce2,0x2b4c006f}},	//   ارست_, אֱמֶ, _pusa_, ádca_
  { {0x64480f48,0x89370015,0x6ce7008b,0x19590174}},	// [f130] _oddi, إعرا, _гіне, разы_
  { {0xf807005e,0x99d40058,0x0000006a,0x0000006a}},	//   бчен, أتفا,   ,
  { {0xb06500f2,0xd6390033,0xb8d40015,0x29113681}},	//   llää, аялі_, ستكش, _viza_
  { {0xdced0007,0x2919002d,0xd6180115,0x1995006b}},	//   _praė, _tusa_, متها_, _дамя
  { {0xb065008c,0x76590034,0x64a55ce3,0xd5670680}},	//   nlää, rgwy, жала, степ
  { {0x76590176,0xfbd00086,0x91790092,0x6d3c000a}},	//   sgwy, _آتی_, hật_, נתונ
  { {0x68fa0008,0x5c5c0053,0x04560015,0x78fa004f}},	//   _כלשה, אדוק, زلية_, _כפשו
  { {0x6e3b002e,0x64485ce4,0x312503ae,0x52a91b5f}},	//   ðubl, _eddi, одиг, рвим_
  { {0x76490035,0xc1050029,0xb5fd00bc,0x26cf5afa}},	//   _idey, يوبي, _obši, migo_
  { {0xd12e002b,0x90c5005e,0x26cf5ce5,0x0000006a}},	//   کمی_, ібне, ligo_,
  { {0xb4e5000b,0x6d444b20,0x389c000a,0xf2e730db}},	//   नवी_, _svia, טיזנ, _людо
  { {0x93250086,0xdce40024,0x8d66004a,0x26cf5ce6}},	//   _هرچن, _oriģ, овме, nigo_
  { {0xbcfb0014,0xe29f0084,0xa3c5005d,0xe1ee0054}},	//   rtén, öðu_, उज़र_, _цг_
  { {0xc1050029,0x6c360021,0x7e6d007c,0x6aa60030}},	//   _بوتي, تفسا, _ebap, _sokf
  { {0x25af0034,0xbea637fb,0x0000006a,0x0000006a}},	//   hygl_, _макк,   ,
  { {0x26cf00bd,0x6d400030,0xeab7009b,0x0000006a}},	//   jigo_, ámas, ойс_,
  { {0x5c160015,0x26cf5ce7,0x6d48002a,0x9e650021}},	// [f140] _وبدأ, digo_, ądas, _راين
  { {0x44255ce8,0x38c8002b,0x0903027a,0x99820091}},	//   _nfl_, حاری_, дпун, _sekų_
  { {0xf7720029,0x929d002a,0xfaa65ce9,0xe61a0cab}},	//   باء_, jmło, _дано, аде_
  { {0x44253885,0x366a027c,0x0000006a,0x0000006a}},	//   _afl_, радо_,   ,
  { {0xb6030010,0xc5760015,0x85760021,0x3ea20079}},	//   мяшк, تطاع, تدائ, ijkt_
  { {0x7af6022d,0x734a0036,0xddcf0011,0x7ae900bd}},	//   llyt, ачив_, lecţ, čete
  { {0xb4ca005d,0x7af600dc,0x26cf3e83,0x8c1b000a}},	//   _लगी_, olyt, bigo_, בוצי
  { {0xc298061d,0x2bed000b,0x6b83016e,0xa2c5000b}},	//   ских_, _आँसू_, _ânge, ़ोल्
  { {0xd0d4006b,0x3abb004c,0x92570015,0x0446135f}},	//   зопъ, ימקנ, زشير_, _меан
  { {0xc0e700c3,0x64480034,0x7af60034,0xd0aa00af}},	//   يفين_, _uddi, hlyt, ртид_
  { {0xb4d6005d,0x2d8034ff,0xf487002b,0x7af60091}},	//   ाची_, _asie_, _باقی, klyt
  { {0x216a18ba,0xdee70015,0x91790016,0xe2970a9d}},	//   _види_, تأخي, uật_, _мах_
  { {0xf5aa000a,0xf19402ed,0x0000006a,0x0000006a}},	//   ׁבֹּ, _хиль,   ,
  { {0x7af60030,0x6ef60125,0xa0670054,0x0000006a}},	//   elyt, hábh, _даља_,
  { {0x6d400084,0xfaa75cea,0xdee70015,0xbef70015}},	//   ámar, ошан, _وأبي, _وأعت
  { {0x6d480050,0xf1bf006f,0x0000006a,0x0000006a}},	//   ądar, žšej_,   ,
  { {0xb9550063,0xce38000a,0x69090085,0x99550033}},	// [f150] яващ, _ואחת_, _ožet, якац
  { {0x26ce0144,0x7cf2001a,0xa2ca000b,0x478b004a}},	//   èfon_, færu, तोत्, исем_
  { {0x26cf03af,0xa3c9014e,0xdc880008,0x39520007}},	//   tigo_, _लें_, _וְרָ, arys_
  { {0x4b7a00b2,0x8f9b0008,0x9f610030,0x9f4b0030}},	//   _פארו, ייבי, épét_, ülék_
  { {0xceb400b2,0xd83b0010,0xaa9a000a,0x5a9a000a}},	//   ויף_, _вэб_, _הברכ, _השרא
  { {0x7d7c00b2,0xf4840001,0xcd7c0008,0x45180036}},	//   ינדו, дућн, שְׁכ, іція_
  { {0x5c380008,0x16350afb,0xe3b10015,0xd763002b}},	//   חרון_, _невя, عرت_, _تنزی
  { {0xc24515fd,0x98a0002a,0x7bdc0643,0x7159024f}},	//   чник, rpią_, יקוו, брос_
  { {0xddc4018c,0xdced0007,0x84670063,0x3f9e0069}},	//   _obiš, _apač, _мъже, extu_
  { {0xa922002e,0x25bd0064,0xa9fa000a,0x11e20033}},	//   _óþek, ızlı_, מִית, эжым
  { {0xf1a80086,0x3ea9003e,0x8eea004a,0x82150040}},	//   مایه_, _boat_, ймов_, _فواص
  { {0x23fa0008,0x3ea9003e,0xe732000a,0x39520416}},	//   _הפעמ, _coat_, עֵת_, yrys_
  { {0x721a000a,0x25d5004f,0x248507c5,0x0000006a}},	//   _הונח, לוֹן_, _kalm_,
  { {0xdc130064,0xc212000a,0xe588000a,0xff25004a}},	//   _aşım, _נהג_, קָרָ, _емко
  { {0xa09a0053,0xddcf0011,0x6616002e,0xfce3006d}},	//   _ליסט, tecţ, þykk, хоро
  { {0xaa7b0084,0x39520026,0x3ea900da,0xa9260da4}},	//   _skýr, trys_, _goat_, здал
  { {0x3e5b013a,0xddcf04f9,0xae5b000a,0xdebb000a}},	// [f160] _הדפס, recţ, _הכפר, _למקל
  { {0xb4ca005d,0xd9100086,0x6d4639bc,0xab662ae4}},	//   _लगे_, ئیس_, mska, _евол
  { {0x7c3e0048,0xec3700f3,0xfbd2002b,0x63a50012}},	//   _iepr, _מאיר_, _ستد_, ähnl
  { {0xcb9b0008,0xeafa0086,0xeab20029,0xa3e6000b}},	//   _הסטט, _درخت_, _أعد_, _युग_
  { {0x36190010,0x7c3e0049,0x26890015,0x6d465ceb}},	//   іццю_, _kepr, تخلي_, nska
  { {0xf746066c,0xe3b20015,0x24850a1c,0x6ef60125}},	//   _него, فرع_, _calm_, sábh
  { {0x2ca5234c,0x6c7b004c,0x99890160,0x69c4026c}},	//   öldi_, מאספ, mbaš_, lzie
  { {0xb7db013a,0x62660115,0xf2c30033,0x6d465084}},	//   _הקלי, سابق, есьн, kska
  { {0x69c45cec,0x6d464aea,0x21630033,0xd3140138}},	//   nzie, jska, нтэг, _сiнт
  { {0x6d460f75,0x55bb0008,0x69c41d51,0x60da0079}},	//   dska, _הממו, izie, untm
  { {0x6d465ced,0x831a0015,0x443e5cee,0x69c40012}},	//   eska, _اقصر_, _iet_, hzie
  { {0x443e2481,0x57fb000a,0x8755000a,0x539b000a}},	//   _het_, מליו, וֹשׁ_, _ליבו
  { {0xf0b70074,0x50b70086,0x62870024,0xbcfb5cef}},	//   زایش_, زدید_, ējot, stém
  { {0x69c40a76,0x212b002d,0xe571000a,0xd197000a}},	//   dzie, íche_, כַל_, _מכדי_
  { {0x443e2481,0x3f820024,0x7aed0cd4,0x30830015}},	//   _met_, ākus_, toat, _سليف
  { {0x7cf20084,0x3fdb0008,0xcff700f3,0x5fdb000a}},	//   færs, _לקוב, _מצוה_, _לחוק
  { {0xdd9104b6,0xbcfb0030,0x6d461945,0x443e0547}},	// [f170] _شود_, nték, cska, _oet_
  { {0x9dd8000a,0x443e5cf0,0x27d90033,0x5e59002b}},	//   _מוחק_, _net_, одзь_, _الکس_
  { {0x69c45cf1,0x7aed0045,0x8c28004f,0x442b0535}},	//   azie, poat, _מֵרֵ, _ęc_
  { {0xae01014e,0x6ef60030,0x443e5041,0x24855cf2}},	//   _ईरान_, tábi, _aet_, _salm_
  { {0xe945002b,0x443e5cf3,0x24852f44,0x69092b19}},	//   _ترجی, _bet_, _palm_, _džer
  { {0x69090007,0x443e5cf4,0x250a002b,0xe5780484}},	//   _ežer, _cet_, يروی_, язі_
  { {0x6d460024,0x443e2b04,0x68f80030,0x9359008b}},	//   zska, _det_, őadá, ірку_
  { {0x6d460050,0x41b50036,0xc7a80015,0x02d90015}},	//   yska, дсот, _عدّل_, توعب_
  { {0x443e5cf5,0xe162002b,0x746b0004,0x910500af}},	//   _fet_, نگوي, _грев_, мпие
  { {0x443e5cf6,0x2ef200aa,0x6f0401b3,0x99990046}},	//   _get_, _skyf_, _shic, _lesů_
  { {0xdee6019c,0x6f04002d,0xf8b20008,0x23b50018}},	//   дони, _phic, דשי_, _تماس
  { {0x6d465cf7,0x443e0c08,0x64435cf8,0x6287003d}},	//   tska, _zet_, lani, ējos
  { {0x443e003e,0x6299016b,0x6d465cf9,0x0000006a}},	//   _yet_, _inwo, uska,
  { {0x6f0403c2,0xfd5f0092,0x6443066f,0x6d465cfa}},	//   _whic, _huyệ, nani, rska
  { {0x6f0422de,0x6d465cfb,0x5ea60015,0xaec60342}},	//   _thic, sska, _يمتل, _обкл
  { {0xdb1d0014,0xfaf50036,0x69c40b8e,0x3d19000b}},	//   ázás, ечую, tzie, _यूके_
  { {0x7c3e0089,0xf2d20135,0xf8aa04c2,0xe9da15ce}},	// [f180] _tepr, דען_, овак_, цка_
  { {0x7ae9016f,0xfd5f0092,0xfd57000a,0x6289008c}},	//   četa, _luyệ, _קשיי_, hdeo
  { {0x4c9b009d,0xdc9b000a,0x443e5cfc,0x64435cfd}},	//   _ושיע, _וייל, _ret_, dani
  { {0xc8690b7b,0x1a5a0029,0x443e2390,0xfa360021}},	//   ין_, _بشدة_, _set_, _تردد
  { {0x96330010,0x62890026,0x6e3b002e,0x443e5967}},	//   тніц, ddeo, ðubi, _pet_
  { {0x84380029,0x2a60007c,0x6593005e,0x64435cfe}},	//   أكثر_, lgib_, ташу, gani
  { {0xd62a0010,0xf4870086,0x230a0015,0xd90d002b}},	//   _мове_, بانی, يتبي_, _ایل_
  { {0xa2e3000d,0x7abb0053,0xd379005e,0x2a60007c}},	//   којд, ַציו, ячі_, ngib_
  { {0xfd5f0023,0x29180d25,0x64435cff,0xfaf7004f}},	//   _duyệ, _kira_, bani, וצקי_
  { {0x299b011f,0x55030010,0x62990026,0xbcfb0f49}},	//   קסימ, _апуб, _enwo, rték
  { {0x085701e4,0xdfd00086,0x5ed515e6,0xa857000a}},	//   ובים_, ايج_, ежну, וייה_
  { {0x22930029,0x72060021,0xbef40015,0x29185d00}},	//   _للمس, _قوام, َأَت, _lira_
  { {0x56370053,0x8637000a,0x90a60015,0x2f1a003d}},	//   ואכע_, ורכב_, _يحتم, _rīgu_
  { {0x6f1c0030,0xbca50015,0xd62202a3,0x3cff000b}},	//   írcs, رمزي, фiка, _शीशे_
  { {0x5f940063,0x905b000a,0xbcfb0125,0x1bb80015}},	//   _чийт, _וכות, ntéi, وافع_
  { {0xe1880023,0x5f040e88,0x6ee70029,0x76405d01}},	//   _kỳ_, _изја, _تستل, _nemy
  { {0x2bcf000b,0x2d85003d,0x98b91ce2,0x64435d02}},	// [f190] _हेरा, āles_, плат_, yani
  { {0x97350086,0xab2b0015,0x6d5d373b,0x7e7d5d03}},	//   فکرا, _وسجل_, musa, lesp
  { {0x6443002c,0x2ca5001a,0x7640063b,0x291841d6}},	//   vani, öldu_, _bemy, _dira_
  { {0x64430f9a,0xcf930053,0xf77000e6,0x291806ee}},	//   wani, כטע_, شام_, _eira_
  { {0x6d5d5d04,0xba56000a,0xa5640040,0x64435d05}},	//   nusa, _אסרו_, ندون, tani
  { {0xc484008f,0x29185d06,0xd00600c3,0xf5920058}},	//   клік, _gira_, _مل_, الوج
  { {0xa3c9005d,0x6d5d1b4a,0x3eb9002e,0x64430c1a}},	//   _लेख_, husa, kkst_, rani
  { {0x71590229,0x29180064,0x43720015,0x6d5d5d07}},	//   прос_, _zira_, اهير, kusa
  { {0x82350086,0xfbd6000b,0x5555002b,0x39493258}},	//   ورکا, _डेनम, _سپار, nsas_
  { {0xc1050029,0x80b9005d,0x6d5d3072,0xe4350015}},	//   عودي, इसें, dusa, _أفاد
  { {0xfd5f0092,0x04c80029,0x64411f8a,0x3cf3000b}},	//   _tuyệ, _تولي_, _ieli, ंकने_
  { {0x39491d7f,0xee37042b,0x64415d08,0x629900c7}},	//   ksas_, нню_, _heli, _unwo
  { {0x4df50010,0x64415d09,0x6d5d5d0a,0x865a00a3}},	//   вярт, _keli, gusa, הדרי
  { {0x315600b2,0x71d60053,0x2d9200dd,0x2569002d}},	//   _ניצן_, _אונד_, _vrye_, iúl_
  { {0x6441013c,0xc052000f,0x7ae91dd6,0xcef6012e}},	//   _meli, _עזה_, četn, _пчињ
  { {0xfd4a0063,0x8f74005e,0xaea90015,0x2569006f}},	//   _език_, _руші, _يطيل_, kúl_
  { {0xb8560001,0x2a600020,0xbcfb0030,0x6d5d5d0b}},	// [f1a0] еђењ, rgib_, ztéi, cusa
  { {0x38b6001a,0x64415d0c,0xe8f7125d,0x3b862f72}},	//   _kæri_, _neli, елу_, _злог
  { {0xf0b600b2,0x29185d0d,0x6b66005e,0x4c3b000a}},	//   עלער_, _vira_, _якна, _מתיב
  { {0x7f3a0053,0xb759005e,0x291801c2,0x75d3002b}},	//   פענו, ьшує_, _wira_, گيها
  { {0x2508002b,0x64415d0e,0x29185d0f,0xdb0e01d3}},	//   ورتی_, _beli, _tira_, szbó
  { {0x35b30033,0xb8f60015,0x64a30aa1,0x64415d10}},	//   ыбір, _أكسب, лача, _celi
  { {0xd4670001,0x6d5d0012,0x48e3004a,0xd3770033}},	//   хије_, zusa, _сорв, ечы_
  { {0x64410020,0x1b7b0053,0x6d5d0035,0xfbd3000a}},	//   _eeli, פטפע, yusa, טתו_
  { {0x5066008f,0xbcfb3ca4,0x64415d11,0x947a00ce}},	//   нтна, stéi, _feli, _нсжу_
  { {0x6d5d0020,0x53a60010,0x99800007,0x644144b9}},	//   vusa, _пазб, lbių_, _geli
  { {0xde590036,0x0f230b9b,0x7e7d5d12,0xe70a004f}},	//   мані_, льям, tesp, ּהָֽ
  { {0x82890191,0x6441044c,0xa2260015,0x6d5d2ca6}},	//   _осіб_, _zeli, _أرضه, tusa
  { {0x7e7d5d13,0x3d1e000b,0x3f830052,0x0000006a}},	//   resp, _यूआइ_, æjur_,
  { {0x6d5d3eb4,0x38b6001a,0x5ff43115,0x7e7d47ee}},	//   rusa, _færi_, _излу, sesp
  { {0xd0f7000a,0xdb23002b,0xdb07008c,0x6d5d0801}},	//   _רמות_, اوری, yyjä, susa
  { {0x539b0008,0x6ffb000a,0x3ffb000a,0x39495d14}},	//   הילו, _מהופ, _מפוע, tsas_
  { {0x39490007,0x38c9002b,0xdbf9002a,0x2ca502dc}},	// [f1b0] usas_, وائی_, _płóc, ölds_
  { {0xd8790029,0x4c9501b7,0x98db0015,0x39495d15}},	//   ظمات_, _риос, أبرز_, rsas_
  { {0xd87400a2,0x39495d16,0x798602f2,0xd246002b}},	//   طالب, ssas_, _eskw, _پن_
  { {0xc5d50191,0x46150086,0x64415d17,0xdbf9002a}},	//   кіль, نوار, _seli, _włóc
  { {0xd126002b,0x64415d18,0xe5692925,0xf62400ce}},	//   _خم_, _peli, филд_, удіо
  { {0x04c90015,0x61f90034,0xbcfb0003,0x0608008b}},	//   بوتي_, _rywl, buée, хнік_
  { {0x64415d19,0x8235002b,0xc4f80015,0xdc8c004f}},	//   _veli, پربا, رعها_, לְהָ
  { {0xd24e002b,0x9f4b0030,0x70b9000b,0x64415d1a}},	//   قچه_, _élén_, इस्ल, _weli
  { {0xc6920053,0xa1560001,0xb2280015,0x46f4004a}},	//   _דאן_, вању_, رأيك_, _счёт
  { {0xe0d60256,0x40950df0,0xdb0e0046,0x45d45d1b}},	//   квы_, трит, vybí, _соус
  { {0x60090080,0x6d4d00f2,0x66280123,0xd496000a}},	//   ьном_, _avaa, _åskå, _שכעת_
  { {0x38b6002e,0xcce9000a,0xba3b0003,0x1287002b}},	//   _væri_, _וכ_, _moïs, _سمتی_
  { {0xfe0c014e,0x0d9904ab,0x40950015,0x0d8302c5}},	//   सेंस_, нтры_, _للإر, алян
  { {0xc1560008,0xa156000a,0xa204005e,0x7c5a002b}},	//   _ישנו_, _יבנה_, _спід, بلسر_
  { {0x316d038d,0x99800007,0xfaf6005e,0x6b66006b}},	//   ltez_, ybių_, вчаю, ъква
  { {0xb9c6002b,0x7db6237f,0x628b17f6,0x7f76004f}},	//   پتره, _асоц, _jago, _יעצב_
  { {0xcb090008,0xceb3000a,0x316d5d1c,0x68e21157}},	// [f1c0] ַל_, _כיה_, ntez_, éodo
  { {0x4b260001,0xed590107,0xe73a0ea6,0xbcfb0003}},	//   _имов, áže_, деж_, tuée
  { {0x2a7500dc,0x9a8a0015,0xbcfb0030,0x4cbb004f}},	//   íííí, _قَدْ_, ttév, _חזיו
  { {0x628b5d1d,0xd6cf0015,0xe7370fdc,0x0000006a}},	//   _nago, يقل_, тец_,
  { {0x91820016,0x99800091,0x64a6252c,0x0000006a}},	//   iệt_, rbių_, када,
  { {0x44f30010,0x8555009a,0x545300af,0x0000006a}},	//   апіс, ایلر_, авшт,
  { {0x628b00b6,0xbcfb0152,0xf6260010,0xf7430e3f}},	//   _bago, quée, _адбо, _весо
  { {0xbcfb0014,0xd2500015,0xe7eb000b,0x628b01f6}},	//   ltét, حنة_, _जुटा_, _cago
  { {0xf1a3008f,0xc05a017f,0xa6e2001a,0x50f40aed}},	//   арэн, мін_, íðul, лзит
  { {0xbcfb2c61,0x25c40061,0x937a0015,0xf8bf0003}},	//   ntét, ırlı_, _يصار_, _tuée_
  { {0xa0a30033,0x96b6000b,0xc7b2000a,0x0f980058}},	//   ршыл, _अकाउ, ׁב֙_, رَحة_
  { {0xe3160015,0xe80a000b,0xe807000b,0x93b7004f}},	//   _شباب, _वरना_, वेटा_, _שלאו_
  { {0x11540063,0x316d0590,0x63b85d1e,0xe1370033}},	//   _склю, ctez_, lyvn, _азіі_
  { {0x628b0582,0x62805d1f,0x0000006a,0x0000006a}},	//   _zago, lemo,   ,
  { {0xf3f8000a,0xf5480016,0x6ef60030,0xce95006b}},	//   גִּל, hụ_, rábr, _байъ
  { {0x6017000a,0xdd910015,0x62805d20,0x6f4b000a}},	//   _בחוף_, _هوب_, nemo, _חֲזַ
  { {0x5a440010,0xbcfb0077,0x62805d21,0x0000006a}},	// [f1d0] рэса, ruéb, iemo,
  { {0x63b800cb,0xbcfb0030,0x62805d22,0x0000006a}},	//   kyvn, gtét, hemo,
  { {0x6280003c,0x2868006b,0x6ee80061,0x96350033}},	//   kemo, ърто_, lıba, гнец
  { {0x96290015,0x62805d23,0x0000006a,0x0000006a}},	//   ركتك_, jemo,   ,
  { {0x80c5000b,0xd6180021,0x62803241,0x628b5d24}},	//   िसमे, نتها_, demo, _rago
  { {0x628b00b6,0xe73300e6,0xbcfb0030,0x97250015}},	//   _sago, _نصر_, mtés, _مفسو
  { {0xbcfb0014,0x91820023,0x43720115,0x628b5d25}},	//   ltés, yệt_, مهور, _pago
  { {0x316d0152,0x82a40054,0x2376006e,0x62805d26}},	//   ttez_, ишње, اميد_, gemo
  { {0xbcfb03c0,0xdb1500dc,0x316d0152,0x628b5d27}},	//   ntés, gyzé, utez_, _vago
  { {0x316d5d28,0xa0c50015,0x6fa90054,0x1fa90004}},	//   rtez_, ايدو, евог_, екои_
  { {0x628b5d29,0x6280047e,0x23b50087,0x316d0590}},	//   _tago, bemo, _حماس, stez_
  { {0xfe720029,0x316d0152,0x6280047e,0xed5a5689}},	//   حدد_, ptez_, cemo, ном_
  { {0xbcfb00dc,0xddd50138,0x0000006a,0x0000006a}},	//   jtés, аўрэ,   ,
  { {0xa0690063,0x4094009b,0x0000006a,0x0000006a}},	//   _чака_, _врът,   ,
  { {0x4a9a008f,0x5ea60029,0xd0e6002b,0xe0d0002b}},	//   нтаў_, _ممثل, _حکيم_, _بزن_
  { {0xc3320008,0x38b6158b,0x20070061,0x9e6608d7}},	//   מול_, _lært_, _izni_, _свид
  { {0xbcfb00dc,0xfe37000a,0x1a060221,0xa9260058}},	// [f1e0] ttét, _גרפי_, упам, اعره
  { {0x291c00c0,0x3ea0002e,0x07a6012f,0x38b604d1}},	//   öva_, _hnit_, лазн, _nært_
  { {0x3ea000da,0x27fc01d0,0x0000006a,0x0000006a}},	//   _knit_, ævn_,   ,
  { {0xbbb2014e,0xaafa005e,0xf7430b1e,0x056a0004}},	//   ीनीक, _їхнє_, сецо, ејки_
  { {0x4ecd0053,0x7ae45d2a,0x62805d2b,0x4d56000a}},	//   וזאַ, mnit, vemo, רֹ֣ן_
  { {0x5334008f,0x260a005d,0x34940010,0x7ae43081}},	//   аект, ़ेगी_, ракр, lnit
  { {0xbcfb1faa,0x27f7099c,0x62805d2c,0x13a6002b}},	//   bréf, čené_, temo, انعی_
  { {0x7ae409e7,0x7d1e5d2d,0xa2b4006b,0x38b6001a}},	//   nnit, _lips, рбич, _væru_
  { {0x38b6002e,0xe4da0015,0x628008aa,0xba57000a}},	//   _fært_, _كورت_, remo, אספו_
  { {0x3d00005d,0x7ae41228,0xe5060015,0xbcfb0030}},	//   ोगों_, hnit, _إبري, mrég
  { {0x20180201,0x6562008c,0xbcfb358a,0x7ae4496d}},	//   äri_, luoh, ztés, knit
  { {0x7ae901a3,0x9e15005e,0x9ec7006e,0x7ae4006f}},	//   četk, идні, ازده, jnit
  { {0x7ae45c4f,0x91b70015,0x0000006a,0x0000006a}},	//   dnit, _مطور_,   ,
  { {0xd3660029,0x644a3ed6,0x5f940459,0x403420e6}},	//   يه_, nafi, _викт, _текс
  { {0x2bbb0029,0x60da0049,0xdb580418,0x3378000a}},	//   راسة_, mitm, лют_, כְּב
  { {0xfebb0074,0xdb2400dc,0xbcfb0030,0x9b240004}},	//   _ساعت_, árás, gtér, сфрл
  { {0x200b0050,0xc27b0053,0xdcb10092,0xd9550086}},	// [f1f0] ęcie_, ערמי, ử_, شناخ
  { {0xbcfb5d2e,0xeaa8000a,0x99d40015,0x6562007c}},	//   rtés, וֹ_, حتفا, duoh
  { {0x64570e57,0xf8070418,0xbcfb3c87,0x6d4f5d2f}},	//   óxim, учан, stés, lsca
  { {0x8b3a0008,0xaa950036,0xbb3a000f,0xbcfb56d3}},	//   _שתרצ, _тимч, _שערי, ctér
  { {0x5eec000a,0x6f0d1f22,0xd4690180,0xe5e5002b}},	//   עַבְ, _mhac, виле_, جزای
  { {0xd7fb20cc,0x22490085,0x26c456a9,0x6d4f5d30}},	//   _зуб_, _žak_, _elmo_, isca
  { {0x38b60293,0xa8a8000a,0x6d5d0012,0x0789000a}},	//   _vært_, _עֹשִ, hrsa, _בְּֽ
  { {0xa535004a,0x6f0d0034,0xe2990740,0x98b20535}},	//   _внач, _nhac, таи_, ędąc_
  { {0x52a60080,0x6d4f005c,0x321900f2,0x91e55d31}},	//   рвым_, jsca, äsy_, ропе
  { {0x764b0035,0x4255002b,0x4f950033,0x3ea000aa}},	//   lagy, _چنار, арму, _snit_
  { {0x6f0d002d,0x2901016e,0x7d1e014b,0x6d5d4689}},	//   _bhac, ilha_, _rips, ersa
  { {0x61d9004a,0xbcfb0003,0x6f0d5d32,0x764b0030}},	//   _имея_, xtér, _chac, nagy
  { {0x563a0053,0x463a004c,0x8d63006b,0x0d760033}},	//   כערײ, כערע, овяе, шыня
  { {0x3fc70086,0x8c430286,0x764b5b8f,0x5cf60342}},	//   _مدعی_, жере, hagy, ряму
  { {0xd0110029,0xbcfb3a3b,0x7ae4049f,0x6d4f5d33}},	//   _بلغ_, ttér, tnit, asca
  { {0x6f0d002d,0xcb670054,0x644a0030,0x6aad001a}},	//   _ghac, јате_, zafi, gjaf
  { {0x2d8c0024,0x3cfa0029,0x20c9002d,0x7ae45d34}},	// [f200] ādes_, _لعدد_, _cúig_, rnit
  { {0x6cd30015,0xe8c70033,0xbcfb5d35,0x7ae40778}},	//   _وقيا, агул_, stér, snit
  { {0x5c5b0008,0xd7ca0086,0x6c5b000a,0x2cac001a}},	//   _בדיק, خواه_, _בדיח, öddu_
  { {0x6d44005c,0x2497002b,0x2901016e,0x05d2000b}},	//   _kwia, ینند_, alha_, _देउब
  { {0x6609005c,0xa2a4000b,0x56570033,0x245802a3}},	//   _czek, कास्, раіў_, галь_
  { {0xc4480086,0xd8430264,0x7bce002a,0xbcfb01e6}},	//   ایان_, ručí_, ozbu, créd
  { {0x66090014,0x14180015,0xca96000a,0x644a5d36}},	//   _ezek, ديثة_, ֹדִי_, rafi
  { {0x6562008c,0x644a5d37,0xbcfb0003,0xf55a0015}},	//   puoh, safi, prég, _للرب_
  { {0x60f8010f,0xe2970054,0x3cf8014b,0x646701d3}},	//   лния_, рањ_, korv_, úriá
  { {0xcfaa0015,0x98a9002a,0x6f0d5d38,0x3179009a}},	//   ناجم_, rpać_, _shac, اجيک_
  { {0x4386002b,0x3f980107,0x73360015,0x6d4f00da}},	//   _خلاق, íru_, _ضرائ, wsca
  { {0xa3e3000b,0x64485d39,0x6d4f3fd6,0xdb1502ad}},	//   नपर_, _hedi, tsca, uzzü
  { {0xdcf70015,0x644834e7,0xa2d30015,0x6d5d5d3a}},	//   لأسب, _kedi, _بينت, ursa
  { {0x91bb0008,0x644806db,0x317b004c,0xb17b000a}},	//   _במדי, _jedi, _סאוד, _סטור
  { {0xaa59059c,0xbae50029,0xd00f002b,0xcb35006b}},	//   ливу_, مكسي, _قله_, себъ
  { {0xbd880074,0xaf330029,0x7ed40029,0x1b190256}},	//   _چنين_, _بروت, _وزيا, ужбы_
  { {0x6d44005c,0x7af4005e,0x7c280091,0x08550033}},	// [f210] _gwia, ізує, ždra, йваю
  { {0xd70f005d,0x6609005c,0x4ddc000a,0x64485d3b}},	//   िष्ठ_, _rzek, _שחזו, _nedi
  { {0xab950029,0x6d44002a,0xbcfb0003,0x660913c3}},	//   _الجغ, _zwia, grée, _szek
  { {0x955500a2,0x2b5e0089,0x2bf6000a,0x85550015}},	//   مختا, átce_, _למתן_, مختط
  { {0xd4d9008f,0x8e980008,0x64483c95,0x058710cb}},	//   лькі_, ידאו_, _bedi, руем
  { {0xdfc65d3c,0x2a69007c,0x044204bc,0x64482430}},	//   _في_, lgab_, пешн, _cedi
  { {0xbcfb038d,0x368b007e,0xe3c40015,0x93bc0045}},	//   crée, _исан_, يْهَ, _sfăr
  { {0xf772000a,0x644802f2,0x2a691839,0x6bec004f}},	//   _מקל_, _eedi, ngab_, כַחַ
  { {0xeaaa00b2,0x9956007f,0x0000006a,0x0000006a}},	//   רױפֿ, _müşt_,   ,
  { {0x23770086,0x7c250034,0x26dd002a,0x64481030}},	//   _ناصح, _nghr, liwo_, _gedi
  { {0xc8780064,0x25db000b,0x5334005e,0x9888000a}},	//   _öğe_, _खेती_, _дехт, בָרֵ
  { {0xf6790053,0xd4910092,0x877a000a,0x4376004c}},	//   נאָמ, _hà_, נארי, _לײען_
  { {0xa2a4005d,0xf2d20008,0x64485d3d,0xada6006f}},	//   कार्, _צעד_, _yedi, _opúš
  { {0xa5da00b2,0x7db50036,0x41040010,0xa2d3000b}},	//   אַלי, ісяц, _дзів, बोर्
  { {0xd4910023,0x75211ee4,0xfaa61cd9,0xa3ca0065}},	//   _mà_, _milz, баво, रैप_
  { {0xd4910023,0xbcfb0003,0x7bce5d3e,0xdaba0015}},	//   _là_, vrée, rzbu, دهرت_
  { {0xe8ea0054,0x3b0717b6,0x6d445234,0x67200160}},	// [f220] гмад_, сето_, _uwia, _rimj
  { {0x6c860029,0xbcfb0152,0x38c80086,0xb609003d}},	//   _الدم, trée, جاری_, ikšķ
  { {0xf7720015,0xa5da002b,0x64480a3a,0x78b53109}},	//   ثاء_, گبار_, _redi, _dozv
  { {0x64480375,0x6efd1f0d,0xbcfb0003,0x6008000a}},	//   _sedi, lébr, rrée, בִנְ
  { {0xa5da002b,0x673b0085,0x64485d3f,0xa5f80054}},	//   دبار_, _čuje, _pedi, јелу_
  { {0x6fca014e,0x7d7b000a,0x47d3002b,0x6efd0003}},	//   ानमं, רנסו, _کيفر, nébr
  { {0x644812d7,0xdc9b000a,0xad1b000a,0x9d1b004c}},	//   _vedi, טיסל, נוצר, נוצט
  { {0x91c4000b,0xdd2d0091,0x64482004,0x926a3db7}},	//   िनलै, vėžy, _wedi, урка_
  { {0xb6bb0008,0x104a0214,0x3952028a,0x64485d40}},	//   _עצמי, ляни_, nsys_, _tedi
  { {0xf20d000b,0x232a006b,0x7413002b,0x9f54030c}},	//   ाइज़_, _божи_, _کوما, овоч
  { {0x2d8000df,0x78fb000a,0xd3e4002b,0x988b000a}},	//   _apie_, רפיו, _بقای, אָכֵ
  { {0x81430074,0xeeab0142,0x51860210,0x9d550015}},	//   _کنون, уток_, _гука, ينجت
  { {0x200b0050,0xef92002b,0x0000006a,0x0000006a}},	//   ęcia_, زیکد,   ,
  { {0x6efd5481,0x39525d41,0x1fa612d9,0x601809a0}},	//   gébr, dsys_, _григ, _коля_
  { {0x2ac70001,0x78b50057,0x200a007c,0xded50015}},	//   бљав, _rozv, übid_, _ويتخ
  { {0xada6002c,0x7e6d0509,0x8337004c,0x7f3b004c}},	//   _spúš, _ucap, מאלס_, _געהו
  { {0x78270029,0x1e58000a,0x78b55d42,0x2a69038c}},	// [f230] معال, _השחר_, _pozv, rgab_
  { {0x99d40015,0x9c470fea,0x764900aa,0x89d40058}},	//   ستقا, _ухил, _seey, ستقط
  { {0x56950080,0xddcd005c,0xcc76000a,0xa3ca0065}},	//   жает, _udał, _ועתה_, रैम_
  { {0x8f9b0008,0xef12000a,0x30a602ed,0x0000006a}},	//   טיבי, ֵּא_, ́рив,
  { {0x98c50064,0x942508fc,0x75210eb3,0x39520034}},	//   ştır_, омле, _pilz, csys_
  { {0x2d990020,0xe3b00086,0x8467006b,0x03a53de5}},	//   ivse_, کره_, съде, жико
  { {0xd49100a7,0x442500b8,0xb385005e,0xe3b10015}},	//   _và_, _vgl_, ілил, ظرت_
  { {0x92b50015,0x6b83016e,0x7bdc004c,0xd2990033}},	//   تحتا, _ângu, טקוו, рткі_
  { {0x05950074,0x3f9c0020,0x95cb012e,0xca38004f}},	//   _بازگ, _arvu_, _сува_, זנחה_
  { {0xe0d90661,0x1477006e,0x4431007f,0x0000006a}},	//   рво_, _دارج, _üz_,
  { {0xa856000a,0x4f950004,0x02d6002b,0xd0093a02}},	//   חיתה_, црпу, صویب_, рене_
  { {0x57fa0008,0x6e290089,0x02440015,0x63050015}},	//   ילתו, žebn, _فَمَ, _بوصل
  { {0x1d0a07be,0xa0c50058,0x20d50058,0x0000006a}},	//   иеми_, _ويصو, _وتتج,
  { {0xa06602bb,0x0000006a,0x0000006a,0x0000006a}},	//   _даша_,   ,   ,
  { {0x2bf60010,0x6efd0003,0x799d0034,0xdfce00c3}},	//   іягр, rébr, _arsw, _ليو_
  { {0x39460010,0x1ee80086,0x1be7005e,0x8f9a004f}},	//   жнаг, _دوبی_, ідти_, _כיצי
  { {0xcee90086,0xfee90015,0x39520091,0xc84a1e2e}},	// [f240] _درون_, _دعوى_, usys_, ипаж_
  { {0xe9d70010,0xfd120015,0x200a002a,0x3ead003d}},	//   цку_, _تجب_, żbie_, ķete_
  { {0xd7ff0011,0x562a0129,0x6f1d005a,0x25720416}},	//   _ţări_, ажем_, ůrce, wâl_
  { {0x98af0024,0xbcfb0152,0x6d670125,0xab630033}},	//   īgā_, préc, _úraí, _ўвял
  { {0xddcd005c,0x94aa0979,0xd5b2009a,0xe693009a}},	//   _gdań, итка_, بفش_, بلند
  { {0xe71a0086,0x0000006a,0x0000006a,0x0000006a}},	//   _چيست_,   ,   ,
  { {0xd4670124,0xe71a0074,0xb8ce000b,0xba9a000a}},	//   ције_, _نيست_, का_, ֹסִי
  { {0xfbe80023,0x8c1b0008,0x82f70058,0x2d8b0535}},	//   _đề_, סוקי, يريز_, ywce_
  { {0xcb13011f,0x045a0086,0xbcfb002d,0xb97a000a}},	//   ולה_, _نجات_, hréa, ׁנֵי
  { {0x3f9c016f,0x397b00a3,0x297b000a,0xc4c60015}},	//   _prvu_, סטינ, סטיא, _بترو
  { {0xe1ef002b,0x1fa600ce,0x656202ad,0x0000006a}},	//   فسی_, ірог, lroh,
  { {0x57fb000a,0x9e340033,0x673e0980,0x0000006a}},	//   שלטו, меюч, ippj,
  { {0x171b00b2,0xf653013a,0x65620012,0xc27b004f}},	//   יוטע, וצר_, nroh, _כראי
  { {0x6fb60029,0x20d30015,0x50d30015,0x61ed0091}},	//   _ومشا, _يتوج, _يزور, _žalg
  { {0x80a30074,0xbcfb12bf,0xab94005e,0xd0100021}},	//   _زمين, gréa, мирі, _ثلث_
  { {0x690b08e0,0x2014002a,0x69350033,0x65625d43}},	//   güen, ącić_, знау, kroh
  { {0x645a12d7,0x7e7b007c,0xa93d0138,0x0000006a}},	// [f250] _odti, õupu, удзi,
  { {0x65623927,0x97c70015,0x39140033,0xf8075287}},	//   droh, يتام, дмур, очен
  { {0x629c0024,0xda66002b,0x602d0030,0xd7880015}},	//   ēroj, _کاپي, _hőmé, ينكو_
  { {0x0f7b0008,0xabfa0008,0x645a00d9,0xda670015}},	//   שראל, _להתר, _adti, _بادي
  { {0xb6070033,0x65625d44,0x80ca000b,0x64a51a2f}},	//   цяжк, groh, िसाइ, зала
  { {0xab980074,0x6fca014e,0x19ba000a,0xe578005e}},	//   _اخیر_, ानां, _המשב, юзі_
  { {0x07680010,0xc6e70036,0xf8b200a3,0xe7300015}},	//   _маёй_, _діап, _אשם_, _لصق_
  { {0xd2a9005f,0x2d840064,0x52a90001,0x0b17004f}},	//   ские_, çmek_, свим_, חַ֖ר_
  { {0xa3db000b,0xddc60535,0x0000006a,0x0000006a}},	//   _ढेर_, zakł,   ,
  { {0xa069023e,0x98bd000b,0xf8bd0065,0x0000006a}},	//   љана_, ोसिए, ोसिय,
  { {0x64435d45,0xcfe9012c,0x8fa53a85,0x0000006a}},	//   mbni, صفحه_, чане,
  { {0xe2980191,0x6aaa0065,0x41d90065,0x60ca02ad}},	//   _має_, _चचेर, _बेअस, _elfm
  { {0xe0ce0191,0xacea0015,0xd2d40015,0x02d40058}},	//   _зв_, مرسل_, _تغلب, _تتلخ
  { {0x913a0008,0x40870cb9,0x213f0049,0xc19a000a}},	//   _העסק, _фудб, mpuh_, _לשני
  { {0xfaa60033,0xeb9a0248,0x0000006a,0x0000006a}},	//   паво, щив_,   ,
  { {0xaf760053,0xbcfb0003,0x8b2328e1,0x4fd6000a}},	//   _זעקס_, rréa, едсе, _מוצב_
  { {0xc9660d9b,0x25db000b,0x05db000b,0x798d02f2}},	// [f260] явай, _खेली_, _मेलब, gwaw
  { {0xedf60086,0xe1ff002a,0x76425d46,0x09030054}},	//   _ويژگ, żów_, wboy, епун
  { {0x1cbb000a,0x66e6096d,0x798d02f2,0x8cbb000a}},	//   _המיע, пожа, awaw, _הציק
  { {0xd6d90036,0x690b11dd,0xc869000a,0x6f36004c}},	//   оті_, qüen, טן_, לװעב_
  { {0x86230080,0xba9b0008,0x6a9b000a,0xa50a0719}},	//   ньше, _הסכי, _השכנ, беда_
  { {0x656204ff,0x7afb00bc,0x89eb05bd,0x39405d47}},	//   rroh, čute, _הַלֵ, mpis_
  { {0xe646005e,0x68fe02de,0x7791002b,0x65620353}},	//   _невп, mopd, _لیلا, sroh
  { {0x994c002c,0xd3790036,0x3f98002e,0xf777000a}},	//   _môže_, ючі_, ærum_, _מעלי_
  { {0x35ca0054,0x64430123,0x0000006a,0x0000006a}},	//   _угао_, bbni,   ,
  { {0x653b000a,0x2f1b003d,0xe53b004f,0xdb1c0535}},	//   _לעמד, _lūgt_, _לתמר, ozró
  { {0xc43b000a,0x389b004c,0xc173002b,0x3014030c}},	//   _התבי, זיינ, ودیت, ьдор
  { {0xd2500015,0x6b9c0085,0xbcfb00bf,0x0000006a}},	//   _شنت_, dvrg, grén,
  { {0x68fe0298,0xa0a61e92,0x02b700a3,0x02fb000a}},	//   kopd, _надд, _מלאך_, _פלדמ
  { {0x2ceb0892,0xb113005e,0x721b000a,0x013705bd}},	//   сьмо_, _зміш, _הודח, _צרות_
  { {0x307b0008,0x807b0008,0x26c6008c,0xb07b000a}},	//   _האונ, _הנוצ, kkoo_, _הנוז
  { {0x59de021e,0xa0070015,0xbcfb3bdd,0x9b440015}},	//   _नेहर, _عقيل_, ntéz, عنقو
  { {0x98b90004,0x64434ba9,0x0000006a,0x0000006a}},	// [f270] олат_, ybni,   ,
  { {0x7e7d141c,0x798d5d48,0x0000006a,0x0000006a}},	//   lfsp, rwaw,   ,
  { {0xbc7a000a,0x28380015,0x5b151377,0x39405d49}},	//   _ונתת, سألة_, _омот, apis_
  { {0xa6340191,0x2bd6005d,0xc6a40054,0x98140058}},	//   енці, _डेटा, ерљи, ربلا
  { {0x8c190074,0xa4d50036,0xc5190010,0xdbcc002e}},	//   _ديگر_, моді, оўкі_, lóða
  { {0x64430012,0xd6180015,0x83390891,0x7aed5d4a}},	//   ubni, ستنا_, очит_, lnat
  { {0x20c9002e,0x64435d4b,0x5c38000a,0x37c50067}},	//   _búin_, rbni, הרון_, _غيرف
  { {0x56941cf2,0x23260457,0x7aed208f,0x7e7d0079}},	//   _паст, мощи_, nnat, jfsp
  { {0xf48715ed,0x61ed016f,0x7aed5d4c,0xd254002b}},	//   _нужн, _žalb, inat, ریوش_
  { {0x629d002c,0xdbcc002e,0x3ea90144,0x7aed5d4d}},	//   ôsob, kóða, _anat_, hnat
  { {0xdbcc002e,0x3cf1000b,0x2836000a,0x3e8a02c8}},	//   jóða, ँचने_, ונתך_, ойно_
  { {0x3940002e,0x33fa000a,0x93fa000a,0xc3fa000a}},	//   ypis_, _והענ, _ולעי, _ולעש
  { {0x82d60008,0xf656000a,0xd656000a,0x291a0123}},	//   _קונג_, וסרי_, וירת_, ympa_
  { {0x7e7d019f,0x7aed0aec,0x722100a1,0x0000006a}},	//   afsp, enat, _tửbạ,
  { {0x656b003f,0xfc03005e,0xeb971f89,0x5bc8000b}},	//   hugh, впро, мир_, रनेव
  { {0x3940016f,0xda660015,0x7aed5d4e,0x21270016}},	//   tpis_, باسي, gnat, _hinh_
  { {0x21270023,0x672e5d4f,0xa9265d50,0x09e31068}},	// [f280] _kinh_, _subj, ддал, вотн
  { {0x39400007,0xa3bf021e,0xd910002b,0x2007001a}},	//   rpis_, ुना_, ایس_, _kyni_
  { {0x21270023,0xdc8b0008,0x93c40092,0x6d40002e}},	//   _minh_, _וְכָ, _chẳ, ímaf
  { {0x21270092,0xb6c50127,0x75d60015,0xcb9b000a}},	//   _linh_, нсій, ويضا, _וסטט
  { {0x20c90125,0x7ae4019a,0xa84a0058,0x0000006a}},	//   _rúin_, miit, _ولحم_,
  { {0x21270092,0x7ae45d51,0xb4e80157,0x64a30189}},	//   _ninh_, liit, मचे_, кача
  { {0x656b00da,0x136a005e,0x64a30054,0x7e7d00aa}},	//   augh, ішки_, таја, yfsp
  { {0x236000bd,0xb7db000a,0x6b830123,0x8c1b000a}},	//   čij_, _וקלי, _änge, חוצי
  { {0x21270092,0x78bc0604,0x69c40251,0x308a01b7}},	//   _binh_, _korv, nyie, ощно_
  { {0x7aed052c,0xd36f0086,0x3cf8005d,0x7ae40586}},	//   znat, _چهل_, ंकों_, hiit
  { {0x20c9002d,0xa3ca005d,0x442c016f,0xd0100029}},	//   _iúil_, रैश_, _igd_, طلح_
  { {0xa3e4000b,0xa1c6249a,0x7e7d0012,0xf1d9000b}},	//   _पेय_, _обед, ufsp, _बेकन
  { {0x7ae40020,0x3e04006b,0x78bc00aa,0x7aed1608}},	//   diit, вярв, _oorv, vnat
  { {0xa0c40015,0x7c84029f,0x78bc5d52,0xfbd30058}},	//   _سيعو, кусе, _norv, نتز_
  { {0x7bd50012,0xc05900e2,0xe0fb004f,0xbfb30058}},	//   uzzu, _хіі_, _ולגל, _لحيت
  { {0x7528002a,0x7aed3b1e,0x0000006a,0x0000006a}},	//   _lidz, unat,   ,
  { {0x2bff005d,0x9b240004,0xdcee003d,0x6f1d0012}},	// [f290] _शुरू_, тфрл, žkār, mmsc
  { {0x79a40063,0x67d50036,0xa177000a,0xbb95005e}},	//   ърсе, нозу, ועמד_, _заощ
  { {0x3cf80029,0xb907000b,0x7b130061,0x2f120030}},	//   _تعيد_, _बग_, rçub, lága_
  { {0x2d4d016f,0x99670063,0x810b000b,0x8c1a000a}},	//   ože_, _отгл, _सीईओ_, _מותי
  { {0xaa3a0008,0x2d4d0107,0x78bc2b0e,0x95c500c3}},	//   _מתרח, nže_, _forv, عيته
  { {0x6d4d003f,0xa8a4049d,0x2329005e,0x93c40016}},	//   _mwaa, _ирск, поки_, _thẳ
  { {0x20c9002d,0x69cb02de,0xf506004a,0xa3ca000b}},	//   _dúil_, øgef, эншл_, रैल_
  { {0x21270023,0x65950010,0x212f0026,0x2d4d0107}},	//   _sinh_, _пабу, _pugh_, kže_
  { {0x15f3000b,0x2007001a,0xa3e40157,0x7528008c}},	//   _आखिर_, _syni_, _पेठ_, _fidz
  { {0x6f0401d1,0xe5700015,0xb0d9000b,0x03c7006b}},	//   _skic, _خطف_, योंग, _осем
  { {0xf8b20008,0x21270092,0xbcfb0003,0x00e20033}},	//   אשי_, _vinh_, grém, ужэн
  { {0x61ea03c0,0xe3360053,0x442c0085,0x12780015}},	//   ámlá, _טרעפ_, _zgd_, _يحنث_
  { {0x67290050,0x21270023,0x29010020,0x91a80015}},	//   _miej, _tinh_, koha_, _يهمك_
  { {0x91ba000a,0xd168000a,0x6d4d0079,0x6f1d0546}},	//   _ממני, _חֻקֹ, _dwaa, amsc
  { {0xdee6007a,0x60d6000a,0x6b660033,0x69c40034}},	//   _поки, _רוצא_, эква, wyie
  { {0x629b00df,0x2d960036,0x501a0053,0x6f04003f}},	//   nduo, _зрос, _צוקו, _ukic
  { {0x6609003f,0xdca6011b,0x316d0003,0xf2d2004c}},	// [f2a0] _nyek, _запи, nuez_, אען_
  { {0xfd120015,0x4906002b,0x7ae405ff,0x8dfb004f}},	//   _حجب_, رواق, siit, _מהפת
  { {0xb80a0029,0x6d4d0111,0x38670030,0x75285d53}},	//   أيام_, _zwaa, ónra_, _ridz
  { {0x20c9002d,0xbb3b000a,0xfe9b000a,0x68e5008c}},	//   _súil_, _מעטי, ּ֙אמ, aihd
  { {0x672900b8,0xe4a6005e,0xe5a302b0,0x65940cfa}},	//   _diej, ерйо, лици, талу
  { {0xd6da002b,0xd627005e,0xf993004f,0x0000006a}},	//   _کورش_, хоче_, _גרש_,
  { {0x92940010,0x3cf1000b,0x7528003d,0x232621a4}},	//   вайц, ँचते_, _vidz, нфиг
  { {0x75280050,0xd2500029,0x877b000a,0x2d4d006f}},	//   _widz, جنة_, _מאלי, yže_
  { {0x8143002b,0x4536005e,0x5214006b,0x316d4dc8}},	//   هپيم, _їхат, ъдит, guez_
  { {0xf9770053,0x44380012,0xbcfb5d54,0x7054009a}},	//   עגיש_, _ür_, trém, خندا
  { {0x6d4d00dd,0xddcd0045,0x6299002a,0x9479008b}},	//   _swaa, _ocaţ, _fawo, _юсту_
  { {0x6465003d,0x316d0003,0x247301d3,0x62993e1c}},	//   ēriņ, buez_, rőmű_, _gawo
  { {0x66f50091,0x6910008c,0x6f1d2ac3,0xb2bb004f}},	//   nąka, väen, rmsc, _ממאר
  { {0x6299005c,0x6fb40015,0x10a30054,0x2d4d0f81}},	//   _zawo, _لمتا, _биљн, rže_
  { {0x2f1200dc,0x1037000a,0xdfcf006b,0x2ef5006b}},	//   sága_, _אטום_, _съ_, _изкр
  { {0x929d005c,0x6d4d016b,0xedd50015,0x0000006a}},	//   połe, _twaa, _ليبد,
  { {0xe9f80036,0x4efc000a,0xfe700015,0xbdf50054}},	// [f2b0] енті_, _מההו, _ادى_, _шпиј
  { {0x629b0007,0xed59006f,0x67291ed6,0xe4e5000b}},	//   zduo, ážu_, _siej, _औषधि_
  { {0xec36013a,0x47d50029,0xa2660007,0xc0530053}},	//   _באתר_, خيار, dėžę_, רזע_
  { {0xb8c8005d,0xcdd5000a,0x9bb6000a,0xf770006e}},	//   _खो_, ֣ךְ_, _סהרה_, صام_
  { {0x9f5c022d,0xa3d3005d,0x672902c1,0x3eb90111}},	//   _hyvä_, सैन_, _viej, ijst_
  { {0x6729005c,0xf7eb0015,0x7a400046,0xf505006b}},	//   _wiej, _فرأى_, rátů, ъзло
  { {0xf8f40010,0xdc3c0053,0x6609002a,0x2376002b}},	//   _спрэ, לעגר, _wyek, نمود_
  { {0xf99f01f6,0xc242009b,0x0000006a,0x0000006a}},	//   _uzès_, анък,   ,
  { {0x36d40080,0x629b0007,0xe535004a,0x6910007c}},	//   _сотр, rduo, _резь, käel
  { {0x2127002b,0x316d0003,0x7e760535,0x0000006a}},	//   ژيکی_, ruez_, _scyp,
  { {0x9956005e,0xd3a70033,0x644b0085,0x6e4600af}},	//   дiли_, _ярап, čnič, кенз
  { {0xfe720115,0xdee60a6c,0xed5a1e64,0x80a1000b}},	//   جدد_, томи, мом_, _कोरे
  { {0x316d038d,0x629c0024,0xf1d9005d,0x865a000a}},	//   quez_, ērot, _बेचन, ודרי
  { {0x8fe50015,0x71d6000a,0xe572000a,0x2fd50015}},	//   _لأعم, _בונד_, סַר_, _لتبح
  { {0x6d40002e,0x7afb00bc,0xac76009a,0x0000006a}},	//   ímab, čutn, _یادش,
  { {0xc33204dc,0xda6600c3,0x8f7400ce,0x0000006a}},	//   שון_, ضاري, _суші,
  { {0x3b070254,0xba290015,0x092a0033,0xcb150033}},	// [f2c0] тето_, فسكم_, джай_, уфры
  { {0x6b9b005c,0xdd57000a,0x6d89000a,0x07a608f7}},	//   ługa, _שביט_, _נָפְ, казн
  { {0xc00f0016,0xd8770058,0xaa4a00af,0x186700af}},	//   _đuối_, ضمنت_, _опна_, ђаци_
  { {0x2bf70008,0xdd110089,0x6d460975,0xdb0e002a}},	//   _ימין_, mýšl, opka, rybó
  { {0xfe37000a,0x29180034,0x65930058,0x0000006a}},	//   דרני_, _thra_, لجور,
  { {0xf8bf0016,0x69cb01d0,0x0000006a,0x0000006a}},	//   _quét_, øgee,   ,
  { {0xe7370036,0x9cd7000a,0x889b004f,0x0000006a}},	//   _аес_, כוסה_, _קבלי,
  { {0x2bba000b,0xc174006b,0xf1a60e4d,0x0000006a}},	//   _उपना, глищ, врон,
  { {0x41530033,0x11ea0015,0xbcfb01c0,0xe5261208}},	//   авыс, بعثي_, bréh, _адап
  { {0xc9530008,0x30a615ed,0xbcfb0030,0x94aa0058}},	//   סמת_, трив, mség, _تطرق_
  { {0x08570008,0xa3bf005d,0x64580a6f,0x69100020}},	//   כבים_, ुनः_, mavi, väel
  { {0x645800df,0xe2460070,0x70540086,0xdce60024}},	//   lavi, _شخصي, خنگا, vukā
  { {0xbcfb0014,0x2002005c,0x40960029,0xc693000a}},	//   nség, łki_, _للشر, באר_
  { {0x31570053,0xbcfb016e,0x753d0030,0x64585d55}},	//   _יידן_, oréi, _észe, navi
  { {0xf0930008,0x6d46013c,0xfc46006f,0x01150033}},	//   _כנס_, apka, _číta_, _сьцю
  { {0xbcfb00dc,0x64585d56,0x5fb7000a,0xdce6003d}},	//   kség, havi, _יהוא_, rukā
  { {0xa3e4000b,0xf9900015,0x443e41c9,0x64585d57}},	// [f2d0] _पेस_, يبك_, _oft_, kavi
  { {0xf1b30053,0x645805e3,0xe855006e,0x7827002b}},	//   ױסע_, javi, اناد, نعال
  { {0x05db000b,0x35db000b,0x97340015,0x69cb02de}},	//   _मेजब, _मेज़, لعنص, øgeb
  { {0x46150086,0x929d005c,0x0bb6000a,0x443e2ee6}},	//   هوار, koła, _עִיר_, _aft_
  { {0xbcfb00dc,0x6d5d3143,0x3cf8002b,0x09e40138}},	//   gség, nssa, _سعید_, _воўн
  { {0xb97a013a,0x64580007,0x6d5d5d58,0xf773002b}},	//   _אנשי, gavi, issa, _پاس_
  { {0x1cbc0053,0xa3bb0015,0xfe7f0144,0x7415012c}},	//   ומגע, باشر_, viïn_, دوغا
  { {0xf8bf0003,0x6458008c,0xbcfb0030,0x0574002b}},	//   _tués_, aavi, bség, _چالد
  { {0xe6050015,0xbcfb0003,0x645818b1,0xa1560054}},	//   _إِذَ, préh, bavi, гању_
  { {0x2ecc005d,0x40950608,0x6d5d1a9f,0xe4350058}},	//   ास्त, урит, dssa, _إفاد
  { {0xd251003b,0xceea1c35,0x6d5d5d59,0x753d0030}},	//   _هنا_, едне_, essa, _észb
  { {0xc33201c8,0x6235000d,0x656b0011,0x7ed6002b}},	//   _הוא_, _седу, orgh, ازدا
  { {0xaed30010,0x7afb00bd,0xa06915f1,0x6d490045}},	//   соўш, čutl, _зала_, ţean
  { {0x515a0008,0xa3ca005d,0x76590026,0xeb9a0888}},	//   _טכנו, रैक_, hawy, ниг_
  { {0x6b630036,0xbcfb00dc,0xbea618ea,0x7659002a}},	//   йкра, zség, _байк, kawy
  { {0xd00e003b,0x645818c7,0x7e9a0029,0xa3d4005d}},	//   _علي_, zavi, _أنظر_, हनत_
  { {0x200b005c,0x44200016,0x76590034,0x9f5e0030}},	// [f2e0] ęciu_, ̀i_, dawy, örög_
  { {0xe849002b,0xa90a0021,0xb86500c3,0x3c460015}},	//   نجمن_, ريال_, لامو, _حَدِ
  { {0x2f190014,0x64580007,0x3f510024,0x6c7b000a}},	//   sége_, vavi, nšu_, _אריד
  { {0xbcfb5d5a,0x3f511253,0xcf92004f,0x370500ce}},	//   tség, išu_, מטב_, ачів
  { {0x9c8701c9,0xbddb0003,0x64585d5b,0xe4e601f3}},	//   _určí, ccèd, tavi, лікн
  { {0xbcfb1364,0x3f510024,0xef190024,0xb8f60015}},	//   rség, kšu_, itļa_, _إكسب
  { {0xbcfb0014,0xa3e4005d,0x929d005c,0xe4750033}},	//   sség, _पेश_, woła, ручэ
  { {0xfbd30008,0x7e64003f,0x64585d5c,0x9377006b}},	//   מתו_, _ndip, savi, убът_
  { {0x3f510024,0x00ea0004,0x6b95002a,0x64585d5d}},	//   ešu_, еќни_, zwzg, pavi
  { {0xf9930008,0xe97b0053,0xb97b0008,0xb6030227}},	//   צרת_, עניש, עניי, ýšen
  { {0x33f60080,0x3f510024,0xbcfb0152,0xe4d70015}},	//   _счас, gšu_, nsée, _حولت_
  { {0x93fb000a,0xbcfb0003,0x81a60021,0x7bdc0144}},	//   _אלבי, isée, _محتل, dzru
  { {0x3f515d5e,0x7e640034,0x6d5d5d5f,0xc693004f}},	//   ašu_, _ddip, ussa, זאר_
  { {0x6d40002e,0x79960026,0x219b000a,0x6722008c}},	//   ímaa, dwyw, _נבוא, hmoj
  { {0xcb1b000d,0x1fa30033,0xda35004a,0x2d8c0045}},	//   еќа_, _грыг, иевы, ădea_
  { {0x6b9b005c,0x5bb8004a,0xe7fa000b,0x3d1a0065}},	//   ługo, ылся_, ्थना_, _मीठे_
  { {0x0855034e,0xb9250015,0x1eea002b,0xa8550763}},	// [f2f0] иваю, لفري, _جويی_, икач
  { {0xd7fb0010,0xa3d4005d,0xe6c00085,0x18680054}},	//   нуе_, हना_, _čišć, лађи_
  { {0xec150086,0x478b0033,0x97a70033,0x7d072495}},	//   _خودد, эсам_, ырал, mojs
  { {0xbcfb0152,0xe70b0087,0xb0650072,0x0000006a}},	//   sséd, رتان_, onää,
  { {0x4a5a0008,0x286b00d7,0x3211002a,0x7659002a}},	//   _בדרו, _прво_, ęzyk_, rawy
  { {0xe3b10015,0x6722040f,0x64a55d60,0x98ab0045}},	//   قرب_, amoj, рака, _ducă_
  { {0xe299076c,0x32d5194a,0x39495d61,0xcc78004f}},	//   вай_, ицис, lpas_, אגות_
  { {0x39495d62,0x25ed000b,0xd2a9004a,0x72c5007e}},	//   opas_, _आइपी_, ткие_, рбиз
  { {0x39490177,0x63a80012,0x50b54db5,0x78b201d3}},	//   npas_, _erdn, асну, _újvá
  { {0x6ad2005d,0x00820268,0x6910007c,0x39495d63}},	//   _सत्र, ольо, väek, ipas_
  { {0x200201e2,0xc2c50086,0x6d445d64,0xef1a006b}},	//   şkin_, _پيشي, _stia, кмо_
  { {0x3f510024,0xe607002b,0x8b66002b,0x26cf5d65}},	//   ršu_, قش_, یازم, nkgo_
  { {0x20d50191,0xe0ce0063,0xacea0015,0x60e00091}},	//   _війс, _дв_, نرسل_, _žymū
  { {0xc5f2013a,0x61da000a,0x8fa50033,0xa0695447}},	//   קדם_, _בקנד, _ваке, _рака_
  { {0xca560001,0x6b830123,0xfbc33334,0x5b360138}},	//   итањ, _ängl, обро, рэгу
  { {0x38c80086,0x5ffa0447,0x5ae50015,0x4a460c1d}},	//   گاری_, _בהצה, مثقف, рнав
  { {0x39490035,0x590a0004,0x7d070085,0x60c30061}},	// [f300] gpas_, веам_, bojs, _konm
  { {0x38c80074,0xebe6000d,0xdd8f0086,0x929d002a}},	//   داری_, _вооп, _کوی_, koło
  { {0xf7720029,0x8b96000d,0x39494eb2,0xe737006b}},	//   تاء_, _трпч, apas_, аех_
  { {0xe5c60f22,0x4aca005d,0x473313ae,0x46ea006b}},	//   исло, _रविव, ініс, ъден_
  { {0xbcfb0152,0x67220a6f,0xa5da00e5,0xf5b30015}},	//   ssée, rmoj, خبار_, قصود
  { {0x53340063,0x67220024,0x186a004a,0x3ead003d}},	//   бект, smoj, _шаги_, ķeti_
  { {0xdb1c00f2,0xbcfb0003,0x316d5d66,0x0000006a}},	//   pyrä, prév, erez_,
  { {0x47d30015,0x2d02000b,0x179b000a,0x7af65d67}},	//   _بيفر, लकुल_, _בילב, nnyt
  { {0x64410026,0xbcfb0003,0x91b7009b,0x316d01f6}},	//   _ffli, nséc, игът_, grez_
  { {0xf4840074,0x753d00dc,0xf4870086,0x63a800bd}},	//   _داری, _észa, _نامی, _trdn
  { {0xf8370008,0x224d00dc,0x6d4007cf,0x2837000a}},	//   ינית_, bbek_, íman, יניך_
  { {0x91b70086,0x3ea00125,0xbcfb0003,0x7afb00bc}},	//   _چطور_, _cait_, hrét, čutk
  { {0xbd6b0063,0x60dd0024,0xe1f2002b,0xb1d30015}},	//   ърне_, ūsma, _بسا_, _ويمث
  { {0x7d02002f,0x9fe6002b,0x9e14005e,0x7bc1008c}},	//   _íosl, _پسته, ідрі, äluo
  { {0xd0f5014e,0x3ea0038d,0xd103000b,0xa3ca000b}},	//   ीकरण_, _fait_, रकरण_, रैच_
  { {0xdee40001,0x5a35017a,0x3ea000da,0x0000006a}},	//   _моји, снат, _gait_,
  { {0x7afa002e,0x4efc000a,0x7b130061,0xbcfb0fab}},	// [f310] étta, _שהחו, lçuk, frét
  { {0x58bb0029,0x5ce40015,0x39495d68,0x97a72d99}},	//   خارج_, _وكيل, rpas_, ирел
  { {0x26c4018c,0xfc460227,0xb6350015,0x28080015}},	//   _bomo_, číte_, مفاع, لْكَ_
  { {0x26c45d69,0x394902d2,0xa3aa000b,0x2d8f0003}},	//   _como_, ppas_, गटन_, _âges_
  { {0x644100b8,0xfb1a000a,0x0445006b,0xf773002b}},	//   _pfli, _תורמ, белн, _ژار_
  { {0x316d0152,0xbcfb1f0d,0x98a3002a,0xf4870361}},	//   vrez_, crét, _biją_, рудн
  { {0x9cd8000a,0xbcfb0030,0x7aed007c,0x6f0d036d}},	//   שווה_, lrés, oiat, _okac
  { {0x316d038d,0x2bf80008,0x1bf801d8,0x236901a3}},	//   trez_, ימון_, יצור_, čaj_
  { {0x690b001c,0x20020061,0x316d0003,0x224d0e8c}},	//   qües, şkil_, urez_, rbek_
  { {0x147704c9,0x83870080,0x316d0152,0x3ea05d6a}},	//   _خارج, _выде, rrez_, _sait_
  { {0x85040029,0x7aed5d6b,0x25ed000b,0x7af6008c}},	//   _بولن, kiat, _आइडी_, ynyt
  { {0xe81f000b,0xc2c40115,0x66fc00bf,0x316d2f19}},	//   _भरना_, _ويلي, očka, prez_
  { {0x7aed19cf,0x2bba000b,0x929a000a,0x216944e7}},	//   diat, _उपहा, _תינת, _сили_
  { {0xf1b20008,0x3ea0003e,0x2d82016f,0x60da0596}},	//   _מסד_, _wait_, rtke_, chtm
  { {0x69cb0134,0xfce306b3,0x2d825d6c,0x7af60123}},	//   øgen, чоро, stke_, tnyt
  { {0x3ea0002f,0x7f3a00b2,0x1ee80086,0x6ee50031}},	//   _uait_, _געקו, _خوبی_, _وسيل
  { {0x5d86003b,0xc9aa0010,0x18360015,0x3d8b002b}},	// [f320] _الخل, ывае_, مراح, _یحیی_
  { {0x26c4003f,0xc212000a,0xbcfb0003,0x78260058}},	//   _somo_, להן_, rséc, معضل
  { {0xbcfb000e,0x6d560034,0x7aed5d6d,0xad250058}},	//   rrét, _hwya, biat, _بريو
  { {0x66760029,0xf6e50036,0xd719005e,0xbcfb001a}},	//   إدار, оцін, аючі_, srét
  { {0xdb230089,0x6aa40034,0xbcfb0052,0x0000006a}},	//   _írán, mdif, prét,
  { {0x6d560176,0xc953039e,0xb0a60065,0x0666009a}},	//   _mwya, _ממש_, _कोंग, _گاسپ
  { {0x25a60234,0xcc3b004c,0x79845d6e,0x6aa45d6f}},	//   svol_, נעקט, ltiw, odif
  { {0x26c404ed,0x673800dc,0xca32000a,0x6aa45d70}},	//   _uomo_, ívju, ּם֙_, ndif
  { {0xc05a022a,0x79840034,0x7bce54ef,0x6d405d71}},	//   лін_, ntiw, hybu, ímal
  { {0x7aed253e,0x935a1923,0x7afb00bc,0x3d02000b}},	//   ziat, _брду_, čuti, लकों_
  { {0x645a0024,0xb8a4005e,0x73360015,0x7f58012e}},	//   _ieti, слiд, _طرائ, јамс_
  { {0x539b0008,0x798400dd,0xd3370008,0xb5fd00bc}},	//   _תיאו, ktiw, _הראה_, _odšl
  { {0xd24f003b,0x6aa40026,0x20c9002d,0x645a0375}},	//   _أنه_, ddif, _cúis_, _keti
  { {0x7aed005c,0xd197000a,0x261b000b,0x317b0447}},	//   wiat, _לכדי_, _बरसी_, _תרגמ
  { {0x645a01e2,0xd00f0029,0x2f1200dc,0x1bd40142}},	//   _meti, _كله_, zági_, поря
  { {0x69cb0134,0x6d560026,0x5b15017f,0x61ed2823}},	//   øgeo, _fwya, імат, _žali
  { {0x1ef80029,0xf8b1002b,0x7aed4828,0x0000006a}},	// [f330] _دعوة_, وکس_, riat,
  { {0xa3ab000b,0x645a5d72,0x7aed5d73,0xd8740058}},	//   खिम_, _neti, siat, كامب
  { {0x661b0050,0xbcfb0030,0xf748002b,0x798402f2}},	//   _szuk, srés, مللي_, atiw
  { {0xbcfb360b,0x1e3c0053,0xa615011d,0x0000006a}},	//   prés, ָגגא, омеч,
  { {0x645a0b99,0x356b017a,0x2bd1000b,0x7afd0079}},	//   _beti, урен_, सनका, _ijst
  { {0x9475002b,0xdfc60015,0x24890085,0x375b0015}},	//   تگرا, _قي_, đamo_, _مؤرخ_
  { {0x2f1200dc,0x36d5023e,0xd91a000a,0x58d8006b}},	//   sági_, _довр, _כושל, _удря_
  { {0xa3de0089,0x645a0020,0x42c91377,0xb1450b98}},	//   běží_, _eeti, ргин_, онил
  { {0xd4b9005e,0xd148002b,0xe0d91664,0x645a5d74}},	//   _клац_, یشین_, иви_, _feti
  { {0x645a5d75,0xa06900d7,0xe588000a,0x00d9002b}},	//   _geti, јана_, _לָעָ, شبخت_
  { {0x69100005,0xdbf20089,0x20c9001a,0xdb050030}},	//   päev, _příp, _búir_, _arhí
  { {0x82340086,0x753b003f,0x41b50015,0x2d9e002a}},	//   _فرها, _kuuz, _ومار, łtem_
  { {0x645a0064,0x69cb0134,0xa2d6000b,0xef18003d}},	//   _yeti, øgel, बसर्, ēļ_
  { {0x853a004f,0x41b2009a,0x225f0073,0x7afd0081}},	//   יגשי, _آمور, lauk_, _ajst
  { {0xf3f10092,0xea5a049d,0xeb9a135d,0x644301b3}},	//   _mẹo_, ирај_, шив_, icni
  { {0x7bce005c,0x0f56000a,0xbddb0003,0x9a1a0033}},	//   rybu, _ויקם_, rbèr, аюзу_
  { {0xc9a706b3,0x4c360033,0x8eda002b,0x7bce00cb}},	// [f340] овте_, _мэнт, _مذکر_, sybu
  { {0x186a4efe,0x79844fb4,0x6910007c,0xf7860058}},	//   ражи_, rtiw, jäet, ْلاَ
  { {0xbb860015,0xdcfa002b,0x79845d76,0xb6c60015}},	//   _بلجي, _مرگش_, stiw, يْئً
  { {0x4b7b0053,0x268a0029,0x645a013c,0x07b70015}},	//   _דאטו, شخصي_, _seti, تهمة_
  { {0x6596003b,0x753d00dc,0xba480007,0x645a5d77}},	//   تجار, _észl, grįž, _peti
  { {0x4991002b,0x53345342,0x65625d78,0x99fb004f}},	//   _سیمر, пект, rsoh, _כפכפ
  { {0xf4870086,0x84e70015,0xd3700015,0x394001c2}},	//   تانی, تفوق_, رهة_, lqis_
  { {0xd141005c,0xc3270029,0xe81f000b,0xd4090015}},	//   knąć_, يكون_, _भरता_, حتهم_
  { {0x11d80029,0x645a5d79,0x27ea0091,0x2d9e002a}},	//   صودة_, _teti, žinė_, łtej_
  { {0x79b70008,0x6b9b002a,0x13b60021,0x673c5d7a}},	//   קליד_, ługi, _وصاح, _kurj
  { {0x320a005c,0x883b000a,0xdde3002a,0x66fc00bc}},	//   łby_, יתיו, łuży, nčko
  { {0x539b0008,0x7ee70036,0xd141002a,0xc444002b}},	//   _כיבו, іцне, fnąć_, _بیژن_
  { {0xc3330008,0xc0d60015,0x90e60015,0xd141002a}},	//   _חוף_, _ويصب, _وستن, gnąć_
  { {0xd12f008f,0x559b004c,0xe571004c,0x69cb02de}},	//   _іх_, ױסלײ, ײַך_, øgem
  { {0x2ac70001,0xac19017c,0x7ac7004a,0x673c007c}},	//   ољав, сову_, осае, _nurj
  { {0x98850089,0xa3ab005d,0x7ee40029,0x3fdb000a}},	//   _vůči_, खित_, _يكون, _כקוב
  { {0x0975017f,0xe84b0015,0x4975021a,0x9f04006e}},	// [f350] ягаю, لجان_, ялас, _تويو
  { {0xf84b0010,0x3946002d,0x0137000a,0x37ab0579}},	//   рчай_, íosa_, קרבת_, итен_
  { {0x872b0010,0x4c9a000a,0xdc9a000a,0x6910007c}},	//   аўда_, _הבתו, _הסתכ, väet
  { {0x41ca005d,0x6d4f0079,0x7e7d0ebd,0x0000006a}},	//   िहास, opca, ngsp,
  { {0x2aba000a,0x7aba000a,0x2bc90065,0xd8770058}},	//   _המרא, _הצרו, रहवा, _واسب
  { {0x04c80029,0x20110061,0xd5ae0015,0x03a50979}},	//   يوني_, üzik_, افو_, зико
  { {0xccf4000a,0xfc58000a,0xc6970058,0x0000006a}},	//   וכס_, חבוש_, _وشرع,
  { {0xd299008f,0xc7b2013a,0x4bfc0008,0x1bfc000a}},	//   сткі_, _אבל_, ילוס, ילוב
  { {0xcb140008,0xf4870484,0x225f0091,0xb98b004f}},	//   ולק_, _мужн, rauk_, ׁרֵ֖
  { {0x7e7d02f7,0xca1a004f,0xe4d70058,0x20d400ce}},	//   egsp, מֵיכ, _بترب, діюс
  { {0x9f580084,0xd0090063,0xa4fa0053,0xd3d80015}},	//   ærð_, сене_, _פלעט, _وبما_
  { {0x141a0008,0xc7d60008,0xf7d6000a,0xa3e4000b}},	//   _הועב, פורי_, פורש_, _पेट_
  { {0xd13b023e,0xf1a70785,0x2d840003,0x2018001a}},	//   _тхе_, _френ, îme_, ýrir_
  { {0x3cf6005d,0xe4470029,0xe5720008,0x6cd60029}},	//   ँचें_, عض_, עַר_, أقسا
  { {0xd141002a,0x60d6000a,0x00ba004f,0x0000006a}},	//   snąć_, _מוסא_, _למסמ,
  { {0x39465d7b,0x0000006a,0x0000006a,0x0000006a}},	//   знаг,   ,   ,
  { {0x386100b8,0xcf250115,0x673c5d7c,0x2a601624}},	// [f360] fahr_, _تروي, _surj, raib_
  { {0xe9d75d7d,0xee3f01c0,0x673c019a,0xdb860aed}},	//   чку_, ndýn_, _purj, _егои
  { {0x98aa0011,0x4c3b0008,0xdc3b000a,0x3b0a067a}},	//   _aibă_, _לתיב, _לעיר, _гено_
  { {0xeaf9005d,0xc56a0015,0xc6a3006d,0x6910008c}},	//   ्कृत_, محتل_, ерши, täes
  { {0xa3e4005d,0x6d400052,0x0000006a,0x0000006a}},	//   _पेज_, ímah,   ,
  { {0x439401b0,0x6fcb000b,0x1394009b,0x7d0e2a3f}},	//   дакс, ाहां, дикю, nobs
  { {0xd4670054,0x44260015,0xd36f0033,0x9d29004f}},	//   чије_, أرشف, эч_, קֵנִ
  { {0x46a30b75,0x57fb000a,0xe3af0040,0x0000006a}},	//   _пасв, _הללו, ارو_,
  { {0x54360018,0xe1660015,0x3f670085,0x7d0e5d7e}},	//   _فرار, أدبي, eđu_, kobs
  { {0x46130029,0xc953000a,0x3cf6000b,0x2ed5000b}},	//   _أوكر, עמת_, ँचों_, दस्त
  { {0xb4d8005d,0x3f630080,0xf1f70086,0x9f580064}},	//   ासी_, нтяб, قعیت_, _özür_
  { {0x333b013a,0xe8b9005d,0x69cb02de,0x7b130144}},	//   _התאמ, _उच्च, øgek, nçut
  { {0x62820079,0x316602d8,0x7e7d5d7f,0x0000006a}},	//   _icoo, _uvoz_, rgsp,
  { {0xdcef0011,0xef19003d,0x94b4004f,0x6d4f0546}},	//   ducă, itļi_, וִֽד_, rpca
  { {0x40eb000a,0x80a3012c,0xfbd300c3,0xdb0f0030}},	//   _לַהֲ, _سمين, رتس_, ődít
  { {0x6ffb013a,0x68ee0251,0x0f7b000a,0x3ffb000a}},	//   _להופ, _ambd, _האהב, _לפוע
  { {0xaf340087,0x38c9002b,0x44290016,0x7e6d0072}},	// [f370] _ثروت, يائی_, ̀a_, _idap
  { {0x6d4d5d80,0x6f0f5d81,0x7d0e5d82,0x66d3007f}},	//   _itaa, locc, cobs, _içki
  { {0xf7990067,0xbcfb01f6,0x0000006a,0x0000006a}},	//   تناب_, nsém,   ,
  { {0x6d4904f9,0x3986016e,0x2b4c0046,0xa2630016}},	//   ţeau, bôs_, ídce_, _chồ
  { {0x3e8800dc,0xa2c0000b,0xe60e0432,0x64a50418}},	//   lító_, वान्, тд_, дала
  { {0x06080010,0x2481007c,0x6b9b002a,0xa3b90015}},	//   чнік_, ühm_, ługu, قابر_
  { {0xf8b2013a,0xf7940033,0x03940033,0x69100012}},	//   _בשם_, _парэ, ерыя, päer
  { {0x7bdc000a,0x660d007c,0x11d5005e,0x6d4d0079}},	//   מקוו, üaks, діор, _otaa
  { {0xc692015b,0x30755d83,0x6b8302dc,0x69cb01d0}},	//   _באן_, мунс, _ångf, øgeh
  { {0xe0d10029,0x30c40015,0x40950783,0xbddb0003}},	//   ئزة_, ّزَّ, фрит, rcèl
  { {0x5f06017f,0x0000006a,0x0000006a,0x0000006a}},	//   дзна,   ,   ,
  { {0x0378002b,0x3e880030,0x0000006a,0x0000006a}},	//   _رحمت_, dító_,   ,
  { {0xc332000a,0xa0695d84,0x8628004f,0x0000006a}},	//   _סוד_, _дала_, ּֽרֶ,
  { {0xee37008f,0xddc40011,0xc1050015,0x913a000a}},	//   ьня_, _adiţ, _توتي, _ועסק
  { {0x6f0f02b9,0x7d0e3be2,0x1fb500e2,0x7092116f}},	//   bocc, robs, _іскр, _рајф
  { {0x629b0026,0x60080008,0x7b3c016f,0x6f0f5d85}},	//   neuo, _מִפְ, _očuv, cocc
  { {0xd7f80011,0x6aa60061,0x290704b2,0x0000006a}},	// [f380] _ţă_, _vakf, čnan_,
  { {0xddc40011,0xeb9a0001,0x629b0034,0x5c160015}},	//   _ediţ, _дио_, heuo, _يبدأ
  { {0x7b3c0085,0x1cbb000a,0x4cbb004f,0x28c40065}},	//   _ačuv, _ומיע, _ומיג, लॉगि
  { {0x3986016e,0xe61a5d86,0x0000006a,0x0000006a}},	//   pôs_, оде_,   ,
  { {0xa2b1005d,0x2ef90030,0x6a9b000a,0xe5a30b98}},	//   _अफ़्, érfi_, _ושכנ, кици
  { {0xa5330036,0x8b650086,0x62825d87,0xb4d8000b}},	//   вніч, _تایم, _scoo, ासे_
  { {0x77910086,0xb17d002c,0x47d6002b,0x06560015}},	//   _میلا, vzťa, _غيرر, _ينسح
  { {0x416a0001,0x816a005e,0xd2500015,0x959a00ce}},	//   ојом_, ороб_, دنة_, _мтзу_
  { {0x05ba0029,0xdd14002c,0xc4860001,0xcb13000f}},	//   _بدأت_, dĺžn, _олак, כלה_
  { {0xa1270029,0x69cb02de,0x0000006a,0x0000006a}},	//   وكيل_, øgei,   ,
  { {0xf457000a,0x389b000a,0x30a301b0,0xb2860033}},	//   _חיבר_, חיינ, трыв, _жылк
  { {0x3e880030,0xfe7f0144,0xa3db0065,0x0000006a}},	//   vító_, viïs_, डनर_,
  { {0x11ea002b,0xd657000a,0xbcfb0003,0x3fc8002b}},	//   _بعضي_, ויכת_, ssém, زدگی_
  { {0x45d9004c,0x3e880030,0x6f0f02b9,0x40930015}},	//   פֿרא, tító_, socc, _للهر
  { {0x1fa30010,0x807b000a,0x6d341635,0x307b000a}},	//   _арыг, _ונוצ, терф, _ואונ
  { {0x3e880030,0xba7700c3,0x5fcb000b,0x62805d88}},	//   rító_, باست, ाहरल, ngmo
  { {0x3e880014,0xeabf0092,0xaf080015,0xf9930015}},	// [f390] sító_, _chùa_, _تقيم_, خبز_
  { {0x6cd50015,0x9874006b,0x6d490045,0x3e880030}},	//   _أقدا, клуц, ţeas, pító_
  { {0x8c44000d,0x4758005e,0x3e35002b,0x6c56000a}},	//   _шеќе, дрія_, _تفکر, _איתא_
  { {0x501b000a,0x37080015,0x36d40054,0x98aa0091}},	//   חובו, وْلُ_, кохр, _ribą_
  { {0xd567004a,0x0f36004c,0x7bd50227,0x78b2001a}},	//   фтеп, גרײט_, lyzu, íkvó
  { {0x3ea9049c,0xa3ab021e,0x7d7c000a,0xb5fd0046}},	//   _laat_, खिल_, קרוג, _neše
  { {0x83640015,0xb8d5000b,0x8464006b,0x0000006a}},	//   نديل, ढ़ा_, тъче,
  { {0x5c38000a,0x9fae0030,0x8c38000a,0x339200c3}},	//   ורון_, _főút_, וטוס_, اليز
  { {0x7afa0084,0x629b0026,0xddc40816,0xe1f90681}},	//   étti, reuo, _odiš, яги_
  { {0x629b0176,0x24550015,0xe4480015,0xa9fa000a}},	//   seuo, _أناس, _يلقى_, לִית
  { {0x32553950,0x929d005c,0x743a004c,0x3ea90079}},	//   _звер, wołu, _זעעװ, _baat_
  { {0xcfd20015,0x92670040,0x0000006a,0x0000006a}},	//   ايَة, _آدام,   ,
  { {0x5d670080,0x9dba0010,0x9e630033,0xd0d50a32}},	//   ниям_, чыну_, ывяд, _подъ
  { {0xa0c50015,0x0000006a,0x0000006a,0x0000006a}},	//   _سيبو,   ,   ,
  { {0xc4d2000a,0x7a2a0030,0xd10c000b,0x69cb0b12}},	//   נגל_, köté, सकरण_, ägen
  { {0x3ea90298,0xfaa311ea,0xcc8a002b,0x2fd8063b}},	//   _gaat_, ласо, _کنده_, ørge_
  { {0xc33204dc,0xc9860029,0x5efb0008,0x4efb000a}},	// [f3a0] רון_, عشري, _מפקד, _מהקו
  { {0x7d57015b,0xd6220138,0x0000006a,0x0000006a}},	//   _רייד_, цiна,   ,
  { {0x9cd7000a,0xe73a004a,0xdb0f0030,0x2f3a004f}},	//   _נוטה_, чее_, ődát, ִגְד
  { {0xc8690008,0x66e301f3,0xb4d80065,0xb716009a}},	//   מן_, лоха, ास्_, رباش
  { {0xe5720015,0x0000006a,0x0000006a,0x0000006a}},	//   اطؤ_,   ,   ,
  { {0xdb0500b8,0x34940033,0x2ee00034,0xcd77000a}},	//   _erhä, такр, _llif_, תעסק_
  { {0x96960083,0x2f1900dc,0xb5fd0263,0xc917000a}},	//   _праш, ségi_, _reše, _נחלת_
  { {0x8c1b000a,0xaae0000b,0x6b830123,0xb5fd0046}},	//   הוצי, नसिक, _ånge, _seše
  { {0x1a9b00b2,0x343a0002,0x7ae40c59,0x66e30033}},	//   ליקע, _فساد_, ihit, _сота
  { {0x94a90029,0xbcfb00dc,0xc0570484,0x3ea95d89}},	//   _يطلق_, rsék, нію_, _saat_
  { {0x32e40092,0x2018002e,0xf487002b,0x9fb50046}},	//   _đườ, æri_, _سالی, _přát_
  { {0x57fb000a,0x7ae400bc,0x753a00d5,0xd366002b}},	//   לליו, jhit, _hitz, یه_
  { {0xed580010,0xc2e90029,0xbcfb0125,0x3ea93513}},	//   ноў_, _تعلم_, lséi, _vaat_
  { {0x91bb0008,0xbca50015,0x7ae40201,0x63ad002a}},	//   _ממדי, خمسي, ehit, łane
  { {0x644a002d,0x936b000a,0x20c90015,0x4fb30015}},	//   icfi, ּ֣לֶ, _تبني_, _مصير
  { {0x3da706b4,0x3f8b0011,0x6ec70015,0x7bd5002a}},	//   _зроб, ăcut_, _ستبق, ryzu
  { {0x5a35017a,0x8a1b002b,0x6d403e08,0x0c7400bf}},	// [f3b0] тнат, سترس_, ímat, ýýýý
  { {0x394f0024,0x6f1d1d10,0xf8070c71,0x2bba000b}},	//   īgs_, llsc, нчен, _उपचा
  { {0x6f1d002a,0x2eab000a,0x0000006a,0x0000006a}},	//   olsc, ּשְּ,   ,
  { {0x443e5d8a,0xf6530015,0x2727007c,0x7ae40bbc}},	//   _agt_, ائض_, kõne_, chit
  { {0x443e01d7,0xe5a50724,0x693601ec,0x6b8302dc}},	//   _bgt_, тили, _zņem, _ångb
  { {0xdb1c0084,0x6f1d0012,0x6aad081d,0x69cb02de}},	//   lyrð, hlsc, ldaf, øgeu
  { {0xdb0500c0,0x3942007c,0x94d20004,0x0000006a}},	//   _erhå, _zuks_, ројц,
  { {0x3bbc000a,0x6aad1af0,0x41b500ce,0x443e02ad}},	//   למוד, ndaf, всот, _egt_
  { {0x30790029,0x26dc003d,0x798d050b,0x64580123}},	//   وحدة_, īvot_, ntaw, bbvi
  { {0x76590026,0xf992000a,0x798d0ef3,0x2127002b}},	//   lbwy, סרי_, itaw, عيدی_
  { {0x22950029,0x2901001c,0xe00b000b,0x798d01d7}},	//   _للاس, inha_, _सुखद_, htaw
  { {0x92eb0074,0x6701005d,0x44250085,0x798d1d0d}},	//   _عراق_, लचिक_, _izl_, ktaw
  { {0xd656000a,0xdce4003d,0x69cb0400,0x6aad5d8b}},	//   כירת_, _aviā, ägel, ddaf
  { {0x7e66007c,0xb22400fd,0xdb1c001a,0x1fb50912}},	//   sakp, _сміл, eyrð, _асир
  { {0x5f060063,0x2d9e099c,0xdddd005c,0x6b633aeb}},	//   _изка, ňte_, gasł, икра
  { {0x501a000a,0x2901016e,0x9f49002a,0x673b0091}},	//   _קוקו, enha_, łków_, _niuj
  { {0x61e904ec,0xf2d20053,0x6e24003f,0x7ae45d8c}},	// [f3c0] nzel, בען_, _uzib, rhit
  { {0x7d7b039e,0x7ae406e8,0x61e9416b,0x3c460015}},	//   _קניו, shit, izel, _جَدِ
  { {0xcc770008,0x76590026,0x3c770008,0xcc57000a}},	//   _בעיה_, fbwy, _בתים_, _שבטי_
  { {0x753a00b8,0xd6d90036,0xcf920643,0x29015d8d}},	//   _sitz, нті_, שטא_, anha_
  { {0xa2c0005d,0x7afa002e,0x61e90079,0x673b0375}},	//   वास्, éttu, jzel, _diuj
  { {0xe4760010,0xf99300a3,0xd6e2002a,0x1513005e}},	//   тудэ, _דרש_, _siłę_, адія
  { {0x64580024,0x61e93c66,0x53a30015,0x66095d8e}},	//   rbvi, ezel, لموك, _exek
  { {0xfbd30008,0x7e64002d,0x3253006b,0xddcd0045}},	//   שתה_, _neip, авър, _neaş
  { {0x7f430467,0x7ae30011,0x3667012f,0x84960058}},	//   _aunq, _înte, _шато_, _لجائ
  { {0x753a0111,0xb145002b,0x6f1d0079,0x44a5006e}},	//   _uitz, دیوم_, wlsc, _محمّ
  { {0x03a30191,0x287b0008,0x487b000a,0x987b000a}},	//   _вихо, ונימ, וטיס, ואיט
  { {0xc6940053,0x7f4304ed,0x93f7000a,0xd243004a}},	//   נאָ_, _dunq, _בצבא_, _кэши
  { {0x61e9005c,0x7e640026,0x753d0030,0xb5fd2647}},	//   czel, _deip, _észt, _keša
  { {0x40a80086,0x71d70008,0xf531000a,0x6fb40040}},	//   _سختی_, _בודד_, ֶ֥ם_, _ممتا
  { {0xa3ab005d,0x113b000a,0xac182dc2,0x9b45002b}},	//   खिए_, _קתול, вору_, انرو
  { {0x386302de,0xba770058,0xbae40138,0xaa7b0052}},	//   _sejr_, ضارت, ацуй, _blýa
  { {0xef1f0061,0x6d4458af,0x59f8006b,0x6aad411e}},	// [f3d0] mlü_, _guia, ветя_, rdaf
  { {0xc0d40008,0xcdaa004c,0x29f30061,0xef1f0061}},	//   נֵּה_, _טיפֿ, _ağaç_, llü_
  { {0x798d3dad,0x1bd50036,0xab2b0015,0xba3b0003}},	//   staw, _соня, _يسجل_, _naïv
  { {0xcf9300b2,0xe7580036,0xf7700002,0x69cb02de}},	//   יטע_, тиці_, زام_, øges
  { {0xa4d50036,0x49740010,0x76590034,0x94d5030c}},	//   лоді, _кляс, rbwy, лодц
  { {0xd006003b,0x4ddc0008,0x61e900bd,0x05740115}},	//   _هل_, וחדו, vzel, شاهد
  { {0xb5fd016f,0x57a402e1,0xef1f0061,0x58050015}},	//   _deša, _кшта, klü_, _صورك
  { {0x61e90f55,0xd18503ad,0x11d90015,0x4159005e}},	//   tzel, глий, فوعة_, ншою_
  { {0x249b0015,0xf57900c3,0x61e95d8f,0x0000006a}},	//   _يخطب_, _سماع_, uzel,
  { {0x9fc90004,0x61e95d90,0x03b70015,0x0000006a}},	//   егоа_, rzel, _لإصد,
  { {0x9259006b,0xf8b2004c,0x853a015b,0x8384004a}},	//   _зает_, זשי_, _נגעי, _выче
  { {0x61e900dc,0xe2db0015,0xb1b5006e,0x2ede0065}},	//   pzel, _تبطؤ_, _محتش, मसेत
  { {0xd12e0074,0xa2c0005d,0xcdf60256,0xa3ab000b}},	//   تمی_, वार्, учны, खिक_
  { {0x71720086,0xc5fa000a,0x4df50121,0x9d434b0a}},	//   _اهوا, תפשט, ряют, серд
  { {0x3bd5005f,0x6fb20086,0x75ea00dc,0x7e6408f6}},	//   аютс, _هموا, _közé, _teip
  { {0xe7f9000b,0x3ad60015,0x7ce2006f,0x224d0030}},	//   ्पना_, ديرز, _dôra, ncek_
  { {0x6b9b04f9,0xf2d20053,0xd9460029,0x316d23a5}},	// [f3e0] ăuga, זען_, ائري, nsez_
  { {0xbd5b0008,0x98b90011,0x644101d7,0x3ea25d91}},	//   _רכיש, _rusă_, _ngli, lekt_
  { {0x2d82016f,0x69cb0134,0xb5fd016f,0x60da004c}},	//   luke_, øger, _reša, עקענ
  { {0x76a90036,0x5b7b0053,0xdd8f002b,0x98b90045}},	//   ктів_, _ארטא, _بوی_, _pusă_
  { {0x2d82183c,0xb5fd06f2,0xbcfb0003,0x99d60015}},	//   nuke_, _peša, rsév, _إتجا
  { {0x291e00dc,0x7d7b000a,0xef1f0061,0x7c3a0091}},	//   _óta_, תנסו, zlü_, žtru
  { {0xd3770010,0xef1f0061,0xaa7b0046,0xa2c0000b}},	//   гчы_, ylü_, _mlýn, वाल्
  { {0xae04000b,0xf7d7000a,0x05760015,0x644119ad}},	//   रपान_, _גולש_, _مائد, _egli
  { {0xf50a004a,0x7ebb008c,0x3ea20079,0x638a016e}},	//   _знал_, _läpä, dekt_, _bênç
  { {0x2d8214c0,0x50f42fe4,0xa0a60129,0xa3a60369}},	//   duke_, рзот, ушил, _محصن
  { {0xc9170008,0x3ed50015,0xde59005e,0x6303002b}},	//   רחית_, لقدر, кані_, شویل
  { {0x753d00dc,0x925a0015,0xf837000a,0xa837000a}},	//   _észr, _أشار_, טנית_, טריד_
  { {0xef1f0064,0xbed8005e,0x6ce700ce,0x644102ad}},	//   rlü_, удях_, гіве, _ygli
  { {0xd12f0029,0x3ead04c6,0x3aff008c,0xade40033}},	//   _فمن_, žet_, käpä_, сцюк
  { {0x3ae7007c,0xd0f7000a,0x7d150bba,0xac190a3f}},	//   _lõpe_, _תמות_, rozs, тову_
  { {0x4a550511,0x2d825d92,0xaa5506eb,0xdf73009a}},	//   ркас, buke_, рваш, _ادوب
  { {0xe9750029,0xadb9006e,0xd141002a,0x0000006a}},	// [f3f0] شهاد, _شهدا_, ciąć_,
  { {0x270d000b,0x2907007c,0x7afa001a,0x5a343758}},	//   िक्र_, õna_, éttr, снут
  { {0xfcac004c,0x5d3a000a,0x0a9501f3,0x78880058}},	//   _װיכּ, _שתתא, _каню, اَمِ_
  { {0xd6ab00c3,0x8aa75d93,0x35b52ae4,0x600b004f}},	//   عدام_, _срод, ибер, תִמְ
  { {0xe7300029,0x298b02c8,0xa2ce000b,0x8b08000a}},	//   أصل_, _ясно_, _तवज्, _תִתֵ
  { {0xb97a000a,0x2ee2000b,0x9477002b,0xbcfb0030}},	//   _בנשי, _पत्त, ادشا, csét
  { {0x9cd8000a,0x80c8000b,0xd141002a,0xa7a9004f}},	//   רווה_, ़ाने, ziąć_, _בֹּ֥
  { {0x2bf80008,0x41b50029,0xc245135d,0x63430030}},	//   טמון_, لمعر, шник, _nőne
  { {0xa4870115,0x3ea200cb,0x46f4004a,0x224d0808}},	//   _مجان, vekt_, _учёт, rcek_
  { {0x7fb50010,0xe0d60080,0xd12e00e6,0xa534005e}},	//   аёмі, ивы_, ومي_, _гнуч
  { {0x316d038d,0xef190024,0x62750115,0xd009061e}},	//   ssez_, guļo_, _نهائ, тене_
  { {0x2d820020,0x6126002e,0x799d00aa,0x6e200072}},	//   tuke_, rðla, _opsw, ümbo
  { {0x25d5000a,0xa1580484,0x3ea25d94,0xe716000a}},	//   ׁוֹן_, _бачу_, rekt_, שחרר_
  { {0x2d823792,0xf9630053,0x7ff5002b,0x398f0061}},	//   ruke_, עהיפּ, _پستا, düs_
  { {0xfaf61402,0x0af60033,0x3ea25d95,0x63430030}},	//   ачаю, ачаў, pekt_, _főne
  { {0x8a0606eb,0x0000006a,0x0000006a,0x0000006a}},	//   азбе,   ,   ,

  { {0x44320023,0x44200092,0x7866047d,0xdb1d0030}},	// [f400] ̀y_, ́i_, иказ, ízás
  { {0x9856027a,0xab6602a3,0xa7b601ca,0x7188004f}},	//   рташ, _квол, исеј, טְעַ
  { {0x62991cb7,0xbc7b000a,0x68430033,0x6c7b0447}},	//   _obwo, _בנית, інца, _בריד
  { {0xa2a7000b,0x398f0061,0x6a96005e,0x25a60034}},	//   _फ़ोल्, büs_, _троє, twol_
  { {0x7ceb00b8,0xe693006e,0x567700e2,0x7ae300d4}},	//   _dürf, تلند, рбія_, _înta
  { {0x03b60015,0x25a60034,0x44f301f3,0x6aa45d96}},	//   لإعد, rwol_, опіс, leif
  { {0x27270020,0xbddb0152,0xd4690015,0xdc89000a}},	//   sõna_, ncèr, احهم_, רְנָ
  { {0xa310000b,0x057a0015,0xbcfb0003,0xcb57004f}},	//   ावेज_, _لمرة_, nsér, בסקה_
  { {0xc05a0484,0xd9f8000b,0xe61a005e,0x9f4d0046}},	//   кін_, ूपित_, _рда_, ěným_
  { {0x6b9e06f5,0xf9930008,0x2eaf000b,0x7bdc0091}},	//   _oppg, קרת_, _जोड़त, kyru
  { {0xa2d60086,0x351b000a,0x67220061,0x3f150c31}},	//   _پيشت, _יומנ, oloj, йдос
  { {0xc7b3000a,0xa2d30021,0x1dc2000b,0x33fb000a}},	//   קבר_, _ويلت, शमंत, _בהבנ
  { {0xfe6e0086,0x11540010,0x28c9000b,0xf3f10016}},	//   ژگی_, _уклю, रामि, _hẹp_
  { {0x2262005c,0x91bb000a,0x7ceb007c,0xd6d9002a}},	//   ńską_, _שמגי, _mürg, _miła_
  { {0x7f84003b,0x67220007,0x3eb0008c,0x212b0003}},	//   _العن, kloj, öltä_, îche_
  { {0x403b0008,0xbcfb0f87,0x539b0008,0xbb840015}},	//   _בגוג, gsér, כילו, تلفي
  { {0x4b04008f,0x8d950015,0xb9250015,0x5b14005e}},	// [f410] цярб, _الخش, مفري, імут
  { {0x261a005d,0x30d8000a,0xdced0085,0x398f0061}},	//   _बड़ी_, נַּע, _kvač, rüs_
  { {0xba3b5d97,0xf7730029,0xd1170008,0x28150015}},	//   _païs, تاذ_, סקבה_, حواس
  { {0x7ceb00b8,0xbcfb0030,0x8bba000a,0xba190015}},	//   _bürg, csér, _עזרת, _ميجا_
  { {0x6ee60030,0xb5a7004a,0xee32004f,0x63ba5d98}},	//   _jóba, ррей, ִֽד_, _artn
  { {0xb4e1000b,0xf773002b,0x8458006b,0x7ceb0012}},	//   दसे_, _واز_, арът_, _würf
  { {0xe3b30074,0xbcfb0152,0xe2990afb,0xd7e4005e}},	//   ترش_, nséq, гай_, _діто
  { {0x7ceb0012,0x0000006a,0x0000006a,0x0000006a}},	//   _hürd,   ,   ,
  { {0x7ceb0061,0x97420033,0xba3b01f6,0x6452005a}},	//   _kürd, цiць_, _zaïr, édií
  { {0x70c90001,0x25ad0026,0x15150033,0x95c40015}},	//   угог_, _isel_, _удзя, _بيكه
  { {0x8fa5006b,0x1ec60015,0x389a004f,0xd6a500ce}},	//   щане, مقدّ, איתנ, рiчн
  { {0x6717005d,0x1719000a,0xba3b0003,0xed5a5d99}},	//   तविक_, רוֹע, _laïq, лом_
  { {0x6d4b038d,0x63bf002a,0xddd4006f,0x225f07c8}},	//   _égal, łynę, ťažn, mbuk_
  { {0xa069000d,0x62890020,0x6aa40012,0x6da30004}},	//   _сака_, lgeo, weif, џира
  { {0x60c3003c,0x6aa400b8,0x4b260029,0x60dc3c8f}},	//   _innm, teif, معرف, örme
  { {0x4a46008f,0xaf760053,0x2fd80020,0x0e6600d7}},	//   снав, _העקס_, ärge_, _укин
  { {0xc332013a,0xaf350086,0xab2713d9,0x6aa45d9a}},	// [f420] לול_, _بويژ, сота_, reif
  { {0xb4e6014e,0x5e570086,0xc9850029,0xdb15002c}},	//   _पते_, _پلیس_, تشفي, ľbác
  { {0x6b9e25c0,0xe3b80064,0x35fa002b,0xd6d9002a}},	//   _uppg, _ayın_, گراد_, _siła_
  { {0x6722008c,0x7ceb007c,0x612f0013,0xd6d90535}},	//   uloj, _pürg, bølg, _piła_
  { {0xa5960063,0x60c3002d,0x3f850375,0xd910002b}},	//   срещ, _onnm, hulu_, _قیر_
  { {0x1e3b004c,0xdb07001a,0x28c9000b,0x3eb20061}},	//   אגנא, ðlög, राणि, _layt_
  { {0xbb3a000a,0xe3af0015,0x93770015,0x25ad0012}},	//   ְעִי, فري_, مصير_, _esel_
  { {0xa3c9014e,0x3f850107,0xb355002b,0x71780054}},	//   _ऊपर_, dulu_, زیها_, абир_
  { {0x52730001,0xd4f60033,0x6d490045,0x3f850034}},	//   чују, _ляжы, ţeaz, eulu_
  { {0x7ceb0064,0xff980001,0xe50600c3,0x6ee60125}},	//   _küre, акој_, _ابري, _róba
  { {0x74160002,0x9f35005e,0x64a307be,0x43e50015}},	//   _اوضا, жені, _хаха, _وأمّ
  { {0x66ca000a,0x7ceb0061,0x216a0004,0xceeb00c3}},	//   אמֹ֔, _müre, _биди_, اردن_
  { {0x8717000a,0xaa7b001a,0x317f5d9b,0x291a5d9c}},	//   מקטע_, _flýj, cruz_, kopa_
  { {0xa2d4005d,0x4237000a,0xcc54006b,0x6c54005e}},	//   यॉर्, _הנדל_, звръ, зкру
  { {0xb0970008,0x23780008,0xe0fb0447,0xa097000a}},	//   _הדוח_, יָּמ, _גלגל, _הדוק_
  { {0x7ceb0064,0x8f57000a,0x6ee6001a,0x0000006a}},	//   _sürd, _פסחא_, _tóba,
  { {0xeef8004f,0x0000006a,0x0000006a,0x0000006a}},	// [f430] _למהר_,   ,   ,
  { {0x6e2d010b,0x28c9005d,0xfc470089,0x0974005e}},	//   _izab, राधि, číst_, ягую
  { {0x7ae304f9,0xead50036,0xf7700002,0xa09b000a}},	//   _înto, _донь, فان_, ריבט
  { {0x7ceb4b0c,0xdb1f00f2,0x6d5d0024,0x0000006a}},	//   _würd, äväk, opsa,
  { {0xb5fd00df,0x7e7c0053,0x7ceb0064,0x3f851865}},	//   _iešk, ראדז, _türd, zulu_
  { {0x7aed0014,0xa5090001,0x7e6f0125,0x8dfc000a}},	//   lhat, јека_, hacp, נהגת
  { {0x2ee90176,0xad1c0008,0x7ceb068c,0x628903f8}},	//   _olaf_, אוגר, _güre, tgeo
  { {0x7aed1683,0x62890012,0x6e2d00bc,0x569434d4}},	//   nhat, ugeo, _ozab, _наст
  { {0x6289010c,0xe5c7053b,0xb5fd5d9d,0x60e909c2}},	//   rgeo, _усво, _mešk, имим_
  { {0x41020010,0x4f9501e5,0xb1160015,0x98b90091}},	//   дзьв, орму, يقيا_, _pusę_
  { {0x04c80029,0x7aed0030,0xdbc6007c,0x1eca113a}},	//   _دولي_, khat, löög, ални_
  { {0x82340086,0xf7720053,0xeef60010,0x3f850064}},	//   _کرما, וקט_, іянэ, rulu_
  { {0x7aed0014,0x7e550010,0xb0f50015,0xd00e002b}},	//   dhat, ятэц, _وأتش, فلی_
  { {0x25a00064,0x463a0053,0xde03005e,0xa2040033}},	//   çili_, יערע, єпри, _эпід
  { {0x6d5d5d9e,0x7fd5042b,0xcb6a0033,0x6e2d0045}},	//   apsa, _філі, рабе_, _ezab
  { {0x0d860080,0x7aed5d9f,0xbf360015,0x4b2601f3}},	//   _длин, ghat, _برتغ, імав
  { {0x7ceb01e2,0x291a01a3,0xee3f001a,0x2a60007c}},	// [f440] _süre, topa_, sdýr_, rbib_
  { {0xed590089,0xe8c70010,0xa3bc000b,0x99160033}},	//   íže_, огул_, इटम_, цьбі
  { {0xab2a0191,0x7aed00dc,0x7d1c5da0,0x5b360033}},	//   _вона_, bhat, mors, _мэму
  { {0xe5c60080,0x7d1c1b8e,0x8f9a000a,0x7aed5da1}},	//   жско, lors, ייעי, chat
  { {0x7ae40007,0x7d1c1663,0xcb0a002b,0x27f60046}},	//   mkit, oors, _ميگن_, _ženě_
  { {0x7ceb5da2,0xd37a08dc,0x35b30033,0x7ae45da3}},	//   _türe, ачи_, ьбір, lkit
  { {0x24800064,0x7ae41a91,0x76a60015,0x6ab6002a}},	//   ğim_, okit, _وحرك, odyf
  { {0x248001e2,0x7ae45da4,0x68430010,0x53970010}},	//   şim_, nkit, _інта, івыя_
  { {0x7ae40007,0x60f80063,0x2369016f,0xc4c60015}},	//   ikit, йния_, ćaja_, _وتطو
  { {0x7aed0014,0x60f80010,0xd1300015,0x24530015}},	//   zhat, ёння_, عمد_, _ينقس
  { {0x7ae400f2,0x6e2d145e,0x7d1c0ce4,0x2d825da5}},	//   kkit, _szab, dors, erke_
  { {0x79960050,0x399400f2,0x41e6022a,0xc3060015}},	//   ktyw, käs_, _міла, _ببطو
  { {0xd337000a,0x7e2b005e,0x63a10046,0x7aed0030}},	//   _וראה_, ріна_, _zpln, vhat
  { {0x6d5d002e,0x61ec0061,0xbcfb0003,0xbfd60015}},	//   rpsa, ıllı, xpéd, _ويشع
  { {0x7aed0014,0xddeb002b,0x1eea002b,0xa2ce000b}},	//   that, _چرخه_, _گويی_, थाप्
  { {0x7d1c00dc,0x7aed0020,0xb606016f,0x2023002c}},	//   aors, uhat, _kršć, íriť_
  { {0xb5fd0089,0xf84b004a,0x7aed5da6,0xaf340067}},	// [f450] _vešk, ачей_, rhat, _تروت
  { {0xa2a1005d,0x7d1c04ed,0x7ae45901,0x7aed5c6c}},	//   _कॉन्, cors, akit, shat
  { {0xb5fd44ec,0x7ceb0061,0x7996002a,0x929d002a}},	//   _tešk, _türb, atyw, liłe
  { {0xec360008,0xb4b3005d,0x6f1d5da7,0xe613002b}},	//   _מאתר_, _जोड़_, nosc, وشش_
  { {0x7cf000c0,0x6d455694,0x7ceb0064,0x63a10264}},	//   _därf, _kiha, _gürc, _spln
  { {0xdfc60029,0xe4510029,0x89da0008,0x6f1d002d}},	//   _كي_, رضت_, _החשי, hosc
  { {0xcc7c01e4,0xa2e50080,0x04425da8,0x3c7c000a}},	//   שְׂר, зойд, нешн, שָׂב
  { {0x6595170d,0xd6c3002b,0xe1f10015,0x6d453ee7}},	//   _набу, _تمری, فسخ_, _liha
  { {0x7d1c01e2,0xddc600bc,0x6f1d0d65,0x0000006a}},	//   yors, kakš, dosc,
  { {0x10150010,0xf99200a3,0x60e90054,0xb5fd42d8}},	//   зьмя, ערי_, смом_, _neši
  { {0x7ae400df,0x80cd014e,0x14ca002b,0x7d1c5da9}},	//   ykit, ताबे, _دهلی_, vors
  { {0x7e6d002d,0xd1380007,0xc0e90086,0x13b6000a}},	//   _ceap, amą_, _گفتن_, _מהעל_
  { {0x7cf00005,0x22290086,0xbd36006b,0x6d455daa}},	//   _järg, _ازای_, зхвъ, _biha
  { {0x7cf00005,0x63510048,0xf1b20008,0x2c570089}},	//   _märg, _jāno, _נסו_, vědí_
  { {0xcc870080,0x929d005c,0x6d450375,0x7d1c262d}},	//   ябре_, woły, _diha, rors
  { {0x7ae446d0,0x7d1c5dab,0x3f7a000a,0xa2a1000b}},	//   ukit, sors, _האקס, _कॉम्
  { {0x7ae45dac,0x929d002a,0x6ab60034,0x7d1c5dad}},	// [f460] rkit, ciłe, rdyf, pors
  { {0x7ae45dae,0x8dfb000a,0x2888002b,0x6923005e}},	//   skit, _להפת, تصری_, емуа
  { {0x2d8f00c0,0x7ae41634,0x064a0002,0x38cb002b}},	//   _äger_, pkit, ملاً_, حاقی_
  { {0xd94631f2,0x5b57000a,0xd1380b48,0x9f600030}},	//   _неми, _מיטב_, zmą_, ösét_
  { {0xd13800df,0xbb3b0053,0xe4e6022a,0x3abb000a}},	//   ymą_, _לעטי, зійн, _המכנ
  { {0x44250089,0xbcfb0003,0xddc40045,0x2916002b}},	//   _byl_, ppée, _zeiţ, _روزآ
  { {0xdcb10092,0x28c9000b,0x929d002a,0x8318002b}},	//   ổi_, रारि, ziłe, يقتر_
  { {0xbc0d0008,0x7cf01d92,0x877b000a,0xd2500015}},	//   יהוָ, _färg, _לאלי, خنة_
  { {0x6b9b0045,0x7cf0007c,0x7e6d08ac,0x11d80058}},	//   ăugi, _kärd, _reap, زودة_
  { {0x60f80191,0x52130010,0x7e6d0541,0xdced006f}},	//   іння_, эдыт, _seap, _spaľ
  { {0xd1380b53,0xb5fd0796,0xb3e90015,0x929d002a}},	//   rmą_, _reši, _وعمل_, wiłe
  { {0x6d450213,0x7cf00123,0xd1380091,0xb5fd5daf}},	//   _siha, _lärd, smą_, _seši
  { {0xd24f003b,0x3dc00026,0x6d450375,0x81d3005e}},	//   _إنه_, _criw_, _piha, _поїх
  { {0xd12f0191,0x7e6d003e,0xd23b0008,0x317b0135}},	//   _їх_, _weap, _הגדל, _פרומ
  { {0x78b5065d,0x309b0008,0x50b70029,0xb09b000a}},	//   _razv, _השומ, _ردود_, _היור
  { {0x7c250227,0x2d9f0003,0xead40033,0x78b532fc}},	//   _vyhr, çues_, нось, _sazv
  { {0xceb400b2,0xdb240014,0xf9930015,0xddc6003d}},	// [f470] _ניץ_, írás, عبر_, pakš
  { {0x63ad0050,0xb9c40015,0x3eab24dc,0x6fb0000b}},	//   łani, عقلي, lect_, _जनां
  { {0x2d9900dc,0x56950080,0x4c9a000a,0x2d8b5db0}},	//   ltse_, дает, _ובתו, luce_
  { {0x7afd00b8,0x3eb90134,0xa6c90029,0xf1cc000b}},	//   _umst, ndst_, توصل_, ़मान
  { {0x83fc010b,0x7cf000c0,0xe81d005d,0x3eab0011}},	//   _među, _färd, _बुरा_, iect_
  { {0x2d991325,0x62870091,0x442507ed,0xe3e9002b}},	//   itse_, ėjom, _pyl_, يکان_
  { {0xe7840001,0x76650015,0xb5fd20db,0xb6080247}},	//   _путо, _يُسم, _nešv, vyšš
  { {0x3eab122b,0xc7b2000f,0x2d99007c,0x86c50058}},	//   ject_, _בבל_, ktse_, _تيرن
  { {0x05950086,0x71720015,0x91b00016,0x2d990030}},	//   _تازگ, نهيا, _đãi_, jtse_
  { {0xddc40007,0x8f75005e,0x2d8b08ab,0x02020033}},	//   _neiš, мумі, duce_, тзьн
  { {0x7cf00005,0x273501d1,0x92590080,0x3eab05d6}},	//   _järe, gång_, _дает_, fect_
  { {0xa2e40036,0x141a0053,0x441a0053,0x63050015}},	//   _поєд, _וועב, _וועס, _توصل
  { {0x02440015,0xf2d2000a,0x2d8b0085,0x6e29002a}},	//   _كَمَ, _שעד_, guce_, żebn
  { {0xc1720008,0xdb240046,0x7ceb007c,0xed59006f}},	//   _יחד_, ěsíc, _püra, íža_
  { {0xdfce00e6,0xe81d000b,0x3ff20015,0x2d992433}},	//   _نيو_, _बुला_, _لكور, atse_
  { {0x1fc9005d,0x2d8b0089,0xee0a0238,0x6b81001a}},	//   िमीड, buce_, _мейл_, álga
  { {0x394636bb,0x28c9000b,0x9139000a,0x3b070663}},	// [f480] днаг, रांि, ַעֲק, фето_
  { {0x49990080,0xcc8a0086,0x2f59000a,0x7cf003c1}},	//   ятся_, _بنده_, ַדְנ, _bäre
  { {0x7cf001d1,0xca4a0015,0xbcfb134b,0x0000006a}},	//   _värd, _ولده_, spéc,
  { {0xc6a30292,0x7cf000c0,0xf6e50010,0x6fb0005d}},	//   врши, _däre, нцін, _जनसं
  { {0x7f3b0053,0xee09000a,0x6593002b,0xad25009a}},	//   קענו, ּמוֹ_, نجور, _زریو
  { {0xcdf7000a,0x2d54007c,0x38d4004f,0xcb9a004f}},	//   ומני_, _mäe_, _אֵֽל_, ַיִם
  { {0x68e301e2,0xb373002b,0x86960054,0x7cf0007c}},	//   önde, نديش, _ојач, _kärb
  { {0x07a30010,0x86f80086,0x41e60036,0x27e70293}},	//   _шасн, _عکاس_, діоа, ønne_
  { {0x2d540044,0xd086004a,0x3f850375,0xa3ca000b}},	//   _näe_, мыни, erlu_, _लपक_
  { {0x64360029,0x1604005d,0x54360031,0xc057017f}},	//   _قراء, _शेयर_, _قرار, мію_
  { {0xddc40007,0x3eab05d6,0xe29a000d,0xf8b3000a}},	//   _reiš, tect_, _маж_, דשת_
  { {0xd57c005e,0x27350123,0x7cf004d6,0x2d8b5db1}},	//   _вiдк, rång_, _närb, tuce_
  { {0x7bda00f2,0xed580010,0x7ae30011,0x333b000a}},	//   ätun, моў_, _înti, _ותאמ
  { {0x3eab31aa,0x2d8b5db2,0x2d995db3,0x0000006a}},	//   sect_, ruce_, rtse_,
  { {0x01350053,0x5c0404f7,0x7cf000c0,0x0137000a}},	//   _אָקט_, вята, _bärb, _חרגת_
  { {0xa3b6000b,0x4ea70054,0xef19003d,0x0f7b000a}},	//   _छनन_, _црка, tuļu_, _ואהב
  { {0x44290023,0xb5fd0089,0xadb401b0,0xa3b5000b}},	// [f490] ́a_, _ješt, _абыш, _चैन_
  { {0x3f8c0046,0x39470123,0x5a340c91,0xb5fd53e9}},	//   oudu_, öns_, тнут, _mešt
  { {0x3f8c016f,0x7cf00012,0xb5fd016d,0x0000006a}},	//   nudu_, _färb, _lešt,
  { {0x7cf000f2,0xdc0301c0,0x78880030,0xda670040}},	//   _väre, nčím, tévü, _تادي
  { {0x7cf000b8,0x4a5a0008,0xbef8000a,0xb5fd18b1}},	//   _wäre, _מדרו, וצאו_, _nešt
  { {0x98c40080,0xdddd002a,0x6d4b0003,0x3f850034}},	//   _иссл, obsł, _égau, yrlu_
  { {0xaa7b002e,0x273500c0,0x63b6002a,0xa3e90b9b}},	//   _flýt, tånd_, łynn, ядка_
  { {0x645a09f0,0xdb0508e9,0x5275002b,0xd24e009a}},	//   _efti, _erhö, رابز, مچه_
  { {0x317900dc,0x85050015,0x86270033,0x955700c3}},	//   ész_, _كورن, _цьве, _آخرا
  { {0xddc404f9,0xe0d10029,0x28d2000b,0x7cf00012}},	//   _afiş, ازة_, सायि, _märc
  { {0x7cf00012,0x5f064266,0x0000006a,0x0000006a}},	//   _lärc, езна,   ,
  { {0x32750053,0x7ceb5db4,0xd356004c,0x2ca70061}},	//   _װײַל_, _büro, _טשעק_, _ında_
  { {0xc33201e4,0xe1ee0001,0x672b003c,0xe3a7002b}},	//   _עוד_, _сг_, ilgj, گر_
  { {0x3f8c0046,0x61340144,0x290f0003,0x61da004f}},	//   budu_, tàle, égal_, _מקנד
  { {0x3ae80074,0x3cf1000b,0x6351003d,0xe3a7006e}},	//   وبری_, ीफ़े_, _sānj, در_
  { {0x80cd000b,0x6ffa000a,0x27184bf4,0x70bc0065}},	//   तावे, _מהצפ, očne_, ्फ़ील
  { {0x271800bd,0xbcfb002d,0x7cf0007c,0x08c603de}},	// [f4a0] nčne_, spéa, _värb, нбан
  { {0xee37008f,0x3c66042b,0xeb9a006b,0x2bd0000b}},	//   _яны_, _яког, _еио_, हमदा
  { {0xb8950063,0xdeba0008,0x3ce500dc,0xb8930015}},	//   ъртъ, ּמְל, ölve_, المع
  { {0x6b7b000a,0x2f5a004c,0x6aad5db5,0x0000006a}},	//   _צרכנ, לדענ, ceaf,
  { {0x8623007a,0x09e3006b,0xceb3000a,0xb6020046}},	//   льше, _боян, טיא_, _čásk
  { {0xb5fd002c,0xb4ea000b,0xd91a002b,0x0000006a}},	//   _rešt, मसे_, _ريزش_,
  { {0xa3d403fc,0xb5fd00bc,0x6562008c,0x929d002a}},	//   тойч, _sešt, spoh, wiła
  { {0xfbd30008,0x784e00dc,0xa79b000a,0x5c37004c}},	//   רתה_, bőví, _משלח, ערקן_
  { {0x92570015,0x8b3b000a,0x690b0535,0x6f0601ea}},	//   رشير_, התקצ, użeg, dikc
  { {0x55770053,0xb5fd0d98,0x69fb000a,0xc4c50015}},	//   _נעבן_, _vešt, פליק, _لتمو
  { {0x889b000a,0xe1ef002b,0xe5050015,0xa0a30033}},	//   הביי, لسی_, _شبكي, ушыл
  { {0x6ed1000b,0x7ceb007c,0x3f822ed8,0xe29a00af}},	//   धाधु, _püro, čku_, _хад_
  { {0xc0e60404,0x0dcb0001,0x3f8c00b3,0xf194005e}},	//   _подк, чуни_, sudu_, _риль
  { {0x81b70008,0x41170015,0x63a801c2,0xbfd40058}},	//   _נהוג_, _كينج_, _kpdn, _ليتع
  { {0x672b002e,0x1fa30033,0xdcef0045,0x6e20007c}},	//   ylgj, _брыг, escă, ümbr
  { {0x9f970008,0x7f830029,0x5ae70015,0x6df50058}},	//   _נדחה_, _إلين, رثأف, _لكبا
  { {0xfeb80074,0x6aad003e,0xdcf6002c,0xe331006f}},	// [f4b0] _سايت_, reaf, _zvyč, účiť_
  { {0x8a440015,0xec6b004a,0x718b000a,0xcdf8000a}},	//   ائِم, _эрик_, לְבַ, _רמזי_
  { {0x6c5600f3,0x7d0701a3,0xcc56000a,0x4758005e}},	//   _ביתא_, mijs, _בבתי_, ерія_
  { {0xb6020089,0xa6ab0015,0x7d075db6,0x4b7a000a}},	//   _čárk, ثائق_, lijs, _קארו
  { {0xe7300029,0x2a7600a3,0xe44e006b,0x7cf00123}},	//   حصل_, _בערך_, иж_, _hära
  { {0xf4840124,0x2a6900e8,0xed580008,0xd6180015}},	//   гућн, lbab_, עבור_, رتنا_
  { {0x23b20029,0x94740086,0xd7f8006b,0xe4d6002b}},	//   لموس, ادها, _зут_, ضويت_
  { {0x6351003d,0xd24e0015,0x7d073f66,0x82f902be}},	//   _jāni, ينى_, hijs, برتز_
  { {0x7cf00123,0x7ae30045,0x0108002b,0xa5f80054}},	//   _lära, _întu, کتيو_, _зету_
  { {0xa2a1005d,0xf994000f,0x4206005e,0x81a40067}},	//   _कॉर्, ארץ_, тньо_, احيل
  { {0x12e70191,0x53a40029,0x27270020,0x7d0701a3}},	//   _підг, _مملك, sõnu_, dijs
  { {0xd35601d8,0x73090015,0x2cba00aa,0x929d002a}},	//   _סיני_, _تقصف_, _sapd_, miło
  { {0x7ceb0064,0x867a000a,0xdce40085,0xbe3a005e}},	//   _türl, וררו, _sviđ, ьчої_
  { {0x7d070796,0x7cf00123,0x2a69013c,0xe588000a}},	//   gijs, _bära, ebab_, עָרָ
  { {0xfc0308fc,0x5a960033,0xab2a4cf5,0x394a2529}},	//   апро, краф, дова_, _ribs_
  { {0xbea6000d,0x7cf00123,0x7a38001a,0x3b430015}},	//   _раик, _dära, _nútí, لَّف
  { {0xee3a0063,0xf9870015,0x6351003d,0xa92608e8}},	// [f4c0] _юни_, َنِي_, _dāni, вдал
  { {0xb95b0023,0x28d2005d,0xbc6a0086,0x7d070198}},	//   _trìn, साधि, _تمدن_, cijs
  { {0x9cd70135,0x6f04002a,0xdce40085,0x67224661}},	//   _סוטה_, _kmic, _uviđ, tooj
  { {0x6d4b0152,0x160a0015,0xf62a005e,0x5b57004f}},	//   _égar, وياً_, міли_, _ששכן_
  { {0x2c06005d,0x6b8300c0,0xf7490067,0x8e57000a}},	//   _हेतू_, _ångr, رجمه_, דינג_
  { {0x26cd000c,0x3dfb000a,0x4dfb004c,0xa7860015}},	//   _eneo_, ולנד, ופנא, _لشرو
  { {0x3cfa005d,0xccf3000a,0xe3a4002b,0x6f0402b9}},	//   _उतने_, שכו_, اشتی, _omic
  { {0xdb0f00dc,0x78bc5db7,0xf2c301f3,0x7d072f84}},	//   ődöt, _harv, асьн, zijs
  { {0xe5720029,0x7ceb0064,0xe3b80061,0x2b4011ff}},	//   _خطأ_, _sürm, _ayıt_, imic_
  { {0x30a30036,0x6f045db8,0x2b4000da,0x78bc10de}},	//   арюв, _amic, hmic_, _jarv
  { {0x8877000a,0xd0100015,0x213e00da,0x1eab0015}},	//   כתיב_, صلح_, rmth_, واحي_
  { {0x877b0008,0xfe700015,0x7d071892,0x69c65db9}},	//   ואטי, يدُ_, wijs, _orke
  { {0xf0b70074,0x442c0176,0x50b70086,0xa2f70008}},	//   رایش_, _hyd_, ردید_, _במאה_
  { {0x7cf00005,0x78bc5dba,0x4237000a,0x7ceb0012}},	//   _pära, _narv, _סנגל_, _türm
  { {0x0137000a,0xe451000a,0xa2b8000b,0x7d075dbb}},	//   _שרות_, מֶן_, ्यप्, rijs
  { {0x442c0026,0x7bc50263,0x7cf0007c,0x7af60034}},	//   _myd_, _vrhu, _vära, ghyt
  { {0xf99000e6,0x78bc0820,0x7d090003,0x23690085}},	// [f4d0] قبل_, _barv, éess, ćaji_
  { {0x78bc1647,0x7cf00123,0x690b002a,0x6cd50058}},	//   _carv, _härn, dżec, _إقدا
  { {0xec330086,0x8cd0005d,0x2c090086,0xf7700002}},	//   _خودگ, दारो, _سعدی_, قان_
  { {0xd6390010,0x98b90024,0x7cf000c0,0x96940036}},	//   нялі_, _pusē_, _järn, иріш
  { {0x78bc0134,0xa2b8000b,0x7bd80045,0x068402a3}},	//   _farv, ्यन्, ăbuş, ргін
  { {0x442c0176,0xb4bd000b,0x2d8b0125,0xa524008b}},	//   _byd_, इये_, irce_, амід
  { {0x442c0026,0x67d40ded,0x7aed5dbc,0xe81d0065}},	//   _cyd_, _кору, okat, _बँटा_
  { {0x5c380008,0x24890064,0x92b500e6,0x7aed5dbd}},	//   כרון_, şam_, احثا, nkat
  { {0xe0d10086,0x356b0484,0x75235dbe,0x3f9e001a}},	//   مزد_, _іран_, ponz, ettu_
  { {0x442c0026,0x239b0015,0x2ee00003,0x80650033}},	//   _fyd_, _يخضع_, _soif_, ывож
  { {0x6e360050,0x442c0176,0xf3f00015,0x7aed5dbf}},	//   _szyb, _gyd_, _وأم_, kkat
  { {0x52150036,0x6305002b,0x05c70065,0x41ae0065}},	//   _йдет, _حوصل, लिपब, _जैकस
  { {0x271800bd,0x2fd6002b,0xd00e002b,0x6eb3000b}},	//   nčna_, نوید_, قلی_, इज़ु
  { {0x7aed1424,0x417a000a,0x61e95224,0x0000006a}},	//   ekat, _טננב, myel,
  { {0x0136013a,0xc0580036,0x711a000a,0xb09a000a}},	//   _גרסת_, _річ_, _אוספ, _ניקר
  { {0x7cf000c0,0xfaf50036,0x7aed20fb,0x3f8a016e}},	//   _gärn, ачую, gkat, ábue_
  { {0x4a75008f,0x20b7005d,0x61e90849,0xddcf0011}},	// [f4e0] рыст, _असाध, nyel, racţ
  { {0x6729002c,0xb5fd002c,0x4a430902,0x6ea0000b}},	//   _akej, _rešp, снув, ग्रु
  { {0x60dc0b0f,0xdc9b00f3,0x1cb7000a,0x7e765dc0}},	//   örmi, _אייל, _גליל_, _keyp
  { {0x673b000c,0x6d56000c,0x7aed00c0,0x2fd80020}},	//   _chuj, _kuya, ckat, ärgi_
  { {0x78bc0c58,0x628600dc,0xe944002b,0x35d4004a}},	//   _tarv, ókom, _نرسی, ролё
  { {0x7ae304f9,0x3f9e0084,0xa2a1000b,0x7c290012}},	//   _într, yttu_, क्स्, ßerg
  { {0x74690036,0xe3b80061,0x7cf00123,0x734a0248}},	//   трів_, _ayır_, _läro, нчив_
  { {0x61fb0012,0x41b40067,0xe3af0015,0x6aa400aa}},	//   fzul, لمبر, سرى_, nfif
  { {0xdce40050,0x61e900dc,0x6ed8000b,0xe28f0015}},	//   _zwią, gyel, यानु, أذى_
  { {0x442c020a,0x43760080,0xa99b000a,0x04570015}},	//   _tyd_, _будт, עביר, _ملكة_
  { {0x3f15000d,0x7cf05dc1,0x33660001,0x44162c0c}},	//   идос, _pärn, _свег, _сфат
  { {0x69c400df,0x63ba0050,0x7ceb3cbf,0x57fb000a}},	//   kvie, _istn, _türk, תלטו
  { {0x91e60036,0x62870007,0x6d5604a5,0xc333004c}},	//   _щоде, ėjot, _cuya, _פונ_
  { {0x6d560064,0x7cf00123,0x69c45dc2,0x0000006a}},	//   _duya, _däro, dvie,
  { {0x69c40024,0x6abd002d,0x8aa7005e,0x66f4000b}},	//   evie, _pasf, лрад, _आतंक_
  { {0x7cf000c0,0x6d560003,0xddcd0045,0xae9b0015}},	//   _härl, _fuya, _ceaţ, _أضغط_
  { {0x3c120014,0x19950063,0xaa640080,0x7cf000c0}},	// [f4f0] tővé_, разя, стск, _kärl
  { {0x7aed5dc3,0xb0cd000b,0x271800bc,0xf9880015}},	//   skat, ़ाएग, včna_, انلي_
  { {0x7c2900b8,0xb8dd000b,0xcc76000a,0x6abd0061}},	//   ßerd, _आस_, _דעתה_, _tasf
  { {0x19950010,0xb8ec005d,0xf7700115,0x7c290061}},	//   _камя, _शो_, سام_, ğerd
  { {0x69c40023,0xb9e4005e,0x2d800003,0x356b006b}},	//   cvie, _ліри, _xvie_, хрен_
  { {0x7cf00123,0x271800bc,0xe795002b,0xfe38000a}},	//   _närl, rčna_, _پاسک, ארדי_
  { {0x3ea900e8,0xd91a000a,0x28d2000b,0xe2b50033}},	//   _obat_, _יושל, सारि, аспэ
  { {0xf3c80086,0x46580015,0xa2e53770,0x59c90065}},	//   ابوه_, _مؤكد_, роид, रिपर
  { {0xa2a1005d,0x20d50010,0x3f8c0003,0x63ba5dc4}},	//   क्ष्, аінс, erdu_, _estn
  { {0x60e6004a,0x61fb5dc5,0x3ea93bab,0x2d840046}},	//   имым_, rzul, _abat_, ámem_
  { {0x3dc9025c,0x8cd9005d,0x798d0a48,0x69c434cf}},	//   _araw_, मानो, hraw, zvie
  { {0x69c40321,0xfe46034e,0xed5a5b73,0x798d0cc1}},	//   yvie, инно, ком_, kraw
  { {0xde360010,0x2369016f,0x6d260029,0xddcd0045}},	//   рэнь, ćaju_, لعسك, _reaţ
  { {0x317f0064,0x3dc90495,0x798d437e,0x272e001a}},	//   msuz_, _draw_, draw, rýni_
  { {0x4a9a0010,0x8c4639e7,0xed43008b,0x273c412e}},	//   ктаў_, реве, інсп, líne_
  { {0xf1a9005d,0x6d564bbf,0x501a000a,0x69c45dc6}},	//   _कहान, _tuya, _שוקו, tvie
  { {0x0906008f,0x317f0064,0xb8560054,0x59760033}},	// [f500] апан, nsuz_, ађењ, рыбу
  { {0x7d7b000a,0x69c45dc7,0xdd7b004c,0x63b6002a}},	//   _שניו, rvie, _שטיל, łyni
  { {0x628600dc,0xd90d0086,0x69c45dc8,0x798d24a9}},	//   ókok, ریف_, svie, araw
  { {0x7c2900b8,0xd7ef0015,0x69c4003d,0x46a6106c}},	//   ßere, بكم_, pvie, радв
  { {0x28760802,0x994a0015,0x66030033,0xd6270054}},	//   _выбр, _للحل_, опца, аоце_
  { {0xed5901c9,0x96330033,0x7c290061,0x8cd9000b}},	//   íži_, цніц, şere, मायो
  { {0xd3770010,0x7cf000c0,0x2ca70064,0xd91b000a}},	//   ачы_, _närm, _önde_, _סולל
  { {0xf1a6008f,0x77bb0008,0x3878079c,0xd4090015}},	//   арон, _במלח, _herr_, دتهم_
  { {0xb5a90029,0xfaf7000a,0x9aeb000a,0x4153004a}},	//   _مالك_, יצקי_, דַיִ, овыс
  { {0x859b000a,0x5478000a,0x75d30015,0xe478000a}},	//   _בשמו, _תְּנ, _بيكا, _תָּש
  { {0x2718018c,0x7cf001d1,0x08570008,0x010a0086}},	//   nčno_, _värl, יבים_, فتگو_
  { {0x3dc9005c,0xd36f0086,0x7cf000c0,0x71a60010}},	//   _praw_, _آهن_, _därm, _вадз
  { {0xae01021e,0x8f100054,0x9345009a,0xe1f75dc9}},	//   _लेखन_, нaтa_, _اخلم, _кгц_
  { {0x3e750092,0x61430054,0xe092002b,0x7cf00c9e}},	//   ất_, _деча, _بیدخ, _härj
  { {0xead5004a,0x7cf001be,0x2378004f,0x31b60065}},	//   бовь, _kärj, טָּמ, _अनुध
  { {0x8e85003b,0x7cf00c58,0x3ea900d9,0x4a550010}},	//   _الظه, _järj, _ubat_, скас
  { {0x4c950063,0xd9990029,0x7cf0007c,0x7e7d5dca}},	// [f510] _липс, طنات_, _märj, masp
  { {0xd8790225,0x5cb90010,0x7cf00123,0xe84b0067}},	//   امات_, _слоў_, _lärj, نجان_
  { {0x9735002b,0x273c1945,0x40eb000a,0x25ad49e3}},	//   مکرا, zíne_, כַאֲ, _spel_
  { {0x798d0050,0x8aa70099,0x0000006a,0x0000006a}},	//   praw, _трод,   ,
  { {0xe56e0010,0x929d005c,0xe610002b,0xbb3a000a}},	//   яз_, siłk, وشه_, _תערי
  { {0x3f8300dc,0xdb07001a,0x43850015,0x1956004f}},	//   ájuk_, ðlæg, ملتق, _לבשל_
  { {0xf8b20008,0x13680054,0x7e7d5dcb,0x0000006a}},	//   _משם_, ашњи_, kasp,
  { {0x4c3c0008,0x32b90029,0x56941b88,0xfc18000a}},	//   כתוב, ادثة_, _маст, יקוי_
  { {0xc69200a3,0x7e7d007c,0x224b0123,0x2d8c002a}},	//   _מאן_, dasp, äck_, ądek_
  { {0x3959018b,0x9f4e0089,0xa3d7005d,0x317f0061}},	//   _muss_, ěním_, ामद_, rsuz_
  { {0x63f40029,0x64b3000b,0x7cf00123,0xe43500c3}},	//   _وأمر, ंजीश, _färj, _افاد
  { {0x1efa003b,0xe3b00029,0x613d0152,0x7cf000c0}},	//   اعدة_, _ترك_, dèle, _värm
  { {0xdce40050,0x01650124,0xa256013a,0xd256011f}},	//   _zwię, _укло, _הבנק_, _השנה_
  { {0x463a0053,0x9d46004a,0x563a004c,0xed57009f}},	//   טערע, сегд, טערײ, сор_
  { {0x7f85003b,0x6f950029,0xd9b2000b,0x7cf007c2}},	//   _البن, _العض, ुट्ट, _härk
  { {0x9ef6002b,0x7cf0008c,0x39595dcc,0xdb4f0058}},	//   _دستش, _kärk, _buss_, َّف_
  { {0x9f46275d,0x7cf00604,0x4efb000a,0x690b002a}},	// [f520] szló_, _järk, _תהפו, rżen
  { {0xa8560001,0xa3d7005d,0x98560001,0x23a1005c}},	//   стај, ामा_, сташ, kój_
  { {0x2d825dcd,0x3878001a,0x0000006a,0x0000006a}},	//   lske_, _verr_,   ,
  { {0xf7290191,0x271800bc,0xf74316d7,0xe9a60c02}},	//   ацій_, rčno_, пехо, _ламп
  { {0xa2b8000b,0xb0b7000b,0xf1b6000b,0xf4860033}},	//   ्यस्, _असंग, _अनइन, буйн
  { {0xb8f60029,0x26c02508,0x6ab6001a,0x2d825dce}},	//   _اكسب, žio_, leyf, iske_
  { {0x976400ce,0x7cf0142c,0x7ae65dcf,0x0000006a}},	//   цiєю_, _pärj, _kokt,
  { {0xfbd30008,0x2d825dd0,0x0000006a,0x0000006a}},	//   לתו_, kske_,   ,
  { {0xe4520086,0x2d82060b,0x60f803fc,0x865b000a}},	//   _فضا_, jske_, иния_, _תדמי
  { {0x60f70010,0x3ae70020,0x7e7d00e8,0x2d820263}},	//   йныя_, _lõpp_, wasp, dske_
  { {0xe4d70074,0xd8db0053,0x12880086,0xdeb50139}},	//   _دولت_, אקיר, _نمای_, обны
  { {0xf8370008,0x7ae60064,0x690b005c,0x2d820263}},	//   מנית_, _nokt, eżel, fske_
  { {0x290a003f,0x2d8202de,0x7e7d5dd1,0x3c4301d3}},	//   _omba_, gske_, rasp, kévé_
  { {0xc19b0008,0x2a7901c2,0x3c430030,0x39595dd2}},	//   _עשוי, _sesb_, jévé_, _russ_
  { {0x3cfa000b,0x307b0643,0x7ae60804,0x2d821922}},	//   _उतरे_, _גאונ, _bokt, aske_
  { {0x2f970008,0x6017000a,0x7d6b005e,0x7bc75dd3}},	//   _הכהן_, _לחוף_, _йшов_, rvju
  { {0x49bb0086,0xceb4004c,0x7ae61a70,0x2d820030}},	// [f530] دازد_, _זיפ_, _dokt, cske_
  { {0x4ddc0008,0x7cf000c0,0xfe7f0003,0x6f0f1d57}},	//   _תחזו, _närh, laï_, licc
  { {0xe7b50115,0xddc6002a,0xf7b9012e,0x205705bd}},	//   تماد, zakż, ргеј_, ציאל_
  { {0x6be8000a,0x96350296,0xfe7f16c3,0x8f9b004f}},	//   _הַשַ, онец, naï_, ריאי
  { {0x1a9a0053,0x23a1005c,0x85a70001,0xc58b004a}},	//   _דירע, wój_, сјед, ущее_
  { {0x80b7000b,0x7d7c000a,0x9554002b,0x690b002a}},	//   _असें, רנגו, سخها, ożem
  { {0x7ae60064,0xf7940010,0xdcfd0024,0x7b060030}},	//   _yokt, _нарэ, lusē, _úttö
  { {0x65950036,0xddc40024,0x23a1002a,0x01650004}},	//   _мабу, _reiž, rój_, окио
  { {0x44290050,0xc175002b,0xd24e002b,0x6f0f1eeb}},	//   ła_, زگشت, نچه_, dicc
  { {0x9f851921,0x2d8201a3,0x0876004c,0x75070054}},	//   огод, vske_, ֿערט_, _уџбе
  { {0xef1a0429,0x273c5dd4,0x0000006a,0x0000006a}},	//   имо_, lína_,   ,
  { {0x7cf0022d,0xdcfd0024,0x2f5403e7,0x93fa000a}},	//   _tärk, kusē, ятьс, _דלעי
  { {0x23850024,0x2d845dd5,0xa2b8000b,0x7cf00123}},	//   lēj_, éme_, ्यर्, _häri
  { {0xdbc7002e,0xc0cb0001,0xa0695dd6,0x2d822d0f}},	//   töðv, _људе_, _така_, rske_
  { {0xf0b80074,0xcfa8002b,0x60c3008c,0x7d0e5dd7}},	//   _دانش_, _هايم_, _ianm, ribs
  { {0xed5a13ab,0x60080008,0x2d820735,0x7f76000a}},	//   _кои_, _לִפְ, pske_, _ועקב_
  { {0xdb050134,0x99f60033,0x6ab6001a,0x7ae600cb}},	// [f540] _ophæ, цяві, reyf, _vokt
  { {0xfc320015,0x7188000a,0xcb0a009a,0xf93609a0}},	//   _يحد_, מְעַ, _چيدن_, іхаю
  { {0xba760029,0x68e71e80,0x7cf00f3a,0x07a31923}},	//   _واحت, _dojd, _näri, дахн
  { {0x27e701d1,0x7c960086,0x4c3b0008,0x7ceb43bc}},	//   änna_, _اشکا, _כתיב, _fürs
  { {0xf5b60225,0xe7370010,0xef13000a,0x1604000b}},	//   تصاد, цец_, וּס_, _शेखर_
  { {0x75d30029,0x628f005c,0x23c5000b,0x7ceb0061}},	//   بيها, ócon, विंद, _hürr
  { {0xbcfb0152,0x9cdb000a,0x3c8b000a,0x6eca0065}},	//   mpét, יקספ, שָׂ֑, ियाँ
  { {0x60c30991,0x1af70053,0x7cf000c0,0xd6d20015}},	//   _aanm, ַמיל_, _däri, _تقر_
  { {0x79840026,0xa3b6000b,0x2cb80079,0xd5d60015}},	//   nsiw, _छनक_, kerd_, _بتأث
  { {0x60c30026,0x889a000a,0x79840034,0xa3b5000b}},	//   _canm, ׁבִי, isiw, _चैक_
  { {0xb4b6014e,0x3cde005d,0xdfd40010,0xdfd000e5}},	//   ज़ी_, खाने_, чоны, ريح_
  { {0x74130002,0x26c6003f,0xcf270015,0xb1e60015}},	//   _توما, ndoo_, ترخي, _وأشه
  { {0xa3b4000b,0xdced0085,0x2cb815e7,0xdbc7007c}},	//   फ़िक_, _svađ, ferd_, nööv
  { {0x2cb827f7,0x9f4e0046,0x60c30034,0x63670061}},	//   gerd_, ěnám_, _ganm, _fınd
  { {0x2611000b,0xc334000a,0x8026002b,0x6f0f23ac}},	//   _देनी_, ֤וּ_, _برشم, picc
  { {0xc334000a,0xda0c000b,0x628058a0,0x2f18004a}},	//   פוּ_, _सेहत_, namo, _мощь_
  { {0x68e700bd,0x3eb93010,0x8d770015,0xf1bc000b}},	// [f550] _pojd, mest_, _باعا, ्टिन
  { {0x2d990005,0xa2cc005d,0x8b080089,0x3eb921f6}},	//   muse_, _दोस्, _pořá, lest_
  { {0x6569018b,0x2d990005,0xb06500f2,0x62805dd8}},	//   _steh, luse_, lkää, kamo
  { {0x95d90080,0x2d99003e,0x41da000b,0x62805dd9}},	//   йдет_, ouse_, बमास, jamo
  { {0x443e0014,0x2d990005,0xb06500f2,0xd4690fbd}},	//   _azt_, nuse_, nkää, биле_
  { {0x7cf00005,0xcd980008,0x3cde005d,0xe4c203a9}},	//   _päri, קדות_, खाये_, ейши
  { {0x59c9005d,0xad1c0008,0x628000da,0x3eb95dda}},	//   रिवर, בוגר, famo, kest_
  { {0x66b40080,0x7cf000f2,0xb06500f2,0x3eb95ddb}},	//   _обсу, _väri, kkää, jest_
  { {0x443e0014,0x3eb90100,0xe4d70015,0x93240015}},	//   _ezt_, dest_, _وتطب, برون
  { {0x2d995056,0x6f0d5ddc,0xf5aa0089,0xdb1e1909}},	//   duse_, _amac, ížeč_, _espè
  { {0x2cb80111,0x60c3016f,0x2d995ddd,0x62800896}},	//   verd_, _vanm, euse_, bamo
  { {0xdce400bd,0xf43a0008,0x2d990493,0x7cf00209}},	//   _vtič, _התעש, fuse_, _järv
  { {0x2d990005,0x60c30251,0x733a0053,0x2cb80111}},	//   guse_, _tanm, _פענס, terd_
  { {0xb6060107,0xa3cf000b,0x3ea001c2,0x6f0d36f5}},	//   _ukáž, शिप_, _wcit_, _emac
  { {0xdce4016f,0xc4d2000a,0xa021007c,0x8d76002b}},	//   _utič, עגל_, ööde, _کابا
  { {0x7cf01307,0x61340251,0x3eb90939,0x2d995dde}},	//   _närv, vàli, cest_, buse_
  { {0xc3320008,0x5eeb0008,0x7e9b000a,0x4efb000a}},	// [f560] תון_, _הַיְ, _הספו, _להקו
  { {0x4999005f,0x79840176,0x63ad005c,0x26c418e6}},	//   ются_, rsiw, łany, _samo_
  { {0x628b060b,0x3c77000a,0xfc5b000a,0x8cd9000b}},	//   _odgo, _מתים_, _לכימ, मारो
  { {0xe73a005f,0xe5c60080,0xcff60008,0x79840026}},	//   щее_, зско, הצעה_, psiw
  { {0x2718018c,0xbcfb0d92,0x62800f14,0x4a57000a}},	//   nčni_, mpér, vamo, _משכל_
  { {0x7ae45ddf,0x3f8500c5,0xb4b6000b,0x9e49000a}},	//   ljit, kslu_, ज़े_, חֲצִ
  { {0x660200dc,0x26c4016f,0xb900000b,0x25a65de0}},	//   szok, _tamo_, था_, stol_
  { {0x7af600df,0x7ae4016f,0x11d80015,0xc298004a}},	//   nkyt, njit, قوبة_, цких_
  { {0xc0ca0054,0x7af60091,0x59cf000b,0x67230030}},	//   буне_, ikyt, _हज़ार, énje
  { {0x2d990005,0x3eb90a25,0xb46500c3,0x62805de1}},	//   vuse_, west_, _قدمه, samo
  { {0x6f1d02c1,0x645a0134,0x3eb95de2,0xdb1e1649}},	//   érco, _igti, test_, _espé
  { {0x2d991c23,0x38170008,0x1eab0029,0xb06500f2}},	//   tuse_, לקים_, حادي_, tkää
  { {0x3eb95de3,0x7ae40085,0xe731004f,0xc305009a}},	//   rest_, djit, דֵם_, _تبلو
  { {0x3eb91c23,0x91bb0008,0x2d995de4,0x7c290012}},	//   sest_, _למדי, ruse_, ßero
  { {0x6e2403af,0x2d990005,0x8fa30124,0x113b0008}},	//   _exib, suse_, _заје, _התגל
  { {0x80370008,0x2d994645,0x03d7000a,0x6f0d002a}},	//   _מנוע_, puse_, הולם_, _umac
  { {0xb9550063,0xa2a1000b,0x6e450058,0x2b495de5}},	// [f570] дващ, क्ट्, _تنظم, rmac_
  { {0xdb050012,0x98b80091,0x7bc1001a,0xa3cf0157}},	//   _sphä, _mirė_, ælus, शिम_
  { {0xaa590015,0x6f1d3e59,0xd1380073,0x0000006a}},	//   _ولدا_, onsc, ilą_,
  { {0x6f1d00b8,0x69cb0123,0x7cf00123,0x645a42bc}},	//   nnsc, åges, _däru, _agti
  { {0xd1380007,0x6f1d04de,0x7cf03c05,0x8557002b}},	//   klą_, insc, _värv, سیار_
  { {0xe5700029,0x89da000a,0x3f8552a1,0xe8550015}},	//   اطن_, _וחשי, yslu_, _ينحد
  { {0x3cde005d,0x68e3300b,0x6aad003f,0x69cd02de}},	//   खाते_, öndu, ofaf, lvae
  { {0xe299006b,0xd138002a,0x1ddd000b,0x7cf003c1}},	//   цаи_, elą_, ममात, _härt
  { {0x65941cf3,0xb145033d,0xf8d1000b,0x69cd005b}},	//   _пату, мнил, _सफाय, nvae
  { {0x271800bc,0x26c20030,0x6f1d08d5,0x0000006a}},	//   včni_, _ókor_, ensc,
  { {0x7cf00005,0x2611005d,0x7c290012,0xff261092}},	//   _märt, _देती_, ßerl, дмно
  { {0x7c2901e2,0x3f850084,0xa3bc000b,0x41b50015}},	//   ğerl, rslu_, ेटर_, _يمار
  { {0xbd36006b,0x98ba002a,0x3204002a,0xd138002a}},	//   дхвъ, ampę_, czmy_, blą_
  { {0x3e7c0023,0xf1bc000b,0x41250015,0x271800bc}},	//   ật_, ्टरन, _تفتق, rčni_
  { {0xe3a70015,0xfaa60033,0xd00e002b,0x6aad35dc}},	//   خر_, маво, _پلي_, ffaf
  { {0x765b0023,0xff260036,0xc052000a,0x9a1a0342}},	//   _nguy, _імпо, _בזו_, оюзу_
  { {0x7af60a6f,0xe8ea005e,0x1ea9002b,0xfe46024f}},	// [f580] rkyt, омад_, _رايي_, _юнио
  { {0xbcfb0152,0x4a4306b3,0x7af65de6,0xf7860015}},	//   spér, тнув, skyt, ِلاَ
  { {0xf989013a,0x8f7a0053,0x7cf00123,0xbdd6002b}},	//   שר_, ַנסק, _därt, _رآکت
  { {0xf8a90008,0x8cc6000b,0x29130f85,0x2005007f}},	//   יש_, ायको, aixa_, izli_
  { {0xe4e60036,0x4ead0053,0xd5b00087,0x2abb000a}},	//   дійн, מבאַ, افت_, _ומכא
  { {0x94aa005e,0x7cf00012,0x236a0054,0xd8b6002b}},	//   ітла_, _gärt, ојио_, _تمسخ
  { {0xec360053,0x7cf000c0,0x98a3009c,0x6b9c5de7}},	//   ואַר_, _härs, _шире, nurg
  { {0x5afb0053,0x7cf046df,0xa2d5000b,0x8afb004c}},	//   ַליצ, _kärs, भाग्, ַליז
  { {0x6ea5005d,0x7cf0007c,0x79960034,0x11d80015}},	//   _काबु, _järs, nryw, سودة_
  { {0x13b60058,0x79960416,0x60c80052,0x0000006a}},	//   _يصاح, iryw, uddm,
  { {0x24970086,0xd01000e6,0x656002f2,0x2897004f}},	//   _زنند_, الج_, _humh, ודין_
  { {0x6b9c0084,0x79965660,0xb3850015,0x6f1d0ccc}},	//   durg, kryw, _أجله, unsc
  { {0xe731000f,0x90e60015,0x6f1d0028,0x6b9c00aa}},	//   רֵי_, _يستن, rnsc, eurg
  { {0xa2b8014e,0x718b0008,0x2029002e,0x6560002d}},	//   ्यक्, _וְהַ, átið_, _mumh
  { {0x309b000a,0xb09b000a,0x63670061,0x961d003d}},	//   _ושומ, _ויור, _kına, _ieņe
  { {0xa3cf014e,0xc27b00b2,0xaf080029,0xcf270031}},	//   शित_, ַרבי, _يقوم_, _ترتي
  { {0x7996005c,0xdb0700dc,0xcb34006b,0x28a7004a}},	// [f590] gryw, ntjé, тетъ, дшег
  { {0x3eb2005c,0x7b670229,0xf1c80016,0x69cd1142}},	//   _zbyt_, _отме, _mỡ_, rvae
  { {0xf1c80016,0x3ce5001a,0x6b9c1fb5,0x69cd0601}},	//   _lỡ_, ölvu_, curg, svae
  { {0x7cf05de8,0x7afd5de9,0x690b0535,0x0000006a}},	//   _färs, _ulst, yżew,
  { {0xe578008f,0x6560375d,0xc9870015,0xd6180021}},	//   дзі_, _cumh, _تشجي, وتها_
  { {0xa3c30089,0x7cf0038a,0xf992000a,0x961d003d}},	//   _září_, _härr, _תרם_, _neņe
  { {0xe3b103c4,0x29110061,0xf486002b,0xf484008b}},	//   ارت_, _imza_, راوی, тучн
  { {0xf7720008,0x7cf00123,0xd3d80015,0x6441006f}},	//   _תקן_, _järr, ببها_, _vzli
  { {0x9f5202d5,0xf1c80092,0xa634005e,0x2b595dea}},	//   ází_, _cỡ_, _анті, _misc_
  { {0xca1a0008,0x89da000a,0xf1c80016,0xa3cf000b}},	//   לֵיכ, פחתי, _dỡ_, शिद_
  { {0xb4bd005d,0xd6d9005c,0x7996005c,0xc5140029}},	//   ेयी_, _siły_, zryw, _شبكت
  { {0x7b030020,0x59df000b,0xc2c50015,0x20182ea8}},	//   _jõud, नमार, _سيتي, úria_
  { {0xf1c80092,0x2005005c,0x76fa0053,0xa3d7000b}},	//   _gỡ_, szli_, פּטצ, ामक_
  { {0x6b9c5deb,0x0000006a,0x0000006a,0x0000006a}},	//   turg,   ,   ,
  { {0x1c390036,0x7cf000c0,0xf0920008,0xec160067}},	//   дять_, _särs, _ענה_, رورد
  { {0x7b030005,0x7996002a,0x7cf001bc,0xf412015b}},	//   _nõud, tryw, _pärs, אפל_
  { {0x39460010,0xe8fa1006,0x69cb0123,0xc89603ae}},	// [f5a0] енаг, пла_, ågep, ерењ
  { {0xe4f4005d,0x02bd005d,0x7cf00f38,0x28e0000b}},	//   _अवधि_, ्युन, _värs, नाधि
  { {0x7cf000c0,0x3958121a,0x6c7b000a,0x6d4e0012}},	//   _färr, _virs_, _מריד, mmba
  { {0xb5aa0015,0xab2a03ca,0x6f7a004f,0x46ea009b}},	//   كاتك_, _хома_, לְדו, яден_
  { {0xfa36002b,0x39585dec,0x6d4e5ded,0x163a0058}},	//   _سرحد, _tirs_, omba, أساة_
  { {0x63670064,0x98a40091,0xf1c80016,0x03c607f7}},	//   _sına, _ėmė_, _rỡ_, есим
  { {0xccf30008,0x02bd000b,0x03a30054,0x63670061}},	//   רכו_, ्यून, гијо, _pına
  { {0xc7d70008,0xdbcf002e,0x2611005d,0x6d4e0012}},	//   _אולי_, nþág, _देवी_, hmba
  { {0xc0ca0054,0xc1b70174,0xa1a70138,0x0000006a}},	//   пуне_, елых_, нтэз_,
  { {0xf1c80092,0xf993000a,0x7b03007c,0xdb070030}},	//   _vỡ_, נרת_, _tõug, rtjé
  { {0x7d1500dc,0xdcf60046,0x0000006a,0x0000006a}},	//   vizs, žbět,   ,
  { {0x6d4e0849,0x23fb000a,0x0326006b,0x33fb000a}},	//   emba, _מהבא, _яден, _מהבנ
  { {0x9df80063,0xbea40010,0x2b595dee,0x7d150030}},	//   енят_, ышэй, _risc_, tizs
  { {0x9ccb0010,0x2ca50030,0xef1f0061,0xc534000a}},	//   чыма_, üld_, snü_, דָֽה_
  { {0x653b0053,0x7d155def,0x69c648cc,0xec290015}},	//   פעלד, rizs, _aske, ذكرى_
  { {0x403b000a,0xa03b000a,0x3f9e5df0,0x6d4e1416}},	//   _מגוג, _מעופ, mutu_, amba
  { {0x7b030005,0x0f5800b2,0x3f9e5df1,0xd2b7000a}},	// [f5b0] _nõue, _איהם_, lutu_, עלמת_
  { {0xa3e0005d,0x58d90010,0x31bb000a,0xe787012f}},	//   दमा_, ьдзя_, הזמנ, еудо
  { {0x690b005c,0x2d8b5df2,0xdb0502de,0x3a39002a}},	//   dżet, lsce_, _ophø, _wysp_
  { {0x8f9b000a,0xb715006b,0x645e0091,0xbb76000a}},	//   ליבי, ъдещ, žpil, _שערו_
  { {0xfcab000a,0x3f9e007c,0xd5e80015,0x64a5021a}},	//   ִיֵּ, hutu_, فعون_, вала
  { {0x273c0092,0x26c9016f,0x2d8b14ce,0x2d995df3}},	//   hính_, žao_, isce_, irse_
  { {0x7c2900b8,0x6282016b,0x2611000b,0x8b0b000a}},	//   ßerh, _beoo, _देरी_, ּלִ֖
  { {0x0000006a,0x0000006a,0x0000006a,0x0000006a}},	//     ,   ,   ,
  { {0x2d8b0050,0xa2a2005d,0xa0bd0033,0x7aef5df4}},	//   jsce_, _गार्, ошнi, _moct
  { {0x3f9e003f,0xd12e0115,0x05190021,0xf065009b}},	//   futu_, يمي_, _غياب_, ъкоп
  { {0x52b50029,0xddc40011,0x14d6000a,0xd009006b}},	//   _لماذ, _ofiţ, _שועל_, фене_
  { {0x690b005c,0x52150461,0xa3b80015,0x62825df5}},	//   ożes, _идет, _سامر_, _geoo
  { {0xd6e8000a,0x929d002a,0xa2f6000a,0x78b5013f}},	//   תַתָ, chła, _שמנה_, _obzv
  { {0xdfa90018,0xed571f33,0x3f9e5df6,0x859a004f}},	//   _قطعه_, коя_, butu_, וששו
  { {0x7cf00123,0x70920004,0x2d995df7,0x6d4e0318}},	//   _därp, _тајф, arse_, rmba
  { {0x38c80074,0x7aef5df8,0x0000006a,0x0000006a}},	//   کاری_, _coct,   ,
  { {0xfd120029,0x690b005c,0x7aef16c8,0xc9aa0033}},	// [f5c0] _نجد_, jżes, _doct, ьвае_
  { {0xd884002b,0xd6a50033,0xe81a0058,0x0000006a}},	//   اهای, сiўн, وزات_,
  { {0xc8b50010,0x8b260033,0xca29004f,0x06862d88}},	//   ысты, _адне, קם_, вген
  { {0xa3d5000b,0x02bd0065,0x0000006a,0x0000006a}},	//   िटन_, ्योन,   ,
  { {0x6f1d0656,0x84e6005e,0x05b40015,0x3f9e002a}},	//   érci, кодж, امتح, zutu_
  { {0x3f9e0064,0xa53302e1,0x238c0046,0x68460317}},	//   yutu_, аніч, těj_, _анга
  { {0x69c4005c,0xd4f50010,0xf1ca002e,0x73c30029}},	//   lwie, ыяцы, kráð_, ليوم
  { {0x69c4005c,0xf5960015,0x44200045,0x7c290012}},	//   owie, _للرج, ăi_, ßeri
  { {0x44320050,0xcb13011f,0x7c290064,0xa697000a}},	//   ły_, ילה_, ğeri, _שכמה_
  { {0xa3cf014e,0x67220091,0x2018016e,0xda49000a}},	//   शिश_, lnoj, úrio_, עֲקָ
  { {0x889b0008,0x69c400b8,0x62820020,0x351b000a}},	//   וביי, hwie, _teoo, _קובנ
  { {0xadbd0033,0x753d003d,0xdcfd003d,0x69c40079}},	//   памi, _īszi, pusī, kwie
  { {0x2d994216,0xf194034e,0x67221cde,0x4106049d}},	//   urse_, _силь, inoj, _издв
  { {0x2d80005c,0x69c4005c,0xf6530008,0xbd450115}},	//   _dwie_, dwie, יצר_, انسي
  { {0xd2590024,0x7ceb00b8,0x0b88005e,0xa0070015}},	//   meņa_, _kürz, ксти_, _لقول_
  { {0x99800050,0x90570008,0x2cad0089,0xa057000a}},	//   dził_, _בסוף_, řed_, _בסוד_
  { {0x690b005c,0x79a7006b,0x3a840033,0x3ea9007f}},	// [f5d0] dżer, ърве, рысв, _icat_
  { {0xce380008,0x67220f28,0xb9240058,0x987400ce}},	//   _באחת_, enoj, لفقي, илуц
  { {0xccf20008,0x69c4005c,0xdc88000a,0xe10b000a}},	//   _הכי_, awie, _בְרָ, וּאָ
  { {0x07a4129a,0xf7940010,0x4758005e,0x8bd6000a}},	//   раїн, рацэ, врія_, _עורו_
  { {0x5a9a0008,0xa63413ae,0x1a9a0008,0x1a68002b}},	//   _אשרא, анці, _אירע, _شیلی_
  { {0xf7730015,0x6722008c,0xfbd0002b,0xdb1e01d3}},	//   _نار_, anoj, _اتی_, _ispá
  { {0x224600dc,0xb907000b,0xd259003d,0x273c0030}},	//   _azok_, भा_, deņa_, zíni_
  { {0x5c5c000a,0x32d40033,0xf366002b,0x72c507be}},	//   ודוק, ацьс, دئوی, убиз
  { {0x798d13e2,0xaaab000b,0x95d9006b,0x7888003d}},	//   nsaw, _छानक, _ядат_, būvē
  { {0xc1050015,0x5996004f,0xe3d70058,0x0000006a}},	//   اودي, נכתב_, _لتصع,
  { {0x69c4005c,0x53a40058,0xd37500af,0x0000006a}},	//   zwie, _نملك, _слећ,
  { {0x69c4002a,0x213e4a58,0x248535e2,0xf2d0009a}},	//   ywie, alth_, _helm_, _وآن_
  { {0xe0ce010f,0x6aa40971,0xd356000a,0x33580033}},	//   _лв_, vgif, _עיני_, _рацэ_
  { {0x621a0135,0x61d6000a,0xb8860046,0x62050061}},	//   _אונק, _תוסף_, otíž, ıtlı
  { {0xbc19005e,0x6c36002b,0x798d5df9,0x2259006f}},	//   віті_, افزا, esaw, ľsku_
  { {0x69c40050,0xdce40085,0xf3890016,0xf412000a}},	//   twie, _otić, iả_, צפן_
  { {0xf3890092,0x09e35dfa,0x4a4618c5,0xbb430a0b}},	// [f5e0] hả_, ботн, унав, сетк
  { {0xb6090024,0xcc3600e6,0x395c0123,0x69c4428e}},	//   iešķ, _مرجع, övs_, rwie
  { {0x6aa401d1,0x6f045dfb,0xb8cc000b,0x69c45dfc}},	//   pgif, _klic, _गा_, swie
  { {0xeafa0029,0xbc1b0053,0xdb9b000f,0x60c15dfd}},	//   _أردت_, _טויש, _אסטר, helm
  { {0xbf37004c,0x6d5e5dfe,0xceb3000a,0x60c15dff}},	//   נאנץ_, _kipa, מיא_, kelm
  { {0x60c1022d,0x6f040251,0xa3f40036,0xa7860031}},	//   jelm, _llic, иплі, _مشرو
  { {0x60c12913,0xe3af0029,0x6d5e003f,0x93930015}},	//   delm, كري_, _mipa, مجيا
  { {0xaa7b002c,0x3bbb0008,0xb7db000a,0x8bd7000a}},	//   _inýc, תמקד, _אקלי, רוקו_
  { {0x171b00b2,0x36f70008,0x7b030020,0xdced5e00}},	//   _נומע, _עצמם_, _jõua, _stač
  { {0x60c15e01,0x6f045e02,0xdced0046,0x91b700c3}},	//   gelm, _alic, _ptač, اطير_
  { {0xd36f0029,0x289b0053,0x2b4000bd,0x6f04079c}},	//   _فهل_, עיטא, klic_, _blic
  { {0x291a04f9,0x9f350036,0xa857000a,0xb857004c}},	//   hipa_, ремі, טייה_, טשיג_
  { {0x7b030020,0xada40010,0x7e280033,0x291a5e03}},	//   _nõua, баўл, гіра_, kipa_
  { {0x656f0152,0xed580010,0x6d5e5e04,0x2bd1000b}},	//   _éche, лоў_, _cipa, हिला
  { {0x6d5e013c,0x6f040876,0xd117000a,0x9be4008b}},	//   _dipa, _flic, _תקוה_, бітк
  { {0x543b0053,0x443e00d9,0xadf50ea6,0x6f045e05}},	//   געלא, _myt_, _впиш, _glic
  { {0x443e271c,0xeef8000a,0x7d1b0003,0xad27012c}},	// [f5f0] _lyt_, _תמחר_, éuss, _مردو
  { {0x6fa8005d,0x798d01d7,0x6f04002a,0x4a5418fc}},	//   _कमां, rsaw, _zlic, скус
  { {0xf770003b,0x443e5e06,0x2b405e07,0xdce40085}},	//   كان_, _nyt_, blic_, _stić
  { {0x1b7a0053,0x0c740086,0x7c2900b8,0x6d5e003f}},	//   _שטרע, _پدید, ßeru, _zipa
  { {0xa6840191,0x60c100dc,0x07080015,0xd5e5067a}},	//   слід, yelm, ديني_, ржли
  { {0x53a50015,0x29030085,0x039501b7,0x7aed5e08}},	//   لمتك, _ulja_, ария, ljat
  { {0x60c1001c,0xf3890092,0x9cdc0008,0x2bd8005d}},	//   velm, uả_, תקופ, डिया
  { {0xe6100086,0xf3890092,0x7aed5e09,0x41b53d93}},	//   _کشف_, rả_, njat, асот
  { {0x62890176,0xf4b60086,0x54a70225,0xb883002c}},	//   raeo, _چشمگ, _محاف, príč
  { {0xa2d5005d,0x6f040398,0x7aed0601,0x6f165e0a}},	//   _मोर्, _slic, hjat, _smyc
  { {0x60c117f7,0x4f260a0b,0x6d5e5e0b,0x7bc10061}},	//   relm, идоб, _ripa, çlul
  { {0x7f4d038d,0x56b50053,0x6d5e2286,0x9836000a}},	//   _chaq, ױפֿן_, _sipa, יטתו_
  { {0xc2c40029,0x63a33ce0,0x0dc70151,0xfaff00aa}},	//   _ديني, lunn, аляй_, _kiëf_
  { {0xdca603f1,0x4e960086,0xd656000a,0xc19a000a}},	//   јави, دشگر, יירת_, _ישני
  { {0x6d5e0ea4,0x8cc5000b,0x8cd8000b,0x7039004c}},	//   _vipa, ाज़ो, मयबो, _בײַצ
  { {0xff520086,0x7c3e0227,0xc058005e,0x2b4000da}},	//   _بخت_, _vypr, _січ_, ulic_
  { {0xdb070084,0x7c3e005c,0x6d5e2410,0x61fb0273}},	// [f600] ðmát, _wypr, _tipa, nyul
  { {0xc8e0005d,0x63a3094d,0x5dfb00f3,0x68464198}},	//   नाइट, kunn, _ספינ, анза
  { {0x485a0010,0xdc9b1c6f,0x4c9b009d,0xcd2900e5}},	//   траў_, _בסיכ, _בשיע, _حسين_
  { {0x7d1c0482,0x6fda0053,0x7aed005c,0x61fb0b63}},	//   lirs, כקעס, cjat, kyul
  { {0xfb370053,0xed590089,0x6286002e,0x86c30002}},	//   _כאטש_, ůže_, ðkom, زيون
  { {0x186a00d0,0x9553002b,0x63a35e0c,0x7d1c5e0d}},	//   _јави_, يخوا, funn, nirs
  { {0xdb0700dc,0xb4e6000b,0x64a30054,0xd4670054}},	//   ltjá, _बची_, цаја, шије_
  { {0x6448002c,0x7b030020,0x2348002b,0xdddd006f}},	//   _vzdi, _lõun, دستی_, lasť
  { {0xdb0700dc,0x443e0026,0xe0e60033,0x3253006b}},	//   ntjá, _wyt_, аўно, овър
  { {0x891e0053,0x7b030020,0x19b7000a,0x63a335aa}},	//   אָס_, _nõun, ספיר_, bunn
  { {0xd8d70053,0x64480085,0x653b000a,0x9f4d008c}},	//   בויט_, _uzdi, _יעמד, yydä_
  { {0xdb230061,0x6437000a,0x33fb000a,0x7e2b0033}},	//   ürüc, _דאבא_, _שהאנ, віга_
  { {0x7e2b0036,0x7e47007a,0x5757004c,0x1757000a}},	//   тіна_, рхне, יבטע_, יסטר_
  { {0x6fb40086,0xc0d30015,0xd0d30015,0x25ee000b}},	//   _همتا, _وينب, _وينظ, _आपनी_
  { {0x7aed5e0e,0x9b6800d7,0x6f940015,0x8fa30054}},	//   tjat, ишта_, _البض, _даје
  { {0x5f730086,0x905b0008,0x69ab0015,0x7aed1147}},	//   _باور, _בכות, َاءُ_, ujat
  { {0x9f53005c,0x6f1d19f7,0xa2a9000b,0xa3c8000b}},	// [f610] ńców_, misc, _टास्, _लैस_
  { {0x2611005d,0x7c2900b8,0x6f1d5e0f,0xd7fb0033}},	//   _देगी_, ßers, lisc, куе_
  { {0x8e380086,0x96750010,0x3ebe00dc,0x7aed0046}},	//   _مسیر_, былі, őtte_, pjat
  { {0xb8fe014e,0xec36013a,0x7bda0008,0x6f1d5e0f}},	//   _दो_, _לאתר_, _עקרו, nisc
  { {0x5887008f,0xb4650086,0x2611005d,0x76400026}},	//   _выба, مگاه, _देखी_, _cymy
  { {0xa5f60124,0x63a30c8d,0x6f1d059b,0x27e70123}},	//   сељу_, tunn, hisc, änns_
  { {0xc9520008,0x6f1d00b8,0x63a300f2,0x07a40033}},	//   _ממך_, kisc, uunn, _маён
  { {0x9725002b,0x63a35e10,0xcb12000a,0xe784110d}},	//   _افرو, runn, ּ֜ה_, _фуро
  { {0x76400026,0x6f1d5e11,0x320d0061,0x20d5008b}},	//   _gymy, disc, uzey_, бінс
  { {0x69da0053,0x7e640034,0x25bf0045,0x60e907f8}},	//   אַטו, _sgip, _ipul_, умом_
  { {0x10150010,0x6f1d237b,0x7d1c5e12,0xcdc9000a}},	//   сьпя, fisc, virs, _רך_
  { {0x6f1d19f7,0x7c380293,0x33980015,0xc7ba000a}},	//   gisc, _øvri, _ضخمة_, נצרט
  { {0x2d84038d,0x2f550191,0xa3cf021e,0x6d260015}},	//   ème_, ютьс, शिक_, معسك
  { {0xa3ab005d,0x6f1d002d,0xb23a004c,0xd37e0085}},	//   कंप_, aisc, _גענז, šćen_
  { {0x656103af,0x7d1c5e13,0x6f1d5e14,0x59a50065}},	//   _milh, rirs, bisc, गूसर
  { {0x8bc5008f,0x6e960029,0xdb0700dc,0x64410870}},	//   ўсёд, _الظا, ttjá, _myli
  { {0xf2d20053,0xe9da044e,0x7cf00012,0x09e30138}},	// [f620] הען_, ыка_, _märz, потн
  { {0xdb0700dc,0xb4e6005d,0x088a0015,0xe8f71923}},	//   rtjá, _बचे_, اناً_, блу_
  { {0x7c290061,0x76400034,0x64410a3a,0xdb07001a}},	//   şerr, _symy, _nyli, stjá
  { {0xdd8f0086,0x7b030020,0x76a90036,0x064a0015}},	//   _توی_, _jõul, итів_, هلاً_
  { {0xd6270010,0x99d60029,0x65615e15,0x85b70015}},	//   боце_, _اتجا, _bilh, ماوس_
  { {0x68f500bd,0x96330010,0x18670461,0x8b65002b}},	//   _gozd, чніц, _гари_, _دایم
  { {0xd499005e,0xc7a3005e,0x7640002a,0x753800bc}},	//   ррі_, _нирк, _wymy, rovz
  { {0x64410bc8,0x93930015,0x1b7b004c,0x929d002a}},	//   _dyli, أجوا, נטפע, ykłe
  { {0xe29f0084,0x65615e16,0x32020264,0x599a000a}},	//   óða_, _filh, áky_, אשִׁ
  { {0x656f0152,0x6f1d00b8,0x09f7000a,0x20ca0054}},	//   _écha, wisc, צמים_, ућио_
  { {0x6f1d2259,0x32020057,0x61e40091,0x25a60034}},	//   tisc, šky_, _šild, luol_
  { {0x71a60010,0xb7db000a,0x8cbb000b,0xadd9004a}},	//   _гадз, אקטי, श्नो, амму_
  { {0x644100b8,0x6f1d5e17,0x71fa0015,0x78bc2389}},	//   _zyli, risc, _حراس_, _obrv
  { {0xd1300029,0xd2570008,0x3ead005c,0x6f1d5e18}},	//   _تمت_, _השדה_, żet_, sisc
  { {0xb4fb0135,0xe398000a,0x798600da,0x6f1d5e14}},	//   נפלי, יֹּש, _awkw, pisc
  { {0xae9b0029,0x9aa50015,0x80250067,0x0000006a}},	//   _إضغط_, تمرو, _برهم,
  { {0x98e50029,0x68f540ef,0xdce60061,0x0000006a}},	// [f630] يكرو, _pozd, arkı,
  { {0xb882002c,0xc8670080,0x99840015,0xad9b0030}},	//   _šírk, стаи, سلمو, szús
  { {0xf84b03fc,0x29014d63,0x98f40058,0xd8740058}},	//   учай_, rkha_, أثقا, سالب
  { {0x17f80029,0xd7580029,0x95d9004a,0x8c440045}},	//   حركة_, مجنا_, идет_, ăşti
  { {0x6561016e,0x7b2c0061,0x64413adc,0x7e9c004f}},	//   _pilh, oğun, _syli, רסדו
  { {0x73990004,0x64410091,0xe3c50015,0xa3d50065}},	//   атис_, _pyli, قْتَ, िटल_
  { {0x3cfc000a,0x8cbb000b,0x0516006e,0x65615e19}},	//   רפוב, श्यो, تيوب_, _vilh
  { {0x8c1c0135,0xd2510015,0xe3b60033,0x65615e1a}},	//   טווי, ونغ_, ібы_, _wilh
  { {0x2d9e005c,0x644109bf,0x05740015,0x82350015}},	//   ątek_, _wyli, _فالد, غربا
  { {0x161f000b,0xc1050015,0xdb070123,0xdcf6003d}},	//   _मेयर_, زوجي, ltjä, īcīb
  { {0xd8d8004c,0x1ee8002b,0x78ba0030,0xceea02b0}},	//   מוזט_, مودی_, _ötve, адне_
  { {0xc7d60008,0x69dd0026,0xcce9000a,0x8708000a}},	//   קורי_, _orse, _בכ_, ֶּרֶ
  { {0x200300bd,0xee37042b,0x9dba0033,0x82370067}},	//   šji_, жня_, шыну_, _ارضا
  { {0x865a000a,0xd256000a,0x9e630033,0x3eb9001a}},	//   ידרי, _ושנה_, ьвяд, afst_
  { {0xdb0700c0,0x69dd20e2,0x69cf0e35,0x913a004c}},	//   ktjä, _arse, _asce, _דעסק
  { {0x28ac005d,0x0b46017f,0x1a2a0608,0x8a06005e}},	//   _चाहि, інан, ажби_, озбе
  { {0x628b0014,0xad9b00dc,0x3b07017a,0x8d760087}},	// [f640] _mego, szúr, цето_, _بابا
  { {0xbca60029,0xa8a60058,0x98a31c80,0x628b5e1b}},	//   _بمدي, تصرو, дифе, _lego
  { {0x69dd00b8,0x6299005c,0x69cf07dd,0x3136004c}},	//   _erse, _odwo, _esce, קנעם_
  { {0xb5aa0029,0xe73a0080,0x25a60026,0x628b38f7}},	//   لاتك_, шее_, tuol_, _nego
  { {0x64450005,0x186a005e,0x7ae60546,0x0000006a}},	//   ühin, _ваги_, _inkt,
  { {0x33980029,0x34f30033,0xb603006f,0x3a15004a}},	//   منتج_, мпіё, úšan, _хьюс
  { {0x261a005d,0x628b2a9a,0xe6c60015,0xdb1e0003}},	//   _मेरी_, _bego, _وتري, _appé
  { {0xc3d50010,0x63670030,0xe7371114,0x628b059d}},	//   яўчы, _bűnb, _дес_, _cego
  { {0xc0c60001,0xe5770004,0x33170058,0x628b5e1c}},	//   ољни, _мзт_, تزود_, _dego
  { {0xe452002b,0xe506012c,0x301407d0,0x0000006a}},	//   _قضا_, _ببري, здор,
  { {0xf1f7002b,0x436a0663,0xc3060058,0xa2d50065}},	//   معیت_, _таен_, _وبصو, _मोक्
  { {0x628b2dcc,0x51860788,0x0000006a,0x0000006a}},	//   _gego, _дука,   ,
  { {0xc69304dc,0xe0cf0086,0xd4910016,0xde64006b}},	//   ואר_, رزی_, _hòa_, дърп
  { {0x224b04de,0x24f4000a,0x10160015,0x9f6a00ce}},	//   ücke_, הֶֽם_, _وبغد, _криз_
  { {0xcb1b000d,0xb6030046,0x0b5b0015,0x307b000a}},	//   аќа_, _zmáč, لشرب_, _דאונ
  { {0x929d005c,0xb882002c,0x539b05bd,0x639b000a}},	//   okła, _šípk, יסלא, יסלנ
  { {0x5d840029,0x2eaa004c,0x44290016,0xd99b0015}},	// [f650] _قليل, _השפּ, ̃a_, ؤخرا_
  { {0xaa7b002c,0xd8b80015,0xc87b0054,0x7ae60073}},	//   _iným, قدما_, рџа_, _enkt
  { {0x6d470198,0xd7fb000d,0xf8680015,0x7b03007c}},	//   mlja, јуз_, زمني_, _jõuk
  { {0xae02000b,0x87280033,0xcc56000a,0xef67000a}},	//   रैकन_, оўча_, _מבתי_, קֹב֙_
  { {0x628b02d7,0x2a760008,0xef140053,0x7edc0053}},	//   _rego, _מערך_, וּװ_, יקאצ
  { {0x628b08e0,0xdb0700c0,0x4a5a000a,0xf9fa000a}},	//   _sego, stjä, _לדרו, _ההשמ
  { {0x7b030005,0xe4c80029,0x84580063,0xe7330115}},	//   _nõuk, زبون_, орът_, _قصر_
  { {0x1616005d,0x656f0152,0x6aad5e1d,0x8cbb000b}},	//   _देकर_, _écho, ngaf, श्तो
  { {0x91b00092,0x25700144,0x6d470b28,0x63670030}},	//   _đại_, _gàl_, klja, _bűnc
  { {0xa3bb0002,0x65150015,0x6d470030,0x94740015}},	//   _ناصر_, _عوائ, jlja, _قدما
  { {0x78fc0053,0x929d005c,0xd12e0015,0x1755000a}},	//   יפזו, akła, امٍ_, ּסָר_
  { {0x91f70029,0x6d475e1e,0x60180033,0x2f2f002a}},	//   _وأشا, elja, іцэр_, tęga_
  { {0x28ac000b,0xed5a0681,0xa227006e,0x9e1e0033}},	//   _चालि, йом_, _براه, учнi
  { {0x91f60008,0x2d9e12c3,0x25ee000b,0x7188000a}},	//   _ממנו_, čte_, _आपसी_, _וְקַ
  { {0x3eb100f2,0x5ea60015,0x207a004c,0x4a9a0033}},	//   ältö_, _فمثل, _פאקא, йтаў_
  { {0x7e9a0029,0x63ae0134,0xe9df002d,0x5ffa000a}},	//   _انظر_, _åbne, _brú_, _להצה
  { {0x6d470198,0xc332000f,0x63a30264,0x7c3b0061}},	// [f660] blja, גון_, hrnn, ğura
  { {0xcdb7000a,0x3c94002b,0xfe37000a,0x672b0e05}},	//   _צפיה_, _زیرز, _מרפי_, engj
  { {0x78a3002e,0x929d005c,0x3cfb000a,0xacfb000a}},	//   ónva, zkła, _הלינ, _ההיכ
  { {0x60c8005c,0x929d005c,0x248c0089,0xf1bd000b}},	//   zedm, ykła, _sedm_, ्बान
  { {0xa4d40036,0x94d4009b,0x0000006a,0x0000006a}},	//   долі, долц,   ,
  { {0xb4d6014e,0x672b1b8e,0xe38a02ed,0x0000006a}},	//   िये_, angj, бщил_,
  { {0xf214005d,0x9989005c,0xdc9b0008,0x279520d1}},	//   _तेज़_, czał_, ציקל, _оштр
  { {0x33970015,0x7bdb000a,0x71740067,0xe7b7004f}},	//   أخوة_, מקצו, وهبا, _מהלר_
  { {0xd5280092,0x7996005c,0x67220007,0xe5a314b5}},	//   _cộn, nsyw, mioj, _пити
  { {0x6722229a,0x79fb0008,0xf487002b,0xd5280016}},	//   lioj, צליח, _فامی, _dộn
  { {0x6d47065d,0xc4d30008,0xe1ef0086,0x547b000a}},	//   vlja, _רגע_, نسی_, _הטבו
  { {0xd017008f,0x67220091,0x7d1e0147,0x39d20065}},	//   яфы_, nioj, _amps, सिफ़ि
  { {0x660200d9,0x6ce70036,0xa2f7000a,0x6d470b28}},	//   nyok, піве, _ממאה_, tlja
  { {0xeb05005d,0x41530036,0x7b03007c,0xed590091}},	//   रस्त_, _звіс, _tõuk, įžo_
  { {0x00bb0008,0xcc540063,0xc3340008,0x6d470085}},	//   _המומ, евръ, ֥וּ_, rlja
  { {0x6722003f,0x5bb80080,0x395a1e83,0x213e219f}},	//   jioj, ялся_, emps_, loth_
  { {0x6d470263,0xd357000a,0x5ed4002b,0xaa580342}},	// [f670] plja, לילי_, _ستيز, зиту_
  { {0xb4d6014e,0xb17b000a,0x58d40342,0xc8c90015}},	//   ियो_, צטבר, ноут, توطن_
  { {0xf6d50036,0x06990029,0x6f0d5758,0xacfc000a}},	//   діля, قناة_, _klac, _להזכ
  { {0xd4910023,0x9989005c,0xe9df1f94,0xb065008c}},	//   _còn_, rzał_, _trú_, ljää
  { {0x9989002a,0xd5bb09b1,0xe9df0125,0x4974134f}},	//   szał_, ссе_, _urú_, _пляс
  { {0xd5280092,0x04450004,0x1dde000b,0x6f0d5e1f}},	//   _rộn, мелн, मितत, _llac
  { {0x6f0d01e2,0xcc78000a,0xdc9c000a,0x0000006a}},	//   _olac, הגות_, זיול,
  { {0xd2a9004a,0x442400c3,0x07090015,0x36d4144f}},	//   цкие_, عروف, _بيري_, _поср
  { {0x59e0000b,0x51920015,0x44b5007e,0x35fb002b}},	//   नियर, نليذ, _обас, _ارزد_
  { {0x6f0d5e20,0xa2bd000b,0xf1d2000b,0x2ee95e21}},	//   _alac, _वॉर्, तिजन, _anaf_
  { {0x6f0d0276,0x1eca0a0b,0x75480030,0xb8eb00fd}},	//   _blac, олни_, őszá, ркiн
  { {0xe1f10029,0xf43a000a,0xe607002b,0x02450058}},	//   _لست_, _ותעש, نش_, _قَضَ
  { {0x6f0d005c,0xee3a022a,0x8e55005e,0xbe3a005e}},	//   _dlac, інг_, етрі, ючої_
  { {0x6025023e,0xcb6a0c53,0x333f30f8,0xc105006e}},	//   _одла, жаве_, loux_, _زوبي
  { {0x7fd50036,0x6f0d5e22,0xdc670180,0x8c431673}},	//   _цілі, _flac, дард_, вере
  { {0x6f0d4393,0xac07005e,0x333f0003,0xbebb00aa}},	//   _glac, єнта_, noux_, liën
  { {0x2d950010,0x8d560036,0x5eeb000f,0x189a0015}},	// [f680] _прэс, _оточ, _וַיְ, قضاة_
  { {0xbd46002b,0x66020573,0x7996002a,0x7c390003}},	//   _زنجي, vyok, rsyw, ébré
  { {0xc66a03ae,0x8b960033,0xd7ca0015,0x2ee90034}},	//   ошле_, _ўроч, تواه_, _ynaf_
  { {0xa3e1005d,0x7bdb000a,0xcff6000a,0x464a017a}},	//   दिन_, _וקטו, וצעה_, озен_
  { {0x67220007,0x3871002d,0x333f266b,0x6d5c12a8}},	//   rioj, íorú_, doux_, omra
  { {0xd37a047d,0x67220d91,0x94d30033,0x9f5f01c0}},	//   очи_, sioj, коіц, ryté_
  { {0x68fc5e23,0x2927006f,0xbebb0079,0x18a30b1e}},	//   _iord, ývať_, diën, _јасм
  { {0xc2980001,0x11d80015,0xdb08008c,0x47d30015}},	//   чких_, كوبة_, _äläk, _جيفر
  { {0x68fc5e24,0xc4c60015,0xd4c60058,0xb065005b}},	//   _kord, _يتطو, _يغطي, yjää
  { {0x15fb000a,0xba57000a,0x45fb000a,0xbebb0079}},	//   _והמע, וספו_, _והמג, giën
  { {0xb4bc005d,0x68fc5e25,0x6f0d5e26,0x3f980227}},	//   ेजी_, _mord, _plac, éru_
  { {0x9f50002e,0x01da0015,0x3f64004a,0x63a50046}},	//   ðaða_, _ووضع_, ктяб, áhne
  { {0x2f02002e,0xe0da004a,0x68fc165c,0x02bc000b}},	//   _nógu_, _мвд_, _oord, ्जीन
  { {0xbebb0111,0x23c2000b,0x2bbb0015,0x68fc0881}},	//   ciën, _शहाद, يازة_, _nord
  { {0xb0650e95,0x6f0d0b7e,0x7ff30015,0x251b000a}},	//   rjää, _tlac, _لسيا, קולא
  { {0xc9870001,0x8f9b000a,0xb06505ff,0xbdb50054}},	//   дужи, _ויהי, sjää, _збиј
  { {0x7e6d0020,0x5a350063,0x65680125,0x60d80061}},	// [f690] _igap, хнат, _oidh, _kavm
  { {0xba540001,0x64450020,0x25a60026,0x68fc5e27}},	//   твуј, ühik, drol_, _cord
  { {0xf7700806,0x18a40036,0x752300b8,0xec150015}},	//   لان_, таєм, vinz, _أوجد
  { {0x25a60026,0x65680125,0xd61b0015,0x61e25e28}},	//   frol_, _aidh, يتشا_, _orol
  { {0x6568003f,0x1ae40010,0x7afd5e29,0x68fc5e2a}},	//   _bidh, _роўм, _iost, _ford
  { {0x19b601e4,0xa3bd000b,0x7afd0b9d,0x68fc5e2b}},	//   _אפשר_, ेबल_, _host, _gord
  { {0x61e20176,0x7afd5e2c,0xd4660054,0x24090342}},	//   _arol, _kost, нише_, янки_
  { {0x7afd00f2,0x64480007,0x61e25e2d,0x25a65e2e}},	//   _jost, _dydi, _brol, brol_
  { {0x6d5c0026,0xbebb0079,0x569401c5,0x61e25e2f}},	//   ymra, tiën, _шатт, _crol
  { {0x2b405e30,0x7afd29b2,0x7e6d5e31,0x61e25e32}},	//   zoic_, _lost, _agap, _drol
  { {0x7afd0161,0x2d995e33,0x68f80123,0x64480034}},	//   _oost, esse_, övdi, _gydi
  { {0xbebb00dd,0x7afd5e34,0x93270015,0x6da615d5}},	//   siën, _nost, _غران, нима
  { {0xbd360063,0xe716000a,0xd00e002b,0xa3ab0157}},	//   ехвъ, תחרר_, للی_, कूर_
  { {0x53990008,0xd196000a,0x361a000a,0x7afd5e35}},	//   ּיּו, _טכני_, לורד, _aost
  { {0x7afd2bd7,0x9f520030,0x7d030015,0x1be70973}},	//   _bost, ázó_, دِّه, ндри_
  { {0x7afd19cf,0xab2a0033,0x20050091,0x68fc5e36}},	//   _cost, чоба_, myli_, _sord
  { {0x4a750010,0x2b400f21,0xc9aa0033,0xcf57000a}},	// [f6a0] тыст, roic_, явае_, _אבקת_
  { {0x290e002e,0x38c80086,0xf7860015,0xc7960088}},	//   ófa_, باری_, ّلاَ, ерды
  { {0xcd02005c,0x68fc45c0,0x32040bba,0x25a60034}},	//   ęść_, _vord, zymy_, wrol_
  { {0x68fc05d6,0x65680f8b,0xa96a006b,0x25a65e37}},	//   _word, _sidh, _нима_, trol_
  { {0x6f1d0251,0xd6d9005c,0xd4910092,0x45d40076}},	//   èrci, _dał_, _bè_, толс
  { {0xfe370053,0xb4bc005d,0x9f59002d,0x7afd066f}},	//   ערסי_, ेजे_, árú_, _zost
  { {0xa3ab005d,0x3d08000b,0xc8c6000b,0xb8660015}},	//   कूल_, _सकने_, _रॉयट, _ساسو
  { {0x18670036,0x64940007,0x61e2424b,0x77bb000a}},	//   _часи_, džių, _prol, _ממלח
  { {0xcb130008,0xe7371c35,0xe1f20015,0x63670030}},	//   טלה_, _чет_, اسع_, _tűnn
  { {0x60f80036,0x859b000a,0x64485e38,0x61e20079}},	//   єння_, _משמו, _tydi, _vrol
  { {0xb3e90029,0x2d8001c2,0x7b03007c,0x69b2000b}},	//   _يعمل_, _atie_, _kõut, इंडी
  { {0xbebb0111,0x61e225e7,0x7b03007c,0x290f003d}},	//   ciël, _trol, _jõut, īgai_
  { {0xc333000f,0x7afd270d,0x2d995e39,0x61e20c10}},	//   _גוף_, _rost, usse_, _urol
  { {0xd24f003b,0x3ea00556,0xe0d3023e,0x7afd5e3a}},	//   _انه_, _edit_, _бошњ, _sost
  { {0xf093000a,0x8ae700fd,0xf8b1002b,0xb434000a}},	//   _ענק_, ніал, یکس_, דָּו_
  { {0xa3e1014e,0x7b030020,0xdb500029,0x28c6000b}},	//   दित_, _nõut, مَّ_, _रॉबि
  { {0x7afd5e3b,0xe29f002e,0x9f5f00dc,0xa8a710a0}},	// [f6b0] _vost, óði_, sztó_, ерек
  { {0xd8740015,0x7c38016e,0xdb070046,0x6d450573}},	//   هامب, çarã, mují, _ukha
  { {0x28150074,0x5695005f,0xf0930053,0xad1c000a}},	//   خواس, вает, רנע_, _מוזר
  { {0xc747002b,0xf7840015,0x5d84002b,0x7afd2888}},	//   رضاي, النَ, _جلیل, _uost
  { {0x5e9c00b2,0x2005005c,0xdb070046,0xe578005e}},	//   לבאק, zyli_, nují, езі_
  { {0xf992011f,0x7c340064,0xfaff00dd,0x2005008c}},	//   _דרך_, _çerç, _hoë_, yyli_
  { {0xdb070089,0xdce500bd,0xd8e40033,0xe6890015}},	//   hují, _nihč, _сцяп, _ينسى_
  { {0x67d4005e,0xdb070046,0xc3d40033,0x0000006a}},	//   _щосу, kují, уўшы,
  { {0x26cf005c,0xdb070046,0x61e40125,0x28c6000b}},	//   mego_, jují, _áill, _रॉडि
  { {0xdb0702d5,0x6009111b,0x41020080,0x26cf5e3c}},	//   dují, дном_, изыв, lego_
  { {0x7b030005,0xc9520008,0x61ed20db,0x69d80065}},	//   _jõus, שמי_, _šald, _नैनी
  { {0xe290040b,0x26cf0050,0x27e700f2,0x26dd0012}},	//   _هذه_, nego_, änny_, ndwo_
  { {0xc332013a,0x531a000a,0x00e3002b,0xc692004c}},	//   _דוא_, _קונצ, _متغی, סאך_
  { {0xa3b5014e,0x98ba0024,0x0000006a,0x0000006a}},	//   _जमा_, kopā_,   ,
  { {0x7b030005,0x0c3a0015,0xdb0704b2,0x8c4617b6}},	//   _nõus, ذكرة_, aují, теве
  { {0x3f8504f9,0x26cf0050,0xdb070046,0x273c04b2}},	//   mplu_, jego_, bují, bíny_
  { {0x26cf005c,0xdb070046,0x28960054,0x092a0015}},	// [f6c0] dego_, cují, вјес, وسطي_
  { {0x3f850061,0xfb82002b,0x0000006a,0x0000006a}},	//   oplu_, _نگری,   ,
  { {0x26cf016e,0xd9450015,0xdde9002b,0xf71a0033}},	//   fego_, ائقي, _قریه_, міды_
  { {0xd7ef0029,0x6d4e02d2,0xec37000a,0xf7190033}},	//   تكم_, llba, _יאיר_, нічы_
  { {0xdb1e0050,0xe76900e6,0x05d30015,0x6d4e5e3d}},	//   _wspó, رحمن_, لزوج, olba
  { {0x2458004e,0xdb0e02ad,0x0000006a,0x0000006a}},	//   наль_, stbä,   ,
  { {0x67310014,0x25ee005d,0x94230001,0xdb070089}},	//   ókjá, _आपकी_, имље, zují
  { {0x26cf0050,0x61d803ad,0x6d4e0012,0x42e30033}},	//   cego_, емия_, hlba, ацьб
  { {0x05662b43,0x527300af,0x0000006a,0x0000006a}},	//   _аван, шују,   ,
  { {0xf9930008,0xdb070089,0xdb1c002a,0x9f5f0046}},	//   סרת_, vují, owró, rytí_
  { {0xd007019c,0xf8b3000a,0xb4ae000b,0x6e950098}},	//   веќе_, בשת_, कली_, лину
  { {0xb2260080,0xc7b30008,0x25a90844,0x6d4e189b}},	//   _имел, סבר_, šale_, elba
  { {0x5bcb000b,0xf044002b,0x91960054,0x51f6002b}},	//   ाब्व, ضعگی, _рјеш, _جسار
  { {0xed58008f,0x26cf005c,0xdb070046,0xbfba006e}},	//   коў_, zego_, rují, _قطعا_
  { {0x212b0152,0xac19017c,0xdb070046,0x26cf1d0d}},	//   èche_, хову_, sují, yego_
  { {0xdb070089,0xdb1c4265,0xfb3401b0,0x9e070033}},	//   pují, ntrè, ансэ, _ачол
  { {0xaa55000d,0xba5500d0,0x3df4004a,0x61e40085}},	// [f6d0] уваш, увај, _взыс, _šilj
  { {0x26cf0050,0x2bab005d,0x31bb000a,0xf807006b}},	//   wego_, _छिपा, וזמנ, кчен
  { {0x26cf0050,0x3d08005d,0xdb07002e,0xb8cb000b}},	//   tego_, _सकते_, ðmót, _गय_
  { {0x59f90063,0xdb0700dc,0x473504f7,0x26cf0077}},	//   _земя_, ntjü, ынес, uego_
  { {0xdb1e0084,0x3f5200dc,0xe6100087,0xe9470010}},	//   _uppá, dául_, يشه_, _ахво
  { {0x7b030020,0xe7950086,0x7544042b,0xf5760015}},	//   _tõus, _مارک, аніз, دموع_
  { {0xf8b20008,0x03940010,0xe7870292,0x2cfc004c}},	//   _לשם_, арыя, _југо, ולגא
  { {0xf1b7000b,0xfc58000a,0x78790030,0x0000006a}},	//   _आमदन, כבוש_, _fúvó,
  { {0xd4c70015,0xc692000a,0x68b5000a,0x62890651}},	//   _لغاي, _לאן_, ְלֹא_, rbeo
  { {0x28c6000b,0x6604007c,0xe00e000b,0xf519000a}},	//   र्पि, äike, ानंद_, _אֵ֣ל
  { {0x28ab005d,0xb4470010,0xf1d8000b,0x63c20046}},	//   _चयनि, _рэак, _बैठन, ěvní
  { {0x7b0a01c0,0x0000006a,0x0000006a,0x0000006a}},	//   _výuk,   ,   ,
  { {0xa0c50086,0x929a000a,0xe29f001a,0x471a000a}},	//   _ميشو, _ניסת, óðu_, תורג
  { {0x9d5603c4,0xdb1c002a,0x6458002a,0xb8030065}},	//   انست, ywró, ściń, लहाम_
  { {0xf0920008,0xc0c80001,0xdb1c0003,0xcff4002b}},	//   _פנה_, _јуче_, ltré, _نيوک
  { {0x28c6000b,0x0000006a,0x0000006a,0x0000006a}},	//   र्नि,   ,   ,
  { {0x7f3b0053,0x6aab002d,0xdb1c45f4,0xb9960015}},	// [f6e0] _רעפו, ógfa, ntré, الطب
  { {0xe9d704ab,0x61e621f0,0x61e40073,0x0000006a}},	//   ыку_, åkli, _šilk,
  { {0x7c950010,0x66e65e3e,0xa686011a,0xcbfa0058}},	//   _трыц, ложа, глед, _أرخص_
  { {0xd6d90036,0xcc8a002b,0x07450033,0x2f2f002a}},	//   кті_, _تنگه_, ахім, tęgi_
  { {0x6a9b000f,0xf7170015,0x25790144,0x6c9a000a}},	//   _אשכנ, دينغ_, _cèl_, ֲשֵׂ
  { {0xb4ae000b,0x6ab60034,0x2f2f002a,0x23b40015}},	//   कले_, lgyf, ręgi_, لمتس
  { {0xc7d8000a,0x9f4b0030,0xe3c30015,0x9cd7000a}},	//   _בַּכ, őjét_, مْوَ, רוצה_
  { {0x6ab60026,0x7b03007c,0x3f52001a,0x660d0030}},	//   ngyf, _jõup, fáum_, önké
  { {0xc4ca006b,0x64b600c3,0x61140e4d,0xc11401ca}},	//   _плаж_, _محار, идиу, имиј
  { {0x46130015,0xe424002b,0xa3e1000b,0x6ab60034}},	//   _اوكر, _پکتي, दिश_, hgyf
  { {0x58f70053,0x61e70024,0x8cbf000b,0xc8c6000b}},	//   אמיע_, ājla, _लॉगो, र्यट
  { {0xa3e1005d,0x03d7000a,0x80c5000b,0x7b03007c}},	//   दिर_, _תואם_, ़्बे, _nõup
  { {0xe29b0053,0x3fc8002b,0xa2d30015,0xddcd002a}},	//   _טשאר, ردگی_, _دينت, _szał
  { {0x61db0008,0x28c6005d,0x30760180,0x69d60034}},	//   _נקוד, र्मि, _судс, dwye
  { {0xdc19002a,0xdfa60058,0xab9500af,0x636701d3}},	//   _ołąc, _إحتي, рабљ, _bűnh
  { {0x7f830029,0xc214000a,0xd5d40157,0x3f9e0fff}},	//   _الين, ֑הּ_, _धनंज, mstu_
  { {0x3f9e5e3f,0xbf34002b,0x28c6000b,0xadd50054}},	// [f6f0] lstu_, _دروغ, र्भि, _топљ
  { {0xd2570008,0xb9c40029,0x0a6805c8,0x9693005e}},	//   רשמה_, إقلي, урси_, _бiля_
  { {0xccf20008,0x6d471b2e,0x87071092,0x69d600da}},	//   _וכי_, moja, ляде, awye
  { {0x3f9e5e40,0xbd88002b,0x25790144,0x6d475e41}},	//   istu_, _جنین_, _pèl_, loja
  { {0xdb070084,0x4a9a0053,0xaa9a000a,0xd6270015}},	//   stjó, _בירג, _בברכ, دعاي
  { {0x63a50089,0x290f0024,0x3f9e5e42,0x7d7c0053}},	//   áhno, īgas_, kstu_, ענוו
  { {0x9992005c,0xd7e408fb,0x98c40033,0x62860061}},	//   czył_, _літо, _усял, ıkon
  { {0x2903441c,0xdc0f0046,0x81f50015,0xdb1c0003}},	//   _hoja_, _něče, لأخط, ttré
  { {0x2903010b,0x92e80029,0x71590010,0x6d470c80}},	//   _koja_, طريق_, крос_, koja
  { {0x64450020,0xbfc5000d,0x95570015,0x0fc50c71}},	//   ühis, абок, _إخرا, айон
  { {0x6d4718a6,0xdb1c0152,0x2903516e,0x3f9e5e43}},	//   doja, stré, _moja_, gstu_
  { {0xf3b600b2,0x29033a96,0xb8390033,0xcfd20015}},	//   _כּדי_, _loja_, элiг, آيَة
  { {0x28c6005d,0x7ff5002b,0x6b850125,0x3f9e2f68}},	//   र्डि, _چسبا, _athg, astu_
  { {0xed5a0001,0x2d84003d,0xafe50aa1,0x9f5f013f}},	//   тог_, īme_, _вокл, rytá_
  { {0x8fc40086,0x6a960036,0xab2a059c,0xace70054}},	//   _هزين, ирає, вова_, јмса_
  { {0xfb160015,0x25a02ed8,0x6a860bb1,0x2d9613d6}},	//   جورج, šili_, рлаа, _крос
  { {0xe9da0063,0x38760001,0xea000092,0x2903049f}},	// [f700] ъка_, аћет, _trật_, _boja_
  { {0x69d60034,0x0c26005e,0xae5b000a,0x98a63da0}},	//   rwye, _вмон, _בכפר, риже
  { {0xcd36002b,0xdc8b000a,0x63670030,0x1dde0065}},	//   _مرگب, _בְכָ, _tűnh, मिकत
  { {0xeab20806,0xfc570008,0x9992005c,0xcb9b000a}},	//   _بعد_, _כביש_, rzył_, _בסטט
  { {0x6f04005c,0x45d60063,0x9992005c,0x25a0002d}},	//   _moic, рцет, szył_, éil_
  { {0xdc190050,0xa4d402e1,0x6f04002d,0x3f9e001a}},	//   _włąc, сокі, _loic, ystu_
  { {0xa5070180,0x28c6000b,0xf8c6000b,0x6f160123}},	//   реја_, र्णि, र्णय, _olyc
  { {0xb7db000a,0x25a929e3,0x31c608a0,0x61ed1ffb}},	//   _בקלי, šala_, асов, _šala
  { {0x28c6005d,0x7d01002e,0xd2570036,0xf8c6000b}},	//   र्थि, ölsk, иць_, र्थय
  { {0x30a30036,0x55bb000a,0xdce50045,0x50660b44}},	//   орюв, _בממו, _mihă, итна
  { {0x1957000a,0x3f9e0046,0xd3e4002b,0x6f160034}},	//   שביל_, ustu_, _دقای, _blyc
  { {0x28c6014e,0x3f9e5e44,0x5f27029b,0x41e602a3}},	//   र्ति, rstu_, рфоз, _віка
  { {0x6d47571f,0x6f0401b5,0x12fb000a,0x2ee001c2}},	//   toja, _doic, _שהדב, _daif_
  { {0xfd470010,0x6d4745d8,0x40940015,0xd657000a}},	//   рэмн, uoja, _الثر, ייכת_
  { {0x9f5900dc,0x29031967,0xda7b0033,0x1fa30033}},	//   áró_, _roja_, вяз_, _дрыг
  { {0x200f0f1b,0xc214000a,0xc334000a,0x3a755e45}},	//   íliš_, ֖הּ_, צוּ_, слар
  { {0x212c002d,0x0cab0004,0x7bda001a,0x2903007c}},	// [f710] oidh_, _итни_, ætur, _poja_
  { {0x6cd50074,0x3eb9002e,0x7d240015,0x2f2f002a}},	//   _اقدا, lgst_, _وفين, ręgu_
  { {0x161f000b,0x28c6000b,0xfd58004c,0x2d8b00bc}},	//   _मेजर_, र्धि, _דשזי_, lpce_
  { {0xd6390010,0x35f50484,0x501b000a,0xa3ea000b}},	//   лялі_, йпер, כובו, मिन_
  { {0x200c0034,0x7c3b0061,0x0f58004f,0xd6d800af}},	//   hydi_, ğuru, ביאם_, ртх_
  { {0x28c6005d,0x86c50086,0x9f5f00f2,0x03950063}},	//   र्दि, _گيرن, lytä_, брия
  { {0xd7f50033,0xa506006b,0x232900f4,0xa7d40058}},	//   _узвы, сеща_, локи_, _وتفص
  { {0xec380008,0x5c38009d,0x23760015,0x212c0125}},	//   יאור_, יטוב_, حميد_, eidh_
  { {0x212c002f,0x93240115,0xdb1e0123,0x9992002a}},	//   fidh_, ترون, _uppå, czyń_
  { {0x6f04002d,0x4222004a,0x2ee03be3,0xdb07019a}},	//   _soic, ядыв, _saif_, lujä
  { {0x6f0404ed,0x201e0091,0x2011451a,0x24550058}},	//   _poic, gzti_, ázi_, _اناس
  { {0x212c002f,0x69dd151c,0xf456000a,0xdb240061}},	//   aidh_, _osse, _היער_, ürür
  { {0xd5f900b2,0x6f041873,0xd356000a,0xc0e50a31}},	//   נפֿר, _voic, _פיני_, _голк
  { {0x307900b2,0xd5fa0008,0x4d390080,0x0000006a}},	//   _גאַנ, אפשר, аяся_,
  { {0x6729018c,0xb09a039e,0x69dd4a58,0x1d07006b}},	//   _omej, _עיקר, _asse, щери_
  { {0x673b016f,0xc052000a,0xfaf5005e,0x9f481112}},	//   _njuj, _מזו_, очую, _orné_
  { {0xdb070020,0x69090052,0x0000006a,0x0000006a}},	// [f720] dujä, _nþes,   ,
  { {0x6729003f,0x6299051e,0x7c960248,0x0000006a}},	//   _amej, _lewo, _уриц,
  { {0x409a0053,0xb09a0053,0x69dd052a,0xa156000a}},	//   רבעס, ריער, _esse, צבעה_
  { {0x7bde016f,0x99560024,0x63ae0134,0xb8ef000b}},	//   _ispu, _kļūs_, _åbni, _वॉ_
  { {0x86c3006e,0xa50a2124,0x7986002a,0x449800f4}},	//   سيون, леда_, _utkw, авлю_
  { {0xe0c70029,0x8e57000a,0x69c45e46,0x79730015}},	//   _عز_, זינג_, mtie, _رُفض
  { {0xe73a000d,0x61eb232a,0xf3ca0015,0x889b000a}},	//   _бев_, _argl, ابته_, _תבלי
  { {0x11d80029,0x521403ad,0x32440015,0x7ae452fa}},	//   لوبة_, ждит, ينغف, ndit
  { {0x3a2000b8,0x69c45e47,0x64a65e48,0xeab1000a}},	//   nzip_, ntie, _газа, וֹי_
  { {0xf8d8005d,0x7ae40706,0x89db000a,0xe5050015}},	//   ड़िय, hdit, נחיי, _وبلي
  { {0x705403c4,0x32ca03be,0x69c400f2,0x645a0024}},	//   تندا, _было_, htie, _uzti
  { {0x61e40007,0x3e070063,0x7ae40cca,0x93f7000a}},	//   _šilu, бягв, jdit, _לצבא_
  { {0x201e00dc,0x2d8b0fde,0x9e340033,0x7ae41ff9}},	//   szti_, upce_, зеяч, ddit
  { {0x301a0015,0x91bb004c,0x7b2c0061,0x3a200125}},	//   _متعة_, _עמוי, uşun, dzip_
  { {0x69c40048,0xd1382aad,0xb09b000a,0x8aa7005e}},	//   etie, mną_, _גיור, йрад
  { {0xd13814f5,0x28c6000b,0x8037000a,0x3b5500fd}},	//   lną_, र्सि, _לנוע_, ікар
  { {0x69c43267,0x7b2c0061,0xd1381e7f,0x7bde1f4a}},	// [f730] gtie, mşul, oną_, _espu
  { {0x63410024,0xd138005c,0x67290844,0x7ae401bc}},	//   mēne, nną_, _smej, adit
  { {0xb901005d,0x7b2c0064,0x47d500e5,0x80ca000b}},	//   _दस_, oşul, تيار, त्ये
  { {0xf655000d,0xbebb0079,0x46150021,0x69c45e49}},	//   овеќ, ciët, يوار, btie
  { {0xd24604b6,0xf8a90074,0x69c40298,0xf7700031}},	//   _آن_, _نگاه_, ctie, رام_
  { {0xd138005c,0x09f6000a,0xd0060021,0x25a920a3}},	//   jną_, _ומשם_, _قل_, šalo_
  { {0xd138005c,0xd3f90033,0x9f600030,0x6498005e}},	//   dną_, рэлі_, őség_, стір_
  { {0xd1380007,0x9c180008,0x13090142,0x41a90286}},	//   eną_, מחוק_, рний_, авин_
  { {0x11d60015,0x28c6000b,0xe6050015,0x65942850}},	//   قوية_, र्वि, _بِذَ, _нату
  { {0xd138002a,0xe125005e,0x3ea95e4a,0xd5c8004f}},	//   gną_, імни, _adat_, _לֶעָ
  { {0xf8b20008,0x69c40024,0xb4d5000b,0x5f750015}},	//   ושי_, ztie, िजी_, غادر
  { {0xd5a70036,0xd138005c,0x21f50015,0x798d02f2}},	//   _вiдп, aną_, _وكاس, kpaw
  { {0xd138005c,0xa3ea021e,0xa3e1000b,0xfe46008b}},	//   bną_, मिथ_, दिक_, інго
  { {0x3f660152,0x3ea90251,0xd138002a,0x3b960004}},	//   _cœur_, _edat_, cną_, жјат
  { {0x61e90945,0xb3a9000a,0xdb1c39a9,0x7f850015}},	//   lvel, יֹּ֙, strí, _بلبن
  { {0xa3ea014e,0x7ae41efc,0x6f1d00b8,0x6ec1000b}},	//   मित_, udit, chsc, _वायु
  { {0xf2d20632,0x61e4002d,0x0906017a,0xfce65e4b}},	// [f740] וען_, _áilt, опан, _допо
  { {0xb8560001,0x1089000a,0xe8f72556,0xad9b0077}},	//   ођењ, שָּֽ, олу_, ayús
  { {0x28c6005d,0x97a5005e,0x7bde0085,0x69c4399c}},	//   र्षि, зріл, _uspu, stie
  { {0xd138005c,0xdb1c0011,0x85ea05ab,0x61e95e4c}},	//   zną_, strâ, идев_, kvel
  { {0xd1381256,0xe5a307f7,0x35f70058,0x0000006a}},	//   yną_, дичи, قرود_,
  { {0x28c6014e,0xbebb016b,0x61e95e4d,0x0000006a}},	//   र्शि, niër, dvel,
  { {0xb8fe000b,0x2cfb004c,0xd3770033,0x96ba005e}},	//   ढ़_, ילסא, очы_, _вузу_
  { {0xf1a618a9,0xe73a0063,0xd138005c,0x28c6000b}},	//   орон, _теб_, wną_, र्रि
  { {0xd138005c,0x61e95e4e,0xdb0e0030,0xd13a098a}},	//   tną_, gvel, ltbó, ихо_
  { {0x4fc60080,0x09f7000a,0xa3ea000b,0xef20002a}},	//   осма, קמים_, मिद_, óżni_
  { {0x6f1d002f,0x287b0008,0xdb0e00dc,0x187b0008}},	//   thsc, ינימ, ntbó, יטיב
  { {0xd138005c,0x3f660152,0xd12f002b,0x3f670033}},	//   sną_, _sœur_, _یمن_, ўтоб
  { {0x63750007,0x224b00b8,0xbebb0159,0x63b80057}},	//   _išna, ückt_, fiër, luvn
  { {0xad670015,0x91bb000a,0xc16f005e,0x4c840033}},	//   تاجه, _כמדי, _ії_, длёв
  { {0xc04f02e5,0xd0100015,0xc046002b,0x63670030}},	//   _ці_, _سلة_, _بخشو, _tűnt
  { {0xdb500029,0xdb071faa,0x4f670015,0x0000006a}},	//   نَّ_, frjá, _باتف,
  { {0xd9990058,0x0000006a,0x0000006a,0x0000006a}},	// [f750] صنات_,   ,   ,
  { {0x29070084,0xda080015,0x28c6000b,0x657b008c}},	//   ðna_, غيله_, र्लि, _ruuh
  { {0xbf780016,0x61e9046f,0x97a705b5,0x082802ed}},	//   _đuợc_, zvel, юрал, оцци_
  { {0xdb07002c,0x0057000a,0x3057000a,0x61ed1c4e}},	//   hujú, חשבת_, חשבך_, _šalm
  { {0xbafa0008,0xd6180115,0x8afa000a,0x9afa000a}},	//   _ההרש, يتها_, _ההרי, _הפרח
  { {0xb97a0008,0x03951654,0x2db8000a,0x2ddc000a}},	//   _לנשי, прия, קלון_, שַׁב
  { {0xdb07032c,0xc9520008,0x8ccd000b,0xc6d70015}},	//   dujú, _נמל_, द्यो, _وترت
  { {0x11d9003b,0xdc3c0008,0xd3d80015,0xcc3c000a}},	//   موعة_, יעור, تبها_, יעוט
  { {0x94ab0029,0x7bc70030,0x61e95e4f,0xdb1c5e50}},	//   _نطاق_, htju, uvel, ntrá
  { {0x61e93812,0xc5fe003d,0x44b4025f,0xdb07006f}},	//   rvel, ķēta_, _обус, gujú
  { {0x63f40015,0x7bc70030,0xdee60299,0x61e95e51}},	//   _يأمر, jtju, пони, svel
  { {0xd00e0029,0xd2510029,0xba3b00dd,0xdb1c0107}},	//   الَ_, _كنا_, _geïg, ktrá
  { {0xee370036,0x427a0008,0x5f75002b,0xe3a7002b}},	//   зня_, _האנג, _کاتر, کر_
  { {0xc0e5004a,0xdb07006f,0xf1b90e1d,0x1d190342}},	//   _хокк, cujú, muš_, оюсь_
  { {0xb09a000a,0xab1a056d,0xbebb08cf,0xeb97008a}},	//   _היצר, бцах_, riër, зис_
  { {0xdf290015,0xbebb0547,0x0000006a,0x0000006a}},	//   _وأين_, siër,   ,
  { {0xdebb0008,0x61ed016f,0xbebb0111,0x3b070608}},	// [f760] _המפל, _šalj, piër, чето_
  { {0xdb1c0144,0xddcd0085,0x63a4003d,0xdb0e0030}},	//   strà, _ugaš, ņini, ttbó
  { {0x7ceb000a,0xbc7b000a,0xe73a575c,0x6c7b004f}},	//   _הַכֶ, _לנית, беж_, _לאיפ
  { {0xb5aa003b,0xdb07002c,0xdd8f0086,0xdb0e00dc}},	//   ماتك_, zujú, _جوی_, rtbó
  { {0x5fdd005d,0x7ae6156a,0x59830033,0x9f6301d3}},	//   _फैसल, _iakt, _пляб, évén_
  { {0xec36000a,0xdb07006f,0x6d4e4f9f,0x07a61b5d}},	//   ּאֵר_, xujú, noba, _нагн
  { {0xdb07006f,0xdc89000a,0xccf3004f,0x7ae65e52}},	//   vujú, חְפָ, תכו_, _kakt
  { {0xa6b50080,0x883b0008,0xf3630010,0x6d4e0c0b}},	//   _осущ, _התלו, нтын, hoba
  { {0xd4d60010,0xcad700f3,0xf743057e,0x63b80107}},	//   _ніжэ, לוקת_, _чето, suvn
  { {0xf55a0029,0x75d30018,0xf993000a,0x7ae65e53}},	//   _الطب_, _سيما, ערת_, _lakt
  { {0xdb1c5e54,0x03a60004,0x645e007c,0xdb07006f}},	//   ztrá, _ѕидо, üpid, rujú
  { {0x3f8a0048,0xc7b30008,0xde590010,0xdb1c0134}},	//   ību_, עבר_, жамі_, ltræ
  { {0x925a0015,0x4ea40033,0xdb07006f,0x25a65e55}},	//   _اشار_, эрэа, pujú, nsol_
  { {0x6018010f,0x98ba0089,0x61e2153a,0x3ea20079}},	//   _моля_, ropě_, _isol, aakt_
  { {0xb09b015b,0x7ae65e56,0x3d0d000b,0xb5fd00bc}},	//   _פיהר, _bakt, _सकीं_, _izše
  { {0x403b0008,0x60da0064,0xe7f0005d,0x7bc70d9c}},	//   _לגוג, letm, घटना_, rtju
  { {0x7ae65e57,0x531b000a,0x7b18001a,0x2efa004f}},	// [f770] _dakt, צומצ, _tíun, _וִיב
  { {0x290a00e8,0xe79b0029,0x60da5e58,0x89370015}},	//   _coba_, مخصص_, netm, أعرا
  { {0xdb1c5e59,0xdc88000a,0x290a03f2,0x7ae65e5a}},	//   strá, _מְרָ, _doba_, _fakt
  { {0xd763002b,0x9655006b,0x8f8b004f,0x0000006a}},	//   رنشی, мълч, צְבֵ,
  { {0x84e50ac6,0xa2a0000b,0xa5092cd9,0xf7480015}},	//   долж, _गज़्, жела_, ألني_
  { {0xf9fa000a,0x7ae65e5b,0x79fa000a,0xfbe1000b}},	//   _והשמ, _zakt, _ולשח, _पनाम
  { {0x67d4129d,0xa3d200d0,0x60da0061,0xd4660054}},	//   _пору, војч, detm, мише_
  { {0x6d4e003f,0x27f80264,0x25a60045,0x60da007c}},	//   zoba, šený_, bsol_, eetm
  { {0xc245006d,0x6d4e5e5c,0xf772000a,0x60da0061}},	//   ьник, yoba, _יקל_, fetm
  { {0x6fa90001,0x00820238,0x9f85029f,0xf4870bc0}},	//   овог_, кльо, мгод, _хуан
  { {0xd009098b,0x68e719c6,0x3ea25e5d,0x0695004f}},	//   цене_, _majd, takt_, ֭דָם_
  { {0x941f0061,0x63a50046,0xa3ea000b,0x91f90015}},	//   ışıy, áhnu, मिर_, _وفاء_
  { {0x7ae60780,0x7e760015,0x6d4e5e5e,0x60da0061}},	//   _rakt, بادئ, toba, betm
  { {0x68e70820,0xf8cf000b,0x28cf000b,0xdb070012}},	//   _najd, स्मय, स्मि, hrjä
  { {0xf092000a,0x9af60015,0x61e20030,0x8ccd000b}},	//   _ינג_, وكست, _zsol, द्धो
  { {0x8f9a01c8,0xc0520008,0xcfb60008,0xbec80024}},	//   _ויקי, _שזה_, _חלקי_, _brīž
  { {0xc3320008,0x7ae65e5f,0x0000006a,0x0000006a}},	// [f780] דון_, _vakt,   ,
  { {0x8ccd005d,0x7ae60849,0xe81a00a2,0x6dc50058}},	//   द्दो, _wakt, يزات_, _أزيل
  { {0x3ce7021e,0xacfb000a,0xc8b50033,0x2cfb000a}},	//   _छोटे_, _והיכ, эсты, _וליא
  { {0x7ae6005c,0xe7375e60,0x3ea00030,0x60da0d40}},	//   _uakt, мех_, _jeit_, zetm
  { {0xa5da0070,0x056a05e6,0x290a5e61,0x6aa40125}},	//   تبار_, ојки_, _toba_, maif
  { {0xa3ea014e,0x3ea00084,0xa5070001,0xf484002b}},	//   मिल_, _leit_, деља_, راتی
  { {0xdb1c0134,0x25a65e62,0x73c30058,0x0000006a}},	//   rtræ, ssol_, نيوم,
  { {0xdb1c193d,0x6aa40fdb,0x68e708c1,0x25a62160}},	//   stræ, naif, _zajd, psol_
  { {0xdb1c1d31,0xd5d60015,0xb355002b,0xa3e30065}},	//   mträ, _تتأث, ریها_, _पैठ_
  { {0x3d0d005d,0x69fb0008,0x65160086,0x6aa4003f}},	//   _सकें_, קליק, _توطئ, haif
  { {0x60da0064,0x3d02000b,0xd8db000a,0x20185e63}},	//   retm, शाने_, חקיר, ári_
  { {0x672200f2,0xdb1c079c,0xb3690015,0x7d1e2f6b}},	//   nhoj, nträ, _فإنك_, _alps
  { {0xe2160015,0xdb1c0012,0x91b7009a,0x2d8000d4}},	//   _تباع, iträ, _قطور_, _cuie_
  { {0xa3e3000b,0xdb1c02ad,0x0000006a,0x0000006a}},	//   _पैड_, hträ,   ,
  { {0x3ea0016b,0x69a4000b,0xead5004a,0xb478000a}},	//   _feit_, _चौबी, новь, לָֽי
  { {0x61ed00df,0xa3b6005d,0x25a92f4f,0x8f8b000a}},	//   _šali, _जिन_, šali_, _וְזֵ
  { {0xaa58005e,0x5d67004a,0x98c700fd,0x213e00da}},	// [f790] диту_, _отоз, дсел, onth_
  { {0x3ea0018b,0xdb1c0012,0x0000006a,0x0000006a}},	//   _zeit_, eträ,   ,
  { {0x636500dc,0xdb1c0012,0x68e71115,0x9b59011e}},	//   lóne, fträ, _vajd, _ниот_
  { {0x1995044e,0xf9930015,0x3984001a,0x6f0d5e64}},	//   _памя, _لبس_, _fös_, _joac
  { {0x25a9002f,0x2ee90509,0x5a470033,0x68e75e65}},	//   éal_, _maaf_, _цэна, _tajd
  { {0x2edc005d,0x236601b2,0xe3b10015,0xa99a000a}},	//   _बस्त, _ahoj_, هرب_, _מבשר
  { {0xc7c41afd,0x869900ce,0x46b70058,0x394601f6}},	//   _исти, _нквс_, _يحرس, éose_
  { {0xc2c50029,0x213e003e,0xcc780008,0x2d8427b8}},	//   ريخي, enth_, וגות_, ímek_
  { {0x91350036,0x28cf005d,0xe1f10031,0x3ea03993}},	//   ехні, स्थि, اسب_, _reit_
  { {0x3ea051b8,0xc51b0015,0x636505a4,0xa1560054}},	//   _seit_, _بغرض_, dóne, нању_
  { {0xc952000a,0xa8a8000a,0x351a000a,0xd6a502a3}},	//   רמי_, וֹרִ, _צוענ, фiчн
  { {0x28cf005d,0x6f0d0ec9,0xe28e0054,0xe1f10067}},	//   स्ति, _coac, _ља_, _مست_
  { {0x3ea005d8,0xf2d2004f,0xdb1c02dc,0x0000006a}},	//   _veit_, _תעד_, ntrå,
  { {0x52380029,0x3ea000b8,0x8c960010,0xc0e200d0}},	//   _تسمح_, _weit_, эрмі, _бошк
  { {0x6aa42f1b,0x711a000a,0xe0d00015,0x3ea0008c}},	//   taif, _מוספ, _خزن_, _teit_
  { {0x62895e66,0x26dd002a,0x0000006a,0x0000006a}},	//   nceo, jewo_,   ,
  { {0xaa46008f,0x718c0053,0xc18c0053,0x6aa40026}},	// [f7a0] хеал, ַװאַ, ַטאָ, raif
  { {0x8d760015,0xbd46006e,0xebe6058c,0x0d97004f}},	//   _ثابا, _سنجي, _зооп, _רכים_
  { {0x2cac002e,0x28c6000b,0x7c9b000a,0x7aa6005e}},	//   óddu_, र्गि, _משיג, _пинз
  { {0xe5c611c0,0x8f9a000a,0x6d5c5e67,0xf8a9000a}},	//   еско, פיני, llra, מש_
  { {0xceb3039e,0xdb1c0b1c,0x4a7b000a,0x0f37004c}},	//   ריד_, rträ, _מרכב, ערנט_
  { {0x2b405e68,0x53e60404,0xdb1c04d4,0x28c6000b}},	//   lnic_, ециа, strä, र्खि
  { {0xe3af0015,0xdb1c0123,0x6d5c001a,0x2b40183a}},	//   مري_, pträ, ilra, onic_
  { {0xca32000a,0x6d5c0012,0x28d8000b,0x722a0a32}},	//   ָם֙_, hlra, ड़कि, зцов_
  { {0xe1d70033,0x61d70033,0x1ddf000b,0x9f4b0046}},	//   едыі_, емыя_, _पैंत, íbí_
  { {0x2b4057e8,0x104a0342,0x25d7000a,0xf993000a}},	//   hnic_, зями_, _אומן_, ארז_
  { {0x443827a9,0x8937000a,0x6e9526ca,0x6d480091}},	//   _är_, תריע_, кину, čdal
  { {0x657a0495,0xd7bb000a,0x9f35005e,0x883b000a}},	//   _hith, הצטר, темі, לתיו
  { {0xe3370053,0x657a003f,0x67d30046,0x2b405e69}},	//   _אראפ_, _kith, mějš, dnic_
  { {0x63650077,0x26dd002a,0x83aa000a,0x0fda0058}},	//   róne, zewo_, ּיּ֥, _فبعث_
  { {0x7b67004a,0x78a5008c,0x657a5e6a,0x1cd80033}},	//   етае, vahv, _mith, эдры_
  { {0x67d30089,0x8f55002b,0x3df50004,0x657a1a6d}},	//   nějš, _جنبش, _азис, _lith
  { {0x7b640080,0x645a0007,0x78a5007c,0xf99000c3}},	// [f7b0] утре, _lyti, tahv, مبل_
  { {0x3da40063,0xad27002b,0xba740015,0xc237000a}},	//   _сръб, _سرخو, طاقت, גרמו_
  { {0x78a50020,0xe8df0016,0xe94403ca,0x28c70065}},	//   rahv, _ngục_, ухто, _लाठि
  { {0x657a002f,0xf7700225,0x8ccd005d,0xcda80086}},	//   _aith, مان_, द्रो, _تهیه_
  { {0x7aed5e6b,0x55e50e3f,0x63b805ca,0x7afd5e6c}},	//   mdat, толб, ervn, _inst
  { {0xdbdd0084,0xbc380086,0x7aed5e6d,0x8557002b}},	//   ráæt, _آسیا_, ldat, ریار_
  { {0xb3e80015,0xe6950015,0xdb07001a,0xd918004a}},	//   فعيل_, _للأد, drjú, _чья_
  { {0x657a0495,0x52750608,0x7aed5e6e,0xdb1c0789}},	//   _eith, купу, ndat, ptrå
  { {0x225902de,0xf7480015,0x657a0125,0x69cd5e6f}},	//   æsk_, _ألقي_, _fith, ntae
  { {0x7085006b,0x62890125,0x25ad10e5,0x69cd008c}},	//   ъгоз, sceo, _ivel_, itae
  { {0x28c6005d,0x69cd0020,0x349434c4,0x7aed5e70}},	//   र्टि, htae, _сахр, kdat
  { {0xa2950191,0x7afd00cb,0x93940015,0xa3b60065}},	//   _раді, _nnst, _إجلا, _जित_
  { {0xf7720b7b,0xd00e0086,0x7aed5e71,0x2b405e72}},	//   יקט_, ملی_, ddat, vnic_
  { {0xdbdc001a,0xb19a000a,0x7afd5e73,0x82340015}},	//   _báða, _חיסכ, _anst, _حرما
  { {0xa1560001,0xfaa605b5,0xdca31b12,0x2b405e74}},	//   _шаљу_, каво, раси, tnic_
  { {0x7aed0035,0x3a3f12ce,0x0b43024e,0x0000006a}},	//   gdat, _župa_, ансн,
  { {0x2b405e75,0x60260003,0x3a150323,0xe8ea01c5}},	// [f7c0] rnic_, _témé, льфс, ммад_
  { {0xa9060021,0xf1b90091,0xa9230e7c,0x7afd5e76}},	//   خبرن, irš_, адул, _enst
  { {0x657a0bd7,0x1cb7000a,0xbcb7000a,0x2b4010cd}},	//   _rith, _בליל_, _בפיו_, pnic_
  { {0x28c6000b,0x9553002b,0x75210012,0xa8550054}},	//   र्जि, یخوا, _allz, утуј
  { {0x67d302d5,0x4ead0053,0x75d40087,0xd707006b}},	//   vějš, לבאַ, ايتا, ънце_
  { {0xda4b000a,0xd9461afd,0x645a0034,0xa8a50058}},	//   _חֲלָ, _реги, _pyti, _مصفو
  { {0x67d30089,0xd8d7000a,0x28c7000b,0x7bce04eb}},	//   tějš, _שולט_, _लाति, ntbu
  { {0x657a003e,0x645a01b2,0x36fa0021,0x1db2000b}},	//   _with, _vyti, _تفرج_, _जिंत
  { {0xdb1c0152,0x657a0541,0x11d80015,0xdb150030}},	//   guré, _tith, رودة_, nuzá
  { {0x28c6000b,0x657a5e77,0x7aed174f,0x50660058}},	//   र्चि, _uith, zdat, َادِ
  { {0x61ed0007,0x7aed5e78,0xdbe40003,0x9406006e}},	//   _šalt, ydat, héât, _جواه
  { {0x7aed04ff,0xdbdc001a,0x6437004f,0x41c3009a}},	//   xdat, _ráða, _באבא_, دقیق
  { {0xa3ea005d,0x7e470484,0xa3de000b,0x7aed5e79}},	//   मिक_, тхне, दौर_, vdat
  { {0xc27b0135,0xba3b016b,0x222b002b,0xdd940033}},	//   _חרדי, _beïn, _غزنی_, рары
  { {0x636500dc,0xd1381256,0xd00f0098,0x317b05bd}},	//   lóna, mią_, _тф_, _קאוד
  { {0x2bb8003b,0x69cd022d,0xc8c6005d,0xba3b00dd}},	//   ضافة_, ttae, र्घट, _deïn
  { {0x28a70080,0x7aed5e7a,0x7bce0e05,0x58d51440}},	// [f7d0] вшег, rdat, atbu, лоат
  { {0x9dd60008,0xd1381256,0x29c80015,0x69cd5e7b}},	//   _עותק_, nią_, ئِلَ_, rtae
  { {0x56950080,0xba3b09f2,0x7aed28ac,0x69cd5e7c}},	//   гает, _geïn, pdat, stae
  { {0x69cd0084,0x8c1a000a,0x6d555e7d,0x7afd2a6d}},	//   ptae, _נורי, loza, _unst
  { {0xd1380007,0x6365001a,0xd6780015,0x75e40015}},	//   kią_, jóna, نحها_, لأوك
  { {0xe894004a,0x63650030,0x6d555e7e,0x58870033}},	//   _варь, dóna, noza, _шыма
  { {0x8882002b,0x9475002b,0xd138002a,0x04b402a3}},	//   _ایمن, اگذا, dią_, рсія
  { {0xbc7c0008,0xdb1c0003,0x6d550030,0x6c7c000a}},	//   ונות, turé, hoza, ורוד
  { {0x6d5500dc,0x78b2002e,0xa3e3000b,0xd138002a}},	//   koza, _ákvö, _पैर_, fią_
  { {0x600944fc,0x410514fd,0x6f1d158f,0xd138340c}},	//   еном_, узов, eksc, gią_
  { {0x6d5500dc,0xdb1c0152,0xbea61f54,0x33871d9f}},	//   doza, suré, ланк, _рузв
  { {0x8fc40086,0x8cd6005d,0xcce9000a,0x5f460015}},	//   گزین, म्नो, _מכ_, انحل
  { {0x2d840152,0xef1703a9,0xd138002a,0xdb0e001a}},	//   ême_, умя_, bią_, pubú
  { {0xd138005c,0x7c3a006f,0x41b2006e,0xd656000a}},	//   cią_, útro, _امور, רישת_
  { {0xe0d20053,0x9f060015,0x1c39004a,0x8fa200ce}},	//   _לײג_, _موثو, вять_, _лаще
  { {0xa3b6014e,0x1ee8002b,0xba3b0144,0x6f1d5e7f}},	//   _जिस_, _شوخی_, _veïn, cksc
  { {0xe9da04f7,0xed360033,0xc9860015,0x7bce53d2}},	// [f7e0] эка_, _бэнэ, اشري, stbu
  { {0x28cf005d,0x8ca5005d,0x2d95006b,0x7bce02ad}},	//   स्लि, करणो, _тръс, ptbu
  { {0x9b460029,0x636500dc,0xa3e2000b,0xad1b000a}},	//   _مندو, zóna, _कैंप_, _נוטר
  { {0x4422003d,0x3a9a00ce,0xd1380535,0x7b2c007f}},	//   _āk_, _ятою_, zią_, rşus
  { {0x363600e6,0x35b60457,0x85b70369,0x0000006a}},	//   دراس, ущес, هاوس_,
  { {0xb5fd00bc,0xa507027a,0x291116ee,0x67a60058}},	//   _izšl, леча_, _goza_, _محرق
  { {0xd4990036,0x68ef0089,0x28750010,0xd826004a}},	//   трі_, řidá, _вытр, _сдви
  { {0xd138005c,0xdc080024,0x25ec005d,0x636500dc}},	//   wią_, dēļa, _आईपी_, tóna
  { {0xda04005d,0x86460001,0x7986003f,0xcb13000a}},	//   रमित_, _снаж, _jukw, מלה_
  { {0x7986003f,0x320a002a,0x63651793,0x31340342}},	//   _mukw, ćby_, róna, реор
  { {0x39570008,0xd1380b53,0xf957000a,0xe29a006b}},	//   רשים_, rią_, רסית_, _зае_
  { {0xd1380007,0xd24f0086,0x0877004c,0x71a60033}},	//   sią_, _کنه_, טעיט_, _бадз
  { {0x6d555299,0x3d16000b,0x6f1d0c0c,0xd138340c}},	//   toza, _नकशे_, rksc, pią_
  { {0x2eed07c4,0xc534004f,0x5d680058,0x9d470058}},	//   žef_, בָֽה_, ُمَّ_, ائحن
  { {0xa3ea005d,0xd5280016,0x6d554f04,0xdb6b1236}},	//   मिट_, _cổn, roza, ерал_
  { {0xab620064,0x25a00046,0x0000006a,0x0000006a}},	//   şünc, šily_,   ,
  { {0x29114139,0x2d840030,0xba3b0079,0x99d90015}},	// [f7f0] _poza_, ímet_, _geïl, ضواء_
  { {0x2d9900da,0xdb080046,0x68ee0144,0x6365001a}},	//   mpse_, ělát, _cabd, jónn
  { {0x1a650086,0x7aee00f2,0xa08b000a,0x645e007c}},	//   _چیزی_, öntä, גְדִ, üpil
  { {0xef1f0064,0x2057000a,0x36d53023,0x6b9a000a}},	//   nkü_, ניאל_, родр, _ששרד
  { {0x6365032c,0x6f4c000a,0x3f660003,0x66050a96}},	//   fónn, עֲבַ, _vœux_, рпла
  { {0x6619002a,0xfbd0002b,0x19ba000a,0xaa3a000a}},	//   rywk, _بتی_, _במשב, _יתרח
  { {0x0d180008,0x63410024,0x3cfc000a,0x59a90065}},	//   רקוט_, lēni, תלונ, _चौतर
  { {0xd2510029,0x5c380008,0x11d90029,0x8c38000a}},	//   ينغ_, טרון_, نوعة_, טטוס_
  { {0x8627008f,0x13060080,0x629b0007,0xd4c7006e}},	//   _сьве, рный_, rbuo, _مغاي
  { {0xdb1c04d1,0x8574024e,0x7aef1be3,0x216900af}},	//   strø, _глух, _lact, ђини_
  { {0x52b50029,0x63480089,0x34fa000a,0xb4fa000a}},	//   _نماذ, měnn, _שהעד, _שפעי
  { {0x539a013a,0x25a004f9,0xa8560008,0x67f000dc}},	//   _ייעו, ţile_, ייתה_, lójá
  { {0x78b500bc,0x8628000a,0x9756004f,0x6365016d}},	//   _odzv, ָֽרֶ, שירו_, lóno
  { {0x78a70089,0x59a9005d,0x408700d7,0xc244022a}},	//   _nejv, _चौधर, _судб, _унік
  { {0xbb560029,0x913a000a,0x2d995e80,0x6365006f}},	//   لنسب, _בעסק, apse_, nóno
  { {0x0d86053b,0x63650069,0x68ee07c8,0x7aef268d}},	//   _клин, zónn, _sabd, _cact

  { {0x88ca005e,0x2f5b000a,0x7aef5e81,0x0000006a}},	// [f800] клав_, _בדקנ, _dact,
  { {0xd5280092,0x09030001,0xba3b0159,0x7aef030d}},	//   _tổn, опун, _geïm, _eact
  { {0x2ba5005d,0xb7e6005e,0x7aef0b8b,0x3f870085}},	//   गीदा, ржек, _fact, _junu_
  { {0xb5aa003b,0x3f870084,0x7a2c0152,0x98ab003d}},	//   ناتك_, _munu_, _côté, ēmās_
  { {0x59760010,0x1a9b0053,0x550605b3,0x7ae43ec5}},	//   _выву, _ביכע, ичка, meit
  { {0xb7960001,0xa5330036,0xcdf7000a,0x63f60015}},	//   _враћ, оніч, ימני_, لأعر
  { {0xb226002e,0x45190010,0x61ed0091,0xa818000a}},	//   kvæð, ыцця_, _šalp, _גֵּי
  { {0xb02400a7,0x7ae45e82,0x3eab5e83,0x0000006a}},	//   _ngườ, neit, xact_,
  { {0xdb1d00dc,0x69c45e84,0x6458002a,0x7333002b}},	//   ézés, nuie, _ścię, تروئ
  { {0x7bde02d7,0x3f8701e2,0x33d60036,0xe1340139}},	//   _oppu, _bunu_, _відт, ённы
  { {0x25ec005d,0x61eb0251,0x7ae45e85,0xa2e618fe}},	//   _आईडी_, _esgl, keit, _воед
  { {0x61240251,0xe29a5e86,0x7ae45e87,0xa857000a}},	//   _dòla, _рад_, jeit, שיטה_
  { {0x7ae40026,0xc3050029,0x7bde5e88,0x51940015}},	//   deit, _دبلو, _appu, _التذ
  { {0x621b0008,0xc0aa0086,0x7c8415ec,0xfbd30021}},	//   _בודק, _شاتل_, жуте, يتز_
  { {0xfaa7000d,0x7ae45e89,0xa0070029,0x8b5b0015}},	//   ишан, feit, _نقول_, نجرس_
  { {0xbb280010,0x307b0008,0x61eb0034,0x67f00030}},	//   ацуе_, _באונ, _ysgl, zójá
  { {0x69c40467,0x6d56002e,0x25690125,0x7bde02b9}},	// [f810] guie, ófað, húla_, _eppu
  { {0x3ea9509a,0xdb1c0045,0x6e3c000a,0x5118000a}},	//   _heat_, gurâ, _שתזד, נֵּנ
  { {0x7ae405cf,0xf80704c2,0x6d470085,0x7aef2678}},	//   beit, шчан, mnja, _tact
  { {0x7ae4193a,0x7784017f,0xcc56000a,0x4758005e}},	//   ceit, іліз, _לבתי_, арія_
  { {0x67f000dc,0x3ea9003e,0x69c40011,0x69dd07eb}},	//   tójá, _meat_, cuie, _upse
  { {0x3ea9017e,0x2a760008,0x64980063,0x0d980008}},	//   _leat_, _לערך_, атър_, סכום_
  { {0xd7c90086,0xe4d60015,0x6286006f,0x6d475e8a}},	//   _حوزه_, صويت_, ľkon, inja
  { {0x68e500f2,0x63650f07,0x3ea95e8b,0x42e90054}},	//   lehd, róno, _neat_, умио_
  { {0x63480046,0x9f520046,0x3f875e8c,0x65944e39}},	//   měnl, ízí_, _sunu_, _мату
  { {0x7ae400b8,0x3f87016f,0xd5140015,0xdff4000b}},	//   zeit, _punu_, _وبلغ, ेमंद_
  { {0x14190029,0x3ea9259c,0x7ae4003f,0x43850015}},	//   _حياة_, _beat_, yeit, _الصق
  { {0x2d8100f2,0x643a0053,0x6d47064e,0xfeba0015}},	//   _aihe_, _געענ, enja, دادت_
  { {0xdfce0086,0x71f8002b,0x32090061,0x7ae45e8d}},	//   ويی_, _پرنس_, _çay_, veit
  { {0x4095003b,0xb2260084,0x365a0053,0x7ae40940}},	//   _الغر, svæð, רכשנ, weit
  { {0x3f80007c,0xab2a011a,0x73fa000a,0xdb0a013f}},	//   _tiiu_, гова_, ְּלו, šník
  { {0x70a7000b,0x8c430004,0x80d3000b,0x6d473521}},	//   _ग़ुल, чесе, ब्रे, anja
  { {0x0dc9000d,0x6d47016f,0x7ae45e8e,0x6f0435ec}},	// [f820] _куќи_, bnja, reit, _inic
  { {0x7ae44652,0x5fdb000b,0x6341003d,0xdb0e0125}},	//   seit, _बहाल, mēnu, isbé
  { {0xf9890008,0xf5480092,0x61e906ad,0x1d17000a}},	//   תר_, hục_, hwel, _הקיר_
  { {0x61e95e8f,0x9980002c,0xc68f0015,0xd3780085}},	//   kwel, dziť_, ِّن_, _opća_
  { {0x69c45e90,0x09f6005e,0x7d77002b,0xdbe3001a}},	//   quie, _учня, _خمیر_, _héða
  { {0xdb1c007c,0x15b90033,0x61e924a7,0xadd7004f}},	//   htrü, рыцы_, dwel, מונח_
  { {0x63a4016f,0x394f0030,0x493b000a,0x61e95e91}},	//   ćino, égse_, _עגלו, ewel
  { {0xfbd3013a,0x070c005d,0x61e90034,0x395a1859}},	//   פתח_, _सचिव_, fwel, lops_
  { {0xc8cf014e,0x2569002d,0x44200024,0x61e90e18}},	//   स्कट, súla_, ņi_, gwel
  { {0x3ea9003e,0x644f005c,0xe1340033,0xa3e3000b}},	//   _seat_, _ście, інны, _पैक_
  { {0x6d47018c,0xf1b9002c,0xb5fd0107,0xb4250015}},	//   vnja, vyše_, _vyše, _وعمو
  { {0x487b0008,0x67220a6f,0x52860015,0x57fb004c}},	//   טטיס, nkoj, _الإك, אלטו
  { {0xe2870086,0x6d470796,0x2018007c,0xa2f7000a}},	//   _اطمی, tnja, ärib_, _למאה_
  { {0x71730015,0x7f83002b,0x3039002b,0xdb1c006f}},	//   _فهنا, _کلين, اتیک_, ktró
  { {0x672200f2,0x5c04056d,0xc334000a,0x6d470b28}},	//   kkoj, пята, ֧וּ_, rnja
  { {0xeafb0086,0xc334000a,0xc214000a,0x213e2cb6}},	//   درست_, קוּ_, ֗הּ_, lith_
  { {0x59390010,0x91bb0053,0x201e0007,0x5ee8000a}},	// [f830] азаў_, ָמבי, lyti_, _הַתְ
  { {0x6d402ac4,0x67220024,0xf8070a1f,0xa3e8000b}},	//   émat, ekoj, йчен, यबा_
  { {0x201e0091,0x286b0054,0xa177000a,0x68e5008c}},	//   nyti_, урао_, מעמד_, rehd
  { {0xcf930053,0x68e500f2,0x61e95e92,0x8b88000a}},	//   לטע_, sehd, ywel, _לָשֶ
  { {0xceb4000a,0xff7c004c,0xd5bb54cb,0x5c8b000a}},	//   פיס_, אטאמ, усе_, ְרֵ֣
  { {0x201e00df,0xe4250086,0x039503fc,0x8503000b}},	//   kyti_, يکاي, ория, लाइट_
  { {0xdb1c5e93,0x250a002b,0x03940033,0xad1c000a}},	//   ctró, شروی_, прыя, רוור
  { {0x201e00df,0xb06500f2,0xa8480015,0x97250067}},	//   dyti_, hdää, _الفم_, _بفرو
  { {0xe6130029,0x21b80086,0x7bc70213,0x61e93f92}},	//   _عشر_, مپيک_, huju, uwel
  { {0xe0d60080,0x7bc75e94,0xf994000a,0x61e95e95}},	//   овь_, kuju, הרץ_, rwel
  { {0xa93a0008,0x92950033,0x672934e9,0x201e0091}},	//   שתתפ, _даец, _klej, gyti_
  { {0x213e3744,0xb5fd00bc,0xdb1c01c0,0x7bc75e96}},	//   aith_, _azši, kurá, duju
  { {0x92670074,0x20d50036,0x22920015,0x7e6d002a}},	//   _ادام, _дійс, _غلوس, _czap
  { {0x23dd000b,0x067a000a,0x8d760015,0x53dd000b}},	//   _महाद, ינרל, تاجا, _महाश
  { {0x30790053,0x0caa005d,0xe1f90007,0xe3a700e5}},	//   _דאַנ, _क़ीम, lvų_, بر_
  { {0xff520086,0xab66022a,0x6f0430c5,0x2b495e97}},	//   _تخت_, івал, _unic, gnac_
  { {0x7bc70007,0xdb1c3fa2,0x395a5e98,0x0000006a}},	// [f840] auju, gurá, tops_,
  { {0xd9100086,0xa3ba005d,0x67295e99,0xb4e8000b}},	//   ریز_, _अटल_, _alej, _बसे_
  { {0x6d5c22c1,0xa156000a,0x7bc70085,0x672226a6}},	//   mora, קבעה_, cuju, tkoj
  { {0xd6d90036,0xdb1c00dc,0xa0260201,0x6d5c0390}},	//   йті_, rtró, ltöö, lora
  { {0x88c60015,0xa026007c,0x7af60091,0xc6f70033}},	//   _وتسل, otöö, mdyt, ўніх_
  { {0xdb1c08e0,0x7af600df,0x672900dc,0xa026008c}},	//   ctrò, ldyt, _elej, ntöö
  { {0x7af60007,0x66e60015,0xf2c6005e,0x8afa0c44}},	//   odyt, _وأرق, оспн, ֹהִי
  { {0x7af600df,0xe61a0010,0x672900bd,0x213e0335}},	//   ndyt, _кдб_, _glej, with_
  { {0x90d50092,0x5a170053,0x05d1000b,0x69b2000b}},	//   rìn, ַקטן_, _समयब, ेंटी
  { {0x201e00df,0x6d5c5e9a,0x7af6008c,0xf617000a}},	//   tyti_, jora, hdyt, _וחמש_
  { {0x7af60007,0x2918065d,0x28cf005d,0x7e6d00dc}},	//   kdyt, _mora_, स्टि, _szap
  { {0x201e00df,0xd5280016,0xd5b8008b,0x6d5c07c8}},	//   ryti_, _hồn, _вiдо, eora
  { {0x201e00df,0x3f980024,0x7bc70509,0x9e67002b}},	//   syti_, ūru_, wuju, تادن
  { {0x01330015,0x612d0125,0x7bc73c3a,0x201e0091}},	//   _يعود, _cúld, tuju, pyti_
  { {0x7bd50012,0x2aab0054,0xd5280016,0x62870046}},	//   utzu, итао_, _mồn, ějov
  { {0x28dd000b,0x7bd50012,0xc1780091,0x6d400003}},	//   न्नि, rtzu, lmė_, émar
  { {0x2918003f,0x7bd500b8,0x5a35017a,0x6d5c1139}},	// [f850] _bora_, stzu, чнат, bora
  { {0x67290024,0x99670484,0xc19b000a,0x25fe000b}},	//   _slej, італ, ישמי, लिनी_
  { {0x7af600df,0xad270086,0xf770002b,0xd7c80021}},	//   bdyt, _هرگو, چان_, قوله_
  { {0xd3660074,0xf77004c9,0xe1f90007,0xcc76000a}},	//   _سه_, نان_, yvų_, _מעתה_
  { {0xd246040b,0xc1780007,0xfa9600a3,0x7f3c000a}},	//   _أن_, kmė_, _מדרש_, סעדו
  { {0xd006040b,0x97c70015,0x29180263,0x7e60007c}},	//   _كل_, _وتأم, _gora_, ümpi
  { {0x67292c8a,0x61e25e9b,0x63655e9c,0x0000006a}},	//   _tlej, _apol, lóni,
  { {0x13090036,0x67290134,0x61e2002d,0x4acb000b}},	//   сний_, _ulej, _bpol, िलिव
  { {0x51590010,0x63650896,0x9567006b,0x68f52e77}},	//   йшоў_, nóni, _дъжд, _kazd
  { {0x2cb1005c,0x68f55e9d,0xe1f90091,0x28cf000b}},	//   jazd_, _jazd, rvų_, स्चि
  { {0xaf0a0015,0x0876004c,0x7af6008c,0x7f5d0144}},	//   مقدم_, ּערט_, ydyt, fosq
  { {0x6d5c002a,0x68f50091,0x3f84001a,0x3a205e9e}},	//   wora, _lazd, ömu_, yyip_
  { {0xa02600f2,0x6365002e,0x42540004,0xd00e002b}},	//   ttöö, jóni, _отшт, نلی_
  { {0xc27a0008,0x6d5c00f2,0x865a0008,0x127a004c}},	//   _פרסי, uora, מדרי, _פאסע
  { {0xf092013a,0xa0260020,0xfb6a0015,0xfc030294}},	//   _אנו_, rtöö, مصرى_, нпро
  { {0xa0260005,0x69d600f2,0x63655e9f,0x29185ea0}},	//   stöö, ttye, fóni, _sora_
  { {0x29185ea1,0xda660021,0x61fb5019,0x6d5c3f29}},	// [f860] _pora_, ساري, nvul, pora
  { {0x0e570008,0x61fb00f2,0x38c80086,0xdcb10092}},	//   _משפט_, ivul, تاری_, ửa_
  { {0xe9ff0092,0x87060010,0xad1b000a,0x29185ea2}},	//   _tiếc_, зяле, _הויר, _vora_
  { {0x6286006f,0x69d602f2,0x96b700af,0x0000006a}},	//   ľkok, ptye, пуљу_,
  { {0x1d16000a,0xbafb000a,0x4b7b000a,0x68f52755}},	//   ּקֶר_, _ההכש, _לאטו, _fazd
  { {0x63480089,0x644f005c,0x7589005e,0x68f55ea3}},	//   měni, _ścia, ісів_, _gazd
  { {0x61e23f6a,0x9cd7000a,0x69c45ea4,0xf0e50065}},	//   _spol, פוקה_, lrie, क़ैद_
  { {0xe73a0063,0x77bb0008,0xdb241671,0x68f50bba}},	//   _уеб_, _למלח, érès, _zazd
  { {0x68f50064,0xd6cf0015,0x05760015,0xf1aa0015}},	//   _yazd, _حقق_, _فائد, حابه_
  { {0x859b0008,0x3a37000f,0xe58b000f,0xf8cc000b}},	//   _לשמו, פרים_, _הָאָ, ालिय
  { {0x69c4018b,0xc49b000a,0xf9460033,0xdb1c0144}},	//   hrie, _השבת, ўнiк_, curç
  { {0x69c41175,0x612d0125,0xc1780091,0x93260058}},	//   krie, _cúlb, smė_, _عرضن
  { {0xada40010,0xc333000a,0xddcf0091,0x31e50015}},	//   наўл, _אוף_, ždži, _يسهّ
  { {0xc16f0191,0x14df005d,0x2d850020,0xc27b0008}},	//   _її_, प्पण, öle_, _הרדי
  { {0x60db0008,0x80db0008,0x68f502c6,0x50db000a}},	//   _הקונ, _החוז, _razd, _הקוא
  { {0xae9b0029,0x139b0053,0x539b0008,0x7ff30015}},	//   _اضغط_, מבלע, מילו, _أسوا
  { {0xdebc0008,0x69c41554,0xd8e7006b,0x2395003d}},	// [f870] _המחל, grie, зцеп, _māja_
  { {0x63651ad7,0x9e670086,0x320200f2,0x0000006a}},	//   róni, _واکن, äkyy_,
  { {0x290701e2,0x57a40010,0x68f5016f,0x63650077}},	//   ına_, ешча, _vazd, sóni
  { {0xfaa50086,0xdb07008c,0x636516ee,0xd8740067}},	//   _تجدی, usjä, póni, رالب
  { {0x69c45ea5,0xbafa000a,0x8afa0447,0xd5280016}},	//   crie, _והרש, _והרי, _sốn
  { {0x85e80036,0xfdf8000a,0x25de000b,0x65920054}},	//   ядів_, פצות_, _गहरी_, њају
  { {0xc9520008,0x0000006a,0x0000006a,0x0000006a}},	//   _סמל_,   ,   ,
  { {0xb4ac005d,0xf7730086,0x34db0086,0x97150010}},	//   _कड़ी_, _ساز_, _گذرد_, _ўмац
  { {0xdb240014,0x201800f2,0x87280033,0x61fb008c}},	//   érés, ärin_, _эўра_, uvul
  { {0x05740015,0xa1560054,0x6365001a,0x34b5002b}},	//   _كالد, мању_, jónv, _آماز
  { {0x69c4002c,0x916c0092,0xceea335c,0x61fb5ea6}},	//   zrie, uốn_, одне_, svul
  { {0xe28e5ea7,0x26cf00b6,0xcf3a0036,0xd5d1021e}},	//   _ја_, nggo_, ічні_, _समाज
  { {0xb5fd002c,0xc332000a,0xee371eea,0xe0ce04bb}},	//   _myšo, _בוא_, дня_, _ив_
  { {0xe0450054,0x69c45ea8,0xf1b2000a,0xac0a0ac9}},	//   _онли, vrie, _יסד_, онга_
  { {0x69c40176,0xb09a000a,0x2f560099,0xeb972925}},	//   wrie, _ויצר, _отис, дис_
  { {0x61ed0007,0x69c41e56,0xc9aa0033,0xfaf500fd}},	//   _šaly, trie, жвае_, нчую
  { {0xf2d200b2,0x79870111,0x59860004,0xdb07001a}},	// [f880] כען_, _bijw, длаб, yrjö
  { {0x69c40738,0xbca6012c,0x8d76006e,0xb5fd013f}},	//   rrie, _تمدي, _تابا, _pyšn
  { {0x28dd005d,0x5fc5000b,0x8b95004a,0x644f002a}},	//   न्धि, _विफल, _пряч, _ścin
  { {0x9f5d0264,0xaab2000b,0x86460004,0x6d4e003d}},	//   _prvé_, _ज़िक, мнеж, lnba
  { {0x3f7b004c,0x1e49004f,0xd90d009a,0xdb1c15c8}},	//   קאנס, ּרוֹ_, _گیل_, ftrö
  { {0x6d4e00b8,0x628b0030,0xfe37000a,0xdb0e0012}},	//   nnba, _aggo, ורני_, hrbü
  { {0x3219008c,0x929401b0,0x6d4e123d,0x13b30015}},	//   äsyn_, найц, inba, نصيح
  { {0xfbd3000a,0xcc57000a,0xd703006b,0x6d4e0012}},	//   דתה_, ובצי_, _изси, hnba
  { {0x63650084,0x51f80036,0x966303c5,0x9aeb000a}},	//   jónu, їною_, _акте, חַיִ
  { {0xd1300018,0xb5fd0107,0xe5060002,0x19e9004c}},	//   امد_, _myšl, _تبري, פֿפּ
  { {0xe29a0010,0x0000006a,0x0000006a,0x0000006a}},	//   _дае_,   ,   ,
  { {0xd80b0008,0x4393005e,0xb2260342,0xde590033}},	//   קִיָ, _раїс, _омел, замі_
  { {0xde640063,0x0e6b0015,0xbe380033,0x1289002b}},	//   върп, تصدي_, дзях_, _عموی_
  { {0x63530011,0xdb150030,0x6d4e00cb,0xbebb0073}},	//   măna, mszé, gnba, okëk
  { {0xd30f0092,0x212b0003,0xcbc40015,0x1bd402da}},	//   _mệnh_, êche_, َزِي, коря
  { {0xd30f0092,0xa3cf000b,0x3378000a,0x79a70004}},	//   _lệnh_, वंत_, לְּב, држе
  { {0xfb8402bf,0x0975004a,0x63650125,0xdb150030}},	// [f890] тырн, егаю, mónt, nszé
  { {0xe6a7005d,0x182b0015,0xdb07001a,0x35c8000b}},	//   खर्ज, يساً_, nsjú, _रमज़
  { {0xe6100086,0xfecb000a,0x58d437c6,0x0000006a}},	//   یشه_, ַמַּ, тохт,
  { {0xcaa700e6,0x7c2804d1,0xcad5004f,0x0000006a}},	//   _تصدي, ødre, _אוֹת_,
  { {0xd30f0023,0xba9a000a,0xaa9a000a,0xa2b2000b}},	//   _bệnh_, _מסרי, _מברכ, _इज़्
  { {0xc4c9005d,0x7aed0cd9,0x29350053,0x14c7002b}},	//   रलेख, leat, _טאָן_, ذهبی_
  { {0xdb1500dc,0xf8b2039e,0x53fb0015,0xf770002b}},	//   eszé, _תשל_, ترشح_, _چاق_
  { {0x7bc70020,0xdb1c5ea9,0x7aed30c5,0xae0f000b}},	//   irju, orrá, neat, ामान_
  { {0xa2d0005d,0x20d50484,0xdb150030,0x6d4e00aa}},	//   _धार्, нінс, gszé, ynba
  { {0xb6cc0061,0x7aed5eaa,0xf8af0065,0x0000006a}},	//   _çürü, heat, टरिय,
  { {0xd009364e,0xa779000a,0x3f890cfd,0x7aed37b0}},	//   чене_, ּרָפ, _biau_, keat
  { {0xdb1c0152,0x6fc0000b,0x69cd007c,0xc1ea000b}},	//   ntrô, _विरू, kuae, _जैकब_
  { {0xa2270015,0x7bc1171f,0x7bc75eab,0x7aed0096}},	//   _تراه, álun, erju, deat
  { {0x721a0008,0x52740086,0x463a004c,0x621a0643}},	//   _מונח, _شانز, לערע, _מונק
  { {0x7aed003e,0x6365002e,0x98ba0011,0xf3e70015}},	//   feat, sónu, hipă_, دأ_
  { {0x6286002c,0x7aed5eac,0x6a860004,0x28dd000b}},	//   ľkov, geat, елба, न्सि
  { {0xc332039e,0x50d9000a,0x7bc7007c,0x69cd007c}},	// [f8a0] און_, ּחֲצ, arju, guae
  { {0xb5fd0107,0x3e5b000a,0x291c001a,0xe9d70033}},	//   _vyšl, _מדפס, ðva_, эку_
  { {0xacd70053,0x2bba0029,0x1efa0008,0xdb1c002d}},	//   _אויפ_, _عادة_, ּלְע, arrá
  { {0x60c60007,0xdb9b000a,0xbbe9002b,0x7bce19c7}},	//   ėkmi, _מסטר, _کریم_, mubu
  { {0x7d1e0048,0xfb1b004c,0xd7070033,0x28dd000b}},	//   _kops, _זוכמ, энце_, न्हि
  { {0x66030001,0xdb150030,0x24f70138,0x0000006a}},	//   упља, vszé, еншы_,
  { {0xe4a50036,0x7bce5ead,0xbb3a000a,0xdb1c001a}},	//   тріо, nubu, ּעִי, durú
  { {0xb7db0008,0xd4090015,0xdb150030,0xd3770033}},	//   _מקלי, بتهم_, tszé, нчы_
  { {0x612d002c,0x320228cc,0x28dd005d,0x3f890273}},	//   _súla, íky_, न्वि, _riau_
  { {0x7bc7002e,0xc05a0033,0xd4910016,0xaa3b000a}},	//   yrju, зім_, _hàn_, פתיח
  { {0x39960134,0x41c2000b,0xb8fc0033,0x7bdc002a}},	//   _læs_, _शिवस, скiм, jtru
  { {0xe292003b,0xceeb0029,0xf457000a,0xd3780085}},	//   _إذا_, أردن_, _איבר_, _opći_
  { {0x5ce70036,0x61460152,0x6ce7042b,0xce6b0033}},	//   нюва, _célè, ніве, ярод_
  { {0xc05a0036,0x71770036,0x629c005c,0x7bc700bd}},	//   _ній_, _збір_, środ, trju
  { {0x7aed46f1,0xd4910016,0xab95005e,0x40341411}},	//   teat, _oàn_, тибі, _шекс
  { {0xdb075eae,0x98ad00bc,0x9f5d005a,0x0000006a}},	//   nsjø, čoči_, _krví_,
  { {0xf99303c4,0xda340010,0x98c75eaf,0xaab2000b}},	// [f8b0] ابر_, геты, فغان, _ज़रक
  { {0xb9c40029,0x7bce11ac,0xe7ef000b,0x6f0d013f}},	//   اقلي, bubu, ज़िला_, _hnac
  { {0x7aed3bd6,0x80d8000b,0xd4910016,0x63480046}},	//   peat, _माने, _bàn_, něns
  { {0xdcfe0011,0xfcab002b,0x9989006f,0x8f9b000a}},	//   _tipă, _باکو_, dzať_, פידי
  { {0xf7700031,0xf6d4002b,0xb5a75eb0,0xd49100a1}},	//   حال_, ازمد, хрей, _dàn_
  { {0xcd980008,0x05770029,0xe4c20080,0xd7950015}},	//   עדות_, راشد, айши, _للآخ
  { {0x14d2005d,0xdce40024,0xf8b2000a,0xa954005e}},	//   _सारण, _etiķ, _כשם_, _скрі
  { {0x05c9000b,0x07090015,0x53320004,0xd6d800ce}},	//   _रिपब, _تيري_, иејт, _пту_
  { {0x44290048,0xc692013a,0x6d475eb1,0x04c90015}},	//   ņa_, _כאן_, kija, _يوري_
  { {0x41020033,0x636504b2,0x3eb20012,0x6f0d0051}},	//   азьв, tóns, _seyt_, _anac
  { {0x7bdc00c0,0xbea642da,0x7d1e0085,0x889a000a}},	//   xtru, канк, _rops, ובתי
  { {0x7d1e016f,0x0caa000b,0xd0580033,0x44275eb2}},	//   _sops, कर्म, эрыі_, myn_
  { {0xb6ba013a,0x7d1e0afe,0x733a004c,0x9f590046}},	//   וצרי, _pops, _קענס, írá_
  { {0x6f0d4bd3,0x2360044c,0x7bce5eb3,0x6da311bd}},	//   _enac, čije_, tubu, рира
  { {0xcb940086,0x44275eb4,0x9c590920,0x8cb508f0}},	//   اهرک, nyn_, ешту_, ысяч
  { {0xef260064,0x6d47003f,0x7bce2286,0x2ca50061}},	//   çüde_, aija, rubu, ılda_
  { {0xd4910023,0xe9da13ae,0x44270026,0x7bce5901}},	// [f8c0] _nào_, ька_, hyn_, subu
  { {0x4427020a,0x6f0d3925,0x6ab60064,0xdd8f002b}},	//   kyn_, _znac, sayf, _گوی_
  { {0x61fc0024,0x8cd7000b,0x6f0d0034,0x09290015}},	//   ārli, _बातो, _ynac, رسكي_
  { {0x44270176,0xe5c61206,0xdd8f002b,0x2cb84c40}},	//   dyn_, вско, _دوی_, lard_
  { {0x45f30029,0x74130086,0x99860015,0x9663004a}},	//   لأوس, یوها, _للحو, акце
  { {0x44270176,0x55580010,0x63750091,0x2cb85eb5}},	//   fyn_, эаля_, _išny, nard_
  { {0x44270026,0x68fc51cb,0xa3b70015,0xd9433924}},	//   gyn_, _iard, ناير_, _тери
  { {0x51f8005f,0x236d00bd,0x6d475eb6,0x68fc58eb}},	//   ению_, glej_, zija, _hard
  { {0xcb130008,0x87550063,0xda05000b,0x25ec000b}},	//   שלח_, _сърц, रियत_, _आईटी_
  { {0x44270176,0x6563001c,0x240a0063,0x25a63310}},	//   byn_, conh, _онзи_, mpol_
  { {0x30130010,0x63a4016f,0x44274ebb,0x44380078}},	//   адэр, ćins, cyn_, _år_
  { {0x01da0015,0xe9ff0016,0xe3a7002b,0x68fc5eb7}},	//   _يوضع_, _giặc_, _ششمی, _lard
  { {0xa2d7014e,0x6286002c,0xb5fd0007,0x66025eb8}},	//   _यात्, ľkos, _ryšk, nvok
  { {0x2cb80493,0x62860b7e,0x6d47008c,0xdb1c0012}},	//   gard_, žkos, uija, hrrä
  { {0xa5cc014e,0x256900dc,0xd00f0029,0xa177000a}},	//   _समझौ, múlt_, _وله_, _שעוד_
  { {0x8b080089,0x93fb0008,0x6f0d06e8,0x6d475eb9}},	//   vyří, וללי, _unac, sija
  { {0x68fc26c2,0x27ea00e8,0x4427005c,0x3eb92b88}},	// [f8d0] _bard, _apbn_, zyn_, mast_
  { {0xacf50124,0x442700f2,0x3da40063,0x612d002e}},	//   _спољ, yyn_, _тръб, _núll
  { {0xdb1500dc,0x8078000a,0x47940015,0x65630030}},	//   lszí, תְּה, لجنس, vonh
  { {0xdbd10005,0x65951a11,0x86c5002b,0x86c40015}},	//   _müüg, гаду, ايشن, ليمن
  { {0x44271f8d,0xbb3a0008,0x7afd0011,0xdb150030}},	//   wyn_, _נעשי, _iast, nszí
  { {0xd49100a7,0x2a3a00b2,0x05640010,0x3eb90020}},	//   _vào_, _טערמ, авін, hast_
  { {0xe2990558,0x25ef005d,0xd4660054,0x656802de}},	//   най_, _इनकी_, лише_, _dkdh
  { {0x8219000d,0x3eb9382e,0x2cb805d6,0x44275eba}},	//   ецот_, jast_, zard_, ryn_
  { {0x3eb90f37,0x68fc17e3,0x7afd4828,0x2cb8508e}},	//   dast_, _yard, _mast, yard_
  { {0x44270026,0x442b0054,0x7afd5ebb,0x236d19c2}},	//   pyn_, _оцем_, _last, slej_
  { {0x7e76002a,0x7afd0045,0x9f860883,0xdb150030}},	//   _szyp, _oast, лгод, eszí
  { {0x6d4511d8,0xe39a0053,0x3eb905d8,0x2cb804dd}},	//   _amha, _טשעכ, gast_, ward_
  { {0xd4910023,0xb0620020,0xd5f90053,0xc0e5017a}},	//   _làm_, ääru, עפֿר, _болк
  { {0x7afd1c23,0x2d8c0f38,0x6ed6000b,0x3eb9053a}},	//   _aast, öde_, _भावु, aast_
  { {0xc172000a,0xab960015,0x7afd5ebc,0xd116000a}},	//   _החג_, الرغ, _bast, _תקצה_
  { {0x2cb80152,0x3eb95ebd,0x6008000a,0xc052000a}},	//   sard_, cast_, _יִפְ, _לזו_
  { {0x68fc5ebe,0xa3b3000b,0xda650015,0x2cb844c6}},	// [f8e0] _pard, जीत_, لاكي, pard_
  { {0x63ad010b,0x7afd5ebf,0x2e3b000a,0x0000006a}},	//   ćanj, _east, _נגינ,
  { {0x78b504f9,0x68fc246f,0x8caa000b,0xddcd0085}},	//   _dezv, _vard, _ज्यो, _izaš
  { {0x47890036,0x7afd5ec0,0x68fc20e2,0x31650c0c}},	//   всім_, _gast, _ward, holz_
  { {0xbb3b0053,0xe4e6042b,0xa5f803ae,0xae07000b}},	//   _טעטי, гійн, телу_, शियन_
  { {0x68fc0c23,0x25a614a1,0x7afd340e,0x3eb9006f}},	//   _uard, rpol_, _zast, zast_
  { {0xc7f8000a,0x63e60015,0xb7950054,0xb8ea000b}},	//   _בִּר, استك, _врућ, ोल_
  { {0xfbac005d,0xe76a0015,0x6ab2000b,0x61360003}},	//   टीएम, _أحسن_, _ज़ोर, _mâle
  { {0x3eb9069a,0xe4d60029,0x20070026,0x612d00dc}},	//   vast_, _متاب, _arni_, _túll
  { {0xdcb10092,0xdbd1007c,0x99f7000a,0x09f7004f}},	//   ửi_, _püüg, נזיה_, נמים_
  { {0x0493003b,0xb5fd0007,0x03c5005e,0x3eb93a47}},	//   _المح, _ryši, _всім, tast_
  { {0x539b000a,0x8857004c,0xc7d7000a,0x32062ac8}},	//   _נידו, רשטע_, נוכי_, _troy_
  { {0x3eb95ec1,0x4917000b,0xe731000a,0x7afd195f}},	//   rast_, नामो_, חֵם_, _rast
  { {0x01fb0008,0xfbac000b,0x27e6002a,0x3eb95ec2}},	//   _נפול, टीऍम, łony_, sast_
  { {0x8ca4005d,0x11690086,0xb09b0135,0x3eb95ec3}},	//   कड़ो, _جلوی_, _טיגר, past_
  { {0xdb150030,0xa08b004f,0xe451004f,0xc5fe01ec}},	//   pszí, _נְגִ, קֶם_, ķēja_
  { {0x7afd5ec4,0xcd34002b,0x2a980015,0x2b495ec5}},	// [f8f0] _vast, _گريب, ائفة_, riac_
  { {0x2b49002c,0xfe700015,0x7afd5ec6,0x0000006a}},	//   siac_, _عدي_, _wast,
  { {0x7afd5ec7,0xf8070033,0x59c7000b,0x57f51114}},	//   _tast, ычан, _लिवर, рпет
  { {0x8c1a000f,0x2d830030,0x75215ec8,0xd3660015}},	//   _סורי, lmje_, _solz, _ذه_
  { {0xfad600b2,0xeef80053,0xa6470086,0x75210144}},	//   _דורך_, טמאר_, دخان, _polz
  { {0x69cd0176,0x6fc5000b,0xc7b70015,0xd626005e}},	//   mrae, _विलं, _مصرع, роше_
  { {0xd5380029,0xc6a7049d,0x9cd8000a,0xd3f90033}},	//   دثنا_, _брзи, אווה_, тэлі_
  { {0x1309006d,0x66280247,0x1bfc000a,0x032519cc}},	//   тний_, íská, תלהב, рдин
  { {0x11d60029,0xd24e002b,0xd346002b,0xa2350033}},	//   لوية_, وچه_, جینه_, рэйш
  { {0x60090164,0x6f1d002a,0x29015ec9,0x3fe50d1f}},	//   вном_, ejsc, ndha_, ажов
  { {0xb4c3000b,0x9fc9006b,0x1603000b,0xa2f51119}},	//   ्ली_, ъгна_, लिवर_, _впеч
  { {0x200700bd,0x9f5d002c,0x539a0008,0x6d5504ed}},	//   _vrni_, _prvá_, _סינו, enza
  { {0x471a0008,0xe28e01cf,0xad660058,0x7205009a}},	//   דורג, _фа_, لاسه, _خوشم
  { {0x69cd0176,0x4f950004,0xb23a004c,0x61360003}},	//   drae, _криу, _בענז, _pâle
  { {0x6ab603de,0x29013578,0x8b260033,0x20070e01}},	//   исах, ddha_, адве, _urni_
  { {0x2911003f,0x9f5d0227,0xce5a0015,0x6d555eca}},	//   _anza_, _trvá_, _لشخص_, anza
  { {0x394604c2,0xc896009c,0x0d760033,0x7ae45ecb}},	// [f900] анаг, арењ, _выня, rfit
  { {0x78bb0152,0xf0920053,0x993902e1,0xba170015}},	//   _œuvr, ַנד_, ляху_, جيكا_
  { {0x98aa0011,0x22a60046,0xf71a0033,0x0000006a}},	//   _albă_, líků_, кіды_,
  { {0x95ca070e,0x66092716,0x8b9b000a,0xf7190033}},	//   вука_, _brek, _שבכת, лічы_
  { {0x22a60089,0xb4c3000b,0x6b8429fb,0xfe9b000a}},	//   níků_, ्लू_, mmig, דינמ
  { {0x4a57000a,0x03c60785,0xdb150030,0x6b8404f6}},	//   _כשכל_, асим, mszá, lmig
  { {0xdb1500dc,0xd4990036,0xc448002b,0x6f1d002a}},	//   lszá, урі_, دیان_, yjsc
  { {0x661600f2,0x66095ecc,0xb7d70015,0x7aa9000a}},	//   äyks, _frek, _خوفا_, ְׁתֵ
  { {0xdb1500dc,0x660902d2,0x24f61742,0xd5e90015}},	//   nszá, _grek, _вчер, _معلن_
  { {0x6b8400b8,0xf8b3004c,0xf6090015,0xd1340054}},	//   hmig, ֿשר_, _حتفه_, сноћ
  { {0x88bb000a,0xc2c6002b,0xb4d2000b,0x653b000a}},	//   כזיי, _نياي, वली_, _שעבד
  { {0xdb1500dc,0xf2060033,0x91e606a6,0x14170015}},	//   kszá, _вяко, _воде, _خيمة_
  { {0x97570008,0x51f60002,0x9e670015,0x9df8024f}},	//   שיכו_, _خسار, شاحن, анят_
  { {0xc5f30008,0xa3b3005d,0xc27b000a,0xd0d3006b}},	//   חדש_, जीव_, _סרגי, _дошъ
  { {0x717b000a,0x0137000a,0xb17b015b,0xdb150030}},	//   _שנוס, _דרגת_, _שטור, eszá
  { {0x4ea700d0,0x69c2000b,0x69cd5ecd,0x9ed91068}},	//   _трка, _लिखी, trae, _смит_
  { {0xdb1500dc,0x6ce7017f,0x0f7c000a,0x63ad0085}},	// [f910] gszá, _кіне, _באהב, ćani
  { {0x69cd0b84,0x28a70010,0xadd6000a,0xf807023c}},	//   rrae, ршаг, _פותח_, ичен
  { {0xb8ef000b,0xd618002b,0xb8680004,0xdb150030}},	//   _षय_, یتها_, ајце_, aszá
  { {0x7bd50061,0x660905e3,0x16c80015,0x69cd5ece}},	//   muzu, _prek, لِمٍ_, prae
  { {0x06c80036,0xaae6002b,0xf6500067,0xd4910016}},	//   ргій_, _اسپو, وئه_, _hài_
  { {0xbdf80008,0xe4e70036,0xb4c3000b,0x7544005e}},	//   שֶׁה_, рідн, ्ले_, оніз
  { {0x7bd50064,0x03940010,0x27fc02de,0xd7f809d3}},	//   nuzu, орыя, ævnt_, _кут_
  { {0xcc58009d,0xfc58000f,0xdc58000a,0x83640015}},	//   יבוי_, יבוש_, יסוח_, يديل
  { {0xe1f10029,0x13060080,0x16340080,0xf1a90015}},	//   سسة_, сный_, _детя, داعه_
  { {0x23e70191,0x64a40001,0x24750016,0x80a9004a}},	//   _відв, _мађа, _t́m_, ывов_
  { {0xe1880029,0xe8df0092,0x612d5ecf,0x40494068}},	//   جئين_, _ngọc_, _júli, упно_
  { {0x2295003b,0x612d0030,0xd5c500fd,0x9888004f}},	//   _الإس, _múli, _вiдн, יָרֵ
  { {0x52850029,0xa3b30065,0x0000006a,0x0000006a}},	//   _الشك, जीर_,   ,
  { {0xa009003b,0x61360045,0x7bd51999,0x5274002b}},	//   _مقتل_, _vâlc, fuzu, _بامز
  { {0xd4910023,0x201801be,0xe3a700c3,0x6b842cc8}},	//   _bài_, ärit_, ثر_, tmig
  { {0xd4910023,0x2b9c0089,0xdb1500dc,0x6b84007c}},	//   _cài_, _víc_, tszá, umig
  { {0x3b070063,0xd4910092,0x58960015,0x6a830054}},	// [f920] щето_, _dài_, مجاز, злта
  { {0xdb150014,0x6b8404d2,0xb4c3000b,0x7bd55ed0}},	//   rszá, smig, ्लो_, buzu
  { {0xca290632,0xdb1500dc,0x3cfb000a,0x28a7000b}},	//   עם_, sszá, _גלינ, गड़ि
  { {0x98b80064,0xd6d90036,0x0745005e,0xdb150030}},	//   ızın_, иті_, охім, pszá
  { {0x690100f2,0x80d8000b,0xd7050015,0x291c0123}},	//   öydä, _माले, تظلي, övas_
  { {0x6d4e5ed1,0xdb050003,0xe9a30788,0x3cc9004f}},	//   niba, _athè, _харп, ֑לוּ_
  { {0xccf30008,0x29370053,0x69d60077,0xa3180342}},	//   פכה_, _פאלן_, luye, ижку_
  { {0x236000bd,0x8c1b0053,0xc2980001,0xe44f0015}},	//   čijo_, טוצי, шких_, عضو_
  { {0x94060086,0x9b17000a,0x569b000a,0x6d4e5ed2}},	//   _گواه, מחקה_, _תימצ, kiba
  { {0x6d4e00e8,0x86370008,0x7af6008c,0x859b004f}},	//   jiba, _הרמב_, heyt, _עשבו
  { {0x28dd000b,0x7af63c28,0xb145002b,0x16030065}},	//   न्टि, keyt, تیوم_, लिअर_
  { {0xe29a0e88,0x7bd50064,0xc3050015,0x6d4e03f8}},	//   _сад_, vuzu, _وبنو, eiba
  { {0x5186008f,0x442e5ed3,0x877b004c,0x78be00aa}},	//   _лука, lyf_, טאטי, kapv
  { {0xab950001,0xd657000a,0x91f7000a,0x2018007c}},	//   жављ, מיכת_, _למדו_, äris_
  { {0xdfa600e5,0x1b770015,0x7c341c80,0x7b770058}},	//   _احتي, مدرج, перх, مطرا
  { {0x7bd5003f,0x9057000a,0xb065008c,0x6d4e5ed4}},	//   ruzu, _לסוף_, seää, aiba
  { {0xd4910092,0xce33002b,0x7bd50046,0x4a553be6}},	// [f930] _vài_, _رودک, suzu, цкас
  { {0x2be2005d,0x127b0053,0xce38000a,0x27050016}},	//   _पहचा, ראמע, _לאחת_, _ồn_
  { {0xd49100a7,0x38350033,0xaa950923,0x0a9501f3}},	//   _tài_, ўнер, _минч, _маню
  { {0xdc88000a,0x69d6492b,0x291c0123,0x9a872666}},	//   _לְרָ, buye, övar_, _гугл
  { {0x35e70191,0xceb40008,0x2cb200c0,0xc64b0015}},	//   сцев, ליף_, _ändå_, دجال_
  { {0x2c830152,0xdb1c001a,0xa50918fc,0x53f90058}},	//   cédé_, lurð, река_, لربح_
  { {0xb97a000a,0x63e40015,0x3ea20123,0xe5700015}},	//   _כנשי, كسيك, yckt_, رطه_
  { {0x644f005c,0x6d4e0410,0x5c38000a,0x29035ed5}},	//   _ścis, ziba, מרון_, _haja_
  { {0x612d00dc,0x7c2e002a,0x4252002b,0x290301bc}},	//   _múlv, zybr, وچهر, _kaja_
  { {0x95570002,0xe3b30015,0xa5080054,0x59da000b}},	//   _اخرا, _فرص_, _леђа_, यंतर
  { {0x3d1d005d,0x29035ed6,0xdb1c001a,0xc4550058}},	//   माने_, _maja_, kurð, _بَاب
  { {0xb7da0135,0x3e8a024f,0x7c2e013f,0x6d4e355c}},	//   סקרי, ийно_, vybr, wiba
  { {0x5fc5014e,0xc332013a,0xaa7b0089,0x7c2e0026}},	//   _विकल, _קוד_, _zbýv, wybr
  { {0xd00915e6,0x6d8b002a,0x20190058,0x0000006a}},	//   _веке_, _mżaw, _نتبع_,
  { {0x7af6022d,0x69cb02c1,0x6fb50029,0x6d4e5cca}},	//   teyt, ágen, _بمعا, riba
  { {0x69d602c1,0xdb1c001a,0x6d4e5ed7,0xf5480016}},	//   tuye, gurð, siba, hụp_
  { {0x7af60084,0x3d0a000b,0x394a0054,0x29035ed8}},	// [f940] reyt, ायदे_, азао_, _baja_
  { {0x38cb0074,0x6f04002d,0x3ea50089,0x29030077}},	//   لامی_, _haic, ělte_, _caja_
  { {0xdb1c002e,0xeb9a0001,0xc8b50033,0x61fb0012}},	//   burð, _њим_, ясты, hwul
  { {0xeab20029,0x69d60152,0x929d002a,0xe73a03ae}},	//   _تعد_, puye, ydła, јед_
  { {0xd4910092,0x442e0026,0x1af7000a,0x6f040045}},	//   _màu_, wyf_, _ומכל_, _maic
  { {0x69c40048,0x2d930003,0x6f045ed9,0x29035eda}},	//   msie, _xixe_, _laic, _gaja_
  { {0xcb12000a,0x18790033,0x6f1657f9,0x69c45edb}},	//   ֵל֙_, _гётэ_, _onyc, lsie
  { {0x4420010b,0x442e020a,0x6702005d,0xc1b80036}},	//   ći_, ryf_, _रोचक_, блих_
  { {0x69c45edc,0x316e01c2,0xf1aa0015,0x78bc5edd}},	//   nsie, _pkfz_, جابه_, _kerv
  { {0xe7d1000b,0x308a006b,0x75d30021,0x69c45ede}},	//   _हिमप, ищно_, _آيلا, isie
  { {0xa2e60124,0xb97b0008,0x889b0008,0x67220091}},	//   _можд, שניי, יביי, ojoj
  { {0x93fb000a,0x6722008c,0x69c45edf,0x78bc5ee0}},	//   _כלבי, njoj, ksie, _lerv
  { {0x35d2005d,0xada40010,0xb2370029,0x7528005c}},	//   _सिफ़, маўл, _وكما_, _kodz
  { {0x3af50016,0x158a000a,0x78bc533a,0x23690b28}},	//   _ấp_, ינָֽ, _nerv, čaje_
  { {0xdb1c002e,0x4fb30029,0x29035ee1,0x5f770015}},	//   turð, _قصير, _raja_, _واعر
  { {0x75280048,0xbfa30092,0x2903013c,0xc214000a}},	//   _lodz, _miễ, _saja_, ֔הּ_
  { {0x69c40024,0x5ee80008,0xb9350004,0x78bc1418}},	// [f950] gsie, _וַתְ, пеај, _berv
  { {0x75282adb,0x48ab0128,0x78bc5ee2,0x6f0402ad}},	//   _nodz, ртам_, _cerv, _zaic
  { {0x29030005,0xd6d10015,0x78bc5ee3,0xc7c4004a}},	//   _vaja_, فقا_, _derv, дсчи
  { {0x44390024,0x6d54002a,0xdb14001a,0xe7870a32}},	//   _ās_, ągał, _þaða, цузо
  { {0x2903003f,0xe945002b,0xfb1a000a,0x64a50c1d}},	//   _taja_, _فرآی, _הורמ, пала
  { {0x7528005c,0x64a536bb,0x8548005e,0x78bc5ee4}},	//   _codz, чака, озів_, _gerv
  { {0x7d05000c,0x07f80015,0x61360045,0x2bcb000a}},	//   _mahs, _ورفع_, _pâln, ׁמַ֣
  { {0xd687006b,0xfc5c000a,0xbfa30016,0xb3840015}},	//   _дузп, יכומ, _diễ, وجيه
  { {0xe4e7009e,0xda0e000b,0x0000006a,0x0000006a}},	//   _міжн, सियत_,   ,
  { {0x75280050,0x8a160008,0x213e003e,0xb7ff000b}},	//   _godz, פחתו_, ghth_, _ईनाम_
  { {0xf994000a,0x2d4d0046,0x63ad0085,0xa0695ee5}},	//   ורץ_, ržel_, ćans, сана_
  { {0x547a0008,0xd5df000b,0x9836000a,0xe3b0012c}},	//   _הטעו, _नमाज, פטרו_, _شرم_
  { {0x6f040024,0x7d050064,0x612d001a,0x61360416}},	//   _vaic, _bahs, _súlu, _gâlo
  { {0xcfe90074,0xdb1c002e,0xd13100a2,0x612d524a}},	//   _هفته_, rsrí, _سمع_, _cúlt
  { {0x799d018b,0x7aef0064,0x673b0e1d,0xd4910016}},	//   _ausw, _bbct, _oluj, _tàu_
  { {0x3f670063,0x69c45ee6,0x2f55004a,0x78bc3605}},	//   _нищо_, tsie, _отыс, _serv
  { {0x7f3b0008,0xdb1c0020,0x78bc5ee7,0x4a460004}},	// [f960] _לעקו, kurö, _perv, чнав
  { {0x6aa45ee8,0x30d9000a,0x60c12b8e,0x69c45ee9}},	//   scif, מַ֣ע, nalm, rsie
  { {0x75280050,0x78bc09f2,0xdc9b000a,0x4c9b0447}},	//   _rodz, _verv, _לסיכ, _לשיע
  { {0xeafa0029,0x6d5c0024,0xe61a106d,0x69c4014c}},	//   _اردت_, lnra, йде_, psie
  { {0x60c10014,0x4ecb00b2,0xceb30008,0x672200f2}},	//   kalm, מזײַ, תיד_, rjoj
  { {0xa6130010,0x994f0064,0x673b007c,0x629900aa}},	//   эміч, müş_, _eluj, _agwo
  { {0x60c100dc,0xe3af0015,0x673b0077,0xdb070123}},	//   dalm, هري_, _fluj, rsjö
  { {0x7528005c,0xbfa30092,0x92940033,0xdce70085}},	//   _wodz, _viễ, майц, vojč
  { {0x257603c4,0xfb1b0008,0x60c1003f,0x994f0064}},	//   _فهرس, מוקמ, falm, nüş_
  { {0xe1ef06e4,0x64a3000d,0xb034059c,0x9263002b}},	//   اسي_, _зафа, днош, رگنم
  { {0x64430050,0x7d0500d9,0xc057017f,0xa786000a}},	//   czni, _rahs, зія_, ּךָ֔_
  { {0x987b0008,0x08570008,0x60c10020,0xa8570008}},	//   מריק, לבים_, aalm, לייה_
  { {0x0e340080,0xd259003d,0x6abd1964,0xeea80033}},	//   еняю, paņa_, _resf, ятэк_
  { {0x2ba700d0,0x3f9c003d,0x3e540015,0xe6b9000b}},	//   зјав, _tuvu_, رَّز, _उज्ज
  { {0x961d0048,0x317b000a,0xc103002b,0x417b000a}},	//   _izņe, _האגד, _سويي, _הנגב
  { {0x905b000a,0xc99b0015,0x0a6b011e,0x6d5c0416}},	//   _לכות, مخطط_, брзи_, anra
  { {0x433b0053,0x7d050064,0x612d00dc,0x799502ed}},	// [f970] צעמב, _tahs, _túlt, диаф
  { {0x673b0011,0x9cf50010,0x929d002a,0x28e2000b}},	//   _sluj, _ўзні, ydło, _पाणि
  { {0x97350074,0xed600007,0x3f920061,0x27f900c3}},	//   وکرا, ėžti_, _önuç_, تفاد_
  { {0xf77003c4,0x60c11099,0x7bc7003d,0x67b80015}},	//   هان_, zalm, msju, سامح_
  { {0xc1780007,0x247c0016,0x7aed17ff,0x8cc10065}},	//   klė_, _ảm_, mfat, वरपो
  { {0x7bd50d24,0x7aed5eea,0x644302ad,0x0000006a}},	//   orzu, lfat, tzni,
  { {0x62860264,0x60c15eeb,0xd389004a,0x7bc72078}},	//   ýkon, valm, ойке_, nsju
  { {0x7aed5eec,0x613f0003,0xe8940033,0x42d5008b}},	//   nfat, _mêle, _чась, фіку
  { {0x7aed0176,0x82f90086,0x45d400d0,0x60c15eed}},	//   ifat, مرکز_, _потс, talm
  { {0xe1250036,0x7bc7007c,0x25ad0546,0xc1780073}},	//   ємни, ksju, _itel_, glė_
  { {0xe4350015,0x9267002b,0xdb0e0012,0x60c12b8e}},	//   _تفاد, _کدام, tsbü, ralm
  { {0xd24e04b6,0xd3d80029,0x7bd5005c,0x60c12724}},	//   انی_, _ربما_, drzu, salm
  { {0x612d0125,0x7aed1b6f,0x60c10a35,0x4e7a0058}},	//   _dúlr, dfat, palm, تحدد_
  { {0xdd920067,0xdb14001a,0x6d5c008c,0x994f0061}},	//   ئوس_, ðaþj, unra, vüş_
  { {0x7ff50086,0x8b96000d,0x2b405d87,0x7aed5eee}},	//   _آستا, драч, thic_, ffat
  { {0x7e76022d,0xf0920008,0xb0dd005d,0x49ba0029}},	//   _tyyp, _בנו_, _माँग, قائد_
  { {0xda660086,0x61e95eef,0x320d00da,0x79400012}},	// [f980] ذاري, ntel, nvey_, _löwe
  { {0x718a0053,0x497a0010,0x994f0064,0x2360044c}},	//   ַװײַ, ісаў_, rüş_, čiji_
  { {0x2b40003e,0xad1b0053,0xa6ca0015,0x61e92022}},	//   phic_, _וויר, قوال_, htel
  { {0x0ab60029,0x48fa000b,0xd6cf0015,0x61e93716}},	//   _تحدد, _उसको_, لقم_, ktel
  { {0xb0dd005d,0x7bdc013c,0x8afb000a,0xbafb000a}},	//   _मांग, luru, _והכי, _והכש
  { {0xbbe9002b,0x61e95ef0,0xb8f60058,0x200b01ec}},	//   _بریم_, dtel, _تكسب, ācij_
  { {0x7bdc0849,0xdce70024,0xe73a0036,0x8cd7000b}},	//   nuru, nojā, _дев_, _बाघो
  { {0x61e95ef1,0x7bdc01c2,0xc1b809c2,0xe3af0058}},	//   ftel, iuru, плих_, جرو_
  { {0x96760010,0x2d4d0046,0x7bd5002a,0x61e95ef2}},	//   _цыві, užek_, zrzu, gtel
  { {0x7bdc1437,0x3ea90011,0x2369044c,0xd40a0015}},	//   kuru, _sfat_, čaja_, _وتضم_
  { {0xe8d70008,0x78fb000a,0xe58b000a,0x250b002b}},	//   וויר_, חליפ, _וָאָ, _برقی_
  { {0xdce70024,0xdb1500dc,0x14390086,0x7bdc5ef3}},	//   dojā, sszú, _عينک_, duru
  { {0x61e90011,0x7e2b0010,0x925a0115,0x92670138}},	//   ctel, ціна_, _بشار_, _орша_
  { {0xd0100086,0xc05a0036,0x961d0024,0x61130010}},	//   _ملت_, _мій_, _uzņe, _адшу
  { {0xdd9404f7,0x9b1b00a2,0x9f5930e6,0x80db000a}},	//   тары, يترز_, író_, _וחוז
  { {0xd1381256,0x7bc70123,0x0000006a,0x0000006a}},	//   lką_, rsju,   ,
  { {0xf99f08e0,0x0dbb0074,0x25fe005d,0x59d90010}},	// [f990] _què_, _باعث_, _शैली_, ядаў_
  { {0xd1380c85,0x200b002a,0xdce7003d,0x98a3003d}},	//   nką_, łcie_, bojā, _bojā_
  { {0x25ad1786,0x61e900dc,0xdca40004,0xdb070030}},	//   _stel_, ztel, _шаќи, apjá
  { {0x98bf01e2,0xdc360053,0x290701a3,0x0057000a}},	//   ırın_, _נארט_, žna_, ושבת_
  { {0xd246003b,0xfad60008,0xf7700031,0x75e40015}},	//   _إن_, _אורך_, جال_, نأوك
  { {0x06080010,0x3878002e,0x61e900dc,0xf50606b3}},	//   ьнік_, _fyrr_, vtel, еншл_
  { {0xd138005c,0x36d514a3,0x6b8d5d4b,0xd3b90033}},	//   dką_, _повр, omag, чулі_
  { {0x61e95ef4,0x4917000b,0xd138002a,0x26cd0085}},	//   ttel, नाको_, eką_, _udeo_
  { {0x515515b3,0x61e91786,0x8aa8000a,0xd774006e}},	//   етну, utel, וֹתֶ, _شافع
  { {0x7bdc0064,0x320d5ef5,0xd116000b,0x34b50015}},	//   yuru, rvey_, तागण_, _أماز
  { {0xdbd70209,0x6d555ef6,0x61e95ef7,0x68e1001a}},	//   _jääv, diza, stel, _öldu
  { {0x9f480134,0xc7d60008,0x7bdc0064,0xcce9000a}},	//   _opnå_, עורי_, vuru, _לכ_
  { {0x64640011,0x6d555d53,0xee374976,0xae07000b}},	//   ătiţ, fiza, еня_, शिगन_
  { {0xd138005c,0xdce7003d,0x91e201c5,0x8c9600fd}},	//   cką_, tojā, _соше, ербі
  { {0x629c0089,0x7bdc007c,0x6b8d001a,0x913a000a}},	//   ěrov, uuru, fmag, _מעסק
  { {0xc9aa0010,0x6b8d00dc,0xdce70024,0xab270155}},	//   звае_, gmag, rojā, носа_
  { {0xfe720029,0xe9da5ef8,0xed5a006b,0xdca6025f}},	// [f9a0] _حدث_, яка_, _нои_, _папи
  { {0x186a0063,0x8cc1005d,0x6d55031f,0x35c9000b}},	//   пази_, वरणो, ciza, _रिज़
  { {0x3d1d005d,0x59750010,0x31360053,0xc7af0015}},	//   मारे_, тыту, ענעם_, مّل_
  { {0x8bd7000a,0xd6d20021,0xd138002a,0x16a7098a}},	//   _אוטו_, اقش_, zką_, евци_
  { {0xba9b039e,0xdd8f002b,0xd138002a,0x6a9b0c44}},	//   _מסכי, _خوی_, yką_, _משכנ
  { {0x9633008f,0x83f8107c,0x2ebe0065,0x0000006a}},	//   ыніц, декс_, ्णुत,
  { {0x769601e2,0xd91b000a,0x443a0016,0xd75a0015}},	//   _büyü, _צולל, áp_, _فلست_
  { {0xfbd30008,0x290a13bf,0xd138002a,0xf99f0003}},	//   אתה_, _haba_, wką_, _grès_
  { {0xd2500074,0xd138005c,0x290a0061,0xdb1c0123}},	//   شند_, tką_, _kaba_, msrä
  { {0xd1380007,0xd1340001,0x04b50033,0x26c600da}},	//   uką_, тноћ, _асця, laoo_
  { {0xd13810da,0x53e50015,0x6b8d5ef9,0xc445002b}},	//   rką_, _لأنف, ymag, _لیون_
  { {0xde590010,0x71a60210,0xd13810da,0x1c14000b}},	//   дамі_, _задз, ską_, डिनल_
  { {0x6b430020,0xd138002a,0x82330040,0x6b650091}},	//   _jõge, pką_, _مروا, jėga
  { {0x463b0053,0x10740080,0x23600085,0xef18003d}},	//   לעכע, _иллю, čiju_, ēļa_
  { {0x291f0092,0xa926003d,0xe58b000a,0x6d550bda}},	//   _đua_, iežā, לָלָ, riza
  { {0x6b8d0035,0x807b000a,0x307b000f,0x9f680033}},	//   umag, _מנוצ, _מאונ, _прыз_
  { {0xeed6000a,0x290a34a4,0xdb1c0123,0x49751764}},	// [f9b0] _בֵית_, _baba_, dsrä, влас
  { {0x3eb9018b,0xdbd7008c,0x49b80015,0x6b8d4ef4}},	//   lbst_, _pääv, عاقد_, smag
  { {0xf99f0152,0x28e2005d,0xb909021e,0x290a56ac}},	//   _près_, _पारि, _या_, _daba_
  { {0x96350033,0x613f0003,0xec36000a,0x87d40015}},	//   кнец, _mêla, _יאתר_, اغلا
  { {0x5b140063,0x05a8005e,0xa5091c4c,0x61360045}},	//   _смят, евій_, дела_, _tâlh
  { {0xe3c50015,0x0000006a,0x0000006a,0x0000006a}},	//   نْتَ,   ,   ,
  { {0xf99f038d,0x3ce9005d,0xd408002b,0xe759005e}},	//   _très_, _जाने_, فتيم_, _живі_
  { {0x3f890023,0xb7940029,0x9f5d002c,0x236900bd}},	//   _nhau_, _مؤقت, _prvý_, čajo_
  { {0x3392003b,0x13060080,0xd49b0001,0xe2a80087}},	//   جليز, тный_, _ере_, راين_
  { {0x63a10020,0xe4d70015,0x442b02ed,0x32da007f}},	//   _tuln, _ستطب, _нцем_, tüyü_
  { {0x3f6a3c89,0xe51e000b,0x00820342,0x04c80015}},	//   дино_, पारि_, ильо, _سوني_
  { {0x3f890034,0x32550a10,0x0000006a,0x0000006a}},	//   _chau_, _ивер,   ,
  { {0x8336004c,0x2d9a1873,0x91e52c63,0x0000006a}},	//   _שאנס_, _pipe_, _роле,
  { {0x10a20054,0x3afc0016,0xde0302d9,0x0000006a}},	//   _кишн, _ập_, јпри,
  { {0x73ac000a,0x290a44b1,0x40320004,0x60c301ec}},	//   ּימֵ, _raba_, _вејс, _ienm
  { {0x6b63119f,0xf8b90016,0x2d9a00da,0x207a000a}},	//   акса, _đũa_, _wipe_, _קאקא
  { {0xc332011f,0x9e660036,0xdb1c00c0,0x2d9a1f36}},	// [f9c0] בון_, _швид, vsrä, _tipe_
  { {0x3ce9005d,0x58960015,0x61360003,0xdb1c17ca}},	//   _जाये_, نجاز, _pâli, dsrå
  { {0x290a0020,0x65f10053,0x68460015,0xc8960054}},	//   _vaba_, _געפֿו, خَال, трањ
  { {0x7c2101f0,0x6b43007c,0xd5c501f3,0x60c35efa}},	//   ålre, _põge, _гiмн, _lenm
  { {0x7bda5c4f,0x7ae402f2,0xa4d4008b,0xfb1b000a}},	//   štud, mgit, голі, _חוכמ
  { {0x7ae40005,0xcdb70008,0x92a6002a,0x660201d7}},	//   lgit, דפסה_, zełę, rwok
  { {0x8d5b000a,0xb906000b,0x660201d7,0xf3660e41}},	//   וכסי, फल_, swok, ктин
  { {0xd5b20074,0x7ae40cf5,0x799c0e42,0x68e1171f}},	//   _نفر_, ngit, _hirw, _öldr
  { {0xe5a635fe,0x6d80008c,0x7ae45efb,0x35a64e39}},	//   _ризи, töal, igit, _разг
  { {0x3ea00152,0xc3d60010,0xe5060015,0x0000006a}},	//   _agit_, _аўды, _جبري,
  { {0x41d4005d,0xc9530008,0x70540087,0xd250002b}},	//   _दिवस, שמת_, انجا, شنگ_
  { {0x60c3016b,0xfbd3009a,0x3eb902ad,0x0000006a}},	//   _eenm, یتز_, ubst_,
  { {0x3eb900b8,0x91e3005e,0x914a01c5,0x26c4531c}},	//   rbst_, _воче, _очка_, _memo_
  { {0x799c1984,0x760b000a,0xc69305bd,0x5d850040}},	//   _nirw, וּלַ, יאר_, السل
  { {0x2d4d016f,0xead5033d,0xcc54006b,0xe0fb000a}},	//   džet_, ловь, авръ, _חלול
  { {0xa0970008,0xeab30029,0x98a3005c,0xb0970008}},	//   _בדוק_, شعر_, _moją_, _בדוח_
  { {0x61e00064,0xab94005e,0xbae40015,0xba740015}},	// [f9d0] numl, риті, شكلي, لاكت
  { {0x58b8003b,0xd8b80029,0x3ad30092,0x60c80167}},	//   نامج_, ندما_, ệp_, nadm
  { {0x799c0026,0xd7d5009c,0xf807006b,0x644a0030}},	//   _dirw, ужењ, ъчан, jzfi
  { {0x61e00024,0x2366016f,0x26c40085,0x799c0034}},	//   kuml, _njoj_, _cemo_, _eirw
  { {0x61e05efc,0x6d47008c,0xd5e80015,0x60c804d6}},	//   juml, ohja, نعون_, kadm
  { {0x04c90029,0x3cdc000b,0xa3e9213b,0x98a30535}},	//   روبي_, _बाज़ा, едка_, _boją_
  { {0xe4e40036,0x6d4b0007,0xc3c800e6,0xf3c80021}},	//   річн, _įgal, نظيم_, نبيه_
  { {0x4429010b,0x13050001,0x42090001,0x60c80020}},	//   ća_, узим, енио_, eadm
  { {0xdb1500dc,0x69cd0034,0x60c30702,0x6b9d5efd}},	//   lszó, nsae, _penm, _misg
  { {0xea160053,0x81450018,0x4a7c000a,0x6609007c}},	//   אַטי_, اندن, ורחב, _isek
  { {0x68e5002d,0xf4080015,0xb5fd0091,0x6b650091}},	//   ighd, _ليلى_, _ryšy, jėgo
  { {0x29cf0048,0xe1f10086,0xdb1500dc,0x6b9d00e7}},	//   kļa_, _هست_, gszü, _nisg
  { {0x8e56017f,0x8e55005e,0x290104f6,0x60c35efe}},	//   утні, атрі, keha_, _tenm
  { {0xafe50063,0xe6e0005d,0x6b9d002d,0x29010085}},	//   _бокл, _पञ्ज, _aisg, jeha_
  { {0x6563003c,0x6c860015,0xa0090015,0x8c4318dc}},	//   innh, الأم, _أقبل_, бере
  { {0x2ee6004a,0x3b070248,0x7ae40072,0x9f950138}},	//   _сжиг, лесо_, ugit, _кшыш
  { {0x7ae40020,0xc332000f,0x6b9d0495,0x5ad30015}},	// [f9e0] rgit, זון_, _disg, صْلا
  { {0x7ae45eff,0x8288004f,0xcd06009b,0x0000006a}},	//   sgit, דְעֶ, _спой,
  { {0x8c260074,0x3ce9014e,0x7ae4003c,0x2d4d0089}},	//   _صفحه, _जाते_, pgit, ržet_
  { {0x7bce0bad,0xe5c6004a,0xdbd2007c,0x61e00061}},	//   msbu, гско, _müüv, yuml
  { {0x660900dc,0x99860015,0x26c400bc,0x799c0034}},	//   _csek, _ملحو, _vemo_, _tirw
  { {0x15b90010,0x7bdc2c46,0x18a308f7,0xa3b4005e}},	//   тыцы_, orru, _гарм, абкі
  { {0x0d17013a,0xdc360053,0xec360053,0x26c42fdc}},	//   טקסט_, טאַט_, טאַר_, _temo_
  { {0x395a0106,0x2481007c,0x722a0eaf,0xf74300eb}},	//   lips_, ühma_, ецов_, _лесо
  { {0xf2e70086,0xd1300029,0xcb37000a,0x25a4007c}},	//   اکمه_, قمة_, טאקי_, _uuml_
  { {0x61e001e2,0x21540010,0x929d002a,0x71f700c3}},	//   ruml, ркоў, jdłu, اريس_
  { {0xf5930029,0xd8db0053,0x4438003c,0x60c802cd}},	//   _اللج, עקטר, _ær_, radm
  { {0x32ba0029,0x395a003e,0x929d005c,0x9e150036}},	//   _أداة_, hips_, edłu, адмі
  { {0x2d4d016f,0x9757000a,0x9f5400e2,0x0000006a}},	//   džer_, ריכו_, свяч,
  { {0x3d0f005d,0xdb151e42,0x2bbb0015,0x709407be}},	//   ायें_, sszü, فارة_, _калф
  { {0xbc95000d,0x4c95005e,0x317b004c,0x75370643}},	//   равј, ривс, _ראוד, נאלד_
  { {0x29cf003d,0x929d0535,0xdb1501d3,0x0000006a}},	//   tļa_, adłu, vszó,
  { {0xb9550063,0x99550010,0x6b9d0091,0xa3e4000b}},	// [f9f0] аващ, акац, _visg, भूत_
  { {0x17fb0029,0x6b9d0034,0xdb150030,0xbb55002b}},	//   فرصة_, _wisg, tszó, _چندب
  { {0x290100b6,0x28870001,0x6d455f00,0xa3a90065}},	//   reha_, ућав, _ilha, _गंध_
  { {0xa615005f,0x87d800c3,0xdb150e8c,0xe70b00c3}},	//   имеч, ابلس_, rszó, عتان_
  { {0xdb150014,0x65950033,0xceb4015b,0x29010b28}},	//   sszó, ааду, ציס_, peha_
  { {0x8cba005d,0x25b60029,0x290f0024,0x89da000a}},	//   ्रयो, جهود_, ēgas_, _בחשי
  { {0xd928000a,0x29070034,0xad38000a,0x044507d0}},	//   _עֵשָ, ônau_, רנוס_, рейн
  { {0x94740086,0x660948b7,0xeab7000a,0x929d002a}},	//   حدها, _tsek, נִ֔י_, zdłu
  { {0x6d45001c,0x8cba005d,0xeb92000a,0xb14503b1}},	//   _olha, ्रमो, חָז_, инил
  { {0x3d0f005d,0x59da000b,0xe9ff0016,0xd095004a}},	//   ायों_, यूटर, _giấc_, ишны
  { {0xdcec0046,0xff260120,0xd3e6002b,0xd3d8002b}},	//   _řiďt, амно, _نقلی, _مبنا_
  { {0x82340086,0x2f56017f,0x80a7000b,0x98ab0091}},	//   _گرما, ртос, _फ़्रे, ėmęs_
  { {0x93940086,0xada648c6,0x2229002b,0x7bce2b7f}},	//   _اجلا, рагл, _جزای_, wsbu
  { {0x82340087,0x2d9e5f01,0xc0e20839,0x0d760033}},	//   _درما, öte_, _дошк, рымя
  { {0xdea20074,0x30790053,0x40790053,0x65f1004c}},	//   _ویدی, _באַנ, _באַװ, _געפֿי
  { {0x6d4500dc,0xbb43000d,0xfaa301c5,0xf1b9003d}},	//   _elha, оеск, жато, opš_
  { {0x3b0706ac,0xc9a7000d,0xeb971eb8,0x09e62103}},	// [fa00] шето_, ивте_, рит_, розн
  { {0xdce7002a,0xa92304e5,0x224d013b,0x0000006a}},	//   koję, одул, izek_,
  { {0xc7960010,0xd2590024,0xe6c60015,0x6d5c05ee}},	//   арды, maņu_, لتشي, mira
  { {0x28e2014e,0x09e612d2,0x3ea9000a,0xf7460054}},	//   _पाकि, _комн, ְכוּ_, једо
  { {0x3f82002a,0xe7370054,0x6d5c008c,0x3abb004f}},	//   ilku_, јеч_, oira, _במכנ
  { {0x6d5c5f02,0x5dc9000a,0xa96a2925,0x69bf0065}},	//   nira, אֶקְ, _рига_, _लौटी
  { {0xaaaa005d,0x6d5c0020,0xdce70091,0xb7da002b}},	//   _कलाक, iira, goję, _جوزا_
  { {0x42040015,0x320a002a,0x938a03ae,0x6d5c5f03}},	//   مِعْ, łbym_, њска_, hira
  { {0xa79b000a,0xd5a4002b,0x6d5c1ae7,0x926a006b}},	//   _ישלח, _طلای, kira, ърка_
  { {0x09f70008,0x32530010,0x98a3002a,0x3f8204b2}},	//   סמים_, івэр, _boję_, elku_
  { {0x940604b6,0x1306010f,0x506600d0,0x4254002b}},	//   _خواه, _взем, ртпа, شنگر
  { {0xd49100a7,0xc2e90029,0xf43b000a,0xc7d7000a}},	//   _này_, _معهم_, _שתאש, סוכי_
  { {0x224d005c,0x3f850024,0x443c002c,0x539b0008}},	//   czek_, ēlu_, lyv_, _סידו
  { {0x7c3c0034,0xd23b000a,0x6d5c5f04,0x6578016d}},	//   fyrr, _בגדל, gira, novh
  { {0xb0b7000a,0xd4910016,0xaba9002b,0x2ac70054}},	//   _דפוס_, _bày_, اهرم_, иљав
  { {0x4fb30031,0xb09b00a3,0x93fb000a,0x409b000a}},	//   _بصور, _ביור, כללי, _בבוס
  { {0xe29300b2,0x63a8005c,0x28a70080,0x5a35006b}},	// [fa10] ַװע_, _ludn, ашег, щнат
  { {0x6d5c0a00,0x8cba000b,0x236902d8,0x7e7c004f}},	//   cira, ्रणो, čaji_, _באחז
  { {0x2d83052c,0x57f508fc,0x06b7002b,0xd7c80067}},	//   mlje_, спет, لناک_, لوله_
  { {0xe796002b,0xd4910016,0xd366006e,0x2d830030}},	//   مانک, _gày_, _ره_, llje_
  { {0xa9970086,0x2d830b28,0x201a0160,0x0000006a}},	//   _نشست, olje_, _špil_,
  { {0x24e90036,0x3a360008,0xe5780127,0x2907007c}},	//   умки_, _הרשם_, азі_, õnad_
  { {0x6e3d0026,0xf9920008,0x612d0030,0x63a80bba}},	//   hysb, _זרם_, _túlz, _cudn
  { {0x6d5c5f05,0x29110030,0xdb050125,0xc6d40015}},	//   zira, _haza_, _athú, _وتقت
  { {0xb3080029,0x29113b69,0xf772000a,0xb062007c}},	//   شغيل_, _kaza_, _זקן_, äänu
  { {0x2911003f,0xdce7002a,0xdd0401ec,0x0000006a}},	//   _jaza_, poję, ēsīb,
  { {0x6d5c5f06,0x224d12f7,0x9327002b,0x99de0033}},	//   vira, szek_, _پران, зiла_
  { {0x6d5c5f07,0x83870033,0x29115f08,0x3ea40013}},	//   wira, _тызе, _laza_, ømt_
  { {0x23740029,0x02440029,0x471a0008,0xade3005d}},	//   _بالح, _وَمَ, אורג, कूलन_
  { {0x661b0fcd,0x7c3c0293,0xc692000a,0x291101c2}},	//   _mruk, tyrr, פאם_, _naza_
  { {0x8c432031,0x6d5c5f09,0xdfce0015,0x0000006a}},	//   пере, rira, _كيو_,
  { {0xce5a0086,0x6d5c0bd5,0x7aa6006b,0x7c3c0034}},	//   _مشخص_, sira, сиаз, ryrr
  { {0xd2590024,0x2d830263,0x29115f0a,0x39460033}},	// [fa20] paņu_, blje_, _baza_, бнаг
  { {0xeeeb0023,0x1e570008,0x4a43000d,0xc8ca0086}},	//   ượng_, _לשפר_, чнув, اوان_
  { {0x9b460002,0x7d37000a,0x07b70015,0x3ead1e01}},	//   _هندو, _הניב_, مهلة_, žete_
  { {0x661b0c83,0x7fd60053,0xab2a0054,0xb07a004c}},	//   _bruk, מועס_, _сома_, אנעז
  { {0x99160191,0x6b8416a9,0x9586005e,0x63a80e2a}},	//   _льві, mlig, блде, _sudn
  { {0x28e2005d,0xe853002b,0xd6250015,0x661b5f0b}},	//   _पाटि, _کنفد, تعمي, _druk
  { {0x1cbb0008,0xf1aa0086,0xd3d70115,0x9cd7000a}},	//   אמצע, گابه_, مبيا_, צוקה_
  { {0xe71a002b,0x8c1b000a,0x938a004a,0x61d801b7}},	//   _حيرت_, רוקי, ысла_, амия_
  { {0xd5b20029,0xcb130008,0xf1aa002b,0x6b845f0c}},	//   _رفض_, ללה_, دابه_, ilig
  { {0xf8ba005d,0x3a37011f,0x63a800dc,0xaa370053}},	//   ेरिय, צרים_, _tudn, צטיק_
  { {0xe1ef0086,0xe97b0053,0xdb1500dc,0x2d83044c}},	//   وسی_, רניש, mszö, vlje_
  { {0x6b843851,0x8f475f0d,0x7f5d0003,0xd13e002a}},	//   jlig, сход, uisq, _żąda_
  { {0x32960029,0x6b8402cd,0x0e440033,0x7bda0030}},	//   _الشأ, dlig, пэрм, átun
  { {0x6b650007,0x63a2002d,0x2d832645,0x216704bb}},	//   mėgi, _hion, ulje_, _личи_
  { {0x63a2003f,0x7bda016f,0x853b000f,0x6fb40002}},	//   _kion, štun, נגלי, _بمبا
  { {0xfb580029,0xbae50015,0x6b840a3a,0x61e00061}},	//   مؤقت_, تكري, glig, orml
  { {0x63a2002d,0xbef40015,0x9e95002b,0x5d850015}},	// [fa30] _mion, _رأيت, _باغچ, _ولعل
  { {0xdcee0045,0x6b845f0e,0x201c0735,0x63a20738}},	//   robă, alig, _krvi_, _lion
  { {0xe787042b,0x645e006f,0x6b845f0f,0x64b4000b}},	//   будо, úpil, blig, ुरैश
  { {0xcb0b0010,0x501b000a,0xdb0f008c,0x6b84050b}},	//   _сход_, טובו, äjär, clig
  { {0xbef80008,0x9f9c004c,0x6b650091,0xd629098b}},	//   מצאו_, אסאפ, jėgi, роле_
  { {0x33d90080,0xe4e7005e,0xfdf8000a,0x7d150030}},	//   афию_, сідн, צצות_, ndzs
  { {0xf8ae0086,0x7d07005c,0x23b2006e,0xc7c4005e}},	//   _شکل_, iejs, وموس, _нсти
  { {0xf1d4005d,0x63a24d74,0xf773002b,0x661b5f10}},	//   _दिखन, _cion, _راز_, _truk
  { {0xeab201e4,0x422505d1,0xab1a000a,0xdb150030}},	//   וֹת_, ідов, בֵית, bszö
  { {0xa7d3005d,0x628b00bc,0x7d150030,0x398f0061}},	//   _डिफ़ॉ, _vzgo, jdzs, büse_
  { {0x63a2002d,0x7afd5f11,0x6b845f12,0x9475002b}},	//   _fion, _obst, ylig, _بگشا
  { {0x26cf0035,0x7c2a0251,0x533402e1,0xe6070002}},	//   nago_, _àfri, _нехт, وش_
  { {0x80ba005d,0x237800dc,0xe0ce0175,0xadb70015}},	//   _श्वे, _írja_, _ов_, يهَا_
  { {0x23691007,0x7afd2395,0x200e008c,0xe4ed000b}},	//   čaju_, _abst, ämiä_, च्चि_
  { {0x3d09000b,0x6b840a3a,0xdca31068,0x40950058}},	//   ाज़े_, tlig, дари, _بلغر
  { {0xeeeb0092,0xf0920008,0x6b840595,0xf412000a}},	//   ưỡng_, _קנה_, ulig, ופל_
  { {0xf296004c,0x6b84153c,0x6d4b0091,0x8f9b004f}},	// [fa40] ַכער_, rlig, _įgav, _דיקי
  { {0x7afd019f,0x6e3b0012,0x6b845f13,0xb5a50138}},	//   _ebst, äube, slig, _улiч
  { {0xb902014e,0x7aef022d,0x6b841d31,0xcc8a002b}},	//   _नए_, äntö, plig, _خنده_
  { {0xf98900a3,0xc4b4000b,0x64b4000b,0xe61a030e}},	//   דר_, ुर्ख, ुर्श, иде_
  { {0x929d002a,0x63a25f14,0x2b4700d4,0x19b9066a}},	//   wełn, _rion, _înca_, _гусь_
  { {0x9e0b000a,0xf8a90015,0x98760054,0x63a24067}},	//   שִׁ֖, _هدفه_, _дубљ, _sion
  { {0x26cf00b6,0x53e60010,0xb4930001,0xd57502e1}},	//   bago_, іцка, мишљ, чуць
  { {0xdb1500dc,0x26cf164a,0x0377002b,0xa857000a}},	//   sszö, cago_, يحيت_, _וילה_
  { {0x416a0001,0x63a2003f,0x6d4e00d9,0xc20700c3}},	//   ијом_, _vion, khba, ققين_
  { {0x321d0176,0x929d0050,0x201c0a00,0xa5460015}},	//   _drwy_, pełn, _prvi_, _بضرو
  { {0xf8b30008,0x6d4e002d,0x60ca002e,0x63a220f4}},	//   ושת_, dhba, _vefm, _tion
  { {0x80ba014e,0x71a60010,0x0000006a,0x0000006a}},	//   _श्रे, _дадз,   ,
  { {0xd2520086,0xe29a0054,0xdb1c0144,0xbe8b0432}},	//   _تنش_, _тад_, mprè, рсне_
  { {0xbfd40058,0x0000006a,0x0000006a,0x0000006a}},	//   _فيتع,   ,   ,
  { {0x93bc0045,0x332622db,0x7d070c73,0xd0100058}},	//   _drăg, _knox_, rejs, _ألب_
  { {0xeea70015,0x6d4b0091,0x48fd0065,0x0000006a}},	//   _بحثً, _įgau, र्नो_,
  { {0xaf4b0074,0x7d07005c,0xc8d90036,0x48ab0080}},	// [fa50] _مشکل_, pejs, ймає_, атем_
  { {0x6d4e00b8,0xcd00005c,0x929d005c,0x161e000b}},	//   chba, ęści_, zeło, पिनर_
  { {0x26cf0035,0xb8d3000b,0x28080015,0x718b000a}},	//   tago_, _ऑल_, يْكَ_, בְאַ
  { {0x47580036,0xcce7002b,0xe7a80033,0x600b004f}},	//   орія_, _اسکي, івіл_, יִדְ
  { {0x98aa005c,0x59e2000b,0xe56e20b9,0x85e800ce}},	//   _sobą_, _पियर, ез_, ждів_
  { {0x25bd0026,0xaa9a000a,0x7aed5f15,0x7bd5002a}},	//   rpwl_, _לברכ, lgat, oszu
  { {0x64a20001,0x26cf0077,0x2b4b01c2,0xf7730015}},	//   наша, pago_, _klcc_, _قار_
  { {0x32b90015,0x7aed45f9,0x3f990085,0x6d800123}},	//   حدثة_, ngat, jmsu_, nöar
  { {0xc2e80029,0x2019003d,0x81f60058,0x0000006a}},	//   زعيم_, āsim_, كفير_,
  { {0x3ea9002f,0x2eb6005d,0x98aa005c,0xd5140015}},	//   _agat_, ूर्त, _tobą_, _يبلغ
  { {0xf3f0003b,0xf51a000a,0x48fd000b,0xc952004f}},	//   _لأن_, _לֵאל, र्यो_, גמי_
  { {0x321d0176,0x7bda2497,0x23fa0008,0x33fa0008}},	//   _trwy_, átum, _לפעמ, _להענ
  { {0x25a5003e,0xe732000a,0xddd00046,0x6d4e3181}},	//   _kill_, תֵת_, řeži, thba
  { {0xb226002e,0x91ba0008,0x7bda0091,0xdb1c0f24}},	//   stæð, _המסי, štum, mpré
  { {0x93bc0011,0xa0663839,0x25a55f16,0x2054006b}},	//   _grăd, _наша_, _mill_, _отър
  { {0xf4120053,0x6d8000f2,0x23b1163c,0x9980002a}},	//   עפן_, töas, _máj_, zwiń_
  { {0x6b650007,0x93bc0045,0x38c8002b,0x39460033}},	// [fa60] jėgu, _trăg, قاضی_, пнаг
  { {0x38cb002b,0xef18003d,0x28960054,0xe9d701fe}},	//   مامی_, ēļu_, пјес, яку_
  { {0x5d3b0008,0x0d3b0008,0x6d3b000a,0xb7d70015}},	//   _התיא, _הגיב, _התינ, كولا_
  { {0xdc8b0008,0x61e95f17,0x0000006a,0x0000006a}},	//   _לְכָ, kuel,   ,
  { {0xceb30008,0xd6cf0002,0x1c14000b,0xcb9b000a}},	//   גיד_, اقه_, डिकल_, _לסטט
  { {0xe3af002b,0x25a50125,0x23b10030,0x4536027a}},	//   گرو_, _cill_, _báj_, яхет
  { {0xa84a0029,0xa026008c,0xb4ac000b,0xdb1c0003}},	//   _الأم_, isöö, _गली_, epré
  { {0xb7db0008,0xe3af0087,0x25ad0b77,0x98a3006d}},	//   _לקלי, درو_, _fuel_, _чисе
  { {0x69d600d9,0xf0f9000b,0x518612ae,0x92b30015}},	//   nsye, ौजूद_, зуна, رحيا
  { {0x7bd5005c,0x7aed00dc,0xdb1c0144,0x55bb000a}},	//   yszu, zgat, sprè, _לממו
  { {0x7bda01a3,0x7528002a,0x94d30058,0xb92a00ce}},	//   štuj, _indz, _سينش, ркiв
  { {0x69d63d8a,0x61e90077,0x6d5e5f18,0x0000006a}},	//   ksye, buel, _ampa,
  { {0xd3370008,0x61e95f19,0x877b00a3,0x9757000a}},	//   _מראה_, cuel, מאטי, ליטו_
  { {0x61db0008,0xe29b000a,0x7bd50012,0x93bc0045}},	//   _פקוד, _השדר, tszu, _trăd
  { {0x01330002,0x5c0402bf,0xe0fb000a,0x69d601c2}},	//   _سعود, нята, _הלול, esye
  { {0xb3bb000a,0x6d5e26c9,0xcb34006b,0x7aed15d0}},	//   ממלכ, _empa, несъ, ugat
  { {0xad550029,0x7bd500dc,0xad270018,0x391509c3}},	// [fa70] _ينبغ, sszu, _فردو, ммар
  { {0x7aed5f1a,0x6d800123,0x48ab0c6e,0x7642007f}},	//   sgat, söar, стам_, dyoy
  { {0xf770002b,0xacfa000a,0x61e957f6,0xf19b000a}},	//   گال_, _והתכ, zuel, משמש
  { {0xf1dd005d,0xdb0700f2,0xf77300e6,0xbbd601ac}},	//   _मिलन, ömäs, راض_, _קורץ_
  { {0xf7700115,0x25ad1081,0x95990b9b,0x61e95f1b}},	//   دال_, _quel_, отку_, xuel
  { {0xc9840036,0x61e95f1c,0x5dfc000a,0xe9a40033}},	//   _зуси, vuel, צפונ, _паўп
  { {0x25a527a9,0xe9ff0092,0x753a0144,0xec68000a}},	//   _vill_, _khắc_, _dotz, ּ֑וֹ_
  { {0x25a50708,0xb225135d,0x6b650091,0x752801f1}},	//   _will_, дмил, mėgs, _endz
  { {0x25a527a9,0xecbf000b,0x25ad007c,0x6d47001a}},	//   _till_, ्राफ, _uuel_, kkja
  { {0xdb1c0152,0xc692000a,0x1515005e,0x6908000a}},	//   rpré, _יאן_, _ідея, ִּתְ
  { {0xdb1c08e0,0x656303af,0xc0580010,0xe2f90036}},	//   spré, minh, зіў_, _межі_
  { {0xe9ff0092,0xe805005d,0x98aa002a,0x65635f1d}},	//   _nhắc_, _रहना_, _dobę_, linh
  { {0x236d4033,0x64430026,0xa294042b,0x01350015}},	//   mnej_, lyni, _заці, _يعتد
  { {0xfce60036,0x236d0c09,0x24800064,0xe1f90091}},	//   ього, lnej_, şime_, mtų_
  { {0x628f016f,0xbf660015,0x6da30718,0x236d002a}},	//   škoć, _يدعو, тира, onej_
  { {0xe9ff0023,0xe1f90007,0x236d5f1e,0xdee20033}},	//   _chắc_, otų_, nnej_, _рукi_
  { {0xe1f900df,0xe9da0484,0xed5a1eb8,0x929d002a}},	// [fa80] ntų_, юка_, _мои_, dełk
  { {0xe1f900df,0xb4ac000b,0x69d65863,0x6d5e2982}},	//   itų_, _गले_, rsye, _umpa
  { {0xc0ac0053,0xb17a004c,0x65632e86,0x9cd7000a}},	//   ציאָ, קטער, dinh, _קוטה_
  { {0xe1f900df,0x64431256,0x064a0029,0x236d1332}},	//   ktų_, dyni, يلاً_, jnej_
  { {0x99d60029,0x236d066f,0x5664002b,0x88c60015}},	//   _تتجا, dnej_, رگرف, _يتسل
  { {0x64430026,0xef1f00dc,0x344a004a,0x236d006f}},	//   fyni, elül_, жчин_, enej_
  { {0xe1f90091,0x98a3011e,0xbfa400a1,0x644310c6}},	//   etų_, _аире, _phễ, gyni
  { {0xcc770008,0x27f701b2,0xd2140054,0x93bc0045}},	//   ועצה_, žení_, емић, _prăb
  { {0x6d470462,0xe1f90091,0x26c6055e,0xe816000b}},	//   ykja, gtų_, mboo_, णिका_
  { {0x93bc0011,0x64430026,0x236d002a,0xb0340054}},	//   _crăc, byni, anej_, енош
  { {0x291822cc,0xc0570036,0x236d066f,0xdbd6007c}},	//   _mara_, дія_, bnej_, _jääg
  { {0x122a0080,0x236d0d55,0x57fb000a,0x02c30033}},	//   _моей_, cnej_, חלטו, _айцо
  { {0xec680053,0xcd00002a,0x42560015,0x0e34005e}},	//   _פֿ_, ęśni_, _تنشر, вняю
  { {0x2bbb0015,0xb118002b,0xd1c90015,0x29185f1f}},	//   قارة_, _رقبا_, _ربهم_, _nara_
  { {0x6d470084,0xac185f20,0x317b000a,0x2ba70099}},	//   rkja, мору_, _ואגד, дјав
  { {0x6563001c,0x1600000b,0x59c50015,0x2918007c}},	//   zinh, ोबार_, فيرك, _aara_
  { {0x6443005c,0xd91b004a,0x29185f21,0xae9b0058}},	// [fa90] zyni, жье_, _bara_, _بضغط_
  { {0x661d002e,0x236d1332,0x29185f22,0x9dd8000a}},	//   _áski, znej_, _cara_, _חוזק_
  { {0xe9ff0092,0x6563016e,0xef1f0061,0x29185f23}},	//   _thắc_, vinh, ylül_, _dara_
  { {0xe1f90007,0xdc9a000a,0xf093004c,0x64430091}},	//   ytų_, _מסתכ, דנע_, vyni
  { {0x29182b1f,0x236d002c,0x64430d4f,0xd6d60015}},	//   _fara_, vnej_, wyni, رووش_
  { {0xfbd00074,0x236d005c,0xf7eb0015,0xdcee0046}},	//   _حتی_, wnej_, _ورأى_, době
  { {0x673b038d,0xd8830086,0x236d4033,0x65635f24}},	//   _touj, _شهری, tnej_, rinh
  { {0xe8940010,0x3cff005d,0x6b5100c0,0xcb12000a}},	//   _рась, श्ते_, _fåge, ָ֜ה_
  { {0xe1f90007,0x236d066f,0x29185f25,0x64432e87}},	//   utų_, rnej_, _yara_, syni
  { {0xe1f90007,0x236d25b5,0x0000006a,0x0000006a}},	//   rtų_, snej_,   ,
  { {0xe1f900df,0x13f5005e,0x1ee8002b,0x236d1d08}},	//   stų_, _їздя, وودی_, pnej_
  { {0xe1f90007,0x141a000a,0x35c6000b,0xd49804e5}},	//   ptų_, _מועב, रीक़, _цру_
  { {0x3ea400c0,0x9756000a,0x52d6000a,0xc0e50138}},	//   ämt_, תירו_, _נוסע_, _золк
  { {0x98aa0089,0xdb050030,0xe2a5001a,0x61fb1ca2}},	//   _době_, _ruhá, öðug_, mtul
  { {0x3b96000d,0xeb9a01dc,0x6ff50015,0x7ff50015}},	//   ејат, зив_, _أستط, _أستا
  { {0xdbd60020,0xdb060030,0xdb050030,0x61fb0045}},	//   _rääg, _kiké, _puhá, otul
  { {0x29185f26,0x2d840003,0xda660015,0x61fb5f27}},	// [faa0] _para_, îmes_, راري, ntul
  { {0x5e5700b2,0xbd460015,0xdb060030,0x394e001a}},	//   _נייע_, _أندي, _miké, ófs_
  { {0x61fb0020,0x36360086,0x29185f28,0xb908000b}},	//   htul, کراس, _vara_, _यय_
  { {0xdc370053,0x98b10045,0x61fb16ad,0x6e240072}},	//   _נאכט_, _poză_, ktul, _krib
  { {0x9e0a000a,0x29182b86,0x45b700ce,0x0000006a}},	//   לִַ֖, _tara_, егію_,
  { {0x59b5014e,0x4ddb000a,0x2007001a,0x69c45f29}},	//   _अंतर, לחנו, _opni_, mpie
  { {0xf8a7005d,0x6f040ee0,0x66e6135d,0x69c45f2a}},	//   _कृपय, _obic, _пова, lpie
  { {0xe805005d,0xe6c60015,0x31c65f2b,0x7855002b}},	//   _रहता_, _ستري, нсов, _جیمز_
  { {0x61fb0035,0x3f825f2c,0x32b70015,0x2d54007c}},	//   gtul, doku_, ردية_, _käed_
  { {0x09f70008,0x2be1000b,0x69c45f2d,0x88aa004f}},	//   עמים_, _फिला, ipie, ּבֹ֙
  { {0xf65f0084,0xc9530008,0x19570008,0x3957000a}},	//   _þær_, רמת_, גביל_, גשים_
  { {0x9582005c,0x98aa0089,0xdcee0046,0x6e245f2e}},	//   żąda, _sobě_, pobě, _brib
  { {0x69c4005c,0x61fb0011,0xf773000a,0x853c0091}},	//   jpie, ctul, רקר_, _riėj
  { {0x2d540020,0xc6930135,0xada40010,0x021700a3}},	//   _näed_, טאר_, лаўл, _נחום_
  { {0xef1f01e2,0x69c40024,0xdb1c002c,0x70b70008}},	//   nlük_, epie, aprí, _אהוד_
  { {0xa3e8005d,0xcb090015,0x59b5000b,0x6e245f2f}},	//   _बिन_, بيرن_, _अंदर, _frib
  { {0xf1b30053,0x58d90010,0x539b000a,0x98aa0046}},	// [fab0] ָסע_, ддзя_, לילו, _tobě_
  { {0x6f0f329b,0x6f1d0b8e,0xa3c2000b,0xef1f0061}},	//   lecc, ldsc, ्ठा_, klük_
  { {0x2d8300df,0xa3b0000b,0x99890061,0x0cbf000b}},	//   moje_, _टूल_, avaş_, ्रीम
  { {0xdc360053,0x2d830007,0x37c40015,0x6f1d02b3}},	//   _סארט_, loje_, اينف, ndsc
  { {0x61fb0011,0x6458006f,0xcf58000a,0xd7740040}},	//   xtul, ezvi, עבדת_, دالع
  { {0x86440010,0x2d830007,0x6b8d423f,0x73e50248}},	//   ыніж, noje_, llag, вокз
  { {0x2d830007,0xdc6c000a,0x63f60015,0xe894004a}},	//   ioje_, ּ֣וֹ, نفوس_, _барь
  { {0xd138005c,0x6f0f0251,0x6f1d0111,0x6b8d5f30}},	//   eją_, jecc, jdsc, nlag
  { {0x11d60029,0x2d831f07,0xa2350033,0xd24e002b}},	//   نوية_, koje_, тэйш, يچه_
  { {0x2d8300df,0x6b8d00b8,0xa1560001,0xd684032e}},	//   joje_, hlag, кању_, _сусп
  { {0xf8b2013a,0x69c40050,0xf9920008,0x61fb5f31}},	//   ישי_, zpie, שרי_, stul
  { {0xd138005c,0x6b8d27f7,0x61fb5a53,0x7d0e2d07}},	//   ają_, jlag, ptul, webs
  { {0xee37006d,0x6b8d5f32,0xaed30033,0x3f825f33}},	//   вня_, dlag, шоўш, roku_
  { {0xd2560008,0xd138005c,0x6da60001,0x2d831283}},	//   _בשנה_, cją_, ђива, goje_
  { {0x5c730010,0x69dd0cbf,0x0c79004a,0x20320015}},	//   алёт, _avse, есты_, _نفوس
  { {0x6b8d00b6,0xc0520008,0xed590024,0x6f045f34}},	//   glag, _כזו_, īža_, _ubic
  { {0xf2d200b2,0xc9aa0010,0x6e240c98,0x7e9a0015}},	// [fac0] יען_, двае_, _urib, _تنظر_
  { {0x6b8d4415,0x63ab5f35,0x7659002a,0x9989002a}},	//   alag, _lign, dzwy, ewał_
  { {0x66090035,0x69c45f36,0xbb860015,0x6b8d5f37}},	//   _apek, spie, _للدي, blag
  { {0x0bb70008,0x69c4014c,0xb9c60015,0xd138002a}},	//   _שלכם_, ppie, _لتسه, zją_
  { {0x6b840152,0x628e005c,0xcf93000a,0xd138002a}},	//   moig, ębok, בטא_, yją_
  { {0xad9b002e,0x5693000d,0xd99a002b,0x61e95f38}},	//   rtúg, јашт, _آنست_, drel
  { {0x86ea0029,0x66090035,0x6f0f5bc5,0x7659002a}},	//   _يعرف_, _epek, yecc, azwy
  { {0x9294008f,0xef1f0064,0x67a50002,0xfbd3000a}},	//   лайц, rlük_, _محقق, בתה_
  { {0xf743000d,0xdb0d00dc,0x6f0f3536,0xe61a091b}},	//   _тето, ókén, vecc, _юда_
  { {0xba9b0008,0x4a9b0053,0x6b8d0844,0x1a9b004c}},	//   וספי, ויפג, zlag, ויפע
  { {0x33f60010,0x14170029,0x61e95f39,0x6f0f0a33}},	//   _шчас, _ليلة_, arel, tecc
  { {0x2d83005c,0x2d540020,0xd138005c,0x7bdc57fd}},	//   woje_, _näeb_, sją_, dsru
  { {0x2d8300df,0x61e90064,0x6f0f1e89,0x2117002b}},	//   toje_, crel, recc, رتیب_
  { {0xe9ff0023,0xac19000d,0x644500b8,0x63ab005c}},	//   _nhạc_, ногу_, ähig, _zign
  { {0x9989005c,0x2d830107,0x317900dc,0x6ace000b}},	//   ywał_, roje_, észe_, ़रूर
  { {0x16cc000b,0x2019003d,0x2d832ca2,0x8037004f}},	//   ारोब, āsit_, soje_, _ינוע_
  { {0xdb12002d,0x99993c89,0x49b8012c,0x99d40015}},	// [fad0] ágái, екат_, نالد_, لتلا
  { {0xef1f0064,0x6b8d5f3a,0xfaa40054,0xa9680054}},	//   ldü_, slag, рађо, виђа_
  { {0x6c3504c9,0x61e95f3b,0x6b8d5f3c,0x29880b1e}},	//   _صفحا, zrel, plag, тсто_
  { {0x7c2a0084,0x7bc7016f,0xd886002b,0xef1f0061}},	//   _áfra, mpju, دهمی, ndü_
  { {0x9989005c,0x44255f3d,0x9f460046,0xdcfc003d}},	//   rwał_, _srl_, nulá_, lorā
  { {0x75d20029,0x63ab0f4b,0x4425458b,0x61e95f3e}},	//   حيوا, _sign, _prl_, vrel
  { {0xdcfc0024,0xb8e9000b,0xa7b8005e,0xb4b3000b}},	//   norā, ैर_, _алсу_, _टली_
  { {0xaad3005d,0xb8820264,0x93bc0016,0x92f5005e}},	//   तरिक, číta, _trăn, учкі
  { {0x6609000c,0x77640063,0x97820086,0x20d502e1}},	//   _upek, _търж, _اینه, лінс
  { {0x61e60227,0x61e95f3f,0xae220065,0x628b01d0}},	//   ákla, rrel, मिसन_, _vygo
  { {0x63ab00b6,0xe97c0053,0x628b005c,0xb97c000a}},	//   _tign, ונזש, _wygo, ונזי
  { {0x628b005c,0x69c15f40,0xc7fa000a,0xc2c50058}},	//   _tygo, _člen, עִיר, _إيشي
  { {0xcdf6065e,0x6f63004a,0x4df60033,0xc1050015}},	//   ычны, связ, ыянт, _موشي
  { {0xe1f60054,0x61450054,0x7bdc0123,0x5c1604d5}},	//   _сгш_, _љека, tsru, льбу
  { {0xdd8f00c3,0x3b0a04ae,0x40320054,0x6b5101ee}},	//   سوف_, нево_, _гејс, _såga
  { {0xe7f7000b,0x7bdc3dc8,0x0000006a,0x0000006a}},	//   ँढना_, rsru,   ,
  { {0x0eaa0191,0x3a260033,0x8d76006e,0x7bdc0c2e}},	// [fae0] _який_, ымаг, _مادا, ssru
  { {0x7bda00dc,0xe6cc000b,0x0e5b000a,0x98560099}},	//   átus, ार्ज, _נדיב, лтеш
  { {0x3cfb0008,0x2cfb000a,0x69b0000b,0x6cfb015b}},	//   _אלינ, _אליא, _अंकी, _אפיס
  { {0x27e7002f,0xcc3b0053,0xf6d6002b,0xc7950033}},	//   ánna_, _נעכט, ازاد, арчы
  { {0x7d1e5f41,0xe9ff0016,0x16340da4,0xd6270033}},	//   _kaps, _thạc_, реля, лоце_
  { {0x7af60091,0x6d4e5f42,0x0000006a,0x0000006a}},	//   lgyt, nkba,   ,
  { {0x4ab8014e,0x97b5000d,0xb7960001,0xa81801d8}},	//   _अलाव, _всуш, _браћ, _בֵּי
  { {0x7d1e0458,0x75d60002,0xdac2005e,0xb6a615d5}},	//   _laps, _ميرا, ацiя_, _библ
  { {0x926a0033,0xa2260015,0x2258004a,0x2348002b}},	//   эрка_, اربه, типы_, فسکی_
  { {0x69fb00b2,0x6d4e0111,0x7d1e0a5e,0x25aa0015}},	//   עליק, jkba, _naps, _أدري_
  { {0xb4c2005d,0x89370053,0x661d002e,0xd36f0086}},	//   ूरी_, אריע_, _áskr, _کهن_
  { {0x60c401e2,0x6d4e0079,0x644a001a,0xdb1f0030}},	//   _şimd, ekba, myfi, ívük
  { {0xe292003b,0x5ce70191,0xef1f0064,0x91e30190}},	//   _اذا_, люва, rdü_, _гоче
  { {0x74ca000b,0x7c87017a,0x7d1e5f43,0xf518004f}},	//   _स्मृ, губе, _caps, כֵֽל
  { {0x0704005d,0xe478000a,0x9fe60015,0x5d64004a}},	//   रभाव_, דָּש, _إسته, стяз
  { {0x60da0064,0x6d4e47bb,0xc334000a,0x5b150004}},	//   latm, akba, סוּ_, јмат
  { {0x5f740086,0x5a350254,0x3e07005e,0xdb26002b}},	// [faf0] _داور, шнат, _сяйв, جوقی
  { {0x7bc7007c,0x29073750,0x60da5f44,0xc87b0054}},	//   ppju, ýna_, natm, нџе_
  { {0xdb1f00dc,0xdb1c0227,0xb8590015,0x7b080046}},	//   ívók, sprá, خلاص_, ístí
  { {0x644a005c,0x7d1e0089,0xcc3a004c,0xb273004a}},	//   dyfi, _zaps, _סערט, ́льш
  { {0x644a29fc,0xa3ae000b,0xa3d7000b,0x5a470033}},	//   eyfi, ओआई_, ़ीन_, _сэна
  { {0xe5a510a0,0xa5090b27,0x644a0052,0x0000006a}},	//   шили, тека_, fyfi,
  { {0x36d50010,0xa954005e,0xad1c000a,0xe4e401c6}},	//   _вобр, _укрі, גוור, січн
  { {0x93bc0045,0x11e501e8,0x29135f45,0x82350058}},	//   _grăm, ажим, lexa_, لرخا
  { {0xe0d1002b,0x6b48004f,0x0000006a,0x0000006a}},	//   يزد_, ר֨וּ_,   ,
  { {0xe6100086,0x32d30092,0xd6d9005c,0x41020010}},	//   _عشق_, ảy_, _koło_, озьв
  { {0x6b5101d1,0x644a005c,0x764b0026,0xb4c1005d}},	//   _någo, cyfi, lygy, ंडी_
  { {0x2d910089,0xf43a000a,0x60da007c,0x3f6a364e}},	//   elze_, _בתעש, aatm, тимо_
  { {0x4384003b,0x7bc50084,0x2018002e,0x7d1e5f46}},	//   _النق, _athu, ærir_, _paps
  { {0x3179004c,0xa0a51053,0x1d19030c,0x725a004f}},	//   _שאַד, _калд, люсь_, _בכנפ
  { {0xdfd10029,0xaba60029,0x6d4e5f47,0xdca620e6}},	//   _بيع_, لإره, rkba, рави
  { {0x207a0053,0xd00e0029,0x1efa0029,0xc4d1000b}},	//   _באצא, _آلي_, _شعبة_, हरुख
  { {0x44200023,0xc332000f,0x6d89001a,0xc9660af4}},	// [fb00] ̉i_, חון_, rþar, авай
  { {0x38cb0086,0x7e9b000a,0x48e60033,0x0000006a}},	//   نامی_, _בספו, рожв,
  { {0x661b041c,0xa3d7000b,0xad9b006f,0x86c6012c}},	//   _asuk, ़ीम_, stúc, ليان
  { {0xb8ed005d,0xe7390026,0x6c7b000a,0x8bbb000a}},	//   _ष्_, _siŵr_, _יריד, _שזכת
  { {0x25b70015,0x98de005e,0xc4d1000b,0x799c0034}},	//   لهند_, _освi, हरूख, _thrw
  { {0xe5e50029,0x6e3b00b8,0xb4c2000b,0x644a002a}},	//   إثني, äubi, ूरे_, tyfi
  { {0xdb0d0012,0xe3f70015,0xdb1c02de,0x37e30a13}},	//   nmaß, لعيش_, rpræ, _морг
  { {0x644a5f48,0x14590033,0xdb1c02de,0xd32601c5}},	//   ryfi, ышчы_, spræ, рьки
  { {0xd130003b,0x6299002a,0x3e4a0091,0xe1d70033}},	//   كمة_, _czwo, nėtą_, адыі_
  { {0x21540010,0x7a0a0024,0x6299005c,0x66024825}},	//   скоў, mētā, _dzwo, mtok
  { {0x60da0064,0x7a0a0024,0x6568002d,0xb7c2017f}},	//   ratm, lētā, _imdh, блiк
  { {0xe7f7000b,0xdb1c0012,0x04930015,0x3e4a0091}},	//   ँढता_, nprä, _بلمح, kėtą_
  { {0x60da0064,0x67220024,0x7a0a003d,0x66025f49}},	//   patm, idoj, nētā, ntok
  { {0xd578000a,0x3e4a0091,0xd24f002b,0xa280002b}},	//   אָֽר, dėtą_, _تنه_, _ویژو
  { {0xb19b0008,0xfb670001,0x6b5100c0,0xbc48005e}},	//   _שיוכ, ањам, _fågl, ачте_
  { {0x6720016f,0x7f840015,0xd47b000a,0x93bc0045}},	//   _namj, _ولون, דאלל, _prăj
  { {0x88c70029,0xba99005e,0x8f7c004f,0x0000006a}},	// [fb10] لتال, уває_, _שנחק,
  { {0xce38000a,0x93bc0045,0x7a0a003d,0xdb1c0012}},	//   _כאחת_, _vrăj, dētā, eprä
  { {0x7d150064,0xd6d70015,0x69c60061,0xad9b0077}},	//   mezs, لتشغ, _etke, ctúa
  { {0x3ead4f7c,0x61e25f4a,0x7d150307,0xdc88004f}},	//   žetu_, _ovol, lezs, _כְרָ
  { {0x6d450005,0xcb360008,0xda670015,0x61e20144}},	//   _koha, _הארי_, _ضاحي, _nvol
  { {0x5dda0053,0xb4c1000b,0x0564005e,0x356b006b}},	//   אַקס, ंडे_, овін, ърен_
  { {0x6602000c,0x6d451686,0x5caa000a,0x6299002a}},	//   atok, _moha, ְׁפַ, _szwo
  { {0xcc780008,0xe1f9004a,0xa6c80015,0x2d5405ff}},	//   יגות_, гги_, _نوفل_, _näen_
  { {0x7a0a0024,0x661b2fa3,0x0000006a,0x0000006a}},	//   cētā, _usuk,   ,
  { {0x00c90080,0x6720016f,0xf8b9000b,0x5437002b}},	//   ылок_, _zamj, ेडिय, _پرطر
  { {0x0495003b,0xb4fa000a,0xcea9000a,0xa2d5002b}},	//   _الاح, _תפעי, _ני_, _هيات
  { {0x2f563966,0xb7b10138,0x9f4d005a,0xdcfc0535}},	//   стос, олiл, budí_, iorą
  { {0x877a00b2,0xa3b0000b,0x6d453414,0x6b510123}},	//   רארי, _टूट_, _boha, _vågl
  { {0xd4910023,0xc0cb0001,0xe0d901f3,0x987a0045}},	//   _kỳ_, _руде_, _свк_, nţăm_
  { {0x7a0a0048,0x61e20156,0x75210064,0x224d00dc}},	//   zētā, _zvol, _malz, lyek_
  { {0x236d0050,0x40920086,0xdb0d00b8,0xdb060030}},	//   niej_, _علير, rmaß, _biká
  { {0xbb430001,0xeb9715e6,0xc8b60029,0x224d00dc}},	// [fb20] четк, сит_, مصاب, nyek_
  { {0x8c4901e2,0xa3e8005d,0xb4c1005d,0x6e3b0008}},	//   _başı, _बिल_, ंडो_, _עתיד
  { {0x236d0050,0x60da0053,0x6d5c002d,0x1bec000b}},	//   kiej_, רקענ, mhra, _जटिल_
  { {0x6602022d,0x6d450a72,0x67220091,0x16da0015}},	//   ttok, _zoha, udoj, اذاة_
  { {0x6602000c,0xd5b10092,0xdb1c03c1,0x6d45050b}},	//   utok, _bí_, rprä, _yoha
  { {0xdb1c00b8,0x7a0a0024,0x66024092,0x9f5f0030}},	//   sprä, rētā, rtok, rtté_
  { {0x61e204ba,0x66025f4b,0xdb1c0123,0x7a0a003d}},	//   _svol, stok, pprä, sētā
  { {0x236d005c,0x08770053,0xb2180015,0x60d80061}},	//   giej_, _העלט_, لقبض_, _sevm
  { {0x07a30010,0x24530016,0x67330046,0x2d8a00b3}},	//   _хатн, ạm_, šejí, kobe_
  { {0x8c490064,0xd1b70015,0xdd05003d,0x2fc75f4c}},	//   _yaşı, حايا_, ēsīs, _btng_
  { {0x236d002a,0xaab8000b,0x2d8a5f4d,0x6d45227c}},	//   biej_, _अलंक, dobe_, _roha
  { {0x236d005c,0x224d01d7,0x4343004a,0x6d455f4e}},	//   ciej_, byek_, _нехв, _soha
  { {0x6e220048,0x61e20089,0x539b000a,0xa3c2000b}},	//   _šobr, _uvol, _עידו, ्ठक_
  { {0x6d5c3c93,0x01fb000a,0x63ba40c1,0x527b004f}},	//   ghra, _עפול, _kutn, _גנדא
  { {0x71650015,0x5577004c,0x63ba0030,0x93bc0045}},	//   _بانك, צעלן_, _jutn, _brăi
  { {0xc1780091,0x6d5c5f4f,0x93bc0045,0x63ba0085}},	//   lnė_, ahra, _crăi, _mutn
  { {0x6d5c002f,0xc8d9005e,0x19bb0015,0x8b040046}},	// [fb30] bhra, имає_, اطرة_, ířat
  { {0x236d0050,0x3ead0024,0x6d5c5f50,0x442c2a8a}},	//   ziej_, žets_, chra, _ord_
  { {0x225f00dc,0xd8790029,0xad670086,0x63ba0107}},	//   zzuk_, جمات_, _ناگه, _nutn
  { {0x18a4005e,0x93bc0045,0x75211c9c,0xd7f80b1e}},	//   чаєм, _grăi, _salz, суф_
  { {0x442c002d,0x95c40015,0x35fb002b,0x26dd002a}},	//   _ard_, كينه, ارصد_, rawo_
  { {0x8c4901e2,0x6e2d000c,0xd8b80015,0x67d55f51}},	//   _taşı, _mrab, _هدفا_, _могу
  { {0xd5b10023,0xe3e90086,0xdb1c0971,0xd7c9002b}},	//   _ví_, شکان_, språ, _خوزه_
  { {0x6d5c099c,0xc1780091,0x75210012,0xdff2000b}},	//   zhra, enė_, _walz, _अमजद_
  { {0x2489005c,0xd67b002b,0x44270016,0xd2990033}},	//   łam_, _صحرا_, svn_, шткі_
  { {0x63ba00dc,0x236d002a,0x60091ce8,0x6f0d473d}},	//   _futn, siej_, аном_, _abac
  { {0x236d005c,0x73c40087,0x3074004a,0xa227002b}},	//   piej_, _فيلم, зуяс, _گراه
  { {0x61ee0064,0x6e2d5f52,0x9954006f,0x9eaa0317}},	//   ünlü, _brab, mäť_, ивна_
  { {0x200a01e2,0x6d5c11d8,0x25b20064,0xa2270015}},	//   çbir_, thra, _ünlü_, _دراه
  { {0xad9b002d,0x127a0053,0x6e2d5f53,0x6ebc0065}},	//   stún, _דאנע, _drab, _एलवु
  { {0x8b260894,0x3a290061,0x6d5c3e08,0x9f4c0030}},	//   одве, evap_, rhra, álók_
  { {0x399400f2,0xab690015,0x2d8a0183,0x5dda03ea}},	//   mäsi_, محقق_, sobe_, _кфор_
  { {0x24800064,0x3946275c,0x3994008c,0x6e2d5f54}},	// [fb40] ğimi_, онаг, läsi_, _grab
  { {0xc8960001,0x24800064,0x4a750033,0x4996005e}},	//   орењ, şimi_, чыст, ішат
  { {0x93bc0011,0x8cb9000b,0x3994008c,0x2005080d}},	//   _trăi, ्डरो, näsi_, ntli_
  { {0x6008000a,0x2005003d,0x95ca0076,0x6b5809ae}},	//   מִנְ, itli_, аука_, _fíga
  { {0xe534008f,0x6b810014,0xdb1c00dc,0x644500f2}},	//   зель, élge, őzón, ähin
  { {0x1cba0008,0x03c601e5,0x399401be,0x63ba5f55}},	//   ׁמְע, осим, käsi_, _putn
  { {0x6b9614d8,0x399400f2,0x34470033,0xdce7003d}},	//   olyg, jäsi_, жчын_, nijā
  { {0x3756002b,0x5b57004c,0xdb040003,0x03a30054}},	//   _بپرس, ַשין_, umiè, мијо
  { {0x2005002a,0x36360015,0xdb040003,0x9f4d016e}},	//   etli_, _برأس, rmiè, judá_
  { {0x3a3701d8,0x64360015,0xaa37004c,0x24890061}},	//   קרים_, _وراء, קטיק_, şama_
  { {0x88bb000a,0xb8bb0053,0x41b40086,0x399b004c}},	//   ימיז, יזיש, _کمتر, שייד
  { {0xc1780007,0x6e2d5f56,0xdce701ec,0x0000006a}},	//   snė_, _prab, dijā,
  { {0xdb0600f2,0x637e003d,0x628e0012,0x9df80a32}},	//   _mikä, cīna, ßbod, онят_
  { {0x6ad3005d,0xc5f3000f,0x660f02ad,0x6e2d5f57}},	//   तर्र, ודש_, _äcke, _vrab
  { {0x5c04478e,0xdc3d006f,0x6b9630a6,0xdd940033}},	//   мята, páčt, flyg, фары
  { {0xa3dc005d,0x6f0d016f,0x6e2d0fb3,0x905b000a}},	//   तीय_, _ubac, _trab, _ככות
  { {0xecf90010,0xb9b500c3,0xb955006b,0x63a25f58}},	// [fb50] _лепш_, سماع, пващ, _mhon
  { {0xceb40008,0x8cd5000b,0xb924002b,0xdce7003d}},	//   _קיץ_, _बजटो, وفقي, bijā
  { {0x63a20176,0xdce70024,0x6b960026,0x6d41014b}},	//   _ohon, cijā, blyg, ölau
  { {0xf6e70036,0x8c1a000f,0xa08b000a,0xcad5000a}},	//   іцен, _פורי, בְדִ, _מוֹת_
  { {0xf770003b,0xbc680086,0xeb3a0053,0xbb3a01d8}},	//   خال_, _همین_, _הערש, _הערי
  { {0x20050227,0xfdf8000a,0x3994008c,0x63a25f59}},	//   ytli_, קצות_, yäsi_, _ahon
  { {0x63a2002d,0x9cd8000a,0xf992000a,0xccf2004f}},	//   _bhon, חווה_, _נרל_, ׂ֛ה_
  { {0x399400f2,0x96f80080,0x63a21082,0x59d2000b}},	//   väsi_, _мест_, _chon, दीकर
  { {0xddc60050,0xe1f10029,0xf628005e,0x95c83770}},	//   zykł, رسة_, _міфи_, _духа_
  { {0xc6920053,0x399400f2,0x9954002c,0xc5570015}},	//   _טאן_, täsi_, päť_, _بضرب
  { {0x63a2002d,0xd1480015,0x52b50015,0x746b0248}},	//   _fhon, تشين_, _فماذ, _трав_
  { {0xa8560008,0x7c2a047e,0x63050015,0x3994008c}},	//   פירה_, _áfri, _روتل, räsi_
  { {0xde360010,0xa3d7005d,0x399400f2,0x200501b2}},	//   чэнь, ़ीर_, säsi_, stli_
  { {0xe1640029,0xc10400e6,0x1d0a0054,0x63a25f5a}},	//   _يدوي, _يوني, љеви_, _zhon
  { {0x63a95f5b,0x913a000a,0x50da000a,0x6b960091}},	//   omen, _לעסק, _הקצא, tlyg
  { {0xbb430cb9,0xdce70024,0x63a95f5c,0x9e5a0912}},	//   неск, rijā, nmen, _гроф_
  { {0x7f77013a,0xb1830089,0xdfa50115,0xdce7003d}},	// [fb60] _מעקב_, šťuj, _تحوي, sijā
  { {0x63a90ecc,0x0d830033,0xdb06008c,0x6d550012}},	//   hmen, _плын, _sikä, ckza
  { {0x8d850029,0xb19a004c,0x63a95f5d,0xad1b000a}},	//   _تشين, ציעכ, kmen, _פוטר
  { {0xf98900b2,0x63a90264,0xc7af0015,0xd5ba0033}},	//   אר_, jmen, هّل_, бск_
  { {0xba760018,0x63a20335,0x63a9361a,0xc6960058}},	//   _راحت, _rhon, dmen, أشاع
  { {0x63a95c8b,0x6a9b000a,0xceb3000a,0x9e77000a}},	//   emen, _לשכנ, ׂיא_, הגנה_
  { {0x29370053,0x63a25767,0x2d980030,0xa3d7000b}},	//   _צאלן_, _phon, ilre_, ़ील_
  { {0x987b0053,0x63a908a2,0x94730015,0x938a0054}},	//   _האלט, gmen, عدوا, љска_
  { {0xa3dc014e,0x93bc04f9,0xb17d006f,0xa3e8000b}},	//   _तौर_, _arăt, vrťr, _बिक_
  { {0x6f19005c,0x865b000a,0x394a2ef8,0x93bc0045}},	//   _ówcz, _הדמי, _jobs_, _brăt
  { {0xe5050015,0x63a25f5e,0x442a0030,0x63a95f5f}},	//   _تبقي, _thon, _éb_, bmen
  { {0x389b00b2,0x643b0053,0xc43b000a,0x27e7001a}},	//   מיינ, _לעבנ, _לתבי, ánni_
  { {0x7d0301d1,0x91a60092,0xa3c2005d,0x4ea401c5}},	//   _önsk, _trò_, _एंड_, ерра
  { {0xc534000a,0x291a0085,0x61435f60,0x4237000a}},	//   וָֽה_, jepa_, _печа, _מנדל_
  { {0xab950036,0x6d550111,0x40eb0008,0xc19b0008}},	//   диві, rkza, _הַחֲ, _השגי
  { {0x307b0008,0x4f680033,0x3a2200aa,0x5e450058}},	//   _לאונ, _ншым_, _bskp_, _يَغْ
  { {0x394a20b1,0xa3dc0065,0x6d41005b,0x0000006a}},	// [fb70] _bobs_, तीत_, ölas,
  { {0x99d400e6,0xa8a72246,0x4ddc000a,0x3994007c}},	//   عتقا, прек, _החזו, käsu_
  { {0xf99000e5,0x63a95f61,0xa3e8000b,0xccf2000a}},	//   ابق_, ymen, _बिग_, _בכי_
  { {0x64450601,0x0000006a,0x0000006a,0x0000006a}},	//   ähim,   ,   ,
  { {0x9f5f04ed,0x5a340127,0x85e8005e,0x85c80015}},	//   ittà_, _знят, здів_, كِنْ_
  { {0xe6180036,0xc8e1000b,0x63a90b58,0xdbd7008c}},	//   яді_, _फ़िट, wmen, pääh
  { {0x7d7c000a,0xa3d7000b,0xf5320004,0x63a95f62}},	//   זנגו, ़ीं_, тејќ, tmen
  { {0xeb93000a,0xd1c9006b,0x67c50091,0x63a95f63}},	//   ךָ֥_, олие_, _gėja, umen
  { {0xf8e1005d,0x10f50010,0x63a95f64,0x92a6002a}},	//   _फ़ाय, мяня, rmen, jgłę
  { {0xd5b1006e,0x63a95f65,0x3075134a,0x4fe900af}},	//   _شفا_, smen, думс, омон_
  { {0x212b0089,0x63a95f66,0xc952000a,0xdb17016e}},	//   ěch_, pmen, דמי_, _auxí
  { {0x83670087,0x82150015,0x73c40015,0x25bf007c}},	//   _عدال, _يواص, _أينم, _kuul_
  { {0x6f630010,0x25bf5f67,0x66a8004f,0xb6060160}},	//   твяз, _juul_, ּ֙רֶ, _gušć
  { {0x25bf0020,0xa1350086,0x91ba000a,0xa0c50015}},	//   _muul_, _زرتش, _ומסי, _غيبو
  { {0xdbf20046,0x61fb019a,0x1c3902ed,0x0000006a}},	//   přít, luul, пять_,
  { {0xf092013a,0xf412000a,0x2127052d,0x2054005e}},	//   _שנה_, כפל_, _hanh_, _ятір
  { {0xe3b80064,0xb226002e,0x2e860015,0x09e336a6}},	// [fb80] _asıl_, mræð, _تشغّ, котн
  { {0xb226002e,0x15fc000b,0x499a0033,0xeab10015}},	//   lræð, उंसर_, ітая_, اعِ_
  { {0x5d3b000a,0x21270016,0x0d3b000a,0x6d5e5f68}},	//   _ותיא, _manh_, _וגיב, _ilpa
  { {0x61fb0e95,0xa3c1000b,0x7d1c37e7,0xdb24008c}},	//   kuul, ंदन_, lers, ärär
  { {0x59760010,0x21270016,0x7ae45f69,0x7c2e0778}},	//   _жыву, _oanh_, mait, lvbr
  { {0x61fb00f2,0x7ae45f6a,0xceb3000a,0x9f4d013f}},	//   duul, lait, דיד_, vrdí_
  { {0xd82305e6,0x45190033,0xc10e0016,0x139401b7}},	//   _идри, яцця_, _bỗng_, никю
  { {0x7ae4002f,0xdb0f0045,0xd6cf0015,0x7d1c3dcc}},	//   nait, _zicâ, _نقف_, hers
  { {0x61fb0035,0x7d1c5f6b,0x6d0e000b,0x21270016}},	//   guul, kers, िभाग_, _banh_
  { {0x7ae45f6c,0xd6d9005c,0x21270092,0x224b00c0}},	//   hait, _dołu_, _canh_, äcka_
  { {0x21270023,0xb2260084,0xa3e8000b,0x7ae45f6d}},	//   _danh_, fræð, _बिट_, kait
  { {0xb2260084,0x7ae400f2,0xf8b3000a,0x7d1c141c}},	//   græð, jait, כשת_, eers
  { {0x93bc0011,0x7ae41f22,0x7e280210,0xad9b0125}},	//   _trăs, dait, міра_, ltúi
  { {0xada40010,0x23a10030,0x6b512494,0x7d1c5f6e}},	//   каўл, mója_, _lågt, gers
  { {0xeb930115,0x23a100dc,0x7ae45f6f,0x70fb000a}},	//   نظر_, lója_, fait, _והוח
  { {0xc3340008,0x7ae40de2,0x0000006a,0x0000006a}},	//   עוּ_, gait,   ,
  { {0x44290092,0x9f460057,0x5e440015,0x753a0079}},	// [fb90] ̉a_, nulý_, _لَيْ, _ontz
  { {0x21270092,0x75281ae6,0x7d1c5f70,0x6f1d5f71}},	//   _xanh_, _nadz, cers, lesc
  { {0x9cd6013a,0x6ec3000b,0x47d40015,0x39940123}},	//   _אותה_, रखपु, َيْر, väst_
  { {0x8c440004,0x7c250085,0x0077000a,0x17f80015}},	//   _реџе, _ishr, ותבי_, بركة_
  { {0x8f9c0008,0xaaf6000a,0xc10e0016,0x3ce1007c}},	//   קידי, _אזרח_, _rỗng_, _kehv_
  { {0xbdda0053,0x78a20089,0x89da000a,0x23a10030}},	//   פֿנט, řova, _מחשי, dója_
  { {0x68e500f2,0x07f80015,0x21270016,0xf8b40033}},	//   mahd, _يرفع_, _ranh_, _абрэ
  { {0x753a00b8,0x04560015,0x68e5008c,0x25bf007c}},	//   _entz, علية_, lahd, _tuul_
  { {0x6f1d2970,0x4906000b,0x752801c2,0x7d0551fe}},	//   desc, स्को_, _fadz, _ochs
  { {0x2ee0002d,0x68e5008c,0x7528002a,0xe0451377}},	//   _seif_, nahd, _gadz, енои
  { {0xad9b002d,0xf992000a,0x7d1c50e4,0xb936004f}},	//   ctúi, ררי_, vers, גנתו_
  { {0x7d1c0050,0x6d89002c,0x48160053,0x6f1d2259}},	//   wers, hľad, ײַטן_, gesc
  { {0x3f9e0048,0x68e51521,0x7ae445d8,0x7d1c0380}},	//   ētu_, kahd, vait, ters
  { {0x7ae40176,0xd138005c,0x61e95f72,0x7d1c0012}},	//   wait, gląd_, msel, uers
  { {0x69cf0048,0x30790053,0x7d1c5f73,0x6fc6000b}},	//   _atce, _מאַנ, rers, _रूपं
  { {0x7ae4002d,0x29d60015,0x1ee8002b,0x6d5e0034}},	//   uait, فيرس, _کوکی_, _wlpa
  { {0x3f7b0053,0xf2d20135,0x7ae45f74,0x6e24003f}},	// [fba0] _מאקס, טען_, rait, _usib
  { {0x7ae45f75,0x61e95f76,0x9c260004,0x0c26005e}},	//   sait, isel, _здод, _змон
  { {0x62990026,0x61e900b8,0x38cb0086,0x75280d2a}},	//   _lywo, hsel, سالی_, _radz
  { {0xdc7700b2,0x61e95f77,0x0e5a000a,0xaa462a6b}},	//   _טעיפ_, ksel, ּדַב, _земл
  { {0x49c70033,0x7528003d,0xb17d006f,0xcb13004f}},	//   _плян_, _padz, esťm, _גלר_
  { {0x96d0005d,0x344a005e,0x95c3012c,0x23a10030}},	//   _ड्रॉ, зчин_, ديوه, vója_
  { {0x9f460030,0xb895006b,0x18a32e68,0x61e95f78}},	//   nuló_, _артъ, _барм, esel
  { {0x23a100dc,0x389b0008,0x92940033,0x8c1b000a}},	//   tója_, _זילנ, кайц, פופי
  { {0xd130003b,0x6f1d04ed,0x36671179,0xf777000a}},	//   لمة_, vesc, _зато_, _נעמי_
  { {0x506600d0,0x21540033,0xb0340054,0x75d30015}},	//   етма, ткоў, внош, _إيلا
  { {0x74130002,0x62995f79,0xa3dc000b,0x58f7004c}},	//   _مولا, _eywo, तीश_, עצטן_
  { {0xdb1c00dc,0x9f460030,0x187b000a,0x6fb40033}},	//   ipró, duló_, לטיב, лёўц
  { {0x2d72003d,0x6f640015,0x61e928ad,0x6f1d5f7a}},	//   aņem_, اهُم, csel, resc
  { {0x6b5101d1,0x3014008f,0x6f1d0011,0x23850024}},	//   _någr, _адкр, sesc, mēja_
  { {0x6f1d5f7b,0x0197000a,0xac950e77,0xdb1c0012}},	//   pesc, _רכוש_, тавш, bprü
  { {0x409b0008,0xddd00089,0x309b000a,0x909b000a}},	//   _מבוס, řeši, _משומ, _מסוק
  { {0xcfb80008,0x2385003d,0x0a150015,0xd37b000a}},	// [fbb0] _אלהי_, nēja_, ضواح, פרמט
  { {0x2901000c,0x7e7c000a,0x999802ed,0xd838013b}},	//   ugha_, _מאחז, екут_, _šča_
  { {0xb8080029,0x2d540020,0xdb1c00dc,0xdbf20089}},	//   فيلم_, _päev_, gpró, přát
  { {0x5727003b,0x86c40015,0xf093004c,0x61e95f7c}},	//   عراق, هيمن, אנע_, ysel
  { {0x2d720024,0xa6e2001a,0x68e5008c,0xd6d40033}},	//   zņem_, æðam, pahd, ужчы
  { {0x4a5a011f,0x61e92017,0xd6180015,0x2385003d}},	//   _חדשו, vsel, عتنا_, dēja_
  { {0xd7f80124,0x6498010f,0xdb1e0152,0x58840033}},	//   _пут_, нтър_, _supé, _быта
  { {0x9f5f00f2,0x03950063,0x61e95f7d,0x2bb4000b}},	//   nttä_, ърля, tsel, ंगया
  { {0x35b5008f,0x9f4d002c,0x07080015,0x6b580125}},	//   _абар, budú_, _سيلي_, _dígh
  { {0x2127002b,0x61e94b8d,0xeb1e0065,0x2d7201ec}},	//   ريجی_, rsel, _पस्त_, tņem_
  { {0x6299005c,0xe5360053,0x61e902b3,0x931500c3}},	//   _wywo, _שטעט_, ssel, _لواش
  { {0x61e95f7e,0x3f84007c,0x78ba001a,0xf233002b}},	//   psel, õmu_, _útve, _مبتک
  { {0xc7b200b2,0xdb1c00b8,0xfe250010,0x25f7000b}},	//   יבט_, rprü, льён, उंटी_
  { {0xdb1c0c1f,0x2d5400f2,0xa0590029,0xd5fa000a}},	//   sprü, _näet_, _يؤثر_, ופשר
  { {0xeb9a2c6b,0x69cb5f7f,0x1ae60004,0x3b9602d9}},	//   див_, ígen, ковм, вјат
  { {0xfaa60010,0x332d5f80,0x0b1a0015,0xb09a000a}},	//   вабо, ndex_, بقرة_, _קיקר
  { {0xdd8a000d,0x09e60342,0x9f97000a,0xeb971eb8}},	// [fbc0] _обид_, тозн, _בדקה_, тит_
  { {0x3d11005d,0xa3c1021e,0x5e57000a,0x3dfb000a}},	//   द्दे_, ंदा_, _סייע_, _קליד
  { {0xd70a004a,0x6b510123,0x2385003d,0x9cd7015b}},	//   днее_, _vågr, zēja_, _שוטה_
  { {0xe1f90007,0xe813000b,0xdb1c001a,0x186703ae}},	//   krų_, _ठहरा_, rpró, њаци_
  { {0xe7ee005d,0x5f05000b,0xb5aa0015,0x98c6002b}},	//   _चटका_, _वास्_, واتك_, _لغزن
  { {0x23850024,0x08fa0015,0x6d5c5f81,0xe1f90091}},	//   vēja_, _ترحب_, nkra, drų_
  { {0xa3dc005d,0x7d7b00a3,0x6f16002a,0x637e003d}},	//   तीं_, ונסו, _obyc, līni
  { {0x040d0023,0x2d540020,0x2385003d,0x24800045}},	//   _hướn, _käes_, tēja_, ăim_
  { {0x2492005c,0x6d5c002e,0x6791002b,0x42540015}},	//   łym_, kkra, _اینط, انخر
  { {0x6f160089,0x23850024,0x3f820a52,0x4153004a}},	//   _abyc, rēja_, enku_, ивыс
  { {0x9f5f022d,0x39570008,0x78fb0447,0x250b002b}},	//   yttä_, דשים_, ופיו, _ترقی_
  { {0xe4790053,0x23850024,0x6d5c5f82,0x28a7000b}},	//   _אָנש, pēja_, ekra, केटि
  { {0x6d5c0084,0x8d770086,0xa25a0015,0x6e360034}},	//   fkra, ناسا, _تشاء_, _cryb
  { {0xd12f003b,0xd2570008,0x6fca005d,0x317900dc}},	//   _ومن_, _בשדה_, _संपू, észt_
  { {0xc04f0036,0x30a30063,0x4c840033,0xd5c501c6}},	//   _ті_, _кръв, алёв, _бiзн
  { {0xe0b70053,0x6d5c5f83,0x6e360535,0x7b645f84}},	//   _בלוט_, akra, _fryb, атуе
  { {0xeab0003b,0x5f740086,0x6458008c,0x8f38000a}},	// [fbd0] قعك_, _خاور, hyvi, _יאהו_
  { {0x7bc100dc,0x645809e2,0x98f40015,0x6d5c46d1}},	//   ílus, kyvi, لثما, ckra
  { {0xc7f50001,0x2d830085,0x4e94002b,0x0000006a}},	//   узећ, mnje_, _مشیر,
  { {0x29070050,0x57a40033,0xd3660021,0x99d70015}},	//   żna_, ашча, _طه_, _لتسا
  { {0xd2465f85,0xe730003b,0x637e003d,0x95990033}},	//   _ان_, تصل_, cīni, нтку_
  { {0x7bc50f4d,0x97c50015,0xd6180015,0xf505004a}},	//   _kuhu, _مقسو, ضتها_, узко
  { {0x7bc55f86,0xbee3000b,0x0574002b,0x6395006b}},	//   _juhu, _ख़ून_, جاند, лшиф
  { {0xe1f90007,0x03251297,0xe787096d,0x4cbc004f}},	//   trų_, удин, _руго, וזוו
  { {0xdce70007,0x11d60029,0xd9e3000b,0x170a002b}},	//   siję, هوية_, गठित_, _سفلی_
  { {0x95c805e6,0xdb0f016e,0x2d830085,0x040d0016}},	//   _јута_, _ficç, jnje_, _xướn
  { {0x2d830198,0x76590026,0xdee60770,0xc4d2000a}},	//   dnje_, lywy, лони, _הגב_
  { {0x82350015,0x9f440003,0x6d5c0546,0xe1f90073}},	//   _مرتا, éjà_, wkra, prų_
  { {0x9f60001a,0xc332000a,0x0dc70033,0xa1590054}},	//   _þrír_, _לוא_, лляй_, _паду_
  { {0x8e75022a,0xc692000a,0xa2db000b,0x6d5c0ffd}},	//   руюч, צאם_, नरक्, ukra
  { {0xd00e0015,0x6d5c5f87,0x7ff50058,0x6ff50058}},	//   _فلو_, rkra, _إستا, _إستط
  { {0xa09a00b2,0x6e36005c,0x61fb0064,0x8cd4000b}},	//   _איצט, _tryb, orul, _ब्रो
  { {0xa3ab005d,0x2bc0000b,0x6d48007c,0x5f76002b}},	// [fbe0] _गठन_, _शंका, ödas, _لاکر
  { {0x6d5a0020,0xbd460015,0xb8820046,0x09f70015}},	//   ötad, _إندي, římn, افلة_
  { {0x97c50015,0xdb060030,0x040d0016,0x3c460015}},	//   لتنم, _kikü, _vướn, _صَحِ
  { {0x23850048,0xf7290036,0x3705005e,0x645810fd}},	//   dējo_, кцій_, ичів, vyvi
  { {0xe505014e,0x040d0023,0x66760086,0x6b84002d}},	//   _राशि_, _tướn, ددار, mnig
  { {0x64582ea7,0xad9b30d5,0x7ae65ca3,0x61fb5f88}},	//   tyvi, ltúr, _hekt, drul
  { {0x98a30048,0x6b840020,0xa9280024,0x61fb0045}},	//   _tajā_, onig, režģ, erul
  { {0xad9b002c,0xf3630010,0x59db000b,0x6b845f89}},	//   ntúr, йтын, मीकर, nnig
  { {0xd2500086,0xdcfc0024,0x7ae631e7,0x9757000a}},	//   زند_, norē, _mekt, _עימו_
  { {0xd1300086,0x361b0008,0xa2d4002b,0x69c00003}},	//   آمد_, _אומד, ديکت, _émeu
  { {0xe1ef0074,0x69c6022d,0x63060029,0x660200f2}},	//   يسی_, _luke, _موال, luok
  { {0x7bc5000c,0xa3c1005d,0xde590010,0x7ae65f8a}},	//   _ruhu, ंदर_, вамі_, _nekt
  { {0x33930029,0x9f5f0227,0x6b8441db,0x2d830263}},	//   _النز, nuté_, dnig, tnje_
  { {0x7bc50458,0xbd450029,0x40340142,0x6449002a}},	//   _puhu, جنسي, _векс, ślił
  { {0xc19b000a,0x2d830796,0x7659002a,0x69c6008c}},	//   _רשוי, rnje_, zywy, _auke
  { {0x61170061,0x2d830085,0x29185f8b,0x66025f8c}},	//   ağlı, snje_, _abra_, kuok
  { {0x66020a6f,0x2d8310ca,0x9f6000dc,0x4975467b}},	// [fbf0] juok, pnje_, _írás_, алас
  { {0xd9440054,0x69c65f8d,0xc27b000a,0x6b84007c}},	//   беђи, _duke, גרמי, anig
  { {0x290f005c,0x2bf40033,0xb6d500c3,0x7ae65f8e}},	//   ęga_, _ляўр, لقاع, _fekt
  { {0x98140015,0xad9b0125,0x3d11000b,0xc7b40015}},	//   إبلا, ctúr, द्रे_, مصنع
  { {0x66020007,0x06c8005e,0xaaa8006b,0xa50924fe}},	//   guok, угій_, _бърз_, вела_
  { {0x23850024,0x7c3500bc,0x61fb0061,0xf9fa000a}},	//   tējo_, ovzr, vrul, _בהשמ
  { {0x67d4005f,0x0d3c000a,0x8bb4002b,0x9f5f0003}},	//   _госу, תגוב, _خصیص, auté_
  { {0xe299008f,0x27fc002c,0x986a0061,0x2385003d}},	//   кай_, ávne_, lığa_, rējo_
  { {0xe6671d23,0x61fb13b9,0x69c00003,0x2385003d}},	//   _ство, urul, _émet, sējo_
  { {0x23850024,0xdb0a002c,0x68e70046,0x4206005e}},	//   pējo_, ľnéh, _jejd, шньо_
  { {0x93190029,0x2d840089,0xdb0a0264,0x6faa0054}},	//   _لقاء_, émem_, žnéh, квог_
  { {0xe6070087,0x68301723,0xbf5a005e,0x75235f8f}},	//   يش_, lódá, трої_, lenz
  { {0x614544cf,0x44270026,0xc105002b,0x3ea9002a}},	//   _вела, lwn_, _نوشي, _czat_
  { {0x69c6003c,0x68e701b2,0x75235f90,0x54f7000b}},	//   _ruke, _nejd, nenz, ीलिए_
  { {0x66020007,0x61e223c0,0x417a000a,0xab7a0015}},	//   zuok, _zwol, _שנצב, نمسا_
  { {0x6b845f91,0x75235f92,0x69c65f93,0xee3a0aed}},	//   unig, henz, _puke, _ани_

  { {0xbf9b0008,0x2fc7162b,0x88e6004a,0xdb1d00e9}},	// [fc00] _ביקש, _hung_, ижае, _misè
  { {0x2fc7025c,0x613400dc,0x66020a6f,0xad9b0527}},	//   _kung_, pülő, vuok, stúr
  { {0x75235f94,0xd90d002b,0xacfb000a,0x46ea07be}},	//   denz, عیف_, _בהיכ, вден_
  { {0x69c600f2,0x44270026,0x2d98052a,0x6602122e}},	//   _tuke, dwn_, lore_, tuok
  { {0x44270176,0x2fc70939,0xa4d400fd,0x5ee9000a}},	//   ewn_, _lung_, болі, רַעְ
  { {0xad9b002d,0x66020a6f,0x2d980fb7,0xe5970033}},	//   crúd, ruok, nore_, акіі_
  { {0x44270026,0xf8aa000b,0x84380015,0xb4460033}},	//   gwn_, _करिय, اكبر_, рэлк
  { {0xe3af0029,0xfbd30008,0x9f5f0152,0x75d60015}},	//   وري_, חתה_, puté_, _نيرا
  { {0x44270335,0xc2070015,0x75235f95,0x44f6002b}},	//   awn_, لقين_, benz, _نساز
  { {0xf8aa005d,0x6d89002c,0x2fc70273,0x98aa000b}},	//   _कराय, eľan, _bung_, _कराए
  { {0x2fc70023,0x656a002d,0x759b000a,0x0326005e}},	//   _cung_, mhfh, _יימח, _вден
  { {0x2fc70023,0xdcf50024,0xc207009a,0x0000006a}},	//   _dung_, pozī, دقین_,
  { {0x2d980041,0x61e2002a,0x79850034,0x511800e2}},	//   fore_, _uwol, ynhw, _болю_
  { {0x61fd01b2,0xa15715b6,0x6d48007c,0x2d985f96}},	//   ásle, _вашу_, ödap, gore_
  { {0xe0cf0029,0xf3f1000a,0xcc54006b,0x1bd5006b}},	//   _غزو_, ּ֣ל_, овръ, собя
  { {0x2bbb0029,0x752319e4,0x6d4e002a,0x68300030}},	//   ئاسة_, zenz, ajba, zódá
  { {0x98a30050,0xcf780086,0x78eb004a,0x3f995f97}},	// [fc10] _mają_, _خصوص_, вьев_, mosu_
  { {0x2d98038d,0xc4b8005d,0xd2b70008,0x3ae50092}},	//   core_, ेखाओ, שלמת_, ặp_
  { {0xe7270036,0x2fc70092,0xd87900e5,0xf6d5017f}},	//   иєдн, _xung_, دمات_, біля
  { {0xf7700806,0x15f50029,0x68e7005c,0x3f991608}},	//   وان_, مستح, _wejd, nosu_
  { {0xfb1a0008,0x7aed5f98,0x75235f99,0x1dda000b}},	//   _גורמ, maat, tenz, _बढ़ात
  { {0x2ee9003e,0x7aed5f9a,0x44270034,0x2a56000a}},	//   _leaf_, laat, twn_, _הבשן_
  { {0xad1c0008,0x75235f9b,0x2509002b,0xdb1d0003}},	//   דוור, renz, نرژی_, _aisé
  { {0xf7850029,0x7523253e,0x2d980b6c,0x2fc75f9c}},	//   _الرَ, senz, zore_, _rung_
  { {0x2fc75f9d,0x7523003f,0x2bc0000b,0x98a3002a}},	//   _sung_, penz, _शंघा, _dają_
  { {0x656a002d,0x95540015,0x7aed0079,0x0fd90256}},	//   chfh, _وخلا, haat, льмы_
  { {0x33190036,0xb97c000a,0x7aed5f9e,0x6b58001a}},	//   _біля_, כנזי, kaat, _mígr
  { {0x3204066f,0x3f9906d1,0x1167002b,0x2fc70016}},	//   bumy_, gosu_, الگی_, _vung_
  { {0x2d9802d7,0xd00e0086,0x8e550036,0x7aed5f9f}},	//   tore_, ولی_, отрі, daat
  { {0x61d6013a,0x2fc75fa0,0xe56700c3,0x78a2005a}},	//   _הוסף_, _tung_, سط_, řovi
  { {0x2d9802d7,0x645c0005,0x6e2d0064,0xa1120115}},	//   rore_, _ürit, _esab, _رويت
  { {0xd113014e,0xad9b002c,0x256b01f0,0x1efa0015}},	//   त्रण_, stúp, _følg_, _صعبة_
  { {0xcf930008,0xdd1c0089,0xc332000a,0xdb1e0125}},	// [fc20] _מטה_, mážd, הון_, _cupá
  { {0xfe370053,0x38cb002b,0xcd06006b,0x2e37004f}},	//   _פריי_, هامی_, _упой, _פריש_
  { {0xb17a00b2,0x86c60086,0x19b90036,0xb7d70087}},	//   נטער, ميان, руть_, مولا_
  { {0x7bdc02c1,0xdcf50024,0x7aed0111,0xb8ff000b}},	//   mpru, mizā, caat, _ध्_
  { {0xdcf50024,0x20050035,0x656a002d,0x36330015}},	//   lizā, huli_, thfh, كروس
  { {0x52e0005d,0xbbe90086,0x02e0005d,0x78ba00dc}},	//   नर्स, _حریم_, नर्न, _útvo
  { {0x88840086,0xdcf50024,0xb97b004c,0xc7d8000a}},	//   _بیان, nizā, _ענלי, _כַּכ
  { {0xd3260191,0x51f8005f,0xcc3b0053,0x3204002c}},	//   ськи, анию_, רעקט, tumy_
  { {0xda7b0053,0x4254002b,0x41b40015,0x637e0091}},	//   ָניר, زندر, يمبر, gūna
  { {0x2c19000b,0x6f0d02b9,0x442c007c,0x563b004c}},	//   _पहलू_, _scac, _tsd_, _געמײ
  { {0x04960029,0x20055fa1,0x657a0125,0x3f995fa2}},	//   _الضح, guli_, _imth, tosu_
  { {0x3f6724b7,0x9e15005e,0xd5be003d,0x637e0091}},	//   стоб, одмі, žāda_, būna
  { {0x539b0008,0x225a0018,0x7aed5fa3,0xdcfc0091}},	//   _גיאו, _حجاب_, vaat, norė
  { {0x661d00f2,0x41b60063,0x20055fa4,0x99800091}},	//   _äske, _усет, buli_, ivių_
  { {0x317b0008,0x6fcf000b,0xf3f8000a,0x8117000a}},	//   _תרומ, _संयं, יִּל, _החוג_
  { {0x3d1a000b,0x317e1cfd,0x600b004f,0x7c3a0052}},	//   म्बे_, litz_, _תִגְ, ætra
  { {0xad9b002d,0x9f5f0107,0x2a9b0015,0xbb840015}},	// [fc30] grúc, nutí_, ائزة_, سلكي
  { {0xb8820107,0x7aed0044,0x98c709c3,0xaffa000a}},	//   čína, saat, ссал, ָּ֑י
  { {0x48ab0010,0x6d453b87,0x67650015,0x7aed0bb5}},	//   утам_, _inha, يُطل, paat
  { {0xf1c8000b,0x1efc000a,0x27fc04b2,0xb09b004f}},	//   रदान, ָּׁמ, ávna_, ניאר
  { {0xc5fb000d,0xf8ae002b,0x99893695,0x6b58001a}},	//   уѓе_, _یکم_, evať_, _tígr
  { {0x99890050,0x637e0007,0xb465002b,0xe9a40033}},	//   stał_, vūna, يگاه, _наўп
  { {0x9989002a,0xa3491215,0x7cec004f,0xf5920058}},	//   ptał_, изка_, אַחֶ, بلوج
  { {0x6fcf014e,0xe1f90cfa,0xd3b90033,0x02450058}},	//   _संबं, аги_, шулі_, قَبَ
  { {0x41750015,0x68f9000f,0xc50b002b,0x9989006f}},	//   قادس, ֱלֹה, _متال_, avať_
  { {0xbebb00dd,0x36040015,0x41b20015,0xd83800bc}},	//   reël, _رومف, ومير, _šči_
  { {0xcea90135,0xb779000a,0xb80b005e,0xdc3c0046}},	//   _סי_, ֹאָש, влiн, táče
  { {0x60dc01e2,0x25f0005d,0x6d452c21,0x889a000a}},	//   ırma, ुंची_, _anha, יבתי
  { {0xd1090086,0xa3e5000b,0x73b8002b,0xdb060030}},	//   _نقشه_, बीर_, _اطلس_, _kikö
  { {0xaabf000b,0xb6ba000a,0x2d9e0003,0x1d0a0054}},	//   ्शनक, יצרי, ôte_, јеви_
  { {0xdb0600dc,0x8c960010,0xdb0a0089,0xeb7a0004}},	//   _mikö, іргі, žníh, асај_
  { {0x99800007,0x7f440493,0x6d453093,0xdcf5003d}},	//   yvių_, _uniq, _enha, rizā
  { {0x9989002c,0xfaa35fa5,0x2bbe000b,0xcb670054}},	// [fc40] zvať_, дато, ्दबा, цате_
  { {0x8a030080,0x6bd60015,0x2cad0046,0x291c006f}},	//   ьзуе, _وتجر, ředa_, ýva_
  { {0x6ac60015,0x9d1b000a,0x0000006a,0x0000006a}},	//   _وقدم, _דויט,   ,
  { {0x1efb000a,0xd6d00015,0x99800091,0xb7d70067}},	//   ֹּאמ, رقت_, tvių_, زوها_
  { {0xa4d40127,0xf7170015,0x70a6000b,0x6d89006f}},	//   полі, تينغ_, _ऑर्ल, dľaj
  { {0xfe9b0008,0x96330010,0xdcf50011,0x6d89006f}},	//   סיסמ, ьніц, miză, eľaj
  { {0xdcf504f9,0x04430b1e,0xd4670054,0xb7da002b}},	//   liză, дејн, жије_, _خوزا_
  { {0x39580152,0x938a009c,0x33970015,0xf2e60033}},	//   _hors_, јска_, يخية_, цюко
  { {0xa50a0001,0x67450046,0xdcf50045,0x914a5fa6}},	//   _веза_, šují, niză, ачна_
  { {0x5503034e,0xd657000a,0xd1300015,0x20740033}},	//   _опуб, _וימת_, رمج_, злоў
  { {0xd3360010,0xc3da0015,0x4254002b,0x2385003d}},	//   _мэды, _ضباط_, زنگر, zēji_
  { {0x3958038d,0x317e00b8,0xa2d30115,0x6d5a0f38}},	//   _lors_, sitz_, _قيمت, ötan
  { {0x3ead00fb,0x224b00c0,0x443e5fa7,0x93b7000a}},	//   ået_, äckt_, _hrt_, _ולאו_
  { {0x395800df,0x23850024,0x7d1b016f,0x7243002b}},	//   _nors_, vēji_, đuso, _آپول
  { {0xe88b006f,0xaac6000b,0x1bd40342,0x60db004f}},	//   _ťažš, वशंक, дося, _דקונ
  { {0xe8e00092,0xe84b002b,0x2385003d,0x3a2201d7}},	//   _đền_, یجان_, tēji_, _bpkp_
  { {0x49d80080,0xe9d00015,0x7c3e0012,0x9989002a}},	// [fc50] ждую_, نغل_, _erpr, ytań_
  { {0x443e5fa8,0x79a70010,0xe8950033,0xad9b001a}},	//   _ort_, ірае, пазь, brúa
  { {0xf84b0033,0x776948d2,0x660201d7,0xf6d500ce}},	//   шчай_, _plex, erok, піля
  { {0x35f90015,0xd774002b,0x501b004f,0x238501ec}},	//   مرتد_, وانع, שואו, pēji_
  { {0x66270029,0x8d740086,0x9f6200dc,0x3f8b0003}},	//   تراك, _رایا, épés_, incu_
  { {0xe5780036,0x2aba000a,0x7aba000a,0x39580034}},	//   озі_, _למרא, _לצרו, _gors_
  { {0xb8e1005d,0xad1c000a,0xc952000a,0x59d1000b}},	//   ुश_, יוגר, _אמם_, _थंडर
  { {0x37040001,0x42d5005e,0x9989002a,0x66024065}},	//   _очув, чіку, stań_, brok
  { {0x443e0084,0x0ca8000b,0xe513000b,0x4222056d}},	//   _ert_, _गर्म, _ठापि_, едыв
  { {0x84470015,0xc5f2000a,0x600938f9,0x95c8009b}},	//   _وخال, _נדב_, бном_, _фута_
  { {0x237f005c,0xe572000a,0x8fa6006b,0x225f01d7}},	//   piuj_, _אַף_, зане, syuk_
  { {0x224b0123,0x78a804d1,0xd436004f,0x91f50058}},	//   äcks_, _ødve, _מטעי_, _فأتا
  { {0x3ea4002e,0x1228005e,0x9e630033,0x32451377}},	//   æmt_, _моїй_, евяд, _хелг
  { {0xe80c005d,0xd256000f,0xf652000a,0xad9b001a}},	//   _हमला_, _משנה_, עצם_, trúa
  { {0x2b590144,0x10a2005e,0xdb040003,0xdc670461}},	//   _bosc_, _пишн, llié, пард_
  { {0x5aca000d,0xe51b005d,0x2b59002d,0xf092000a}},	//   слам_, प्ति_, _cosc_, _רנה_
  { {0xe8fa058f,0x3f825fa9,0x6d89320c,0x1d0a1979}},	// [fc60] йла_, miku_, džaf, _лепи_
  { {0x3f825faa,0xe8fa0010,0x23850024,0xdcf50011}},	//   liku_, ёле_, mēju_, riză
  { {0x7e6000b8,0xc72603ad,0xbd5b000a,0x1828002b}},	//   ämpf, здей, _הכיש, تقای_
  { {0xe5c6009c,0x28bd000b,0x8bd7000a,0xe50e000b}},	//   пско, ्ख़ि, _מוטו_, _साहि_
  { {0xe5340ac7,0x7ae40bab,0x9f5f4055,0xed56000a}},	//   дель, mbit, nutá_, ּבֶר_
  { {0x660200f2,0x7a8b000a,0x2bb4000b,0xa5330033}},	//   rrok, _הָלַ, ंगका, еншч
  { {0x7bc6000c,0x6ba7001c,0xebd6000a,0x3f8b0034}},	//   _kiku, _órgã, הֵ֥י_, yncu_
  { {0x07a35b60,0xb8820046,0x61d8024f,0x68ee5fab}},	//   _засн, řísn, омия_, _hebd
  { {0x784e00dc,0xa6aa00e6,0x7ae402b9,0x7bc65fac}},	//   _fővá, _طارق_, ibit, _miku
  { {0xc173004a,0x21780033,0x26c00091,0x2385003d}},	//   ельщ, ійны_, žios_, dēju_
  { {0x30130010,0x6e240007,0x04db000a,0xc953000a}},	//   ндэр, _apib, _הקבל, תמת_
  { {0x69da0089,0xdb040152,0xf487002b,0xa857000a}},	//   _čten, blié, _عالی, פיכה_
  { {0x6234109b,0x61463c36,0x63a25fad,0x7ae45fae}},	//   _целу, _неда, _ikon, dbit
  { {0x7bc600f2,0xdb1d001c,0xb2bb000f,0x6233004a}},	//   _aiku, _visí, _המדר, _чешу
  { {0x0137000a,0x8f550015,0xdd940033,0x2ca502de}},	//   _זרות_, _ينتش, хары, æld_
  { {0xf3890092,0xdb1d0057,0x6fb50015,0xd1381ed6}},	//   hản_, _tisí, _تمبا, ldą_
  { {0x63a2000c,0xd1380007,0x7bc60049,0x2f98000a}},	// [fc70] _mkon, odą_, _diku, _מכהן_
  { {0xd1380870,0x2d840030,0x3ec30046,0x9f460123}},	//   ndą_, émet_, ěstě_, rslå_
  { {0xd1380007,0x2d830263,0xb9c40015,0x63a2136b}},	//   idą_, mije_, رقمي, _okon
  { {0x2d830263,0xd366002b,0xcb0b004a,0xa097000a}},	//   lije_, _شه_, _уход_, הדבק_
  { {0xbb3a0008,0x8b3a000a,0xcb56000a,0xe60e006b}},	//   _וערי, _ותרצ, _חסרה_, ъд_
  { {0x2d830a00,0x69dd0ae5,0x63a25faf,0xb92500e5}},	//   nije_, _itse, _akon, _تفسي
  { {0x26d201e2,0x9cd8000a,0xd24e002b,0x2385003d}},	//   ıyor_, הווה_, یچه_, zēju_
  { {0x69c7016f,0xd1380007,0x61c8000b,0x0577002b}},	//   _hije, edą_, रदूष, _کارد
  { {0x22140010,0x3f82128b,0x4429002c,0x6d890057}},	//   нфэр, viku_, ňa_, ožad
  { {0x23850024,0x63a2055d,0x7aef0f4b,0x7c2e0034}},	//   vēju_, _ekon, _lect, ywbr
  { {0x6d5a0020,0x69c7016f,0x2d830263,0x20550238}},	//   ötam, _mije, dije_, фтпр
  { {0x69dd0020,0x69c7016f,0x7afd145c,0x40940033}},	//   _otse, _lije, _ndst, эрыт
  { {0xfbbe005d,0xc2c40029,0x7bc60020,0x69cf0089}},	//   ्दसम, _كيمي, _riku, _nuce
  { {0x63a202d5,0x22420134,0x69c729b9,0x2d8302c6}},	//   _zkon, ække_, _nije, gije_
  { {0x69dd0048,0x8c950036,0x7188000a,0x40950015}},	//   _atse, ерті, _מְקַ, _تلغر
  { {0x63a901e2,0x5baa0010,0x238515e5,0x0aea002b}},	//   nlen, ікам_, pēju_, ترسي_
  { {0xb2ba00b2,0x7bc64c18,0xa2ba0053,0x69cf0011}},	// [fc80] ַמער, _viku, ַמעט, _cuce
  { {0x69c7010b,0x2d8315eb,0x990a0029,0x3aec0092}},	//   _cije, cije_, تغرق_, ếp_
  { {0xb8f6005d,0x63a95fb0,0x69c715db,0xd7ef0015}},	//   _हल_, klen, _dije, لكل_
  { {0xf9890008,0xdb1d001c,0xd1380007,0xb765005e}},	//   בר_, _visã, zdą_, нтій
  { {0x2bd2005d,0xbddb0003,0x63a95fb1,0x64415fb2}},	//   _दूता, rvèg, dlen, _arli
  { {0xf3890092,0x63a95fb3,0x6b840e95,0x63a25fb4}},	//   uản_, elen, liig, _skon
  { {0x63a92c9a,0xf993000a,0x33f30040,0x9d29004f}},	//   flen, _ירש_, نسيس, לֵקִ
  { {0xdb0d03af,0x6d5a0005,0x63a91266,0xf62600d7}},	//   rmaç, ötaj, glen, _одбо
  { {0x44250020,0x64415fb5,0x200557cf,0xd010009a}},	//   _epl_, _erli, erli_, گلج_
  { {0x7bde016f,0xd5af0015,0x63bb5fb6,0xd1380091}},	//   _otpu, _نفق_, amun, udą_
  { {0xd13800df,0x2d830263,0x63a95fb7,0x6b8d5fb8}},	//   rdą_, vije_, blen, ynag
  { {0x63bb02c1,0x63a2099c,0x91e6005e,0x63a95fb9}},	//   cmun, _ukon, _жоде, clen
  { {0xc0460086,0x2d83044c,0x6d890264,0x7aef0390}},	//   سخگو, tije_, yžad, _rect
  { {0x550e000b,0x7aef1915,0x9f5f0046,0x7a380030}},	//   सलिए_, _sect, mrtí_, zútá
  { {0x69c70955,0xfe6e0086,0xd0100029,0xe5710053}},	//   _rije, لگی_, _صلة_, אַן_
  { {0x69c7016f,0x2d830263,0x69cf41d6,0x2d840144}},	//   _sije, sije_, _puce, émer_
  { {0xdb1d002c,0x2d8301a3,0x7aef16c8,0x69c73f66}},	// [fc90] _cisá, pije_, _vect, _pije
  { {0x9f5f002d,0xa81b0015,0x63a95fba,0x4ddc000a}},	//   irtí_, قتصر_, zlen, _וחזו
  { {0x69c7010b,0x63bb11b9,0x63a95fbb,0x200c06c0}},	//   _vije, ymun, ylen, nudi_
  { {0xf8df0372,0x28df014e,0x7afd0134,0xee3f0057}},	//   _प्रय, _प्रि, _udst, ový_
  { {0x69c7010b,0x85e80036,0x3c390089,0x63a91e8c}},	//   _tije, ддів_, bývá_, vlen
  { {0x660b0150,0x63a90012,0x4425050b,0x75d20040}},	//   rugk, wlen, _ppl_, ديوا
  { {0xb5c20010,0x64a20175,0x63a95fbc,0x26c200bf}},	//   ыйшл, лаша, tlen, _úkon_
  { {0x23850024,0x4b0c0008,0x63a90f9d,0x425505b3}},	//   vējs_, ַּחֲ, ulen, етот
  { {0x63a95fbd,0x03220033,0x6d5a007c,0x63bb2277}},	//   rlen, удын, ötak, rmun
  { {0x63bb0084,0x35b40033,0x44270015,0x60090a3e}},	//   smun, _абур, _يراف, пном_
  { {0x3ea9064e,0xc952000f,0x63bb5fbe,0x67b9000a}},	//   _ayat_, אמי_, pmun, ּמָק
  { {0x3c390089,0xc27501ca,0x2385003d,0xb2755fbf}},	//   zývá_, _плеј, rējs_, _плеш
  { {0x6f630010,0xcdf60033,0x2385003d,0x74c70065}},	//   увяз, эчны, sējs_, ाशकृ
  { {0xf3890016,0x200500bc,0x3ead0144,0x2385003d}},	//   iảm_, prli_, üeta_, pējs_
  { {0xc4d2013a,0x6ea0005d,0x3f6a023e,0xe1f90091}},	//   רגל_, _गुरु, _нико_, lsų_
  { {0xe9da2850,0x645c03a0,0x0000006a,0x0000006a}},	//   зка_, _àrie,   ,
  { {0x6b840005,0xfbc90008,0xdcfc0024,0xe1f90007}},	// [fca0] riig, ֶת_, airā, nsų_
  { {0x850e014e,0xe1f90007,0x7e9b004f,0x598302ed}},	//   _साइट_, isų_, _מספו, глуб
  { {0xc8960001,0x2f3a000a,0xa3c1000b,0x3c390046}},	//   храњ, ּגְד, ूदा_, rývá_
  { {0x68e301e2,0x65ad002c,0xd6c40086,0x09e640c8}},	//   ında, súhl, نمای, _помн
  { {0x6d5e3415,0x16341654,0xbbbe000b,0x4aa70065}},	//   _kopa, теля, ्दीक, _कुपव
  { {0xceb3000a,0x9f5f005a,0x26cd5fc0,0x0000006a}},	//   איד_, vrtí_, _egeo_,
  { {0x533400a4,0xc448002b,0xb4660015,0xc4f70015}},	//   вейт, بیان_, عدته, رعوا_
  { {0xd3770080,0x31c8000b,0xfbd3000a,0x8c1b0c44}},	//   ечь_, रद्ध, נתח_, לוצי
  { {0xc298087a,0x238c0046,0xe231002b,0x7d013ab6}},	//   ьких_, něji_, لکوب, ólsk
  { {0x15fb000a,0x02e0000b,0x200c5fc1,0x63a05fc2}},	//   _מהמע, _ग्रह_, tudi_, somn
  { {0x63a05fc3,0x260c0065,0xa50700af,0x232a02ed}},	//   pomn, डूरी_, _чеха_, _ножи_
  { {0x20020a00,0x200c003f,0x937a002b,0x637e0091}},	//   čki_, rudi_, _عصار_, kūni
  { {0x753a00b8,0x200c32ed,0x71f70015,0x51862d1e}},	//   _katz, sudi_, _كروس_, _пука
  { {0x238c0089,0x70540015,0x6d5e5fc4,0xee3f006f}},	//   ději_, _لنتا, _copa, rvý_
  { {0x3ce0005d,0xc3340008,0x1fa72923,0x5c040b75}},	//   कड़े_, ֣וּ_, _приг, лята
  { {0x80370015,0xcb34006b,0x7fb3002b,0x9b582c63}},	//   _أسوأ_, лесъ, _حلبچ, нист_
  { {0x28c3000b,0x5a35006b,0x5ee8000a,0x5e440015}},	// [fcb0] वेनि, ънат, _אַתְ, _مَيْ
  { {0x93bc0045,0x7cd9004a,0x7c950015,0xdd050091}},	//   _spăl, _юмор_, _للخص, _įpėd
  { {0x7af60061,0xe7870054,0x4815029f,0xb8d90065}},	//   bayt, нудо, тмес, _चर_
  { {0xdddd005c,0x35a9005d,0x6d5e0107,0x6c56004f}},	//   mysł, _चीज़, _zopa, _סירא_
  { {0x5f04000b,0x0574002b,0x26c20046,0x4efc004c}},	//   _वयस्_, گاند, _úkol_, להאו
  { {0xceb40008,0xdb160123,0xbe3c000a,0x5c8b004f}},	//   ניס_, åbör, פעות, ּאֵ֔
  { {0xd4e40036,0x0574002b,0x0395006b,0x753a06a8}},	//   уючи, داند, крия, _datz
  { {0xe3c50015,0x91c60016,0x8c1c000a,0xdb1b004f}},	//   خْبَ, _đúp_, פוחי, לֵ֖ך
  { {0x45d50036,0xe1f90007,0x637510e5,0xa5352de6}},	//   _розс, usų_, _láng, _инач
  { {0x673b000c,0xeeeb0092,0xf1a90015,0xe1f90091}},	//   _hauj, ướng_, باعه_, rsų_
  { {0x673b003d,0xc4550015,0x30750033,0xdee6053b}},	//   _kauj, _جَاب, тупс, кони
  { {0xdddd005c,0x2d9104ed,0xd4880008,0xf456000a}},	//   dysł, enze_, _אָנֹ, _ביער_
  { {0x9f5f022d,0x42040029,0x6d5e0516,0x2bb5000b}},	//   yttö_, _مِنْ, _popa, ंतना
  { {0xdb1d0945,0x6025008f,0x238c0046,0x75f80030}},	//   _lisä, _адка, věji_, _húzá
  { {0xddca00dc,0xdb04001a,0xdca615d5,0xa3e50065}},	//   ínűl, fmið, тави, बीच_
  { {0x673b0780,0x98a70089,0xcf260029,0xdb1d008c}},	//   _nauj, žně_, _شرعي, _nisä
  { {0x4b230004,0xad9b006f,0x63b90034,0x61fb05ed}},	// [fcc0] јмув, krúh, _mhwn, nsul
  { {0xda650015,0x61fb401d,0x186a06b3,0x0000006a}},	//   دافي, isul, мази_,
  { {0xd8840086,0x3f97002b,0x753a5fc5,0x673b02ad}},	//   دهای, _سپید_, _ratz, _bauj
  { {0x753a00b8,0xf0b6004c,0x86c6006e,0xb8050015}},	//   _satz, דלער_, نيان, ابله
  { {0x9f590152,0x36330015,0xc6760015,0x7d7c004f}},	//   éré_, لروس, خطاب, ּנ֔ו
  { {0xe5e50029,0x6e290064,0x4e7b0053,0x1513005e}},	//   اثني, çebi, ואנצ, идія
  { {0xe9df0092,0x29180061,0x75f80030,0x61fb5fc6}},	//   _trúc_, _icra_, _búzá, esul
  { {0xd2140054,0xdcee006f,0x889b000a,0x60cd140d}},	//   гмић, jobľ, _חבלי, _şamp
  { {0x171b00b2,0x61fb0035,0xdddd005c,0x32530063}},	//   _קומע, gsul, zysł, ивър
  { {0x673b0264,0x21540033,0x71740040,0xf617000a}},	//   _zauj, укоў, اهدا, _בחמש_
  { {0x7bda0c98,0xc05700e2,0x61fb3591,0xb8fc0138}},	//   ítul, вія_, asul, цкiм
  { {0x57fb000a,0x03a317b6,0xb363009b,0x6375039f}},	//   ולטו, _кихо, _въшк, _cánd
  { {0x32170018,0x76425fc7,0x5f941fdb,0x63750077}},	//   _ليند_, nvoy, рият, _dánd
  { {0x7e6000c0,0x2126002b,0x61ed0061,0x9f5f006f}},	//   ämpa, _شيعی_, _çala, nutú_
  { {0xdb04002e,0xfaff003d,0xc5880016,0xac18004e}},	//   tmið, žīmu_, gồi_, кору_
  { {0x61170064,0xa057000f,0x0057000a,0xdb500015}},	//   aşlı, _יסוד_, _ישות_, يَّ_
  { {0xdb04002e,0xae9b0015,0xd91b004a,0xa021007c}},	// [fcd0] rmið, _تضغط_, дье_, _ööra
  { {0xdb1d0945,0xd7e70191,0xdb040084,0x2d870064}},	//   _sisä, відо, smið, _öne_
  { {0x201e022d,0x9e670086,0xa9c4022a,0x87d40015}},	//   ntti_, _ساکن, рстк, لغنا
  { {0xd6db0036,0x201e00f2,0x6d5a0020,0xdcfc0045}},	//   єте_, itti_, ötav, piră
  { {0x63b90176,0x98b10011,0xf7700087,0xe796002b}},	//   _rhwn, _bază_, غام_, دالک
  { {0xe5b40033,0xad9b0125,0xf6500015,0x5964006b}},	//   айчы, frúi, تئم_, _къса
  { {0x33f40010,0xb8f7000b,0x1dda000b,0xdd030091}},	//   ачыс, ाख_, _यूनत, ūrėd
  { {0x1cb80008,0x274200dc,0x86c5002b,0x07080015}},	//   כלול_, ténő_, _ميزن, _ليفي_
  { {0x68f50014,0xd6d9005c,0xe1f10115,0xe6100015}},	//   _kezd, _całe_, حسب_, _وشك_
  { {0xf3890092,0xc1050087,0x68f55fc8,0x637510e5}},	//   iải_, دودي, _jezd, _sánd
  { {0xf3890092,0xbfc60063,0x61fb439c,0x853a000a}},	//   hải_, лбок, ssul, _רגעי
  { {0xeeeb0023,0x201808e0,0xf8b20008,0xd24e002b}},	//   ường_, ària_, משי_, آنی_
  { {0x5fcf005d,0x877a0008,0x637519fe,0x201e5fc9}},	//   _संकल, תארי, _vánd, atti_
  { {0x90450002,0xadb70015,0x68f5053e,0x5bbe000b}},	//   _منته, ُهَا_, _nezd, ्द्व
  { {0x919a0053,0xa3e6005d,0xfc03005e,0x6561016e}},	//   _אױספ, _बढ़ा_, йпро, _molh
  { {0x29030014,0xf092013a,0x3f8b0003,0x200a0046}},	//   _adja_, _לנו_, ébut_, ábie_
  { {0xf2d200b4,0x4a460033,0xdb040030,0x68f509fa}},	// [fce0] מען_, ынав, gliá, _bezd
  { {0x1e57000a,0x236d016d,0xdcee01ec,0x0000006a}},	//   _עשיר_, hkej_, ribē,
  { {0x9d1b00b2,0xa8060001,0x98b10045,0xd70a033d}},	//   _אויט, узел, _rază_, енее_
  { {0x97a5005e,0xdb0401d3,0x0000006a,0x0000006a}},	//   аріл, bliá,   ,
  { {0xab65003d,0xe9df001a,0x98b10045,0x65615fca}},	//   _daļā, _trúa_, _pază_, _bolh
  { {0xceb301e4,0x201e55d5,0xda4b000a,0x68f50061}},	//   ציג_, ytti_, _אֲלָ, _gezd
  { {0x44260029,0xf8b8000b,0x2600000b,0xd90d002b}},	//   ارتف, _अरिय, _रिकी_, _زین_
  { {0xb8930029,0x24430061,0x6f0416a5,0x27fc006f}},	//   _الفع, _dım_, _ndic, ávnu_
  { {0x0676008f,0x6561001c,0x75d60029,0x69ce003f}},	//   _сувя, _folh, _إيطا, _kibe
  { {0xaa370053,0x6f045fcb,0xdb1e01c9,0x3a37000a}},	//   נטיק_, _adic, _kupó, נרים_
  { {0x0577003b,0x201e333f,0xf957000a,0x1957004c}},	//   _حملة_, utti_, אסית_, אביל_
  { {0x236d032c,0x201e5fcc,0x22460111,0x7174002b}},	//   ckej_, rtti_, _trok_, اهگا
  { {0x61e20014,0xf1ba0092,0x91620092,0x11543a2d}},	//   _utol, _thơ_, hử_, _вклю
  { {0xa1580054,0xdde30030,0x6f045fcd,0x823b000a}},	//   _јаку_, örűe, _edic, _נעוצ
  { {0x80db0008,0x60db000a,0xeb4b005e,0x2b890058}},	//   _אחוז, _אקונ, нчак_, نَسٍ_
  { {0x501b000a,0x0000006a,0x0000006a,0x0000006a}},	//   _נוחו,   ,   ,
  { {0x3d950036,0xd8f50001,0xb9c50015,0x3f8b5fce}},	// [fcf0] _випр, изањ, لقري, micu_
  { {0x2d8a02c1,0x6d5a0020,0x3f8b2996,0x6448050d}},	//   cibe_, ötat, licu_, _ordi
  { {0x69ce0375,0xdb1e0077,0xc6d50054,0x66040091}},	//   _dibe, _cupó, ажећ, šikl
  { {0x99d70029,0x3f8b049f,0xdb040077,0x69ce02f7}},	//   _متسا, nicu_, pliá, _eibe
  { {0x8afa000a,0x69ce304a,0xbafa000a,0x7e7d0012}},	//   _שהשי, _fibe, _בהרש, nzsp
  { {0x2cad0089,0x442c01d7,0xd6180015,0x95c40040}},	//   ředu_, _bpd_, طتها_, مينه
  { {0xf8a9000b,0xc4f80015,0xd5120015,0x98b1002a}},	//   _कडिय, اعها_, زِيد, _bazą_
  { {0x442c00e8,0x3f8b0e1d,0x2d8a0061,0x64435fcf}},	//   _dpd_, jicu_, zibe_, rvni
  { {0x3f8b016f,0x64485fd0,0x9f460030,0x7bd75fd1}},	//   dicu_, _erdi, zsló_, _luxu
  { {0x236d002c,0x200300bc,0x7e7d0030,0x2d8a016e}},	//   skej_, šjim_, dzsp, xibe_
  { {0x21270086,0x7649002e,0x637502c1,0x6e2d0375}},	//   نيکی_, _hrey, _cánc, _apab
  { {0x8fa60449,0x7bcf5fd2,0x0000006a,0x0000006a}},	//   раме, _nicu,   ,
  { {0x200c5983,0xd235006b,0xd2680067,0x6d890e1f}},	//   ardi_, _ъндъ, _مصون_, ržan
  { {0xeeeb0023,0x427a0008,0x21660054,0xf27a000a}},	//   ưởng_, _באנג, _виши_, _ברנש
  { {0x6b660063,0x6729005c,0x61e90007,0x5c73004a}},	//   аква, _obej, lpel, олёт
  { {0x28a9005d,0x7aed0035,0x9e66004a,0xb09a0447}},	//   _कड़ि, gbat, _ввид, _שיקר
  { {0x6d5a0020,0x7f3b000a,0x7bcf0509,0x99f6005e}},	// [fd00] ötas, _יעקו, _dicu, рябі
  { {0x4dfb0053,0x5dfb0135,0xdebb000a,0x8dfb000a}},	//   _שפיא, _שפינ, _במפל, _שהית
  { {0x49990036,0xa856049d,0x3a2033f9,0x320d1bd0}},	//   уття_, штај, stip_, hrey_
  { {0x764909f0,0xe666005e,0x1cb7000a,0x70d2000b}},	//   _brey, итло, _כליל_, _सल्ल
  { {0xe4da0086,0x1dbc000b,0x76490077,0x28b8000b}},	//   نوشت_, ोगपत, _crey, _अरवि
  { {0x25080086,0x7bc45fd3,0x58d30015,0x320d0d3a}},	//   ارشی_, lmiu, _ويُذ, drey_
  { {0x9cd7013a,0x7d7b0008,0x7d57000a,0x54330015}},	//   בוצה_, כנסו, ייסד_, قرير
  { {0x8bd7000a,0x200c0085,0xc3540099,0x320d5fd4}},	//   סופו_, vrdi_, скиј, frey_
  { {0x7e6000c0,0xd2500087,0x637507da,0x3f8b10af}},	//   ämpl, سند_, _sánc, vicu_
  { {0x644800bd,0x7aed0011,0x200c00bd,0xdfda006b}},	//   _trdi, zbat, trdi_, към_
  { {0x40340063,0xc32a0015,0xc9b7000a,0x7aed0061}},	//   щенс, _لكان_, שהית_, ybat
  { {0xde590010,0x6d890085,0x7e7d0012,0xd604005e}},	//   гамі_, ažal, tzsp, _вiдв
  { {0xa1160074,0x290700dc,0xdb04008c,0x3f8b0e1d}},	//   _نوشت, ónak_, iliä, ricu_
  { {0x7bcf02d7,0xac190848,0xd6d9002a,0x63750030}},	//   _sicu, логу_, _mała_, _tánc
  { {0xdd940033,0xef1f0030,0x3f8b1418,0x70530021}},	//   цары, niük_, picu_, _ونها
  { {0x7aed007c,0x6d5a04f8,0x63750030,0x4b540058}},	//   ubat, ötar, _kána, يَّر
  { {0xf1ba005d,0x8d87002b,0x7aed28bb,0x49750421}},	// [fd10] _उठान, _نشدن, rbat, блас
  { {0x63750084,0x5d840015,0x69da0046,0xad9b001a}},	//   _mána, _وليل, _čtet, trúu
  { {0xd2460086,0x66d50029,0x39a4005e,0xb6d50015}},	//   _کن_, ميائ, ішув, مقاع
  { {0xdc360053,0x07080015,0x870701c5,0x6d89003d}},	//   _פארט_, ليمي_, ряже, ižam
  { {0x6375002e,0xd6d9005c,0xcb56000a,0xa50901d2}},	//   _nána, _cała_, _הסרה_, гела_
  { {0x2a3a0053,0x27070092,0xce38000a,0x64e80015}},	//   _געשמ, ốn_, יאדת_, لّهِ_
  { {0x8458006b,0x7b060030,0xe894004a,0xd7e4005e}},	//   ирът_, _áttö, _дарь, _міто
  { {0x7649002e,0x6b8d5fd5,0xe4500015,0x637501d3}},	//   _trey, niag, بضه_, _bána
  { {0xe5070086,0xb3840086,0x6375002d,0x28c3000b}},	//   _نباي, تجوه, _cána, वेरि
  { {0x3f890026,0xc5170015,0x61e934b5,0x61ed0061}},	//   _amau_, _خبرت, rpel, _çalm
  { {0xe4500015,0x98b8003d,0x94740015,0x61e95fd6}},	//   _يضم_, _karā_, _ودما, spel
  { {0xa8560008,0x2d9e0089,0x6375002d,0x34b60008}},	//   צירה_, čtem_, _fána, _הפעם_
  { {0x86350053,0x82d60008,0x42da004c,0xc105006e}},	//   זאָג_, _הונג_, _עקסע, _هوشي
  { {0x92b40015,0xf088002b,0x61e6001a,0x63a95fd7}},	//   _بحما, ائیه_, íkle, loen
  { {0xc0c80001,0xdd8f00e5,0xc0a8002b,0x3b0a009f}},	//   _куће_, روف_, _پاول_, лево_
  { {0xef1a0146,0x8b660015,0x6b8d5fd8,0xae46009a}},	//   _сми_, حاسم, giag, _هپبو
  { {0x9f5f0264,0xc8d60015,0x25790003,0x60e60030}},	// [fd20] nutý_, مزاع, _zèle_, _érmé
  { {0x63a92538,0x8a030088,0xc9860015,0xe8f707c9}},	//   hoen, язуе, حشري, йлу_
  { {0x46ea000d,0x28c3000b,0x6b8d01e0,0x0000006a}},	//   гден_, वेलि, biag,
  { {0x7c3e010b,0xc7950010,0x18670054,0x63a900aa}},	//   _ispr, орчы, љаци_, joen
  { {0x858a0010,0x200300bd,0x63a90150,0x46580033}},	//   лёка_, šjih_, doen, ралю_
  { {0x96330033,0xe5a3005e,0x3eb2008c,0x09e32925}},	//   яніц, пичи, _myyt_, _хорн
  { {0xe3af002b,0xf7461635,0x84460015,0x1867098a}},	//   کرو_, _лево, إختل, _лари_
  { {0xd3770010,0xd7960015,0x75d60015,0xfbd3000a}},	//   йчы_, _الرخ, _هيرا, התה_
  { {0xc114012e,0x8b5705bd,0x32020046,0xf1a6030c}},	//   омпј, מיקס_, éky_, йрон
  { {0x660200dc,0xb97b004c,0x7c3e0f5d,0x0ef1000b}},	//   msok, ָנטי, _ospr, चर्स_
  { {0xdbf10046,0x9f990054,0xa3df000b,0xd250002b}},	//   _přín, ивоу_, _धूप_, سنگ_
  { {0x443e0bcf,0x389b0008,0x83c609ef,0x289b00a3}},	//   _ist_, ריטנ, _убеж, ריטא
  { {0x71a60010,0x68fe00aa,0x82b60067,0x69c5377d}},	//   _ладз, kapd, _احاط, ymhe
  { {0x61430c1d,0x6d5a008c,0x9f5f0046,0x660202d8}},	//   _неча, ötap, isté_, isok
  { {0x9fe6003b,0x3ea00c87,0x5478000a,0xb478000a}},	//   _استه, _exit_, בְּנ, בָּי
  { {0xb097000a,0x62801ed5,0x99d70015,0xeafb0015}},	//   _לדוח_, ozmo, متطا, طررت_
  { {0xeab30029,0x6b8d5fd9,0x7c3e5fda,0xaa581f5c}},	// [fd30] سعر_, riag, _espr, биту_
  { {0x88950063,0xaac5000b,0x443e5fdb,0x63a90079}},	//   оизх, लेषक, _ost_, zoen
  { {0x69c5002f,0xf7700086,0xdb0d002d,0x32cf0064}},	//   rmhe, کال_, llaí, _köyü_
  { {0xdb0d002f,0xbb55002b,0x0000006a,0x0000006a}},	//   olaí, _بچسب,   ,
  { {0x443e39a3,0x8f9c000a,0x637c0077,0x6f7a004f}},	//   _ast_, נידי, _ménd, סְעו
  { {0xdcf50048,0x85c80015,0x98e50015,0x443e5fdc}},	//   mizē, مِنْ_, _ذكرو, _bst_
  { {0xdcf50048,0xad1c0643,0x443e00da,0x2bbf000b}},	//   lizē, טוגר, _cst_, ्षपा
  { {0x443e065b,0x42090054,0x11e5023d,0xe3b90b1e}},	//   _dst_, анио_, ожим, јби_
  { {0x443e0b7a,0x93bc0011,0xdcf50024,0x6d89016f}},	//   _est_, _apăs, nizē, ržaj
  { {0x6606001a,0xbbb5000b,0x63a45fdd,0xc00504e5}},	//   _ækka, ंतुक, čina, опок
  { {0x25a0002f,0x7dc00c19,0x3eb2008c,0x98b80045}},	//   éile_, nöse, _syyt_, _iară_
  { {0xd6d9005c,0xa8a8000a,0x1ee7002b,0x00c60033}},	//   _mało_, מֹרִ, يوپی_, ўлюк_
  { {0xa224002b,0xdb0d0125,0xceb60015,0xd26b0058}},	//   _فروه, glaí, تحدث, _حصان_
  { {0xb4f9004c,0x9f460125,0x2fc00bbc,0x31c71368}},	//   יפֿי, mplí_, _whig_, _усев
  { {0x3d1b005d,0x2fc0002d,0x63751754,0xa3df000b}},	//   _बारे_, _thig_, _jáno, _धूम_
  { {0xdb04002f,0xa088000a,0xe8e00016,0x0aea0033}},	//   lliú, _לְפִ, _đốn_, рдай_
  { {0xc33204dc,0x98b80011,0xdb0d002d,0x99e90015}},	// [fd40] וון_, _oară_, claí, معلق_
  { {0x61e4002d,0x09060033,0xb8b60054,0x9f5f0077}},	//   _éile, іпен, осећ, butó_
  { {0x19b90036,0xb17a0053,0xdb040125,0x93bc0045}},	//   суть_, סטער, iliú, _mpăr
  { {0xd378016f,0xd6d9002a,0x6280002a,0xc66a012e}},	//   _kuće_, _dało_, yzmo, ишле_
  { {0x98b80011,0xdcf50024,0x68e90045,0x8f9b000a}},	//   _bară_, cizē, _şede, סיני
  { {0x1dbc005d,0x53e603fc,0x8cda000a,0xd9560015}},	//   ोगित, оциа, ׁחְת, _بنسخ
  { {0xd8230124,0xf71a0010,0x475a1660,0x68fc00dd}},	//   _одри, _візы_, _края_, _ierd
  { {0x93bc04f9,0xad9b0125,0x0776002b,0x66020091}},	//   _apăr, hrúp, _بهرح, psok
  { {0xa5f70083,0x613f0091,0x2e24001a,0x61d70033}},	//   _меѓу_, kšlė, jöf_, омыя_
  { {0x3178005c,0xd578000a,0x316a0054,0x5578000a}},	//   órz_, _פָּר, ршио_, _פְּד
  { {0xd8db0053,0x6fe10024,0xc8db0008,0x6280002a}},	//   יקיר, _pēca, יקיט, szmo
  { {0xc43b000a,0x6266002b,0x68fc0061,0x63750030}},	//   _כתבי, _واشق, _lerd, _jánl
  { {0x7dc00030,0x68fc042f,0x8d6b0054,0x6146135e}},	//   zöse, _oerd, ајва_, _меда
  { {0xdcf50048,0x225902de,0xdb0d0125,0x61430054}},	//   vizē, åske_, rlaí, _жеља
  { {0xa3b1005d,0x6568002d,0xbc480080,0x7b67004a}},	//   _फ़ीड_, _modh, очте_, отае
  { {0xdcf50024,0x6d4b0091,0xd47b000a,0x929d002a}},	//   tizē, _ėgau, באלל, egły
  { {0x29d5003b,0x637c0c98,0x68fc0375,0x4fd40033}},	// [fd50] سياس, _géne, _berd, _ўжыт
  { {0xdcf50024,0x68fc5fde,0x753800bc,0x6f1d0374}},	//   rizē, _cerd, jevz, lgsc
  { {0xf8070010,0x68fc049c,0x2d915fdf,0x2ca70045}},	//   ючан, _derd, mize_, _ând_
  { {0x657a0041,0xcc3a0053,0x17f80029,0x3ead005c}},	//   _alth, _פערט, تركة_, żetu_
  { {0x7afd0048,0x68fc0cc2,0x6d455fe0,0xcc88002b}},	//   _iest, _ferd, _kaha, _هنیه_
  { {0x2d9101e2,0x68fc0176,0x6d475fe1,0x89da000a}},	//   nize_, _gerd, ndja, _לחשי
  { {0x7dc000b8,0x63a40057,0xe4e4042b,0x98b80045}},	//   lösc, činn, фічн, _vară_
  { {0x03a8003b,0x6d455fe2,0x68e50026,0x7afd5923}},	//   يديو_, _laha, lchd, _jest
  { {0x68fc0064,0x929d002a,0x68000030,0xe664004a}},	//   _yerd, kałe, _tájá, _отфо
  { {0x61e60156,0x05770087,0xe8d5000a,0x3ce5000b}},	//   íkla, _بارد, ּוֹר_, कडों_
  { {0xf9920008,0xcea90053,0xd4910092,0x929d005c}},	//   תרי_, _עי_, _kèm_, dałe
  { {0x69d500b8,0x76400026,0x7afd5fe3,0x64415fe4}},	//   _lize, _ysmy, _nest, _isli
  { {0xe8b8005d,0x9e1e0033,0x6d455cc9,0xa2f6000a}},	//   _अर्च, ычнi, _baha, _זמנה_
  { {0x6d450509,0x7afd00c7,0x2d9100da,0x69d500bc}},	//   _caha, _aest, gize_, _nize
  { {0x30790053,0xdbf10089,0x6375002d,0xe108000a}},	//   _לאַנ, _přán, _lánm, _וּפָ
  { {0xbea60036,0xd00e0029,0x69dd304a,0x7afd0480}},	//   _найк, _إلي_, _buse, _cest
  { {0x2d840152,0xdb0d002e,0x7afd5fe5,0x68fc23c3}},	// [fd60] èmes_, rmað, _dest, _perd
  { {0x7afd1c23,0xe8e00092,0x7ae45fe6,0x3a99005e}},	//   _eest, _đồn_, scit, іттю_
  { {0x69d55fe7,0x07fa0029,0x7db50010,0x65685fe8}},	//   _dize, صراع_, _ісьц, _rodh
  { {0x68fc0959,0xd7ef0029,0x9989005c,0xacf6002b}},	//   _werd, اكن_, grał_, _بسکت
  { {0x69d55fe9,0x68fc0375,0x91620016,0x64410bc7}},	//   _fize, _terd, hứ_, _asli
  { {0x7afd37b3,0x7bde27ae,0x20051bab,0x89d70058}},	//   _zest, _kupu, ksli_, _روفر_
  { {0xd4670124,0xe5b30010,0xec360053,0x25fd005d}},	//   зије_, эйшы, לאַר_, रीबी_
  { {0x929d005c,0x8c1b0135,0x889b000a,0xc79a002b}},	//   załe, צופי, _הבלי, _اپرا_
  { {0xd6eb0008,0xcebf002a,0x65680125,0x7bde3c23}},	//   _הַבָ, łęzi_, _todh, _lupu
  { {0xad9b002d,0x867b000a,0x20740033,0x067b000a}},	//   gsúl, _הרמו, длоў, _הנמל
  { {0x2d910089,0xc9530008,0x6d455fea,0x7bde007c}},	//   vize_, גמת_, _raha, _nupu
  { {0x929d005c,0x4fc70010,0x6d455feb,0x6e95004a}},	//   wałe, яспа, _saha, диму
  { {0x32ba0029,0x798e003f,0x6e3d0111,0xe8dc000b}},	//   _اداة_, _ombw, uwsb, _बलूच
  { {0x7afd5fec,0x69dd5a41,0x80260015,0xfe700015}},	//   _sest, _ruse, _فربم, ادَ_
  { {0x40a80086,0x91bb0008,0x718b0008,0x6c542fa9}},	//   _بخشی_, _המגי, _לְהַ, нкру
  { {0x1fa40010,0x69d53d86,0x6d45324c,0x69dd5fed}},	//   _прыг, _size, _waha, _puse
  { {0xaa5803e3,0x2bb80015,0x7afd5fee,0xda340033}},	// [fd70] питу_, سافة_, _vest, неты
  { {0x68270010,0x7afd02b3,0x6d8900bc,0x7e7c000a}},	//   зьдз, _west, ežav, _לאחז
  { {0x29015fef,0x68e52851,0x7afd5ff0,0x69d55ff1}},	//   raha_, rchd, _test, _vize
  { {0x56950080,0xe6950029,0x2901064e,0x78b50107}},	//   мает, ولاد, saha_, _vyzv
  { {0x69d500dc,0x85e80015,0x8b080046,0x7dc00123}},	//   _tize, كّنك_, stří, lösa
  { {0x7c94002b,0x660d1c4e,0xda5a004f,0x0000006a}},	//   _آشیا, šako, _וכשל,
  { {0x57f501f3,0x44330144,0x5d48000a,0xe5040015}},	//   _іпат, ïx_, לָהּ_, ربوي
  { {0x77050074,0xbc7c000a,0xe3b10015,0x27f60046}},	//   _آژان, מנות, خرت_, ýdnů_
  { {0xd3460086,0x3a290509,0x4222004a,0x929d002a}},	//   بینه_, ntap_, вдыв, wałb
  { {0xa1890036,0x442700d9,0x3a290061,0xfaff00aa}},	//   ібна_, ptn_, itap_, _leë_
  { {0x8fa607de,0x6441016f,0x645e00f2,0xdcf50091}},	//   дане, _usli, äpit, lizė
  { {0x54340086,0x73c40015,0x7bde0045,0xdbcc001a}},	//   _سرمر, _كيلم, _rupu, jóðn
  { {0x8e550036,0x8db6005e,0x7bde5ff2,0xe28e016a}},	//   нтрі, дсві, _supu, _ра_
  { {0x2256002b,0xd1310067,0x59d8000b,0x7bde1f85}},	//   _آلود_, _شمع_, _भूगर, _pupu
  { {0x2d840007,0xfce35ff3,0x224d1945,0x21a214c2}},	//   ėme_, тосо, lvek_, _шишм
  { {0x05dd005d,0xd378016f,0x0b1a0015,0x5ffa000a}},	//   मदाब, _kuća_, تقرة_, _והקה
  { {0x394602e1,0xaec60457,0x6fe80046,0xef19002a}},	// [fd80] мнаг, _юбил, _věce, óże_
  { {0xda650029,0x637c0152,0xf9c7017f,0x7bde0ff0}},	//   راقي, _ména, дгук_, _tupu
  { {0xc9d5002b,0x6f0d0034,0x637c001a,0x872600fd}},	//   رممک, _ydac, _léna, дмеж
  { {0x2907001a,0x0000006a,0x0000006a,0x0000006a}},	//   ónar_,   ,   ,
  { {0x6d890a00,0xeb3b000a,0xb5aa0015,0xc6e5005e}},	//   ržav, _ועכש, ياتك_, хієп
  { {0x2508002b,0xf200000b,0xc3e60015,0x91620016}},	//   سرتی_, लीफ़_, وثبو, iữ_
  { {0x91620016,0xe71a0015,0x224d0030,0x0000006a}},	//   hữ_, _ويست_, evek_,
  { {0xe737005e,0x938a0033,0x0000006a,0x0000006a}},	//   _оес_, ўска_,   ,
  { {0xc2980142,0xd62600e6,0x25fd000b,0x76170058}},	//   яких_, _تعزي, रीदी_, _يقفز_
  { {0x99de0010,0x8506002b,0x637c0003,0x661d0123}},	//   вiка_, _آوان, _déna, _åska
  { {0x645c0007,0xa0a60142,0xf993000a,0x04db000a}},	//   _šrif, ьшил, כרז_, _וקבל
  { {0xd2520015,0x28c30065,0x20112067,0x0000006a}},	//   _لنص_, वेटि, ázia_,
  { {0xdb0d08e0,0x91620016,0xef1f0061,0x9df8024f}},	//   llaç, gữ_, rgü_, мнят_
  { {0xb2bb000a,0xe81f000b,0x6fde003d,0x7dc0008c}},	//   _ומדר, मूडा_, _līci, tösa
  { {0x0137000a,0x30830015,0x1fa707ec,0xfe79005a}},	//   _חרות_, _للوف, _ориг, šů_
  { {0x6d89006f,0xc1780091,0xdfa70015,0x9b581d8a}},	//   ežat, lkė_, _تحتي, мист_
  { {0x4efc000a,0x99d90015,0xa2c4000b,0x4ea70033}},	// [fd90] _והחו, سواء_, ाइट्, _юрка
  { {0x2eaa004c,0x929d002a,0x7dc00123,0xc1780091}},	//   _משפּ, nała, lösn, nkė_
  { {0x63a4016f,0x98b8002a,0xd7e4008b,0xdd91002b}},	//   činj, _karę_, вічо, _لوک_
  { {0x8c1a00b2,0xcc76000a,0x224d0046,0x7dc00030}},	//   _צורי, _נערה_, yvek_, nösn
  { {0x659511f2,0x28c3000b,0x929d002a,0x7bcd110b}},	//   наду, वेजि, kała, mmau
  { {0x9f5f01c9,0xdb0d016e,0x63a20038,0xf9fa000a}},	//   vrtý_, flaç, _ajon, _מהשמ
  { {0x637c0152,0x7bcd00f2,0x3cfc000a,0xa2e50033}},	//   _séna, omau, חלונ, нойд
  { {0x13090191,0x637c0003,0x7bcd0012,0x6609156a}},	//   чний_, _péna, nmau, _tvek
  { {0x46150086,0x2609000b,0xd794006b,0x7bcd0012}},	//   _سوار, _सिटी_, _ритъ, imau
  { {0x7af60089,0x99800064,0x91b40016,0x224d5ff4}},	//   zbyt, iriş_, _đẹp_, rvek_
  { {0x44270067,0x0000006a,0x0000006a,0x0000006a}},	//   _زراف,   ,   ,
  { {0x987a0053,0x9989005c,0xf1b904c6,0xa3c2000b}},	//   פארט, eważ_, duše_, ूषण_
  { {0x69c7022d,0x539a000a,0xa1590432,0x63bb5ff5}},	//   _ohje, _צינו, _наду_, mlun
  { {0x66d601e2,0x63bb13fd,0xc5f2000a,0x91620016}},	//   _hükü, llun, רדם_, rữ_
  { {0x6d8900df,0xdca309dd,0x63bb5ff6,0xcc150058}},	//   ežas, гари, olun, َذِب
  { {0x63bb194e,0xbb431f54,0x0000006a,0x0000006a}},	//   nlun, леск,   ,
  { {0x63bb00b8,0x19c6219d,0xfce620b8,0x2bb50065}},	// [fda0] ilun, ебам, _попо, ंतजा
  { {0x63bb00b8,0x7af65523,0x3afe0016,0x63750030}},	//   hlun, sbyt, ắp_, _dáni
  { {0xad1b0053,0xa3df000b,0xacfb000a,0xb9b5006b}},	//   _צוטר, _धूल_, _מהיכ, тстъ
  { {0xdd20000b,0x63a405ba,0xad9b006f,0x7bc6014b}},	//   _बाँध_, čink, esúh, _uhku
  { {0x63bb0b0f,0xe4e6005e,0x2bbf0065,0xdef7004f}},	//   dlun, нійн, ्षरा, גמנט_
  { {0x63a23b5d,0x6c9a000a,0x746a0c31,0x63bb5ff7}},	//   _sjon, ּשֵׂ, зрив_, elun
  { {0x63bb5ff8,0x637501c0,0x63a25ff9,0xccf3004f}},	//   flun, _záni, _pjon, נכה_
  { {0x6b840026,0x32662b7a,0x929d002a,0x9989002a}},	//   nhig, етов, wała, zważ_
  { {0xe1ef0086,0xdb0d001c,0xdd20000b,0xdb041115}},	//   یسی_, slaç, _बांध_, llió
  { {0xc1780007,0x82330115,0x75d30015,0xdb0d1e83}},	//   ukė_, اريا, _ميقا, plaç
  { {0x98b8005c,0x672222b3,0xb4250015,0xd4c60015}},	//   _parę_, ogoj, _لعنو, _أغذي
  { {0x389b00a3,0x672214f2,0x289b000a,0x27fc006f}},	//   ליינ, ngoj, לייא, ávny_
  { {0xdd910015,0x6d8919a6,0x67220091,0x13890015}},	//   لوح_, džar, igoj, _تخلى_
  { {0xad9b002d,0x7ec90024,0x6f06005c,0xe611000a}},	//   osúi, _rūpī, aakc, יִל_
  { {0x61e200f2,0x66d60064,0x41c30002,0x2177000a}},	//   _huol, _yükü, _حقوق, _אתגר_
  { {0x201e0005,0x61e200f2,0x00bb000a,0x60bb000a}},	//   muti_, _kuol, _ממומ, _מצוד
  { {0x4fd80008,0x63a0002d,0x201e5ffa,0x9fad0046}},	// [fdb0] _אוהב_, inmn, luti_, _něé_
  { {0x25a00125,0x213e2356,0x7bcd5ffb,0xd99b0058}},	//   éill_, neth_, smau, أخرا_
  { {0xac990086,0x201e5ffc,0x39a40292,0x61e2008c}},	//   _آنجا_, nuti_, уштв, _luol
  { {0x98140015,0x6b840b20,0x7d075318,0x501b004f}},	//   ابلا, chig, lajs, לובו
  { {0x61e21a91,0x213e00da,0x201e007c,0xe56e1b5d}},	//   _nuol, keth_, huti_, аз_
  { {0xe4e70191,0x201e5ffd,0x7d074d5f,0xc5f40015}},	//   хідн, kuti_, najs, اثنت
  { {0x63bb002e,0xf992000a,0xa988000a,0xad9b0125}},	//   tlun, _כרך_, _נָשִ, gsúi
  { {0x637c0152,0x63bb5ffe,0x201e3acf,0x9f5f013f}},	//   _déno, ulun, duti_, ystá_
  { {0xd36e0029,0x2d81016e,0x7d07006f,0xc3d40033}},	//   تهي_, _olhe_, kajs, ыўшы
  { {0x63bb00ca,0x201e003f,0xe6070086,0x2cad0046}},	//   slun, futi_, یش_, ředy_
  { {0x22460213,0x7d070107,0xdb0f0046,0x6556000a}},	//   _esok_, dajs, _akcí, _שבעא_
  { {0x213e0176,0x22920086,0x7dc0008c,0x0000006a}},	//   aeth_, الیس, töso,
  { {0x201e0007,0x333f0003,0x213e5fff,0x8268005e}},	//   auti_, meux_, beth_, _паїв_
  { {0x333f0152,0x201e6000,0xadb70015,0xc0e2112c}},	//   leux_, buti_, َهَا_, _кошк
  { {0x1c39007a,0x67220007,0x5c1517be,0xfc030674}},	//   нять_, ygoj, льту, ипро
  { {0x6e960029,0x333f0152,0xbddb0003,0x929d002a}},	//   _للعا, neux_, uvèr, nało
  { {0x7db60015,0x333f0003,0xcfb7000a,0xbb430155}},	// [fdc0] _لصدا, ieux_, _שלפי_, шетк
  { {0x8c96042b,0xc8d60015,0x0c960033,0x63a46001}},	//   _армі, نزاع, _ашмя, čini
  { {0x6bd60029,0x7d7b000a,0x29036002,0xade8000b}},	//   _لتحر, _חריג, _deja_, _टंडन_
  { {0xf9890008,0xeb9a0036,0x8a066003,0x637c0003}},	//   חר_, _цим_, _изме, _réno
  { {0xc6f7042b,0x97130033,0x6443002a,0x333f0003}},	//   тніх_, рміц, ewni, deux_
  { {0x63750084,0x61e21f4c,0x2d9811c8,0x6f046004}},	//   _mánu, _ruol, nire_, _leic
  { {0x213e00da,0x2d98007c,0xf8c6000b,0x6d4e25c5}},	//   veth_, iire_, _वरिय, idba
  { {0x61e226f9,0x201e2e59,0xe3af00e6,0x988b000a}},	//   _puol, vuti_, يري_, _חָמֵ
  { {0x2fc90176,0x55e60036,0x69dc003f,0xc7d700f3}},	//   _rhag_, _розб, _kire, _יולי_
  { {0x61e204ed,0x45d30001,0xd13000e5,0xa5450115}},	//   _vuol, _вођс, حمد_, _مضمو
  { {0xf9930008,0x05770029,0x6f040313,0xd91b00a3}},	//   שרת_, _جملة_, _beic, וויל
  { {0x6d5e1893,0xf8b30008,0x3fc90086,0xd36f0029}},	//   _anpa, ישת_, عددی_, _وهل_
  { {0x213e0026,0x2c51005c,0x7d0703df,0x6f040a11}},	//   peth_, _sąd_, tajs, _deic
  { {0x69dc0035,0x11e90015,0x60860015,0x201e45ae}},	//   _nire, _أعني_, _لشبك, puti_
  { {0x6f0411d8,0xfbd30087,0x113b000a,0x7d1a001a}},	//   _feic, لتر_, _חתול, ótsa
  { {0x290303af,0x2d982fd8,0x5b1403fc,0x600b000a}},	//   _seja_, aire_, имст, _חִזְ
  { {0x69dc0064,0xee870033,0x1bd40a1f,0x2d986005}},	// [fdd0] _bire, _шыко, ротя, bire_
  { {0x6f04018b,0x6443005c,0x69dc6006,0x929d002a}},	//   _zeic, ywni, _cire, zało
  { {0x2903001c,0xe7190029,0x481500a4,0x4d740015}},	//   _veja_, فيات_, умес, _خطير
  { {0xf7700225,0xcc560008,0xe7050086,0x69dc01b3}},	//   يان_, _עברי_, اسای, _eire
  { {0x333f0152,0x7bdd19e7,0x48f0000b,0x29034fde}},	//   veux_, _iisu, इडशो_, _teja_
  { {0x69dc6007,0x64a50484,0xceb4039e,0x929d002a}},	//   _gire, лала, סיס_, wało
  { {0xd4350029,0x5435002b,0x333f0003,0x929d002a}},	//   اعتب, ارتر, teux_, tało
  { {0x2a6d005c,0xe4740010,0x8cdc000a,0xe6130015}},	//   _żeby_, рушэ, וחות, _نشط_
  { {0x333f038d,0x6f0404b0,0x9f5f00f2,0x7bdd08b4}},	//   reux_, _reic, istä_, _misu
  { {0xf1f6002b,0x6f046008,0x6fe80046,0x333f01f6}},	//   اکنش_, _seic, _věcn, seux_
  { {0xc9520008,0xc0580010,0x2d986009,0x6f040012}},	//   זמי_, віў_, vire_, _peic
  { {0x56b50053,0x63750077,0xd611005e,0x3245006e}},	//   ָפֿן_, _cánt, _вiдб, _منصف
  { {0xd2280029,0xd00e0086,0x2b400024,0x6f04600a}},	//   _لكنه_, يلی_, veic_, _veic
  { {0x9f5f00f2,0x6f0400b8,0x929a000a,0x7c2e600b}},	//   estä_, _weic, _אינת, ttbr
  { {0x6f0439c7,0x2d98600c,0x101554b1,0xddcd002a}},	//   _teic, rire_, _сьля, _brał
  { {0x2d98248e,0x0076000a,0x7c2e600d,0x69dc3f4b}},	//   sire_, _תתקי_, rtbr, _sire
  { {0x2b400026,0xed5a006b,0x2d9804a8,0x7bdd600e}},	// [fde0] reic_, _зоп_, pire_, _disu
  { {0x4a750033,0x6d5e58ec,0x3a2000aa,0x6abd4d5a}},	//   шыст, _unpa, ruip_, _dysf
  { {0xb17a00b2,0xe81f000b,0x19b9005e,0x69dc600f}},	//   עטער, मूला_, туть_, _vire
  { {0x7aed04ed,0xf0b60053,0xdc9b0135,0x8c1b000a}},	//   ccat, אלער_, _טייל, _אוטי
  { {0xd5ba01d9,0x69dc0493,0x8f9b000a,0xd765002b}},	//   нск_, _tire, עיני, شنوی
  { {0x75d30002,0xa5330033,0x69dc0125,0x75d4006e}},	//   مينا, йніч, _uire, جيتا
  { {0xf9830760,0x07a60608,0xa2d60065,0x0000006a}},	//   _угро, _бавн, मेन्,
  { {0x087700b2,0xd6260015,0x5214053b,0xad9b0052}},	//   _געלט_, _معطي, адит, lsút
  { {0xbb3b0053,0x7791002b,0x63750030,0xd6250058}},	//   געפי, _بینا, _ránt, _نعلي
  { {0xc33900dc,0xceeb002b,0x3f99002a,0x717801b7}},	//   áírá, کردن_, wisu_, тбор_
  { {0xb0ce005d,0x9f5f00f2,0x29370053,0xc057042b}},	//   हेंग, ystä_, נאטן_, гія_
  { {0xe81c000b,0x7dc00123,0xdfd10015,0x63750069}},	//   _पटना_, lösh, تيج_, _dáns
  { {0x7bdd02d7,0x957c0050,0x5f940063,0x69b9005d}},	//   _risu, _ciąg, сият, ्तमी
  { {0x7bdd0005,0x22590013,0x3f99007c,0x6606001a}},	//   _sisu, æske_, sisu_, _ækku
  { {0x41bb0008,0x7bdd2a15,0x9414000a,0x5577004c}},	//   _רצוע, _pisu, יַּד_, נעלן_
  { {0x9be40033,0x9aa50015,0x7aed6010,0xd497004f}},	//   сірк, لمزو, ucat, אכלת_
  { {0xbda703c4,0xdb04002e,0xd357000a,0x7bdd6011}},	// [fdf0] _محدو, rlið, נימי_, _visu
  { {0xf9930015,0x7bdd01d7,0x9980006f,0x18ab0054}},	//   حبر_, _wisu, ytiť_, нђео_
  { {0x7bdd016f,0x661c003d,0x38c70238,0x7e99002b}},	//   _tisu, _ārka, ущав, _سنگر_
  { {0x205700a3,0xb465002b,0x98a70091,0x7dc0008c}},	//   טיבל_, یگاه, žnį_, yösk
  { {0xd2460196,0xd138002a,0xf5052f47,0x79a7011e}},	//   _بن_, ciąg_, азло, _брве
  { {0x35f80074,0x5a9a05af,0x27150092,0xaa9a000a}},	//   ارند_, _ישרא, ền_, _יברכ
  { {0x2606000b,0x6498006b,0x2db8004c,0xdcfc0091}},	//   सीबी_, лтър_, אלגן_, airė
  { {0x63ad05e3,0x7dc0008c,0x3235006b,0x2d84003d}},	//   čano, tösk, ахос, īmei_
  { {0x9980002c,0xddcd002a,0xe2990054,0x63750077}},	//   stiť_, _krań, ђао_, _sáns
  { {0x320d1915,0x41b20015,0x06840015,0x63750069}},	//   rsey_, يمير, _الكُ, _páns
  { {0x64c40015,0x320d20d5,0x0000006a,0x0000006a}},	//   _هيكل, ssey_,   ,
  { {0x2018242e,0x6235034e,0x68b6000a,0x3f84006f}},	//   ária_, _веду, ילתא_, ómu_
  { {0xde360010,0x398400c0,0xa2940010,0x80c9000b}},	//   шэнь, _lösa_, _лаці, हेजे
  { {0xe2c80036,0x8cb1000b,0x621a000a,0x90450015}},	//   _слід_, _आँखो, _יונק, _ننته
  { {0x41260036,0x3b960001,0xe0d3002b,0xeb9a18e7}},	//   _тощо_, ајат, _ازش_, вив_
  { {0xdca30036,0x6fb30029,0x2bbf000b,0x2606000b}},	//   іати, _وموا, ्षगा, सीडी_
  { {0x6da60191,0x5f770015,0x1d1a004a,0xe8f60058}},	// [fe00] _випа, _خميس_, _июнь_, لساخ
  { {0xc963005e,0x9e7b000a,0xe8f71853,0x0d830033}},	//   овуй, _סניפ, илу_, _млын
  { {0xd1160008,0xad37000a,0xd70a004a,0x99390033}},	//   שקעה_, _דניס_, внее_, ыяту_
  { {0xc7af0015,0xfbdf0016,0xf1b9003d,0x9f5f00d6}},	//   وّل_, _giê_, kušo_, pstå_
  { {0xf1b9003d,0xad9b2ed5,0xbafb004f,0x237f0535}},	//   jušo_, csús, _בהכש, dkuj_
  { {0x5e570053,0x7b3e005c,0xdcfe0024,0x8e57000a}},	//   יינע_, _dłuż, _impē, יינג_
  { {0xe4b80010,0x04580029,0x25a9002d,0xd90d002b}},	//   ылкі_, البة_, éala_, _سین_
  { {0xea000023,0xfaff00dd,0xd378016f,0x9cd7000a}},	//   _luật_, _hoër_, _kući_, סוקה_
  { {0xe3af0086,0xf1b90024,0x68e90011,0x93930015}},	//   برو_, gušo_, _şedi, تجوا
  { {0x7c3e06f5,0xca370008,0x3a370008,0xaa3700a3}},	//   _oppr, סניה_, סרים_, סטיק_
  { {0x04960010,0xafd90080,0x3957000a,0xb366006b}},	//   _траў, лдоф_, בשים_, _вълк
  { {0x25fd014e,0x63a400bd,0xc3da0029,0xa2da005d}},	//   रीकी_, čins, _شباط_, _पृथ्
  { {0x6f160026,0x5db70029,0x21f40015,0x7c3e0738}},	//   _ddyc, لإسر, _اكتس, _appr
  { {0x6f16005c,0xc27b000a,0xd23b000a,0x127b004c}},	//   _edyc, _ברדי, _סגול, _באדע
  { {0xd0f70008,0x25b90125,0x3cec013f,0xf411004f}},	//   _דמות_, _ísle_, _živý_, ּ֤ל_
  { {0x60db000a,0x80db000a,0x3e890015,0xdb040003}},	//   _בקונ, _בחוז, _مَعَ_, nniè
  { {0x59c50015,0x443e247b,0x0000006a,0x0000006a}},	// [fe10] ميرك, _lpt_,   ,
  { {0xdebc0008,0xa3e6000b,0x9178000a,0x929d002a}},	//   _במחל, पदा_, נְּח, wałk
  { {0x6f160176,0x7b3e0050,0xa3c8005d,0x66160007}},	//   _ydyc, _służ, ोगा_, šykl
  { {0x60d900b2,0x30d90053,0xd8740015,0x57a40033}},	//   אַנג, אַנע, غالب, ошча
  { {0x98a701e2,0xf77004c9,0xbb3a0053,0x637c0152}},	//   ını_, بال_, _גערי, _géni
  { {0x9985003b,0xd90f0086,0xea76000a,0x7dc0008c}},	//   _السو, _آیا_, _הגשר_, tösi
  { {0xaadb000b,0x645a0085,0xad38000a,0x4518005e}},	//   _मृतक, _crti, ינגס_, рція_
  { {0xf3490080,0x13680001,0x645a0046,0x7d080030}},	//   упил_, ишњи_, _drti, ódsz
  { {0xd24e0029,0x2259001a,0x645c001a,0xe7eb000b}},	//   فني_, ísk_, _árin, _जूता_
  { {0x05740196,0xe1f90007,0x81a40015,0x7791002b}},	//   _والد, rpų_, ْحَل, _بیچا
  { {0xc3550063,0x3951003d,0x20110030,0xdee601b7}},	//   _гълъ, _mazs_, ézi_, йони
  { {0x083a0053,0x883a000a,0x6fe80046,0x64c40058}},	//   נערל, נתרו, _měch, _بيمل
  { {0xd7ba000a,0xbda600c3,0xddc40045,0x201e6012}},	//   רֶיך, محسو, _criş, arti_
  { {0x98a70089,0xd256000a,0xa3e6000b,0xa256000a}},	//   ýně_, _לשנה_, _यूँ_, _לבנק_
  { {0x7ff50074,0xddc401e2,0x6ff50029,0xceb8002a}},	//   _استا, _eriş, _استط, łę_
  { {0x637c0152,0x501a000a,0x3a320123,0xb47a004c}},	//   _péni, _עופו, ttyp_, אָמי
  { {0x5aca0174,0xe80a000b,0xc9aa0033,0x1a090015}},	// [fe20] улам_, हीना_, гвае_, لآلي_
  { {0x186a0124,0x8e570008,0xbd460087,0x3a320c77}},	//   лази_, _פייג_, _اندي, rtyp_
  { {0x63ad116e,0x3f820020,0x6ff30011,0x3a320c77}},	//   čanj, okku_, _făce, styp_
  { {0xdc3b00b2,0xcb6a243b,0xf7290036,0x27e000f2}},	//   _געטר, _саме_, ицій_, öin_
  { {0xd138002a,0x8bd7000a,0x443e01d7,0x765b6013}},	//   niąc_, _לוטו_, _spt_, _cruy
  { {0x86070029,0x38c8002b,0x7d0e0012,0x443e6014}},	//   حقوق_, _نازی_, nabs, _ppt_
  { {0x7e7d005c,0xc7f8000a,0x61fb37f0,0x3cfb004f}},	//   zysp, _כִּר, epul, אלצנ
  { {0xd6da002b,0xadfa000b,0x645a036d,0x201e6015}},	//   _موزش_, ्ठान_, _vrti, vrti_
  { {0xa686008f,0xdb04038d,0x7d0e0134,0x5b7b000a}},	//   _улад, rniè, kabs, טרקא
  { {0x201803af,0x6e2600dd,0xc01403ad,0x201e00bc}},	//   ário_, dukb, омощ, trti_
  { {0xdb0f0014,0xc32a0029,0x64c60086,0x7bc40007}},	//   ődés, _مكان_, _ايال, kliu
  { {0x7e7d00f2,0x870b000a,0x2918001a,0x3a2002f2}},	//   tysp, ְּכֶ, _ldra_, krip_
  { {0x6e260030,0xe80a000b,0x29186016,0x479b004f}},	//   gukb, _हौसा_, _odra_, ריכס
  { {0xc6930053,0x291c00dc,0x52d7000a,0x201e00bc}},	//   לאר_, óval_, _הודע_, prti_
  { {0xdd940010,0x319b000a,0xfc64006b,0x8f35006b}},	//   чары, _תבונ, пътн, _дейц
  { {0xec340036,0xab940036,0x7bc404ed,0x8fa4009c}},	//   янсь, писі, gliu, _наје
  { {0x3a20016b,0x2f98000a,0xf1bf006f,0x7ac70088}},	// [fe30] grip_, _לכהן_, ššej_, ссве
  { {0x7bc40007,0xe919005e,0xc27b004c,0x6fe80046}},	//   aliu, рожі_, ארמי, _pěch
  { {0x2606005d,0xf7f40015,0x290a0077,0x6ff30045}},	//   सीसी_, كسند, _deba_, _tăce
  { {0x5fc9005d,0xd378016f,0x6d476017,0x29180123}},	//   रतिल, _kuću_, leja, _edra_
  { {0xf770003b,0xf6250036,0x6d55002a,0xcf2c000a}},	//   عام_, ідко, odza, אֽוֹ
  { {0xce38013a,0x6fe80089,0xdb160152,0x2d836018}},	//   צאות_, _těch, voyé, nkje_
  { {0x3f890034,0x6d5558f5,0x7d7c004f,0x6d476019}},	//   _olau_, idza, רנוו, ieja
  { {0x765b0023,0x221516cf,0x7dc0601a,0x25790144}},	//   _truy, офор, löst, _pèls_
  { {0xe6670127,0x6d470375,0x7d1a00bf,0x6458601b}},	//   _утво, keja, ótsk, avvi
  { {0x7dc01b45,0xa1e80015,0x89ec000a,0x6d4701c2}},	//   nöst, حريك_, נַחֵ, jeja
  { {0xd138005c,0x94ab0033,0x3f89601c,0x6faa0054}},	//   wiąc_, _стаа_, _blau_, ивог_
  { {0x3f890b4c,0xa8560008,0x40940010,0x6d55173b}},	//   _clau_, קירה_, ярыт, edza
  { {0x92b70086,0xe8c6000b,0x63a9601d,0x6d550079}},	//   _احضا, _वर्च, mnen, fdza
  { {0x6d4722a4,0xc5f2000a,0x63a9183c,0x637c0003}},	//   geja, ודך_, lnen, _dénu
  { {0xd138005c,0x7188000a,0x4427601e,0x7d0e601f}},	//   siąc_, _לְקַ, nun_, rabs
  { {0x63bb003e,0x290a6020,0xbea602c8,0x5ea60015}},	//   noun, _seba_, _майк, _ومثل
  { {0x3fe30010,0x89160029,0x89da00e6,0x44275f22}},	// [fe40] _ўжыв, قبائ, لورر_, hun_
  { {0x2d840024,0x63a900b8,0xa85a0054,0x442711cd}},	//   īmes_, hnen, ијех_, kun_
  { {0xa81a0086,0x61eb04ed,0x63bb016f,0xb81a0015}},	//   شتار_, _lugl, koun, شتاء_
  { {0x6b8d6021,0xbd460086,0x30e30053,0xddc4002a}},	//   chag, _انگي, _גרופּ, _usił
  { {0x63bb02c1,0xceb3000a,0x7f3b000a,0x63a9006f}},	//   doun, ֽיו_, שענו, dnen
  { {0xa2da005d,0x8c430064,0x44273993,0x14180015}},	//   _पृष्, ışve, fun_, ميتة_
  { {0x61eb09f0,0x63bb003e,0x44276022,0x69b9000b}},	//   _augl, foun, gun_, ्तरी
  { {0x63a91475,0x9cd7000a,0x6d47002a,0x57fb000a}},	//   gnen, חוצה_, zeja, _כללו
  { {0xfbd3013a,0x05b9014e,0xb6a30036,0x61e30064}},	//   ותה_, ेतशब, _житл, _binl
  { {0xc05a0010,0x63a9003f,0xba9b01ac,0x599a000a}},	//   аім_, anen, יספי, ישִׁ
  { {0x3f8908e0,0x6f0f04ed,0x61e30064,0x6d4714e5}},	//   _plau_, tacc, _dinl, veja
  { {0x6d55005c,0x63a9002c,0x61e31a15,0x91e6381e}},	//   wdza, cnen, _einl, _доде
  { {0x7dc000f2,0xb7db0008,0xa3b7000b,0xa2d6000b}},	//   yöst, יקטי, चकर_, मेश्
  { {0x0cab006b,0x7dc00030,0x6b840079,0x637c6023}},	//   атби_, döss, ekig, _vénu
  { {0x672b0084,0xfe6e0086,0x61eb00b8,0xf3f8000a}},	//   yggj, نگی_, _zugl, מִּל
  { {0x799c0034,0x6d476024,0x8e1502d9,0x63a06025}},	//   _amrw, seja, _едиц, nimn
  { {0x05ca014e,0x44270064,0x7dc000f2,0x6ce7017f}},	// [fe50] िताब, zun_, töst, _міне
  { {0x63bb003f,0x79d40036,0x27e4002d,0x44270943}},	//   zoun, джує, _aimn_, yun_
  { {0x4c830086,0x63bb0b63,0x29010c0b,0x7dc00c77}},	//   _غیرق, youn, rbha_, röst
  { {0x4427022d,0x6b840b0f,0x9cd6000a,0x7dc0008c}},	//   vun_, ckig, _מותה_, söst
  { {0xb4f8005d,0x44270026,0xa6470086,0x637c002e}},	//   ुरूप_, wun_, تخان, _léns
  { {0x5dfc0135,0x44276026,0x6ff30045,0xf1c60046}},	//   ספונ, tun_, _lăca, _žánr_
  { {0x63a9032c,0x61eb4932,0x63bb6027,0xd538002b}},	//   tnen, _sugl, toun, تثنا_
  { {0x05950074,0x6441018c,0x16350010,0xf1b90024}},	//   _کارگ, _vpli, _небя, muši_
  { {0x13060080,0x799c0026,0x63a96028,0x63bb4a2d}},	//   чный_, _ymrw, rnen, roun
  { {0x44270d25,0xf5950021,0x63a96029,0x63bb08d2}},	//   pun_, _علاج, snen, soun
  { {0x7dc00014,0xf9920008,0x63bb00da,0x6f0d602a}},	//   zöss, גרי_, poun, _beac
  { {0x6f0d002d,0xb4c9000b,0x7dc0008c,0xe456015b}},	//   _ceac, ोधी_, yöss, _מיעט_
  { {0xee370036,0x82640015,0x6f0d602b,0x1e830da4}},	//   пня_, _يهمن, _deac, елям
  { {0xf1b90024,0xb6ba000a,0x98b30046,0x20110030}},	//   kuši_, מצרי, ádět_, ázis_
  { {0xaffe0023,0xf1b90048,0x6f0d002d,0xfb84002b}},	//   _trướ, juši_, _feac, ودری
  { {0x661600df,0x6f0d0298,0x7dc000f2,0x33f10a40}},	//   šyki, _geac, töss, _máx_
  { {0x01f90053,0x5eeb000a,0xada61f5c,0xee3a027a}},	// [fe60] מפּל, _לַיְ, _наил, _унп_
  { {0x7e9b000a,0x6b84007c,0x63a001c2,0x7dc0166c}},	//   _לספו, skig, zimn, röss
  { {0x7d7b009d,0xc18c0053,0x6d7b0008,0xf1b90024}},	//   _הניו, ױטאָ, _האיח, guši_
  { {0xdb24002b,0xcf57000a,0x501a000a,0x0bf7000a}},	//   _توحی, ּ֑את_, מועו, _מצטט_
  { {0x9666005e,0x6603602c,0xd6220033,0x7bdb000a}},	//   якде, епча, _вiна, _לקטו
  { {0xdb0d002e,0xf5780029,0x05780015,0x186a0004}},	//   llað, تمتع_, تمتة_, _лаги_
  { {0xc448002b,0x7467004a,0x34370015,0x63a0602d}},	//   تیان_, зрыв_, كسيد_, timn
  { {0xeb92000a,0x51f8004a,0x63a00125,0x722a030c}},	//   ךָ֖_, онию_, uimn, бцов_
  { {0x63a0002c,0x2258004a,0x6f0d03fe,0xdcfc003d}},	//   rimn, ципы_, _reac, zkrā
  { {0xb60302d5,0x6f0d002f,0xdb0d001a,0xdb230030}},	//   ášen, _seac, hlað, _öröl
  { {0x656800fb,0xf200005d,0x6ff30011,0x6f0d08b8}},	//   _indh, लीज़_, _păca, _peac
  { {0xd4690015,0x929d002a,0x657a01b3,0xdef80033}},	//   _بحكم_, tałt, _hoth, зыр_
  { {0x59be005d,0x54f0000b,0x6f0d0045,0x511803a7}},	//   ्तार, _चलाए_, _veac, _долю_
  { {0x6e200030,0x61430054,0x2fd9602e,0xdcfc01ec}},	//   ámba, _зеља, smsg_, tkrā
  { {0x657a17ce,0x6f0d0541,0x913b000a,0xddd6002a}},	//   _moth, _teac, _העוק, _brył
  { {0x8bc400d7,0xe0850002,0xf1b9003d,0x7dd202de}},	//   есуд, _تجهي, vuši_, væse
  { {0xb5fd0263,0xf979012e,0xadb50054,0xe979012e}},	// [fe70] _krše, обај_, _обиш, обаш_
  { {0x657a602f,0xddc4003d,0x0000006a,0x0000006a}},	//   _noth, _asiņ,   ,
  { {0xdb0d002e,0x4735201e,0xe7190021,0x3a2901c2}},	//   blað, днес, قيات_, suap_
  { {0x7dd202de,0xe796002b,0x7dc0008c,0x65686030}},	//   ræse, وانک, lösp, _andh
  { {0xa3c0005d,0xf1b9003d,0xe73000c3,0xcd34002b}},	//   ंकन_, suši_, اصم_, _غریب
  { {0x09e40010,0x657a002d,0xceb40053,0xbe3c000a}},	//   _поўн, _coth, עיס_, צעות
  { {0xad1c0447,0x6d5710ad,0x0000006a,0x0000006a}},	//   מוגר, _maxa,   ,
  { {0x27fc002c,0x9f5f0077,0xe1f91ce8,0xe4e4008b}},	//   ívne_, istó_, оги_, хічн
  { {0x657a002f,0x6609003f,0x5b58000a,0x6d576031}},	//   _foth, _uwek, לשהן_, _oaxa
  { {0x11d60015,0x657a405c,0xc6d40058,0x82840058}},	//   ووية_, _goth, _ستقت, عجيل
  { {0xff260080,0x29380053,0xd928000a,0xb80b0033}},	//   ммно, לאזן_, הֵרָ, алiн
  { {0x6b830011,0x3f6a0054,0x777b01f6,0x0ef90138}},	//   _îngh, цимо_, _joux, зэры_
  { {0xa3b800e6,0xe716000a,0x63bc0030,0x0000006a}},	//   _عامر_, וחרר_, _írna,
  { {0xf0b80074,0x2d8c006f,0x6fce000b,0x2e360052}},	//   _کاهش_, óde_, _धीरू, ræf_
  { {0xef1f0064,0xdb0d002e,0xc172000a,0xdca6004a}},	//   mkün_, tlað, _בחג_, фави
  { {0x77690003,0x7c210125,0x0000006a,0x0000006a}},	//   _nnex, álra,   ,
  { {0xc3320008,0xed5a3658,0x550d000b,0xadfa00c3}},	// [fe80] כון_, _доп_, हराए_, _بربط_
  { {0x2617005d,0xe9d732cd,0x7af6002a,0x776910e3}},	//   _निजी_, дку_, scyt, _anex
  { {0xa84a0015,0x657a6032,0x6bd60058,0xb46b0138}},	//   تلام_, _roth, _يتجر, _воiн
  { {0x6ac60015,0xd6d20015,0x657a6033,0xc7b20058}},	//   _يقدم, نقض_, _soth, خّص_
  { {0xcb13000a,0xc7a303ae,0x35f700c3,0x3ea9000a}},	//   _שלש_, њичк, ورود_, ּכוּ_
  { {0xa4d4005e,0x8e97000a,0xc56a0015,0x2916009a}},	//   нолі, ודנו_, تحصل_, _زورآ
  { {0xd4670124,0xa8060010,0xb1760092,0xd6d9005c}},	//   дије_, _ізал, _nhượ, _mały_
  { {0x389b000a,0xd3700015,0xd3d70015,0x8c1b000a}},	//   _וילנ, اهة_, وبيا_, קופי
  { {0x07a30001,0xd1300029,0x9989002c,0x657a0251}},	//   _ратн, همة_, stať_, _toth
  { {0xa69700a3,0x867b000a,0x9f5f0003,0x66021839}},	//   _חכמה_, _ורמו, mpté_, mpok
  { {0xc9530008,0x9f35005e,0x395806a5,0xb5fd0085}},	//   דמת_, нені, _mars_, _vrše
  { {0x83540074,0x59d0005d,0x6e9505c4,0xd3f40033}},	//   _سپتا, _तीसर, еиму, _сiст
  { {0x5f940063,0x98b80007,0xdb06008c,0x93250015}},	//   тият, _tarė_, _ykkö, _أرمن
  { {0xea000023,0xd6d9005c,0x61fd0046,0x2cfb0065}},	//   _xuất_, _cały_, ísle, ्रेल_
  { {0x70540029,0x91bb000a,0xd6d9002a,0x4c95012e}},	//   _أنبا, _ומגי, _dały_, хивс
  { {0x69d4014e,0x798e0176,0x213e00da,0xeb4800e2}},	//   _बीबी, _albw, lfth_, мчук_
  { {0xde190015,0x39580287,0x6d576034,0x29136035}},	// [fe90] _عقدت_, _bars_, _taxa, taxa_
  { {0x39586036,0x66020057,0xe29f001a,0x7d1a001a}},	//   _cars_, dpok, úði_, ótst
  { {0x7d150064,0x213e00da,0x0000006a,0x0000006a}},	//   mazs, ifth_,   ,
  { {0xea000092,0x3958003e,0xef12000a,0xcd2b002b}},	//   _suất_, _ears_, ָּא_, _اسکن_
  { {0xbafa0008,0x05ca005d,0x06080010,0x8afa000a}},	//   _מהרש, ितंब, днік_, _מפרק
  { {0xdd020085,0x6fd6006f,0xea000016,0x39580618}},	//   čući, máce, _quất_, _gars_
  { {0xf9920008,0x6ff30045,0x66021945,0x57f402d9}},	//   _גרם_, _răco, apok, _апст
  { {0xd6db0010,0x7769003e,0xdb1d001a,0xe66701b7}},	//   _дтз_, _unex, _oksí, _отзо
  { {0xd2a9004a,0x95cb1368,0xea000016,0x02450058}},	//   якие_, _дужа_, _tuất_, رَدَ
  { {0xf99200b2,0x3cfb005d,0xe0010010,0x84470029}},	//   ָרט_, ्रों_, льмi_, _يخال
  { {0x2cfb014e,0xcea904dc,0xa0691c55,0x22465e0a}},	//   ्रैल_, _פי_, чана_, _epok_
  { {0x2b59002f,0xdef90010,0xf8b20053,0x63ad0ea1}},	//   _nasc_, дыё_, רשט_, čans
  { {0x8db60036,0xe28e6037,0xf2c70033,0xf26902ed}},	//   есві, _са_, _ўсен, _хилл_
  { {0xc69200f3,0xef1f0014,0xb1760092,0x11440015}},	//   ראך_, lkül_, _thượ, _لَهُ
  { {0x1c390080,0x8c4303e7,0x6142006b,0x2b590144}},	//   мять_, лере, _сеща, _basc_
  { {0xffd6008f,0xf412000a,0x2b590144,0xf092000a}},	//   _яўля, טפל_, _casc_, _תנה_
  { {0x44270107,0x291101c2,0xb40b002a,0x2cbf0061}},	// [fea0] hrn_, _beza_, ężył, ğuda_
  { {0x29110064,0x5e57004c,0xf1b9003d,0x2b590125}},	//   _ceza_, _טיפע_, pušu_, _easc_
  { {0x39585452,0x661b1695,0xc8ca0015,0xc726033d}},	//   _vars_, _avuk, أوان_, едей
  { {0x2907002e,0x39581d40,0x6d5c446f,0x6d4e6038}},	//   ðnar_, _wars_, ldra, leba
  { {0x7bc600f2,0x442700b8,0xe5340142,0xff17000a}},	//   _ikku, ern_, вель, תקנת_
  { {0x6d4e6039,0xab5b0030,0x2d8a0030,0xb603006f}},	//   neba, _lkül, nkbe_, ášan
  { {0xf3f10023,0x68460080,0x53e609ef,0x5d3b000a}},	//   _cụ_, _янва, нциа, פתקא
  { {0xf3f10023,0xddcd0011,0x6d4e0213,0x6d5c0710}},	//   _dụ_, _oraş, heba, hdra
  { {0xa29401f3,0x6d4e603a,0x12d4006b,0xd62a012e}},	//   тапі, keba, ъжия, _хозе_
  { {0x3a370008,0xaa370053,0x1a9b0053,0x3d0a005d}},	//   ערים_, עטיק_, פייע, वरों_
  { {0x7bc60084,0xddcd0064,0x69de002d,0xf993000a}},	//   _okku, _araş, impe, ררת_
  { {0x6710005d,0xa9be000b,0xddcd0045,0x6d5c603b}},	//   ारिक_, ्तुए, _braş, edra
  { {0x262a000a,0x539b000a,0xc7b3000a,0x442e016e}},	//   הוָ֣, _צידו, רבר_, luf_
  { {0x7e640495,0x6d5c603c,0x6d4e603d,0x7bc6603e}},	//   _drip, gdra, geba, _akku
  { {0x3ce500c0,0x7e640fb2,0x2b400f0c,0xd0f7000a}},	//   älv_, _erip, ffic_, _אמות_
  { {0xa3c0014e,0xa3c2005d,0xf215005d,0x5ba4091c}},	//   ंकि_, ृति_, _दौड़_, груз
  { {0x6d4e064e,0x442e0012,0x61ea0030,0x7e64603f}},	// [feb0] beba, huf_, _kifl, _grip
  { {0x6fd60089,0xdd040011,0x7dd202de,0x44276040}},	//   ráce, ărăr, læsn, yrn_
  { {0xa3c0005d,0xe9440010,0x2911016f,0xaffb000a}},	//   ंका_, ыхто, _veza_, ִּׁי
  { {0x8c1a0008,0x27fc002c,0x2911003f,0x6a15004a}},	//   _קורי, ívna_, _weza_, _имму
  { {0x44270026,0x9b16000a,0x7bcd0012,0xa5d90015}},	//   wrn_, _בחרה_, mlau, وبتر_
  { {0x63a2003e,0x06840010,0x6e3d00b8,0x64a56041}},	//   _amon, ыгін, itsb, кала
  { {0x7bc6001a,0x44272529,0x58d430db,0x84360015}},	//   _ykku, urn_, _борт, نكور_
  { {0xf3f10023,0x44270b0f,0x6d4e005c,0xc2452978}},	//   _vụ_, rrn_, zeba, вник
  { {0x24890024,0xd24e0015,0x7bcd0a64,0x7c2e0012}},	//   ņam_, قني_, ilau, zubr
  { {0xd1b90029,0x3f4c0092,0xe6040015,0x7bcd6042}},	//   بابا_, _ếu_, _إِلَ, hlau
  { {0x7bcd00df,0x61ea0026,0x6025006b,0x4427002b}},	//   klau, _difl, ъдна, _سراف
  { {0x6d450a11,0x6d4e079b,0x7e646043,0x8fa617bd}},	//   _abha, weba, _prip, таме
  { {0x27760053,0x8237002b,0x539a000a,0x6d5c6044}},	//   דערש_, _سرشا, _קינו, tdra
  { {0xe29f001a,0x7afd6045,0x3a296046,0x7c2e0a35}},	//   úðu_, _afst, drap_, tubr
  { {0x5bc6002b,0x6e3d1568,0x6d4e6047,0x3a2907c8}},	//   نترف, atsb, reba, erap_
  { {0x7c2e012d,0x6d4e26c9,0x69de0034,0x7e6406d7}},	//   rubr, seba, wmpe, _trip
  { {0x6d5c0298,0x6a832c2a,0x8a460015,0x7c2e01e0}},	// [fec0] pdra, алта, ضَان, subr
  { {0x7afd002e,0x3f80007c,0x7bcd2357,0xac861ff7}},	//   _efst, _hoiu_, alau, _агол
  { {0x38c80086,0x7bcd02f7,0xad1b000a,0xe73a0891}},	//   راطی_, blau, _קוטר, дее_
  { {0x7bcd6048,0xb765005e,0xef13004f,0x478900ce}},	//   clau, лтій, ֹּף_, нсім_
  { {0x6934002b,0x16370015,0x442e088a,0xd6a8009a}},	//   _مکار, نسوة_, wuf_, رگرم_
  { {0xdb0d0152,0x95c7006b,0xbddb0003,0x63a202b9}},	//   nnaî, куща_, rtèg, _smon
  { {0x61ea052a,0xe44f0021,0xccf3000a,0xb5fd0085}},	//   _rifl, قضي_, סכה_, _vrša
  { {0x442e2219,0xa857000a,0xe2340004,0xf483008b}},	//   ruf_, _בילה_, гнињ, рушн
  { {0x442e0a3d,0x6ece0065,0x98af0535,0xb5fd013b}},	//   suf_, _सरगु, ęgą_, _trša
  { {0x11d80029,0x69c300bd,0x7bc40020,0x91cf000b}},	//   عودة_, čneg, hoiu, _सीआई
  { {0xc9170008,0xb4250087,0xb7fe00ce,0x9f5f005b}},	//   כחית_, _معنو, блiо, istö_
  { {0x331a0074,0x83830080,0x69d4000b,0x6e3d0fd4}},	//   _آزاد_, _выше, _बीसी, ttsb
  { {0xdd910029,0x6e3d00dd,0x61ea6049,0xa2da0065}},	//   موح_, utsb, _tifl, _पृच्
  { {0x20180030,0x403407f7,0x21a303ae,0x6e3d604a}},	//   áris_, _бекс, _кичм, rtsb
  { {0xebc70001,0x7bcd2061,0x0c24004a,0x6e3d604b}},	//   вљан, tlau, имён, stsb
  { {0x69c7003c,0xf1b9044c,0xe502000b,0x3a29039d}},	//   _skje, vrši_, रुति_, trap_
  { {0x6d410020,0x59d90033,0x9ad50033,0x7d020045}},	// [fed0] õlas, едаў_, ужач, _şose
  { {0x7bcd2ea7,0x0a68006b,0xf99300c3,0x5d550974}},	//   slau, ърси_, جبر_, _скот
  { {0x398400c0,0x30d8000a,0xb9e4005e,0x7bcd2ebb}},	//   _röst_, תַּע, ріти, plau
  { {0x2d8100b8,0x569503ad,0xd639005e,0x4b040033}},	//   _hohe_, лает, еякі_, _вярб
  { {0x2d810020,0xa634005e,0x0596002b,0x2c78002a}},	//   _kohe_, инці, گانگ, ażdą_
  { {0x69c713e1,0x6a9a000a,0x4a9a004f,0xc984011e}},	//   _ukje, _טשרנ, _טירג, _куси
  { {0x7d7c000a,0x0596002b,0xf992000a,0x9783002b}},	//   ונגו, دانگ, _פרל_, _پیشه
  { {0xd2510029,0xdb04016e,0x6b8d0b09,0xa7d40058}},	//   منع_, rniç, nkag, _نتقص
  { {0x51f50015,0x7bdc000a,0x01150128,0x0000006a}},	//   دسبر, וקהו, льню,
  { {0x60090080,0xdd3c0091,0x7dd2001a,0x95d80b1e}},	//   нном_, _sąži, gæsl, _адут_
  { {0x80a5003b,0xf3350029,0xa439005e,0x7a47003d}},	//   امجن, _مفاج, _їзду_, lītā
  { {0x69c502ad,0x0000006a,0x0000006a,0x0000006a}},	//   hohe,   ,   ,
  { {0x61450558,0xe2f80036,0x7a470024,0x63a9604c}},	//   _бела, _речі_, nītā, mien
  { {0x27ed038d,0x621a0053,0x63a9604d,0x0000006a}},	//   _lien_, _טונק, lien,
  { {0x6b960176,0xa0660063,0x113a0008,0x41cf000b}},	//   thyg, _баща_, _נתקל, _सीएस
  { {0x6b8d02f2,0x63a9604e,0x8b9502bb,0x0000006a}},	//   gkag, nien, аруч,
  { {0x39960134,0xeb750010,0xe9da604f,0xaac50015}},	// [fee0] _læse_, шырэ, ека_, لتكن
  { {0x7a470048,0x7e9b0008,0x63a96050,0xed5a00d7}},	//   dītā, _נסיו, hien, _џон_
  { {0x27ed2c45,0x63a96051,0x6bd60040,0x7dc00030}},	//   _bien_, kien, _متحر, kösz
  { {0x4b56010f,0x6d5e003f,0x27ed2512,0xeb9a0185}},	//   _съот, _hapa, _cien_, _чим_
  { {0x6d5e1640,0x41cf000b,0x9cb3002b,0x80ca000b}},	//   _kapa, _सीऍस, _نمیت, _सुने
  { {0x6b830011,0x8e570135,0x9f990003,0x6f1606a8}},	//   _îngr, טינג_, réé_, _leyc
  { {0x69dc018b,0xd7f80011,0x6d5e1640,0x84460015}},	//   _ihre, _îă_, _mapa, اختل
  { {0x6d5e6052,0xef1f0061,0xe7090015,0x291a0f69}},	//   _lapa, rkük_, _لتكن_, lapa_
  { {0xf1aa0086,0x171b0053,0xe3af0015,0x20d30016}},	//   فاده_, _רומע, ثرو_, _ại_
  { {0x27ed0298,0x291a0049,0x9a3b000a,0xcf27002b}},	//   _zien_, napa_, עתיק, گردي
  { {0x7051002b,0x1f75006b,0xe04a002b,0x69dc0034}},	//   قچيا, алня, رشده_, _mhre
  { {0xe1fa0001,0x63a90c5c,0xf457000a,0x42560067}},	//   _згд_, cien, _תיאר_, _منصر
  { {0x291a29c6,0x6d5e0049,0x69dc0012,0x9df801b7}},	//   kapa_, _bapa, _ohre, лнят_
  { {0xf2370008,0x69dc0026,0x98b80091,0x6fd6006f}},	//   _ערוץ_, _nhre, _narį_, ráca
  { {0xfbd30031,0xee3f0107,0x5f95005e,0xac940033}},	//   متر_, stý_, _вийт, барш
  { {0xcf270029,0xaab50036,0x2d9800b8,0x3b550b1e}},	//   _صربي, айбі, ahre_, јкар
  { {0x27ed038d,0x201e0024,0x69dc002d,0x3915023e}},	// [fef0] _rien_, lsti_, _bhre, имар
  { {0x27ed020a,0x201e6053,0x69dc3744,0x291a088a}},	//   _sien_, osti_, _chre, gapa_
  { {0x98170015,0x6ff30045,0x201e4f10,0x69dc0125}},	//   ابطا, _păci, nsti_, _dhre
  { {0x7a470024,0x69dc0435,0x201e0f68,0x6d5e26e5}},	//   tītā, _ehre, isti_, _zapa
  { {0x69dc002f,0x6d5e3464,0xdb0d002d,0x27ed1d7f}},	//   _fhre, _yapa, nnaí, _vien_
  { {0x63a90050,0x69dc002d,0x201e6054,0x27ed6055}},	//   wien, _ghre, ksti_, _wien_
  { {0x7a470024,0xad38000a,0x63a916c8,0x27ed3e0f}},	//   sītā, אנוס_, tien, _tien_
  { {0x360500e6,0x63a916ee,0x93a90015,0x61fd0069}},	//   _نورف, uien, ضاعف_, íslo
  { {0xe2990561,0xf7840015,0x201e246e,0x76610061}},	//   тап_, _القَ, esti_, üzyı
  { {0xd49b0124,0x21270086,0xf1cf000b,0x6f166056}},	//   _пре_, ديدی_, _सीखन, _seyc
  { {0xc952000a,0x1ee7002b,0xf994000a,0x6d5e6057}},	//   חמי_, یوپی_, מרץ_, _rapa
  { {0x6fb30029,0xe47a0053,0x6d5e6058,0x547a000a}},	//   ْمَا, _ברעכ, _sapa, _בטעו
  { {0x28ac005d,0xdc3c00bd,0x2d98002d,0x97560008}},	//   _टेनि, ršče, thre_, בירו_
  { {0xf2d20008,0x929a009d,0xc0e50403,0x91a90015}},	//   _ועד_, _בינת, _колк, _جهتك_
  { {0x6d5e022d,0x998904af,0x403200d7,0x39530144}},	//   _vapa, mpaň_, _дејс, dexs_
  { {0x291a003f,0x8024002b,0x69dc6059,0x6fd6016d}},	//   wapa_, _اروم, _shre, máco
  { {0x637c0014,0x29070064,0x6d5e605a,0x69dc0710}},	// [ff00] _pénz, ınan_, _tapa, _phre
  { {0xa2dd000b,0x44d50016,0xdb040125,0x9d461191}},	//   _परन्, _ó_, nniú, _теод
  { {0x291a0849,0x98360010,0x7d1c605b,0x7d7b000a}},	//   rapa_, рэзі, mars, _סנטו
  { {0xf62a0036,0xdb04002d,0x8c1b000a,0xabfb000a}},	//   віки_, hniú, _בוטי, _שהכר
  { {0x69dc488f,0x96330033,0x291a605c,0x63bc0030}},	//   _thre, жніц, papa_, _írni
  { {0xceb30008,0x23ba0024,0x7d1c605d,0x8806002b}},	//   חיד_, dīja_, nars, _نظرم
  { {0x34370015,0x9553002b,0x0000006a,0x0000006a}},	//   لسيد_, زخوا,   ,
  { {0x3a203c56,0x929d002a,0x7d1c3637,0xe3af0058}},	//   osip_, lały, hars, ِرٌ_
  { {0x1dc6005d,0xbb3b0053,0x179b0135,0x3a200049}},	//   लकात, דעפי, _סימב, nsip_
  { {0x3a204af1,0xa63b000a,0x71980015,0xf518000a}},	//   isip_, _בגמר, اندز_, _תֵּל
  { {0x201e00df,0x3fa70015,0x29183697,0x659b000a}},	//   usti_, لصحف, _mera_, _שיבק
  { {0x7d0e00c0,0x7d1c0c0b,0x201e605e,0x291802dc}},	//   ebbs, ears, rsti_, _lera_
  { {0x539b013a,0x0e340142,0x7c2e605f,0x22930015}},	//   _ביאו, оняю, erbr, _ولمس
  { {0x44d50023,0x229b0008,0x29180ba1,0x80c1000b}},	//   _ý_, _שֹׁמ, _nera_, _रुके
  { {0x5f770086,0x2ba700d0,0x317b0643,0x11db000a}},	//   _ناظر, ајав, _ברגמ, _שחוב
  { {0x5bb80080,0x2bb80015,0x853c0091,0xd1381ed6}},	//   ался_, لاقة_, _smėl, lgą_
  { {0x2b8e0089,0xd138005c,0xdad90001,0x291805d8}},	// [ff10] _mých_, ogą_, умац_, _bera_
  { {0xd13800df,0x27f86060,0x6f1d6061,0x7d1c6062}},	//   ngą_, _burn_, lasc, cars
  { {0x6ff304f9,0x57e70010,0x29186063,0x79c80058}},	//   _făcu, аўдз, _dera_, جولف_
  { {0x637c0030,0x6f1d6064,0x6d556065,0x0000006a}},	//   _tény, nasc, leza,
  { {0xf7700115,0x29180d92,0xcdd5000a,0x442e0161}},	//   ظام_, _fera_, ֖ךְ_, erf_
  { {0x6d55003f,0x29186066,0x5e58000a,0x0000006a}},	//   neza, _gera_, יידע_,
  { {0xe8df0023,0xb895003b,0xcd98000a,0xd49b006b}},	//   _trực_, _الأع, שדות_, ърд_
  { {0x61b1014e,0x7d1c02c1,0x23ba0024,0x8cdc000a}},	//   ीक्ष, zars, tīja_, כחות
  { {0x957c005c,0x6f1d6067,0x6d55003f,0xe6100015}},	//   _piąt, dasc, keza, _يشك_
  { {0x917b0092,0xdd00003d,0x29016068,0x11450015}},	//   _kể_, ātīg, ncha_, حَدُ
  { {0x93150074,0x2901000c,0xf9920008,0x23ba0024}},	//   _هواش, icha_, פרט_, sīja_
  { {0x644300c0,0xd1380091,0x65610030,0xd4980dfd}},	//   mtni, agą_, _halh, _тру_
  { {0x6e290089,0x7d1c6069,0x9756000a,0xdcec006f}},	//   šebn, tars, זירו_, áhľa
  { {0x237f00bd,0xdb16008c,0x64432495,0x6d550c0d}},	//   ljuj_, nlyö, otni, geza
  { {0x7d1c5208,0x65610d92,0xd116000a,0x8b960aa1}},	//   rars, _malh, _הקצה_, брач
  { {0x2918606a,0xfbdf0016,0x929d002a,0xfaa60033}},	//   _sera_, _chê_, wały, бабо
  { {0x24410092,0x2918606b,0xcb67006b,0x2d840003}},	// [ff20] hóm_, _pera_, щате_, êmes_
  { {0xf2d200b2,0x6443606c,0xa13c003d,0xac17002a}},	//   לען_, ktni, tiķi, _żółc
  { {0xa3c9005d,0x291805d8,0x3a2004a9,0x6ff30045}},	//   ोता_, _vera_, ssip_, _tăcu
  { {0x29013ed5,0xb5fd00bd,0x97a5005e,0x9aa6002b}},	//   acha_, _gršk, оріл, _همجو
  { {0xd1380007,0xceb3000a,0x6443606d,0x7f3b015b}},	//   ygą_, ּיו_, etni, רענו
  { {0xb996003b,0x27f8606e,0x99860015,0x644328e4}},	//   _السب, _turn_, _الآو, ftni
  { {0x78780008,0x764200f2,0x64430134,0x6fe9002a}},	//   _דָּו, stoy, gtni, _wści
  { {0xf7430860,0x8c1b000a,0xd4670054,0x6d550e8c}},	//   _несо, אוקי, сиће_, zeza
  { {0x27e6003e,0x6561001c,0xf777000a,0x6d47001a}},	//   mmon_, _falh, _פעמי_, yfja
  { {0xd1380007,0x27e60c0a,0x75d60015,0x6561606f}},	//   ugą_, lmon_, _ايطا, _galh
  { {0x6d556070,0xe97b0053,0x2b8e002c,0xb97b0643}},	//   veza, אניש, _tých_, אניי
  { {0x6d55003f,0x27e600e7,0x7413009a,0x237f0535}},	//   weza, nmon_, _روها, cjuj_
  { {0x41e605d1,0x3ebf0999,0x8295002b,0x6f1d6071}},	//   _ліка, çut_, _وهمچ, rasc
  { {0xd0100029,0xd257000a,0x27e6008c,0x1013002b}},	//   _قلت_, _לשדה_, hmon_, _کبود
  { {0xfbdf0092,0x6f040003,0xb4fb004c,0x2bbb0015}},	//   _phê_, _ffic, רפלי, هارة_
  { {0x6ab4000b,0x3996001a,0xb037000a,0x6d550085}},	//   ंपूर, _ræsa_, _הנהג_, seza
  { {0x6d5502c1,0x7528005c,0x29016072,0x27e66073}},	// [ff30] peza, _oddz, tcha_, dmon_
  { {0x42db0053,0x661d002e,0x64434ade,0x58d90033}},	//   רקמע, _æski, ytni, адзя_
  { {0xe8550021,0x290138ec,0xfbdf0016,0xe8596074}},	//   تناد, rcha_, _thê_, раеш_
  { {0xae440086,0x9be40484,0xe69500c3,0x7bc10003}},	//   _بپیو, _ніяк, يلاد, élud
  { {0xbb3a0053,0xeb3a0053,0xb5fd0844,0xef19005c}},	//   _דערי, _דערש, _krši, óży_
  { {0x644301d1,0xdcfe0024,0x9980006f,0x2e30001a}},	//   ttni, _kopā, triť_, _höfð_
  { {0xc4280015,0x2a69007c,0xe3c50015,0x65616075}},	//   مثيل_, lvab_, يْتَ, _valh
  { {0xbb3c0053,0xfdf9000b,0x7d1a002a,0x64436076}},	//   ָעזי, ंदास_, ótsz, rtni
  { {0xd1790036,0x0cd6005d,0x4255005e,0x67296077}},	//   асні_, _धर्म, ітит, _idej
  { {0x05950074,0x41750015,0x54450015,0x6443013b}},	//   _بارگ, زاخس, _ونذك, ptni
  { {0x6e24016f,0x7e6d552e,0xadf3000b,0xa2c9000b}},	//   _svib, _arap, _इंजन_, _हुर्
  { {0xe7c9014e,0x27fc00dc,0x35af000b,0x883a0447}},	//   िकिप, ívni_, _झगड़, סגרת
  { {0xa2d0000b,0xbddb0144,0xcdf601b0,0xee372797}},	//   _डुप्, rtèn, ючны, оня_
  { {0xbddb0251,0xa069000d,0xc5fa004c,0x320d4b1f}},	//   stèn, _вака_, יפשט, mpey_
  { {0xab1a0080,0x7e6d0020,0x6729037f,0xbb560015}},	//   ицах_, _erap, _odej, ينسب
  { {0x7e6d0152,0x0b460010,0xeb9707f7,0x0000006a}},	//   _frap, ўнан, оис_,
  { {0x69c3002c,0xc9aa0033,0x5cf60033,0x7e6d5441}},	// [ff40] čnen, авае_, _мяну, _grap
  { {0x3f820085,0x1d0a0054,0x672931ab,0xba170015}},	//   ljku_, _њени_, _adej, تيكا_
  { {0xfce61560,0x0000006a,0x0000006a,0x0000006a}},	//   _фоно,   ,   ,
  { {0x2cb50030,0xe7375a1b,0xcb6a0597,0x0000006a}},	//   őadó_, жец_, _таме_,
  { {0xa613005e,0x16a7080e,0xa4f8002b,0x27e66078}},	//   дміч, овци_, مکار_, rmon_
  { {0x27e600e7,0x85040015,0x18a60033,0x98a607bd}},	//   smon_, أوغن, _дагм, _диге
  { {0x7d7b000a,0x66090d40,0x7d1a001a,0x5fca0065}},	//   ינסו, _etek, ótsy, रवाल
  { {0x2480010b,0xccf30008,0xe7370d7f,0x136a37c6}},	//   ćim_, וכו_, _мес_, ршки_
  { {0xd2500074,0xc17a0036,0xef1f0064,0x06660086}},	//   رند_, аїн_, kkür_, _بازپ
  { {0xd5a4002b,0xfa77000a,0x67290dd2,0x6fdd0003}},	//   _علای, קעית_, _zdej, déca
  { {0x78fb009d,0xf957000a,0x3957000a,0x130601f3}},	//   יפיו, חסית_, חשים_, _дзем
  { {0xd36f0029,0xcfa7005e,0xde590033,0x7e6d6079}},	//   _لهم_, ішни, бамі_, _prap
  { {0x35df005d,0x80ca000b,0x51862fa0,0x05df0065}},	//   _पीड़, _सुरे, _мука, _पीडब
  { {0x7d040033,0x0dcb20ae,0x7e6d0085,0xc0aa009a}},	//   дзёж, руми_, _vrap, _پاتل_
  { {0x5f950080,0xb5fd0b6c,0x7e6d04d0,0x2bd9002b}},	//   _никт, _vrši, _wrap, مارک_
  { {0xb09b000a,0x7e6d607a,0xa3c00065,0x3f1502ed}},	//   _כיור, _trap, ंकट_, _эдис
  { {0x5a350d9b,0x79a703a9,0x3a3200aa,0xcb080058}},	// [ff50] янат, орже, gryp_, تيقن_
  { {0x89370029,0x35df000b,0xa2dd000b,0xdd910015}},	//   تعرا, _पीढ़, _परस्, _أود_
  { {0x8d5a0008,0x2a690020,0x2b9c002c,0xa3ca000b}},	//   _הכתי, svab_, _síce_, लका_
  { {0xf77300e5,0xdb21008c,0x4425007c,0x907b004f}},	//   باط_, ätäv, _rvl_, יטבי
  { {0xddc4016f,0x4b7a009d,0x68fb0061,0xcf94000a}},	//   _hriš, _הארו, _şudu, וטף_
  { {0x05a80036,0x2b9c0089,0xce380008,0xf9fa0008}},	//   овій_, _více_, קאות_, _להשמ
  { {0xe7330015,0xdb0d016e,0x6286008c,0x1d18000a}},	//   _يصر_, gnaç, äkon, חקור_
  { {0x8c1c0008,0xe4c80015,0x6fd60046,0x7dd202de}},	//   בוהי, غبون_, ráck, læst
  { {0xfbd4000a,0x46380015,0xad9b001a,0x5a9b000a}},	//   ותק_, _وأكد_, npús, שׁ֥ו
  { {0x10a510b3,0x6fd6607b,0xdb160030,0x88f6004f}},	//   зион, máci, rnyé, ּ֖יו_
  { {0x6fd63ae3,0xc948000a,0x3f6a607c,0x0000006a}},	//   láci, חֲרֹ, бино_,
  { {0xe3a5002b,0xad9b006f,0x0000006a,0x0000006a}},	//   _عشای, zpút,   ,
  { {0x63bb0064,0x6fd60ce7,0xdcb70016,0x644b0aee}},	//   mnun, náci, ổng_, žnič
  { {0xbbc4005d,0xddc40263,0x6fdd0003,0x1d070137}},	//   वक्क, _briš, réca, зери_
  { {0x6ab4000b,0x8b960033,0x5b9a0054,0x63bb607d}},	//   ंप्र, прач, бњар_, onun
  { {0x6fd648fe,0x50b80086,0x501a0008,0x60dc18b8}},	//   káci, _بدهد_, _פופו, ürme
  { {0x799e0034,0x7dd202de,0x4f3b000a,0x63bb607e}},	// [ff60] thpw, fæst, _התפע, inun
  { {0x63bb00b8,0x291c016e,0xdb040030,0x6fd6607f}},	//   hnun, úva_, lniü, dáci
  { {0xacfb0008,0x63bb001a,0x7d1e003d,0x3cfb004f}},	//   _להיכ, knun, _ieps, _ללינ
  { {0x7d1e0064,0x1e96000a,0x6fd6016e,0xdb040030}},	//   _heps, ּכַל_, fáci, nniü
  { {0x63bb00b8,0x6fd66080,0x0000006a,0x0000006a}},	//   dnun, gáci,   ,
  { {0x7dd20134,0x67fa0089,0xc955004a,0x5ee9000a}},	//   mæss, _půjd, _отсы, חַצְ
  { {0x65d90010,0x09e306b4,0x63bb05f7,0x399b000a}},	//   цьцё_, _чорн, fnun, _פילד
  { {0x7d1e005c,0x58bb0008,0xb274005e,0xdb0d6081}},	//   _leps, _המלצ, длиш, rnaç
  { {0xdcfc0048,0x877b0053,0xd5b20015,0x6fd6016e}},	//   nkrē, _פאמי, _كفر_, cáci
  { {0xc05a0033,0x569b000a,0x63bb6082,0x009402ed}},	//   бім_, _הימצ, anun, диоэ
  { {0xd2500086,0x53fa002b,0x9f35042b,0x68050091}},	//   رنگ_, _طراح_, мені, _kėda
  { {0x547b000a,0x2d8c2ce8,0xb3690058,0x0000006a}},	//   _לטבו, öden_, _وإنك_,
  { {0xbddb038d,0xe8b9000b,0x0000006a,0x0000006a}},	//   stèm, _आश्च,   ,
  { {0xf8be005d,0xddc412d7,0x41e3005e,0xb5fd005a}},	//   ्थाय, _priš, _піща, _iršt
  { {0x6fd616fb,0x28ac000b,0xf1a90021,0xdc740033}},	//   záci, _टेलि, _بانه_, нгры
  { {0x00bb000a,0x23cc000b,0xdb04002a,0xb5fd0085}},	//   _למומ, ाविद, dnió, _kršt
  { {0x6f7a000a,0x6fdd0003,0x256d0030,0x6445007f}},	// [ff70] _וְיו, léco, lölő_, çhiz
  { {0xa928008f,0x213e003e,0x127b0053,0x6fd6163c}},	//   зіце_, ngth_, זאמע, váci
  { {0x99840015,0x4af9107c,0x23cc000b,0xdcfe0091}},	//   علمو, _меню_, ावाद, _alpė
  { {0xa8180029,0xe738005e,0x6fd642bd,0xdc56002b}},	//   ستمر_, зеї_, táci, _کریک
  { {0xb8d4000b,0x63a00125,0x6fdd0003,0x6604005e}},	//   _जे_, dhmn, héco, епіа
  { {0x6fd6163c,0x8a7a000a,0x395a6083,0xdb040030}},	//   ráci, _ואשת, ceps_, zniü
  { {0xf992000a,0xa3e90a16,0x0000006a,0x0000006a}},	//   _ירך_, одка_,   ,
  { {0xcc78000a,0x6fd6006f,0x8c1c000a,0x6fdd0003}},	//   לגות_, páci, זוהי, déco
  { {0xa13500a2,0x63bb1611,0x15ab006b,0x6fdd16ee}},	//   وردش, rnun, _лъжи_, técn
  { {0x55bb0015,0x35b400ce,0x0000006a,0x0000006a}},	//   _اطرح_, _збур,   ,
  { {0x75236084,0x04950015,0x4094004a,0xdb040030}},	//   manz, _تلاح, ерят, tniü
  { {0x2614005d,0x75236085,0x7d1e6086,0x442701d0}},	//   नीकी_, lanz, _seps, msn_
  { {0x59bf005d,0xa3ca005d,0x6145250c,0x69c303cd}},	//   ्वार, लकर_, _жела, čnej
  { {0xe9ff0023,0x61fd099c,0x865a000a,0x75236087}},	//   _hoặc_, íslu, חדשי, nanz
  { {0xe502014e,0x8d63006b,0x7d1e6088,0x81140058}},	//   रुटि_, ъвре, _veps, _أذها
  { {0xee3a0f13,0x75230586,0x09c6000b,0x1efa0015}},	//   _дни_, hanz, वव्य, _بعثة_
  { {0x6d4f002e,0x3cfa0015,0xab27005e,0x395a00da}},	// [ff80] únað, _وعدد_, ьота_, teps_
  { {0x7e6444c3,0x6e37000a,0x75230077,0xfe37004f}},	//   _isip, _קטיף_, janz, _קריי_
  { {0x7766010f,0xca290008,0x7d7b000a,0xcd97000a}},	//   дълж, שם_, _וניו, _חדית_
  { {0x917b0016,0x6d5c6089,0x6d4e0778,0x7c3c608a}},	//   _lề_, lera, lfba, murr
  { {0xe5c63629,0x7523608b,0xdb160030,0xe5a615be}},	//   мско, fanz, nnyí, миди
  { {0x2d980014,0x661b005c,0x7c3c0152,0xd9560015}},	//   nkre_, _dwuk, ourr, _تنسخ
  { {0x84e8000b,0xcdb7000a,0x2d98608c,0x6d5c608d}},	//   टेंट_, ופסה_, ikre_, iera
  { {0x256d0030,0x6d5c608e,0x988b004f,0xbefd0065}},	//   völő_, hera, _וָמֵ, _एलेन_
  { {0xfbd30008,0x754603de,0xfd650016,0x6d5c32c4}},	//   כתה_, _оназ, _chuồ, kera
  { {0x6736005c,0x75234f5b,0x3cfa000b,0x6d5c608f}},	//   łają, canz, ्डों_, jera
  { {0x130a0080,0x2937000a,0xb4fb000a,0xb0c6004a}},	//   _дней_, ואין_, _ולבר, ьщик
  { {0x65680553,0x443c007c,0xde590033,0x7c3c6090}},	//   _hadh, muv_, памі_, durr
  { {0x02e2014e,0x6568000c,0x7d770029,0x91860029}},	//   _परिभ, _kadh, واسط, _يجتم
  { {0x316700b8,0x6d5c6091,0xa2f7004f,0x23ba01ec}},	//   _ganz_, gera, _חמדה_, dīji_
  { {0x0cd40036,0x65686092,0x0b970067,0xfbd3006e}},	//   ворю, _madh, وجرد, نتر_
  { {0x6d5c00e8,0x644a01d0,0x2d9802dc,0x0000006a}},	//   aera, itfi, akre_,
  { {0x657a0234,0x6d5c6093,0x7b64006b,0x644a007c}},	// [ff90] _onth, bera, ътре, htfi
  { {0xf7700074,0x917b0092,0x65682015,0x6d5c6094}},	//   یان_, _kế_, _nadh, cera
  { {0xb907005d,0xa3be005d,0x47350076,0x7c3c0c5c}},	//   _पर_, ँचा_, енес, curr
  { {0x2f5c004c,0x657a0043,0xe611002b,0x443c1703}},	//   ַדונ, _anth, هشت_, duv_
  { {0xe6180036,0xa5090fd2,0x67200012,0x75236087}},	//   дді_, пела_, _demj, tanz
  { {0x7523003f,0xd4691179,0x14c7002b,0xa50901ca}},	//   uanz, зике_, وهشی_, чека_
  { {0x6d45003f,0x44273677,0xdc3c0085,0x75236095}},	//   _mcha, usn_, ršće, ranz
  { {0x61c7014e,0x36d50036,0x6fd60089,0xc1780007}},	//   रक्ष, _зобр, náct, kmės_
  { {0x65686096,0xf7480029,0xd2990010,0x7c3c04ed}},	//   _fadh, _تلقي_, яткі_, zurr
  { {0x6d5c6097,0x65150015,0xcad8000a,0x6e3d007c}},	//   xera, _أوائ, ווחת_, dusb
  { {0x917b0023,0xd00e0086,0x61f8016f,0x6d5c6098}},	//   _về_, یلی_, _divl, vera
  { {0x34940342,0x3f6a6099,0x6d45609a,0x9327009a}},	//   _шахр, чимо_, _acha, _آران
  { {0xa1950010,0x02440015,0x0ef90033,0x31670012}},	//   _падч, _لَنَ, дэры_, _tanz_
  { {0x752100dc,0x6d4e0012,0x2d9e006f,0x81a80015}},	//   _jelz, ufba, óte_, _يطوف_
  { {0x6d5c01d1,0xc4d20053,0x3a290064,0xc1780007}},	//   rera, ָגן_, esap_, amės_
  { {0x69d500b8,0xd00e0029,0x6d452110,0xe89b0061}},	//   _akze, _الي_, _echa, _şağı
  { {0xdb0f00dc,0x7e64003f,0xfaa312ba,0x67200085}},	// [ffa0] ájár, _usip, гато, _remj
  { {0x75210089,0xcee90029,0xe9d7381e,0xd910002b}},	//   _nelz, _غرين_, еку_, شیر_
  { {0x644a609b,0x6568609c,0x6d8b004f,0x07fa0058}},	//   xtfi, _radh, _זָכְ, سراع_
  { {0xd6d90050,0xa3de000b,0x6286008c,0x5e9a000a}},	//   _był_, _दीं_, äkok, ּבַק
  { {0xb7d70087,0x8afb000a,0xa50601f3,0xeb970c31}},	//   روها_, _מהכי, няйл, _чия_
  { {0xceb30053,0x443c007c,0xd6cf0015,0x644a609d}},	//   ניג_, tuv_, حقه_, ttfi
  { {0x6fd600dc,0x94d30054,0xddc40091,0xb0cf0065}},	//   nács, лошц, _asiū, _सुलग
  { {0x6568003f,0x94730029,0xfc57000a,0xff5f0003}},	//   _wadh, ادوا, תבקש_, noît_
  { {0xdbc70020,0x6568609e,0x443c609f,0x6fd60030}},	//   _tööh, _tadh, suv_, hács
  { {0xe4d60029,0xc5690015,0xd657000a,0xc0ca1923}},	//   _كتاب, _يحلل_, _אימת_, зуме_
  { {0xc9530008,0x89370053,0x3cfa000b,0x7f5d0730}},	//   אמת_, ערטע_, ंशों_, tesq
  { {0x6d452e4e,0x35b60065,0x6e3d60a0,0xe3160058}},	//   _scha, _अगड़, tusb, _أباب
  { {0x8fa40015,0x7f5d50d8,0xf773004f,0x73e300ce}},	//   امُه, resq, אקר_, _соцз
  { {0x127b00b2,0xc297008f,0x917b0092,0x99800007}},	//   _מאדע, _якіх_, _tế_, irių_
  { {0xe0d400b2,0x21670001,0x6fd60030,0xc1780091}},	//   _בײַ_, _чији_, gács, smės_
  { {0x80db0008,0x60db000a,0x50db0643,0x0000006a}},	//   _מחוז, _מקונ, _מקוא,
  { {0xdb040084,0x9989002c,0x3a290035,0x6fd60896}},	// [ffb0] rnið, hrať_, usap_, ráct
  { {0xdb04002e,0x6d4560a1,0xdebc000a,0xf9930015}},	//   snið, _ucha, _ממחל, دبر_
  { {0xbb1b038d,0xa9c400fd,0x2ca701de,0xcdf6004f}},	//   _boît, устк, _ånd_, _שמתי_
  { {0x1ab50010,0xdb0700f2,0xe7840004,0x5a470033}},	//   _абмя, ämät, лучо, _пэга
  { {0x99890a52,0xbb3a004c,0x75210012,0xfd8b000a}},	//   erať_, _קעשי, _pelz, ּטֶּ
  { {0xc58b004a,0x6daa004f,0x917b00a1,0xdb0d03a0}},	//   ящее_, ֽׁקֶ, _mễ_, liaà
  { {0x65920001,0x917b0092,0xd4660f5c,0x99800091}},	//   рају, _lễ_, вище_, arių_
  { {0x77d70029,0x58d430e1,0xbc7c000a,0x442c60a2}},	//   _أغسط, _сост, לנות, _dvd_
  { {0xd2f6002b,0x4222004a,0xdcfe0085,0xb2220033}},	//   نکها_, адыв, _uopć, амыл
  { {0x6f0d04f9,0x9989032c,0x6fdd0152,0xdb040092}},	//   _afac, brať_, léch, ghiê
  { {0x8fa6010f,0x89dc000a,0x7a47003d,0x60e902ed}},	//   ване, החזי, lūtā, ьмом_
  { {0x6fdd0003,0x4f9615df,0xb4cd0065,0x23640058}},	//   néch, троу, रथी_, _مهمّ
  { {0xe28e129a,0x9e63008f,0xfe7901b0,0x59d1000b}},	//   _та_, авяд, нёры_, तकार
  { {0x917b0092,0x30850015,0xc692004f,0x6f0d0416}},	//   _dễ_, _للتف, סאם_, _efac
  { {0x224d00dc,0x6f0d0dc7,0x0548004f,0x1d07009b}},	//   ltek_, _ffac, עֲשֽ, теси_
  { {0x25e8005d,0x99800007,0xb0680015,0x236d0085}},	//   _चीनी_, yrių_, _أصول_, ndej_
  { {0x224d411a,0xff5f0003,0x7fd7004f,0xdb040052}},	// [ffc0] ntek_, roît_, _בוקס_, kniö
  { {0x957c002a,0x7794002b,0x0000006a,0x0000006a}},	//   _wiąz, گیرا,   ,
  { {0x98b101e2,0x574a0010,0xfbc604c2,0xdca60684}},	//   _bazı_, дзем_, _абно, _рани
  { {0x224d24a6,0x7e763634,0xc7af0058,0x0000006a}},	//   ktek_, _kryp, يّل_,
  { {0x06540029,0x99800007,0x47330127,0x6cd3002b}},	//   انتح, urių_, рніс, _مقیا
  { {0xd6930124,0x35b60063,0x224d00dc,0xdcfe002a}},	//   ришћ, ъщес, dtek_, _popę
  { {0xa8230086,0x67e3007c,0x03c62b2c,0xe4b80138}},	//   _نکنن, sõja, ксим, элкі_
  { {0x68e360a3,0x98b10061,0x35a6000b,0xd4670054}},	//   ünde, _gazı_, कोज़, тиће_
  { {0xc5660001,0x02430015,0x05661119,0xe3af0040}},	//   _икак, لَيَ, _иван, ترو_
  { {0xc1b70033,0xbddb0144,0xc17301c5,0x84b6006b}},	//   клых_, ntèt, альщ, _ищец
  { {0x25d70008,0x993b0008,0x493b0008,0x98b10064}},	//   _יומן_, ותיה, וגיו, _yazı_
  { {0x6722000b,0x23ba003d,0xdb04007c,0xe29a2e38}},	//   मरिक_, tīju_, oniõ, _оае_
  { {0xd3370008,0x28d9005d,0x539b039e,0x63a260a4}},	//   _יראה_, _बुनि, _קידו, _ilon
  { {0x5bbd000b,0x60a60015,0x81440058,0x0000006a}},	//   ्क्व, _لإبق, _صنعن,
  { {0x1df8004a,0xddc70030,0x63a260a5,0x2b93009a}},	//   теры_, óműv, _klon, لیدس
  { {0xddcd0045,0xd0f7000a,0x69de0d16,0xa037004f}},	//   _braţ, _במות_, elpe, _סאחה_
  { {0x98b10061,0xb955006b,0x7e7660a6,0x0000006a}},	// [ffd0] _razı_, лващ, _gryp,
  { {0x63a20026,0x89340015,0x6fdd0a8b,0x645a0767}},	//   _llon, لعما, déci, _opti
  { {0x224d00dc,0x97c7002b,0x38c9002b,0xdd91002b}},	//   ztek_, پتام, رائی_, _نوک_
  { {0x224d1e80,0xe7300015,0xddcd0045,0xc053004c}},	//   ytek_, قصه_, _fraţ, יזע_
  { {0x6fdd0152,0xf7700031,0x645a5cf3,0xddcd0045}},	//   réch, تال_, _apti, _graţ
  { {0x69cb00dc,0x58050029,0x63a23396,0x7bdf00b8}},	//   éged, _موسك, _alon, llqu
  { {0x26d20064,0x7a470024,0x200a0046,0x5fd3000b}},	//   üyor_, sūtā, íbil_, सवाल
  { {0x0456003b,0x224d0014,0x2489016f,0x3cfc000a}},	//   الية_, ttek_, ćam_, ולונ
  { {0xd24e0029,0xc7b2000a,0xd1b90015,0xef1f0030}},	//   كني_, _הבן_, فادا_, rjül_
  { {0x646842e8,0xeab2000a,0x224d60a7,0x63a260a8}},	//   äsiä, מֹת_, rtek_, _elon
  { {0x224d60a9,0x841515fb,0xa988004f,0x0000006a}},	//   stek_, _смех, דָרִ,
  { {0xa3de000b,0x3996001a,0x224d0e8c,0x2011003d}},	//   णतः_, _hæst_, ptek_, īzi_
  { {0x52740086,0xd7ba000a,0x479a000a,0xdb0d001a}},	//   _پانز, תֶיך, גירס, fnaþ
  { {0xe8e00092,0xde0326ca,0xdb0f002a,0x63a2036d}},	//   hiều_, спри, _ojcó, _zlon
  { {0x8c950036,0xdca32dfa,0xd9bf0065,0xe164009a}},	//   арті, бари, ्वैट, _ضدوي
  { {0xcb670001,0x3996193d,0xd245002b,0xba1a0015}},	//   ласе_, _læst_, يچ_, فيرا_
  { {0x4e1d005d,0x39ea0054,0xda66002b,0x2ba5000b}},	// [ffe0] बीआई_, едао_, دازي, _ऐतरा
  { {0x3996002e,0x8d66557e,0x4d660681,0x680c007f}},	//   _næst_, _свое, _сков, _ağda
  { {0x485a0010,0xf99f0251,0x3f920061,0xdcf70045}},	//   эраў_, _atès_, _koyu_, ăcăt
  { {0x87da002b,0xfaa60033,0xddcd1289,0x46a608fe}},	//   رباس_, _бамо, _iraš, лаев
  { {0x9f8b0020,0x6d4130e6,0xdcfa002b,0x7c2e60aa}},	//   _tööl_, ólag, _ترکش_, lsbr
  { {0xe4e602e1,0x7bc460ab,0xa4f8002b,0x6d76004c}},	//   лійн, lniu, نکار_, רײַב_
  { {0x89db000a,0x7794002b,0xa9230046,0x63a260ac}},	//   _נחלי, _پیشا, ížec, _plon
  { {0xb8f8005d,0x6fdd1649,0xbddb0003,0xf4830004}},	//   ाथ_, péci, ntèr, сушн
  { {0xf12618a9,0x3996002e,0x7bc44327,0x63a20046}},	//   льно, _fæst_, iniu, _vlon
  { {0x76420064,0x92570015,0x399602de,0x865b05bd}},	//   muoy, اشير_, _gæst_, _אדמי
  { {0x3f920061,0x84e6004a,0x70540015,0x7c2e0079}},	//   _boyu_, _сожж, جنجا, jsbr
  { {0x7c2e0134,0xf8b30008,0xd3a5005e,0xdfd50088}},	//   dsbr, משת_, _кріп, ромы
  { {0x9f920084,0xef1f0014,0xdb0d001c,0x3f80005c}},	//   ráð_, ljük_, liaç, _dniu_
  { {0x6fc80061,0x1619000b,0xddcd00b3,0x7bc460ad}},	//   rıca, नीटर_, _braš, eniu
  { {0x2b9c0023,0xef1f00dc,0x11db000a,0x7c84012e}},	//   _kích_, njük_, _רחוב, буте
  { {0x40eb0008,0x307b01ac,0xa4b7000a,0xddcd00b3}},	//   _אַחֲ, _טאונ, אללה_, _draš
  { {0x645c0020,0x7ac70033,0x9f98000a,0x52e2000b}},	// [fff0] _ärif, усве, _תדחה_, _परोस
  { {0x7de70015,0xa2c5000b,0x7d18006f,0x6f1d0012}},	//   _حسبم, ापत्, časí, lbsc
  { {0x31570053,0x7ae2003d,0x4ddc000a,0xbc8b0015}},	//   ריבן_, ļota, _אחזו, _أضخم_
  { {0xbddb038d,0x6d47002e,0x291c002e,0xef1f00dc}},	//   ctèr, lgja, ðvar_, djük_
  { {0x36695586,0xe8e00016,0xe56e08e8,0x6b8b001a}},	//   тало_, riều_, оз_, öggu
  { {0xd6180029,0x86240010,0x6d4760ae,0xc987261d}},	//   اتنا_, сьце, ngja, _суми
  { {0xcd980008,0xa988000a,0x2b9c0016,0x6d47001a}},	//   רדות_, _עָשִ, _bích_, igja
  { {0xf8b20008,0x6b8d0509,0x0615005e,0x4375110c}},	//   _ושל_, njag, _вдаю, рукт
  { {0xe6100029,0xe29f001a,0x672b0030,0x69c560af}},	//   _فشل_, áð_, magj, onhe
  { {0x69c55643,0x7bc40030,0xc5fb0015,0x6b8d0072}},	//   nnhe, zniu, _أعرض_, hjag
  { {0xdb0d001c,0x557a0053,0xbfc60036,0x27ed0092}},	//   ciaç, _שװעד, ибок, _khen_
  { {0xe8d60008,0x141a000a,0x78fa000a,0x5ea60015}},	//   יותר_, _יועב, כפתו, لمجل
  { {0x539a013a,0x64431878,0x63a9002e,0x27ed0026}},	//   _שינו, luni, mhen, _mhen_
  { {0xddcd0780,0xdee30036,0x61420001,0x6d47002e}},	//   _praš, іори, _деша, ggja
  { {0x1c39034e,0x91ba000a,0xcce50015,0x672b001a}},	//   лять_, _שמצי, مسفي, kagj
  { {0x63bb2283,0x3326007c,0x2b9c0016,0xe8e00016}},	//   niun, _xeox_, _xích_, hiểu_

  };

static const uint32 kQuadTableInd[24752] = {
  // [0000]
  0x00000000, 0x00001e0f, 0x37004e13, 0x00000506,
  0x00002506, 0x0000191c, 0x38000509, 0x0000160f,
  0x0000070f, 0x03066612, 0x00000706, 0x00002406,
  0x00003f1c, 0x0000250f, 0x05001412, 0x5c000713,
  // [0010]
  0x0000300f, 0x0000170f, 0x00000606, 0x0b000208,
  0x0000181c, 0x00003706, 0x00004306, 0x2b003f14,
  0x37004e11, 0x19002113, 0x00001406, 0x17000822,
  0x00000d0f, 0x27012b12, 0x00001c2d, 0x0b0602af,
  // [0020]
  0x0000190f, 0x4e003707, 0x1d001707, 0x0000431c,
  0x0000150f, 0x03050621, 0x00002b0f, 0x1d450c21,
  0x03000607, 0x0000370f, 0x00000c06, 0x00004e06,
  0x0000450f, 0x00001f0f, 0x0000140f, 0x00001f1c,
  // [0030]
  0x00001806, 0x37004e14, 0x27192912, 0x00003006,
  0x00002b06, 0x0000210f, 0x0000230f, 0x030b0221,
  0x05190407, 0x43002b07, 0x220b1055, 0x0000371c,
  0x00000b0f, 0x00001506, 0x0000010f, 0x00003f0f,
  // [0040]
  0x4e003709, 0x0000011c, 0x16001712, 0x050601af,
  0x19000414, 0x00001706, 0x00001206, 0x250e23a4,
  0x0000151c, 0x29002714, 0x00000e06, 0x1d4016ad,
  0x00005c06, 0x2b060108, 0x30002302, 0x00000701,
  // [0050]
  0x00000c1c, 0x0f050109, 0x00001401, 0x00005c0f,
  0x00001e06, 0x250e2313, 0x40013f12, 0x45001214,
  0x00003701, 0x02120107, 0x00001201, 0x00000401,
  0x00000c0f, 0x0000240f, 0x00002306, 0x00000e1c,
  // [0060]
  0x16004012, 0x00002206, 0x04003802, 0x00001c0f,
  0x0000220f, 0x00002401, 0x450b0202, 0x37004e07,
  0x180d05a4, 0x12004509, 0x00000000, 0x00001c06,
  0x18221012, 0x0e002313, 0x37004e08, 0x00004506,
  // [0070]
  0x4e003722, 0x04010209, 0x00001901, 0x00001601,
  0x00004e1c, 0x160427af, 0x1c1e2512, 0x00000f06,
  0x020b1023, 0x00000306, 0x23000e13, 0x25301c09,
  0x00001906, 0x020b1422, 0x0e001e07, 0x00002201,
  // [0080]
  0x00000e0f, 0x1d004002, 0x1c253007, 0x0000251c,
  0x0000141c, 0x00001d06, 0x00004e0f, 0x37004e12,
  0x30000e07, 0x0000120f, 0x251c0e08, 0x30002308,
  0x00000406, 0x1e0e2313, 0x270d29a4, 0x0000301c,
  // [0090]
  0x04050112, 0x00001606, 0x0000430f, 0x43450f07,
  0x10380107, 0x15001612, 0x08012b07, 0x14001812,
  0x1e002307, 0x25001e08, 0x00004e01, 0x00001c01,
  0x25001e13, 0x0000070a, 0x30002323, 0x251c0e12,
  // [00a0]
  0x171812a4, 0x00004301, 0x4e003711, 0x07005c13,
  0x0e001c12, 0x1c250e12, 0x04002b07, 0x0000432d,
  0x150806bb, 0x06002b07, 0x00006606, 0x38000b08,
  0x0f002707, 0x10006612, 0x0c1d1009, 0x00001e01,
  // [00b0]
  0x37004e20, 0x0d041212, 0x00005c1c, 0x12001d07,
  0x00005c2d, 0x0f100107, 0x0000211c, 0x01190307,
  0x0000060f, 0x30001c20, 0x0c000b13, 0x10031907,
  0x00004006, 0x0000400f, 0x380f0d13, 0x12004508,
  // [00c0]
  0x0000100f, 0x0c011712, 0x0e002302, 0x4e003708,
  0x430104a4, 0x15001611, 0x04030607, 0x06000107,
  0x380d1809, 0x0e251c14, 0x06001420, 0x00000b06,
  0x0c400bbb, 0x05001607, 0x00002301, 0x1e0e2502,
  // [00d0]
  0x1e002512, 0x38170112, 0x23251c60, 0x10003f07,
  0x00001701, 0x04000607, 0x10000b09, 0x1e002514,
  0x0e251e12, 0x0000290f, 0x00000106, 0x01382b07,
  0x0000180f, 0x0000660f, 0x380f0512, 0x0000161c,
  // [00e0]
  0x060c01a4, 0x0f000d08, 0x23003009, 0x43386607,
  0x03001921, 0x4e003714, 0x4e003712, 0x01002b07,
  0x0000270f, 0x38000507, 0x2b000112, 0x1c000e09,
  0x27001f12, 0x660301af, 0x0d170107, 0x04032b07,
  // [00f0]
  0x1d001612, 0x1e250eaf, 0x0000040f, 0x07005c14,
  0x23000e09, 0x30002335, 0x03006623, 0x06220309,
  0x0c002b20, 0x01380455, 0x06011908, 0x0000021c,
  0x06036660, 0x30002307, 0x0b020407, 0x231c2520,
  // [0100]
  0x19000113, 0x02001807, 0x45083808, 0x10000b02,
  0x164512af, 0x2b011f12, 0x66030112, 0x45001213,
  0x01030613, 0x100f1912, 0x01083820, 0x00001d1c,
  0x060501af, 0x38000f07, 0x011f2112, 0x00001c1c,
  // [0110]
  0x051f0112, 0x0000030f, 0x1f002b13, 0x03040613,
  0x2b000120, 0x4e003713, 0x662b0112, 0x1e002302,
  0x10001808, 0x05380809, 0x1c251e13, 0x1c230ebe,
  0x1c1e3007, 0x25000e08, 0x00002501, 0x5c000721,
  // [0120]
  0x1e230e13, 0x0e002309, 0x061f0121, 0x00001006,
  0x00001e1c, 0x00001f06, 0x061f2b55, 0x30002312,
  0x230e3009, 0x230e1e09, 0x0e252309, 0x1c251e09,
  0x37004e09, 0x19001012, 0x1e002508, 0x1c0e1e07,
  // [0130]
  0x0d381412, 0x18000311, 0x30000e02, 0x1c3023a4,
  0x0000020f, 0x07005c12, 0x231e1cad, 0x23251ca4,
  0x00003001, 0x30000e14, 0x0000071c, 0x00004001,
  0x29002713, 0x251e1c13, 0x1c230e07, 0x45001208,
  // [0140]
  0x0f000507, 0x011904a4, 0x0e002312, 0x03010412,
  0x00003806, 0x01210411, 0x23000e11, 0x19006607,
  0x250e1ea4, 0x04000308, 0x66000412, 0x04001907,
  0x66000113, 0x1e1c0e12, 0x0000241c, 0x0c001811,
  // [0150]
  0x03006614, 0x1c003007, 0x0000050f, 0x01196612,
  0x18451211, 0x0e1c1e12, 0x45001223, 0x24004108,
  0x01001908, 0x66000312, 0x21292712, 0x07005c07,
  0x3f1f1813, 0x2b001f34, 0x060b0307, 0x02000402,
  // [0160]
  0x00001d01, 0x66000314, 0x0e1c2560, 0x01660460,
  0x0e001e14, 0x0e232507, 0x04002121, 0x1d0b1007,
  0x43010407, 0x0c272255, 0x251e1c09, 0x66000313,
  0x27036608, 0x00004501, 0x00000d06, 0x00001d0f,
  // [0170]
  0x1c0e1eaf, 0x03001912, 0x12400ca4, 0x05141612,
  0x0e003008, 0x0e001e13, 0x00002b1c, 0x03006611,
  0x1c001e22, 0x19141007, 0x25001c14, 0x12004014,
  0x23001e12, 0x0e2330ad, 0x00001f2d, 0x30002313,
  // [0180]
  0x1e002513, 0x18006612, 0x01050812, 0x1d004508,
  0x250e1cad, 0x1e002314, 0x06000311, 0x3f0c06be,
  0x45120c12, 0x25231c09, 0x190529ad, 0x0000061c,
  0x0000401c, 0x251e1c07, 0x05001621, 0x23001e11,
  // [0190]
  0x1c002509, 0x0000231c, 0x40001513, 0x04000111,
  0x0b020612, 0x0e001c09, 0x4e003721, 0x19000420,
  0x1d004022, 0x251e0e21, 0x04001909, 0x06161407,
  0x0000252d, 0x05106607, 0x151d1608, 0x03000207,
  // [01a0]
  0x18000412, 0x0b001612, 0x23250ebe, 0x40001d14,
  0x1c1e0e23, 0x401d1511, 0x1d1040af, 0x0b001012,
  0x0d001f07, 0x0e1e1c60, 0x100c1fbb, 0x0b000222,
  0x07005c11, 0x19001508, 0x10151421, 0x14001011,
  // [01b0]
  0x0e003007, 0x02030608, 0x45001212, 0x01001f07,
  0x0f061013, 0x17001f11, 0x38000108, 0x0e001c07,
  0x10060b07, 0x150f1612, 0x010821ac, 0x05001812,
  0x1d001907, 0x010408a4, 0x19000407, 0x080b1012,
  // [01c0]
  0x45001209, 0x14100b14, 0x00002906, 0x2b1701af,
  0x05001813, 0x23000e07, 0x30002309, 0x020118bc,
  0x0000072d, 0x12004512, 0x1e002509, 0x45001211,
  0x0b040209, 0x01105107, 0x05001807, 0x1e1c25a4,
  // [01d0]
  0x00000201, 0x0000101c, 0x1c0e2509, 0x00001801,
  0x06010409, 0x06141913, 0x38010809, 0x00002706,
  0x5c000712, 0x0e003020, 0x1c250ea4, 0x080c05a4,
  0x23251e12, 0x020b0812, 0x02000b09, 0x1d451260,
  // [01e0]
  0x00000801, 0x1c1e2509, 0x0000221c, 0x1c230e13,
  0x5c000720, 0x0e1c2312, 0x0d0f05a4, 0x1e302321,
  0x1c0e1e09, 0x25001c02, 0x12001d02, 0x1e230e09,
  0x00001501, 0x30251c6f, 0x0b100207, 0x0f000813,
  // [01f0]
  0x0b000214, 0x01000607, 0x400c1d07, 0x23003007,
  0x29004320, 0x16151921, 0x00000501, 0x1527296f,
  0x080c17a4, 0x00000101, 0x221d45af, 0x043f1509,
  0x02101909, 0x050301a4, 0x0e302355, 0x27294012,
  // [0200]
  0x10190809, 0x19000413, 0x19004022, 0x2b0143a4,
  0x23001c02, 0x19001611, 0x19401d22, 0x0b401d23,
  0x19000f12, 0x04001913, 0x0000661c, 0x02140b12,
  0x18001d13, 0x01000611, 0x18000b11, 0x1d1540af,
  // [0210]
  0x23003011, 0x0c001d13, 0x04151921, 0x27002912,
  0x1c002309, 0x231c0e11, 0x01022b07, 0x14021009,
  0x27020b12, 0x1c302312, 0x230e30af, 0x03001412,
  0x100b0211, 0x061440bc, 0x24004113, 0x66270621,
  // [0220]
  0x06050112, 0x30231e12, 0x22451212, 0x020b01af,
  0x456612bb, 0x37004e22, 0x010c2b12, 0x12004514,
  0x15000c08, 0x1c000e22, 0x23003014, 0x1d002909,
  0x030129a4, 0x0000041c, 0x16451213, 0x18124508,
  // [0230]
  0x10002b13, 0x24004112, 0x2b0d08be, 0x0d1d4012,
  0x03006613, 0x0e231c60, 0x40182207, 0x12001d11,
  0x23001c07, 0x30001c08, 0x121d4555, 0x1c0e25a4,
  0x230e1c13, 0x1e231c07, 0x25001e12, 0x1c2530ad,
  // [0240]
  0x03061407, 0x14012908, 0x16001d14, 0x16061412,
  0x45000c08, 0x1e0e1c08, 0x1d050108, 0x45001207,
  0x0e002308, 0x300e1e07, 0x2b0104bc, 0x14001f13,
  0x181d27a4, 0x12004009, 0x0e302309, 0x0e001c08,
  // [0250]
  0x013803a4, 0x0000380f, 0x06010512, 0x21004513,
  0x1c002514, 0x18001907, 0x30000e13, 0x40100b55,
  0x010603af, 0x05160613, 0x06160112, 0x06140512,
  0x0000212d, 0x10001807, 0x29002120, 0x1c0e1e12,
  // [0260]
  0x21272913, 0x293f2113, 0x1e302355, 0x40001d13,
  0x12004513, 0x011d1712, 0x27100b60, 0x01080f6f,
  0x1c002311, 0x1d000813, 0x0f000d09, 0x38054511,
  0x03000602, 0x380d05be, 0x052b01af, 0x02000111,
  // [0270]
  0x380105be, 0x04010612, 0x0f001913, 0x29002712,
  0x0f380521, 0x0f292712, 0x08020112, 0x38000521,
  0x29273f21, 0x160f21ad, 0x0e302307, 0x38010508,
  0x1c251e08, 0x01003811, 0x03050612, 0x251e23be,
  // [0280]
  0x230e3008, 0x22000c12, 0x10660313, 0x66010612,
  0x66004012, 0x19121d07, 0x0e002311, 0x38050112,
  0x05450611, 0x1c251e22, 0x0c002b07, 0x2b2901af,
  0x0f000521, 0x05001712, 0x012b0612, 0x38000513,
  // [0290]
  0x063f04af, 0x38000512, 0x25001e22, 0x02000b13,
  0x1c0e2311, 0x0b0210af, 0x1c0e2307, 0x66003f12,
  0x0000031c, 0x0e1e25af, 0x0f040513, 0x1e1c2507,
  0x272904bc, 0x1f000413, 0x0f040112, 0x1c002508,
  // [02a0]
  0x0b0238af, 0x01030609, 0x06226607, 0x23003008,
  0x22046614, 0x0f000420, 0x0b055112, 0x1e250e12,
  0x2b001812, 0x120118ad, 0x04051f12, 0x0b050212,
  0x080f0109, 0x00000601, 0x05000207, 0x020608ad,
  // [02b0]
  0x1c1e25af, 0x0f030112, 0x050104be, 0x030601af,
  0x0b140223, 0x0f081d14, 0x0e1c23bb, 0x180f0421,
  0x0f0b0209, 0x00000806, 0x22664008, 0x0e233007,
  0x08160102, 0x08010d12, 0x37004e02, 0x0e003012,
  // [02c0]
  0x1d0d08a4, 0x00000f0f, 0x0d001013, 0x10001820,
  0x1c251ebe, 0x1c003013, 0x1d004014, 0x03040107,
  0x230e1c12, 0x19081812, 0x0b0266a4, 0x3f124521,
  0x1d000f21, 0x10020b12, 0x10005113, 0x400f2912,
  // [02d0]
  0x171f0112, 0x40430107, 0x10000b13, 0x0c1d4022,
  0x291d3f12, 0x0000121c, 0x0b0210a4, 0x0000081c,
  0x1d004009, 0x25001e09, 0x230e1ca4, 0x23000e02,
  0x00001001, 0x230e1c02, 0x00000206, 0x10000b12,
  // [02e0]
  0x18000f09, 0x23003012, 0x1d0522ac, 0x0c002908,
  0x2b002913, 0x23003022, 0x12001811, 0x052b0112,
  0x29003f12, 0x0b000223, 0x27002b21, 0x03121f12,
  0x1c302360, 0x00000e01, 0x66190612, 0x15000c14,
  // [02f0]
  0x0b101413, 0x400c3f12, 0x00002106, 0x1d000513,
  0x1d400c13, 0x05010807, 0x401d0caf, 0x03000608,
  0x060105bb, 0x03044512, 0x12450c07, 0x050b01ac,
  0x10050112, 0x15001622, 0x05012bbc, 0x2b050112,
  // [0300]
  0x0e1c1e13, 0x1d0504ad, 0x1e1c2508, 0x66000613,
  0x27002b12, 0x01000c11, 0x18001708, 0x12001807,
  0x16001907, 0x10000409, 0x04001807, 0x0f003807,
  0x23000e08, 0x03001707, 0x1e1c25af, 0x18001913,
  // [0310]
  0x01004508, 0x45032b08, 0x04002108, 0x06002b12,
  0x18001f07, 0x380f1d07, 0x03002b08, 0x1e1c2514,
  0x10030607, 0x0c001713, 0x06001f07, 0x40171daf,
  0x12000112, 0x1d401712, 0x250e1c11, 0x1d001713,
  // [0320]
  0x06001711, 0x16000411, 0x190429af, 0x230e3007,
  0x05001808, 0x02004007, 0x03050107, 0x16001908,
  0x1e0e1c55, 0x1e003013, 0x190414af, 0x452b01a4,
  0x0000451c, 0x23251e13, 0x251e2321, 0x382b0112,
  // [0330]
  0x10000223, 0x272151af, 0x3f292712, 0x38001013,
  0x06000113, 0x01002b12, 0x3f001021, 0x212927af,
  0x0d272912, 0x0f4301af, 0x15001207, 0x0b062207,
  0x14021022, 0x1c000e07, 0x401d01a4, 0x25002311,
  // [0340]
  0x1d001512, 0x38000d13, 0x0e002307, 0x29272b21,
  0x0d124508, 0x1c002511, 0x03662712, 0x17401d12,
  0x020501a4, 0x38140521, 0x1c300e21, 0x10080102,
  0x66292712, 0x22000611, 0x23000e14, 0x66001414,
  // [0350]
  0x0e1c2507, 0x01001607, 0x22006607, 0x19000607,
  0x30231c12, 0x231c0ead, 0x19000423, 0x451d12cf,
  0x21003f13, 0x22000607, 0x10451209, 0x66000c09,
  0x020b22be, 0x08020baf, 0x0f001d07, 0x0c004007,
  // [0360]
  0x06000121, 0x1c0e2313, 0x02660baf, 0x12000807,
  0x1d000213, 0x1f002120, 0x08030baf, 0x22170daf,
  0x081d4008, 0x4e003702, 0x030b026f, 0x1d0c40ac,
  0x12080107, 0x1d004008, 0x0c1d1212, 0x08021721,
  // [0370]
  0x0c451213, 0x120c1d07, 0x0000242d, 0x080201a4,
  0x03060207, 0x27002913, 0x08050112, 0x19120113,
  0x0f451214, 0x010b1007, 0x08000b13, 0x05000f08,
  0x12000c08, 0x061f01af, 0x08060112, 0x0c001213,
  // [0380]
  0x100601af, 0x40001712, 0x0e231e11, 0x01000608,
  0x66000322, 0x0f6601af, 0x21030112, 0x18000f12,
  0x43000112, 0x18003811, 0x10001913, 0x0b000113,
  0x19000608, 0x0000051c, 0x0d002123, 0x06001008,
  // [0390]
  0x0f3801af, 0x10191fac, 0x1d4004a4, 0x1d041fad,
  0x10000f07, 0x03001f07, 0x23301eac, 0x404503be,
  0x1d000113, 0x18002213, 0x0b06666f, 0x04061012,
  0x21014512, 0x10030107, 0x5c000714, 0x00000f01,
  // [03a0]
  0x00003801, 0x02080b07, 0x0d002712, 0x451d1812,
  0x04001012, 0x040529a4, 0x01000d07, 0x300e2309,
  0x1e0e23af, 0x1c000e11, 0x211401af, 0x211f1712,
  0x3f002121, 0x0e001c14, 0x25001e07, 0x00000d1c,
  // [03b0]
  0x380f01af, 0x0e231e60, 0x0d010813, 0x211814bc,
  0x21020b12, 0x191f01af, 0x19000620, 0x27001612,
  0x0d0f01af, 0x15221914, 0x06002211, 0x1d0f19ad,
  0x18001209, 0x084519af, 0x0e003023, 0x17051d12,
  // [03c0]
  0x0000182d, 0x10000607, 0x0000012d, 0x45191621,
  0x37004e21, 0x0e002513, 0x43384021, 0x1e302311,
  0x06172212, 0x081751af, 0x0e2330a4, 0x27380d13,
  0x06020d09, 0x45004013, 0x0f002b22, 0x212729af,
  // [03d0]
  0x04000d12, 0x66192213, 0x06030b07, 0x386645a4,
  0x0d001809, 0x0f001720, 0x273f0112, 0x38052709,
  0x2b401d12, 0x18001f12, 0x0c000614, 0x1d4021a4,
  0x22000c08, 0x05001422, 0x1e001c07, 0x0c004012,
  // [03e0]
  0x0f054512, 0x12000107, 0x18451512, 0x1e002311,
  0x05002111, 0x143f0112, 0x1d001007, 0x0e002314,
  0x250e23be, 0x00001503, 0x231e2507, 0x0000152d,
  0x25302355, 0x1d124520, 0x031d06a4, 0x00004e42,
  // [03f0]
  0x05060109, 0x25001e23, 0x45121daf, 0x17001213,
  0x06012207, 0x10000812, 0x19000212, 0x1d0c2207,
  0x03006609, 0x18170812, 0x250e1c12, 0x300e1c12,
  0x0e001c13, 0x1f030612, 0x381701af, 0x18001912,

  // [0400]
  0x06001007, 0x19060107, 0x251e0eaf, 0x25001c23,
  0x0e001c23, 0x06002208, 0x02290111, 0x22001921,
  0x43001811, 0x03006612, 0x02002b07, 0x0000372d,
  0x08041712, 0x400c1d20, 0x12042b12, 0x04163f12,
  // [0410]
  0x18003f12, 0x03451d12, 0x451810ad, 0x21222712,
  0x17451260, 0x0e1c25ac, 0x00002b01, 0x12004502,
  0x0e233012, 0x231c2512, 0x27161808, 0x231c0eac,
  0x04001921, 0x08000413, 0x082b0512, 0x18040814,
  // [0420]
  0x030c1213, 0x1c233013, 0x01001711, 0x0c271912,
  0x0c151655, 0x0d001213, 0x0d381fad, 0x231e2508,
  0x18004508, 0x0e231e13, 0x45000807, 0x30002314,
  0x19002107, 0x0e301c07, 0x300e25a4, 0x03006607,
  // [0430]
  0x08272212, 0x25001e21, 0x23001e07, 0x18150822,
  0x05012712, 0x04000611, 0x29051408, 0x04000613,
  0x1903666f, 0x030466bc, 0x21000113, 0x06041012,
  0x03000411, 0x23300e13, 0x04000b12, 0x40000c22,
  // [0440]
  0x0000172d, 0x12004312, 0x1e232513, 0x02100bbe,
  0x030618a4, 0x0c003f21, 0x16001812, 0x00000703,
  0x45120cad, 0x23300eaf, 0x23002513, 0x0c004011,
  0x40001d12, 0x01006607, 0x0e003022, 0x0104196f,
  // [0450]
  0x43001720, 0x04004512, 0x0c121612, 0x040c1614,
  0x06012707, 0x40003f21, 0x66031621, 0x1c000e13,
  0x04001922, 0x1c250e14, 0x06010412, 0x29271614,
  0x25233008, 0x042716ad, 0x12041612, 0x0e002507,
  // [0460]
  0x29181614, 0x0e1e1c07, 0x45001411, 0x0f014021,
  0x22006612, 0x45120cac, 0x05000d12, 0x00000f1c,
  0x05004307, 0x22291d12, 0x1f003f12, 0x2b013f12,
  0x17002913, 0x0d001712, 0x03124513, 0x171d40a4,
  // [0470]
  0x030c06a4, 0x2b4027af, 0x16000113, 0x19660412,
  0x030b0112, 0x22000608, 0x290627af, 0x1e1c2555,
  0x190340af, 0x12000113, 0x0c002712, 0x012b0c11,
  0x45220108, 0x1c251e21, 0x0f000d14, 0x0b000607,
  // [0480]
  0x1d451213, 0x0e251c55, 0x0000222d, 0x211d4512,
  0x23003013, 0x12000114, 0x06000807, 0x12450c02,
  0x080116ad, 0x0d0f1608, 0x14001521, 0x10002212,
  0x29001912, 0x064512af, 0x171f1960, 0x1d220112,
  // [0490]
  0x0d1701af, 0x25001c20, 0x1f3f1221, 0x05000113,
  0x05011fa4, 0x2b000113, 0x66031012, 0x10000622,
  0x080d0112, 0x0e1c25a4, 0x12001f11, 0x10002220,
  0x03006622, 0x25001e14, 0x1d124512, 0x1d004513,
  // [04a0]
  0x05080112, 0x08401d21, 0x221d1507, 0x0b100607,
  0x0f0d1f08, 0x01000f07, 0x12401d13, 0x22002112,
  0x17050112, 0x08000107, 0x083805ac, 0x0e003013,
  0x0c120507, 0x04000507, 0x1c232507, 0x12004523,
  // [04b0]
  0x01000620, 0x121d4509, 0x12004507, 0x660b0612,
  0x1e230ea4, 0x1c0e2302, 0x00004e2d, 0x08121d21,
  0x04001014, 0x250e1c13, 0x08001213, 0x1e251c09,
  0x0e251e14, 0x17380812, 0x151601af, 0x171d08ac,
  // [04c0]
  0x12004012, 0x120c1da4, 0x1e003011, 0x06013807,
  0x031d0607, 0x1c000e02, 0x1d001213, 0x01170fa4,
  0x66170812, 0x37004e23, 0x1e233014, 0x01292707,
  0x100216a4, 0x17004302, 0x0b040202, 0x3f292720,
  // [04d0]
  0x66000112, 0x02000b08, 0x06001907, 0x1f030620,
  0x06001013, 0x30230ea4, 0x19001007, 0x231c2509,
  0x06190108, 0x0c451912, 0x381701a4, 0x292227af,
  0x5c000722, 0x062b0112, 0x03000611, 0x38140112,
  // [04e0]
  0x230e2512, 0x012b0512, 0x45120112, 0x06661812,
  0x22002b13, 0x231c0e08, 0x0d000f02, 0x230e1c55,
  0x012b0655, 0x430d0fa4, 0x06000413, 0x38000307,
  0x03000620, 0x0000080f, 0x01062b08, 0x08000607,
  // [04f0]
  0x0e302321, 0x19292709, 0x27001620, 0x38000f12,
  0x660306be, 0x0e3023ac, 0x01001907, 0x0e003011,
  0x10000407, 0x0000171c, 0x04001021, 0x0f1245a4,
  0x04001022, 0x03004311, 0x231c0e23, 0x12000607,
  // [0500]
  0x06172712, 0x040b0507, 0x040106a4, 0x06210108,
  0x3f000435, 0x66002112, 0x120c5112, 0x191d4011,
  0x3f002123, 0x27002914, 0x0b001807, 0x01002707,
  0x3f214013, 0x380801af, 0x1e002523, 0x0e251e22,
  // [0510]
  0x1e0e2507, 0x1e0e2312, 0x040d1707, 0x0e1e30a4,
  0x274045af, 0x251c1e08, 0x121d0cad, 0x0c120faf,
  0x0f0d3821, 0x06001911, 0x0d040612, 0x660f3f12,
  0x01191d07, 0x1f213f12, 0x01000c07, 0x38273fad,
  // [0520]
  0x1d401909, 0x29271909, 0x1d451212, 0x19002713,
  0x0f380da4, 0x06100207, 0x40121dbb, 0x38000d07,
  0x04272913, 0x40010507, 0x08000113, 0x250e2307,
  0x40001d21, 0x01004307, 0x19001f21, 0x40041821,
  // [0530]
  0x10000623, 0x0f001721, 0x380f0dac, 0x0d000f07,
  0x06270312, 0x00000c01, 0x0f002b02, 0x38001f12,
  0x451210ba, 0x12000c14, 0x19000307, 0x1c1e2514,
  0x0b0604af, 0x1d020307, 0x40451212, 0x40001622,
  // [0540]
  0x16001f14, 0x1f000113, 0x0c002b08, 0x27042b60,
  0x19000b12, 0x17660311, 0x00000301, 0x03006608,
  0x22001813, 0x1c002522, 0x0d380520, 0x29004013,
  0x231c0ebe, 0x051701a4, 0x16030607, 0x0e003014,
  // [0550]
  0x12292755, 0x190b0260, 0x38001902, 0x3f002913,
  0x1c300ea4, 0x1c0e1ea4, 0x21000112, 0x14000812,
  0x0000302d, 0x45004012, 0x04003f13, 0x29042260,
  0x45121d08, 0x22292712, 0x03000107, 0x30000e09,
  // [0560]
  0x231e0e55, 0x1c232512, 0x14002221, 0x19040507,
  0x19142bbe, 0x04222707, 0x224519af, 0x08002212,
  0x27002213, 0x12662b08, 0x221512af, 0x0b000308,
  0x66002212, 0x30000e08, 0x10000213, 0x121440be,
  // [0570]
  0x01220207, 0x1d082713, 0x1c302355, 0x00003f06,
  0x032b0112, 0x29272213, 0x0d430613, 0x03000407,
  0x380f0d20, 0x0e251c12, 0x01030608, 0x291606af,
  0x1d221712, 0x1d151421, 0x1c001e12, 0x271722af,
  // [0580]
  0x231e1c13, 0x03000b12, 0x1d004020, 0x0f0d3822,
  0x19001522, 0x25231c08, 0x06003f12, 0x10401709,
  0x1c1e2508, 0x0d0f1d09, 0x29002708, 0x251c0e22,
  0x1c0e2308, 0x0b380f02, 0x230e1e60, 0x231c0e12,
  // [0590]
  0x17000512, 0x100322ad, 0x03660baf, 0x14000b21,
  0x19142212, 0x0b000213, 0x03000614, 0x1c001e02,
  0x1c1e0e02, 0x66060313, 0x18030612, 0x03000612,
  0x1e002312, 0x00000d01, 0x03190d12, 0x030201a4,
  // [05a0]
  0x06036655, 0x0c1201af, 0x01031807, 0x12450121,
  0x0f001407, 0x18000612, 0x1c301e13, 0x1e251c14,
  0x12030108, 0x020b1909, 0x0e251c13, 0x1e000e08,
  0x01120c07, 0x661201bb, 0x231c0e21, 0x5c000723,
  // [05b0]
  0x10060ba4, 0x1e1c2522, 0x124501af, 0x1c002513,
  0x43660112, 0x0e233008, 0x0f002908, 0x064018a4,
  0x12402207, 0x0f030155, 0x121d4012, 0x451d40af,
  0x100b02ac, 0x07005c09, 0x22160d08, 0x100b0260,
  // [05c0]
  0x251c2307, 0x0e1e2521, 0x1d221760, 0x1c2325bc,
  0x1c000e12, 0x0c220112, 0x45120609, 0x66000612,
  0x25231c13, 0x14030620, 0x1d001207, 0x23000e22,
  0x0000452d, 0x02000b20, 0x40000c14, 0x2b000623,
  // [05d0]
  0x19002111, 0x30002311, 0x010f1709, 0x02060308,
  0x05003823, 0x0f211411, 0x03000113, 0x10001412,
  0x14005113, 0x400c45af, 0x450d1221, 0x0c0f08cf,
  0x05020b22, 0x0d4512af, 0x45661212, 0x011f0611,
  // [05e0]
  0x1d0c45af, 0x050d45af, 0x450d1212, 0x1d4045af,
  0x036616af, 0x0b0f0809, 0x1e002511, 0x080c1720,
  0x0d004523, 0x1d450c14, 0x401d17bb, 0x0c1d3faf,
  0x0c0d01a4, 0x050f01a4, 0x401d01af, 0x170801a4,
  // [05f0]
  0x382b0821, 0x45120daf, 0x0c4045af, 0x272129af,
  0x02011407, 0x161419af, 0x45401d6f, 0x06001414,
  0x231e2512, 0x030b0234, 0x450d1222, 0x401d45af,
  0x23003023, 0x0e251cbe, 0x080f01af, 0x04001908,
  // [0600]
  0x170605a4, 0x19000408, 0x06050307, 0x0f001f10,
  0x19000412, 0x1e233022, 0x291d22af, 0x04001914,
  0x25001c13, 0x17003823, 0x10001908, 0x40001d23,
  0x38221d22, 0x17222712, 0x0d221523, 0x060416af,
  // [0610]
  0x401d2912, 0x450c1d14, 0x0e1e3009, 0x02100b12,
  0x02000521, 0x06170512, 0x17190512, 0x30001c13,
  0x01000507, 0x06042207, 0x06052111, 0x2b220c13,
  0x100201a4, 0x1e000e23, 0x1e001c14, 0x18270caf,
  // [0620]
  0x04001608, 0x100817bc, 0x0c2b2255, 0x10170823,
  0x100851af, 0x0c002b34, 0x29002734, 0x10001709,
  0x10190307, 0x17105112, 0x1e250e14, 0x38000811,
  0x17002212, 0x1c002320, 0x18000c14, 0x0e233055,
  // [0630]
  0x08001723, 0x0f1d0112, 0x07005c20, 0x01052b12,
  0x27211934, 0x19001211, 0x04000f07, 0x01052211,
  0x036645af, 0x171008be, 0x271d21af, 0x0b000207,
  0x10081721, 0x08030507, 0x270f2112, 0x17050160,
  // [0640]
  0x15000813, 0x08101721, 0x211501af, 0x07005c08,
  0x0f0d3fbc, 0x06000b13, 0x19140411, 0x06000c07,
  0x170419a4, 0x020b0d12, 0x08041955, 0x0c001912,
  0x02000b02, 0x08000d11, 0x29002722, 0x2729026f,
  // [0650]
  0x02100b11, 0x06000308, 0x15060112, 0x66030614,
  0x03660609, 0x1d4540af, 0x0d000f14, 0x1e002534,
  0x1e1c2512, 0x0e1e2511, 0x05190420, 0x27000113,
  0x08660111, 0x1d004023, 0x0e003021, 0x1e232514,
  // [0660]
  0x30251e07, 0x25001c12, 0x0d010607, 0x25001c09,
  0x020c0611, 0x29002721, 0x23300e12, 0x08001712,
  0x19000c13, 0x17121609, 0x0e003002, 0x171f0811,
  0x1c002523, 0x170545a4, 0x0c000211, 0x0c004513,
  // [0670]
  0x0f190809, 0x0c001412, 0x06080509, 0x660c0112,
  0x0e252307, 0x15006622, 0x0d380f09, 0x14001013,
  0x45124008, 0x056612af, 0x1c002507, 0x17006613,
  0x27450c20, 0x230e1ebc, 0x080c4512, 0x0f380814,
  // [0680]
  0x1e1c0e14, 0x1c0e23a4, 0x380f0812, 0x450d0112,
  0x1c251e12, 0x06000c22, 0x15450334, 0x030c6633,
  0x38050108, 0x660c12af, 0x05031022, 0x142729af,
  0x06002207, 0x662101af, 0x25001c11, 0x032b6612,
  // [0690]
  0x22002b21, 0x10430112, 0x0b0208a4, 0x06100ba4,
  0x1d001812, 0x0f004508, 0x01000407, 0x08001820,
  0x03001920, 0x10190112, 0x14001920, 0x03000112,
  0x10000b23, 0x251c0ebc, 0x05010b12, 0x05430107,
  // [06a0]
  0x66000c21, 0x38190112, 0x01292760, 0x2b063f12,
  0x27036621, 0x100501af, 0x1e251c13, 0x21001412,
  0x06000307, 0x380f0dad, 0x031901af, 0x301e2307,
  0x25001c22, 0x06002b13, 0x170801af, 0x120603ad,
  // [06b0]
  0x19001d21, 0x14101da4, 0x45000313, 0x23002507,
  0x30002322, 0x231c2507, 0x0f183812, 0x0c012708,
  0x10140b60, 0x231c0e55, 0x66000508, 0x0b1002ad,
  0x02100b55, 0x0c002b11, 0x05000d13, 0x23251ea4,
  // [06c0]
  0x40001d08, 0x40171dad, 0x27000413, 0x0e251eaf,
  0x15451d6f, 0x1d152208, 0x14052b21, 0x020b1055,
  0x1d194508, 0x38050f14, 0x451d12af, 0x0f380d14,
  0x1c2523ac, 0x06001807, 0x14002b22, 0x12001d12,
  // [06d0]
  0x302325be, 0x1d002207, 0x04001808, 0x0c151708,
  0x0f000d23, 0x1d001212, 0x19000314, 0x0d0f01a4,
  0x01211807, 0x08001809, 0x0e251e07, 0x451d1212,
  0x02193faf, 0x120c2bbb, 0x12060809, 0x43170509,
  // [06e0]
  0x12451dbc, 0x45001d21, 0x04221412, 0x080366ad,
  0x4e003720, 0x1f001d20, 0x12001d13, 0x0c001812,
  0x01003f12, 0x0c062b07, 0x0d031812, 0x1c003008,
  0x0c0b1907, 0x03000c07, 0x14002b13, 0x17001912,
  // [06f0]
  0x060803af, 0x22002b11, 0x40001d07, 0x25230ea4,
  0x230e25a4, 0x00000b1c, 0x1e3023ad, 0x1e002309,
  0x01001f13, 0x06011aaf, 0x19001822, 0x0b2b1960,
  0x0504146f, 0x0d003f12, 0x1c252321, 0x30232507,
  // [0700]
  0x18002212, 0x143f5112, 0x01002b08, 0x272b0c60,
  0x04000221, 0x3f000113, 0x22000413, 0x08040b11,
  0x06000112, 0x1c251eaf, 0x380822bb, 0x12002107,
  0x0e231c07, 0x220801af, 0x1e003012, 0x301c2513,
  // [0710]
  0x06012b07, 0x01170860, 0x00000c0a, 0x0c001623,
  0x08003807, 0x040501af, 0x3f020baf, 0x29002212,
  0x1e1c2523, 0x1e1c2513, 0x251c0e21, 0x0c1712af,
  0x061918af, 0x1e3025a4, 0x15080512, 0x300e23af,
  // [0720]
  0x1d002212, 0x14001614, 0x1c00371f, 0x0b000209,
  0x231e0e12, 0x0e231caf, 0x12432b07, 0x04002207,
  0x2b006614, 0x40121da4, 0x380d0fa4, 0x1d403813,
  0x030801a4, 0x250e1c22, 0x01100460, 0x03061807,
  // [0730]
  0x05000109, 0x1e000e11, 0x3f2b1f21, 0x12450daf,
  0x230e1c14, 0x45401d12, 0x062b0d13, 0x0d2b0107,
  0x080501af, 0x08000407, 0x27012908, 0x18431411,
  0x1f3f2912, 0x381716bc, 0x08050111, 0x06001908,
  // [0740]
  0x0e1c2555, 0x1d384508, 0x02000d11, 0x06000511,
  0x14001821, 0x05010612, 0x06005113, 0x06292712,
  0x01451d12, 0x06192112, 0x01103821, 0x04000d08,
  0x06001422, 0x0c1745be, 0x04190112, 0x19222907,
  // [0750]
  0x191f04af, 0x01061faf, 0x05003f11, 0x01153fad,
  0x06292713, 0x300e2509, 0x020b2b21, 0x10002b11,
  0x23001c12, 0x0d1638af, 0x0f191212, 0x02001420,
  0x1d000421, 0x12003f20, 0x22001914, 0x220605af,
  // [0760]
  0x1e000e14, 0x0419166f, 0x220c3f13, 0x1e251c08,
  0x05173809, 0x100106ad, 0x1e000e02, 0x164001a4,
  0x45401214, 0x12000111, 0x1722196f, 0x15191609,
  0x1c003021, 0x0c041908, 0x012166a4, 0x1e230e08,
  // [0770]
  0x250e1e21, 0x12450c09, 0x380c4308, 0x10006608,
  0x21272909, 0x1c001e14, 0x16292712, 0x1c232513,
  0x020b1008, 0x0000060a, 0x1e253021, 0x430b0255,
  0x2b003f12, 0x03001207, 0x021d40a4, 0x16272923,
  // [0780]
  0x0000162d, 0x05003807, 0x00000f2d, 0x250e1c07,
  0x23002512, 0x251e1c12, 0x07005c1a, 0x45121d13,
  0x1c251ea4, 0x02000b07, 0x06101907, 0x06160109,
  0x23301e60, 0x231c0ebc, 0x22001807, 0x23003021,
  // [0790]
  0x45401208, 0x010810ad, 0x2b4501af, 0x1d29276f,
  0x12000d07, 0x10000b08, 0x1d004013, 0x1c1e25bc,
  0x0c062107, 0x08002907, 0x0f1608a4, 0x02000b14,
  0x10000613, 0x10020b55, 0x10150c07, 0x06105112,
  // [07a0]
  0x10161421, 0x451206ad, 0x12450d14, 0x02001007,
  0x66144060, 0x14040609, 0x1d401007, 0x1e300eaf,
  0x1d401813, 0x12100c08, 0x40450baf, 0x19660112,
  0x30232521, 0x1e30236f, 0x66020baf, 0x1d000333,
  // [07b0]
  0x45194011, 0x1d036620, 0x403f0160, 0x01100621,
  0x151622ac, 0x14272921, 0x1d454055, 0x16101508,
  0x450d14bc, 0x66000413, 0x0b006607, 0x45401d21,
  0x0e251cac, 0x23251e07, 0x25001c07, 0x0b160655,
  // [07c0]
  0x1d020b12, 0x25001e11, 0x10000408, 0x0e1e2513,
  0x1d004007, 0x19000302, 0x01002b13, 0x051516ac,
  0x27002909, 0x30230e08, 0x0c401212, 0x08002707,
  0x0d000113, 0x01052b55, 0x124518ad, 0x14004513,
  // [07d0]
  0x1c0e2355, 0x0e251c09, 0x04002212, 0x1f0f1812,
  0x12401daf, 0x1e251c6f, 0x181f0f60, 0x0b1d3f12,
  0x03290112, 0x1c0e2507, 0x0d180f07, 0x0f001814,
  0x180b1d12, 0x38000f14, 0x30001c12, 0x15005113,
  // [07e0]
  0x18001008, 0x03380509, 0x010319ad, 0x12000311,
  0x12001814, 0x45190460, 0x0f001821, 0x04001d08,
  0x04001421, 0x0c000113, 0x18380f12, 0x18040112,
  0x231e0e09, 0x12006607, 0x170501a4, 0x01170609,
  // [07f0]
  0x04061d09, 0x0c0f0112, 0x231e1caf, 0x1f0801af,
  0x18004507, 0x1d1901af, 0x19004008, 0x1c251e07,
  0x0e231ea4, 0x1e002502, 0x034512af, 0x01060cac,
  0x05380112, 0x10000614, 0x23001e20, 0x19451207,

  // [0800]
  0x23301e12, 0x19272912, 0x30000e22, 0x1e233021,
  0x0b001008, 0x1c002312, 0x4e003723, 0x2b001f23,
  0x22001808, 0x1e002313, 0x02002208, 0x03001708,
  0x06000c13, 0x19002207, 0x1e251caf, 0x10001611,
  // [0810]
  0x0d181fad, 0x0c006607, 0x04430108, 0x18224512,
  0x03003811, 0x1d2240af, 0x1d004507, 0x27291f21,
  0x1c230e12, 0x45000c02, 0x150621ad, 0x01121702,
  0x1f000d14, 0x02001407, 0x08150ca4, 0x231c30ac,
  // [0820]
  0x40001213, 0x0000140a, 0x0e233009, 0x170d0309,
  0x17000812, 0x010840a4, 0x14121907, 0x10002b07,
  0x06211212, 0x30251c09, 0x38101809, 0x05002b07,
  0x03000f12, 0x050d01af, 0x03001013, 0x04000107,
  // [0830]
  0x06180c09, 0x1c0e30bb, 0x18000b13, 0x1e0e2523,
  0x18001621, 0x23002522, 0x380117af, 0x06052b07,
  0x02000113, 0x0e302312, 0x012104a4, 0x01051fbb,
  0x18080b12, 0x04171812, 0x17080b12, 0x14170baf,
  // [0840]
  0x1c0e2314, 0x17272920, 0x0d061012, 0x10001411,
  0x1d004012, 0x2b001013, 0x180c3f12, 0x22001d08,
  0x0e231e12, 0x29002723, 0x05001707, 0x16003f13,
  0x1f001814, 0x16121507, 0x041f3f09, 0x30251c07,
  // [0850]
  0x25002307, 0x0c002912, 0x03272960, 0x06272955,
  0x02065112, 0x06001411, 0x036602be, 0x66031412,
  0x18401d22, 0x040c12af, 0x0b401d82, 0x291d1412,
  0x1d400baf, 0x0e001c11, 0x046603be, 0x040b0f12,
  // [0860]
  0x25000e14, 0x29270412, 0x0c0f3f60, 0x08003f11,
  0x2b011012, 0x03003807, 0x661f05bb, 0x3f0c0112,
  0x38000821, 0x1d400c11, 0x0c001620, 0x0f000212,
  0x06006607, 0x17000814, 0x231c0e60, 0x030666be,
  // [0870]
  0x0c001612, 0x19161407, 0x1940106f, 0x12450112,
  0x031f0512, 0x03046607, 0x10000113, 0x1c251ead,
  0x08120107, 0x0c001009, 0x0e002322, 0x01001207,
  0x37004e34, 0x14001813, 0x10020bbe, 0x23300e60,
  // [0880]
  0x251c0e55, 0x0b100609, 0x1c0e2502, 0x1c250e07,
  0x03011fa4, 0x03004008, 0x43450107, 0x0b023fad,
  0x1e230e07, 0x120d2122, 0x29002709, 0x0c401d09,
  0x45000202, 0x1e003014, 0x16002221, 0x38001d20,
  // [0890]
  0x0e1c3008, 0x0e251c07, 0x30000e12, 0x1c1e0e22,
  0x0e002512, 0x08000b07, 0x0d000f12, 0x231e30af,
  0x060114a4, 0x2b0f086f, 0x14100baf, 0x151612a4,
  0x22002708, 0x0c002209, 0x21082212, 0x380d0fbe,
  // [08a0]
  0x251c2309, 0x2b030112, 0x0d380112, 0x1e2530af,
  0x22292722, 0x0d081712, 0x1e1c0eaf, 0x0e1c25be,
  0x27381612, 0x40004508, 0x0f0d01af, 0x0f1701af,
  0x0f0d0108, 0x1c1e0e09, 0x18001f09, 0x05040112,
  // [08b0]
  0x0e1c2514, 0x06000412, 0x660801af, 0x15000f07,
  0x01000813, 0x66010c09, 0x451516af, 0x04022907,
  0x27000112, 0x0c040112, 0x052b4555, 0x662701af,
  0x661d4021, 0x120c0421, 0x010c1d07, 0x060115ad,
  // [08c0]
  0x27002922, 0x1d120c07, 0x01000c12, 0x66060420,
  0x66041421, 0x0b0c0107, 0x0c451208, 0x22000812,
  0x29001212, 0x251e1cbe, 0x661f3f13, 0x0c010f07,
  0x181d0412, 0x100212af, 0x03001607, 0x66000309,
  // [08d0]
  0x0c001207, 0x43002708, 0x050f0107, 0x15160421,
  0x2b1001af, 0x01030655, 0x04004008, 0x1e1c0e13,
  0x060110a4, 0x06001002, 0x25300eaf, 0x01001212,
  0x1c1e25be, 0x171812ad, 0x23301e21, 0x1c0e1e13,
  // [08e0]
  0x0000381c, 0x03000621, 0x380501a4, 0x01291908,
  0x012b2708, 0x060d03be, 0x00002142, 0x18000f21,
  0x1e0e2307, 0x10000612, 0x0d001823, 0x03003f13,
  0x0c061007, 0x041210ac, 0x08061d11, 0x10664511,
  // [08f0]
  0x0e003009, 0x40100b12, 0x1c0e2323, 0x0d380f07,
  0x0d083808, 0x06002212, 0x1f002b12, 0x0e233013,
  0x0d000c07, 0x1d000207, 0x45120fa4, 0x23003020,
  0x30230e12, 0x10001d09, 0x1c300e12, 0x080c0112,
  // [0900]
  0x45001602, 0x0d080112, 0x23002514, 0x1d0c2b12,
  0x041f0112, 0x290604af, 0x0d454021, 0x16150814,
  0x0c1040a4, 0x0b290109, 0x231e30a4, 0x401d1922,
  0x40001d35, 0x01050c07, 0x2b002221, 0x0c001513,
  // [0910]
  0x121d4512, 0x170d0f09, 0x251c1e07, 0x19003f12,
  0x1d0c166f, 0x29002213, 0x2b004020, 0x04100b20,
  0x120c4520, 0x19043fac, 0x451812ad, 0x23301c07,
  0x30230e21, 0x15004013, 0x04004012, 0x03001f12,
  // [0920]
  0x1e002308, 0x66031f12, 0x40001508, 0x25001c08,
  0x301e2309, 0x1c251e60, 0x0b001907, 0x12101955,
  0x14000d09, 0x01051607, 0x01293f12, 0x05292760,
  0x020b1908, 0x0e002521, 0x03161f12, 0x0f0201af,
  // [0930]
  0x29001834, 0x27002936, 0x0b001911, 0x0d0f0555,
  0x15221609, 0x0b0319a4, 0x0f0d0512, 0x1e003007,
  0x03001612, 0x17000113, 0x66042260, 0x22001612,
  0x301c0ead, 0x22006621, 0x38181712, 0x19002213,
  // [0940]
  0x2b000622, 0x22000414, 0x2b3805be, 0x22002713,
  0x1d001620, 0x0000042d, 0x17001812, 0x12001611,
  0x04220122, 0x016603bc, 0x030806ad, 0x04005113,
  0x01000811, 0x04001422, 0x2b1006af, 0x04082221,
  // [0950]
  0x1d22156f, 0x210f3821, 0x3f000121, 0x272204bb,
  0x01433fad, 0x00001d2d, 0x1c002314, 0x10020112,
  0x3f004313, 0x03000634, 0x0f430d07, 0x12450c12,
  0x08030421, 0x02380baf, 0x27005113, 0x042201af,
  // [0960]
  0x011904af, 0x190104af, 0x1d003f12, 0x1d001611,
  0x0b0222ad, 0x1c230eaf, 0x293f4060, 0x01402220,
  0x12431d07, 0x30001e09, 0x1d020c09, 0x19002b07,
  0x45120c13, 0x0e1e2507, 0x012b1908, 0x17000507,
  // [0970]
  0x01181508, 0x0b001014, 0x060f0108, 0x0e1c23a4,
  0x1c230e08, 0x02000308, 0x14001f14, 0x03000102,
  0x0c001707, 0x231e2509, 0x430d0109, 0x0c124555,
  0x12010c09, 0x1e251cad, 0x10002b21, 0x032251af,
  // [0980]
  0x19001807, 0x100215a4, 0x180d0b12, 0x17000407,
  0x141821a4, 0x15181712, 0x1d051f12, 0x08036609,
  0x251c0e14, 0x02660322, 0x251e1ca4, 0x0e001e08,
  0x0c401512, 0x0d001713, 0x080c4507, 0x30231e21,
  // [0990]
  0x06001507, 0x66000321, 0x17080f09, 0x1e1c2502,
  0x1d002221, 0x02220baf, 0x062b2112, 0x100b0221,
  0x19020655, 0x38000511, 0x04006612, 0x01001420,
  0x12004522, 0x436605ad, 0x06020112, 0x02192b14,
  // [09a0]
  0x23003002, 0x29100baf, 0x12150507, 0x08003822,
  0x1c252311, 0x011d1408, 0x1c0e2522, 0x25002312,
  0x1c252314, 0x2b002122, 0x0b140dbb, 0x2b020112,
  0x1e252312, 0x0c0801a4, 0x0f000d07, 0x2b000d14,
  // [09b0]
  0x4045126f, 0x23300e07, 0x40061212, 0x061912af,
  0x011d4011, 0x230e1ead, 0x062b0dad, 0x18401213,
  0x06190d21, 0x0f000607, 0x1c1e23a4, 0x1d000c07,
  0x2b2166af, 0x0c381213, 0x170d12af, 0x0c002b13,
  // [09c0]
  0x0b021007, 0x16180d12, 0x23001e08, 0x1e000e07,
  0x231e2560, 0x1c300e02, 0x181d0d12, 0x0d180baf,
  0x400d0c14, 0x10001423, 0x400d12af, 0x1d4012af,
  0x40121dad, 0x1d0c1212, 0x0c0612af, 0x01002107,
  // [09d0]
  0x400f4509, 0x01150c08, 0x0c010508, 0x1c233008,
  0x1d401613, 0x0b0c0f55, 0x160c4021, 0x251c3021,
  0x04026607, 0x231c1ea4, 0x0e231e08, 0x16184509,
  0x160c1509, 0x1e1c2560, 0x40003f11, 0x121d45af,
  // [09e0]
  0x173801a4, 0x3f211621, 0x16000413, 0x03180655,
  0x041916a4, 0x23251c11, 0x0f003f12, 0x04001923,
  0x30001e12, 0x211d1709, 0x011d2909, 0x17003f21,
  0x0b010ca4, 0x0f080d08, 0x06171909, 0x1c000e14,
  // [09f0]
  0x0000142d, 0x0d010c11, 0x66000323, 0x04451812,
  0x190d17ac, 0x10006607, 0x45121612, 0x1d174011,
  0x0c000620, 0x45000c20, 0x0c124513, 0x01123f12,
  0x191002ac, 0x1e0e1ca4, 0x251c1ebe, 0x18000220,
  // [0a00]
  0x40001d22, 0x18124012, 0x0c001007, 0x14181011,
  0x06400107, 0x12004011, 0x0c1840ad, 0x12060ca4,
  0x08061faf, 0x0d384012, 0x19011f12, 0x1e251c12,
  0x450c4008, 0x19030613, 0x27223f14, 0x01000421,
  // [0a10]
  0x0e001e02, 0x06001f12, 0x01080414, 0x231c0e09,
  0x401f0108, 0x1e0e3009, 0x301c0e08, 0x17060108,
  0x01043f20, 0x17001f21, 0x2b0501af, 0x27082113,
  0x17000107, 0x0d0c0808, 0x01006613, 0x0e1c2307,
  // [0a20]
  0x38140111, 0x1e251c21, 0x011708a4, 0x25002308,
  0x1c250e08, 0x663f01af, 0x0f196660, 0x01036611,
  0x0f003823, 0x300e1ebc, 0x03020607, 0x231c25af,
  0x23000e21, 0x17000807, 0x181d3f12, 0x0d2901af,
  // [0a30]
  0x451d1214, 0x300e2307, 0x1c000e08, 0x0f003814,
  0x030801ad, 0x380f0d14, 0x0d0f2122, 0x0d2b0fbe,
  0x29273faf, 0x12100207, 0x02100baf, 0x45151402,
  0x1d404507, 0x01292712, 0x230e1e07, 0x0e1e2308,
  // [0a40]
  0x0f000d13, 0x082901af, 0x221514be, 0x080d0f60,
  0x0f000307, 0x01000808, 0x020c0107, 0x0e002335,
  0x29002b12, 0x0d000f22, 0x1d154009, 0x450f0da4,
  0x21002b12, 0x21001812, 0x15452b12, 0x1f2b08af,
  // [0a50]
  0x19101612, 0x0d0f0409, 0x0c004512, 0x15062212,
  0x01001912, 0x22001812, 0x160c1212, 0x2b002209,
  0x272922af, 0x0e251c6f, 0x29270121, 0x1c0e3014,
  0x06031807, 0x0c000107, 0x04001213, 0x45001007,
  // [0a60]
  0x162215cf, 0x23000e12, 0x1c231e07, 0x19002209,
  0x06000407, 0x04001023, 0x300e23a4, 0x0b061907,
  0x25231caf, 0x01080508, 0x04001902, 0x020f18ad,
  0x1c1e2312, 0x16000412, 0x15001812, 0x04001612,
  // [0a70]
  0x160415be, 0x15000422, 0x01003f11, 0x300e1e08,
  0x66150cbe, 0x06000411, 0x15000c22, 0x041d12af,
  0x0c001514, 0x14002b09, 0x15170c13, 0x0b001f12,
  0x042b01ac, 0x010f0d21, 0x15004513, 0x23000e23,
  // [0a80]
  0x40013fa4, 0x160c66a4, 0x1c231ead, 0x19000612,
  0x04100612, 0x27291612, 0x0e002508, 0x29222113,
  0x14001008, 0x0c004511, 0x01161f12, 0x0f000508,
  0x231c30ad, 0x01052909, 0x01000411, 0x10040860,
  // [0a90]
  0x120c45af, 0x04000609, 0x050d2712, 0x230e3013,
  0x06000409, 0x1829216f, 0x0e3023af, 0x0f001d08,
  0x08012907, 0x03000111, 0x38000412, 0x0f1d0411,
  0x0000032d, 0x231c1e07, 0x40003f20, 0x010c1812,
  // [0aa0]
  0x0b0201af, 0x0e1e3007, 0x19401d07, 0x06143fad,
  0x381f0108, 0x22003f13, 0x272916be, 0x020b2ba4,
  0x0c030608, 0x1f0506bb, 0x142b1fad, 0x27402112,
  0x060d1921, 0x06000322, 0x2927226f, 0x0f000612,
  // [0ab0]
  0x29270112, 0x400601a4, 0x0d002b08, 0x0f001f12,
  0x06451214, 0x14000113, 0x380f0dbe, 0x02100caf,
  0x1d1640be, 0x152101af, 0x250e1c6f, 0x1d001911,
  0x05001713, 0x01660612, 0x02060112, 0x03450112,
  // [0ac0]
  0x22000613, 0x27001412, 0x0c222113, 0x010c2260,
  0x06004509, 0x0f001f11, 0x0e002520, 0x23000e20,
  0x10000412, 0x1c1e0e07, 0x450114ad, 0x38010f09,
  0x251c0e11, 0x170d3812, 0x38002b23, 0x19003813,
  // [0ad0]
  0x17003821, 0x1d010c07, 0x05012121, 0x05003814,
  0x272921af, 0x0c002112, 0x191004a4, 0x0d003820,
  0x16004014, 0x0600100c, 0x380f0107, 0x0d003811,
  0x1d2927af, 0x300e1e12, 0x0d003814, 0x17380dbc,
  // [0ae0]
  0x250e3008, 0x04121d09, 0x04221922, 0x04221921,
  0x12001712, 0x04000113, 0x0e232509, 0x050d3820,
  0x16081212, 0x0d003821, 0x03170823, 0x172b38bc,
  0x272901a4, 0x1e251c07, 0x451d4012, 0x00005c0a,
  // [0af0]
  0x01451209, 0x0b042212, 0x301c2311, 0x06190112,
  0x300e1caf, 0x02000b12, 0x17000413, 0x0d2729ad,
  0x12173f12, 0x0d002120, 0x30000e11, 0x1c003012,
  0x190f0d60, 0x38101621, 0x0c001211, 0x0d0501af,
  // [0b00]
  0x06000111, 0x0f2708ad, 0x0f082112, 0x1c000e20,
  0x171d4021, 0x060103ad, 0x1d171212, 0x3f011fbc,
  0x1c002313, 0x18000108, 0x04213821, 0x38163fa4,
  0x1e1c23af, 0x06101808, 0x22001723, 0x10000611,
  // [0b10]
  0x14002b14, 0x171801af, 0x06001009, 0x0c002709,
  0x10000609, 0x120c4512, 0x401d21a4, 0x10010608,
  0x1c000e23, 0x2b004313, 0x1e002520, 0x0c001f12,
  0x06001014, 0x010d03a4, 0x1e002507, 0x04001007,
  // [0b20]
  0x066601af, 0x0d002707, 0x10060c09, 0x12451dad,
  0x04001013, 0x0c1640af, 0x12062907, 0x0e251e08,
  0x40001d09, 0x101701af, 0x291014be, 0x06011207,
  0x06290109, 0x14000608, 0x12161d07, 0x14000d20,
  // [0b30]
  0x06020b12, 0x18001408, 0x14120d22, 0x011d03a4,
  0x01102712, 0x06000b07, 0x430d1fbe, 0x02061f12,
  0x16101f11, 0x66141f21, 0x16124513, 0x181f4312,
  0x04380f08, 0x0d1f4321, 0x12451f21, 0x08020b12,
  // [0b40]
  0x12000402, 0x1f001422, 0x66050121, 0x0b101607,
  0x250e1caf, 0x23002502, 0x40001507, 0x451218bc,
  0x0c001608, 0x0f171d08, 0x06030207, 0x0d001412,
  0x0000382d, 0x18000d13, 0x06181407, 0x03000214,
  // [0b50]
  0x050118a4, 0x22000112, 0x060d0107, 0x0c001621,
  0x0c001622, 0x06386608, 0x10000b14, 0x18100222,
  0x2b000108, 0x0e1c1ea4, 0x10011408, 0x01006610,
  0x25231e14, 0x21000108, 0x060c0f11, 0x123f1412,
  // [0b60]
  0x0c212712, 0x0c000623, 0x03050112, 0x21003f12,
  0x05292711, 0x03060c07, 0x0c150321, 0x141810af,
  0x661003be, 0x27290812, 0x66000c08, 0x0c006612,
  0x40001d11, 0x45060c60, 0x0f051521, 0x15044512,
  // [0b70]
  0x0c000622, 0x27002921, 0x1f036612, 0x100b08ac,
  0x02100b13, 0x1c003011, 0x251e3007, 0x29000112,
  0x00001f0a, 0x29270421, 0x0000052d, 0x07005c22,
  0x00002b2d, 0x43003821, 0x12004511, 0x16000422,
  // [0b80]
  0x0f0d1212, 0x141f0d13, 0x38003f12, 0x29271921,
  0x19002b20, 0x06001207, 0x45051f12, 0x14001f35,
  0x02401d12, 0x2b380112, 0x12184311, 0x173801af,
  0x1f123821, 0x06000220, 0x03000613, 0x0429276f,
  // [0b90]
  0x0c002b12, 0x290427be, 0x08001722, 0x10020bac,
  0x0b006611, 0x17000108, 0x19401211, 0x1e1c2521,
  0x1c1e0e08, 0x0b000220, 0x19401212, 0x30230e07,
  0x25001c21, 0x060301af, 0x0f100112, 0x16000414,
  // [0ba0]
  0x100c04ad, 0x16000812, 0x38011211, 0x173801ad,
  0x06000108, 0x0d080f6f, 0x0f0c0812, 0x012718ad,
  0x40000c13, 0x03001608, 0x060b01ac, 0x16002112,
  0x2b450112, 0x02000b11, 0x18000608, 0x231c3012,
  // [0bb0]
  0x06141812, 0x1c1e2507, 0x0c141660, 0x14120c11,
  0x04401d07, 0x19000409, 0x0d380faf, 0x14001d13,
  0x181201a4, 0x1e000e12, 0x12000c07, 0x25231e07,
  0x080501a4, 0x01060c07, 0x0e251ead, 0x030d0655,
  // [0bc0]
  0x1c0e1e08, 0x04161daf, 0x06001011, 0x06042b12,
  0x01162208, 0x0c1245af, 0x0f001012, 0x22002707,
  0x10002b12, 0x21041921, 0x05040107, 0x1f0d0112,
  0x032901a4, 0x10020109, 0x0f0838ad, 0x0000062d,
  // [0bd0]
  0x0f1d21ce, 0x0f063807, 0x021722a4, 0x29010309,
  0x0f001f1d, 0x1d160112, 0x080f3fac, 0x14001f12,
  0x03062b07, 0x22272911, 0x0f0d1714, 0x1c1e2555,
  0x19151d14, 0x193f1422, 0x0d0129ad, 0x05000314,
  // [0be0]
  0x0c001920, 0x03051f6f, 0x031f05bc, 0x15161d09,
  0x29001f21, 0x150c0112, 0x29221521, 0x21292782,
  0x45291509, 0x100106a4, 0x291551af, 0x0d401513,
  0x401d1508, 0x06030507, 0x1d1615a4, 0x03060507,
  // [0bf0]
  0x0c221913, 0x1d401f09, 0x05001f34, 0x292705bc,
  0x29151daf, 0x05000112, 0x1d451255, 0x27032913,
  0x270d15af, 0x061529af, 0x0b000212, 0x221929a4,
  0x060c1612, 0x0b001009, 0x0c151607, 0x0c276612,

  // [0c00]
  0x0c001609, 0x1c0e23bb, 0x0e231c09, 0x27661509,
  0x0d030612, 0x0d0603a4, 0x17000f21, 0x0f000113,
  0x1d000311, 0x45000c22, 0x18000113, 0x01001f11,
  0x01030607, 0x06000309, 0x02160107, 0x01020b07,
  // [0c10]
  0x0b0201a4, 0x030b0207, 0x03080107, 0x020b0c13,
  0x030c12af, 0x18060c21, 0x1f050112, 0x02100b08,
  0x10180b09, 0x06001812, 0x401d4512, 0x05001f12,
  0x1c1e0e12, 0x230e3012, 0x16040112, 0x0c000612,
  // [0c20]
  0x251e3021, 0x14001f07, 0x0f0d1f55, 0x0f001f13,
  0x0d001f12, 0x431f3f6f, 0x06036613, 0x29013f09,
  0x27011d08, 0x1f001d14, 0x1d012108, 0x300e1e13,
  0x27001413, 0x01020b55, 0x0b061007, 0x0e302302,
  // [0c30]
  0x23001c08, 0x1c002308, 0x1d190f55, 0x660b04a4,
  0x08141008, 0x301c25af, 0x291f1912, 0x2b002912,
  0x01402bad, 0x23300e14, 0x03196621, 0x45001413,
  0x030619af, 0x10000c13, 0x03661913, 0x19660309,
  // [0c40]
  0x08012bac, 0x08002b07, 0x181766af, 0x19002b09,
  0x5c000709, 0x251c1e14, 0x38190d14, 0x010b3fa4,
  0x19002907, 0x1d0c19a4, 0x01182ba4, 0x120d0109,
  0x23001e02, 0x0b000411, 0x00000b01, 0x0d0f2912,
  // [0c50]
  0x01190407, 0x020466a4, 0x03012109, 0x30001e13,
  0x66002b22, 0x23001c11, 0x19004507, 0x38000f20,
  0x19000422, 0x19003f11, 0x17380112, 0x0e1c2512,
  0x050f0112, 0x1d124509, 0x0c000108, 0x40124513,
  // [0c60]
  0x19003f20, 0x0f27296f, 0x301c1e12, 0x036604ad,
  0x08001207, 0x19040fa4, 0x45000412, 0x0d121d14,
  0x251c23a4, 0x061904a4, 0x01004302, 0x100b0214,
  0x1d123f12, 0x45401212, 0x0e2330af, 0x08401da4,
  // [0c70]
  0x05010f07, 0x1c0e2312, 0x14001d07, 0x12451d09,
  0x16001011, 0x021d2207, 0x22002912, 0x06001012,
  0x01032107, 0x221d4007, 0x23251c55, 0x1d270411,
  0x1e252309, 0x160b1509, 0x0b001834, 0x18001411,
  // [0c80]
  0x15001620, 0x1d012912, 0x22002711, 0x00000b2d,
  0x16002b08, 0x0c001613, 0x0b101912, 0x0c4501ad,
  0x451d1213, 0x0c001611, 0x19006620, 0x00000403,
  0x06002b21, 0x19000421, 0x0b001411, 0x03066614,
  // [0c90]
  0x053801af, 0x0e231e07, 0x1f001414, 0x25302313,
  0x0e001e20, 0x21001909, 0x1e251c60, 0x10061912,
  0x0d000f13, 0x03002107, 0x0e1e2307, 0x08290608,
  0x1e000e21, 0x031906a4, 0x19001008, 0x1d2b15af,
  // [0ca0]
  0x19001011, 0x22272907, 0x0d060109, 0x12001512,
  0x160d0809, 0x100b4009, 0x29192712, 0x05100813,
  0x0c120107, 0x08161d14, 0x16031907, 0x1c251e14,
  0x400f0812, 0x1e253012, 0x100406ad, 0x020b10af,
  // [0cb0]
  0x0e251e09, 0x12001f12, 0x1d151609, 0x0f084012,
  0x17001f07, 0x0f0d0809, 0x010f0da4, 0x21004022,
  0x18001d08, 0x1e002521, 0x25231c11, 0x020b51af,
  0x40451260, 0x40004522, 0x06041512, 0x0b001013,
  // [0cc0]
  0x0e301cad, 0x0c002707, 0x01080b12, 0x15401d09,
  0x293f27af, 0x2b010508, 0x0b036613, 0x40003f35,
  0x140410af, 0x181d0612, 0x45004014, 0x38000613,
  0x03010607, 0x12004013, 0x16193f13, 0x10081908,
  // [0cd0]
  0x17001d12, 0x18041920, 0x03140611, 0x12041909,
  0x16001513, 0x27060412, 0x27153f60, 0x02161521,
  0x02000b23, 0x08001f21, 0x3f001921, 0x45000611,
  0x1e301c11, 0x14001612, 0x29271908, 0x100819ac,
  // [0ce0]
  0x01290512, 0x181904ad, 0x66102b12, 0x45000113,
  0x0d210112, 0x0d0f17a4, 0x18404512, 0x18004514,
  0x400106ad, 0x061d45af, 0x19062207, 0x144504bb,
  0x23251ebe, 0x0b000612, 0x17040112, 0x190801af,
  // [0cf0]
  0x0f001208, 0x101d6608, 0x231c1e21, 0x382927af,
  0x16062b21, 0x381901af, 0x05450109, 0x05000f07,
  0x0c060baf, 0x3f002b21, 0x1c2523af, 0x1900060b,
  0x231c2522, 0x05002b08, 0x30001e08, 0x221d4013,
  // [0d00]
  0x012b1a12, 0x27290d09, 0x0c1d12ad, 0x21002b22,
  0x293f1809, 0x0000122d, 0x27293f21, 0x16211922,
  0x1e1c0e11, 0x0c001911, 0x19002133, 0x27292bbc,
  0x17002b12, 0x0f150daf, 0x40121d13, 0x1f000813,
  // [0d10]
  0x054301ad, 0x19003f14, 0x1e1c3055, 0x190f2121,
  0x0f161921, 0x66002b11, 0x01000308, 0x10000b21,
  0x10020612, 0x080c0307, 0x380d0520, 0x0c2927af,
  0x0c3f27af, 0x270c3faf, 0x02103807, 0x1e231ca4,
  // [0d20]
  0x04292760, 0x0d022b60, 0x1e1c0ead, 0x0f192112,
  0x06000c08, 0x27002923, 0x402b2908, 0x27293f22,
  0x0d0f0109, 0x380f0d09, 0x29000c13, 0x02000b21,
  0x21272921, 0x080d01af, 0x19021007, 0x29000c20,
  // [0d30]
  0x1804226f, 0x0c272920, 0x223829af, 0x0c1729a4,
  0x04190655, 0x21292709, 0x060801a4, 0x0b190155,
  0x18002b13, 0x19272911, 0x050801a4, 0x0f0d2b12,
  0x0e001c02, 0x0b021009, 0x0e251ea4, 0x2b006620,
  // [0d40]
  0x03002207, 0x22000c13, 0x03022213, 0x38192107,
  0x210b29af, 0x19100baf, 0x12001808, 0x03162b55,
  0x40001907, 0x17060d13, 0x06000408, 0x251c2355,
  0x25302314, 0x400c2b07, 0x04001f12, 0x66002b12,
  // [0d50]
  0x2b060c09, 0x05012212, 0x10380112, 0x0d0c0612,
  0x17000c08, 0x45000c12, 0x1e003021, 0x0c4512af,
  0x0f1f1712, 0x12050113, 0x121f0112, 0x231c25be,
  0x05220812, 0x1d002b12, 0x0b002713, 0x0f001912,
  // [0d60]
  0x17001d14, 0x0c150112, 0x0d404512, 0x2b011212,
  0x450c12a4, 0x053801a4, 0x29002b23, 0x0f0d01a4,
  0x100d0212, 0x38270cbb, 0x02101821, 0x0f081721,
  0x01041f12, 0x40122212, 0x036606be, 0x0b050160,
  // [0d70]
  0x40451213, 0x17004513, 0x2b000c14, 0x12041721,
  0x0c050112, 0x14002b12, 0x0c081f6f, 0x01661508,
  0x0f451712, 0x041917af, 0x0e251ca4, 0x050317a4,
  0x1d451208, 0x30251c13, 0x1d124508, 0x301c0e07,
  // [0d80]
  0x45401dad, 0x21220c60, 0x120c1d60, 0x150f3809,
  0x19001608, 0x1d001807, 0x293f2712, 0x1e1c0ebc,
  0x231e2513, 0x27293f12, 0x25301e60, 0x0f2b3808,
  0x10661daf, 0x0d0f0823, 0x14190433, 0x19041012,
  // [0d90]
  0x401d0812, 0x04001607, 0x0d000512, 0x19220412,
  0x08140b12, 0x06052709, 0x3f100b09, 0x0c190412,
  0x45001d12, 0x451d0cad, 0x664301a4, 0x30001c11,
  0x10001812, 0x210b01af, 0x1f1929af, 0x08382208,
  // [0da0]
  0x101914be, 0x29010c08, 0x0c0104af, 0x04002b09,
  0x231c0eaf, 0x03010507, 0x25000e13, 0x04061007,
  0x05270b12, 0x301e2508, 0x301c23a4, 0x07005c23,
  0x0c002b09, 0x38290108, 0x14162208, 0x1c300e07,
  // [0db0]
  0x08003f12, 0x1d1645bb, 0x10001813, 0x150c04bb,
  0x0d020f12, 0x38001409, 0x03000609, 0x1e302307,
  0x2b001911, 0x15000107, 0x16001d07, 0x06002107,
  0x06000c09, 0x661d3f12, 0x03001809, 0x18000c21,
  // [0dc0]
  0x380f2b12, 0x120b0609, 0x2b000f21, 0x06100407,
  0x66000d12, 0x430d0508, 0x1d012911, 0x05002b11,
  0x060305bc, 0x01402712, 0x10000608, 0x052701af,
  0x451d1512, 0x05001223, 0x010b0260, 0x1d6640be,
  // [0dd0]
  0x17080102, 0x2b0f08af, 0x0c001208, 0x0d0f0112,
  0x01032907, 0x1d001509, 0x400f2b09, 0x020b0612,
  0x0e1c23be, 0x40451214, 0x15080521, 0x0d1d0112,
  0x12164512, 0x01003802, 0x0c000112, 0x08000421,
  // [0de0]
  0x22181907, 0x660b0409, 0x15001f11, 0x04190613,
  0x45001202, 0x0e1c2313, 0x080604a4, 0x061951af,
  0x1d001208, 0x251c1eaf, 0x0c190b13, 0x191d406f,
  0x0b021013, 0x231c2514, 0x04010bac, 0x12454013,
  // [0df0]
  0x251c0e13, 0x05000413, 0x05101407, 0x15002221,
  0x05000412, 0x0f050102, 0x060b6612, 0x06151914,
  0x3f000414, 0x19010612, 0x27061912, 0x01170bbc,
  0x1c0e1e02, 0x1e233007, 0x0b000633, 0x15061412,
  // [0e00]
  0x06011412, 0x19004007, 0x231c1ead, 0x100614a4,
  0x38050412, 0x0b001407, 0x0b060209, 0x012914bc,
  0x04051908, 0x45003f11, 0x2b001920, 0x1c002323,
  0x0d0f3820, 0x010622ac, 0x221d4512, 0x013f1f60,
  // [0e10]
  0x0c224012, 0x231e30ac, 0x221d40af, 0x2b026612,
  0x2b404511, 0x1d001502, 0x1c2523a4, 0x3f1617bc,
  0x01002b11, 0x010d1f12, 0x251c0ead, 0x1d001f07,
  0x04004507, 0x45001d07, 0x03001007, 0x401d4513,
  // [0e20]
  0x17004507, 0x40180360, 0x00000715, 0x12000c13,
  0x1d0c4512, 0x1d001720, 0x18001013, 0x1d044012,
  0x18001011, 0x10401d22, 0x0c001d07, 0x19000435,
  0x0d003823, 0x43002913, 0x1f061020, 0x3f000613,
  // [0e30]
  0x6606036f, 0x40000307, 0x66000222, 0x03004009,
  0x010f0821, 0x0f080112, 0x2b004312, 0x0e2523af,
  0x041245a4, 0x0b020107, 0x180d1521, 0x1e3023a4,
  0x08000307, 0x020629af, 0x0f660309, 0x25000e07,
  // [0e40]
  0x1e302308, 0x230e1ea4, 0x04002b08, 0x06051709,
  0x1e001c12, 0x02001607, 0x01002b14, 0x16000b13,
  0x04001713, 0x0b051209, 0x22001821, 0x231e25a4,
  0x2b0b0220, 0x251c0e07, 0x183f0112, 0x19041755,
  // [0e50]
  0x01041712, 0x0d000f09, 0x400c1609, 0x16041521,
  0x0b011907, 0x124504af, 0x15401daf, 0x0f000d22,
  0x150866ad, 0x0c401dad, 0x0c064509, 0x0f0d17a4,
  0x05170f08, 0x25300e08, 0x3000371d, 0x02001412,
  // [0e60]
  0x0e1e2514, 0x121d0c07, 0x10002213, 0x12002b07,
  0x1c1e0ea4, 0x190d1d08, 0x450b12a4, 0x16004022,
  0x0d0f08be, 0x10000f13, 0x0f000812, 0x01191d12,
  0x0f0d0814, 0x0000402d, 0x02001411, 0x45120c23,
  // [0e70]
  0x2b0d0112, 0x0e231c13, 0x27052109, 0x0d000b07,
  0x14061011, 0x0d000f23, 0x30251ca4, 0x1e230e12,
  0x1400101f, 0x030c01a4, 0x02182111, 0x1966036f,
  0x30002507, 0x0b012912, 0x30002334, 0x01030ca4,
  // [0e80]
  0x19000d07, 0x100801af, 0x030d0521, 0x190d51af,
  0x66030baf, 0x4e003735, 0x03001507, 0x401d3fbb,
  0x1e002522, 0x1c1e0ebc, 0x22002111, 0x18001911,
  0x0c001807, 0x66031913, 0x1d0427af, 0x16004511,
  // [0e90]
  0x01190808, 0x0e1c25af, 0x041901af, 0x040b0209,
  0x01272912, 0x04001912, 0x066614ad, 0x1d120107,
  0x0c060160, 0x042927af, 0x0f060509, 0x12010607,
  0x400c1209, 0x01000302, 0x02451208, 0x1d004514,
  // [0ea0]
  0x0d121d07, 0x401d1212, 0x25301c07, 0x150c06af,
  0x40003f12, 0x45124021, 0x1c002512, 0x0c124509,
  0x1e1c3012, 0x301e0e08, 0x1d1901ac, 0x0d0f1807,
  0x121d0c09, 0x29000120, 0x450c1213, 0x23250e07,
  // [0eb0]
  0x1e001c11, 0x1f6603af, 0x0d171921, 0x0c000607,
  0x041019ad, 0x454001a4, 0x15001213, 0x401d1613,
  0x0b035112, 0x06010ba4, 0x18000c13, 0x03061d14,
  0x0f3801a4, 0x100b0209, 0x0b660212, 0x660b02be,
  // [0ec0]
  0x172b0111, 0x0f380d23, 0x06000313, 0x081f0112,
  0x0f4501af, 0x27000c12, 0x03006635, 0x060f6621,
  0x2b000412, 0x060301ad, 0x18003f14, 0x10013f12,
  0x01000612, 0x301e0e12, 0x40271d21, 0x1d222707,
  // [0ed0]
  0x02170112, 0x040b1007, 0x0c002713, 0x041951af,
  0x0b021907, 0x0c000412, 0x19001408, 0x041019a4,
  0x10022ba4, 0x10000522, 0x1e2530ac, 0x180f0811,
  0x22052b12, 0x05173834, 0x0000082d, 0x06220411,
  // [0ee0]
  0x1d001712, 0x38122912, 0x21161511, 0x19662714,
  0x0b220c55, 0x1d214009, 0x10000202, 0x23002508,
  0x0c103f11, 0x380b0112, 0x14001f20, 0x21002214,
  0x0f124512, 0x45001813, 0x053f0860, 0x08000d09,
  // [0ef0]
  0x0f451207, 0x081915a4, 0x10020b08, 0x27003f12,
  0x0d002107, 0x1c233009, 0x0f0d4307, 0x05271460,
  0x08036608, 0x27291daf, 0x380f19bb, 0x0e301ea4,
  0x1c0e1eac, 0x1d0d0f07, 0x22002134, 0x272b2212,
  // [0f00]
  0x140f1fa4, 0x0f003808, 0x170f0d09, 0x38013f12,
  0x17001f12, 0x051f01a4, 0x18001f13, 0x0f004507,
  0x1f001813, 0x1c001e13, 0x01002207, 0x27000513,
  0x030601ad, 0x400c1d21, 0x0138066f, 0x12451d55,
  // [0f10]
  0x12451f23, 0x1f001812, 0x010c0f11, 0x0e001c21,
  0x0f000d12, 0x0f1d0108, 0x1f1001af, 0x0f1406bc,
  0x01041707, 0x18124512, 0x14192113, 0x45001222,
  0x08000507, 0x01000408, 0x0c101612, 0x03000513,
  // [0f20]
  0x02061d21, 0x05000107, 0x0e002320, 0x38001713,
  0x38000508, 0x0c081609, 0x04080c21, 0x1200180b,
  0x15001613, 0x03000508, 0x17190407, 0x04161913,
  0x1e1c25bb, 0x08162b13, 0x120c1d12, 0x0d041908,
  // [0f30]
  0x0d160fad, 0x06452b12, 0x38050307, 0x231e0e60,
  0x45002b14, 0x2b4506be, 0x0d0f1912, 0x19001021,
  0x10001912, 0x141d45af, 0x19001013, 0x19151612,
  0x18001412, 0x16000d22, 0x06000b12, 0x05000608,
  // [0f40]
  0x041f1daf, 0x18101460, 0x12001817, 0x030501af,
  0x22003f20, 0x1f004513, 0x05000614, 0x0b000211,
  0x2b004513, 0x12001812, 0x05012b07, 0x380501af,
  0x0d191013, 0x00003f2d, 0x0b002211, 0x14050baf,
  // [0f50]
  0x66002b13, 0x06000b22, 0x251e3034, 0x01000b21,
  0x230e3021, 0x06000312, 0x12403f21, 0x66032712,
  0x1d003f21, 0x40191d11, 0x100b1407, 0x2b001822,
  0x0e1c23af, 0x12404512, 0x2b660320, 0x29210460,
  // [0f60]
  0x0f0d1607, 0x04000511, 0x45152212, 0x0f0d0507,
  0x12000d20, 0x0c150255, 0x05000f02, 0x0f0d18af,
  0x04121612, 0x15292760, 0x100419a4, 0x16272921,
  0x0c042112, 0x14000d08, 0x140b06a4, 0x0b180613,
  // [0f70]
  0x1c1e0e21, 0x153f1409, 0x06226621, 0x1d043f11,
  0x06100b12, 0x0000662d, 0x276617bc, 0x02186613,
  0x1e0e2508, 0x16063f08, 0x19000411, 0x12000f07,
  0x12020107, 0x10010308, 0x19100409, 0x4e003734,
  // [0f80]
  0x03660412, 0x12001d08, 0x250e1ca4, 0x04000313,
  0x19380509, 0x0d003809, 0x27660312, 0x0000180a,
  0x19210312, 0x27190412, 0x04001d12, 0x01001011,
  0x04660311, 0x046619af, 0x401d1708, 0x0e1e3002,
  // [0f90]
  0x17002b09, 0x031f0609, 0x0b001213, 0x3f161513,
  0x10020ba4, 0x37003007, 0x08292708, 0x660310be,
  0x0d0f2b09, 0x021001af, 0x00000c2d, 0x0d0f05ac,
  0x380f0d23, 0x05001911, 0x0d380f13, 0x380f0d60,
  // [0fa0]
  0x293f27be, 0x380f0d55, 0x050145af, 0x291d2213,
  0x300e2507, 0x300e2355, 0x0f182109, 0x08272108,
  0x053827a4, 0x14002112, 0x292701af, 0x05001407,
  0x1c232508, 0x08161d12, 0x1d0f0d6f, 0x0f002112,
  // [0fb0]
  0x45050dad, 0x060f2207, 0x04001911, 0x210f0d22,
  0x660419be, 0x161510be, 0x25301c08, 0x050801af,
  0x0f051d07, 0x45120f07, 0x30002521, 0x1e231c08,
  0x45180d13, 0x0e1e2512, 0x010b2707, 0x0f080108,
  // [0fc0]
  0x21452708, 0x01002908, 0x10192113, 0x21003f20,
  0x01002711, 0x21001512, 0x16002b21, 0x43002207,
  0x16002b20, 0x0d000f11, 0x271f4521, 0x45001612,
  0x45002b12, 0x0c003f12, 0x18000c12, 0x05000623,
  // [0fd0]
  0x1d1245af, 0x3f002122, 0x0e301e12, 0x190d01af,
  0x0b100112, 0x0e1e25a4, 0x2b006609, 0x08000f14,
  0x10001907, 0x16002108, 0x27290112, 0x15002b07,
  0x250e1c08, 0x121d406f, 0x1d401212, 0x0c1f0109,
  // [0fe0]
  0x10036607, 0x160f0855, 0x220d0fa4, 0x10000311,
  0x250e2312, 0x12010ca4, 0x06000f12, 0x66001812,
  0x17182209, 0x301e0e55, 0x1c002307, 0x1c001e11,
  0x04292711, 0x21060112, 0x0d1d1209, 0x15000f12,
  // [0ff0]
  0x0f002107, 0x27000f13, 0x05001d07, 0x15121d08,
  0x251c30ad, 0x190210af, 0x0f010d12, 0x0d220107,
  0x02002207, 0x010d0fbc, 0x10000108, 0x08050f08,
  0x040b0208, 0x02006607, 0x1e251c55, 0x12001408,

  // [1000]
  0x022101bc, 0x271d4021, 0x12000308, 0x0b1002be,
  0x05001208, 0x43050107, 0x1c233012, 0x40001d20,
  0x660305a4, 0x031d4007, 0x01270555, 0x06020107,
  0x05660312, 0x19160b12, 0x02001d07, 0x1c301e09,
  // [1010]
  0x2b100b12, 0x05001221, 0x03021007, 0x05004013,
  0x120506ad, 0x27001d13, 0x1d0d4012, 0x0e1e2312,
  0x06004007, 0x29274009, 0x18000621, 0x21292714,
  0x050f1508, 0x27040612, 0x15001911, 0x06102107,
  // [1020]
  0x01040608, 0x251c2314, 0x18000c08, 0x0b010209,
  0x03000412, 0x14060421, 0x06041414, 0x3f210112,
  0x230e3060, 0x400b0209, 0x21196609, 0x021805ad,
  0x1d053fad, 0x0b161dbc, 0x12450255, 0x660245a4,
  // [1030]
  0x03066613, 0x0d0f2214, 0x23251c07, 0x060b5112,
  0x1e233009, 0x16192712, 0x06001707, 0x010210af,
  0x17052207, 0x19660314, 0x181d4508, 0x0b142b12,
  0x06451207, 0x07005c21, 0x19080112, 0x10021907,
  // [1040]
  0x14000112, 0x402205a4, 0x082b0112, 0x0f001811,
  0x060b6608, 0x1c230ea4, 0x19160455, 0x051703af,
  0x04196621, 0x170201ad, 0x66291f12, 0x02001907,
  0x22000212, 0x21000421, 0x1e2330ad, 0x0c000812,
  // [1050]
  0x290b0421, 0x0f036607, 0x19221407, 0x1c253008,
  0x0c121812, 0x1e2330a4, 0x0e1e2311, 0x17080f12,
  0x451d4021, 0x45100608, 0x0e1c1e09, 0x160d0f55,
  0x16181721, 0x0f0d3fad, 0x40180109, 0x27081212,
  // [1060]
  0x27292b12, 0x020801a4, 0x3f001421, 0x0f001813,
  0x03064511, 0x06171808, 0x013f06af, 0x0e231e21,
  0x0e1c2509, 0x0b012bad, 0x21050112, 0x660305bc,
  0x1c003009, 0x23001c13, 0x383f0809, 0x012b3812,
  // [1070]
  0x0e233011, 0x17002211, 0x15002b13, 0x030604ad,
  0x0f001412, 0x1d000408, 0x06141908, 0x07005c0c,
  0x04220b07, 0x1e1c0e07, 0x3f100b6f, 0x1c0e30a4,
  0x231c0e13, 0x17003813, 0x02062baf, 0x1e0e2308,
  // [1080]
  0x020618af, 0x05000814, 0x01291f12, 0x186601af,
  0x01001f20, 0x03001613, 0x03001808, 0x380604a4,
  0x1e252313, 0x40661712, 0x06006611, 0x01210320,
  0x17003807, 0x0c012b07, 0x06660112, 0x192b0112,
  // [1090]
  0x22003812, 0x18001920, 0x231c0e07, 0x062b0109,
  0x08010307, 0x061f0112, 0x03010613, 0x14065112,
  0x1e2523a4, 0x22001811, 0x19001811, 0x1e0e1c12,
  0x0e1c1e60, 0x011f1909, 0x1d041207, 0x22000c09,
  // [10a0]
  0x1c0e23ad, 0x251c2312, 0x0d001f1f, 0x03011512,
  0x0c1d4012, 0x40004507, 0x1c251e11, 0x30000e20,
  0x05001f10, 0x0f0d1208, 0x0f0d1f09, 0x10181dbc,
  0x08004007, 0x01001007, 0x170215a4, 0x45001d08,
  // [10b0]
  0x0b100155, 0x06150112, 0x1c1e2502, 0x1e0e1c13,
  0x121615af, 0x22021413, 0x12000502, 0x1c230e14,
  0x080b0112, 0x250e1e13, 0x66060409, 0x020b0421,
  0x45150221, 0x0c002b14, 0x1d401907, 0x10060f02,
  // [10c0]
  0x180c22ad, 0x45012ba4, 0x662b2212, 0x010f0d08,
  0x66031921, 0x27292208, 0x0b000602, 0x0b0601af,
  0x23250ebc, 0x18002b14, 0x1d004011, 0x301c0e12,
  0x06001912, 0x12004007, 0x23251ead, 0x251e23a4,
  // [10d0]
  0x14000420, 0x05380107, 0x21270112, 0x380401af,
  0x0f290112, 0x1d001211, 0x45122212, 0x0b005108,
  0x40290d08, 0x380d0814, 0x0c001614, 0x29020621,
  0x012b1907, 0x19162b60, 0x04450107, 0x29000113,
  // [10e0]
  0x05001f11, 0x29000c12, 0x1d400221, 0x170f0d13,
  0x19660311, 0x0f001807, 0x140419bc, 0x401d1607,
  0x06151713, 0x06051412, 0x1d2719ad, 0x01000508,
  0x2b000c12, 0x063f1212, 0x06000507, 0x031d4034,
  // [10f0]
  0x01052212, 0x15000c21, 0x16216609, 0x03450f07,
  0x15001607, 0x120c1d09, 0x06003812, 0x0d0f1612,
  0x22081821, 0x0d100f08, 0x16401d09, 0x38000620,
  0x060c1211, 0x12000407, 0x18000c22, 0x25230e55,
  // [1100]
  0x23300e09, 0x160d0f20, 0x30250e12, 0x083801af,
  0x0b000112, 0x19080107, 0x190414ad, 0x40190412,
  0x06196611, 0x1d0604a4, 0x45290612, 0x0c060407,
  0x301c2309, 0x230e1c07, 0x230e3023, 0x064001ad,
  // [1110]
  0x190601a4, 0x231c0ea4, 0x12000507, 0x01166607,
  0x231e0ea4, 0x45001807, 0x0c001809, 0x1c250e55,
  0x19001d02, 0x250e1c14, 0x45051402, 0x0e001e21,
  0x020b0509, 0x16450312, 0x1d124507, 0x2b2101ad,
  // [1120]
  0x030419ad, 0x04190314, 0x04000608, 0x04031913,
  0x220403a4, 0x04064507, 0x01036660, 0x0e231c14,
  0x18002709, 0x12401d07, 0x04006608, 0x19010607,
  0x25300e07, 0x0e231e02, 0x45102b13, 0x45121dac,
  // [1130]
  0x10450c21, 0x27660321, 0x38010812, 0x190301af,
  0x04061912, 0x080d0512, 0x2b450c12, 0x010f1612,
  0x2b000c13, 0x0d0801af, 0x1e251c23, 0x14000d12,
  0x03000d12, 0x010d0f21, 0x14000f10, 0x0f050108,
  // [1140]
  0x01172ba4, 0x160d0f13, 0x05031907, 0x0c0d0f60,
  0x10060107, 0x18002222, 0x43004513, 0x15001608,
  0x45141221, 0x16053faf, 0x19431a12, 0x101406a4,
  0x01081da4, 0x080f0112, 0x29062112, 0x04190612,
  // [1150]
  0x22190411, 0x01000511, 0x01163812, 0x16000b14,
  0x14000f20, 0x231e3012, 0x020b1012, 0x08380507,
  0x180b1012, 0x1d002712, 0x120301a4, 0x0b1001af,
  0x180604a4, 0x05220109, 0x182922bc, 0x08000622,
  // [1160]
  0x031f0112, 0x1c302309, 0x04191d07, 0x0b021408,
  0x15000c12, 0x02051aaf, 0x0f010509, 0x14000f12,
  0x04001622, 0x27290caf, 0x22191834, 0x14000f08,
  0x010429a4, 0x0e233002, 0x1d004021, 0x25001e02,
  // [1170]
  0x04061612, 0x17002b08, 0x01400307, 0x1e230e02,
  0x0e001e22, 0x15160612, 0x05272913, 0x21292760,
  0x15061621, 0x0e001e12, 0x2b174312, 0x05061512,
  0x0c0b0212, 0x18001208, 0x05001212, 0x21002212,
  // [1180]
  0x01002912, 0x66272908, 0x22182112, 0x27192909,
  0x193f0611, 0x45001614, 0x1c1e30ad, 0x223f2712,
  0x053f1f13, 0x0c150612, 0x230e1c60, 0x662b0813,
  0x27290412, 0x01121907, 0x0b000107, 0x23251c13,
  // [1190]
  0x04006613, 0x0e1c1eaf, 0x010b0307, 0x01030507,
  0x17000d08, 0x170801be, 0x1f2701af, 0x17002713,
  0x05011007, 0x0e251ebb, 0x1d292722, 0x38141060,
  0x2b020b12, 0x0f060307, 0x05100155, 0x25003012,
  // [11a0]
  0x45010ca4, 0x031806a4, 0x210103af, 0x0c2b0112,
  0x02002b11, 0x05015112, 0x03660621, 0x08000511,
  0x06006613, 0x45210112, 0x1d0c4021, 0x05180108,
  0x27002112, 0x12042712, 0x0c0d2707, 0x05400108,
  // [11b0]
  0x04191509, 0x01272960, 0x10000211, 0x250e1c20,
  0x2b000614, 0x04151609, 0x0b1006a4, 0x08001807,
  0x251c0eac, 0x22002b12, 0x292721bc, 0x27295112,
  0x02001013, 0x1e251cbe, 0x23250e13, 0x1f051212,
  // [11c0]
  0x1c1e0ebe, 0x22012707, 0x251e3013, 0x17054512,
  0x22272112, 0x05001907, 0x19043f60, 0x04003f14,
  0x17000813, 0x1d020b22, 0x08191411, 0x023801a4,
  0x08002122, 0x29142712, 0x1d001412, 0x0f4008af,
  // [11d0]
  0x21002222, 0x011f2bbc, 0x251e30ac, 0x22002120,
  0x0d001f13, 0x270b0212, 0x0f083f60, 0x17401609,
  0x2b001f21, 0x1c250e21, 0x0f222112, 0x1d4008be,
  0x08272bad, 0x38000d14, 0x1d083f21, 0x12001d22,
  // [11e0]
  0x00000d2d, 0x0d2b0fbb, 0x18000613, 0x1f000114,
  0x04101407, 0x19010b12, 0x010306a4, 0x0b190213,
  0x050301af, 0x0b050112, 0x251e3012, 0x03060102,
  0x04272912, 0x23300e23, 0x231c30a4, 0x100b01af,
  // [11f0]
  0x08000d07, 0x10140113, 0x30002513, 0x30251e13,
  0x0f0b2208, 0x050138a4, 0x06150413, 0x174505ad,
  0x05011909, 0x22011807, 0x29270413, 0x1c253055,
  0x0f011002, 0x1e231c14, 0x0e1c2523, 0x01001707,
  // [1200]
  0x0c000408, 0x06000422, 0x062b1613, 0x04001621,
  0x04001823, 0x04062bad, 0x251e0e12, 0x0c001d08,
  0x0e1c2309, 0x01000c09, 0x1c300e09, 0x0d380512,
  0x1916046f, 0x06660308, 0x04062107, 0x251c1e22,
  // [1210]
  0x06021012, 0x036621ad, 0x12000c12, 0x01001712,
  0x02100bad, 0x230e1c08, 0x06001708, 0x19060308,
  0x06001d22, 0x19021721, 0x16001512, 0x230e1e55,
  0x06004514, 0x19140112, 0x231c2513, 0x12001d20,
  // [1220]
  0x06001421, 0x29001612, 0x0d001608, 0x0c004008,
  0x17000d12, 0x04081fbc, 0x45000612, 0x17001f20,
  0x45000620, 0x041016ad, 0x38000d22, 0x0c030112,
  0x1d004512, 0x1e2530be, 0x04001611, 0x1c2330a4,
  // [1230]
  0x160c0412, 0x01081707, 0x0f011712, 0x19000f07,
  0x08430107, 0x1e1c23bc, 0x250e1e08, 0x38001712,
  0x04001812, 0x02010507, 0x0e231c08, 0x04182b08,
  0x14004508, 0x010c0607, 0x0e251c08, 0x17000120,
  // [1240]
  0x01000f11, 0x0f0d1712, 0x05001721, 0x380d0f21,
  0x17051f07, 0x432b0508, 0x0e2523a4, 0x08001620,
  0x08150508, 0x17004007, 0x30230eaf, 0x19100613,
  0x01191712, 0x08005113, 0x171f01af, 0x1f170111,
  // [1250]
  0x030b6608, 0x1f190460, 0x22001713, 0x1d001507,
  0x060501a4, 0x40001912, 0x16000c12, 0x400d19ad,
  0x19004021, 0x19004012, 0x0d0538bc, 0x1d404514,
  0x1c250e09, 0x0e301e13, 0x38004021, 0x3f401921,
  // [1260]
  0x16080f13, 0x193840af, 0x40001933, 0x04190312,
  0x3f191413, 0x18000420, 0x2b000b13, 0x051806bc,
  0x1d080408, 0x06012b11, 0x0f100307, 0x01060309,
  0x0b064512, 0x1e0e2321, 0x056606ad, 0x0c191d07,
  // [1270]
  0x17021412, 0x06001233, 0x04020f13, 0x020b40ac,
  0x140b0212, 0x17401d20, 0x19040308, 0x27000620,
  0x06050812, 0x38000f08, 0x04191707, 0x232530af,
  0x04011407, 0x0e1c2311, 0x231e30be, 0x15171421,
  // [1280]
  0x03146609, 0x21100112, 0x07005c10, 0x16004013,
  0x08001607, 0x454016af, 0x16004020, 0x050108ac,
  0x04001407, 0x16004008, 0x02100608, 0x1d001912,
  0x04142255, 0x45121d12, 0x10162912, 0x14002708,
  // [1290]
  0x0b0c6612, 0x40191d12, 0x30000e21, 0x0e1c1e07,
  0x40152712, 0x22001814, 0x0c161d14, 0x0e1e23ac,
  0x3f004513, 0x1c0e2560, 0x0000232d, 0x45041da4,
  0x060229a4, 0x23001e22, 0x0d380f12, 0x06142ba4,
  // [12a0]
  0x0b0210ac, 0x40006608, 0x0e302512, 0x660d01a4,
  0x0d061607, 0x22000408, 0x06002709, 0x03100b20,
  0x01006608, 0x10401409, 0x3f171821, 0x1c252307,
  0x2b011812, 0x032b22ad, 0x30001c07, 0x05180112,
  // [12b0]
  0x010d0308, 0x3f6605af, 0x05001007, 0x0d003813,
  0x0201086f, 0x151d4021, 0x0d050f22, 0x1d221007,
  0x0c001d11, 0x38170822, 0x300e2312, 0x12451811,
  0x0d002210, 0x251c0e60, 0x02221608, 0x05001f13,
  // [12c0]
  0x1c1e3021, 0x0f001508, 0x18004023, 0x12004521,
  0x1d001209, 0x19006611, 0x06180baf, 0x080f3812,
  0x04151912, 0x23001e21, 0x17050c12, 0x0c180112,
  0x06150c55, 0x0d053808, 0x1d1245a4, 0x0f000d02,
  // [12d0]
  0x06050c02, 0x0c003f13, 0x1e000e13, 0x29273f12,
  0x66000f12, 0x14005112, 0x05000308, 0x40004513,
  0x18050c13, 0x250e2308, 0x0c001d12, 0x03142221,
  0x03000122, 0x19291409, 0x0f0d0823, 0x1d000c13,
  // [12e0]
  0x0c001813, 0x1d000c12, 0x03002211, 0x06002713,
  0x06003f14, 0x0c010802, 0x0e302334, 0x3f001213,
  0x291d2709, 0x251e1c02, 0x3f002713, 0x1c253060,
  0x04141812, 0x18006614, 0x101d12ad, 0x1d000c11,
  // [12f0]
  0x14001f21, 0x27001013, 0x08013fac, 0x0b013fbb,
  0x190c1d07, 0x3f04196f, 0x01000514, 0x0c001814,
  0x29270c21, 0x38004513, 0x16180caf, 0x451d12ac,
  0x401d0409, 0x1e1c0e08, 0x030201af, 0x251c1e02,
  // [1300]
  0x190366be, 0x1c233007, 0x0f001907, 0x1d000820,
  0x036619ad, 0x1c2325af, 0x38050d08, 0x19001020,
  0x08000108, 0x0d380f23, 0x12005113, 0x0e1c2322,
  0x66013faf, 0x1c1e2313, 0x0e231c11, 0x2b001f13,
  // [1310]
  0x1c0e2321, 0x21142712, 0x01210612, 0x012b0613,
  0x0c010308, 0x020601a4, 0x66000c12, 0x0d010ca4,
  0x17053808, 0x251c0e20, 0x27000c13, 0x01081955,
  0x3f006621, 0x151d40ad, 0x12050cac, 0x231e0e07,
  // [1320]
  0x01001211, 0x290601af, 0x062b1211, 0x43001f23,
  0x38001212, 0x66001913, 0x0f0c2712, 0x2b001212,
  0x1c0e2322, 0x2129276f, 0x15001d11, 0x17001512,
  0x15001d23, 0x030b66ad, 0x150112ac, 0x401d1521,
  // [1330]
  0x15001d14, 0x1d001514, 0x45000c13, 0x01276655,
  0x1f000521, 0x38001522, 0x15001411, 0x12151dac,
  0x43012b12, 0x45171212, 0x251e0e14, 0x1d120c12,
  0x19001511, 0x40171dbe, 0x0f2b0108, 0x22003811,
  // [1340]
  0x66384013, 0x19000613, 0x01000f08, 0x051912af,
  0x18004020, 0x18011921, 0x38000112, 0x38000522,
  0x22000d07, 0x0d002b07, 0x25003002, 0x05000d07,
  0x05211709, 0x0b000608, 0x1c1e2320, 0x1c0e3007,
  // [1350]
  0x03080112, 0x01001807, 0x05003813, 0x29272221,
  0x0000170a, 0x0d0f38be, 0x250e3007, 0x1d1227ad,
  0x0d001707, 0x05000108, 0x17010508, 0x02100c07,
  0x1f013f12, 0x0e252312, 0x0e301e09, 0x250e1e07,
  // [1360]
  0x12151d09, 0x124045af, 0x40021d08, 0x401d0c20,
  0x0d001812, 0x250e1c60, 0x45661f09, 0x0c401d13,
  0x1e003009, 0x17006620, 0x082b1a11, 0x0c401d12,
  0x22000612, 0x0f450812, 0x0c1245a4, 0x1d0c4008,
  // [1370]
  0x38172707, 0x16002909, 0x25230e13, 0x1c0e1e10,
  0x0d0b1812, 0x38401d12, 0x18100b12, 0x1c001e07,
  0x10016612, 0x15002213, 0x19221d12, 0x2b000f13,
  0x0f060312, 0x150316af, 0x034518a4, 0x27290421,
  // [1380]
  0x050306a4, 0x15193f12, 0x031719af, 0x2b27296f,
  0x153f1921, 0x05170313, 0x18060112, 0x301c0e13,
  0x0b001511, 0x27223faf, 0x16001514, 0x22000813,
  0x16001912, 0x16151912, 0x19002712, 0x1c230ebc,
  // [1390]
  0x0b272912, 0x2b292722, 0x06380107, 0x0e233020,
  0x03665112, 0x03001f21, 0x22141912, 0x1d272121,
  0x301e2313, 0x04002713, 0x3f212712, 0x16190413,
  0x3f4021cf, 0x453f17bc, 0x45294008, 0x04222912,
  // [13a0]
  0x06000522, 0x1d3f0421, 0x191f04bb, 0x05150421,
  0x1f050421, 0x061f0411, 0x30000e34, 0x051f1560,
  0x0d004313, 0x23251e60, 0x19000609, 0x1c002521,
  0x43002b09, 0x031d0608, 0x30002321, 0x1f050413,
  // [13b0]
  0x04001521, 0x01293f07, 0x08002708, 0x15001609,
  0x29220112, 0x19000311, 0x0d170809, 0x21660323,
  0x0d081413, 0x19002212, 0x142227af, 0x042b0baf,
  0x061021a4, 0x03190613, 0x18290112, 0x29002113,
  // [13c0]
  0x45124055, 0x02060b09, 0x1f002221, 0x0c001808,
  0x051738be, 0x14001d22, 0x030c1d07, 0x17221655,
  0x196603af, 0x06121813, 0x660c0b13, 0x06450521,
  0x22001707, 0x22001207, 0x12004520, 0x0f0b51a4,
  // [13d0]
  0x1e0e2309, 0x17380baf, 0x17012907, 0x163819af,
  0x191804ad, 0x160c1d09, 0x300e2308, 0x00001703,
  0x14124512, 0x25230e12, 0x05010d07, 0x050f1f12,
  0x17124002, 0x04012709, 0x16662909, 0x1e1c30ac,
  // [13e0]
  0x020b5112, 0x0b005113, 0x19002b11, 0x0d001708,
  0x0c006620, 0x14002713, 0x05010c11, 0x1d001421,
  0x21190412, 0x22001420, 0x662b0309, 0x0d001422,
  0x06012bac, 0x06033f21, 0x38170808, 0x02000612,
  // [13f0]
  0x10001413, 0x30251e12, 0x01382207, 0x03001909,
  0x02080355, 0x142201af, 0x19143821, 0x0c004020,
  0x0c052907, 0x40001521, 0x06120c07, 0x03010611,
  0x10002120, 0x2b000621, 0x2b000620, 0x19292713,

  // [1400]
  0x12450caf, 0x1d3819ad, 0x0e302360, 0x29271913,
  0x19001414, 0x0000022d, 0x19001f11, 0x100d0f55,
  0x17001909, 0x0c401513, 0x30231ea4, 0x27184008,
  0x19272909, 0x17002208, 0x1d193f60, 0x0d433f07,
  // [1410]
  0x23301c60, 0x1e1c2509, 0x17190408, 0x011240a4,
  0x27004012, 0x1d214007, 0x27293faf, 0x454012af,
  0x1d002707, 0x05060108, 0x40211908, 0x1d4008af,
  0x06036608, 0x06401d55, 0x23300e02, 0x08213f12,
  // [1420]
  0x08011208, 0x45001f12, 0x121d4021, 0x030166a4,
  0x14004011, 0x02161513, 0x40000508, 0x251e2313,
  0x050b0fa4, 0x0b2b0309, 0x16450812, 0x05451213,
  0x19000402, 0x17272912, 0x19046609, 0x191701af,
  // [1430]
  0x14000612, 0x19001f13, 0x0f1908ad, 0x050401af,
  0x19000808, 0x0d0108af, 0x06220b08, 0x04003f12,
  0x3f272921, 0x05000613, 0x0e251e13, 0x3f0501a4,
  0x010f0507, 0x03100808, 0x19036612, 0x03041907,
  // [1440]
  0x251e1caf, 0x030419ac, 0x290f3813, 0x08010609,
  0x01050d14, 0x381466af, 0x0d000514, 0x0d050112,
  0x431901a4, 0x0b1410a4, 0x1c230e09, 0x21000109,
  0x40001f11, 0x10020b11, 0x19001512, 0x0e1c1e14,
  // [1450]
  0x3f2729af, 0x293f2713, 0x170c2912, 0x0e231c55,
  0x12272113, 0x27210112, 0x250e30af, 0x27151aaf,
  0x3f0415be, 0x0b0302ac, 0x0e251e55, 0x45120cbc,
  0x14000211, 0x01062b07, 0x0c001822, 0x0f2927af,
  // [1460]
  0x15191613, 0x10062ba4, 0x19140434, 0x0c042b12,
  0x271406af, 0x27102212, 0x251e2309, 0x40010820,
  0x272b1812, 0x1f055112, 0x380c01af, 0x080f17ad,
  0x182b1f12, 0x100b51af, 0x0b0622ad, 0x1f011912,
  // [1470]
  0x081701af, 0x380f45af, 0x100d1712, 0x1d011f12,
  0x40001812, 0x05020b12, 0x38171608, 0x0d2205be,
  0x173805a4, 0x05663822, 0x08055112, 0x45004007,
  0x01002120, 0x08010c09, 0x0f013f12, 0x1e230e14,
  // [1480]
  0x0c003f11, 0x0d0f0c12, 0x21272960, 0x40001211,
  0x01430c12, 0x01270cad, 0x43012108, 0x022b0560,
  0x0b0c45ad, 0x1c1e23af, 0x150c06ac, 0x06380109,
  0x0b000302, 0x060103a4, 0x05000111, 0x0e1e2522,
  // [1490]
  0x0b0206a4, 0x01002213, 0x22001f12, 0x08002213,
  0x03010fac, 0x0f2201a4, 0x0d041daf, 0x1d4029af,
  0x27003f21, 0x160b01a4, 0x0c000807, 0x08191655,
  0x0d0f1d12, 0x0d000822, 0x0c010602, 0x01380612,
  // [14a0]
  0x05220112, 0x012927ad, 0x1d171607, 0x1c251e6f,
  0x1c301eaf, 0x14000614, 0x663801a4, 0x40001208,
  0x19000d21, 0x38180111, 0x66002709, 0x0b010608,
  0x01180812, 0x012b0611, 0x030d0609, 0x1d402960,
  // [14b0]
  0x06180212, 0x1d004035, 0x19060408, 0x04161512,
  0x271d4012, 0x0e1e1ca4, 0x06001612, 0x1c251eac,
  0x40001d36, 0x18451260, 0x401d27af, 0x0b190421,
  0x29401d20, 0x06001611, 0x0b061908, 0x380406be,
  // [14c0]
  0x1d000107, 0x16270412, 0x1e001c08, 0x22161407,
  0x16004512, 0x03002913, 0x0d124512, 0x15161da4,
  0x66000414, 0x19161511, 0x14001822, 0x04001514,
  0x1d001711, 0x3f2129af, 0x08001f12, 0x0b000407,
  // [14d0]
  0x19043f21, 0x040116af, 0x2b162122, 0x15001914,
  0x2b271612, 0x15191760, 0x19001523, 0x14151912,
  0x16002b12, 0x1d0f0112, 0x03021055, 0x031f0208,
  0x0b020112, 0x231c0e14, 0x29190112, 0x154501a4,
  // [14e0]
  0x1f050623, 0x66001934, 0x400302ad, 0x10193fcf,
  0x040c19bb, 0x0d001612, 0x17000112, 0x16002b22,
  0x191504ad, 0x04006607, 0x432b0112, 0x27451212,
  0x2b0c1f21, 0x081729af, 0x081451af, 0x0c001f34,
  // [14f0]
  0x16662260, 0x0c292711, 0x0f001611, 0x45000c23,
  0x23001e14, 0x16000c22, 0x661904be, 0x062b0409,
  0x0c001f21, 0x08010f22, 0x660119af, 0x0c1245ac,
  0x0e1e1cad, 0x25230e07, 0x14404508, 0x27000122,
  // [1500]
  0x2b1f0c20, 0x16000c13, 0x120c1daf, 0x040f01ac,
  0x2b0c1f20, 0x1f000c13, 0x18000c09, 0x1e233060,
  0x01000c13, 0x08170107, 0x14402708, 0x45012912,
  0x0b000c11, 0x14121612, 0x222b1711, 0x0c1d1709,
  // [1510]
  0x0b3801a4, 0x0d0419ad, 0x0e1c2302, 0x3f000c22,
  0x01660c12, 0x06000c11, 0x1d1722a4, 0x190c0111,
  0x15001723, 0x19002b12, 0x01000412, 0x0d004507,
  0x05000812, 0x22272914, 0x0c002207, 0x0d031707,
  // [1520]
  0x1c302509, 0x0000291c, 0x16121709, 0x19001d09,
  0x06012b08, 0x210366bc, 0x661f3f09, 0x03003f11,
  0x231e1c07, 0x030b0612, 0x143804ac, 0x04036612,
  0x05001513, 0x66292760, 0x19000c02, 0x050d38af,
  // [1530]
  0x29270321, 0x04012707, 0x301c2302, 0x0b060812,
  0x232530a4, 0x14043811, 0x14220412, 0x12170f11,
  0x1d013faf, 0x0f081707, 0x06080112, 0x010d0f60,
  0x10020baf, 0x250e1e09, 0x0b030509, 0x0b661421,
  // [1540]
  0x011822ad, 0x450c03bc, 0x05380f22, 0x0b1014ce,
  0x04001712, 0x06382b02, 0x060822be, 0x21000408,
  0x031d66ac, 0x45121f12, 0x01292121, 0x04000807,
  0x23300ebe, 0x12190407, 0x17001d11, 0x1d451613,
  // [1550]
  0x08000412, 0x05660360, 0x03041760, 0x29003f13,
  0x06001521, 0x15000614, 0x1f000622, 0x06001621,
  0x0c451255, 0x14150309, 0x14062b60, 0x16061420,
  0x120f4509, 0x14060308, 0x230e30ad, 0x224012a4,
  // [1560]
  0x25230e08, 0x30000e23, 0x140d06af, 0x2b0140a4,
  0x1d002b08, 0x140d0614, 0x04140660, 0x1d0c66a4,
  0x66030608, 0x38151602, 0x0b001007, 0x1e302320,
  0x0e302323, 0x1d1815ad, 0x061001af, 0x29030109,
  // [1570]
  0x02450108, 0x01174555, 0x0e251e02, 0x40001612,
  0x08140612, 0x1d0c12ad, 0x18052b60, 0x66000622,
  0x40001610, 0x1f000613, 0x66030512, 0x06010c07,
  0x026601af, 0x020b1021, 0x03020621, 0x16001913,
  // [1580]
  0x660506af, 0x10000411, 0x0c1514bc, 0x0c0401ac,
  0x15272112, 0x451219a4, 0x06030c09, 0x121d40ad,
  0x1e0e1c21, 0x250e37ad, 0x40001614, 0x14000b13,
  0x1d1f3faf, 0x1d036607, 0x250e1c55, 0x01000307,
  // [1590]
  0x100b0213, 0x1c252308, 0x0f153808, 0x03001012,
  0x43016611, 0x05026609, 0x0f0d0b21, 0x1d0115a4,
  0x050d1fbe, 0x40000112, 0x38004008, 0x3f006622,
  0x22000420, 0x251e0e13, 0x010d27af, 0x0d011709,
  // [15a0]
  0x01102b21, 0x170c0109, 0x663f0521, 0x081666bc,
  0x191822af, 0x1e252322, 0x06001902, 0x19002214,
  0x45171012, 0x273801af, 0x0d004512, 0x2b004509,
  0x0f000513, 0x19121008, 0x1f004333, 0x120d01a4,
  // [15b0]
  0x0b166607, 0x66221960, 0x186622bb, 0x25000e20,
  0x401d0c55, 0x19000d09, 0x300e1e14, 0x291827af,
  0x300e1ca4, 0x0d000307, 0x18272920, 0x07005c1d,
  0x231c1e12, 0x1d0817af, 0x251e1c08, 0x0e003710,
  // [15c0]
  0x0b060521, 0x0d172912, 0x0d292711, 0x04190607,
  0x03002b20, 0x04291912, 0x030b0607, 0x19020412,
  0x10000602, 0x38081413, 0x10001409, 0x06001914,
  0x19050612, 0x02661aa4, 0x1c253012, 0x1e3025af,
  // [15d0]
  0x08001707, 0x1c2530af, 0x1c232509, 0x14181007,
  0x030c2b55, 0x1c1e0e14, 0x38036607, 0x400c51af,
  0x03006636, 0x1d154021, 0x27062914, 0x271d2912,
  0x04001811, 0x38450202, 0x0f170509, 0x1c0e2309,
  // [15e0]
  0x0f380d60, 0x16272912, 0x10292713, 0x45162708,
  0x22001712, 0x0000150a, 0x25000e12, 0x06000b08,
  0x04160821, 0x1d001508, 0x38012b55, 0x1d004036,
  0x25231c07, 0x1c000e21, 0x1c0e25af, 0x3f066613,
  // [15f0]
  0x080d0107, 0x23301c12, 0x300e1c20, 0x27211412,
  0x230e30a4, 0x01000609, 0x03660612, 0x250e1eaf,
  0x66000611, 0x0e251cad, 0x03296607, 0x300e1c08,
  0x036601af, 0x1e230eaf, 0x401d4560, 0x16001523,
  // [1600]
  0x01401d13, 0x19006622, 0x15002b20, 0x0d163fac,
  0x27080f13, 0x161d1712, 0x451501ac, 0x16273fad,
  0x40121daf, 0x402b1507, 0x08001813, 0x1c0e25bc,
  0x170f0daf, 0x14271612, 0x0d381721, 0x27000412,
  // [1610]
  0x1d292bad, 0x14000613, 0x012716bc, 0x01002911,
  0x191d3fad, 0x196601af, 0x050d0108, 0x02062209,
  0x010d0f08, 0x2b1d0112, 0x0b000512, 0x40000308,
  0x0b170214, 0x142b0633, 0x2b0f0513, 0x192903ad,
  // [1620]
  0x0c040109, 0x22430109, 0x0f002207, 0x381001a4,
  0x01170da4, 0x02002121, 0x06021907, 0x66291012,
  0x17401d55, 0x10170560, 0x211d0608, 0x43000113,
  0x38002711, 0x082101af, 0x18142209, 0x66002220,
  // [1630]
  0x16451211, 0x1d000607, 0x22292709, 0x0f0601ad,
  0x21001612, 0x1c1e0eaf, 0x21002913, 0x22001622,
  0x23300e08, 0x10000212, 0x27002920, 0x401d1909,
  0x18004513, 0x0e1e23af, 0x40051d12, 0x40451207,
  // [1640]
  0x21002713, 0x17001911, 0x16020b20, 0x19001421,
  0x1d000c14, 0x27292121, 0x19222111, 0x380d0112,
  0x1f140112, 0x05000d14, 0x050f01af, 0x06002b14,
  0x1f001421, 0x14000609, 0x01046655, 0x16020112,
  // [1650]
  0x66050112, 0x01040dac, 0x040119a4, 0x660d0111,
  0x231c0e20, 0x1d0406af, 0x012221a4, 0x01102b07,
  0x1d404512, 0x06011fa4, 0x25230e09, 0x1c250e22,
  0x21036612, 0x01002208, 0x08002b11, 0x06002b23,
  // [1660]
  0x0e001c20, 0x02001014, 0x0f0d05ac, 0x19036611,
  0x25231c14, 0x06000d14, 0x19020b09, 0x19001d07,
  0x082b01ad, 0x66380112, 0x0000040a, 0x02181907,
  0x06001808, 0x451f1209, 0x1c002321, 0x19002112,
  // [1670]
  0x450b0507, 0x43000507, 0x1d2b1512, 0x250e1c09,
  0x0f171609, 0x082b0121, 0x4522176f, 0x013f2912,
  0x080b1821, 0x181004ad, 0x16152b22, 0x0c001908,
  0x0f3827af, 0x0f170d09, 0x66000621, 0x300e1c13,
  // [1680]
  0x06121907, 0x1c2330bc, 0x1f001014, 0x1f180112,
  0x010f0d60, 0x05380d20, 0x270129af, 0x290f01af,
  0x21001d12, 0x0f272912, 0x1e250e07, 0x101229a4,
  0x38000d12, 0x04001414, 0x01053fac, 0x1c0e2360,
  // [1690]
  0x38004312, 0x0f033807, 0x06010312, 0x0f002711,
  0x0b100608, 0x04002213, 0x10001407, 0x0d010612,
  0x15000312, 0x1f12456f, 0x22272920, 0x02000b22,
  0x14020b12, 0x0d180609, 0x0b0301af, 0x06000d02,
  // [16a0]
  0x04001011, 0x04001813, 0x06041807, 0x0d003808,
  0x030c0607, 0x0d0f0807, 0x06001811, 0x05000607,
  0x17001d13, 0x0b021012, 0x22292755, 0x451d18af,
  0x38000111, 0x1d002107, 0x15001610, 0x45000d12,
  // [16b0]
  0x251e1c21, 0x03021009, 0x301c2560, 0x0b1015ad,
  0x0b020613, 0x180c1221, 0x4504216f, 0x0f12455e,
  0x100406af, 0x27170860, 0x45000d11, 0x1c302307,
  0x38000d08, 0x1d082b07, 0x03060108, 0x19401d12,
  // [16c0]
  0x401d1914, 0x21000c12, 0x17001d07, 0x03000507,
  0x0f0501a4, 0x22161907, 0x124518ac, 0x1c231ea4,
  0x0f0501af, 0x45121812, 0x160322a4, 0x18380f11,
  0x220c2107, 0x0f1838af, 0x12451807, 0x1e0e23a4,
  // [16d0]
  0x1f180f12, 0x180f3821, 0x451218ad, 0x1d003f11,
  0x18003834, 0x0b046611, 0x16002114, 0x1e0e2512,
  0x12000414, 0x1f102b13, 0x272b0c12, 0x1c251e55,
  0x2b001213, 0x01380d13, 0x40002b21, 0x0d0f1da4,
  // [16e0]
  0x0b102b12, 0x45121d21, 0x16002122, 0x05041207,
  0x2b010812, 0x0d000312, 0x450c1221, 0x231e25af,
  0x1c233055, 0x40002711, 0x02000102, 0x192b0dad,
  0x1d004312, 0x01401d11, 0x0d000f08, 0x01401d07,
  // [16f0]
  0x0d450f07, 0x1f001214, 0x0f083860, 0x04000307,
  0x06056655, 0x122227af, 0x2b0517a4, 0x140d0f11,
  0x15401d20, 0x1d4027ad, 0x17124560, 0x18004522,
  0x08000408, 0x05006611, 0x1c230e60, 0x45003812,
  // [1700]
  0x1f002212, 0x451d1211, 0x38000d09, 0x17001907,
  0x66192712, 0x23251cad, 0x300e1c11, 0x1d002b02,
  0x141810ac, 0x3f001821, 0x100b03ac, 0x01180309,
  0x03001411, 0x1e1c2312, 0x010319a4, 0x052b21ad,
  // [1710]
  0x29660112, 0x080d0f07, 0x12001809, 0x226614a4,
  0x0f001812, 0x301c0ea4, 0x21001521, 0x06660312,
  0x1f001821, 0x0f172160, 0x1c1e0e60, 0x0e1e2313,
  0x02140baf, 0x1d0c0112, 0x66430112, 0x14001809,
  // [1720]
  0x12031507, 0x190f2707, 0x38000813, 0x18001f14,
  0x18001213, 0x231c0e6f, 0x18001712, 0x660315bc,
  0x08000d08, 0x16040cad, 0x45022121, 0x660b0312,
  0x2b005113, 0x18000c07, 0x01002907, 0x0d2b4512,
  // [1730]
  0x0f124507, 0x01031721, 0x08003813, 0x0c000313,
  0x1d120607, 0x030106af, 0x22001412, 0x18001713,
  0x452138af, 0x66001621, 0x08002b12, 0x0c001512,
  0x38003f20, 0x40381212, 0x1f001713, 0x0c000d02,
  // [1740]
  0x01001f12, 0x05660112, 0x0e1c2520, 0x064001af,
  0x1d124521, 0x03002b12, 0x1418121e, 0x050301ad,
  0x30231e60, 0x22000d11, 0x1d4045be, 0x23250e02,
  0x1f0501af, 0x0b000202, 0x0c035112, 0x12401d08,
  // [1750]
  0x12191d07, 0x45120baf, 0x05030108, 0x0f181207,
  0x45001812, 0x12010c07, 0x0d001807, 0x06010209,
  0x03190612, 0x01292b09, 0x01101422, 0x38451807,
  0x38001813, 0x12000f09, 0x12271613, 0x21182bbb,
  // [1760]
  0x2b002123, 0x22003f23, 0x102129af, 0x18152baf,
  0x25231e09, 0x182b21af, 0x033f2bbc, 0x0f3845af,
  0x1c0e236f, 0x18663f12, 0x05001f07, 0x181d2b21,
  0x0e1c3012, 0x0c124021, 0x29001d13, 0x23251e14,
  // [1770]
  0x27401d08, 0x3f0445af, 0x18000f13, 0x1d1817ad,
  0x19000d20, 0x3f1929af, 0x21001012, 0x1d001814,
  0x100c2907, 0x1d000c08, 0x18401d14, 0x04000612,
  0x121845ac, 0x0f012109, 0x1d0c1821, 0x0c0d1012,
  // [1780]
  0x0f181f60, 0x0c291dbb, 0x19001d08, 0x19101809,
  0x04001d11, 0x27290faf, 0x03006621, 0x180d0f11,
  0x19002912, 0x0b0302a4, 0x15000611, 0x03170111,
  0x03010b12, 0x03050408, 0x010d0faf, 0x0d000511,
  // [1790]
  0x121910a4, 0x250e1e12, 0x19001004, 0x18001f08,
  0x0b003f12, 0x22195107, 0x08212207, 0x1c1e2513,
  0x15004012, 0x01660311, 0x22293f12, 0x273f19bc,
  0x01010107, 0x17003f12, 0x12002b08, 0x03020b12,
  // [17a0]
  0x10140614, 0x45401da4, 0x22403f12, 0x19381813,
  0x0c102b07, 0x0e251ebe, 0x040c27ad, 0x0b060214,
  0x29000420, 0x162217af, 0x0f0d1809, 0x10031908,
  0x063801ad, 0x27212223, 0x1d0c1207, 0x0b101412,
  // [17b0]
  0x1d452112, 0x1e0e3007, 0x05010ca4, 0x120c4513,
  0x0c1922ad, 0x12380d12, 0x1e251ca4, 0x30001e21,
  0x0d010c07, 0x19061055, 0x0c160455, 0x2b006611,
  0x08003809, 0x0e231c12, 0x0e23306f, 0x1d160f12,
  // [17c0]
  0x06040b07, 0x08001614, 0x22271912, 0x050f3f09,
  0x060122ad, 0x29270609, 0x38000814, 0x220d3f12,
  0x082b0109, 0x381901a4, 0x10000208, 0x08270112,
  0x10021908, 0x19000107, 0x1f000112, 0x031d4508,
  // [17d0]
  0x45380fa4, 0x45401209, 0x12451660, 0x0c153fbc,
  0x40002b11, 0x22030c07, 0x08451209, 0x0b030611,
  0x04012121, 0x01000311, 0x05003f14, 0x01660621,
  0x06000d12, 0x18150422, 0x220b0313, 0x10001911,
  // [17e0]
  0x0b031812, 0x170601af, 0x22141512, 0x22000113,
  0x01051512, 0x40451d07, 0x14002220, 0x06000323,
  0x18051512, 0x0b0366af, 0x2b001421, 0x40000c12,
  0x100b026f, 0x011d0cad, 0x3818156f, 0x040c1521,
  // [17f0]
  0x27211821, 0x0b001814, 0x0c041612, 0x0b064012,
  0x03000c08, 0x12030507, 0x0c271d09, 0x19001812,
  0x010419ad, 0x04012b12, 0x29222121, 0x401229af,
  0x1d0f2b12, 0x19124008, 0x06041955, 0x0b100209,

  // [1800]
  0x291921be, 0x0d292712, 0x10001520, 0x0f0d21af,
  0x06001913, 0x0c3f0421, 0x124001af, 0x0c001f07,
  0x023801af, 0x1d0f45af, 0x16000407, 0x192901af,
  0x290d27af, 0x0b001811, 0x2b104512, 0x02064008,
  // [1810]
  0x020306a4, 0x1c301e20, 0x100619ac, 0x12001802,
  0x19001808, 0x12001911, 0x12010c12, 0x0c002b21,
  0x29152b12, 0x011915a4, 0x060366af, 0x16060313,
  0x0c2b1da4, 0x16012108, 0x10140609, 0x66100b60,
  // [1820]
  0x121d0c13, 0x251e2323, 0x40451daf, 0x190b0612,
  0x27290614, 0x15002713, 0x45191508, 0x0c451212,
  0x12171d08, 0x27001520, 0x19081d07, 0x25231c55,
  0x04101913, 0x27060cbc, 0x0e2330ac, 0x0c161d09,
  // [1830]
  0x272101af, 0x0e231c02, 0x663f01a4, 0x30251e08,
  0x2b170112, 0x17000c07, 0x08001821, 0x450c1212,
  0x05402b12, 0x19002707, 0x0f080107, 0x08003811,
  0x19004513, 0x08036621, 0x451d4023, 0x29192714,
  // [1840]
  0x08000302, 0x211d1912, 0x2b001921, 0x3f002213,
  0x21190112, 0x0b001208, 0x19012b14, 0x151419af,
  0x27002209, 0x05450c60, 0x0c1d1807, 0x121706a4,
  0x121d4020, 0x21002b21, 0x042b19a4, 0x272919be,
  // [1850]
  0x0f182b21, 0x171901af, 0x080601a4, 0x230e1e12,
  0x04000f20, 0x16002b09, 0x10060407, 0x0410066f,
  0x12451760, 0x05060107, 0x02011208, 0x03660660,
  0x0f001f20, 0x222101af, 0x05030107, 0x01290609,
  // [1860]
  0x163f01af, 0x05161f12, 0x02002b12, 0x430b0108,
  0x053f0112, 0x66003f13, 0x27296612, 0x01040508,
  0x400c1dbe, 0x02006612, 0x0c401d23, 0x0c1d40be,
  0x66030612, 0x1d0c4014, 0x22002911, 0x04001009,
  // [1870]
  0x12041d07, 0x29270c12, 0x1d001021, 0x02050112,
  0x01191760, 0x17140112, 0x19221607, 0x060b1407,
  0x14002b21, 0x0c170560, 0x141f066f, 0x66001912,
  0x052b1f21, 0x120210a4, 0x0d000502, 0x300e2313,
  // [1880]
  0x2b002112, 0x0000430a, 0x0f0801a4, 0x250e30a4,
  0x23300ea4, 0x06000b21, 0x1e003008, 0x04191820,
  0x27210412, 0x012b18ad, 0x082b02cf, 0x01061207,
  0x046603ad, 0x19002122, 0x06140b12, 0x1d000b20,
  // [1890]
  0x08020b23, 0x2b660608, 0x0c000307, 0x06001021,
  0x2b170f08, 0x271f0112, 0x0c122ba4, 0x10000414,
  0x400b12a4, 0x0e233022, 0x100406a4, 0x06012912,
  0x1d000202, 0x22001521, 0x0f0801af, 0x2b1901af,
  // [18a0]
  0x011d0c12, 0x100c1da4, 0x1d041512, 0x03050420,
  0x010f1512, 0x190415af, 0x15001621, 0x1c1e2521,
  0x21162b12, 0x0e002323, 0x12152221, 0x06192207,
  0x16210808, 0x12191512, 0x03171221, 0x10001420,
  // [18b0]
  0x171012be, 0x12451d12, 0x08041512, 0x05003812,
  0x0d060112, 0x29122121, 0x29274012, 0x06001f13,
  0x06002213, 0x042216ad, 0x23251e21, 0x3f2927af,
  0x03180fac, 0x222119be, 0x22192121, 0x22213f6f,
  // [18c0]
  0x22193fcf, 0x0f004511, 0x0f3822af, 0x1e1c2308,
  0x0f0d3809, 0x1c301e07, 0x2b2201a4, 0x1d001622,
  0x43000c11, 0x0b001402, 0x40121d12, 0x10270108,
  0x0b272955, 0x25002314, 0x21080160, 0x080f1707,
  // [18d0]
  0x0c121d07, 0x10020355, 0x03106609, 0x01001821,
  0x101715a4, 0x0d0f38a4, 0x010317a4, 0x04221f09,
  0x04000812, 0x3f271621, 0x02082b09, 0x01002112,
  0x0e251caf, 0x16453f12, 0x43060108, 0x16001507,
  // [18e0]
  0x100b0223, 0x1d001513, 0x1545401f, 0x02401060,
  0x190b0212, 0x45000c34, 0x0c401d6f, 0x25230e60,
  0x100b0812, 0x010c1255, 0x0e2330bb, 0x154012ad,
  0x0b001d20, 0x29032709, 0x1d002708, 0x0c002b22,
  // [18f0]
  0x031d2107, 0x1d454021, 0x0c151909, 0x0c031007,
  0x2b016609, 0x1d000b12, 0x45001235, 0x40061909,
  0x10000807, 0x0c100b09, 0x1e1c2311, 0x041d2907,
  0x251c1e09, 0x40033809, 0x0e002511, 0x020b14ad,
  // [1900]
  0x0d1f2113, 0x060b1507, 0x380b02a4, 0x01172b60,
  0x10002b22, 0x1d010b12, 0x29000521, 0x08170f13,
  0x01050834, 0x38000514, 0x43080f22, 0x140c1f60,
  0x08001209, 0x01051f22, 0x38012907, 0x10290312,
  // [1910]
  0x01050609, 0x19100660, 0x140b1fbc, 0x011f0421,
  0x02100612, 0x0f050112, 0x02450112, 0x03000121,
  0x10052721, 0x03061f23, 0x2b000421, 0x290608bb,
  0x22002114, 0x0d120f07, 0x401d1512, 0x151918bc,
  // [1920]
  0x0b000412, 0x1e252321, 0x0b041907, 0x30001e07,
  0x451708af, 0x66032212, 0x12001520, 0x40004512,
  0x66041912, 0x2b290112, 0x10124012, 0x15006612,
  0x03066622, 0x15012bac, 0x100b1212, 0x30002320,
  // [1930]
  0x016622af, 0x06193fad, 0x12021708, 0x0d292722,
  0x16000f12, 0x1e300e07, 0x06000207, 0x02061007,
  0x10041960, 0x1f000513, 0x15000d12, 0x0b221507,
  0x01401007, 0x14000212, 0x12292722, 0x1d4045a4,
  // [1940]
  0x140366ad, 0x400b5112, 0x08001911, 0x1e0e3008,
  0x1e1c25be, 0x45001808, 0x0000020a, 0x1f012b12,
  0x10020b13, 0x0d001709, 0x1c0e2512, 0x06000c14,
  0x0e301c08, 0x0f380d22, 0x100b0208, 0x01223821,
  // [1950]
  0x0d0f45ad, 0x06010c13, 0x250e1e11, 0x38000808,
  0x0d0f21be, 0x15140321, 0x1d2212ac, 0x213f0421,
  0x140c0311, 0x020d0112, 0x12003810, 0x0f000d20,
  0x05013f21, 0x10000621, 0x1d170112, 0x0d0f45af,
  // [1960]
  0x211601af, 0x140b1021, 0x12451f10, 0x05191612,
  0x170f0d07, 0x02000112, 0x05010307, 0x38000f13,
  0x29012212, 0x16660112, 0x182166a4, 0x05000d08,
  0x0d010fa4, 0x08003823, 0x04002221, 0x02061021,
  // [1970]
  0x0d3f01af, 0x0e1e2555, 0x1c1e2523, 0x0f0105ac,
  0x1d151607, 0x0b1019a4, 0x14061021, 0x1e1c23a4,
  0x0c100b08, 0x1c251e02, 0x100b0307, 0x1c2530bc,
  0x1d403f13, 0x10660308, 0x04191408, 0x160c2b12,
  // [1980]
  0x0c1d16a4, 0x0c1d40bc, 0x27000609, 0x0b1401af,
  0x060c2707, 0x02000407, 0x04000312, 0x251e1cbb,
  0x190b14ad, 0x140b51af, 0x0c010307, 0x1e1c25ad,
  0x19660413, 0x45004020, 0x3f002113, 0x06001413,
  // [1990]
  0x0b1001ad, 0x38002913, 0x38001708, 0x0f380109,
  0x0b021002, 0x170b0208, 0x16272908, 0x02190b12,
  0x2b010d60, 0x22001708, 0x06001407, 0x01191012,
  0x19001412, 0x02124508, 0x03003f21, 0x190f0b12,
  // [19a0]
  0x22001714, 0x150c4009, 0x19002211, 0x0f012bac,
  0x08000614, 0x251e0e07, 0x1d164012, 0x12061d6f,
  0x2b000111, 0x061d0f07, 0x08000608, 0x45001d1f,
  0x10002707, 0x08010507, 0x12450f08, 0x1e301c13,
  // [19b0]
  0x01000513, 0x181001af, 0x250e2311, 0x45000f13,
  0x0f140dad, 0x0d0f06ad, 0x06000212, 0x21000614,
  0x18000f08, 0x2b002713, 0x12002208, 0x17001808,
  0x03003f22, 0x06006608, 0x450c3f12, 0x30002511,
  // [19c0]
  0x031d0612, 0x01021012, 0x45004008, 0x2b006612,
  0x2b006608, 0x0c0b3f12, 0x1d0c1807, 0x21002909,
  0x300e23bc, 0x1d1640a9, 0x10161d09, 0x080401a4,
  0x251e0e09, 0x0c001710, 0x231e2520, 0x38080112,
  // [19d0]
  0x0c082b07, 0x16004021, 0x041d4511, 0x1d000c22,
  0x66000111, 0x38001711, 0x07005c33, 0x1d6601a4,
  0x15184509, 0x030627af, 0x04161908, 0x0e1c2308,
  0x02100b09, 0x2b004013, 0x06140155, 0x45401d60,
  // [19e0]
  0x0b1214ad, 0x38452707, 0x1c000e35, 0x29002234,
  0x18000611, 0x06023f22, 0x0c0301a4, 0x19001707,
  0x06272912, 0x402729af, 0x29021760, 0x18000414,
  0x1d001214, 0x0f001408, 0x276629af, 0x0c1d2207,
  // [19f0]
  0x18002108, 0x0c451222, 0x06021008, 0x38100209,
  0x06003f11, 0x011f2b12, 0x0f14180c, 0x03000622,
  0x29002735, 0x38100ba4, 0x033f01a4, 0x38001812,
  0x292b43bc, 0x27211f08, 0x0f001808, 0x0b041009,
  // [1a00]
  0x2718436f, 0x382b01af, 0x0d0f1712, 0x151f2bbe,
  0x170108a4, 0x2b1d4512, 0x050d0112, 0x3f272912,
  0x08451daf, 0x01002b22, 0x080f1faf, 0x0c210112,
  0x18660382, 0x251c1e21, 0x2b012912, 0x06000102,
  // [1a10]
  0x0f2901a4, 0x25002313, 0x0b212255, 0x08001907,
  0x0f0517a4, 0x14000611, 0x22124509, 0x16270460,
  0x06191807, 0x22193f20, 0x18002b11, 0x06272212,
  0x3f000114, 0x06145112, 0x190504be, 0x06001f22,
  // [1a20]
  0x012b1912, 0x2b061812, 0x1f000b20, 0x18045112,
  0x19211807, 0x06010f08, 0x27001421, 0x1f2b0baf,
  0x16001f12, 0x66050314, 0x380d0f09, 0x032b0612,
  0x191f06be, 0x30231e07, 0x38040b12, 0x23300e55,
  // [1a30]
  0x12000f12, 0x1d0c4009, 0x19002108, 0x1d124008,
  0x38001702, 0x0f0529a4, 0x22382909, 0x16002713,
  0x19141208, 0x17052107, 0x1e0e2323, 0x3f000422,
  0x0f3806ad, 0x2b222908, 0x30251e60, 0x192704af,
  // [1a40]
  0x08040512, 0x06000811, 0x45120612, 0x10010c07,
  0x040621a4, 0x66080460, 0x40191808, 0x062b1920,
  0x19040555, 0x29660baf, 0x251e1cac, 0x18004512,
  0x19660313, 0x1c250e11, 0x2b0301a4, 0x03013807,
  // [1a50]
  0x12221820, 0x0d1801af, 0x2b660322, 0x186601a4,
  0x192201af, 0x0b221934, 0x0e251c21, 0x03003f23,
  0x040c1608, 0x0f0c0509, 0x0b010407, 0x29000111,
  0x1f000121, 0x3f002114, 0x0c001907, 0x1d4001af,
  // [1a60]
  0x01062bad, 0x0d0f2b12, 0x1f2b0112, 0x0b002b12,
  0x06042755, 0x29271421, 0x022901af, 0x020b0ca4,
  0x2b000414, 0x01401d12, 0x1f190112, 0x21153f09,
  0x18063f08, 0x662b01af, 0x29041912, 0x19401d20,
  // [1a70]
  0x222927af, 0x23301c09, 0x10191807, 0x29402760,
  0x270406a4, 0x0d010821, 0x04061908, 0x29382709,
  0x251c2322, 0x43010507, 0x08380c07, 0x401901af,
  0x2b4001af, 0x66032b12, 0x022b01cf, 0x1d181221,
  // [1a80]
  0x1d124555, 0x45660108, 0x19180121, 0x1d000b14,
  0x2b190112, 0x03011960, 0x19180112, 0x0d000513,
  0x032b0120, 0x2b000121, 0x19000508, 0x01000512,
  0x19161812, 0x210201af, 0x1d2b0112, 0x120c4514,
  // [1a90]
  0x40190112, 0x04001613, 0x010f1907, 0x14000208,
  0x0f011f08, 0x19000f08, 0x2b6601ad, 0x1d164013,
  0x45210108, 0x18041908, 0x1e000e22, 0x190204af,
  0x0d000811, 0x0e1e2560, 0x0b0302be, 0x0b100208,
  // [1aa0]
  0x381f01af, 0x16004513, 0x030b0222, 0x012b38bb,
  0x101419ac, 0x10030407, 0x16660207, 0x3f012709,
  0x040b02ad, 0x01381f13, 0x22030108, 0x16451dac,
  0x1e253014, 0x0f0d38bc, 0x43001907, 0x05382207,
  // [1ab0]
  0x220601a4, 0x231c3008, 0x0b046614, 0x1e232507,
  0x0e1e2355, 0x1c0e3012, 0x301c0ebb, 0x18001d09,
  0x16292713, 0x06020b08, 0x3f0501af, 0x15001420,
  0x03060107, 0x16000d08, 0x16003f20, 0x05041909,
  // [1ac0]
  0x04192709, 0x120c0112, 0x0c161522, 0x221d0407,
  0x02060b12, 0x0d380fad, 0x0c001408, 0x30231caf,
  0x45180f60, 0x300e2514, 0x180f1412, 0x23250e14,
  0x0f1f4512, 0x0c0122a4, 0x0f001f09, 0x19001507,
  // [1ad0]
  0x192204a4, 0x45000c21, 0x12006612, 0x23251caf,
  0x191d2707, 0x1f000f20, 0x14001808, 0x0d000f21,
  0x0b0602ad, 0x293f1913, 0x0c013f08, 0x1d002112,
  0x251c1ea4, 0x04272112, 0x050f0109, 0x0f012b12,
  // [1ae0]
  0x08170112, 0x15000421, 0x17043f13, 0x05170809,
  0x0c182907, 0x030d0f13, 0x1d0c40be, 0x40292712,
  0x38000f23, 0x270c2121, 0x0e1c3021, 0x2b210c09,
  0x05080109, 0x190416af, 0x01162712, 0x0e233060,
  // [1af0]
  0x14272914, 0x02080112, 0x03002b11, 0x040366bb,
  0x030104a4, 0x0d0f3810, 0x01006611, 0x0f0d3812,
  0x22000407, 0x1d124012, 0x061801ad, 0x1d001811,
  0x0b022b12, 0x251e1c14, 0x020c0b09, 0x0f001711,
  // [1b00]
  0x03046613, 0x1e1c0e6f, 0x0f080d12, 0x06011907,
  0x0e1c1e21, 0x1d004033, 0x12001714, 0x251e2312,
  0x17001408, 0x04001707, 0x29221421, 0x291d2713,
  0x10180b12, 0x660b1834, 0x02052912, 0x030104af,
  // [1b10]
  0x22000521, 0x17002b07, 0x0e1e2309, 0x06000c20,
  0x18450221, 0x172712af, 0x120f4507, 0x0b030812,
  0x12000212, 0x08001720, 0x12031821, 0x190b6612,
  0x210b2221, 0x0b021909, 0x020b0408, 0x223f2912,
  // [1b20]
  0x03660c21, 0x06012109, 0x030502ad, 0x45000808,
  0x220b02be, 0x12020421, 0x14003f13, 0x18100bbe,
  0x0b105112, 0x19222712, 0x1d002713, 0x23251c23,
  0x1f004313, 0x08030d13, 0x16003f11, 0x43001d07,
  // [1b30]
  0x01042212, 0x66291812, 0x220b04bb, 0x66292212,
  0x14004533, 0x04001f11, 0x0d2901ad, 0x19002114,
  0x253023af, 0x0c000114, 0x0b221407, 0x0f041913,
  0x3f001d14, 0x38430512, 0x06000512, 0x45120ca4,
  // [1b40]
  0x06100baf, 0x0f143807, 0x23301c08, 0x17161921,
  0x17003822, 0x10000413, 0x010f1fbc, 0x2b001014,
  0x10021212, 0x050f0d14, 0x19002121, 0x12001d14,
  0x06222b21, 0x03101421, 0x180d0560, 0x0b1d2ba4,
  // [1b50]
  0x66222b13, 0x01041907, 0x16000611, 0x1d403f6f,
  0x06036607, 0x27662913, 0x030b0608, 0x17004308,
  0x0c0306ad, 0x402b01af, 0x27294021, 0x29270613,
  0x050d4512, 0x30230e09, 0x43380507, 0x1e001c09,
  // [1b60]
  0x451240a4, 0x03040112, 0x060110ad, 0x02665112,
  0x0f0127ad, 0x0d3801af, 0x10060312, 0x0b1951a4,
  0x45062208, 0x22061412, 0x12160109, 0x142101af,
  0x04662708, 0x06010311, 0x06002b22, 0x03430107,
  // [1b70]
  0x12381d09, 0x0f080109, 0x031f1608, 0x05060411,
  0x16154512, 0x16271712, 0x1f000512, 0x0c381512,
  0x1d124513, 0x0c1d01af, 0x1f151009, 0x12041921,
  0x030614bb, 0x10001708, 0x380f08af, 0x191d21a4,
  // [1b80]
  0x1c231ebb, 0x16031512, 0x080f4512, 0x160815be,
  0x1d400c12, 0x4516156f, 0x04004513, 0x06040ca4,
  0x1c0e3020, 0x0b000507, 0x27293813, 0x2b000411,
  0x273f29af, 0x293f1421, 0x03001807, 0x1d272913,
  // [1b90]
  0x19003807, 0x08001708, 0x0f160809, 0x27292214,
  0x04160c55, 0x08160c11, 0x08004020, 0x27291912,
  0x03000811, 0x01430812, 0x450c1708, 0x053817ad,
  0x08293813, 0x14273f21, 0x17003814, 0x01162707,
  // [1ba0]
  0x172927af, 0x0b100107, 0x042729af, 0x29041620,
  0x16002b11, 0x05004312, 0x0d664360, 0x15000413,
  0x150b1013, 0x10061408, 0x05004311, 0x19001607,
  0x43000d12, 0x380f1f09, 0x0415166f, 0x43000d11,
  // [1bb0]
  0x43000d09, 0x1e250ea4, 0x45061011, 0x010d0521,
  0x04002b12, 0x010819ac, 0x1d192707, 0x1d1240af,
  0x451901af, 0x052729ad, 0x19040c07, 0x106603af,
  0x17001d08, 0x166603af, 0x19041807, 0x10080412,
  // [1bc0]
  0x05270112, 0x27182113, 0x30251e6f, 0x19221660,
  0x00000503, 0x043816a4, 0x180f0d22, 0x16005113,
  0x1e0e3012, 0x03001511, 0x01141512, 0x22001913,
  0x66150112, 0x14100412, 0x230e1ebb, 0x0f000b13,
  // [1bd0]
  0x0f060107, 0x08001713, 0x06020309, 0x02290109,
  0x0f2201af, 0x22400112, 0x06020baf, 0x14012221,
  0x29042213, 0x0d1d0f14, 0x02191809, 0x030615bc,
  0x45011907, 0x1d104055, 0x021d2212, 0x230e3055,
  // [1be0]
  0x171d04af, 0x182202af, 0x29061021, 0x38270109,
  0x19170814, 0x19382b09, 0x022729a4, 0x1d401921,
  0x38272b12, 0x0b1001ac, 0x0d1f01af, 0x18402912,
  0x10030612, 0x05210112, 0x190501a4, 0x1c231e14,
  // [1bf0]
  0x040366be, 0x27001812, 0x03000408, 0x08190612,
  0x29222708, 0x19291055, 0x250e3013, 0x191410ac,
  0x01453f12, 0x231c2502, 0x17060112, 0x0d060f07,
  0x010b38a4, 0x380601af, 0x01100612, 0x04000808,

  // [1c00]
  0x19036622, 0x01036607, 0x27000814, 0x120b0307,
  0x19400407, 0x290d0108, 0x121d1622, 0x18002112,
  0x66000b12, 0x150b1608, 0x0b002112, 0x301e2555,
  0x0e301c12, 0x17000811, 0x121d0211, 0x0b662712,
  // [1c10]
  0x38056608, 0x02032b21, 0x0d0106a4, 0x10051212,
  0x10060baf, 0x66000334, 0x05012207, 0x1f1051af,
  0x21000f35, 0x04011907, 0x191f0113, 0x062b1f12,
  0x01662baf, 0x1821156f, 0x16001d11, 0x01662b60,
  // [1c20]
  0x030c0112, 0x29181d13, 0x66000320, 0x0000192d,
  0x29212b12, 0x66191009, 0x1f2b1021, 0x1900100d,
  0x04061060, 0x45151255, 0x0d052707, 0x170d16a4,
  0x03001908, 0x221d0c55, 0x0f002209, 0x401801a4,
  // [1c30]
  0x220619ac, 0x230e1caf, 0x1d6601af, 0x2b0419a4,
  0x0d1751af, 0x251c1e12, 0x0d291612, 0x66001412,
  0x010d1607, 0x18015112, 0x401d21bc, 0x01050d07,
  0x06036633, 0x06010cad, 0x21000420, 0x1e252307,
  // [1c40]
  0x40001613, 0x01191207, 0x450c0109, 0x2b1f0112,
  0x1e233012, 0x08401621, 0x18001611, 0x301e1cac,
  0x1000191d, 0x0d000f20, 0x272904af, 0x01080f12,
  0x1e0e25af, 0x251e0e08, 0x1d001607, 0x27292113,
  // [1c50]
  0x29182212, 0x1d401621, 0x1c230e11, 0x01451f07,
  0x08004021, 0x1c1e3012, 0x1d163f60, 0x04660308,
  0x22000602, 0x1e1c3021, 0x12000413, 0x43042107,
  0x66101212, 0x191801af, 0x25301c22, 0x063803ac,
  // [1c60]
  0x3f6619be, 0x01170507, 0x03661912, 0x301c2355,
  0x25003011, 0x0c451207, 0x38001922, 0x03270112,
  0x03083809, 0x05660322, 0x0366066f, 0x06010b07,
  0x19001022, 0x1d124011, 0x401d0ca4, 0x5c00070d,
  // [1c70]
  0x0d0b5107, 0x17001d21, 0x38001d09, 0x01082907,
  0x04660360, 0x01000807, 0x450c01ac, 0x0f0d1f60,
  0x062b0155, 0x016608ad, 0x27002911, 0x036619af,
  0x10190407, 0x1c300e08, 0x10190460, 0x10190411,
  // [1c80]
  0x1c1e25a4, 0x29182109, 0x010616af, 0x29272114,
  0x271829af, 0x04101907, 0x231e0eaf, 0x660312af,
  0x22292721, 0x02032107, 0x382729af, 0x05381722,
  0x301e23af, 0x17002213, 0x181712af, 0x16000821,
  // [1c90]
  0x10060f21, 0x27173834, 0x010d04bb, 0x2b1f0111,
  0x08040112, 0x0d150fac, 0x010b5107, 0x12401d11,
  0x0d2b0f12, 0x38080d21, 0x036604a4, 0x012b1f09,
  0x38010612, 0x180c45ad, 0x01292b12, 0x06000523,
  // [1ca0]
  0x0d000c13, 0x05001620, 0x19001407, 0x1f080112,
  0x22211921, 0x21450baf, 0x0d0501a4, 0x3f1d1921,
  0x22001907, 0x190b01ad, 0x140b0209, 0x16213f23,
  0x22190412, 0x05122b07, 0x38151607, 0x010221af,
  // [1cb0]
  0x01171921, 0x213f0c08, 0x1d451207, 0x29273809,
  0x16270108, 0x010321af, 0x38001707, 0x0c000613,
  0x03000c02, 0x1d180d09, 0x22000313, 0x03270608,
  0x12401d6f, 0x1d120c09, 0x1e253011, 0x18161d09,
  // [1cc0]
  0x22030655, 0x40161d09, 0x381601a4, 0x0b190207,
  0x38290412, 0x1e2530a4, 0x38001502, 0x1d032709,
  0x06292720, 0x0e232508, 0x382922a4, 0x080c1d09,
  0x041516a4, 0x66220112, 0x0f010307, 0x03272913,
  // [1cd0]
  0x080566a4, 0x300e2321, 0x06661955, 0x0f0601af,
  0x10001408, 0x010c0807, 0x05081713, 0x04272960,
  0x080106af, 0x230e1c09, 0x06031fa4, 0x16001522,
  0x100301af, 0x19292711, 0x04001511, 0x0c0314ad,
  // [1ce0]
  0x45021412, 0x15001623, 0x300e23ad, 0x160f21af,
  0x271d01af, 0x07005c35, 0x0f1d3fad, 0x03190408,
  0x0e1e2314, 0x101d1407, 0x0d083809, 0x18000d11,
  0x18003f11, 0x1e2530ad, 0x0d080113, 0x0c102207,
  // [1cf0]
  0x01273f12, 0x3f081422, 0x0e1e3021, 0x301e2512,
  0x271f2212, 0x00001e2d, 0x45120c22, 0x15001d13,
  0x01060311, 0x14002212, 0x16001509, 0x03193f11,
  0x16152111, 0x03010608, 0x05030813, 0x19001d12,
  // [1d00]
  0x162b0607, 0x1f000612, 0x0c064021, 0x0c00061f,
  0x01000613, 0x45120621, 0x2b001412, 0x43661f55,
  0x0c004508, 0x23250ead, 0x0f0301af, 0x10180baf,
  0x1d060c60, 0x0c002107, 0x010638a4, 0x03661421,
  // [1d10]
  0x1f000621, 0x1d400b12, 0x16380f08, 0x0e251c20,
  0x19160ca4, 0x380551af, 0x17050baf, 0x12031408,
  0x43272913, 0x18000122, 0x05381709, 0x43001407,
  0x29212713, 0x270f0112, 0x1f004321, 0x231e25ad,
  // [1d20]
  0x12184312, 0x050c0411, 0x16010ca4, 0x1e3023be,
  0x12002111, 0x06001502, 0x270f0512, 0x220201af,
  0x272219a4, 0x15400808, 0x19223f09, 0x190f0407,
  0x0d000507, 0x01020620, 0x190c1faf, 0x140229af,
  // [1d30]
  0x0d140209, 0x02001012, 0x0d0f2212, 0x030d2212,
  0x0e253013, 0x0b660308, 0x01030612, 0x02000807,
  0x2b0222be, 0x19022221, 0x1e300ea4, 0x30231ca4,
  0x0f270809, 0x251e1c55, 0x0b0266af, 0x01081509,
  // [1d40]
  0x03020112, 0x27002908, 0x222b0355, 0x012b1f6f,
  0x080c1f07, 0x1f000614, 0x21002709, 0x100c0308,
  0x38001507, 0x17010355, 0x380c1fac, 0x1f380fbe,
  0x08000414, 0x08000f02, 0x16004508, 0x02100107,
  // [1d50]
  0x660f0d13, 0x06001508, 0x29000108, 0x100166af,
  0x43001412, 0x380f03af, 0x17002207, 0x0f080ca4,
  0x010f1f08, 0x08000d21, 0x03002208, 0x1d041907,
  0x05170113, 0x02010f09, 0x05000309, 0x27292114,
  // [1d60]
  0x151945af, 0x05040109, 0x19011607, 0x06006620,
  0x3f210509, 0x02101807, 0x050412a4, 0x30231e11,
  0x05191214, 0x170c0309, 0x0f271609, 0x17000311,
  0x22002113, 0x081d3812, 0x1d0501af, 0x02050109,
  // [1d70]
  0x0c173855, 0x38080c12, 0x02006613, 0x12154511,
  0x08380c21, 0x19403f20, 0x10030baf, 0x100b1909,
  0x1e0e30bc, 0x381d1912, 0x19001721, 0x0b021421,
  0x120b1011, 0x66010cbc, 0x150f2212, 0x16001521,
  // [1d80]
  0x05062707, 0x1f000309, 0x230e1c22, 0x27041960,
  0x03060412, 0x401d3fbe, 0x19040d13, 0x1f3f6609,
  0x21000409, 0x02061009, 0x0e1c2508, 0x1c1e2322,
  0x230e1e08, 0x04190608, 0x01430c07, 0x451d1209,
  // [1d90]
  0x1c001e08, 0x121d4009, 0x0000100a, 0x22181008,
  0x45121d07, 0x0f050107, 0x19000611, 0x17060509,
  0x1f001213, 0x03050da4, 0x400c1da4, 0x1d001407,
  0x12000309, 0x03000108, 0x230e2507, 0x0e1c1e08,
  // [1da0]
  0x0600100d, 0x101822bc, 0x1766036f, 0x01383f12,
  0x161d4013, 0x034001a4, 0x12380112, 0x10040ba4,
  0x010805be, 0x060c3fbc, 0x18002214, 0x011f0812,
  0x38026613, 0x04003f11, 0x400f45af, 0x010b0607,
  // [1db0]
  0x30230e23, 0x06001607, 0x15164023, 0x15001409,
  0x121d0c14, 0x12151607, 0x0b021407, 0x38030f07,
  0x030166ad, 0x04001409, 0x38001808, 0x38140f13,
  0x0f0d0807, 0x190b06ac, 0x0d661aa4, 0x05061007,
  // [1dc0]
  0x14001814, 0x21002213, 0x16001535, 0x031701a4,
  0x0d000802, 0x231c3007, 0x2b006613, 0x0b436608,
  0x18036620, 0x1c1e2522, 0x66001713, 0x14180612,
  0x19272121, 0x451d0caf, 0x04003f21, 0x010c0813,
  // [1dd0]
  0x0d061707, 0x0c0117af, 0x100c0108, 0x0e1e23a4,
  0x231e0e08, 0x1e302508, 0x12401d21, 0x45121dad,
  0x27212921, 0x29274021, 0x08000c11, 0x06451fad,
  0x12161dac, 0x15001d21, 0x12184507, 0x06100308,
  // [1de0]
  0x45001613, 0x1e253007, 0x08051f12, 0x16001d08,
  0x04191412, 0x140c1008, 0x14001014, 0x18001514,
  0x292740a4, 0x03001907, 0x121d1612, 0x2b003813,
  0x05001613, 0x18140460, 0x0f042212, 0x010614a4,
  // [1df0]
  0x020c0112, 0x17120da4, 0x12401611, 0x15000c13,
  0x12221d12, 0x38000520, 0x430f1dac, 0x401d12a4,
  0x04000112, 0x010d0307, 0x1e001c13, 0x17032209,
  0x080c1da4, 0x14000221, 0x17430607, 0x0c1d3f12,
  // [1e00]
  0x380f0411, 0x1d4512af, 0x1f0f0c09, 0x0c002210,
  0x1d2729af, 0x2b0103a4, 0x0c000f11, 0x0b2b6612,
  0x10000c07, 0x2b220cac, 0x380d0f22, 0x01003807,
  0x06001032, 0x0c2b6607, 0x2200181f, 0x0d000112,
  // [1e10]
  0x190b0112, 0x12021911, 0x010651af, 0x2b060112,
  0x04000512, 0x16150112, 0x43006607, 0x19010313,
  0x19020b11, 0x05011712, 0x16451212, 0x45001d14,
  0x1f000f09, 0x16081d21, 0x0f030809, 0x40002913,
  // [1e20]
  0x032901ad, 0x45001509, 0x1d144022, 0x04003807,
  0x062927af, 0x12454014, 0x01020b22, 0x19100207,
  0x0d0117bb, 0x0d0f1fac, 0x29271812, 0x37004e10,
  0x1d214012, 0x38660321, 0x251c0ea4, 0x1e0e3002,
  // [1e30]
  0x19000313, 0x381d0809, 0x45000c11, 0x19010307,
  0x450c2b20, 0x03170112, 0x170366bc, 0x45000507,
  0x43001408, 0x050c66ac, 0x160f3813, 0x08450c07,
  0x10450c12, 0x17000322, 0x10000c12, 0x050366be,
  // [1e40]
  0x1e1c2313, 0x080c4555, 0x0c001810, 0x0f0c3809,
  0x06031fac, 0x380f0808, 0x380f0d12, 0x0e302508,
  0x0e1c2511, 0x38143f21, 0x15003f12, 0x0b012b07,
  0x06020b07, 0x0b210213, 0x102b0baf, 0x21193f21,
  // [1e50]
  0x301e1c12, 0x1d191512, 0x0d061912, 0x22003f12,
  0x19001820, 0x0d011412, 0x45060112, 0x010f0307,
  0x30232509, 0x0b0214ac, 0x16172712, 0x27001911,
  0x020b1022, 0x03661921, 0x0f380d09, 0x10001212,
  // [1e60]
  0x251e0ea4, 0x03080507, 0x661f05af, 0x45001607,
  0x231e0e13, 0x38010fa4, 0x1c003022, 0x17430d08,
  0x21041912, 0x18002913, 0x19001814, 0x01001802,
  0x0f080612, 0x1d4018af, 0x01221807, 0x181d19af,
  // [1e70]
  0x21040baf, 0x38011907, 0x1f3f0112, 0x0e3023bc,
  0x01060dac, 0x01212b12, 0x05062207, 0x1d002214,
  0x05272912, 0x03000c14, 0x0319666f, 0x380d0508,
  0x0f010512, 0x14184512, 0x0c0501a4, 0x16000c08,
  // [1e80]
  0x0c001212, 0x190166ad, 0x15053808, 0x05003808,
  0x1c302313, 0x19122712, 0x18000212, 0x0e251c11,
  0x00000e2d, 0x08380f21, 0x03002707, 0x451d0812,
  0x1d002211, 0x04401da4, 0x10381707, 0x401d1912,
  // [1e90]
  0x08001d07, 0x251e23af, 0x23251c12, 0x08060507,
  0x020b2b07, 0x08105112, 0x40000823, 0x190804ac,
  0x0e302313, 0x21001709, 0x05010fa4, 0x182b1012,
  0x2b020ba4, 0x1e0e3014, 0x05430108, 0x19100607,
  // [1ea0]
  0x011d0c07, 0x013f2b13, 0x124301a4, 0x1d454060,
  0x12150c07, 0x230e1e02, 0x0c0138ac, 0x27000d12,
  0x40004514, 0x05012b12, 0x0c124522, 0x23250eac,
  0x12150d13, 0x43010d07, 0x45004021, 0x25231e13,
  // [1eb0]
  0x0c001d02, 0x1c0e1e34, 0x170c0809, 0x1c0e235e,
  0x01051207, 0x05031208, 0x040d1709, 0x2b010ca4,
  0x1c250eaf, 0x042b0b55, 0x10040112, 0x45120521,
  0x19011dac, 0x23001c09, 0x14451813, 0x18151607,
  // [1ec0]
  0x380d0f60, 0x2b0601ac, 0x06180507, 0x370e23bb,
  0x10030611, 0x02000514, 0x45401d22, 0x66020313,
  0x010d2712, 0x1e002323, 0x231e25ac, 0x380d0faf,
  0x301c2308, 0x45121da4, 0x0e302308, 0x45000d08,
  // [1ed0]
  0x03220c07, 0x0c004522, 0x0d380fa4, 0x23301cac,
  0x124517a4, 0x45000c07, 0x0c001607, 0x0f0d45af,
  0x1d4015be, 0x12000c11, 0x30231c09, 0x170d1fad,
  0x0b001023, 0x19001720, 0x153805af, 0x05001021,
  // [1ee0]
  0x1f004021, 0x38000113, 0x03196613, 0x02000b34,
  0x08001511, 0x27211921, 0x2b211aaf, 0x38010521,
  0x19000507, 0x27180112, 0x0e302314, 0x0f003813,
  0x19145112, 0x45124013, 0x02221212, 0x1d0c1907,
  // [1ef0]
  0x1d010fa4, 0x380f0108, 0x01000207, 0x30001e02,
  0x1f0f0112, 0x45270c12, 0x16006608, 0x66001820,
  0x0f1402af, 0x0c002123, 0x060127a4, 0x0d450c07,
  0x19001520, 0x191651af, 0x192b14ad, 0x17000808,
  // [1f00]
  0x21222b21, 0x120c40ad, 0x301c2512, 0x0b0d0207,
  0x0d380c07, 0x18000513, 0x041805bb, 0x12001612,
  0x08162ba4, 0x06041812, 0x0d1f0112, 0x1f012b09,
  0x05030109, 0x18000512, 0x18000522, 0x05001822,
  // [1f10]
  0x01000521, 0x05001823, 0x051d3fad, 0x01001008,
  0x1d292711, 0x04001008, 0x04000207, 0x1f060809,
  0x01066612, 0x10220112, 0x2b030b20, 0x01002220,
  0x08041912, 0x0d0f27ad, 0x040210ac, 0x1d000f08,
  // [1f20]
  0x19404507, 0x14000f13, 0x2b001f12, 0x06660360,
  0x05060808, 0x08142baf, 0x19060407, 0x0d001912,
  0x0f0106ad, 0x06036621, 0x22030621, 0x1d002223,
  0x0f0d1855, 0x450b1d12, 0x380508ac, 0x0f0108a4,
  // [1f30]
  0x01000812, 0x031504ac, 0x040366bc, 0x300e1cad,
  0x1e231caf, 0x25003023, 0x66002713, 0x12451413,
  0x062201af, 0x0e1e2320, 0x03660220, 0x66031914,
  0x0f002113, 0x196603bc, 0x19010412, 0x06002710,
  // [1f40]
  0x19030407, 0x03101d08, 0x03661909, 0x020b27af,
  0x0b061855, 0x05000811, 0x29061921, 0x03660409,
  0x060201af, 0x02003f11, 0x0d0f0809, 0x06003820,
  0x66000812, 0x06002b20, 0x06193f12, 0x45001f13,
  // [1f50]
  0x030b0209, 0x192927a4, 0x12450fbb, 0x01192912,
  0x301e2509, 0x271d2909, 0x12100112, 0x0d0f18a4,
  0x45120cbe, 0x3f001914, 0x12002207, 0x08180112,
  0x1e000e09, 0x0b002108, 0x17292713, 0x08001711,
  // [1f60]
  0x430d1207, 0x300e2314, 0x40660355, 0x10000107,
  0x27163f12, 0x2b036660, 0x0f170109, 0x250e23af,
  0x15030208, 0x0f0366ad, 0x040f15ac, 0x100501a4,
  0x0000160a, 0x1d4015af, 0x060366a4, 0x18004307,
  // [1f70]
  0x14020baf, 0x14661908, 0x060501ac, 0x38450611,
  0x18000f07, 0x181027af, 0x19170407, 0x0b030112,
  0x010508bc, 0x173f0220, 0x04002113, 0x15000621,
  0x38081fbc, 0x0f000c12, 0x18221912, 0x12180f09,
  // [1f80]
  0x0b272112, 0x1d191221, 0x080d1daf, 0x0b1014bc,
  0x08001520, 0x29272113, 0x222729af, 0x172701a4,
  0x151d4012, 0x1c252313, 0x04001512, 0x45004011,
  0x23251eaf, 0x66002b21, 0x04001211, 0x043f0521,
  // [1f90]
  0x15000420, 0x01380512, 0x22181910, 0x19010409,
  0x14004313, 0x0d0f38cf, 0x04003821, 0x10000c10,
  0x02210112, 0x0f3817a4, 0x22003f11, 0x14060412,
  0x04151660, 0x05001421, 0x40161d07, 0x14002b08,
  // [1fa0]
  0x04191007, 0x220302a4, 0x01050360, 0x301c1e21,
  0x10004513, 0x12184508, 0x124518bb, 0x430f0112,
  0x014003ad, 0x0f1218af, 0x45001412, 0x0c061621,
  0x0d010faf, 0x18000614, 0x0b062907, 0x25301e07,
  // [1fb0]
  0x1d002709, 0x10001935, 0x03016607, 0x0c003f20,
  0x66022b21, 0x01051707, 0x01002223, 0x06030112,
  0x220201a4, 0x25233002, 0x16451d02, 0x184512af,
  0x02100b23, 0x061701af, 0x1c302520, 0x080f1708,
  // [1fc0]
  0x18004312, 0x0d1418ad, 0x45121809, 0x2b003809,
  0x0f380808, 0x0f184509, 0x031966af, 0x10001414,
  0x0f1d4512, 0x0d270114, 0x01000520, 0x12000f11,
  0x0f292b12, 0x011619ad, 0x170c0d11, 0x05451212,
  // [1fd0]
  0x100b0302, 0x1214456f, 0x181d4008, 0x211451af,
  0x0c1d4511, 0x06003f13, 0x17080512, 0x08401513,
  0x380f1f13, 0x01224009, 0x08000521, 0x0e231c21,
  0x18000f11, 0x0e233014, 0x1e1c0e60, 0x081d1507,
  // [1fe0]
  0x08010555, 0x15003f13, 0x08401d60, 0x04002714,
  0x1d0c45a4, 0x2b660312, 0x660601af, 0x06030baf,
  0x17000f14, 0x17292112, 0x16001d22, 0x01100baf,
  0x0d0f0512, 0x066603ad, 0x0d0f3823, 0x14000120,
  // [1ff0]
  0x271951af, 0x05010cad, 0x12451d21, 0x12000508,
  0x250e1e14, 0x15170808, 0x1f1d166f, 0x25003009,
  0x02100bce, 0x05010812, 0x03060807, 0x451d1207,
  0x06101412, 0x06001f11, 0x060b10af, 0x05000820,

  // [2000]
  0x19031011, 0x05000807, 0x12450f09, 0x1c0e23af,
  0x03002b07, 0x1d400ca4, 0x17081555, 0x020503a4,
  0x03020b14, 0x19042160, 0x043f2121, 0x66002213,
  0x19001713, 0x04002120, 0x160219a4, 0x02180412,
  // [2010]
  0x050601ad, 0x180204bc, 0x0c000409, 0x22001d11,
  0x27401dbe, 0x12003f12, 0x1d212211, 0x22001912,
  0x04003f23, 0x162729af, 0x220129a4, 0x0e001c35,
  0x062b01a4, 0x120c4555, 0x1e232512, 0x0d1d1212,
  // [2020]
  0x06140bad, 0x160419be, 0x22190460, 0x04193faf,
  0x12001813, 0x12430c07, 0x12004020, 0x16000108,
  0x19002913, 0x06000c12, 0x45010c07, 0x17062b07,
  0x0e302322, 0x0c000d07, 0x380f0d08, 0x23002523,
  // [2030]
  0x1d2b01af, 0x0e002321, 0x0d0638a4, 0x0000240a,
  0x1f003f14, 0x0b021008, 0x0b0206af, 0x0c161807,
  0x0f000512, 0x10660607, 0x22001007, 0x660319bb,
  0x03020107, 0x1c0e3011, 0x19031f55, 0x0e251e6f,
  // [2040]
  0x66101912, 0x1c0e2320, 0x2b010607, 0x03000b08,
  0x25003007, 0x12000511, 0x03156607, 0x1d450cad,
  0x270d0c60, 0x01020baf, 0x0c1d1409, 0x45000512,
  0x270f06ad, 0x23251e6f, 0x08001420, 0x38180f12,
  // [2050]
  0x0c403fad, 0x27010812, 0x0d081fbe, 0x05081f12,
  0x040b2222, 0x27010cbc, 0x29270813, 0x166602af,
  0x66160f12, 0x43000607, 0x213f27af, 0x1d041707,
  0x01002909, 0x1d1940a4, 0x0b1017ad, 0x1d080f08,
  // [2060]
  0x23302509, 0x06001412, 0x0c002213, 0x02081902,
  0x12401d12, 0x0f0d1707, 0x25000e09, 0x184512a4,
  0x15221412, 0x06002907, 0x23301e09, 0x04100107,
  0x12004536, 0x150538ad, 0x18001207, 0x15033807,
  // [2070]
  0x01053812, 0x21100b20, 0x0c453f12, 0x25000e22,
  0x1d0c0508, 0x03100608, 0x191503a4, 0x1c0e1e21,
  0x06100b07, 0x301e0ea4, 0x08053fac, 0x01100607,
  0x17181608, 0x66063f12, 0x060210ad, 0x25003013,
  // [2080]
  0x060366ac, 0x032b06ad, 0x433f0112, 0x08170509,
  0x221001af, 0x1c302511, 0x180314af, 0x040d0f12,
  0x100f1921, 0x18000407, 0x2b0614af, 0x02001808,
  0x0d142113, 0x66033f12, 0x080f0dbe, 0x08041921,
  // [2090]
  0x0f1905ac, 0x041917ad, 0x220d0f14, 0x04170507,
  0x16001412, 0x0d191021, 0x0f080dbe, 0x293f0660,
  0x3f142712, 0x400819ad, 0x0d3f0f14, 0x25001e20,
  0x146651af, 0x171d2707, 0x10013f09, 0x04384508,
  // [20a0]
  0x03010b11, 0x04192209, 0x02145112, 0x451d40ad,
  0x16031955, 0x06030b12, 0x19002202, 0x0b054009,
  0x1d0817bc, 0x38000f11, 0x03000f07, 0x1d0d3f09,
  0x29061821, 0x401d0808, 0x25231c12, 0x38010312,
  // [20b0]
  0x16000c14, 0x01001507, 0x14660108, 0x40002b12,
  0x430f0107, 0x0b1014a4, 0x0f170112, 0x45121fa4,
  0x1c2325a4, 0x23251c09, 0x401f01a4, 0x25000e21,
  0x1c002510, 0x0b190407, 0x43001f13, 0x38001907,
  // [20c0]
  0x12001507, 0x5c00070e, 0x1d1501a4, 0x060b1807,
  0x170f1212, 0x1c1e25ac, 0x03191007, 0x301e2511,
  0x01062b55, 0x1f003f09, 0x08060107, 0x2b004320,
  0x301e23a4, 0x3f001922, 0x15001211, 0x3f050112,
  // [20d0]
  0x013f29af, 0x0e231ead, 0x0d000f10, 0x020366ad,
  0x45004009, 0x052b0108, 0x06011f21, 0x01001811,
  0x430601af, 0x66001f12, 0x16002912, 0x12001607,
  0x2b0b1012, 0x04000309, 0x18000f14, 0x22000b13,
  // [20e0]
  0x052b2213, 0x170b22a4, 0x272b0112, 0x01006612,
  0x3f001714, 0x380f1809, 0x1e1c0e09, 0x01270812,
  0x052201af, 0x03001911, 0x05030112, 0x38193f12,
  0x08010c08, 0x251e1c60, 0x1e302323, 0x1d050112,
  // [20f0]
  0x0e1e1c14, 0x251e1c23, 0x12450409, 0x15000c11,
  0x1f002713, 0x14061060, 0x03001d07, 0x1e231c09,
  0x21292713, 0x100615bc, 0x401508af, 0x29272121,
  0x08002713, 0x08003f14, 0x0e3023ad, 0x22173813,
  // [2100]
  0x08061507, 0x01291507, 0x08001411, 0x25233012,
  0x0b0c1012, 0x1e002322, 0x271d406f, 0x011d406f,
  0x04183fad, 0x29001521, 0x220f3807, 0x172212af,
  0x020b0dbe, 0x401d2bbb, 0x01002708, 0x011d4511,
  // [2110]
  0x050d0fad, 0x0c000333, 0x16000612, 0x0e1e2333,
  0x2b000513, 0x05010c09, 0x0f002713, 0x1d0c4007,
  0x19003f07, 0x0f660509, 0x25231e22, 0x053801ad,
  0x66000512, 0x38150108, 0x0d000114, 0x10190412,
  // [2120]
  0x27162913, 0x19174007, 0x45180d12, 0x0b000307,
  0x251c1e13, 0x03146607, 0x1e302509, 0x222729be,
  0x14100b60, 0x40223fad, 0x1c2325be, 0x22100b08,
  0x432206a4, 0x1e230ead, 0x2b001621, 0x2b162912,
  // [2130]
  0x0b660314, 0x0b196612, 0x2b001633, 0x10060308,
  0x2b001613, 0x0b0501a4, 0x38001007, 0x66011a12,
  0x270f2213, 0x041910a4, 0x0b000611, 0x300e1c09,
  0x0b140112, 0x031d0cbb, 0x660b0112, 0x03041807,
  // [2140]
  0x0c000212, 0x120501ad, 0x2b060512, 0x1c0e2508,
  0x02001421, 0x29000d12, 0x0d061460, 0x121f0109,
  0x06221007, 0x45001407, 0x0f011207, 0x07005c1f,
  0x40010608, 0x010f3808, 0x10080307, 0x1f002b21,
  // [2150]
  0x01124560, 0x01042b12, 0x25231e21, 0x27291712,
  0x05211712, 0x10002712, 0x01173fac, 0x153f2222,
  0x01042707, 0x172729af, 0x01062b12, 0x15181607,
  0x38081712, 0x0b180409, 0x22292720, 0x29001721,
  // [2160]
  0x0d0f2707, 0x011f2b07, 0x17003f14, 0x1d020caf,
  0x22010460, 0x062b12a4, 0x1d161721, 0x450c1209,
  0x27172121, 0x271929af, 0x18001f20, 0x12001f07,
  0x27192922, 0x66004021, 0x0b0318a4, 0x10041913,
  // [2170]
  0x0c124514, 0x0f450502, 0x03143812, 0x1d0b1009,
  0x66192912, 0x273f1921, 0x150d2b12, 0x12451daf,
  0x0b1003bb, 0x0e301cbc, 0x1c300e14, 0x17001511,
  0x27190413, 0x272919af, 0x16002722, 0x020b1812,
  // [2180]
  0x15001923, 0x45121f11, 0x1e233008, 0x1e001c21,
  0x0f081f12, 0x060105af, 0x100c0209, 0x40001820,
  0x06000421, 0x0c060109, 0x0d002212, 0x0b2212af,
  0x10030509, 0x06293fad, 0x25230ebe, 0x031066a4,
  // [2190]
  0x04003f34, 0x21000812, 0x0d032209, 0x1f000412,
  0x270f0d09, 0x052901af, 0x0f171621, 0x663f0c21,
  0x271d2921, 0x17062bad, 0x29400409, 0x061d17a4,
  0x1d143f13, 0x23001e09, 0x2b001020, 0x0f000107,
  // [21a0]
  0x21003f22, 0x21003f23, 0x15211621, 0x1c232560,
  0x1c1e0e13, 0x292221bc, 0x270f29af, 0x0d271d11,
  0x0d002b11, 0x050d0f13, 0x0d0105af, 0x19031402,
  0x21001622, 0x040501a4, 0x08000102, 0x0c120212,
  // [21b0]
  0x23250e55, 0x10050407, 0x12001711, 0x1d401908,
  0x19272960, 0x0b104014, 0x050112af, 0x14000b23,
  0x0c040607, 0x18191721, 0x02060b60, 0x04001212,
  0x29170112, 0x29191713, 0x291722bc, 0x27001720,
  // [21c0]
  0x14002709, 0x291821af, 0x21002721, 0x18001721,
  0x22661760, 0x12001810, 0x272917ce, 0x27220421,
  0x05060d09, 0x29271721, 0x15660513, 0x0f0d1721,
  0x030d0b12, 0x011706ac, 0x03000b11, 0x38100213,
  // [21d0]
  0x14006622, 0x0d000321, 0x030f3809, 0x05065112,
  0x251c23ac, 0x401d2221, 0x05011d09, 0x0c291712,
  0x1d184012, 0x03063f12, 0x0e002336, 0x17062207,
  0x21023f12, 0x0f1d2912, 0x15190d08, 0x15002220,
  // [21e0]
  0x27050112, 0x661f3faf, 0x12400c13, 0x01000f22,
  0x0b181f11, 0x12451809, 0x180108af, 0x02140b13,
  0x38000f09, 0x251c23af, 0x0d050807, 0x080f0da4,
  0x30232512, 0x45020112, 0x450f12af, 0x0b3806a4,
  // [21f0]
  0x10000b07, 0x08380f20, 0x2b0f1920, 0x66100baf,
  0x2b001933, 0x03061855, 0x19001213, 0x19272913,
  0x162b1f09, 0x06003802, 0x02001911, 0x19000802,
  0x38000107, 0x1f002b20, 0x1f0601a4, 0x0d051755,
  // [2200]
  0x01001412, 0x1c232521, 0x19105112, 0x1f000f13,
  0x10292708, 0x1e301c07, 0x120219a4, 0x080f1907,
  0x01101412, 0x12164508, 0x19100b07, 0x19102707,
  0x0c001209, 0x0d272112, 0x10020b14, 0x3f2729be,
  // [2210]
  0x22212712, 0x171821ce, 0x0f292711, 0x0c1738af,
  0x660b0309, 0x02100b07, 0x40452109, 0x17220109,
  0x3f292722, 0x29062712, 0x0d010f07, 0x060804a4,
  0x0c660311, 0x383f2912, 0x060f2113, 0x0c1d40af,
  // [2220]
  0x380b01af, 0x100b1812, 0x190b04a4, 0x1c1e30ac,
  0x272915be, 0x04191534, 0x3f220b12, 0x0b145111,
  0x01152255, 0x0e002514, 0x08010607, 0x0203666f,
  0x1e0e2509, 0x27186609, 0x12450c23, 0x101906ad,
  // [2230]
  0x03126607, 0x0c121daf, 0x031d0f07, 0x15001614,
  0x03061912, 0x23000e35, 0x0b100621, 0x05000313,
  0x38400d09, 0x08050107, 0x1d380409, 0x230e30ac,
  0x38150107, 0x04000d07, 0x1d001920, 0x1d384009,
  // [2240]
  0x661006af, 0x0e251ebc, 0x0d041909, 0x10660b21,
  0x0d080f09, 0x05000213, 0x0e1e1c12, 0x27451213,
  0x04191008, 0x01030407, 0x210d0111, 0x05011da4,
  0x14001720, 0x1c1e23bc, 0x15100b09, 0x06036614,
  // [2250]
  0x080f2707, 0x210501a4, 0x19660308, 0x270b0208,
  0x16003f12, 0x29124513, 0x12001804, 0x06000808,
  0x21000d09, 0x03000623, 0x301c2521, 0x010b0255,
  0x43012708, 0x03010f07, 0x3f1040bc, 0x663f0112,
  // [2260]
  0x19380fac, 0x19150412, 0x10003807, 0x231c2521,
  0x1d292712, 0x17001902, 0x45001011, 0x401d1207,
  0x66081509, 0x030615a4, 0x23001e13, 0x06011407,
  0x30251e55, 0x140422af, 0x23301cbc, 0x1e0e1c09,
  // [2270]
  0x01220312, 0x1c0e23bc, 0x66142b22, 0x211f2b12,
  0x060419a4, 0x04290b08, 0x020b2712, 0x27062213,
  0x382904af, 0x170412af, 0x0e231eaf, 0x02292711,
  0x18272913, 0x29003821, 0x06660c55, 0x29060508,
  // [2280]
  0x38292722, 0x01221721, 0x301c0eaf, 0x0c001712,
  0x1d151712, 0x03000511, 0x27002212, 0x0c1722bb,
  0x01000409, 0x1d661709, 0x1d290ca4, 0x38000822,
  0x03381f12, 0x01272922, 0x450c1d12, 0x1d400312,
  // [2290]
  0x030b1f21, 0x06002112, 0x171622ad, 0x05124555,
  0x1f002114, 0x06192160, 0x38002b12, 0x21193faf,
  0x0f1721bc, 0x0d430112, 0x3f001621, 0x030105bc,
  0x01066608, 0x18272912, 0x020f1f08, 0x271f1960,
  // [22a0]
  0x0b030408, 0x19661609, 0x030d18ad, 0x10160112,
  0x27001912, 0x27190112, 0x010f2207, 0x23251ebc,
  0x45001f11, 0x161d4555, 0x0b024512, 0x10050608,
  0x17002708, 0x1403066f, 0x66031f21, 0x0b001413,
  // [22b0]
  0x1d40456f, 0x141006ad, 0x25002321, 0x18004012,
  0x401245af, 0x250e30bc, 0x16180460, 0x40011607,
  0x22001f13, 0x121d0c55, 0x66004512, 0x40000133,
  0x01002712, 0x40221612, 0x15292720, 0x291d4013,
  // [22c0]
  0x43011d12, 0x290d0112, 0x1d010609, 0x66060360,
  0x080f0d08, 0x301e25ac, 0x1d4001a4, 0x0f141807,
  0x010619af, 0x231e2555, 0x05012108, 0x38080f09,
  0x29003f21, 0x22001d07, 0x22002122, 0x123f1460,
  // [22d0]
  0x0f382b21, 0x170822af, 0x19002221, 0x0d000107,
  0x011d45af, 0x01041f13, 0x03001913, 0x251c3012,
  0x16406655, 0x0c000308, 0x192b0612, 0x38050107,
  0x03011daf, 0x0b220412, 0x43000111, 0x19210112,
  // [22e0]
  0x04660812, 0x04001821, 0x12000d08, 0x0e251e20,
  0x0b2b0208, 0x0b1404af, 0x01063807, 0x0b220421,
  0x2b001f14, 0x2b050d07, 0x08011607, 0x122b0108,
  0x2b1f01af, 0x05001014, 0x1f001721, 0x100b06ad,
  // [22f0]
  0x40060207, 0x02000314, 0x19102b07, 0x01001902,
  0x2b000422, 0x21020612, 0x104301a4, 0x06102ba4,
  0x22002b08, 0x190218bc, 0x17142208, 0x0b060307,
  0x1d000212, 0x18003812, 0x02002b14, 0x30231c07,
  // [2300]
  0x020b10a4, 0x06100209, 0x1d170607, 0x0f001411,
  0x14031014, 0x0b1501af, 0x38661714, 0x2b011713,
  0x0d2b1713, 0x1d020baf, 0x02000321, 0x23250eaf,
  0x0c380111, 0x03384007, 0x03001420, 0x100b02be,
  // [2310]
  0x19030112, 0x1e251cbc, 0x66030621, 0x27050111,
  0x01051f12, 0x020b1412, 0x1f000120, 0x16450508,
  0x0b100255, 0x1d172121, 0x16001511, 0x0e1c3014,
  0x0c1d4060, 0x212b1f09, 0x180d0112, 0x02080114,
  // [2320]
  0x1c0e25be, 0x01101407, 0x01060307, 0x1d400608,
  0x141d0508, 0x21000413, 0x1d272911, 0x06041907,
  0x17012712, 0x01380fa4, 0x06002b11, 0x03160b12,
  0x01100608, 0x081804a4, 0x27662912, 0x100b0608,
  // [2330]
  0x1d191202, 0x0e1c3007, 0x0e1e3008, 0x1c231e08,
  0x04380509, 0x43000509, 0x16001711, 0x08140107,
  0x05194512, 0x0d2116bb, 0x16063f12, 0x1d002b07,
  0x04036607, 0x1d272112, 0x05210109, 0x06002b08,
  // [2340]
  0x25233022, 0x251c2308, 0x010517af, 0x02010307,
  0x1d0543ac, 0x03210112, 0x060366be, 0x020b1707,
  0x273f2113, 0x02036612, 0x400119ac, 0x04292121,
  0x18001413, 0x3f292713, 0x450b0107, 0x02001f07,
  // [2350]
  0x06050155, 0x22002121, 0x25000e11, 0x2715166f,
  0x1c1e2560, 0x080b0407, 0x432b0107, 0x27290413,
  0x01381821, 0x1d103809, 0x14272912, 0x0b064007,
  0x051003a4, 0x37001e12, 0x061405a4, 0x103801a4,
  // [2360]
  0x0c4501a4, 0x05013808, 0x38000114, 0x45031807,
  0x0d401807, 0x031f0111, 0x66020112, 0x0c022207,
  0x040b0811, 0x04031709, 0x1d454008, 0x0b100214,
  0x0d050107, 0x27042912, 0x03042912, 0x01432907,
  // [2370]
  0x14042b11, 0x1e233013, 0x251c0eaf, 0x010d0812,
  0x230e1eaf, 0x020366bc, 0x12154512, 0x2b030baf,
  0x02040baf, 0x0f004022, 0x08212b12, 0x06000314,
  0x220601af, 0x1f001714, 0x38001f07, 0x23251c14,
  // [2380]
  0x192901ad, 0x080f0509, 0x40151dbc, 0x66000120,
  0x2b660112, 0x0b030107, 0x12062912, 0x25301c21,
  0x40171d12, 0x45401d07, 0x1d164022, 0x0f020ba4,
  0x0b020655, 0x01120408, 0x22030112, 0x03100b09,
  // [2390]
  0x211701af, 0x041201a4, 0x1e002535, 0x010305ad,
  0x25231c21, 0x05060112, 0x15000311, 0x010605ad,
  0x1d124560, 0x171201a4, 0x10001608, 0x04000622,
  0x0e001e11, 0x05001708, 0x16001211, 0x0b2166af,
  // [23a0]
  0x030205be, 0x121516ad, 0x170105af, 0x21452b12,
  0x43220107, 0x17000511, 0x01401dad, 0x0f011912,
  0x05013821, 0x14660ba4, 0x0d1f0812, 0x0e001e36,
  0x0f000807, 0x29002736, 0x03060420, 0x38001608,
  // [23b0]
  0x66020b6f, 0x06030f13, 0x66030b12, 0x01162255,
  0x15170108, 0x38081721, 0x18000309, 0x08181408,
  0x18000812, 0x17000820, 0x08000513, 0x05011207,
  0x03010807, 0x450c2b07, 0x021006bc, 0x06036634,
  // [23c0]
  0x03000c12, 0x04000c22, 0x120d17ac, 0x0d2927af,
  0x051001af, 0x1d121507, 0x17050113, 0x03060c12,
  0x08381721, 0x0c000f14, 0x272908bb, 0x01222707,
  0x1c23256f, 0x0d433f12, 0x010f0c12, 0x140b01af,
  // [23d0]
  0x01050409, 0x14001f11, 0x060445af, 0x03000c20,
  0x08041908, 0x14010bad, 0x0b010607, 0x45000f12,
  0x06140112, 0x380d01af, 0x01060fa4, 0x08160107,
  0x40140112, 0x1c001e20, 0x142915ad, 0x010621bc,
  // [23e0]
  0x15191608, 0x080d0f09, 0x172215ad, 0x230e3020,
  0x1e1c256f, 0x060c0112, 0x010445af, 0x0c1517bc,
  0x12162bbc, 0x1d0f2b13, 0x01061aa4, 0x0d080109,
  0x171d27a4, 0x45401daf, 0x0f450112, 0x38001213,
  // [23f0]
  0x38000c07, 0x01273faf, 0x0b001420, 0x06050113,
  0x04272155, 0x17052b11, 0x181214a4, 0x0d101912,
  0x18000814, 0x060b2b21, 0x02400b13, 0x064504bb,
  0x40001511, 0x1c252360, 0x03040612, 0x451004bb,

  // [2400]
  0x050f3823, 0x15292712, 0x12000c09, 0x08432b33,
  0x04272121, 0x19273f12, 0x06003809, 0x15380421,
  0x663f43bc, 0x22000c07, 0x18161d12, 0x01380f21,
  0x02004320, 0x380f0112, 0x45120caf, 0x051f3f21,
  // [2410]
  0x21001621, 0x29212712, 0x043f27af, 0x66062712,
  0x04060112, 0x0f2729af, 0x3f001f22, 0x211f1660,
  0x271516af, 0x17121807, 0x1d0c2912, 0x012b1512,
  0x27152913, 0x27100b12, 0x100d0112, 0x06380108,
  // [2420]
  0x12030612, 0x031d40af, 0x190d0111, 0x290501af,
  0x050f1f09, 0x150405af, 0x18001021, 0x052729af,
  0x06665112, 0x0f0d3813, 0x0d1821bc, 0x40001911,
  0x1f2b1012, 0x1f2b01af, 0x18000d20, 0x06000d07,
  // [2430]
  0x0d0f3808, 0x14004312, 0x030f0112, 0x19000309,
  0x16380dad, 0x100b0caf, 0x0d181212, 0x14002211,
  0x04001412, 0x18000d09, 0x14000223, 0x1e002320,
  0x00004e0a, 0x0e253007, 0x04021002, 0x430d2707,
  // [2440]
  0x300e2311, 0x04002208, 0x0c002212, 0x151d1620,
  0x400f01af, 0x21052712, 0x2b010521, 0x40172b12,
  0x10080555, 0x40001621, 0x01004312, 0x432b01af,
  0x291f1808, 0x01003f21, 0x02211907, 0x04662108,
  // [2450]
  0x03081911, 0x01120d07, 0x10001207, 0x0b100307,
  0x0f082212, 0x27292212, 0x01143820, 0x43020112,
  0x030501ad, 0x0f002213, 0x29006613, 0x1e230e60,
  0x01451255, 0x102b1411, 0x451201a4, 0x02291812,
  // [2460]
  0x0b102baf, 0x12452109, 0x660501af, 0x06012bad,
  0x66180209, 0x16010609, 0x01102b13, 0x1d1821a4,
  0x301c2511, 0x251c2360, 0x166638bc, 0x08021412,
  0x0d2b0113, 0x21001922, 0x04161921, 0x22001623,
  // [2470]
  0x01192707, 0x170f0d14, 0x21001813, 0x27400c12,
  0x1d192207, 0x660116af, 0x03160112, 0x2b060113,
  0x40100c07, 0x0d012b55, 0x2b012112, 0x0c002907,
  0x10004008, 0x251e2308, 0x040201af, 0x40121714,
  // [2480]
  0x29150112, 0x66000336, 0x141501af, 0x450d1807,
  0x02154022, 0x054045a4, 0x013f0da4, 0x100c1212,
  0x400b1408, 0x030f06a4, 0x0b0214bb, 0x12272920,
  0x1c302507, 0x18030608, 0x05170112, 0x06043821,
  // [2490]
  0x100201af, 0x190c0412, 0x0d2901a4, 0x0e1c1e02,
  0x10005108, 0x40000c08, 0x060c6607, 0x45001820,
  0x29184512, 0x182729be, 0x0e1c2513, 0x01190308,
  0x272918bb, 0x27190360, 0x0b102113, 0x29182712,
  // [24a0]
  0x140b0213, 0x19036655, 0x140203af, 0x10060b08,
  0x29401808, 0x27211833, 0x18002713, 0x032b0108,
  0x050d01a4, 0x29272112, 0x251e3055, 0x18001613,
  0x0f001207, 0x0c000609, 0x2b001811, 0x434527a4,
  // [24b0]
  0x18001614, 0x03100614, 0x02030b12, 0x25001c36,
  0x1c2325bb, 0x2b001813, 0x18032baf, 0x0e1e23ad,
  0x18001620, 0x271f2912, 0x06220322, 0x3f012b13,
  0x0b016607, 0x05000102, 0x05380421, 0x1c0e2514,
  // [24c0]
  0x010618ad, 0x1f3f01af, 0x17050111, 0x02101712,
  0x23300e22, 0x050d08a4, 0x0c080307, 0x05220308,
  0x0b180112, 0x060b0108, 0x030518a4, 0x0c1722a4,
  0x300e1c07, 0x02050108, 0x04450c55, 0x17120d60,
  // [24d0]
  0x16191daf, 0x2b2912af, 0x1e232509, 0x29000413,
  0x010f0508, 0x01002113, 0x38055112, 0x050f38a4,
  0x080219a4, 0x010605a4, 0x38001d11, 0x272b0814,
  0x431701a4, 0x010101a4, 0x43051712, 0x01001d02,
  // [24e0]
  0x03062707, 0x05010212, 0x04190307, 0x1e2530bb,
  0x0b021d14, 0x45044008, 0x40161d08, 0x1c301e60,
  0x120c1d20, 0x25301e09, 0x66191209, 0x060319a4,
  0x45001908, 0x063801af, 0x060105a4, 0x05103811,
  // [24f0]
  0x02036621, 0x061d0307, 0x06173860, 0x17380412,
  0x062b2908, 0x06010807, 0x0b101d21, 0x020c1012,
  0x1d120412, 0x1c0e2521, 0x0d451f07, 0x0b121d11,
  0x17060321, 0x38001722, 0x25231e12, 0x661f3f12,
  // [2500]
  0x06182b09, 0x0c001d22, 0x1d060112, 0x401d16af,
  0x026651af, 0x0c036613, 0x193812af, 0x66003821,
  0x1d001614, 0x01021013, 0x010c2b07, 0x01181955,
  0x0e001c22, 0x03026607, 0x0b031021, 0x12162912,
  // [2510]
  0x1e1c0ebe, 0x03012b07, 0x0f004513, 0x21001809,
  0x03006620, 0x1c230e20, 0x231e0eac, 0x38006609,
  0x05036660, 0x03226608, 0x1c25236f, 0x381705bb,
  0x66003812, 0x0c660813, 0x230e30be, 0x38000609,
  // [2520]
  0x66051712, 0x05660313, 0x18000508, 0x01380555,
  0x431d0109, 0x030c19ad, 0x14000209, 0x1e1c30a4,
  0x0d020112, 0x02000107, 0x041d1255, 0x1d292708,
  0x25301e12, 0x0f010808, 0x121d1712, 0x0b004013,
  // [2530]
  0x21000814, 0x18192213, 0x0c1d2912, 0x1f002913,
  0x0f000214, 0x25231cad, 0x45400620, 0x29011f12,
  0x01000312, 0x06451812, 0x0d0f1614, 0x180608a4,
  0x19006613, 0x062b03a4, 0x06000812, 0x181516ce,
  // [2540]
  0x45001823, 0x0f151634, 0x160f0d82, 0x14000411,
  0x19000308, 0x0f1645af, 0x29160f12, 0x0f002122,
  0x0f0d3860, 0x160d0f22, 0x3f000f21, 0x401905ac,
  0x1d190411, 0x1d030607, 0x17000420, 0x050f0108,
  // [2550]
  0x08061f08, 0x1c230e23, 0x0f030613, 0x06022909,
  0x10271812, 0x291f22af, 0x302325af, 0x272218af,
  0x022227af, 0x2b062212, 0x02062913, 0x18000b07,
  0x010f0baf, 0x1d182912, 0x17000d07, 0x06140213,
  // [2560]
  0x22272909, 0x27222914, 0x0b401212, 0x040c1708,
  0x12004002, 0x30230e14, 0x0e002509, 0x170f0d12,
  0x380d0f13, 0x19142912, 0x16001f13, 0x0d083821,
  0x1c231e02, 0x29211609, 0x04010b02, 0x01170309,
  // [2570]
  0x17210112, 0x0b2b0112, 0x18451fac, 0x06272911,
  0x380301af, 0x12002907, 0x08012b11, 0x2b6601af,
  0x22274021, 0x400c2221, 0x293810af, 0x171038af,
  0x27291560, 0x01191621, 0x01001713, 0x0e1e2509,
  // [2580]
  0x010366a4, 0x15160460, 0x121d4513, 0x45121d09,
  0x06381713, 0x16020b08, 0x25002323, 0x063804af,
  0x27062912, 0x14661009, 0x06660b12, 0x18050d12,
  0x06101455, 0x14101909, 0x40270412, 0x43660108,
  // [2590]
  0x041816ad, 0x14010407, 0x402201af, 0x38170121,
  0x1f013814, 0x0f124007, 0x29210f12, 0x010b0d07,
  0x43211612, 0x38170113, 0x401d0c12, 0x0c430112,
  0x08000112, 0x2b003820, 0x180308ac, 0x12400112,
  // [25a0]
  0x19662212, 0x66011612, 0x01050460, 0x01000221,
  0x0b220212, 0x19150409, 0x38170122, 0x1f380112,
  0x08001013, 0x174301af, 0x3f401d6f, 0x22000b12,
  0x40451d34, 0x02401dad, 0x04001934, 0x020b2212,
  // [25b0]
  0x1f223f22, 0x06080514, 0x03004511, 0x05061f60,
  0x291d1912, 0x0c004514, 0x401d12af, 0x03060155,
  0x124527ad, 0x10000114, 0x050b02a4, 0x06000514,
  0x1d404521, 0x032101af, 0x08051a12, 0x03000635,
  // [25c0]
  0x14001021, 0x05140112, 0x1d000307, 0x056601af,
  0x02140112, 0x05030607, 0x032b02a4, 0x08161555,
  0x231c1e11, 0x030119ac, 0x1e002536, 0x05030b13,
  0x180b5112, 0x0b4038af, 0x1800141f, 0x66000333,
  // [25d0]
  0x08010612, 0x0d053812, 0x01292711, 0x04002107,
  0x0f403809, 0x0f0d08be, 0x23301e07, 0x01000f20,
  0x0f000c07, 0x45001220, 0x01080c08, 0x222927bc,
  0x22380dad, 0x08170fa4, 0x22000d08, 0x14004511,
  // [25e0]
  0x0e251c60, 0x02060b13, 0x081738a4, 0x06001f08,
  0x0c023807, 0x0c3f0112, 0x03222ba4, 0x01100b12,
  0x3f001d35, 0x37004e36, 0x1f010b12, 0x010b0613,
  0x05012912, 0x05013813, 0x05220d07, 0x0d000111,
  // [25f0]
  0x66190412, 0x301c1e14, 0x10003813, 0x02001f11,
  0x011038ac, 0x38000b12, 0x29271daf, 0x030622af,
  0x01050613, 0x03060421, 0x04270621, 0x140f3820,
  0x10400321, 0x45151412, 0x12180508, 0x1f2b0613,
  // [2600]
  0x2b036609, 0x141716a4, 0x0d0f3811, 0x16272909,
  0x0b2204bb, 0x66162712, 0x2b170121, 0x05001912,
  0x291651af, 0x15002913, 0x06030420, 0x22060322,
  0x291916a4, 0x16001f20, 0x2b000520, 0x050d18af,
  // [2610]
  0x190f0112, 0x05160d22, 0x05001920, 0x170c1da4,
  0x151f3809, 0x011815a4, 0x15020b09, 0x21012b21,
  0x191628af, 0x03660513, 0x162901af, 0x0e1c2355,
  0x18004309, 0x23251c08, 0x0e231cac, 0x231e1ca4,
  // [2620]
  0x01060b09, 0x0c183f12, 0x0d083fac, 0x0b141055,
  0x0b010609, 0x08001908, 0x0b001408, 0x061003af,
  0x14000b09, 0x06031809, 0x0b180412, 0x0c031d08,
  0x0f1f0112, 0x10001811, 0x02000609, 0x08100455,
  // [2630]
  0x27000111, 0x0c001012, 0x02270b12, 0x230e1c6f,
  0x21272933, 0x02001811, 0x04000c11, 0x170d29af,
  0x16002211, 0x0b1945af, 0x2b0138ad, 0x29050112,
  0x300e1cbc, 0x16150412, 0x152721af, 0x45011fad,
  // [2640]
  0x0c2221af, 0x210c0112, 0x16151f6f, 0x03001008,
  0x66430160, 0x1d000407, 0x02000b0e, 0x16001508,
  0x080f0ca4, 0x272b1f12, 0x02011fad, 0x66040321,
  0x06030412, 0x3f001913, 0x080129ad, 0x2b030612,
  // [2650]
  0x06192707, 0x0f030408, 0x43030112, 0x01030421,
  0x45181209, 0x04030112, 0x043f1912, 0x66000b09,
  0x23250e09, 0x0b022221, 0x163f0112, 0x08000f07,
  0x30251c60, 0x0e1c256f, 0x01220611, 0x024022af,
  // [2660]
  0x04001711, 0x031d02ad, 0x3f000520, 0x0b002212,
  0x27060112, 0x08004312, 0x231e3007, 0x01102212,
  0x10081960, 0x030602be, 0x02220b12, 0x01060507,
  0x05002221, 0x05002b23, 0x25233020, 0x43290512,
  // [2670]
  0x19220b14, 0x08170421, 0x43040512, 0x1d380108,
  0x17000c11, 0x292b0112, 0x451d0112, 0x230e25bc,
  0x170501af, 0x03052708, 0x380601a4, 0x01050607,
  0x012215ad, 0x211d0112, 0x30231e13, 0x04001920,
  // [2680]
  0x10181521, 0x03166612, 0x18000d14, 0x29401d21,
  0x18000307, 0x181516cf, 0x04212712, 0x380d0213,
  0x291d1f09, 0x082251a4, 0x2b080112, 0x010822a4,
  0x2b001512, 0x170f01a4, 0x1e1c25ac, 0x251e30af,
  // [2690]
  0x1c0e1e20, 0x10000421, 0x0c1d4512, 0x061001ad,
  0x14220c13, 0x01431621, 0x37001c12, 0x05380108,
  0x141501a4, 0x1d014007, 0x01100255, 0x060366bc,
  0x01151007, 0x010f386f, 0x2b0c6611, 0x43001912,
  // [26a0]
  0x0c1601af, 0x0d051fac, 0x16190412, 0x661f01af,
  0x08012712, 0x02030ba4, 0x0c000407, 0x450166a4,
  0x050f0d11, 0x43003f12, 0x380b0307, 0x380b14a4,
  0x16291aaf, 0x08380b12, 0x401912af, 0x2b000612,
  // [26b0]
  0x0f0d0107, 0x222719af, 0x05000411, 0x66032221,
  0x190c0b12, 0x2b030621, 0x22004513, 0x02190b09,
  0x14292723, 0x22001607, 0x01060209, 0x01661f09,
  0x450c4060, 0x06272221, 0x05162b60, 0x03140112,
  // [26c0]
  0x21160112, 0x40451913, 0x2b000c22, 0x66191512,
  0x10190111, 0x01081d07, 0x21000f12, 0x27291614,
  0x1827296f, 0x272901af, 0x1e230e11, 0x12221620,
  0x2b003f13, 0x27291812, 0x03191607, 0x10001821,
  // [26d0]
  0x06050107, 0x10030b11, 0x0601146f, 0x056601ad,
  0x010f22a4, 0x080b0213, 0x29173809, 0x050206a4,
  0x1d001413, 0x66272b09, 0x0f003811, 0x05012ba4,
  0x01172707, 0x08000109, 0x0e1c3009, 0x0c011f55,
  // [26e0]
  0x01060cad, 0x0d003f11, 0x250e1c33, 0x08000111,
  0x18004021, 0x120c1d21, 0x19002711, 0x08220112,
  0x450c4022, 0x2b224013, 0x160c04ad, 0x38292713,
  0x0d010507, 0x22050f12, 0x184008bb, 0x0d0f2112,
  // [26f0]
  0x27192221, 0x05000f12, 0x08270512, 0x14001621,
  0x02103fce, 0x43000821, 0x23250e11, 0x12050d13,
  0x06221413, 0x16000420, 0x03002220, 0x12450614,
  0x382b0308, 0x0f1745a4, 0x100412a4, 0x19002120,
  // [2700]
  0x170b18ac, 0x02002212, 0x06216609, 0x0302066f,
  0x142b01af, 0x192204af, 0x19222113, 0x06660321,
  0x10271711, 0x19162b13, 0x660b2709, 0x080f01a4,
  0x050c1d07, 0x0f0d12af, 0x0c0f0107, 0x0e231e55,
  // [2710]
  0x0d124521, 0x0d0301af, 0x1d1727af, 0x08174512,
  0x0d1245af, 0x19400860, 0x03000b13, 0x1e300e11,
  0x29006608, 0x162205ad, 0x19211608, 0x0d451208,
  0x02005113, 0x12451fbe, 0x01000820, 0x1c0e1e55,
  // [2720]
  0x0d451255, 0x5c000733, 0x02010512, 0x43290108,
  0x01043fad, 0x1d190cad, 0x0c101707, 0x1d105112,
  0x06030208, 0x38000407, 0x0b100520, 0x0b006622,
  0x0b1002a4, 0x041966a4, 0x0f3f22bc, 0x03050121,
  // [2730]
  0x66010512, 0x021051af, 0x45000112, 0x0b10026f,
  0x17010512, 0x660306af, 0x02180b08, 0x400c1d12,
  0x03050111, 0x04000b13, 0x12270508, 0x124516a4,
  0x10000112, 0x04010502, 0x190b1009, 0x192b0107,
  // [2740]
  0x301e1c09, 0x080f3823, 0x0d120512, 0x08381d12,
  0x1f0b0222, 0x18451212, 0x21274312, 0x04191508,
  0x02660109, 0x14001012, 0x290c3faf, 0x05061812,
  0x06001722, 0x05124533, 0x251e0ebe, 0x124505be,
  // [2750]
  0x08052b12, 0x05000f13, 0x120805a4, 0x10013f08,
  0x38002107, 0x22002907, 0x080f3809, 0x40180609,
  0x01001611, 0x0f0d4309, 0x083812bb, 0x12401808,
  0x1e2330ac, 0x45001811, 0x1e251c11, 0x15000512,
  // [2760]
  0x18000111, 0x08004323, 0x17005113, 0x43001534,
  0x2b432112, 0x27432b12, 0x170d43af, 0x2b000820,
  0x27004013, 0x45151211, 0x38002b08, 0x10031912,
  0x08292b12, 0x291d4012, 0x0d001534, 0x01180521,
  // [2770]
  0x01030521, 0x2b160433, 0x05036613, 0x05002708,
  0x30001c21, 0x17120f08, 0x01030512, 0x450b12af,
  0x38001621, 0x45170809, 0x12011907, 0x10054512,
  0x05080312, 0x232530ad, 0x010c45af, 0x03010512,
  // [2780]
  0x191001af, 0x0c660320, 0x01001610, 0x01000c08,
  0x05004508, 0x120c0107, 0x45001611, 0x0d000212,
  0x124501bb, 0x100108a4, 0x66451d60, 0x19120107,
  0x0c121809, 0x1d041812, 0x40181212, 0x17000402,
  // [2790]
  0x030266af, 0x23250e12, 0x45104012, 0x1d401260,
  0x0b151413, 0x041d0109, 0x29042709, 0x0e1c30a4,
  0x1d0f0507, 0x1d0c1209, 0x40164512, 0x66041920,
  0x21000b08, 0x0b0102a4, 0x25002309, 0x03061007,
  // [27a0]
  0x430b0107, 0x1e001c02, 0x0b000409, 0x191d1507,
  0x22006608, 0x084502a4, 0x1e300e13, 0x17153f12,
  0x08000c07, 0x0000102d, 0x22021d07, 0x380f0c14,
  0x22166621, 0x0f0c3814, 0x1d0c3f12, 0x22001213,
  // [27b0]
  0x194018af, 0x401218be, 0x66161512, 0x18400607,
  0x22182712, 0x661d2912, 0x05030155, 0x0b170207,
  0x18001212, 0x40121dbe, 0x1d0c18af, 0x02151f21,
  0x08220107, 0x06000233, 0x0e1e25bb, 0x0c1812af,
  // [27c0]
  0x14401d11, 0x401812af, 0x226627af, 0x0c4018cf,
  0x060801af, 0x10000313, 0x01030f07, 0x22401008,
  0x2b000107, 0x1d040507, 0x0f004322, 0x16000408,
  0x10010208, 0x01024307, 0x010f3860, 0x294301a4,
  // [27d0]
  0x0e1c2321, 0x0f380114, 0x16292760, 0x02040b08,
  0x022b0b09, 0x050140af, 0x173822af, 0x3f000112,
  0x301e0e14, 0x050140be, 0x08142212, 0x19143f21,
  0x01141d11, 0x19142207, 0x15001713, 0x0d1d2212,
  // [27e0]
  0x0f220812, 0x0d0c2bad, 0x1d3f01a4, 0x0e231e09,
  0x3f002214, 0x45000c09, 0x223f1908, 0x14221508,
  0x062101af, 0x14041da4, 0x0e1c30ad, 0x180c45af,
  0x0c4518ad, 0x2b000207, 0x30232513, 0x1d45126f,
  // [27f0]
  0x271519bb, 0x2b000608, 0x17401d11, 0x22000811,
  0x031001af, 0x05016611, 0x1c1e2511, 0x02000312,
  0x0103666f, 0x22140112, 0x2b000109, 0x100838bb,
  0x03060112, 0x01050612, 0x19021209, 0x100b06a4,

  // [2800]
  0x16005108, 0x16004514, 0x12400513, 0x45124009,
  0x19001711, 0x18150460, 0x380f0312, 0x452101af,
  0x03001011, 0x061904ac, 0x02010b11, 0x0b031807,
  0x192b1008, 0x10181912, 0x0c0f3811, 0x0c401807,
  // [2810]
  0x02001035, 0x080f2121, 0x1f380f6f, 0x080f2112,
  0x011014ad, 0x1e232508, 0x061d1007, 0x0b292760,
  0x300e25ad, 0x08013808, 0x1d191607, 0x3f003822,
  0x0d161fac, 0x02660409, 0x041d1655, 0x1d001633,
  // [2820]
  0x030d0607, 0x38001513, 0x14003f11, 0x1d001613,
  0x191d4020, 0x0d080312, 0x0b100309, 0x16001534,
  0x06012bbc, 0x06004513, 0x05000407, 0x0c160112,
  0x06030255, 0x40051608, 0x04192207, 0x170105a4,
  // [2830]
  0x0d0c01a4, 0x66020b12, 0x29001921, 0x172201af,
  0x22660355, 0x18020b12, 0x03290160, 0x03011955,
  0x06100112, 0x66032112, 0x45140fa4, 0x02270108,
  0x01271f12, 0x03001f08, 0x29010d09, 0x01061fa4,
  // [2840]
  0x064018af, 0x17180620, 0x10380620, 0x1e1c236f,
  0x010d2b21, 0x0f220120, 0x14102212, 0x10006613,
  0x151d45af, 0x38120c13, 0x100b1f08, 0x18000622,
  0x10060807, 0x081922a4, 0x0c122108, 0x1d4012ad,
  // [2850]
  0x1c233014, 0x012b0607, 0x0d0f0c07, 0x19002914,
  0x251c0e33, 0x66401621, 0x0106035e, 0x1d000412,
  0x17004514, 0x163f2baf, 0x0b030612, 0x0c012707,
  0x382b0c21, 0x011621ac, 0x05380f09, 0x08000612,
  // [2860]
  0x2b000114, 0x081d06ad, 0x18030f21, 0x66080612,
  0x10212912, 0x43001f35, 0x2b291f12, 0x1712456f,
  0x161801af, 0x16151412, 0x27102908, 0x1f170112,
  0x15002222, 0x12181408, 0x121504a4, 0x38001807,
  // [2870]
  0x04194512, 0x100c2b12, 0x12453f14, 0x101719a4,
  0x19042212, 0x06010c09, 0x401916ad, 0x0f011007,
  0x030f0d09, 0x454004be, 0x22002709, 0x12001707,
  0x0b0219a4, 0x0c001014, 0x06012907, 0x0e1c30ac,
  // [2880]
  0x0f003812, 0x12020b55, 0x030210af, 0x1d121708,
  0x40181dbc, 0x10401d07, 0x060c1d07, 0x080301a4,
  0x1d001608, 0x030501a4, 0x16002712, 0x06220307,
  0x160103a4, 0x163866a4, 0x16001212, 0x66030613,
  // [2890]
  0x01000211, 0x03216608, 0x0f0d1dad, 0x10170108,
  0x103f01af, 0x08001d11, 0x061851af, 0x21140f6f,
  0x01172708, 0x01052707, 0x161d0baf, 0x063f1d12,
  0x2b161811, 0x063802af, 0x38001607, 0x17100107,
  // [28a0]
  0x010366ac, 0x16006621, 0x66001612, 0x10170112,
  0x15004023, 0x40000c20, 0x030f0614, 0x0d030107,
  0x01041608, 0x66000420, 0x03386613, 0x0b0210be,
  0x02100b22, 0x18002b09, 0x1e251c22, 0x05081d07,
  // [28b0]
  0x16010520, 0x020b2b12, 0x2b080111, 0x060419bc,
  0x16001d12, 0x40002220, 0x03082107, 0x011d2207,
  0x19211612, 0x0f080d09, 0x161514bc, 0x012927af,
  0x011d2b12, 0x0c011a11, 0x04191821, 0x10010660,
  // [28c0]
  0x100327a4, 0x384301a4, 0x03662220, 0x121d0507,
  0x18401d12, 0x0c022b12, 0x15174512, 0x04000c07,
  0x25301e11, 0x0c124520, 0x05001211, 0x18161912,
  0x45001221, 0x21000c11, 0x01061412, 0x042901ad,
  // [28d0]
  0x0b101909, 0x0d004308, 0x25001e34, 0x0f003821,
  0x04000502, 0x01020b11, 0x0b021609, 0x15004522,
  0x270b10af, 0x03100b6f, 0x18101908, 0x252330bc,
  0x451d0412, 0x38080f13, 0x27221d60, 0x12000412,
  // [28e0]
  0x0c12456f, 0x0e1e1c21, 0x0f170808, 0x0800381f,
  0x0b0210ad, 0x25302312, 0x0b026621, 0x10020bad,
  0x010c27a4, 0x30232508, 0x12011da4, 0x080c0d21,
  0x0d1d0f12, 0x0f081f07, 0x19124512, 0x03000c11,
  // [28f0]
  0x22004514, 0x15000108, 0x380f21af, 0x10140b07,
  0x1d1001af, 0x121d0d08, 0x220f0d09, 0x151d4011,
  0x22002913, 0x0d380f14, 0x29273fbc, 0x190d2212,
  0x04401813, 0x0b0f3807, 0x17454013, 0x23001c14,
  // [2900]
  0x1d190420, 0x01270808, 0x381f0455, 0x03660112,
  0x250e2322, 0x10000307, 0x08000f12, 0x011d6607,
  0x01050807, 0x0d084512, 0x38002b07, 0x05000612,
  0x401d0c13, 0x01034560, 0x38170fad, 0x14000213,
  // [2910]
  0x15173812, 0x0f274307, 0x250e1c23, 0x04001820,
  0x29080612, 0x220d0baf, 0x451712af, 0x18290c09,
  0x45181212, 0x17001507, 0x14660112, 0x06120408,
  0x04002913, 0x021014ad, 0x45271221, 0x19000811,
  // [2920]
  0x66061514, 0x1c302512, 0x301c2312, 0x1c230e21,
  0x14292712, 0x0e1e2508, 0x1d454023, 0x22190807,
  0x38061008, 0x45122709, 0x272229af, 0x40004509,
  0x01271912, 0x220301ad, 0x251e2360, 0x193f2211,
  // [2930]
  0x01061812, 0x01180613, 0x06010307, 0x40001222,
  0x01211f12, 0x251e30a4, 0x23301caf, 0x1d2b0ca4,
  0x0c031d07, 0x1d380f12, 0x45120407, 0x10000b22,
  0x02080baf, 0x02102212, 0x30251c20, 0x0f022212,
  // [2940]
  0x272922ce, 0x182729af, 0x1d2918be, 0x40124560,
  0x401d0fa4, 0x02040c12, 0x1d224508, 0x02010f08,
  0x02040b07, 0x06221008, 0x27292123, 0x66292120,
  0x0c030207, 0x291d27af, 0x22001013, 0x18272914,
  // [2950]
  0x22011609, 0x0d040b60, 0x020b08a4, 0x08170d14,
  0x14160813, 0x0c000420, 0x3f1606cf, 0x141245af,
  0x221218ad, 0x191622bc, 0x17000308, 0x19220f13,
  0x291627ce, 0x150c1611, 0x190b2214, 0x1d042212,
  // [2960]
  0x0d003822, 0x080651af, 0x0e3023be, 0x23001c34,
  0x05290108, 0x66220612, 0x22170f21, 0x142b6612,
  0x1d0419a4, 0x04192208, 0x0f0422bc, 0x1d0c2221,
  0x040f1913, 0x1006196f, 0x0b0501af, 0x01220621,
  // [2970]
  0x17080111, 0x1c003020, 0x08060311, 0x102b0608,
  0x10026609, 0x10010421, 0x10030260, 0x181008af,
  0x0e1e2321, 0x01060313, 0x0c002708, 0x23002521,
  0x2b026621, 0x2b4512af, 0x01660309, 0x1f660112,
  // [2980]
  0x06100309, 0x231e3021, 0x21272912, 0x02100655,
  0x19004013, 0x14190412, 0x1d1614ac, 0x1d0c4012,
  0x22194060, 0x18000620, 0x06081f55, 0x01051d12,
  0x171f1d60, 0x40011d12, 0x30001e20, 0x05381d07,
  // [2990]
  0x40172b07, 0x0f0c1608, 0x450c01af, 0x40041914,
  0x030b0208, 0x05011dad, 0x45001d11, 0x171f1da4,
  0x0c051dad, 0x0f001712, 0x01141921, 0x19292112,
  0x16001409, 0x66060314, 0x66031960, 0x66060321,
  // [29a0]
  0x1f081712, 0x03221907, 0x033801a4, 0x45210455,
  0x19000f13, 0x0c0301ac, 0x2127291f, 0x66000335,
  0x04192155, 0x06101407, 0x01381707, 0x38000d23,
  0x01012407, 0x08293814, 0x0c026612, 0x38050dad,
  // [29b0]
  0x170c3fac, 0x38051707, 0x04010307, 0x22001709,
  0x120c0807, 0x29000f12, 0x12401dad, 0x301c2314,
  0x1d0c16a4, 0x22001d12, 0x01036609, 0x22431708,
  0x0f013809, 0x0f0b0808, 0x40271512, 0x016605af,
  // [29c0]
  0x2b010807, 0x0d080f12, 0x19290308, 0x22010607,
  0x0b180655, 0x0d161508, 0x66001012, 0x0f080d14,
  0x66030221, 0x2b000b12, 0x25230e21, 0x03022212,
  0x03026621, 0x2b002211, 0x2b401d22, 0x21153f60,
  // [29d0]
  0x40124523, 0x020f2ba4, 0x06100507, 0x191416a4,
  0x211001af, 0x062710a4, 0x2b002212, 0x662b01bb,
  0x66012708, 0x160c45af, 0x06210111, 0x66000633,
  0x08010f12, 0x121d40bc, 0x43000407, 0x29380f12,
  // [29e0]
  0x29016623, 0x210f0d13, 0x66000b13, 0x1d404513,
  0x3f0845af, 0x27042914, 0x0d120f55, 0x232530bb,
  0x16170d55, 0x01043809, 0x0c000413, 0x08050108,
  0x03001811, 0x033810a4, 0x150d1634, 0x06041811,
  // [29f0]
  0x0f152712, 0x01160d11, 0x161551af, 0x0f161534,
  0x0b1966af, 0x0f0d18bc, 0x0f0d2912, 0x231c2560,
  0x14002208, 0x221914bc, 0x15212912, 0x19036620,
  0x22001411, 0x150f0c21, 0x02060ba4, 0x430d0112,
  // [2a00]
  0x06040807, 0x190d1509, 0x10040107, 0x29270daf,
  0x100f29a4, 0x0d0c0807, 0x0d161009, 0x0d291522,
  0x0b004007, 0x1f010608, 0x104301af, 0x0e1e30ad,
  0x23251cbe, 0x0f451255, 0x0c010608, 0x1c300eaf,
  // [2a10]
  0x160f01af, 0x23301e08, 0x080d0f11, 0x151245bc,
  0x450c1621, 0x0f001911, 0x19001620, 0x01001013,
  0x0f000d21, 0x21006608, 0x45000813, 0x0d0816af,
  0x03001611, 0x010508af, 0x01101907, 0x030127a4,
  // [2a20]
  0x2b000511, 0x17080208, 0x43050607, 0x010629a4,
  0x220627a4, 0x291927a4, 0x02430107, 0x27042908,
  0x08002b02, 0x01172bad, 0x060b17ad, 0x05080607,
  0x10660212, 0x22010f07, 0x02002b08, 0x22292121,
  // [2a30]
  0x1e302313, 0x0c660612, 0x1f001d12, 0x40451209,
  0x38000411, 0x08050f13, 0x10000d11, 0x22012907,
  0x0f030107, 0x45160fa4, 0x08060109, 0x142216ad,
  0x012b1f55, 0x0f001402, 0x01221613, 0x01000502,
  // [2a40]
  0x14003f12, 0x06100409, 0x1d3817af, 0x10380faf,
  0x1c250ead, 0x120610a4, 0x08002108, 0x0c001d09,
  0x0d020c08, 0x01062b60, 0x17000408, 0x30252308,
  0x3f042113, 0x14061912, 0x2b660360, 0x29380421,
  // [2a50]
  0x213f2213, 0x0d0f0812, 0x21001912, 0x40043f21,
  0x08173f08, 0x23301cad, 0x0000271c, 0x060d0108,
  0x38000608, 0x18000408, 0x0b3f0413, 0x27403f21,
  0x03000521, 0x1d0b40bc, 0x27290baf, 0x19013f08,
  // [2a60]
  0x38272933, 0x3829276f, 0x05170111, 0x0d0f06bb,
  0x0c032bac, 0x06150160, 0x16002b07, 0x010f0d07,
  0x03660521, 0x272938af, 0x38000102, 0x300e2322,
  0x0b001f13, 0x06000109, 0x43001f11, 0x251e3008,
  // [2a70]
  0x0d080502, 0x0e1e2322, 0x10164012, 0x06124009,
  0x01661d12, 0x40124522, 0x124518be, 0x66061d12,
  0x454017a4, 0x06451213, 0x0f010d09, 0x0e302311,
  0x27290daf, 0x16401d22, 0x0d16086f, 0x01272907,
  // [2a80]
  0x04100dad, 0x12181f12, 0x210f0d09, 0x0f0d0821,
  0x011204ad, 0x270f1d60, 0x0b020307, 0x1d400814,
  0x04002908, 0x19001621, 0x100251af, 0x1d380f6f,
  0x0d0f0814, 0x150c4511, 0x0b001021, 0x17053807,
  // [2a90]
  0x1f293f60, 0x251c1e55, 0x21004321, 0x05001214,
  0x06020b11, 0x010b0282, 0x14161913, 0x050201a4,
  0x030106a4, 0x0c400412, 0x01060312, 0x1c30256f,
  0x020627a4, 0x43002b12, 0x180338a4, 0x43001d08,
  // [2aa0]
  0x2b004314, 0x29160408, 0x6604166f, 0x43002b13,
  0x43000d07, 0x04211614, 0x21043f12, 0x04002122,
  0x231c2555, 0x16001823, 0x1e0e1c60, 0x17001623,
  0x100c0607, 0x16000c11, 0x17031612, 0x06001802,
  // [2ab0]
  0x03291608, 0x43002b14, 0x05014512, 0x16181760,
  0x05010309, 0x38001811, 0x38180112, 0x041618be,
  0x162b0412, 0x291627be, 0x27160809, 0x66190109,
  0x141051af, 0x02450109, 0x0b0219af, 0x12030c07,
  // [2ac0]
  0x2b080107, 0x161d2909, 0x06660109, 0x150306a4,
  0x12000520, 0x04061920, 0x1c300ead, 0x40000607,
  0x05080107, 0x40151d12, 0x1d170812, 0x30000e36,
  0x0b120408, 0x01001d07, 0x43224008, 0x18001407,
  // [2ad0]
  0x100d01af, 0x40012712, 0x2b160baf, 0x21011413,
  0x03041909, 0x011738a4, 0x661f0112, 0x1c0e25ac,
  0x0f4016af, 0x301e0eaf, 0x400c16ad, 0x0c001507,
  0x121d1607, 0x08401607, 0x17000f11, 0x0b080107,
  // [2ae0]
  0x100c4512, 0x0f0c0607, 0x152b0612, 0x060c15bc,
  0x231c1e09, 0x271f0c09, 0x050c12a4, 0x1d401612,
  0x163f4020, 0x03010812, 0x0c0d0f13, 0x0d050812,
  0x16000c23, 0x02100307, 0x10220c07, 0x400c1d13,
  // [2af0]
  0x15004512, 0x100c0407, 0x04000c08, 0x0f2b4508,
  0x041922a4, 0x15170f14, 0x03180d08, 0x0e001e35,
  0x04060107, 0x0000120a, 0x301e0eac, 0x40000f12,
  0x01292720, 0x19041608, 0x17000313, 0x38001f13,
  // [2b00]
  0x0d141807, 0x181008ad, 0x1d100dad, 0x193801a4,
  0x0b1051af, 0x10020b07, 0x12001907, 0x031606af,
  0x18003809, 0x081722a4, 0x380d0109, 0x381f0112,
  0x66190821, 0x01380509, 0x0b0251af, 0x04001609,
  // [2b10]
  0x66010f09, 0x17121d08, 0x1c1e2309, 0x05014334,
  0x18101d12, 0x0b160207, 0x1e2325a4, 0x15002b12,
  0x0e233707, 0x16001d09, 0x40291d12, 0x17126607,
  0x10003f11, 0x431d01a4, 0x38660bad, 0x17001421,
  // [2b20]
  0x27002121, 0x160445a4, 0x1d0c0f09, 0x12010612,
  0x1d040b12, 0x1d000f14, 0x08292760, 0x0c030209,
  0x17002b13, 0x04450fac, 0x1f002b22, 0x03450c55,
  0x1c0e1e14, 0x01002111, 0x1e230ebe, 0x012b0608,
  // [2b30]
  0x12060108, 0x0b010507, 0x38451255, 0x03100607,
  0x0b001720, 0x0b1410be, 0x01080c07, 0x40192b55,
  0x2b011fbb, 0x060201a4, 0x1d080407, 0x43186609,
  0x18001612, 0x38082bac, 0x1d402ba4, 0x18011f12,
  // [2b40]
  0x22001810, 0x1c233011, 0x08002b13, 0x251c3008,
  0x0e301caf, 0x301c2360, 0x27293f14, 0x270c3fbb,
  0x032b02bc, 0x032b02af, 0x15003821, 0x0f014307,
  0x03180607, 0x18001512, 0x03660221, 0x02000610,
  // [2b50]
  0x22004007, 0x100f2207, 0x01061607, 0x27222112,
  0x0c001834, 0x0f0127a4, 0x38000622, 0x03026620,
  0x03120612, 0x45000820, 0x272b51af, 0x01124302,
  0x0f080d21, 0x06010cac, 0x16173807, 0x251c1e23,
  // [2b60]
  0x19001014, 0x0b120402, 0x060c4507, 0x051f0109,
  0x101804a4, 0x05081708, 0x02010b07, 0x190c21a4,
  0x04160c09, 0x19005108, 0x292719bc, 0x15000f21,
  0x10060209, 0x170d1513, 0x29274512, 0x010f29af,
  // [2b70]
  0x05002212, 0x22272921, 0x081d2907, 0x0b100602,
  0x1d050808, 0x121d4082, 0x0c430109, 0x10025112,
  0x0b454011, 0x0d160412, 0x250e1c21, 0x0c220b13,
  0x1e300e09, 0x19001d13, 0x3f1d16be, 0x0b2b0107,
  // [2b80]
  0x66002708, 0x27001d12, 0x1d400d22, 0x160c2912,
  0x1d001914, 0x29271021, 0x22011709, 0x0f001d21,
  0x14001914, 0x02221812, 0x05380122, 0x1d003f22,
  0x16105111, 0x06041013, 0x0d0f3814, 0x230e3011,
  // [2b90]
  0x08191d21, 0x1d193f13, 0x05020107, 0x08002911,
  0x451d1560, 0x02032b07, 0x0b18026f, 0x40001821,
  0x1c231eaf, 0x66000308, 0x27191a12, 0x2b001809,
  0x00004315, 0x0e253012, 0x1f380822, 0x23300e11,
  // [2ba0]
  0x04080112, 0x40020b55, 0x180806a4, 0x19660312,
  0x01001920, 0x121d0cac, 0x050c06a4, 0x661f3f14,
  0x21020bbc, 0x16190612, 0x292701a4, 0x011706ad,
  0x2b0538af, 0x01660307, 0x011d1907, 0x2b1f06bb,
  // [2bb0]
  0x060119ad, 0x0f2b0112, 0x1c23306f, 0x19005113,
  0x1e0e2514, 0x18001d12, 0x03661712, 0x19003f13,
  0x063f01af, 0x1d006607, 0x1d001012, 0x1c250ebb,
  0x38000b13, 0x1e2530bc, 0x40173faf, 0x171538a4,
  // [2bc0]
  0x08163808, 0x40001809, 0x060c2b07, 0x08050f09,
  0x1d403faf, 0x161d1908, 0x17004512, 0x27153f34,
  0x141d0ca4, 0x1f292708, 0x08001007, 0x27290512,
  0x21002223, 0x08380f09, 0x06042208, 0x1f0d3f12,
  // [2bd0]
  0x272b2909, 0x21002912, 0x1d050107, 0x1d0f01a4,
  0x162927af, 0x01292708, 0x0f012908, 0x40000113,
  0x381d1f12, 0x0b102212, 0x45120111, 0x05004507,
  0x176601af, 0x0c181f11, 0x451f0c11, 0x1e1c3002,
  // [2be0]
  0x080f1621, 0x16171d11, 0x1c002502, 0x0c1601ac,
  0x08430609, 0x03180d07, 0x250e3009, 0x012b06af,
  0x06030407, 0x08001d12, 0x40001414, 0x45000513,
  0x01020521, 0x01180d08, 0x05003811, 0x01002b02,
  // [2bf0]
  0x05000602, 0x30230ebe, 0x300e2360, 0x0f0538be,
  0x38191611, 0x050d1707, 0x10401dad, 0x380f0db2,
  0x2b001612, 0x400415ac, 0x454004af, 0x04381612,
  0x04054007, 0x384501ac, 0x1d011212, 0x19124507,

  // [2c00]
  0x2b000514, 0x40002b07, 0x17010c09, 0x1e300e08,
  0x251e3009, 0x06000402, 0x66061421, 0x0b002b07,
  0x0f060baf, 0x18062260, 0x08031912, 0x0d030f08,
  0x30002512, 0x0d0f6612, 0x19060409, 0x03001914,
  // [2c10]
  0x400f0d60, 0x121d4007, 0x020b06ac, 0x450f6612,
  0x16124560, 0x40002908, 0x12400c07, 0x21002712,
  0x381829af, 0x301c1ea4, 0x0f003822, 0x10180413,
  0x2b050114, 0x66140420, 0x0b121421, 0x22002908,
  // [2c20]
  0x29001512, 0x2b000613, 0x062b0108, 0x18000c11,
  0x0b401012, 0x17162b02, 0x03020111, 0x01100b11,
  0x01100860, 0x04191060, 0x0e1e3012, 0x161d4008,
  0x10140112, 0x030b6609, 0x0d270f09, 0x01061808,
  // [2c30]
  0x05000609, 0x1d0c0fa4, 0x0d001d02, 0x12454021,
  0x1c1e0eac, 0x14000b11, 0x0f002108, 0x22001911,
  0x66001512, 0x43172202, 0x101f0b09, 0x40161511,
  0x03000212, 0x0f041712, 0x0d000412, 0x38450308,
  // [2c40]
  0x1c230e02, 0x19050b12, 0x0f0105af, 0x0f060d12,
  0x231e3009, 0x0f000523, 0x19006612, 0x06381609,
  0x040201a4, 0x16011512, 0x193f01af, 0x18291608,
  0x15451209, 0x15380512, 0x12000622, 0x250e1eac,
  // [2c50]
  0x1d401912, 0x0e1c23ad, 0x251e3011, 0x01001614,
  0x18660312, 0x29221f82, 0x430c4507, 0x02006614,
  0x01190608, 0x27012909, 0x01180602, 0x2b272913,
  0x02660609, 0x03660b14, 0x1c1e2321, 0x0e1e3022,
  // [2c60]
  0x14036621, 0x0d0f1812, 0x0f0c1d21, 0x251c0e09,
  0x15002120, 0x40000f11, 0x0b000f20, 0x10050b09,
  0x082b0f12, 0x0c180f09, 0x0d080f11, 0x25231c60,
  0x1d0c0faf, 0x381705a4, 0x04154009, 0x140406af,
  // [2c70]
  0x04080f11, 0x06404560, 0x3f000513, 0x66001212,
  0x27060b12, 0x1e1c0ea4, 0x080122ad, 0x15401d08,
  0x18141012, 0x141004bc, 0x1d001820, 0x181f1621,
  0x012b2712, 0x012b1fad, 0x01001407, 0x25230eaf,
  // [2c80]
  0x0f000511, 0x0f154055, 0x40124509, 0x18002211,
  0x1c233021, 0x12001820, 0x010c1807, 0x160d01af,
  0x272b0312, 0x1c302308, 0x0c004507, 0x01192b60,
  0x12000307, 0x124503af, 0x010f0dbe, 0x180b0521,
  // [2c90]
  0x10020607, 0x38080baf, 0x03180107, 0x2b0f01af,
  0x054501af, 0x45292708, 0x060d0308, 0x2b002214,
  0x401d4511, 0x042729ad, 0x2b002222, 0x221d0609,
  0x660329af, 0x0b030209, 0x30250e09, 0x04271909,
  // [2ca0]
  0x0e1c3055, 0x04292720, 0x40001608, 0x12060112,
  0x0f0d16af, 0x0f080dad, 0x04292712, 0x014506ac,
  0x121d1521, 0x40081912, 0x29161922, 0x0d401660,
  0x18001214, 0x0d030109, 0x16020b55, 0x1c301e12,
  // [2cb0]
  0x0e301ca4, 0x380f0d21, 0x100103a4, 0x0d1d01a4,
  0x03290612, 0x10026612, 0x06012ba4, 0x03051907,
  0x16191512, 0x0d0418cf, 0x080f2bbc, 0x2b0603af,
  0x18000422, 0x040b1d21, 0x45010612, 0x19003814,
  // [2cc0]
  0x29270209, 0x3f0f2121, 0x16080112, 0x050b0107,
  0x04190cad, 0x04001720, 0x3f000c20, 0x66010313,
  0x19061807, 0x0e301e11, 0x45120c11, 0x1e251cac,
  0x06002b09, 0x0f381407, 0x08000602, 0x19270112,
  // [2cd0]
  0x14020b22, 0x301c2507, 0x2b000208, 0x3f0b0112,
  0x1e001c20, 0x1d080555, 0x14272922, 0x140b2108,
  0x12000612, 0x0e1c25ad, 0x66030514, 0x1d020112,
  0x080201af, 0x1f000d13, 0x2b030155, 0x1c2330af,
  // [2ce0]
  0x0b1d1860, 0x01032bac, 0x16450cac, 0x21000121,
  0x05193812, 0x05040160, 0x06021512, 0x03011d12,
  0x03061055, 0x01056608, 0x451215af, 0x0b000f11,
  0x02190baf, 0x0b100221, 0x10000820, 0x010d05ad,
  // [2cf0]
  0x38100507, 0x38001614, 0x660d0512, 0x27001920,
  0x12001d21, 0x40292713, 0x192b2912, 0x270c2912,
  0x15000b08, 0x43001709, 0x16003813, 0x22061211,
  0x402927ad, 0x01080611, 0x23253021, 0x19031855,
  // [2d00]
  0x66100321, 0x30251e09, 0x25231e60, 0x10190baf,
  0x0b026607, 0x40121d20, 0x2b000609, 0x030b02af,
  0x14002207, 0x08052112, 0x0b003f13, 0x03000b02,
  0x0f3f2112, 0x0f1d4011, 0x1d2b10bc, 0x401d0baf,
  // [2d10]
  0x0d380f55, 0x220d43a4, 0x0c0f1707, 0x05001d12,
  0x3f080f13, 0x3f001814, 0x02190b07, 0x21000c21,
  0x270d01af, 0x08170508, 0x01270dbc, 0x3f001f14,
  0x04011521, 0x66160113, 0x231c25ad, 0x38660114,
  // [2d20]
  0x38220560, 0x156601af, 0x38050113, 0x05016612,
  0x0f380112, 0x01001911, 0x380d08af, 0x10020b60,
  0x15030113, 0x03150112, 0x15006623, 0x663801af,
  0x062b1811, 0x08020107, 0x2b290208, 0x2b004008,
  // [2d30]
  0x1c3025ad, 0x12001410, 0x29000121, 0x121916a4,
  0x19061012, 0x3800121d, 0x2b453f12, 0x060d0f09,
  0x08001f08, 0x17272212, 0x010d1207, 0x1e253009,
  0x3f000313, 0x161f0421, 0x43030808, 0x04001809,
  // [2d40]
  0x01060c08, 0x1f29276f, 0x0d100407, 0x30251cad,
  0x38012755, 0x2b080f09, 0x18190409, 0x04191812,
  0x2b152908, 0x052b0421, 0x19181f09, 0x21163f09,
  0x16001f08, 0x161240af, 0x121d4060, 0x010b1009,
  // [2d50]
  0x1d003f14, 0x03020b08, 0x080f1d09, 0x66221212,
  0x0d0105ad, 0x02001008, 0x40002707, 0x0c0b0612,
  0x301e0e13, 0x060327af, 0x12404509, 0x040306ce,
  0x220306af, 0x10000308, 0x30230e13, 0x06031760,
  // [2d60]
  0x10060b12, 0x06001408, 0x02000621, 0x0f000520,
  0x22030612, 0x38000321, 0x100306a4, 0x38001623,
  0x06001020, 0x03060413, 0x3f002120, 0x38011607,
  0x05000114, 0x02660355, 0x060310a4, 0x25002302,
  // [2d70]
  0x02001002, 0x06160420, 0x2b661621, 0x161d15bc,
  0x22000102, 0x161522bc, 0x43012907, 0x15061908,
  0x0d0551a4, 0x0f041909, 0x042919af, 0x0c100112,
  0x382b0508, 0x04036609, 0x210f0d21, 0x15192160,
  // [2d80]
  0x06192260, 0x03003f12, 0x66271809, 0x22000821,
  0x10001434, 0x210d0f22, 0x210f0d23, 0x210d0fbe,
  0x0e1e2302, 0x66041913, 0x1e1c2307, 0x05002907,
  0x19001602, 0x19032baf, 0x032b0611, 0x01181621,
  // [2d90]
  0x1c252312, 0x170d0fbe, 0x3f660112, 0x0400181f,
  0x01001708, 0x03012b12, 0x050b2707, 0x06030109,
  0x14001608, 0x25000e02, 0x06011612, 0x01003820,
  0x29160b12, 0x172701af, 0x013816bb, 0x1f292713,
  // [2da0]
  0x010f3812, 0x0c060107, 0x27013f12, 0x27001712,
  0x66272920, 0x1f043faf, 0x0c1d0108, 0x2b000507,
  0x19042712, 0x2b172255, 0x432729af, 0x2b1d45af,
  0x21001722, 0x08401912, 0x252330a4, 0x010c2b08,
  // [2db0]
  0x450201a4, 0x15001602, 0x040306a4, 0x121d40a4,
  0x380f0d07, 0x38000212, 0x14166613, 0x100306af,
  0x0f121f07, 0x66100312, 0x16060baf, 0x0c381f08,
  0x1d124013, 0x12000d09, 0x06380409, 0x040651af,
  // [2dc0]
  0x01273f11, 0x18121f14, 0x301e2312, 0x27292baf,
  0x0b002912, 0x08160607, 0x29160309, 0x034510a4,
  0x0c182221, 0x45270cad, 0x1d151614, 0x01151612,
  0x06036612, 0x19041521, 0x0f120c07, 0x03066607,
  // [2dd0]
  0x04100b13, 0x25301e55, 0x27142914, 0x08050109,
  0x010c2bad, 0x66030660, 0x081719ad, 0x19000d10,
  0x301c0e20, 0x0f011fa4, 0x19403f12, 0x0c292707,
  0x1d161255, 0x0d170821, 0x0b0622af, 0x27212912,
  // [2de0]
  0x0d223813, 0x66100b14, 0x01080407, 0x38000c12,
  0x17190c12, 0x1e0e2355, 0x1e0e1c14, 0x0f03066f,
  0x03065112, 0x2b430822, 0x04294009, 0x40451d09,
  0x01003f13, 0x23251e09, 0x06000320, 0x01100609,
  // [2df0]
  0x43063807, 0x1e302312, 0x0d160813, 0x0f0d0812,
  0x01020812, 0x033f06cf, 0x064308af, 0x40000812,
  0x3f08056f, 0x021808ad, 0x1c252309, 0x0d0f08a4,
  0x29193860, 0x162927bc, 0x1d272960, 0x380d1daf,
  // [2e00]
  0x061708bc, 0x16000813, 0x08060333, 0x0d083f60,
  0x083f0621, 0x0f004011, 0x251e2307, 0x0d1d4055,
  0x17293f12, 0x1d451211, 0x16081512, 0x1d141607,
  0x124540af, 0x06100160, 0x10020b21, 0x15000113,
  // [2e10]
  0x010f2908, 0x050127a4, 0x051029af, 0x1d0f1621,
  0x02030607, 0x0d292709, 0x273f21bc, 0x22081408,
  0x051601ac, 0x1629276f, 0x10380512, 0x2b1816bb,
  0x450501af, 0x080f29a4, 0x3f270112, 0x020b1013,
  // [2e20]
  0x3f005113, 0x101401ad, 0x14002121, 0x02381607,
  0x0b0151af, 0x0b021014, 0x0b0218be, 0x2b1606af,
  0x18004013, 0x16042bbb, 0x030615ad, 0x27211812,
  0x45170409, 0x19000614, 0x66170111, 0x0d0f3813,
  // [2e30]
  0x0f000802, 0x010d1707, 0x04001935, 0x1f000635,
  0x40011909, 0x031f2bbb, 0x01002134, 0x432b0607,
  0x1c002302, 0x10292121, 0x080f15a4, 0x301c0e14,
  0x04011955, 0x0c450309, 0x29270f12, 0x03100baf,
  // [2e40]
  0x0d001735, 0x0b000434, 0x03100212, 0x22000814,
  0x0f290612, 0x66004013, 0x292712ad, 0x02000512,
  0x1400041f, 0x18031013, 0x14002b11, 0x181d406f,
  0x17012120, 0x060b2721, 0x03060baf, 0x031004a4,
  // [2e50]
  0x1d184011, 0x66042712, 0x01062260, 0x0c024512,
  0x010d0655, 0x062b0107, 0x00000603, 0x1d192755,
  0x40000222, 0x19003f21, 0x38000312, 0x21001608,
  0x1d0d16af, 0x02140b09, 0x0e302320, 0x0f0519ac,
  // [2e60]
  0x0c011612, 0x120c1707, 0x0b020807, 0x231e0e14,
  0x10001507, 0x0f003f11, 0x43002b08, 0x22001809,
  0x25231ca4, 0x010408bc, 0x08010523, 0x3f000c13,
  0x29145112, 0x10001922, 0x0b001022, 0x06001022,
  // [2e70]
  0x06001019, 0x19100611, 0x0d014309, 0x041906a4,
  0x1d170509, 0x04192909, 0x291901a4, 0x120c4508,
  0x023f0b09, 0x0e231e14, 0x192927af, 0x0c4501bc,
  0x04171607, 0x1466036f, 0x451040ac, 0x0e1c3010,
  // [2e80]
  0x15003f20, 0x01036621, 0x16142912, 0x100b0107,
  0x0b020607, 0x1d401655, 0x04030d07, 0x0b0c2b07,
  0x250e1ebe, 0x194016bb, 0x010c2907, 0x10272960,
  0x05082b08, 0x02030609, 0x061d0107, 0x16080508,
  // [2e90]
  0x062b0baf, 0x0f021f14, 0x12451fac, 0x030651af,
  0x18006611, 0x05030b07, 0x05101909, 0x010d2707,
  0x0400190d, 0x02000513, 0x01021912, 0x0b0603a4,
  0x0b124555, 0x43000107, 0x0b025112, 0x030c6611,
  // [2ea0]
  0x251c0e6f, 0x22000412, 0x05001511, 0x272921bc,
  0x15143fac, 0x17080fbe, 0x0f012b07, 0x04001620,
  0x0d003807, 0x0d004307, 0x19001009, 0x01002b09,
  0x174340ac, 0x15162134, 0x04085112, 0x38080508,
  // [2eb0]
  0x020105ad, 0x66080520, 0x03190c07, 0x063f0112,
  0x080401ac, 0x0c080112, 0x010d0612, 0x100603ad,
  0x2b051a12, 0x19002b21, 0x0b000312, 0x051601af,
  0x0d170813, 0x38020baf, 0x06002707, 0x06001814,
  // [2ec0]
  0x060104ac, 0x2b1f1211, 0x080b18af, 0x16001f11,
  0x1f0d0113, 0x301e25a4, 0x0f4512a4, 0x19060213,
  0x380d0f08, 0x19001010, 0x27000321, 0x020b1009,
  0x01120caf, 0x03040609, 0x43210112, 0x034301a4,
  // [2ed0]
  0x04193fad, 0x0c451214, 0x230e1c11, 0x450d12a4,
  0x66004020, 0x14001807, 0x06031912, 0x38083fbe,
  0x45121d14, 0x22001902, 0x06001910, 0x020b0107,
  0x1d1204ac, 0x45002709, 0x0b381408, 0x21221d12,
  // [2ee0]
  0x29222712, 0x191d0408, 0x12013f12, 0x19161d12,
  0x15161d22, 0x191d2713, 0x14000108, 0x431d0111,
  0x38106609, 0x380f01a4, 0x1f3f29af, 0x1c230ebb,
  0x3f002b14, 0x272921be, 0x15291d11, 0x15002711,
  // [2ef0]
  0x0c001821, 0x16003f22, 0x43010509, 0x170112a4,
  0x06661008, 0x02150baf, 0x030105a4, 0x05060208,
  0x06270112, 0x0e1c2502, 0x0f060207, 0x01003812,
  0x060502ac, 0x0b661008, 0x0d051512, 0x05106608,
  // [2f00]
  0x0c1d1855, 0x064301a4, 0x22272913, 0x040f0d08,
  0x1e252308, 0x100c4055, 0x03451260, 0x27182922,
  0x0b2701a4, 0x27291809, 0x0b060108, 0x401d18ad,
  0x27222913, 0x18022260, 0x04001208, 0x29221808,
  // [2f10]
  0x18002107, 0x0c004023, 0x1829276f, 0x29000109,
  0x1c0e25ad, 0x101606a4, 0x231e30ad, 0x251c30bb,
  0x19660322, 0x05000c07, 0x01660360, 0x1f003f21,
  0x12144512, 0x066619af, 0x25003022, 0x15001908,
  // [2f20]
  0x40381855, 0x401d4508, 0x45121d22, 0x05451211,
  0x3f001013, 0x01660355, 0x45381255, 0x010b0213,
  0x19171207, 0x121d4514, 0x40381812, 0x4012456f,
  0x38010da4, 0x450f0ca4, 0x380c1fba, 0x080d1808,
  // [2f30]
  0x1c231e21, 0x080d1512, 0x08191007, 0x17120c09,
  0x04001002, 0x401814ad, 0x103801af, 0x051501af,
  0x10061521, 0x120c1907, 0x05381712, 0x05101560,
  0x19142107, 0x03660422, 0x38030112, 0x16662b12,
  // [2f40]
  0x03002213, 0x03661922, 0x05011513, 0x14150112,
  0x27030112, 0x0d380f22, 0x292b2714, 0x30251ea4,
  0x1f000b13, 0x292766af, 0x401d08af, 0x0f010d14,
  0x66001921, 0x190b1f07, 0x01036612, 0x451d4060,
  // [2f50]
  0x010366af, 0x30251c12, 0x0f401d09, 0x0c000312,
  0x0f050d07, 0x19016609, 0x033801ad, 0x45120d07,
  0x04140c12, 0x29000608, 0x16221713, 0x45120302,
  0x0c120307, 0x06000420, 0x062217bc, 0x17430d09,
  // [2f60]
  0x15170c12, 0x0f0d38a4, 0x06020fa4, 0x38002b02,
  0x17051921, 0x0b000c07, 0x17190807, 0x02010f07,
  0x15001907, 0x10000610, 0x231e3008, 0x1d124009,
  0x2b000c09, 0x19001612, 0x380d1407, 0x0f184511,
  // [2f70]
  0x1c231ebc, 0x181904af, 0x300e1ea4, 0x19180408,
  0x432701a4, 0x1d005113, 0x08000d23, 0x06450107,
  0x17001f13, 0x04000c09, 0x1d181955, 0x30251e21,
  0x0e1c3013, 0x1c002533, 0x0d051dbc, 0x012b1655,
  // [2f80]
  0x06011812, 0x05103855, 0x03106608, 0x0e1c1eac,
  0x451d4011, 0x06296612, 0x17003f11, 0x1c001e21,
  0x0f010812, 0x66062912, 0x08380b22, 0x12181d13,
  0x020b1808, 0x662b0109, 0x43012707, 0x25001e35,
  // [2f90]
  0x066601ad, 0x0d083834, 0x191629af, 0x40451da4,
  0x380105bc, 0x0b2b1921, 0x18151621, 0x06001813,
  0x0c292713, 0x66380d13, 0x2b052212, 0x18041012,
  0x38191621, 0x19041808, 0x0c002909, 0x0f2227a4,
  // [2fa0]
  0x0e3023a4, 0x40005113, 0x16151922, 0x19006608,
  0x15292722, 0x191627af, 0x2b183813, 0x450b0d09,
  0x02660112, 0x1c3023ad, 0x08030209, 0x08060b07,
  0x16172711, 0x2b663f12, 0x0b6645af, 0x0b050612,
  // [2fb0]
  0x0d004008, 0x0d0f3809, 0x020f08a4, 0x19042213,
  0x15160b12, 0x011906ad, 0x05022107, 0x29000412,
  0x0c121d12, 0x02030112, 0x050b0108, 0x381d0609,
  0x15050112, 0x040366ad, 0x0e252302, 0x660105be,
  // [2fc0]
  0x08382b07, 0x1d002711, 0x19012bac, 0x29000312,
  0x18010d12, 0x401d15bc, 0x0b0145a4, 0x66000521,
  0x40001813, 0x29190412, 0x18403f12, 0x0f380daf,
  0x060315bc, 0x380d0413, 0x01000f12, 0x2b160612,
  // [2fd0]
  0x04191407, 0x1d454012, 0x1c1e0ead, 0x03181d55,
  0x03171507, 0x011f0555, 0x10124512, 0x12004008,
  0x03000512, 0x0b002208, 0x040601a4, 0x380c2b55,
  0x0f004012, 0x12000410, 0x10000402, 0x16451255,
  // [2fe0]
  0x19293f12, 0x3f6601af, 0x04191413, 0x251c2321,
  0x25301ca4, 0x30001e14, 0x29272123, 0x66001813,
  0x45002211, 0x04036622, 0x05006608, 0x1e0e2521,
  0x10002112, 0x1704226f, 0x12000d11, 0x161501af,
  // [2ff0]
  0x12000802, 0x0b036660, 0x38010dbc, 0x08040107,
  0x21002b14, 0x020c0d07, 0x05660355, 0x050d27af,
  0x23251e11, 0x661f01a4, 0x22381712, 0x0b011555,
  0x401719a4, 0x19041d12, 0x19161712, 0x1e0e25a4,

  // [3000]
  0x141d1960, 0x011619ac, 0x14290413, 0x15001711,
  0x40451223, 0x12191421, 0x161701af, 0x45001822,
  0x05011511, 0x1d041912, 0x04011607, 0x19001411,
  0x16401712, 0x06101d07, 0x171d2109, 0x27172b60,
  // [3010]
  0x15001912, 0x0c001d20, 0x06083faf, 0x4027296f,
  0x251e2355, 0x18002123, 0x400d1007, 0x04192112,
  0x17030f13, 0x03060f23, 0x190b0107, 0x10060fac,
  0x150c1707, 0x19100209, 0x0e301eac, 0x12292712,
  // [3020]
  0x036619a4, 0x050c0407, 0x18001211, 0x0e251e60,
  0x38001412, 0x381d0812, 0x16151da4, 0x15036660,
  0x1e3023af, 0x101451af, 0x030227a4, 0x1c2530a4,
  0x01170f12, 0x17291412, 0x1c0e30af, 0x03012709,
  // [3030]
  0x0f0d16a4, 0x06220c12, 0x40002208, 0x121845af,
  0x08380513, 0x2b0c1709, 0x03013812, 0x102b22ad,
  0x08001208, 0x220b0220, 0x19020b12, 0x0f080421,
  0x060b1055, 0x270f01af, 0x0d6608af, 0x0f1d10a4,
  // [3040]
  0x10000b11, 0x04084021, 0x19050112, 0x1e0e1cbb,
  0x45124060, 0x18002208, 0x06660309, 0x010605af,
  0x12000408, 0x19000512, 0x01005113, 0x0c141d14,
  0x1d400c21, 0x141d406f, 0x030d6607, 0x66041609,
  // [3050]
  0x301c0e09, 0x0b661912, 0x401d0cbe, 0x14026608,
  0x12150c12, 0x100416a4, 0x0c000411, 0x380d0f07,
  0x22061008, 0x03040cad, 0x38430109, 0x10191413,
  0x19001509, 0x19001622, 0x400c1daf, 0x0f2127af,
  // [3060]
  0x38290512, 0x08170522, 0x27291913, 0x15036613,
  0x21013faf, 0x01191560, 0x15121d12, 0x38020112,
  0x380805cf, 0x06003f07, 0x29003f22, 0x0d014307,
  0x0d272922, 0x08002908, 0x270c29af, 0x0d4512ad,
  // [3070]
  0x21191612, 0x0f162112, 0x14001912, 0x0c050660,
  0x06000321, 0x020b0407, 0x0b100213, 0x0d000608,
  0x0f010522, 0x45001809, 0x151d1612, 0x01100b60,
  0x01001012, 0x020501af, 0x0f001213, 0x231c3009,
  // [3080]
  0x0b292711, 0x17004012, 0x17041912, 0x0c222709,
  0x21004012, 0x120b0107, 0x0c402122, 0x14192907,
  0x01040307, 0x3f000b22, 0x27001f13, 0x01100c07,
  0x18061421, 0x04660112, 0x0b024509, 0x432101af,
  // [3090]
  0x06010520, 0x0c000320, 0x08272912, 0x06290112,
  0x0366046f, 0x03380f07, 0x0c001508, 0x1d0b1f07,
  0x43003813, 0x40451507, 0x2b001f08, 0x272908af,
  0x1d151608, 0x06380f07, 0x0f010c09, 0x05272921,
  // [30a0]
  0x08000d35, 0x272b0822, 0x66010fbc, 0x03196655,
  0x0f2b0d08, 0x10036609, 0x020b1007, 0x24004310,
  0x14004507, 0x19001212, 0x18004509, 0x0f1f2912,
  0x38002713, 0x17120109, 0x14036622, 0x43170155,
  // [30b0]
  0x0b170408, 0x02221655, 0x380d0f55, 0x14002202,
  0x121d4008, 0x08100107, 0x18001908, 0x40001711,
  0x01052907, 0x0d1f3812, 0x100301ad, 0x19041707,
  0x16151908, 0x0c060108, 0x25231ebe, 0x29211812,
  // [30c0]
  0x222b0c08, 0x08190155, 0x0d0f1f09, 0x1f661aa4,
  0x17190422, 0x17080112, 0x0d381507, 0x2b001509,
  0x051d2b07, 0x10010b12, 0x020b05ad, 0x10020821,
  0x0b001620, 0x020b05ac, 0x0b030212, 0x43450507,
  // [30d0]
  0x0d000522, 0x0e1e1caf, 0x0c000207, 0x1c300eac,
  0x2b040caf, 0x1f184512, 0x23253012, 0x0b160112,
  0x03000b09, 0x0d0b1855, 0x05010809, 0x30230e55,
  0x10030208, 0x100c29af, 0x06100412, 0x27212913,
  // [30e0]
  0x27100609, 0x25000e23, 0x18002708, 0x0d0f1821,
  0x29001808, 0x45001712, 0x14001811, 0x27292122,
  0x17041da4, 0x22001413, 0x17001913, 0x38270512,
  0x0b180308, 0x27001811, 0x231e1c12, 0x180201af,
  // [30f0]
  0x19011707, 0x020b0608, 0x0b400d07, 0x291f0112,
  0x45401d08, 0x04211d12, 0x23001c20, 0x08060412,
  0x02000507, 0x020b0512, 0x06000508, 0x22042108,
  0x40001212, 0x43660512, 0x0c060408, 0x0f124555,
  // [3100]
  0x0c080620, 0x060d0f07, 0x1f0b6609, 0x01222155,
  0x080c0409, 0x04660355, 0x08191807, 0x0d160612,
  0x45140612, 0x12451dbe, 0x04660312, 0x2b001713,
  0x0b100109, 0x40001611, 0x1622196f, 0x04001702,
  // [3110]
  0x05451209, 0x03021907, 0x01292755, 0x17451dbb,
  0x43000d02, 0x251e0e55, 0x0b000508, 0x010610af,
  0x19182907, 0x03005113, 0x12030512, 0x06021f14,
  0x08010fa4, 0x01001f21, 0x0c1210a4, 0x14000b08,
  // [3120]
  0x431001a4, 0x2b050109, 0x1e250e09, 0x180501a4,
  0x182129af, 0x0d451211, 0x08012960, 0x430c01ad,
  0x14000820, 0x450d0faf, 0x45124307, 0x08211fbc,
  0x061703bc, 0x1f3f1aaf, 0x1e1c2511, 0x450b27a4,
  // [3130]
  0x01000b07, 0x2b004308, 0x1c002535, 0x0b1510ad,
  0x01272911, 0x0b031007, 0x38030f02, 0x12180d08,
  0x180d0f09, 0x02222b12, 0x100b0222, 0x020b106f,
  0x0b381060, 0x050f1507, 0x1e302360, 0x05000b02,
  // [3140]
  0x0f0d1812, 0x1c302555, 0x231c2508, 0x100b0412,
  0x0f401609, 0x12451408, 0x10060455, 0x1d010607,
  0x011916ad, 0x060366ad, 0x0c0306a4, 0x030c1f21,
  0x061f3f22, 0x45121821, 0x030f3fac, 0x270419bc,
  // [3150]
  0x451240bc, 0x1f291812, 0x081d4007, 0x3f2b3821,
  0x01051f07, 0x191716af, 0x402b3f23, 0x17430809,
  0x27401d33, 0x061f0323, 0x2b0417cf, 0x290306af,
  0x16000b20, 0x043f0612, 0x3f001721, 0x18003f20,
  // [3160]
  0x0d0f1407, 0x3f0429af, 0x1e1c0e55, 0x030d0107,
  0x1d192260, 0x12030107, 0x66050308, 0x0f001f21,
  0x0d221412, 0x050f1908, 0x01066660, 0x12451821,
  0x66002b09, 0x08000b12, 0x06012909, 0x01061007,
  // [3170]
  0x061402a4, 0x0f004509, 0x0b190411, 0x03041921,
  0x03002b13, 0x22660baf, 0x0c162ba4, 0x1d033802,
  0x06010d09, 0x031001ac, 0x1200181f, 0x0b190414,
  0x0b000422, 0x02660309, 0x45002b08, 0x43270155,
  // [3180]
  0x22100412, 0x0c080107, 0x0c272911, 0x062221a4,
  0x21004009, 0x2b010fa4, 0x19002b13, 0x45000511,
  0x250e3012, 0x021006a4, 0x400215af, 0x1d451907,
  0x191004ad, 0x15011807, 0x08041907, 0x1e0e30a4,
  // [3190]
  0x180301a4, 0x43013fad, 0x400115ad, 0x04013f12,
  0x14013fad, 0x45401221, 0x43010d09, 0x031f01a4,
  0x18004008, 0x1d1921af, 0x17212712, 0x27171612,
  0x18401d20, 0x451d0ca4, 0x0f002b08, 0x181d4014,
  // [31a0]
  0x12454060, 0x01120612, 0x06124511, 0x08211960,
  0x17001210, 0x03020b60, 0x060b0112, 0x21451212,
  0x45002908, 0x1e2325be, 0x06030107, 0x0d001207,
  0x0c124560, 0x18002221, 0x010306af, 0x192b0ba4,
  // [31b0]
  0x19001d11, 0x43002712, 0x080f0c12, 0x1d002209,
  0x08002b21, 0x012705af, 0x271229bc, 0x100b1460,
  0x08014307, 0x0c000b12, 0x19451209, 0x0b406607,
  0x27191f20, 0x030c0660, 0x21272923, 0x02036613,
  // [31c0]
  0x29001f12, 0x080601af, 0x042119af, 0x060f2712,
  0x0f0d1912, 0x272b19bc, 0x293f21af, 0x01272955,
  0x38003f11, 0x08001920, 0x27213f22, 0x45000d07,
  0x0c006608, 0x0d151760, 0x0b021060, 0x081d1512,
  // [31d0]
  0x050322be, 0x01162912, 0x27080f12, 0x12004022,
  0x19000b13, 0x251c2313, 0x12001608, 0x010227a4,
  0x0b060309, 0x06030ba4, 0x1c230e34, 0x40001202,
  0x080522af, 0x01220522, 0x032201af, 0x1e0e3021,
  // [31e0]
  0x15051812, 0x22100b12, 0x05061913, 0x16050112,
  0x10060213, 0x08010521, 0x15121d07, 0x0b002213,
  0x0b4045a4, 0x196622af, 0x220501af, 0x010540cf,
  0x04000b07, 0x270d2b12, 0x40661907, 0x0f004521,
  // [31f0]
  0x02662712, 0x40001214, 0x1e2325af, 0x1d041902,
  0x40292708, 0x12000c20, 0x0b3f51af, 0x02226613,
  0x226619bb, 0x270d2912, 0x401018cf, 0x38080107,
  0x380d0f14, 0x190d0f21, 0x272b1013, 0x12050855,
  // [3200]
  0x082901a4, 0x100b1514, 0x0b101907, 0x040b1012,
  0x66003f21, 0x10021521, 0x0d170112, 0x29271009,
  0x10150c12, 0x03270807, 0x231c1e08, 0x17001f23,
  0x1d401207, 0x0b101621, 0x16401d12, 0x19020513,
  // [3210]
  0x19000211, 0x0f003810, 0x10190455, 0x1e0e25ad,
  0x04101909, 0x190102af, 0x060f01a4, 0x030c1808,
  0x1d0c4060, 0x21182221, 0x01001512, 0x1d0340af,
  0x010814ad, 0x191829a4, 0x02050307, 0x12401dac,
  // [3220]
  0x15000321, 0x030b0107, 0x27663faf, 0x03041912,
  0x03004014, 0x19180c13, 0x66273f12, 0x03154060,
  0x0f001809, 0x18226622, 0x0c182207, 0x40003f23,
  0x161545bb, 0x01100cad, 0x29032712, 0x03151612,
  // [3230]
  0x0d0b0207, 0x040f1613, 0x05660311, 0x0c012bac,
  0x021f0b12, 0x041921bc, 0x011d2912, 0x01213f6f,
  0x01161707, 0x38292712, 0x010627a4, 0x0d002223,
  0x03063fac, 0x042715be, 0x152921af, 0x45003807,
  // [3240]
  0x22001822, 0x050f0d13, 0x45084008, 0x380d0507,
  0x18004535, 0x1d194008, 0x01452ba4, 0x012b2955,
  0x10162b07, 0x22003f22, 0x08020b07, 0x38291960,
  0x27292b21, 0x04002907, 0x38010ba4, 0x2b101408,
  // [3250]
  0x191d0b07, 0x120f1807, 0x04004007, 0x250e1cbe,
  0x3f451212, 0x45121f07, 0x01660d09, 0x45000621,
  0x0f1601af, 0x16191dac, 0x120c2ba4, 0x151416ad,
  0x45002b11, 0x02040155, 0x190b0d12, 0x08000423,
  // [3260]
  0x0f1d1207, 0x0c4506a4, 0x15041811, 0x191d0608,
  0x180c1fac, 0x0b0106a4, 0x12194507, 0x06001511,
  0x18001909, 0x01080507, 0x45004022, 0x19001514,
  0x0f0d22af, 0x453801a4, 0x01062907, 0x05191609,
  // [3270]
  0x16001520, 0x01124507, 0x27662911, 0x40010b12,
  0x050f0da4, 0x290d2221, 0x25300e22, 0x06000f07,
  0x15140109, 0x21002220, 0x1d121612, 0x06011711,
  0x03216609, 0x1e0e30ac, 0x25003014, 0x120c0607,
  // [3280]
  0x660d0312, 0x0b6606a4, 0x29000613, 0x0b050107,
  0x0d451212, 0x19000622, 0x06190407, 0x041d19ad,
  0x21011f12, 0x03190c12, 0x300e2511, 0x40004521,
  0x0c401d22, 0x0b3843a4, 0x450f01a4, 0x020f1021,
  // [3290]
  0x10006620, 0x0f0d0412, 0x15041921, 0x1d0c40af,
  0x0b021912, 0x100314bc, 0x191d4014, 0x16002111,
  0x0c1d4011, 0x2b142234, 0x05001f21, 0x0d0f386f,
  0x22272922, 0x29142713, 0x14221f22, 0x012b22ad,
  // [32a0]
  0x17000513, 0x2b1f1413, 0x2b2714bc, 0x14380baf,
  0x08000422, 0x040601ac, 0x1d124007, 0x16041933,
  0x0f221412, 0x18004511, 0x291d0d13, 0x12000509,
  0x0d1808ad, 0x38221434, 0x10061d07, 0x100b1421,
  // [32b0]
  0x0e301e07, 0x1c230e55, 0x1c0e1e23, 0x1c300e13,
  0x06041712, 0x2b0304ad, 0x14060413, 0x0d0f3821,
  0x05010fac, 0x380105a4, 0x40000107, 0x05010fbc,
  0x06100107, 0x010d19a4, 0x020b66bc, 0x0f000108,
  // [32c0]
  0x0b001414, 0x14001220, 0x12180c6f, 0x18124560,
  0x100b27af, 0x0f0d18ad, 0x041d4014, 0x45272b12,
  0x17001612, 0x00001815, 0x122701af, 0x0c041613,
  0x22001f11, 0x0e30236f, 0x163f0460, 0x05380d21,
  // [32d0]
  0x450c1f55, 0x40380f09, 0x22041612, 0x0f170809,
  0x16081912, 0x1c231e11, 0x0f010809, 0x10002207,
  0x191f0112, 0x1d12456f, 0x0b000413, 0x2b170409,
  0x38290f08, 0x18141f12, 0x14124521, 0x0d0f3f12,
  // [32e0]
  0x0b191f12, 0x1f1901af, 0x1d163f12, 0x66001d14,
  0x29004020, 0x45154002, 0x0c1d06cf, 0x0c010409,
  0x451240af, 0x12453f09, 0x0f432212, 0x01220508,
  0x43000d33, 0x1d003f13, 0x29010f09, 0x43120c12,
  // [32f0]
  0x01291911, 0x16060109, 0x1d454022, 0x01192921,
  0x01004507, 0x0c010655, 0x25001c10, 0x18001410,
  0x45124014, 0x10030609, 0x04000811, 0x1d000b07,
  0x15001d08, 0x0b100212, 0x0c400812, 0x17161412,
  // [3300]
  0x0c1545af, 0x0c124512, 0x08001812, 0x0f1401af,
  0x271429af, 0x38450107, 0x0f0d08bb, 0x270c10ad,
  0x050d0f08, 0x0f1d08af, 0x1d1614be, 0x1d401013,
  0x402927af, 0x0f380d12, 0x383f0112, 0x1d212260,
  // [3310]
  0x27002113, 0x08210112, 0x050d38ad, 0x220f3f21,
  0x38000d02, 0x080f17be, 0x3f05386f, 0x04002211,
  0x17041613, 0x080f0d02, 0x1d404520, 0x23300e21,
  0x04221912, 0x18001414, 0x16002120, 0x011d2913,
  // [3320]
  0x0d083823, 0x0c190b12, 0x19160421, 0x0d4503af,
  0x0d190821, 0x0f0d40af, 0x18100612, 0x01061420,
  0x0b023f21, 0x21191709, 0x18001f23, 0x0f0d0612,
  0x1d224014, 0x04192122, 0x1d082221, 0x3f001713,
  // [3330]
  0x27001913, 0x06000822, 0x0c001411, 0x30231c21,
  0x231e1c09, 0x150817af, 0x123801a4, 0x2300301f,
  0x170d05be, 0x011d4012, 0x18141712, 0x29036613,
  0x401d0813, 0x401d08bc, 0x272b29af, 0x04000813,
  // [3340]
  0x0d210821, 0x0d011713, 0x08000d14, 0x0e002502,
  0x1e0e30ad, 0x0d1d40ac, 0x180f1207, 0x223f1421,
  0x010c0307, 0x08001608, 0x03042111, 0x0419036f,
  0x04003f20, 0x08400d12, 0x100614ce, 0x0b190212,
  // [3350]
  0x25230e14, 0x06662112, 0x191422af, 0x05000836,
  0x1f000821, 0x16453fac, 0x380f0c12, 0x16380f82,
  0x0e002333, 0x66272912, 0x380b0d09, 0x1e0e2555,
  0x23301eaf, 0x0d180f12, 0x38292112, 0x66450112,
  // [3360]
  0x27180c13, 0x08001611, 0x18663fad, 0x0c001732,
  0x142722bb, 0x2b003f21, 0x16273f13, 0x223f0822,
  0x04272bad, 0x0f273f12, 0x0f00181d, 0x124540be,
  0x04211412, 0x66001d20, 0x38000612, 0x0d040fad,
  // [3370]
  0x03082121, 0x27150baf, 0x170122bc, 0x22401dad,
  0x14180409, 0x231c30bb, 0x1c2523ad, 0x010c1607,
  0x21000c14, 0x04163f13, 0x190318ac, 0x03660b11,
  0x18030bad, 0x02180baf, 0x031701af, 0x103802ad,
  // [3380]
  0x272b2912, 0x06003808, 0x66030622, 0x451f1812,
  0x273f2109, 0x0f380111, 0x03001934, 0x45001d09,
  0x66001213, 0x401518ad, 0x19380c07, 0x0e3025bc,
  0x16001820, 0x40000522, 0x4e00371f, 0x14000511,
  // [3390]
  0x45660112, 0x251e1cad, 0x40050da4, 0x05000122,
  0x084045af, 0x45181208, 0x0f000112, 0x0d080107,
  0x01050d12, 0x08001408, 0x18451209, 0x29272108,
  0x04082912, 0x182b0d60, 0x38160112, 0x45150860,
  // [33a0]
  0x0e301c20, 0x221d12af, 0x0d040808, 0x380f0809,
  0x18451223, 0x03001822, 0x19002908, 0x06451212,
  0x0b150f07, 0x1c231e60, 0x03061da4, 0x100b2b20,
  0x12001020, 0x0b0d01af, 0x0c000611, 0x1d401560,
  // [33b0]
  0x12452212, 0x451206af, 0x18192208, 0x1c232522,
  0x08660b12, 0x03661d14, 0x45660312, 0x020f0d09,
  0x101d4021, 0x451d4014, 0x16000311, 0x1e250e21,
  0x25233013, 0x43060155, 0x160408a4, 0x010b4309,
  // [33c0]
  0x1d0f0808, 0x012b1612, 0x0d451209, 0x29000813,
  0x15214023, 0x15044014, 0x1f002134, 0x053f2912,
  0x21003f21, 0x0c6640cf, 0x0d0416ad, 0x01120c22,
  0x121f2b60, 0x66030609, 0x010c1f34, 0x083f27af,
  // [33d0]
  0x01003808, 0x3f03456f, 0x21000f21, 0x04192907,
  0x06002712, 0x38004007, 0x1d150112, 0x0c006622,
  0x2b0601ad, 0x120418ac, 0x660603cf, 0x03010c12,
  0x40141660, 0x190301ac, 0x0d0f29af, 0x38000807,
  // [33e0]
  0x0f380d13, 0x08002211, 0x230e2560, 0x0d004513,
  0x03011807, 0x08140408, 0x0d4012af, 0x0c082707,
  0x0f002b11, 0x02012707, 0x04121f09, 0x02661f09,
  0x1d001f12, 0x0c0614ad, 0x02140612, 0x141d16ac,
  // [33f0]
  0x27061621, 0x05001722, 0x2704196f, 0x45100b08,
  0x18026612, 0x04010513, 0x0f000102, 0x22124507,
  0x380f10ac, 0x02000313, 0x17020b12, 0x212704a4,
  0x19040112, 0x190b1612, 0x40020baf, 0x141d18bb,

  // [3400]
  0x0f121f11, 0x191d02a4, 0x300e1eac, 0x230e3014,
  0x10014007, 0x40001d02, 0x18191d12, 0x12002909,
  0x0f0817af, 0x0b100308, 0x022216ac, 0x030627a4,
  0x16000c09, 0x03061d07, 0x400c12af, 0x020b2214,
  // [3410]
  0x270d0508, 0x2b000c20, 0x40290c12, 0x45002913,
  0x450c12af, 0x0c001521, 0x0f0d0508, 0x22451509,
  0x40450c6f, 0x040d1612, 0x30250e22, 0x401d0cbb,
  0x1d1915bc, 0x0c404512, 0x19152207, 0x04190d07,
  // [3420]
  0x193f1521, 0x0000220a, 0x06015107, 0x23251eac,
  0x12001f1d, 0x160d15be, 0x0f211d11, 0x38152907,
  0x042119ad, 0x15662709, 0x120d1fab, 0x18153f13,
  0x18011912, 0x06011f34, 0x03041913, 0x66031512,
  // [3430]
  0x19210321, 0x00002b42, 0x12450809, 0x1e230e22,
  0x66401260, 0x06004321, 0x43271912, 0x033801ac,
  0x1d660baf, 0x10001511, 0x04010baf, 0x0b0c01a4,
  0x0d1218a4, 0x06050108, 0x15145112, 0x17011507,
  // [3440]
  0x190c12a4, 0x381d0109, 0x01103812, 0x451412ac,
  0x14124555, 0x18001409, 0x270229af, 0x01050bad,
  0x231e2511, 0x2b001922, 0x17122b12, 0x06022b07,
  0x020b1d08, 0x0c181d08, 0x02000608, 0x062b2709,
  // [3450]
  0x01120c11, 0x12002b22, 0x221015bc, 0x122b1911,
  0x10060b14, 0x1d2b0107, 0x45006608, 0x0f0d3814,
  0x66001421, 0x15124560, 0x15004011, 0x01006609,
  0x05400107, 0x02061812, 0x40002708, 0x032b01af,
  // [3460]
  0x16000107, 0x06010508, 0x0f382207, 0x012b1711,
  0x3f002221, 0x0f0d0121, 0x22003f14, 0x27000420,
  0x43013812, 0x120c1d13, 0x0d1801a4, 0x080f0407,
  0x19050607, 0x451701af, 0x451202ad, 0x0c010507,
  // [3470]
  0x163f27af, 0x05182221, 0x0f1705bb, 0x40170521,
  0x010219ad, 0x0f0301a4, 0x17380512, 0x061922a4,
  0x1d000521, 0x1d1705bc, 0x400f0521, 0x40451221,
  0x45000608, 0x0e1e23bb, 0x02270112, 0x03190560,
  // [3480]
  0x1f1701af, 0x060d17a4, 0x10001914, 0x38430112,
  0x1d190407, 0x451d1609, 0x1727296f, 0x381801af,
  0x21151923, 0x15041922, 0x05060122, 0x050f3809,
  0x10660b09, 0x21431f23, 0x024317cf, 0x0c122b12,
  // [3490]
  0x400d1d09, 0x01060f09, 0x031d4022, 0x0c064523,
  0x22292711, 0x00003f42, 0x293f2121, 0x45124007,
  0x180d1212, 0x150522ad, 0x18004334, 0x1d452134,
  0x27002120, 0x05173833, 0x1f080d14, 0x660340be,
  // [34a0]
  0x27293f13, 0x3f002223, 0x05000821, 0x02106612,
  0x66212912, 0x10000508, 0x27000512, 0x181d2211,
  0x25230e11, 0x06032707, 0x0b4505ad, 0x250e1cac,
  0x0d180812, 0x1d454009, 0x16000511, 0x14001810,
  // [34b0]
  0x19150112, 0x16006611, 0x0c001002, 0x38004511,
  0x270304bc, 0x03272912, 0x27220412, 0x030f1507,
  0x06082712, 0x1f082b11, 0x172b0f55, 0x430201a4,
  0x170d0112, 0x220d4307, 0x01190411, 0x180114ad,
  // [34c0]
  0x14045112, 0x43012908, 0x0b012907, 0x2b0d0108,
  0x30001e11, 0x16001435, 0x04005108, 0x15165111,
  0x0d000102, 0x03001802, 0x27432913, 0x05382909,
  0x12450507, 0x0e2523bc, 0x40001209, 0x45001514,
  // [34d0]
  0x04000122, 0x404512ad, 0x18041909, 0x12180f13,
  0x301e0e09, 0x0f1f1821, 0x1c1e2360, 0x04103fa4,
  0x0f382707, 0x0d051f55, 0x01060508, 0x0c061507,
  0x0c001f13, 0x30251c21, 0x0f181212, 0x06150cad,
  // [34e0]
  0x18001222, 0x1f0f186f, 0x08041fac, 0x450c1520,
  0x1f0f45af, 0x19002134, 0x292751a4, 0x22272912,
  0x06660322, 0x15000c07, 0x01061008, 0x030c4555,
  0x062915bb, 0x17032912, 0x12161509, 0x0b0814ac,
  // [34f0]
  0x291921af, 0x020301af, 0x38272922, 0x1d001609,
  0x02180ba4, 0x01001921, 0x12174509, 0x060214a4,
  0x050f0102, 0x19100455, 0x0b660412, 0x0b190609,
  0x21050d12, 0x45180f12, 0x120f01a4, 0x05001213,
  // [3500]
  0x12050d55, 0x2b010c09, 0x380f1807, 0x220801ad,
  0x382b01a4, 0x17042212, 0x272922be, 0x0b011d12,
  0x2b002220, 0x080501bb, 0x430129af, 0x06004023,
  0x10223f60, 0x380f1821, 0x221f06be, 0x01181a12,
  // [3510]
  0x300e1eaf, 0x01042208, 0x0d002211, 0x22001908,
  0x1d001714, 0x0b2b2260, 0x03140221, 0x273f6613,
  0x05010608, 0x430c3f09, 0x04050108, 0x170214ac,
  0x02006620, 0x0b026611, 0x404512a4, 0x12382707,
  // [3520]
  0x43001820, 0x1d292755, 0x17000309, 0x1d124522,
  0x1200450d, 0x17006623, 0x1f2901ad, 0x66000214,
  0x17002b14, 0x1c251ebc, 0x03066608, 0x04066607,
  0x012b66a4, 0x051701af, 0x02273f12, 0x1c0e3008,
  // [3530]
  0x14020b20, 0x08172b07, 0x1d292709, 0x0c000822,
  0x01062712, 0x053f0812, 0x010f0807, 0x17000412,
  0x040c1607, 0x1d081860, 0x04291613, 0x06040112,
  0x08000512, 0x17080612, 0x10013fac, 0x010b5112,
  // [3540]
  0x1d2745af, 0x0c122912, 0x0610026f, 0x15000608,
  0x291d2712, 0x0d171912, 0x1e2523ad, 0x19451212,
  0x080f0d07, 0x21051960, 0x050c1207, 0x08002913,
  0x021006af, 0x12451fa4, 0x06010809, 0x0e231cad,
  // [3550]
  0x043f1960, 0x17003808, 0x15001920, 0x062b01ad,
  0x0b381855, 0x06050111, 0x66001d09, 0x02180102,
  0x40154512, 0x17400c12, 0x171d0caf, 0x16381912,
  0x2b002908, 0x0b030208, 0x02275112, 0x012b0fad,
  // [3560]
  0x38002b33, 0x291d0cbc, 0x291d0112, 0x0c1d406f,
  0x06430108, 0x0e301e02, 0x03016612, 0x08002712,
  0x0d0b086f, 0x380529af, 0x21002708, 0x012710ad,
  0x03101855, 0x18000d08, 0x22182b08, 0x430f0d11,
  // [3570]
  0x03061713, 0x06180ca4, 0x0c210b09, 0x04062b07,
  0x292740bb, 0x30250e07, 0x0e301c21, 0x060538af,
  0x170127af, 0x0f0d0baf, 0x060515bc, 0x06001920,
  0x15004022, 0x06660213, 0x1d161212, 0x05003821,
  // [3580]
  0x01050ba4, 0x06000513, 0x10000302, 0x19020baf,
  0x01050308, 0x380605ad, 0x0f381509, 0x05193809,
  0x15103809, 0x1c251e23, 0x12451808, 0x231c1e6f,
  0x0000380a, 0x01192911, 0x30001e23, 0x120d4513,
  // [3590]
  0x19000221, 0x29271912, 0x292719bb, 0x12004535,
  0x10004020, 0x18002908, 0x1d056655, 0x02100512,
  0x38001512, 0x080d0f08, 0x142b0308, 0x400121ac,
  0x0d001f1d, 0x0e1e30bc, 0x180f0d60, 0x011d1008,
  // [35a0]
  0x0b080212, 0x06000f11, 0x03661521, 0x0b0227af,
  0x23002509, 0x25300ead, 0x3f27296f, 0x02190655,
  0x161d1008, 0x036610be, 0x0b002707, 0x101d66a4,
  0x400f1dac, 0x10170107, 0x01182255, 0x1d403fad,
  // [35b0]
  0x04011d08, 0x0d2229ad, 0x080c0102, 0x45001408,
  0x401d3f23, 0x01061012, 0x0f0b0608, 0x21012709,
  0x1d2b1f07, 0x27000120, 0x291208be, 0x020b18af,
  0x220c4511, 0x40123f08, 0x0b450607, 0x66100609,
  // [35c0]
  0x01002b20, 0x1d002121, 0x041801af, 0x06002111,
  0x062266a4, 0x103f0b12, 0x10660baf, 0x15161455,
  0x08272913, 0x16381420, 0x0f0d08af, 0x031001ad,
  0x036612af, 0x15293f12, 0x0d002112, 0x14401921,
  // [35d0]
  0x22291daf, 0x1d191021, 0x661f01ad, 0x272906af,
  0x120140bc, 0x150f2b60, 0x66061512, 0x1f6601af,
  0x01082bac, 0x01020b12, 0x0c0845af, 0x38050607,
  0x2b002208, 0x0b012b12, 0x02050807, 0x01080607,
  // [35e0]
  0x150c01af, 0x301c0e55, 0x03060109, 0x14190422,
  0x2b063812, 0x0d380522, 0x150419ac, 0x0d121807,
  0x230e306f, 0x141f2912, 0x0f0d14a4, 0x45126607,
  0x0f0d3823, 0x0d3851af, 0x012729bc, 0x38272960,
  // [35f0]
  0x38292708, 0x04020112, 0x01082182, 0x0f0d3807,
  0x020108bc, 0x0d0f08af, 0x45121411, 0x0d080fbe,
  0x08000c08, 0x0f004007, 0x301c23ac, 0x43450112,
  0x04192712, 0x0b012712, 0x1e252314, 0x02000d14,
  // [3600]
  0x0e231e20, 0x03170607, 0x031901a4, 0x06020f12,
  0x08004012, 0x0d3801a4, 0x0f053814, 0x030f0d14,
  0x0f080daf, 0x0d001811, 0x231c3002, 0x0d000520,
  0x38051913, 0x05002713, 0x45222955, 0x02040108,
  // [3610]
  0x0b0227ac, 0x122716a4, 0x12224507, 0x15041907,
  0x0f013807, 0x04121907, 0x18012108, 0x0666036f,
  0x02051f07, 0x100105a4, 0x100b1612, 0x01382107,
  0x06001513, 0x010f0555, 0x10061855, 0x43003814,
  // [3620]
  0x08170d09, 0x01213f11, 0x45121dbe, 0x21100b12,
  0x151604af, 0x40451d13, 0x30230e22, 0x124510af,
  0x0d2b0155, 0x250e1e60, 0x14001020, 0x16196660,
  0x05451255, 0x40121d02, 0x17010b12, 0x10041560,
  // [3630]
  0x2b031809, 0x3f001514, 0x020b10be, 0x38000408,
  0x0b1001a4, 0x12272922, 0x21001914, 0x12401d09,
  0x081f0522, 0x18000112, 0x04153f6f, 0x1d170533,
  0x0f001922, 0x27003f13, 0x03661020, 0x02012220,
  // [3640]
  0x0c004321, 0x01030807, 0x06000f13, 0x401d1209,
  0x45120f09, 0x0d010fad, 0x06010b12, 0x12220112,
  0x2b030114, 0x1d036682, 0x15662712, 0x01100807,
  0x0f0d2109, 0x05010602, 0x1c231e12, 0x066605af,
  // [3650]
  0x01061709, 0x030108a4, 0x0c001802, 0x0f0d0112,
  0x17211420, 0x17002223, 0x19150455, 0x17212221,
  0x230e1cac, 0x05081407, 0x21081709, 0x08173fbe,
  0x17224012, 0x05271512, 0x050119a4, 0x3f172209,
  // [3660]
  0x40140b12, 0x01050407, 0x0c224021, 0x08190421,
  0x01041912, 0x0f1004ad, 0x012922af, 0x10040814,
  0x050666a4, 0x19080412, 0x1e2523af, 0x01053f12,
  0x2b101412, 0x1c1e0e55, 0x010204ad, 0x19040812,
  // [3670]
  0x40451211, 0x0d0f1412, 0x16004507, 0x0d2b2207,
  0x021001a4, 0x22060314, 0x100b22be, 0x03001407,
  0x100b1809, 0x2b010c12, 0x1c251e20, 0x1e231c13,
  0x04220112, 0x450d18ad, 0x120c4011, 0x08181521,
  // [3680]
  0x3f1d08be, 0x1d001708, 0x3f401d21, 0x15000811,
  0x171d0812, 0x3f000821, 0x451208be, 0x40060813,
  0x1f2215bc, 0x16001414, 0x06016612, 0x03662b09,
  0x38453fad, 0x0c050607, 0x03660507, 0x10000b36,
  // [3690]
  0x0f060555, 0x12060c13, 0x43041f07, 0x45010512,
  0x041d1813, 0x0c004509, 0x1d401814, 0x401d1012,
  0x230e25ad, 0x0b660320, 0x1e302302, 0x1d1851af,
  0x1d0c3f21, 0x150c21a4, 0x080d15a4, 0x450f0c08,
  // [36a0]
  0x664515bb, 0x25301e21, 0x19080355, 0x40080108,
  0x03661513, 0x18401d09, 0x23302507, 0x080f3f08,
  0x01032ba4, 0x02196655, 0x660d08af, 0x080c0620,
  0x02000813, 0x29084512, 0x45122112, 0x4e372355,
  // [36b0]
  0x45161521, 0x03150421, 0x030f01af, 0x150f3820,
  0x1d0845af, 0x18002b12, 0x271501af, 0x23301e14,
  0x3f0127af, 0x15161912, 0x17010f09, 0x1c003014,
  0x060d0102, 0x193f29af, 0x04163f21, 0x27003f20,
  // [36c0]
  0x190110ad, 0x06171509, 0x220c21af, 0x17004309,
  0x19012909, 0x01080f08, 0x0d4301af, 0x04380faf,
  0x082201af, 0x03400107, 0x18123f12, 0x00000142,
  0x66140234, 0x0b212260, 0x2b001433, 0x060301ac,
  // [36d0]
  0x01080608, 0x38431908, 0x02001f12, 0x010217a4,
  0x23253007, 0x15000513, 0x301e1c34, 0x10182112,
  0x43170112, 0x19011512, 0x29270c09, 0x190b0213,
  0x01126609, 0x08001512, 0x1d451220, 0x16272911,
  // [36e0]
  0x0c001921, 0x1d0c1714, 0x173f3813, 0x401d1620,
  0x38034509, 0x29030c12, 0x101951af, 0x45061d11,
  0x162927a4, 0x05000302, 0x19002714, 0x060b0260,
  0x27100baf, 0x45022b12, 0x1d400c55, 0x0b0129a4,
  // [36f0]
  0x29002122, 0x16172223, 0x27221f12, 0x052721af,
  0x061002af, 0x100c01a4, 0x050d1009, 0x160427a4,
  0x05002913, 0x0d0829af, 0x271621be, 0x432927ad,
  0x430401a4, 0x0c451209, 0x450c1609, 0x1d401255,
  // [3700]
  0x04171f20, 0x45151609, 0x3f1514af, 0x660403a4,
  0x10066607, 0x18001f11, 0x0b0614ad, 0x030b10a4,
  0x0b010207, 0x43380f07, 0x03062107, 0x1706216f,
  0x3f000614, 0x27290622, 0x18080f12, 0x020b1423,
  // [3710]
  0x05081721, 0x10030621, 0x06003f20, 0x16004011,
  0x06011821, 0x27100621, 0x18100baf, 0x21043f20,
  0x22101812, 0x21001f12, 0x1d081212, 0x2b002114,
  0x04036660, 0x0f153f11, 0x010419ac, 0x18431422,
  // [3720]
  0x050d3809, 0x084001af, 0x061403a4, 0x10190655,
  0x080301af, 0x01190620, 0x0d0f4507, 0x05000d09,
  0x19030212, 0x07005c34, 0x12450609, 0x23300ebc,
  0x02000311, 0x01401fa4, 0x01381d07, 0x082b0413,
  // [3730]
  0x19290daf, 0x010308ac, 0x16270112, 0x40150408,
  0x143f0814, 0x05001f08, 0x1c230eac, 0x16401d60,
  0x2b000c08, 0x2b0140bc, 0x0d193fac, 0x290427af,
  0x660d3821, 0x1d401812, 0x01083809, 0x03000409,
  // [3740]
  0x66033fad, 0x100b0207, 0x1d662712, 0x05161912,
  0x011f2b60, 0x08272960, 0x1d402909, 0x2b036633,
  0x660319be, 0x29105112, 0x451612ad, 0x16105112,
  0x0d0366bc, 0x10030112, 0x032b6614, 0x04001507,
  // [3750]
  0x45121412, 0x0d0f1d08, 0x190304ac, 0x022201af,
  0x06001423, 0x29271d08, 0x10040660, 0x401d0213,
  0x1e302309, 0x081701a4, 0x161d405e, 0x0b042107,
  0x011904ad, 0x1f002213, 0x060405af, 0x06292714,
  // [3760]
  0x66190112, 0x03010855, 0x05011812, 0x12404521,
  0x0b0366a4, 0x0806666f, 0x0d000808, 0x12660312,
  0x251e30be, 0x1d000d12, 0x40100d13, 0x190f0d13,
  0x0f190112, 0x21002221, 0x40451d12, 0x12184512,
  // [3770]
  0x0e1e1c09, 0x1c253009, 0x03003808, 0x12400c12,
  0x181d2908, 0x3f451213, 0x06041008, 0x0c050107,
  0x06001214, 0x0f1704af, 0x020b5107, 0x38081f12,
  0x40451d14, 0x10002b08, 0x01004012, 0x04081d12,
  // [3780]
  0x06220b07, 0x18001a13, 0x01031708, 0x451d1008,
  0x150112a4, 0x19001413, 0x101d0413, 0x0c180455,
  0x0c034502, 0x100f0ba4, 0x10001f12, 0x1d001534,
  0x1d044023, 0x45183f13, 0x290151af, 0x0c124508,
  // [3790]
  0x10401daf, 0x0f000509, 0x0b001d21, 0x661d12af,
  0x15272911, 0x01431d08, 0x03066660, 0x25302311,
  0x17004312, 0x04451d08, 0x18000d12, 0x250e3021,
  0x23001c21, 0x43010611, 0x0d101407, 0x18001012,
  // [37a0]
  0x102b0612, 0x17010307, 0x01210f12, 0x100622bb,
  0x45042121, 0x082729be, 0x10002111, 0x0d2108bc,
  0x0f180c11, 0x43006622, 0x12660112, 0x12664312,
  0x124538af, 0x0d013f21, 0x0c660112, 0x12002b12,
  // [37b0]
  0x0b000408, 0x150c17af, 0x05001410, 0x03000c13,
  0x01042207, 0x0d1845af, 0x43222907, 0x66002b35,
  0x05150cbb, 0x10451260, 0x060c0811, 0x21004312,
  0x450c2212, 0x1c1e236f, 0x1c2530ac, 0x0b000807,
  // [37c0]
  0x0c1206a4, 0x0d080f02, 0x10062b08, 0x08166609,
  0x010f2955, 0x211002af, 0x23251e08, 0x0e1c2522,
  0x22002107, 0x040c29af, 0x0b0c1613, 0x210f2208,
  0x27011809, 0x16271708, 0x451d0c09, 0x0d160f09,
  // [37d0]
  0x273f2160, 0x14041812, 0x1d160107, 0x163801a4,
  0x0f1d0c21, 0x21160508, 0x1d181912, 0x22080512,
  0x02051807, 0x06011507, 0x02000420, 0x01051d07,
  0x15001009, 0x18100ba4, 0x01381507, 0x1d041960,
  // [37e0]
  0x10062212, 0x12001912, 0x010b0c09, 0x15063807,
  0x0b0110af, 0x1c1e2308, 0x12401d60, 0x06220112,
  0x01100b22, 0x08004002, 0x0c0b0607, 0x19661f12,
  0x050106a4, 0x0c0b1407, 0x3f291909, 0x081d0407,
  // [37f0]
  0x0d0f27a4, 0x40001522, 0x0f033fa4, 0x14162712,
  0x401245be, 0x27401d20, 0x213822ad, 0x45001d13,
  0x060138a4, 0x662b4512, 0x40121760, 0x1c0e3013,
  0x23003035, 0x050666be, 0x16000f21, 0x060366bb,

  // [3800]
  0x19100312, 0x1d120caf, 0x10040209, 0x170d0107,
  0x121d4011, 0x663f0b12, 0x030102ad, 0x100c0b07,
  0x02101809, 0x140b1912, 0x0d1508ad, 0x180b3812,
  0x180b0613, 0x03021812, 0x2b161412, 0x0e1e1cac,
  // [3810]
  0x14190420, 0x03060b02, 0x03190112, 0x04190360,
  0x0d001914, 0x661701af, 0x18000822, 0x12451d07,
  0x19210f08, 0x66060109, 0x2b660109, 0x03050109,
  0x30231c08, 0x660221bc, 0x231e2521, 0x451d1655,
  // [3820]
  0x08003814, 0x0d430107, 0x03190da4, 0x18161508,
  0x05011908, 0x38021908, 0x06006622, 0x1d004511,
  0x06006612, 0x04000520, 0x0d0301a4, 0x0b660360,
  0x02030baf, 0x03192212, 0x19001422, 0x081914af,
  // [3830]
  0x05151012, 0x182b1f21, 0x12000313, 0x1d010fad,
  0x05010609, 0x22001507, 0x061d18af, 0x10141614,
  0x16002213, 0x0e233021, 0x251e0e20, 0x213f22af,
  0x220429a4, 0x020601af, 0x04191455, 0x291922af,
  // [3840]
  0x01124520, 0x0c001922, 0x041422ac, 0x12451908,
  0x45401dbe, 0x21021009, 0x141922bc, 0x19041411,
  0x1e003020, 0x0e1c30af, 0x02100412, 0x171f2209,
  0x033817a4, 0x060104ad, 0x380508af, 0x1c0e23be,
  // [3850]
  0x06140ba4, 0x02001022, 0x1f4512af, 0x020b06ad,
  0x22052b07, 0x010c0612, 0x1d012207, 0x2b273f12,
  0x0c170112, 0x14000c13, 0x2b002107, 0x05002213,
  0x060d0f55, 0x1d003f20, 0x1e002321, 0x27001f08,
  // [3860]
  0x3f001722, 0x01063f07, 0x010c06ad, 0x01120507,
  0x12050dad, 0x2b001709, 0x38051507, 0x08160455,
  0x0d0651a4, 0x12000512, 0x05000d20, 0x0c002711,
  0x04291621, 0x0f0d1609, 0x14451808, 0x00000215,
  // [3870]
  0x0d0821bc, 0x141d1612, 0x141806ad, 0x08380112,
  0x06051560, 0x17380521, 0x061910a4, 0x10190413,
  0x0e232512, 0x05080408, 0x161d4082, 0x380b0507,
  0x19026607, 0x05011707, 0x1c1e25ad, 0x17036607,
  // [3880]
  0x046601ad, 0x01452b12, 0x38036613, 0x17030112,
  0x22000f08, 0x03140107, 0x1d060b07, 0x18100607,
  0x030d6613, 0x2b1601ad, 0x0d004312, 0x1d02056f,
  0x19183f12, 0x06140b55, 0x020b15ad, 0x1929276f,
  // [3890]
  0x051d0607, 0x30230ead, 0x296627a4, 0x0b380502,
  0x40451dad, 0x04066612, 0x04020307, 0x1d2219ad,
  0x19151809, 0x100b1808, 0x271d0c12, 0x1416156f,
  0x060301a4, 0x041214ac, 0x0b010c09, 0x16100208,
  // [38a0]
  0x020b10ad, 0x0e1c2521, 0x0d2201af, 0x661910af,
  0x45120dbc, 0x2b0108a4, 0x061927af, 0x12100b02,
  0x0b0c1d14, 0x0d190455, 0x160c1da4, 0x40181908,
  0x02291207, 0x080b1807, 0x40163fbc, 0x06141007,
  // [38b0]
  0x103f2260, 0x29271d6f, 0x01051507, 0x29273fbe,
  0x01001511, 0x05003820, 0x1e1c2309, 0x01000213,
  0x030b2b07, 0x19660421, 0x2b061f12, 0x38030111,
  0x40000c07, 0x01430407, 0x0b021423, 0x142901a4,
  // [38c0]
  0x030166af, 0x02032212, 0x19660408, 0x45022260,
  0x29142b14, 0x2b001012, 0x19000f11, 0x03001002,
  0x17001811, 0x19044013, 0x14081907, 0x12181412,
  0x040c4007, 0x022b0baf, 0x45184360, 0x041905ac,
  // [38d0]
  0x191d0409, 0x301c0e21, 0x0b3805a4, 0x0b160107,
  0x1d080512, 0x04061f08, 0x1d0203bb, 0x14180d09,
  0x0d3f0608, 0x030666af, 0x1d101507, 0x21171aaf,
  0x02030621, 0x221704ac, 0x08050b60, 0x081001af,
  // [38e0]
  0x01380d07, 0x12400cad, 0x21660320, 0x276601a4,
  0x050f3821, 0x40050112, 0x06290107, 0x45291609,
  0x06191812, 0x0f000411, 0x1d0d4560, 0x15004508,
  0x050d0faf, 0x180801af, 0x0c2b14a4, 0x080d386f,
  // [38f0]
  0x0f451212, 0x381501af, 0x0b3f0111, 0x031422af,
  0x021014a4, 0x030666ad, 0x100127af, 0x382101af,
  0x01381013, 0x0e001e09, 0x06021812, 0x0c401dbc,
  0x011910ad, 0x1c1e3009, 0x030b1020, 0x25302307,
  // [3900]
  0x0e1e2523, 0x45190cad, 0x0c062907, 0x301e1c07,
  0x0b100202, 0x0c006611, 0x2b401d09, 0x080105a4,
  0x081201a4, 0x191d22ad, 0x081901af, 0x181451af,
  0x190445af, 0x1d001408, 0x0c1851af, 0x2b061460,
  // [3910]
  0x18145111, 0x0c003809, 0x03101807, 0x0f001d11,
  0x66181460, 0x061451af, 0x06181413, 0x010f1f07,
  0x0f143809, 0x27193f11, 0x19271d07, 0x17080f11,
  0x381601af, 0x0e003709, 0x40124514, 0x1c252322,
  // [3920]
  0x1d0f40af, 0x45101d12, 0x030b1802, 0x190427af,
  0x1c1e2314, 0x1d000c21, 0x041519af, 0x21000612,
  0x18102211, 0x1d270109, 0x080d1821, 0x16122160,
  0x40161510, 0x451d0d09, 0x080d0f12, 0x18450f12,
  // [3930]
  0x25302308, 0x290d1009, 0x170f0dbe, 0x22012bac,
  0x0f002111, 0x12451602, 0x02380514, 0x0c1f0111,
  0x012b1fac, 0x060c1f55, 0x152729af, 0x1d010caf,
  0x08020607, 0x140608a4, 0x0b001908, 0x1d044512,
  // [3940]
  0x12454009, 0x66160d12, 0x0d000807, 0x021d1407,
  0x02190111, 0x0d080c12, 0x1d030107, 0x141801a4,
  0x08002208, 0x66080112, 0x1d1745af, 0x171622a4,
  0x0f001802, 0x22381921, 0x23251e55, 0x18000b22,
  // [3950]
  0x300e23bb, 0x0e251eac, 0x30231cad, 0x27381922,
  0x010d0f07, 0x192b2212, 0x05041911, 0x0f220112,
  0x301e2522, 0x05001811, 0x15003812, 0x1516196f,
  0x0c0b0807, 0x0d1d04bb, 0x17080513, 0x220619a4,
  // [3960]
  0x19001423, 0x06046621, 0x03451207, 0x10021412,
  0x15001913, 0x101406bc, 0x25002320, 0x16195112,
  0x060810ad, 0x140119a4, 0x150b1921, 0x0d040f07,
  0x1c2325ad, 0x0d180fad, 0x401d1208, 0x06212260,
  // [3970]
  0x0c401d11, 0x06142907, 0x19003808, 0x2b220cad,
  0x161d4060, 0x0d000f36, 0x0000050a, 0x0f401d60,
  0x27211920, 0x40141daf, 0x0b102b09, 0x1d101560,
  0x14290b09, 0x02222712, 0x3f001923, 0x05292712,
  // [3980]
  0x0f191713, 0x01220f07, 0x251c23be, 0x1d381912,
  0x010b14ad, 0x0c1d0412, 0x0b192ba4, 0x020b3f12,
  0x19002b08, 0x19143f13, 0x01082bad, 0x0f002b13,
  0x0e2530a4, 0x0e301e21, 0x00000c03, 0x0322666f,
  // [3990]
  0x06002222, 0x45180511, 0x0d001208, 0x2b001413,
  0x190c1dbb, 0x04060512, 0x0f180521, 0x0b661f21,
  0x0b020509, 0x38451212, 0x0c002221, 0x27182912,
  0x03150409, 0x01060b21, 0x230e1cad, 0x0d000509,
  // [39a0]
  0x431f01af, 0x22000b09, 0x40000c23, 0x01060b12,
  0x16020b6f, 0x21221712, 0x1d660112, 0x05006607,
  0x38000635, 0x0f381f12, 0x0c004021, 0x2b3f2711,
  0x01193809, 0x1d0b0112, 0x0b400c60, 0x430c0107,
  // [39b0]
  0x16001d13, 0x1d381712, 0x250e23ac, 0x40161d12,
  0x27011d09, 0x0c014308, 0x14001213, 0x401216a4,
  0x0d0827af, 0x05010d09, 0x084512af, 0x38191022,
  0x020b1014, 0x25301e22, 0x29010821, 0x0f050655,
  // [39c0]
  0x15001636, 0x190604a4, 0x152b1f13, 0x101d0520,
  0x02660312, 0x0c004013, 0x1d006612, 0x15001f12,
  0x0d0f1860, 0x011f06af, 0x101d2221, 0x2740026f,
  0x16004007, 0x040151af, 0x010d12ac, 0x06222912,
  // [39d0]
  0x081d4512, 0x05190612, 0x05000421, 0x221d4021,
  0x012b22bc, 0x140b1012, 0x45120bad, 0x100b51a4,
  0x012906ad, 0x01180512, 0x04000114, 0x22170109,
  0x29213f08, 0x03220112, 0x17050812, 0x05012221,
  // [39e0]
  0x0b1803af, 0x03661023, 0x14053f12, 0x03150613,
  0x141822ad, 0x05000414, 0x38164308, 0x250e2360,
  0x081d27af, 0x0b380f07, 0x0c000608, 0x0c060311,
  0x03010612, 0x27160421, 0x0d000523, 0x0c0805bb,
  // [39f0]
  0x05013809, 0x0f000611, 0x18000f22, 0x080105af,
  0x45001608, 0x38050fbe, 0x3f212912, 0x27212922,
  0x03663faf, 0x40211dbe, 0x18290d12, 0x22003f34,
  0x384501a4, 0x04080111, 0x29102121, 0x0b001412,
  // [3a00]
  0x03050155, 0x0d162712, 0x231c1eaf, 0x22170f13,
  0x0c2221ad, 0x01221607, 0x19001f07, 0x01270f12,
  0x18000308, 0x061604af, 0x450d0f11, 0x06001213,
  0x01001608, 0x080f17a4, 0x301e0e07, 0x451d1208,
  // [3a10]
  0x05001709, 0x02030555, 0x19162109, 0x0f0d3802,
  0x0c661609, 0x041d4020, 0x17000d14, 0x04190c12,
  0x021d0b60, 0x01033860, 0x022b0dbe, 0x0d020812,
  0x182729bc, 0x432710ad, 0x02060160, 0x27290420,
  // [3a20]
  0x401845af, 0x034012af, 0x0b080113, 0x0f013fa4,
  0x38292bbe, 0x01210baf, 0x15662bbc, 0x0c000b14,
  0x0b022bac, 0x1002016f, 0x66002121, 0x081f01a4,
  0x3f292121, 0x231c0e22, 0x10293f22, 0x21162712,
  // [3a30]
  0x193f21ce, 0x22101821, 0x08050d14, 0x101d21af,
  0x45272912, 0x04272911, 0x273f216f, 0x290317af,
  0x1d211013, 0x02011408, 0x1d0d0808, 0x18000514,
  0x1d210baf, 0x1d292721, 0x061410a4, 0x17010607,
  // [3a40]
  0x0d006614, 0x2b2708bb, 0x2b003812, 0x08000c12,
  0x10001435, 0x19030109, 0x16002107, 0x10145112,
  0x020310bb, 0x0b100222, 0x12451412, 0x161419a4,
  0x0f180d09, 0x0c1666af, 0x45400c60, 0x1d020b14,
  // [3a50]
  0x04141560, 0x192729bb, 0x101401af, 0x29271d12,
  0x0c0d4512, 0x381d0f12, 0x080c03ad, 0x45010212,
  0x08030107, 0x0d3f2960, 0x2b0b1060, 0x0f0d19af,
  0x15450d12, 0x1d082912, 0x04193f13, 0x0f380d11,
  // [3a60]
  0x380d1921, 0x380d29a4, 0x1d272912, 0x030666bb,
  0x03660509, 0x27001012, 0x12454023, 0x212b6612,
  0x010c1d08, 0x01031912, 0x0c001214, 0x01274309,
  0x19062b12, 0x02660382, 0x290c1912, 0x0f382ba4,
  // [3a70]
  0x400c2709, 0x06124508, 0x03001711, 0x152743af,
  0x66210112, 0x10000f08, 0x45161512, 0x12001908,
  0x01050655, 0x06010507, 0x01384007, 0x0b001902,
  0x0c194512, 0x38081907, 0x062b0309, 0x430138a4,
  // [3a80]
  0x18041611, 0x2b001912, 0x183f22be, 0x270c046f,
  0x274021be, 0x30251c55, 0x1f3801af, 0x100c3fbb,
  0x29271512, 0x011440ad, 0x1c302508, 0x1c253002,
  0x01000208, 0x29041909, 0x2b16216f, 0x10450b09,
  // [3a90]
  0x0b104007, 0x100b02af, 0x02106609, 0x050d1721,
  0x0d005113, 0x27293f11, 0x0f000d11, 0x03661914,
  0x01222908, 0x0b1410ad, 0x02001507, 0x100203a4,
  0x66144008, 0x663f1aa4, 0x1d164060, 0x181245be,
  // [3aa0]
  0x23250e21, 0x0b001721, 0x452b1507, 0x66024021,
  0x01212b08, 0x45400112, 0x0d0340ad, 0x083f2b12,
  0x273f16bc, 0x082b0560, 0x2b080c09, 0x08001d21,
  0x163845a4, 0x43010d12, 0x151f0812, 0x0c060812,
  // [3ab0]
  0x1804191f, 0x29191212, 0x013f1f21, 0x152b12a4,
  0x27081d13, 0x0c1201bb, 0x0c001407, 0x12190112,
  0x40120409, 0x120c3812, 0x0e001e23, 0x12223f12,
  0x10021911, 0x08171812, 0x14002913, 0x01000523,
  // [3ac0]
  0x22001422, 0x38000611, 0x2b1f2912, 0x38000d21,
  0x19082712, 0x18003f21, 0x01660520, 0x2b001434,
  0x05001913, 0x15401913, 0x25003008, 0x0f0d14ba,
  0x22001414, 0x30231c55, 0x292b14be, 0x19000807,
  // [3ad0]
  0x450d3811, 0x381f0f09, 0x084019af, 0x3f003821,
  0x66031421, 0x30251eaf, 0x0b001821, 0x01221707,
  0x21662712, 0x16210c13, 0x18002712, 0x18005113,
  0x04000b09, 0x0b0118a4, 0x18450d12, 0x18450d14,
  // [3ae0]
  0x0f173823, 0x12100107, 0x190b01a4, 0x180d4512,
  0x21146612, 0x0b001820, 0x2b1f0620, 0x01084507,
  0x1d0c4508, 0x0d014508, 0x08030607, 0x251c23ad,
  0x1d430107, 0x38450d07, 0x12451855, 0x04002b11,
  // [3af0]
  0x0d081507, 0x06190d55, 0x0b1002af, 0x10060208,
  0x012b2912, 0x3f1f0112, 0x140b5112, 0x12001510,
  0x01100bad, 0x0d223812, 0x25003020, 0x01041507,
  0x1d001902, 0x40000b09, 0x03220baf, 0x0d001410,
  // [3b00]
  0x0e232513, 0x18001f21, 0x12025112, 0x03001d12,
  0x22000308, 0x050440af, 0x0f001f07, 0x19100d12,
  0x080f0412, 0x251c0ebe, 0x106619ad, 0x660b2112,
  0x380d1709, 0x43211f6f, 0x22013fac, 0x14661612,
  // [3b10]
  0x193f0112, 0x182203af, 0x02031d12, 0x0c190422,
  0x22160112, 0x062212af, 0x293f0112, 0x663f1060,
  0x100601ad, 0x051001a4, 0x03060514, 0x012b0209,
  0x0f012212, 0x1d042260, 0x04163fad, 0x2b1422bc,
  // [3b20]
  0x170416be, 0x3f211922, 0x05192221, 0x401d1560,
  0x1d0d22ad, 0x40010f08, 0x141822a4, 0x220f0d21,
  0x19000434, 0x18010812, 0x1d000808, 0x0b101807,
  0x5c000729, 0x184305ac, 0x05080108, 0x19001f12,
  // [3b30]
  0x060319ac, 0x051d3fac, 0x30251ead, 0x0f0d3f08,
  0x21180509, 0x0d000b13, 0x05080113, 0x080d1007,
  0x10081212, 0x05010613, 0x10401d12, 0x27000612,
  0x190f22be, 0x22001920, 0x14270412, 0x180414bb,
  // [3b40]
  0x021d0307, 0x01160408, 0x0b3819ad, 0x05660321,
  0x66272112, 0x0b1019af, 0x0f184513, 0x06004011,
  0x38000d11, 0x19053821, 0x0f0127af, 0x194540a4,
  0x170b0212, 0x22292112, 0x040b03af, 0x10001613,
  // [3b50]
  0x1d170820, 0x19000b20, 0x01033807, 0x1d006609,
  0x0e251c22, 0x01082107, 0x120d0f12, 0x0b080414,
  0x0c1240be, 0x660201af, 0x011202a4, 0x19000b14,
  0x180366ad, 0x03000b07, 0x01192260, 0x251c2311,
  // [3b60]
  0x1e2325ad, 0x1c1e256f, 0x0c006609, 0x12050d12,
  0x1f0b06be, 0x180f0d14, 0x020d0f6f, 0x0c012212,
  0x1f451213, 0x1d223fad, 0x1e001c22, 0x18191d08,
  0x05120d07, 0x0c001711, 0x120b0207, 0x05013f11,
  // [3b70]
  0x08180307, 0x1708666f, 0x272912af, 0x45006621,
  0x142b1f12, 0x272921cf, 0x0b004507, 0x020619af,
  0x03001f11, 0x291f2121, 0x660b10bc, 0x2b012208,
  0x3f166613, 0x0d010b11, 0x170f0112, 0x12001f10,
  // [3b80]
  0x29215112, 0x15272909, 0x271f5112, 0x1d212912,
  0x19184507, 0x27042b6f, 0x17272112, 0x38060112,
  0x011417ac, 0x04141721, 0x22181d60, 0x01401008,
  0x22181060, 0x010638ad, 0x21000412, 0x01381512,
  // [3b90]
  0x01003814, 0x02453f07, 0x100b2211, 0x38010d09,
  0x04292722, 0x0427296f, 0x14431808, 0x01003822,
  0x0f0201a4, 0x1d000422, 0x0b061008, 0x27001020,
  0x120c1d08, 0x011d0f12, 0x17050107, 0x451715ad,
  // [3ba0]
  0x03000208, 0x01066607, 0x16001707, 0x12450d20,
  0x190b0209, 0x2b292712, 0x190117be, 0x1d104023,
  0x060b02ad, 0x06121712, 0x66143f12, 0x05003809,
  0x03060512, 0x38040509, 0x38005113, 0x011051af,
  // [3bb0]
  0x1d151022, 0x0c041807, 0x0b001607, 0x38170512,
  0x40222bac, 0x192203a4, 0x12044007, 0x12184513,
  0x0b380f08, 0x192b2709, 0x01161912, 0x22004014,
  0x17000607, 0x10060112, 0x29001520, 0x210f0612,
  // [3bc0]
  0x660d0112, 0x100817a4, 0x08010cac, 0x181245af,
  0x02400b12, 0x19221612, 0x160108ad, 0x0b0f0812,
  0x051d0107, 0x19060baf, 0x19000b21, 0x15661621,
  0x0c000d09, 0x0f021507, 0x400c12a4, 0x06190baf,
  // [3bd0]
  0x17000b13, 0x01100507, 0x062b1860, 0x06180355,
  0x101904a4, 0x401d1214, 0x19000112, 0x1f451260,
  0x14010b12, 0x02001414, 0x430117a4, 0x12451d02,
  0x10001d12, 0x12451812, 0x100b0255, 0x1d401208,
  // [3be0]
  0x0b001002, 0x29001412, 0x17002707, 0x02012b07,
  0x03660455, 0x061d0112, 0x1e003002, 0x120d0cad,
  0x29001714, 0x0403666f, 0x18081913, 0x4512186f,
  0x040d1912, 0x291219bb, 0x190440be, 0x40191d60,
  // [3bf0]
  0x18031912, 0x37233012, 0x010d0808, 0x14450c21,
  0x0d661f09, 0x0b030608, 0x120d1810, 0x16001921,
  0x0d081912, 0x0d041921, 0x1f001809, 0x43041612,
  0x080119ac, 0x06011912, 0x040206a4, 0x43180113,

  // [3c00]
  0x01063fac, 0x1e1c30bb, 0x27001921, 0x191d01be,
  0x0c0d2720, 0x04101912, 0x063f0113, 0x043801af,
  0x14661720, 0x17011d02, 0x0d0c18ad, 0x0d173814,
  0x17052ba4, 0x180f1407, 0x10121d08, 0x016604ad,
  // [3c10]
  0x0f1d45af, 0x191d4012, 0x45001205, 0x660351af,
  0x03000636, 0x4512180c, 0x38140507, 0x030b01af,
  0x021d0cad, 0x03166614, 0x0b040260, 0x022101a4,
  0x1d0301af, 0x03430112, 0x053810bc, 0x10401212,
  // [3c20]
  0x05000d21, 0x14001820, 0x060538bc, 0x17292712,
  0x0d041409, 0x38100bad, 0x0b226655, 0x16036613,
  0x14000408, 0x060204a4, 0x021218af, 0x10003821,
  0x38001022, 0x02103813, 0x1d450c55, 0x23001c22,
  // [3c30]
  0x02000c07, 0x026615af, 0x30250e02, 0x0d0119ad,
  0x100b18a4, 0x14191d14, 0x1e0e3013, 0x04036614,
  0x22000512, 0x011f2b11, 0x1d292760, 0x25231e20,
  0x22401d13, 0x10401d11, 0x1d221960, 0x0d0f29a4,
  // [3c40]
  0x0c1d1207, 0x08041608, 0x100b0109, 0x03000b21,
  0x0d082907, 0x1d402baf, 0x19183808, 0x38001d21,
  0x170c1512, 0x231e0e20, 0x011d0ca4, 0x380d1811,
  0x0f0b0207, 0x434518ac, 0x1d003820, 0x0f2b19cf,
  // [3c50]
  0x01051412, 0x38050c09, 0x3f056614, 0x060d1f09,
  0x05002b12, 0x38400daf, 0x1d002907, 0x170421bb,
  0x14001909, 0x27020b09, 0x22293812, 0x160b0222,
  0x12100111, 0x38272bad, 0x19141009, 0x16190c12,
  // [3c60]
  0x16190409, 0x0f2104ac, 0x66100612, 0x12000108,
  0x45290c09, 0x0c453fbe, 0x03001812, 0x660d0582,
  0x220c1d12, 0x02101734, 0x173f0523, 0x2b002234,
  0x0d000c09, 0x170d2bcf, 0x2b000822, 0x23302514,
  // [3c70]
  0x0f220807, 0x06270512, 0x16430511, 0x053f0f08,
  0x0f002714, 0x19452baf, 0x0c1201a4, 0x2945126f,
  0x151922be, 0x14292221, 0x401d08be, 0x19160813,
  0x010c4560, 0x1c230e6f, 0x121822af, 0x12450c55,
  // [3c80]
  0x23300ead, 0x19402207, 0x45122221, 0x080421af,
  0x081422be, 0x02381907, 0x042b06bb, 0x0f0d1807,
  0x18000213, 0x0e1c1ead, 0x060b1022, 0x1806146f,
  0x1c300e6f, 0x050d0209, 0x05040b12, 0x10002211,
  // [3c90]
  0x1d0127ac, 0x04012221, 0x430d0107, 0x1f002b14,
  0x1e1c30cf, 0x03066621, 0x0b000521, 0x12004307,
  0x45400408, 0x151d1609, 0x0f010508, 0x18163f12,
  0x14002b07, 0x0d290112, 0x1d0812af, 0x0c1701a4,
  // [3ca0]
  0x1d000312, 0x01380f07, 0x27291d14, 0x12002708,
  0x05001f09, 0x0b021412, 0x0f380107, 0x451d4034,
  0x01163f12, 0x040851af, 0x22061012, 0x01020bad,
  0x403f29a4, 0x16221509, 0x1c302321, 0x17152212,
  // [3cb0]
  0x38012baf, 0x021004a4, 0x06002214, 0x3f001613,
  0x1f0f3f20, 0x17002b11, 0x12002221, 0x45046607,
  0x1d081707, 0x121445af, 0x221f12af, 0x451d1255,
  0x0c1022ad, 0x013f1f20, 0x08191f21, 0x06002221,
  // [3cc0]
  0x38002212, 0x0d050faf, 0x17050460, 0x29193f12,
  0x05382b12, 0x19212207, 0x0f191fad, 0x01171f20,
  0x0e1e30af, 0x2b054311, 0x04181007, 0x1d002b13,
  0x0c1d2b08, 0x05080111, 0x02161507, 0x03662b08,
  // [3cd0]
  0x2b183821, 0x381d45af, 0x1c1e30bb, 0x66101413,
  0x27000109, 0x2b0f0112, 0x1c302314, 0x12452921,
  0x01001213, 0x43120112, 0x0e251e11, 0x08152b12,
  0x08010412, 0x274304af, 0x25231ea4, 0x190151af,
  // [3ce0]
  0x04001413, 0x19171daf, 0x01001411, 0x0b026609,
  0x0d1d0412, 0x1d0d0412, 0x0d000413, 0x22001011,
  0x0e1c3011, 0x18002b21, 0x01400dbc, 0x1e3023ac,
  0x27046612, 0x38002211, 0x18101522, 0x0b2b0212,
  // [3cf0]
  0x16000c07, 0x1e1c2314, 0x2b001714, 0x29000812,
  0x191245af, 0x451922af, 0x450f1207, 0x1d012907,
  0x1d403f21, 0x15001814, 0x03012bac, 0x02032b09,
  0x22032b08, 0x15161d12, 0x02662b12, 0x1c250e23,
  // [3d00]
  0x06012b55, 0x181d1520, 0x16382712, 0x0f270112,
  0x050b06a4, 0x00002203, 0x02102b12, 0x0f1001a4,
  0x04212912, 0x06010308, 0x0d170fbe, 0x0d0503a4,
  0x10022209, 0x19042ba4, 0x05066660, 0x19001f08,
  // [3d10]
  0x10002108, 0x401d2bbe, 0x05012107, 0x2b181434,
  0x401427af, 0x0f000111, 0x1d401809, 0x011d06ac,
  0x08193f21, 0x181d4060, 0x272b0108, 0x1d4018be,
  0x0f221712, 0x122b0ca4, 0x03061707, 0x190c51af,
  // [3d20]
  0x38010f12, 0x1d0f0308, 0x05221912, 0x1d0c5112,
  0x060c4013, 0x38001407, 0x05381412, 0x251c0e23,
  0x180d05af, 0x17030107, 0x0c122909, 0x06000208,
  0x1d0c0d08, 0x38272112, 0x0c4001af, 0x45005113,
  // [3d30]
  0x1d053faf, 0x162b0caf, 0x06011707, 0x22005113,
  0x18022213, 0x23002520, 0x19170dad, 0x660827af,
  0x08011912, 0x3f220322, 0x0c001721, 0x023f51af,
  0x030619ac, 0x22001820, 0x020b51ad, 0x0d660309,
  // [3d40]
  0x01082221, 0x0d0801a4, 0x43191507, 0x29272212,
  0x0f011821, 0x04061907, 0x1e230e21, 0x221901af,
  0x0f053faf, 0x1f001412, 0x152216ad, 0x050366ad,
  0x0e253008, 0x45001f22, 0x45121807, 0x1c302523,
  // [3d50]
  0x14100409, 0x291451af, 0x10081422, 0x120c1720,
  0x120c176f, 0x01081902, 0x120c1712, 0x22140c6f,
  0x12170c14, 0x2b660308, 0x031506af, 0x1d1012af,
  0x1217456f, 0x2b030220, 0x0b010212, 0x180b1dbc,
  // [3d60]
  0x0d030512, 0x0f010807, 0x012227a4, 0x10020621,
  0x213f51a4, 0x02000811, 0x12451712, 0x01120508,
  0x451240bb, 0x0c041713, 0x2b220608, 0x0c171212,
  0x12041760, 0x06660d21, 0x17081214, 0x2b062112,
  // [3d70]
  0x10190414, 0x0f061655, 0x17000613, 0x18451213,
  0x230e2502, 0x43000d08, 0x121743a4, 0x12660508,
  0x38001207, 0x12006608, 0x0b002911, 0x06001005,
  0x16290412, 0x0b001207, 0x14021008, 0x2b1401af,
  // [3d80]
  0x0b001011, 0x05660320, 0x664301ad, 0x06400112,
  0x12001621, 0x0b021812, 0x0c000111, 0x01100660,
  0x010238bb, 0x170d1008, 0x04002911, 0x10660355,
  0x2b001808, 0x1f0401af, 0x162b1f12, 0x14000b12,
  // [3d90]
  0x18000312, 0x1f000514, 0x02036607, 0x1e0e1caf,
  0x0b002b08, 0x010c2bbe, 0x0d003812, 0x19161507,
  0x38010512, 0x01000c21, 0x15041f13, 0x0d043f34,
  0x08453fa4, 0x3f450c22, 0x05060313, 0x01083fbe,
  // [3da0]
  0x230e2509, 0x04003f22, 0x100806a4, 0x05123807,
  0x38083f09, 0x12660c60, 0x10040c12, 0x45083faf,
  0x38450d09, 0x0f001022, 0x0c0f0621, 0x0f000c23,
  0x1c002520, 0x3f000c21, 0x043f4511, 0x080c0621,
  // [3db0]
  0x04274512, 0x080f0621, 0x0f050621, 0x061751af,
  0x0f000621, 0x060b1907, 0x02660c09, 0x23301ca4,
  0x14011612, 0x171614af, 0x19000109, 0x43290112,
  0x14001622, 0x05192b60, 0x45164022, 0x170b0108,
  // [3dc0]
  0x04181960, 0x180d0f08, 0x2b001708, 0x10140507,
  0x2b010608, 0x66002b14, 0x25233007, 0x1d454013,
  0x10041907, 0x051914a4, 0x0c124507, 0x22011907,
  0x01066609, 0x15000409, 0x0d0f1d02, 0x45003f20,
  // [3dd0]
  0x43170812, 0x06180112, 0x10040b14, 0x17083f09,
  0x19380f09, 0x10380209, 0x0f050d09, 0x01082709,
  0x400c4521, 0x662b3faf, 0x044017a4, 0x4022186f,
  0x08020d12, 0x041501af, 0x221018a4, 0x04001f21,
  // [3de0]
  0x212704af, 0x19180421, 0x16100b08, 0x05003f13,
  0x66030412, 0x1e0e1c07, 0x122721ad, 0x29270221,
  0x40181d60, 0x01292b55, 0x06052b08, 0x38002202,
  0x45121610, 0x19000c07, 0x15001d09, 0x06001608,
  // [3df0]
  0x22163f21, 0x0c2721af, 0x21005113, 0x06000d13,
  0x16271d12, 0x1f003f34, 0x01160f12, 0x0f3f1f22,
  0x18060308, 0x1914046f, 0x40190c14, 0x012b1fbc,
  0x020b0307, 0x18041d12, 0x010d3802, 0x0c001914,
  // [3e00]
  0x056601a4, 0x011d0cbc, 0x661921af, 0x03060121,
  0x0d0f1907, 0x29001214, 0x291406af, 0x04173812,
  0x12001407, 0x18400caf, 0x220c406f, 0x190c146f,
  0x27000312, 0x25230e02, 0x19291a11, 0x04660313,
  // [3e10]
  0x66032913, 0x16061508, 0x06036609, 0x120c1007,
  0x100c1612, 0x0c002121, 0x22170812, 0x041045ac,
  0x02270b09, 0x06032207, 0x022b0655, 0x0c002114,
  0x0c002b02, 0x182106a4, 0x02660611, 0x04001d20,
  // [3e20]
  0x220d19a4, 0x27010d12, 0x081405ad, 0x38011707,
  0x0d1f1609, 0x060b4002, 0x1d0c0f07, 0x0f1d1607,
  0x25231e08, 0x380f0814, 0x120c51af, 0x04194009,
  0x140451af, 0x450c1daf, 0x03180660, 0x0c1d15af,
  // [3e30]
  0x02100112, 0x1866036f, 0x10001213, 0x292703af,
  0x03001821, 0x15210112, 0x401d4514, 0x14120d12,
  0x1d0410a4, 0x0d1245a4, 0x19660b12, 0x1d061507,
  0x04002709, 0x03451255, 0x430d0507, 0x2b001f07,
  // [3e40]
  0x2b0127af, 0x141d12af, 0x180f0d13, 0x10192707,
  0x12401d14, 0x180151af, 0x010f2bbc, 0x0b1008af,
  0x27291821, 0x10002907, 0x01052107, 0x17052908,
  0x03660209, 0x17221f12, 0x03061421, 0x03292712,
  // [3e50]
  0x18003f13, 0x21001214, 0x14000c08, 0x06030113,
  0x1d010508, 0x10020b09, 0x100b3faf, 0x21030612,
  0x08380109, 0x01061f07, 0x01031507, 0x0b272913,
  0x011d1612, 0x0e301ead, 0x1d290baf, 0x080f1721,
  // [3e60]
  0x1d001202, 0x230e3002, 0x100b0112, 0x2b161fbe,
  0x2b001622, 0x2b031721, 0x05001809, 0x08050dbc,
  0x14401d6f, 0x01451212, 0x16001d21, 0x0c1d4021,
  0x38041da4, 0x0d051611, 0x01042b11, 0x02160612,
  // [3e70]
  0x29124560, 0x01451222, 0x38060322, 0x121d4013,
  0x14004013, 0x22004021, 0x01124513, 0x01451213,
  0x15082212, 0x16192109, 0x25302360, 0x450c4021,
  0x12191613, 0x0f0114a4, 0x080c6608, 0x30230e6f,
  // [3e80]
  0x38002207, 0x38011612, 0x27222912, 0x0d002111,
  0x22191409, 0x011d1202, 0x100f0b12, 0x450c1d08,
  0x19271709, 0x38050f60, 0x22160dad, 0x0d0f0507,
  0x22194009, 0x03100b12, 0x19160f07, 0x06050f6f,
  // [3e90]
  0x05190109, 0x03661808, 0x101718bb, 0x15000f13,
  0x01060407, 0x12050108, 0x0c022209, 0x400c1dbc,
  0x0b021921, 0x0c190421, 0x0d124509, 0x45061808,
  0x5c000735, 0x050b0112, 0x02001712, 0x032701af,
  // [3ea0]
  0x03026612, 0x15141812, 0x181d51a4, 0x04401d82,
  0x0f041560, 0x18001421, 0x19401822, 0x18001423,
  0x12151908, 0x1d100f09, 0x18043fad, 0x3806226f,
  0x151840af, 0x14185112, 0x15271809, 0x19000c22,
  // [3eb0]
  0x381051af, 0x143819af, 0x190f0d6f, 0x291801a4,
  0x0129276f, 0x10193812, 0x0d210107, 0x08190f09,
  0x380f51af, 0x22193812, 0x402b1daf, 0x1d381812,
  0x050f2707, 0x03061913, 0x1219386f, 0x45381009,
  // [3ec0]
  0x0c1210af, 0x051d0f07, 0x21002208, 0x231e2514,
  0x041d2207, 0x15000408, 0x140d1208, 0x041d2708,
  0x10120c07, 0x151666a4, 0x1c232523, 0x190b0109,
  0x05170612, 0x08013812, 0x66061860, 0x03660d12,
  // [3ed0]
  0x170f18ad, 0x05001f22, 0x16003812, 0x230e1e14,
  0x14000623, 0x3f001f21, 0x2b272912, 0x03292b12,
  0x66402912, 0x161704be, 0x29141922, 0x1f083860,
  0x012b43a4, 0x050f0d08, 0x270b2909, 0x0e301c02,
  // [3ee0]
  0x1e0e2360, 0x120c2222, 0x060b2107, 0x0b1004a4,
  0x2b001602, 0x050f3813, 0x060216ac, 0x292721be,
  0x27382209, 0x1f292760, 0x2b430112, 0x16030cad,
  0x0c011602, 0x0d010807, 0x1d000320, 0x40221d60,
  // [3ef0]
  0x101803a4, 0x0d012b08, 0x40151da4, 0x1d000308,
  0x1d451209, 0x15004008, 0x38172909, 0x1c003709,
  0x17081912, 0x14041921, 0x050f4308, 0x03001d23,
  0x401245ac, 0x0b0510ad, 0x0b101414, 0x43453809,
  // [3f00]
  0x22004512, 0x0b022207, 0x38140c09, 0x291245af,
  0x1900041f, 0x1d0b0214, 0x17272913, 0x19221413,
  0x143f2114, 0x12454012, 0x66222b21, 0x2b000823,
  0x15001635, 0x050c01af, 0x45190c12, 0x020b4008,
  // [3f10]
  0x15002208, 0x12272908, 0x1d194023, 0x30002508,
  0x2b002213, 0x011f12af, 0x081540af, 0x30002514,
  0x23301ead, 0x181d1209, 0x19451222, 0x3f030108,
  0x40190521, 0x17080c07, 0x01162721, 0x010845a4,
  // [3f20]
  0x03004512, 0x03011809, 0x0f012912, 0x16036622,
  0x17270d09, 0x381d01a4, 0x0d0f0509, 0x0f044002,
  0x2229276f, 0x27402912, 0x40000312, 0x12170b08,
  0x01191a12, 0x08380311, 0x0d001711, 0x17000d13,
  // [3f30]
  0x0c1d45ad, 0x19100407, 0x29271209, 0x1c0e3060,
  0x45002713, 0x0b000f08, 0x06020308, 0x10140202,
  0x271d2221, 0x0d020612, 0x191014be, 0x022b1021,
  0x061505bb, 0x1d211060, 0x026638bc, 0x14040baf,
  // [3f40]
  0x0c451d07, 0x181d2221, 0x19030412, 0x06100212,
  0x29153f14, 0x05063813, 0x022b0112, 0x05000621,
  0x15190412, 0x660603be, 0x03220108, 0x19290109,
  0x0b191412, 0x060b1912, 0x27020512, 0x19050608,
  // [3f50]
  0x22011d09, 0x01001208, 0x22062955, 0x21000c09,
  0x0b1951af, 0x03012907, 0x01170512, 0x0b290609,
  0x08190609, 0x190b14bc, 0x2b051f11, 0x181517bc,
  0x19661708, 0x0d0b1807, 0x381718ad, 0x0f0117a4,
  // [3f60]
  0x16000621, 0x45661f55, 0x0f1d0d09, 0x15171821,
  0x0e302507, 0x0b271012, 0x0c401d07, 0x01380655,
  0x140b10be, 0x66000c13, 0x1d451222, 0x0b001035,
  0x08000d12, 0x1f001013, 0x02001d08, 0x02001822,
  // [3f70]
  0x0b430612, 0x02030660, 0x120c01af, 0x151206ac,
  0x042b1212, 0x120c40af, 0x120145af, 0x45121855,
  0x66031009, 0x220106ad, 0x170f0d08, 0x1d454007,
  0x150366ad, 0x01211955, 0x1d3f2113, 0x010f1f13,
  // [3f80]
  0x1e250e11, 0x0c003807, 0x1d150109, 0x1f001913,
  0x0f2b19ac, 0x38001714, 0x0d170faf, 0x01041607,
  0x160c6611, 0x03000d09, 0x18156608, 0x043f1720,
  0x0f173f20, 0x0d4301a4, 0x170119ad, 0x124517be,
  // [3f90]
  0x01004511, 0x030119be, 0x66000311, 0x3f001733,
  0x3f170f21, 0x170d0108, 0x04031921, 0x14000214,
  0x6603196f, 0x230e1c21, 0x66031922, 0x38290112,
  0x0d1627a4, 0x060b6622, 0x0c0840ad, 0x1d181608,
  // [3fa0]
  0x380f0855, 0x19272921, 0x45001814, 0x431d19ad,
  0x19152712, 0x12291612, 0x270d216f, 0x21000f20,
  0x66060c21, 0x1f38056f, 0x0d000635, 0x29001913,
  0x401d2712, 0x19002b22, 0x182b1908, 0x06150cbc,
  // [3fb0]
  0x0d221912, 0x66292708, 0x38290534, 0x451221a4,
  0x66401d20, 0x036601cf, 0x0c040fbb, 0x2b170512,
  0x16101521, 0x401d19a4, 0x06172221, 0x03181555,
  0x222b1412, 0x051201a4, 0x060105ad, 0x0c452b14,
  // [3fc0]
  0x1e252360, 0x450d0f13, 0x19012960, 0x0c451612,
  0x100414af, 0x1d160fbc, 0x45000d13, 0x431401a4,
  0x38000812, 0x0d220112, 0x01160c12, 0x16000d12,
  0x0d0f4512, 0x1f0d4509, 0x250e30ad, 0x141666a4,
  // [3fd0]
  0x29160dbc, 0x1c300ebb, 0x19010509, 0x451214af,
  0x2b000413, 0x190b1807, 0x1f663f09, 0x10061907,
  0x0d0117a4, 0x0f161fac, 0x12180608, 0x29051812,
  0x010f3813, 0x190f0821, 0x0f180112, 0x0b0f0112,
  // [3fe0]
  0x1e1c3009, 0x14124560, 0x03102b09, 0x22106613,
  0x381d2b07, 0x3f001414, 0x1d2214ac, 0x010b0608,
  0x27080112, 0x04001814, 0x220106af, 0x2b0801af,
  0x2b066612, 0x14002222, 0x0627296f, 0x16220260,
  // [3ff0]
  0x0d0f22ad, 0x06192b07, 0x0b000620, 0x381d08af,
  0x43011f08, 0x18000413, 0x030f2911, 0x0b221612,
  0x22001511, 0x27293fbe, 0x010d0609, 0x2b660311,
  0x0c222121, 0x452b1212, 0x3f222121, 0x21223f20,

  // [4000]
  0x38000d20, 0x05010d12, 0x02000307, 0x38170d23,
  0x060305af, 0x01660513, 0x14220411, 0x03052baf,
  0x0b1005ac, 0x14192221, 0x17080121, 0x15192bbb,
  0x14001913, 0x14000821, 0x19272920, 0x12041608,
  // [4010]
  0x38001613, 0x27151912, 0x22271914, 0x16002b13,
  0x1e1c0e21, 0x12081d13, 0x22190413, 0x14160808,
  0x19000812, 0x38002907, 0x0d041607, 0x0d000421,
  0x0d172708, 0x04190812, 0x0d1401a4, 0x0f032b07,
  // [4020]
  0x01003f20, 0x451d0c08, 0x1d0418a4, 0x011d4008,
  0x0c010612, 0x05272914, 0x15451212, 0x0c001823,
  0x272919bb, 0x081d40af, 0x06010dad, 0x171d2955,
  0x01000d12, 0x1e0e23be, 0x381d0f09, 0x2b4301a4,
  // [4030]
  0x0d1d08af, 0x030d0112, 0x0d010c09, 0x0c004521,
  0x18000b12, 0x40451208, 0x030143a4, 0x05225112,
  0x151d1f12, 0x143f51af, 0x27290f14, 0x40000c09,
  0x45271f12, 0x15401d60, 0x0f401913, 0x14102712,
  // [4040]
  0x0b3f0209, 0x0f0306ad, 0x041d0c13, 0x1d193f12,
  0x0d2b21ac, 0x03386609, 0x03010212, 0x02173812,
  0x660601a4, 0x29002121, 0x060401af, 0x453f40af,
  0x210f16bc, 0x66140612, 0x45030c07, 0x451d4007,
  // [4050]
  0x01190807, 0x02450107, 0x06011012, 0x036601ad,
  0x0b060112, 0x05124512, 0x1d401214, 0x02100b21,
  0x0e251c34, 0x12144509, 0x25231eaf, 0x2b000b11,
  0x03050108, 0x0b021023, 0x190301a4, 0x66000221,
  // [4060]
  0x0f001607, 0x05000307, 0x30001c14, 0x0f171fbc,
  0x06051407, 0x66010312, 0x1f380313, 0x052b1f12,
  0x251e0e22, 0x3f29276f, 0x16180112, 0x29001f13,
  0x0c166607, 0x0c2729a4, 0x05012909, 0x663f2721,
  // [4070]
  0x2b401712, 0x1d450c60, 0x22293fad, 0x1f000c09,
  0x401d15be, 0x29273fbb, 0x022714af, 0x221f0413,
  0x161d1521, 0x023f01af, 0x040838cf, 0x141510bc,
  0x041917be, 0x22290baf, 0x04140c11, 0x143843ad,
  // [4080]
  0x12001f33, 0x12160412, 0x400c2912, 0x40141021,
  0x22002b14, 0x252330ad, 0x1e230eac, 0x0d663f09,
  0x29270c14, 0x380f1fbe, 0x042215a4, 0x66060111,
  0x12004321, 0x45431faf, 0x020301a4, 0x2b160812,
  // [4090]
  0x080c01ad, 0x050f01ac, 0x100b18af, 0x0c0106a4,
  0x10141212, 0x17181612, 0x0e002523, 0x27291414,
  0x16002913, 0x29151609, 0x43001609, 0x18152912,
  0x18151622, 0x45120613, 0x16292733, 0x17002222,
  // [40a0]
  0x29151620, 0x010d0f09, 0x06192107, 0x151816af,
  0x17002209, 0x08052b07, 0x06270108, 0x29002220,
  0x29161809, 0x140121af, 0x030d1d07, 0x1e250ebb,
  0x45150cbe, 0x16001d02, 0x12030112, 0x1d001511,
  // [40b0]
  0x2b010509, 0x150f0609, 0x16061512, 0x100c1607,
  0x1e301ca4, 0x05001f14, 0x19000b11, 0x12054522,
  0x06150c12, 0x0b0610bc, 0x18124523, 0x0f272b12,
  0x296622af, 0x250e2321, 0x0f080111, 0x0e232514,
  // [40c0]
  0x29002211, 0x0c1d1209, 0x1d225112, 0x08181608,
  0x380f1012, 0x0d380855, 0x3f000421, 0x12381707,
  0x1c0e3021, 0x1e1c30af, 0x45124012, 0x05270613,
  0x022b2707, 0x0d181407, 0x3f010413, 0x10000222,
  // [40d0]
  0x02043f21, 0x080f3f12, 0x011f2baf, 0x0d142221,
  0x403f1dbc, 0x1d083f12, 0x19003f23, 0x041d1412,
  0x0c4522ad, 0x450f08ac, 0x14211f21, 0x080f1713,
  0x0f272922, 0x45271d12, 0x211615af, 0x18000820,
  // [40e0]
  0x081d0c12, 0x66191412, 0x14002b20, 0x0b060312,
  0x14002122, 0x0e2523ad, 0x22401707, 0x14002120,
  0x041d2112, 0x080f3faf, 0x0c1d4007, 0x101d0107,
  0x08173f13, 0x221d2112, 0x0b0419a4, 0x40451222,
  // [40f0]
  0x38002b11, 0x06002711, 0x080f1f60, 0x45141212,
  0x27402b12, 0x06011d08, 0x45120e07, 0x011d4512,
  0x450f0d08, 0x0d3808bc, 0x380d0509, 0x15291fbc,
  0x05002112, 0x22210112, 0x05380f12, 0x192b1f12,
  // [4100]
  0x43002122, 0x080c1607, 0x08012955, 0x45000d21,
  0x190b0409, 0x050b1609, 0x0d1904a4, 0x05000f21,
  0x40000f14, 0x01002121, 0x0b041fa4, 0x01222108,
  0x1f191613, 0x020b40ad, 0x27011212, 0x01270caf,
  // [4110]
  0x45013fac, 0x45121407, 0x40272b12, 0x0f0d0ca4,
  0x052b3808, 0x08041807, 0x27184020, 0x010617ad,
  0x05380812, 0x0d2118af, 0x29001812, 0x04081811,
  0x1c301ebc, 0x430d18ac, 0x06292709, 0x29270faf,
  // [4120]
  0x01006620, 0x0f192212, 0x030108af, 0x40124511,
  0x060b0255, 0x06004308, 0x060f0107, 0x10060311,
  0x0c270609, 0x66060309, 0x23250e08, 0x06100421,
  0x0d172208, 0x1d1540ad, 0x45001f07, 0x12010308,
  // [4130]
  0x0b0201bb, 0x01000212, 0x1d000313, 0x38003f13,
  0x1d0508a4, 0x1d124021, 0x10012707, 0x45081209,
  0x083829af, 0x17000c12, 0x123845a4, 0x0c401255,
  0x17661512, 0x380516cf, 0x38000536, 0x38060582,
  // [4140]
  0x27182111, 0x050845af, 0x0c1d08bc, 0x38406614,
  0x220205bc, 0x2219046f, 0x0c180d08, 0x19290112,
  0x0f3840af, 0x27212212, 0x036602af, 0x03660b09,
  0x38002b21, 0x38172b21, 0x050122a4, 0x0c0801ad,
  // [4150]
  0x08020b21, 0x0b002221, 0x04002220, 0x05080fbe,
  0x45401912, 0x012b1f21, 0x04161909, 0x1f000122,
  0x17012b07, 0x062b0b11, 0x03010609, 0x08012b55,
  0x16221914, 0x18000411, 0x38220b12, 0x1d221711,
  // [4160]
  0x150f3fac, 0x17380109, 0x0f1d1807, 0x43220d09,
  0x03082b12, 0x010b06ad, 0x0b0105a4, 0x2b000813,
  0x060d0507, 0x08011702, 0x181604af, 0x06172207,
  0x041618a4, 0x45001513, 0x22451d09, 0x0c2240bc,
  // [4170]
  0x1d0f0d09, 0x1f3f0caf, 0x1e250e20, 0x05020112,
  0x031001a4, 0x0c404555, 0x0f013802, 0x03021412,
  0x10050607, 0x22400f21, 0x450401ac, 0x380845af,
  0x0f0d1fbe, 0x02161012, 0x060210a4, 0x21004011,
  // [4180]
  0x011d1607, 0x291701af, 0x030c0107, 0x0e253021,
  0x161421ac, 0x05010302, 0x05402708, 0x2b003f11,
  0x153801af, 0x16181d13, 0x66101412, 0x45001d02,
  0x2b0c40af, 0x401d1907, 0x01270d08, 0x061d40a4,
  // [4190]
  0x011d2907, 0x0c401d08, 0x2b000d23, 0x124518a4,
  0x146604ad, 0x0c122209, 0x150f1d12, 0x29031909,
  0x301c0e11, 0x04270b12, 0x06030212, 0x12450308,
  0x06080411, 0x66001909, 0x10061609, 0x19041013,
  // [41a0]
  0x03192107, 0x18040821, 0x0c000102, 0x0c000b02,
  0x0c4003ad, 0x02001912, 0x106619af, 0x14000414,
  0x06180409, 0x00001203, 0x2b0618a4, 0x100b27a4,
  0x0c401daf, 0x0f050812, 0x1d020b07, 0x0f011607,
  // [41b0]
  0x1d170f07, 0x43040109, 0x10002221, 0x04001f08,
  0x0f1d0d07, 0x290401a4, 0x14080411, 0x06100c12,
  0x192204ac, 0x190401af, 0x041917a4, 0x01063faf,
  0x084517ac, 0x0c2b01ad, 0x43010807, 0x04081d09,
  // [41c0]
  0x45120c02, 0x0b222107, 0x0c380d09, 0x050b666f,
  0x14000b22, 0x401d1021, 0x66031022, 0x012219af,
  0x100618a4, 0x140601af, 0x292719af, 0x04100607,
  0x40291412, 0x21661660, 0x190b1012, 0x0b210111,
  // [41d0]
  0x011d3f11, 0x00002215, 0x22000108, 0x1d402914,
  0x05000235, 0x0f001707, 0x1d000507, 0x05121da4,
  0x40182908, 0x19000521, 0x1d0545af, 0x050801ac,
  0x152b1212, 0x05150d09, 0x45221212, 0x050117af,
  // [41e0]
  0x1d011809, 0x40041212, 0x0c273f12, 0x19124509,
  0x291f27af, 0x01003821, 0x16272955, 0x03660b20,
  0x40124512, 0x1f2729af, 0x10041955, 0x22401d60,
  0x081940a4, 0x16001536, 0x0f1745af, 0x08012ba4,
  // [41f0]
  0x3f010660, 0x03051f08, 0x231c25a4, 0x38081709,
  0x0d401d07, 0x0b010812, 0x1d0d0111, 0x0b0f14af,
  0x1c1e2307, 0x1d164511, 0x15160412, 0x17001f08,
  0x15001909, 0x04292709, 0x0f2722af, 0x382201af,
  // [4200]
  0x10190ba4, 0x0b010260, 0x02190c08, 0x0c0327a4,
  0x19036607, 0x17145112, 0x140b1fad, 0x1d0405ad,
  0x150466ac, 0x22450c02, 0x0c0118a4, 0x03140213,
  0x0c021921, 0x29222112, 0x192b04af, 0x19101514,
  // [4210]
  0x01193fac, 0x15001202, 0x010c05a4, 0x16212712,
  0x101906af, 0x2721186f, 0x19000111, 0x230e2508,
  0x19000121, 0x052b08af, 0x100301a4, 0x45000111,
  0x160c4512, 0x29000614, 0x0c000309, 0x0c066609,
  // [4220]
  0x19000120, 0x292b2712, 0x02100ba4, 0x45401223,
  0x25233014, 0x0b080421, 0x2b381fad, 0x040b18ac,
  0x02040bbc, 0x06021809, 0x06080b12, 0x38213f08,
  0x43181f14, 0x1c231e20, 0x04000b14, 0x010b0c12,
  // [4230]
  0x0f061707, 0x04030b08, 0x18292712, 0x27183f12,
  0x14001908, 0x0f0d1909, 0x1c302322, 0x04290112,
  0x0f0d18ac, 0x401d1f12, 0x18002b22, 0x16401708,
  0x382b2909, 0x0f001820, 0x12010c08, 0x180501af,
  // [4240]
  0x01170812, 0x0d0f1814, 0x22180312, 0x1d000b22,
  0x05430112, 0x060412ad, 0x121d0112, 0x38010513,
  0x18041912, 0x030b02a4, 0x10381612, 0x051d01af,
  0x170201a4, 0x08000522, 0x1d0c22ad, 0x06001714,
  // [4250]
  0x010804bc, 0x380817a4, 0x06290c11, 0x12273f21,
  0x0c214008, 0x0c062207, 0x1d192712, 0x37004e33,
  0x300e1e55, 0x064512a4, 0x05291912, 0x03006633,
  0x273f2911, 0x290f22a4, 0x382b0309, 0x19001813,
  // [4260]
  0x23253008, 0x16270109, 0x1d1712af, 0x66062b12,
  0x233025be, 0x0c000507, 0x0e252308, 0x3f050121,
  0x22402907, 0x29012712, 0x05010da4, 0x052101af,
  0x17052202, 0x25302309, 0x03430108, 0x17660d12,
  // [4270]
  0x080c0212, 0x05121d14, 0x05001835, 0x0f0106bb,
  0x05001820, 0x380b0107, 0x030219a4, 0x1e0e30af,
  0x010521ac, 0x01030b07, 0x03000f08, 0x0d0f6609,
  0x40121d14, 0x0f181912, 0x1c250e60, 0x23251ebb,
  // [4280]
  0x140d3823, 0x19100412, 0x1d400d12, 0x0c6645af,
  0x01166608, 0x45660c21, 0x06010812, 0x030c66af,
  0x1c2523bb, 0x660f0caf, 0x45120512, 0x12454055,
  0x381d4512, 0x16150421, 0x660c0613, 0x15036621,
  // [4290]
  0x14005108, 0x45401d11, 0x15066612, 0x030466bb,
  0x0f170834, 0x231e1cbc, 0x180305ad, 0x14100b12,
  0x45401d13, 0x06041912, 0x1f3f0121, 0x060108ac,
  0x40150c12, 0x40000512, 0x0f292709, 0x0c1215ac,
  // [42a0]
  0x22191612, 0x02001d11, 0x0f190d11, 0x151016bc,
  0x3f2927be, 0x291718be, 0x21006633, 0x101d0d12,
  0x0f160112, 0x19040560, 0x291d2108, 0x0b1004ad,
  0x1d1f0608, 0x141601af, 0x270f1011, 0x27001621,
  // [42b0]
  0x220c3f23, 0x1d140407, 0x05191808, 0x0e1c2320,
  0x384566a4, 0x01171f13, 0x14181908, 0x17001008,
  0x18051412, 0x251c3014, 0x02160112, 0x14000508,
  0x02006608, 0x0d184512, 0x0b2b6621, 0x080d17a4,
  // [42c0]
  0x21663f12, 0x380d4508, 0x38120d12, 0x17002123,
  0x0b0c1907, 0x17270112, 0x0c060307, 0x27101909,
  0x031d18ad, 0x062922af, 0x186621bb, 0x100c5112,
  0x06141012, 0x08050413, 0x21153f13, 0x0f181f12,
  // [42d0]
  0x66193f12, 0x011406a4, 0x38010d08, 0x27213f60,
  0x38080d12, 0x150640a4, 0x03276609, 0x381027af,
  0x1d121607, 0x150204af, 0x251c30ac, 0x0d0f4012,
  0x1d0c17bc, 0x18000808, 0x161921ad, 0x0e301ebb,
  // [42e0]
  0x190d0112, 0x17003812, 0x40000d14, 0x01380dbc,
  0x38400f07, 0x380d1755, 0x27160c12, 0x17000302,
  0x45000408, 0x041006ad, 0x120d0513, 0x380d0408,
  0x301c1ead, 0x040d1f12, 0x22080fa4, 0x10000102,
  // [42f0]
  0x210f0d6f, 0x03401d55, 0x22001720, 0x2b040c20,
  0x19401d08, 0x1e1c3007, 0x06001d07, 0x16210112,
  0x10000813, 0x10210b12, 0x10021621, 0x05271807,
  0x382b6608, 0x04124520, 0x3f0b1621, 0x0f010d08,
  // [4300]
  0x061d6609, 0x400c1613, 0x160b02af, 0x05380109,
  0x2b000221, 0x10081621, 0x16061912, 0x06291daf,
  0x0b150112, 0x450b1212, 0x2b451208, 0x04020107,
  0x191604a4, 0x0c012b08, 0x0c451507, 0x292716bb,
  // [4310]
  0x100b0409, 0x17001908, 0x05011fad, 0x1f380faf,
  0x662927af, 0x04160209, 0x0f210509, 0x19020b60,
  0x040c0112, 0x0b222708, 0x120c3f12, 0x29004012,
  0x08050d20, 0x382b2260, 0x050614a4, 0x08003808,
  // [4320]
  0x04160612, 0x38120c07, 0x050d3802, 0x251c30af,
  0x451218af, 0x30001c02, 0x661901af, 0x17001607,
  0x29432209, 0x04121d07, 0x010522a4, 0x081f05a4,
  0x270d1d12, 0x17060320, 0x2b381fa4, 0x38020409,
  // [4330]
  0x08000f11, 0x451612ac, 0x080f3822, 0x0d0c01af,
  0x08060faf, 0x012b06ad, 0x1f3f0521, 0x1f220112,
  0x040121a4, 0x66221408, 0x38081613, 0x0b0601be,
  0x04192107, 0x230e25ac, 0x272918be, 0x100b21a4,
  // [4340]
  0x66083f21, 0x17152211, 0x05060160, 0x150c4512,
  0x450c1807, 0x01001f09, 0x66102912, 0x400812af,
  0x080f51af, 0x45121613, 0x080d0fa4, 0x010f2707,
  0x27160112, 0x160f27a4, 0x040f0812, 0x03000120,
  // [4350]
  0x0d161911, 0x66002233, 0x10221460, 0x1f000d22,
  0x0b001d07, 0x450c1208, 0x120c0f08, 0x271f2bbb,
  0x03060212, 0x12060321, 0x1d001913, 0x22003802,
  0x18000509, 0x08060511, 0x45120513, 0x140b06ad,
  // [4360]
  0x231e3055, 0x0d001512, 0x030566a4, 0x06030512,
  0x27152112, 0x29000411, 0x231e3712, 0x06180b11,
  0x1d062112, 0x0f6617a4, 0x1e300e14, 0x012b0308,
  0x401d0c07, 0x0f3f0834, 0x1f001409, 0x19401820,
  // [4370]
  0x38001620, 0x14001922, 0x010d2bad, 0x10065112,
  0x18080112, 0x22211512, 0x43030107, 0x2b010512,
  0x06004507, 0x3f001521, 0x27151612, 0x1d030b07,
  0x04160bad, 0x02211412, 0x2b270112, 0x2b210112,
  // [4380]
  0x193f2712, 0x0b191421, 0x19061412, 0x380c0fa4,
  0x271f22be, 0x0c006621, 0x081405af, 0x0f0c06ac,
  0x22000614, 0x01191412, 0x231c3014, 0x121d4055,
  0x1000021f, 0x450d0f08, 0x06101912, 0x41002409,
  // [4390]
  0x060d0112, 0x12080607, 0x1f001733, 0x01051fbc,
  0x27013fad, 0x19001030, 0x66160fad, 0x3f0d0f21,
  0x222701af, 0x273f29be, 0x080d1aaf, 0x14000622,
  0x19160412, 0x401d16be, 0x27291621, 0x38001914,
  // [43a0]
  0x053f0b12, 0x0b451213, 0x30231c60, 0x01030c07,
  0x031d19ad, 0x191602af, 0x100119ad, 0x01050302,
  0x210b0260, 0x40661f08, 0x18000609, 0x660419af,
  0x66001922, 0x16272922, 0x06010407, 0x06002108,
  // [43b0]
  0x5c000734, 0x1000040c, 0x0c021907, 0x29102709,
  0x04036621, 0x010c6607, 0x06660320, 0x14400155,
  0x27291521, 0x08161713, 0x06032ba4, 0x27222120,
  0x03380612, 0x03053811, 0x19001208, 0x22003f21,
  // [43c0]
  0x01223f09, 0x013f2255, 0x01221809, 0x06100402,
  0x05380111, 0x29212221, 0x2b013860, 0x04000108,
  0x192b0111, 0x06001810, 0x18013811, 0x453817ac,
  0x030f02ad, 0x21000213, 0x030b6607, 0x02660b12,
  // [43d0]
  0x082b0111, 0x2b0322a4, 0x14000220, 0x0b2219a4,
  0x16381909, 0x12170fa4, 0x45122b12, 0x0d1002ac,
  0x080f4508, 0x21060412, 0x05001908, 0x19292755,
  0x0f010507, 0x02002108, 0x082b0107, 0x0d000613,
  // [43e0]
  0x10010ca4, 0x401d0508, 0x45272913, 0x043f0112,
  0x301c2313, 0x04050821, 0x0b001822, 0x080b0421,
  0x106604a4, 0x05040bbc, 0x17101d12, 0x10000821,
  0x012706af, 0x031801af, 0x0b1451af, 0x0e251c02,
  // [43f0]
  0x04180813, 0x081804cf, 0x0b001813, 0x0d0501ac,
  0x01050412, 0x01190bbe, 0x191029af, 0x0c0129af,
  0x172b6608, 0x401d12ac, 0x18080212, 0x0d0f2708,
  0x1d002213, 0x15002207, 0x290d6608, 0x0e1e2510,

  // [4400]
  0x10050107, 0x660b0560, 0x0c181dad, 0x0b022212,
  0x02002111, 0x38100b08, 0x08192bad, 0x45000407,
  0x0b040521, 0x45120c08, 0x0b1014bb, 0x192202ad,
  0x19011055, 0x031d4055, 0x27290621, 0x03040108,
  // [4410]
  0x06004008, 0x0e301eaf, 0x16003f21, 0x190c04a4,
  0x3f1d4060, 0x40002112, 0x12014509, 0x21000120,
  0x43120107, 0x01171f12, 0x034016a4, 0x030401ad,
  0x0f003f22, 0x041203a4, 0x080d1955, 0x0f0427af,
  // [4420]
  0x0f1f2b12, 0x05002908, 0x19000d12, 0x401d2b08,
  0x25301e14, 0x27063f12, 0x0c000f09, 0x150b1612,
  0x04031914, 0x66030421, 0x19060413, 0x0b000820,
  0x18003814, 0x022201a4, 0x04002111, 0x080d0507,
  // [4430]
  0x010b1909, 0x27290612, 0x0f1f3809, 0x0d001f11,
  0x032b06a4, 0x08142b07, 0x0c400302, 0x40001814,
  0x12401d20, 0x18000c20, 0x066603af, 0x05010c08,
  0x660301a4, 0x1f041509, 0x40034512, 0x29024012,
  // [4440]
  0x660638af, 0x29221912, 0x020b0409, 0x66060112,
  0x16000409, 0x0f082107, 0x010f08ac, 0x2b060409,
  0x06036623, 0x140b0621, 0x0d0516af, 0x15002202,
  0x1d1651af, 0x0d000422, 0x1c002534, 0x161d1507,
  // [4450]
  0x66120112, 0x160501af, 0x18120d09, 0x03380507,
  0x0e1c3060, 0x0c002b23, 0x43120d55, 0x150c1209,
  0x400c1d09, 0x0e2325ad, 0x1d150c08, 0x38272955,
  0x120c1509, 0x3f002112, 0x0d0f1507, 0x45161807,
  // [4460]
  0x18141d60, 0x191d18bb, 0x021022bc, 0x0b010213,
  0x141d1812, 0x031910bc, 0x010f38af, 0x01036608,
  0x03140608, 0x10146608, 0x17290455, 0x1d191807,
  0x40181d09, 0x12040512, 0x380f0511, 0x10185112,
  // [4470]
  0x060b08ad, 0x38403fac, 0x02292708, 0x0c2b2907,
  0x3f080d13, 0x06402907, 0x45001902, 0x1d151721,
  0x0c451514, 0x38001f11, 0x16140b12, 0x10041855,
  0x0f060b12, 0x15124008, 0x1d380812, 0x210d3f21,
  // [4480]
  0x170f3813, 0x03000812, 0x04062209, 0x0b103808,
  0x0c000509, 0x08000609, 0x1e1c0e20, 0x04180d13,
  0x010d1dac, 0x29012709, 0x22001012, 0x03150c09,
  0x2b050cad, 0x0c1d1f08, 0x1e0e23ad, 0x1c252355,
  // [4490]
  0x151d45a4, 0x020b10bb, 0x22001009, 0x400f0c09,
  0x401d15af, 0x180c0509, 0x181905ad, 0x270c2b08,
  0x02121455, 0x27291d12, 0x0f010607, 0x22040112,
  0x270b2912, 0x1d0c3fac, 0x19012212, 0x18041609,
  // [44a0]
  0x01160d08, 0x2b001814, 0x120c0109, 0x270501af,
  0x27291734, 0x06003807, 0x03004507, 0x0c016609,
  0x040301ad, 0x104512ad, 0x08430112, 0x15450112,
  0x01430cac, 0x251e3020, 0x01380502, 0x0d0166a4,
  // [44b0]
  0x01032707, 0x19124007, 0x66002b20, 0x04000102,
  0x060c0307, 0x011005a4, 0x2b296612, 0x3f002712,
  0x066622af, 0x06032221, 0x03660613, 0x160c0107,
  0x06030c21, 0x0c003f22, 0x14060b12, 0x270c3f22,
  // [44c0]
  0x290c3f60, 0x0c036622, 0x450b05ac, 0x21003f14,
  0x12040509, 0x40161d11, 0x061901a4, 0x040c1507,
  0x051d38a4, 0x1d0c2107, 0x0b001020, 0x021901af,
  0x21040112, 0x151617a4, 0x0f171411, 0x30002520,
  // [44d0]
  0x08223f11, 0x38050102, 0x01080520, 0x020b40a4,
  0x0f430107, 0x0b002207, 0x18001914, 0x14020bad,
  0x03050b07, 0x25231c02, 0x0d0f0808, 0x30231e02,
  0x10002210, 0x16002222, 0x22001611, 0x12170107,
  // [44e0]
  0x08401707, 0x08014508, 0x0e1e1c02, 0x030c3f12,
  0x060517ad, 0x10063f21, 0x45191620, 0x1c232514,
  0x121d1412, 0x1d0c1412, 0x12151d07, 0x22210c07,
  0x15001d12, 0x161d1411, 0x011d08ac, 0x17381809,
  // [44f0]
  0x01001d08, 0x03660212, 0x160827af, 0x15191634,
  0x04081814, 0x04060313, 0x08162155, 0x0c041507,
  0x08100214, 0x29061812, 0x19011407, 0x0b060809,
  0x230e1e21, 0x18040822, 0x08151614, 0x16001422,
  // [4500]
  0x04660322, 0x06010b09, 0x18060409, 0x22081809,
  0x0d2b0512, 0x010305a4, 0x121d17bc, 0x05160d60,
  0x12000d12, 0x0d0f1207, 0x120d0f07, 0x1d191621,
  0x0d002912, 0x1445181d, 0x040f0daf, 0x38120fa4,
  // [4510]
  0x12451f12, 0x300e1ebe, 0x1d010c12, 0x451d0b12,
  0x14105112, 0x18011612, 0x01221912, 0x401d21be,
  0x102b1412, 0x01191dad, 0x45181255, 0x3f001020,
  0x16151013, 0x1d0c1808, 0x38160413, 0x43040511,
  // [4520]
  0x160451af, 0x041f19be, 0x151051af, 0x291d3f21,
  0x0f010b12, 0x102915af, 0x1f0b18be, 0x1d403f60,
  0x10225112, 0x18151660, 0x106612af, 0x40002713,
  0x0d1951af, 0x0c192209, 0x02221013, 0x0f0d1413,
  // [4530]
  0x083f0421, 0x08000d13, 0x01040512, 0x3f030112,
  0x0b010c12, 0x27291409, 0x18290109, 0x0b080112,
  0x291716bb, 0x100c0107, 0x050d5107, 0x1840146f,
  0x08150daf, 0x01062bbb, 0x27181921, 0x1d010c08,
  // [4540]
  0x060b0121, 0x22291855, 0x19042114, 0x660422a4,
  0x03060caf, 0x062b03af, 0x19290107, 0x061f0faf,
  0x10150209, 0x290c1512, 0x01142707, 0x010f0513,
  0x18210112, 0x662721bc, 0x29271734, 0x29003f20,
  // [4550]
  0x3f290112, 0x27291613, 0x0d051f13, 0x45121f13,
  0x0c271921, 0x02062bac, 0x030d06af, 0x0b1f1512,
  0x0d381609, 0x061619ad, 0x15211922, 0x0d004508,
  0x04381611, 0x0d041613, 0x662719af, 0x291617af,
  // [4560]
  0x171d0ca4, 0x291d1920, 0x27190209, 0x010419bc,
  0x0f001d12, 0x06021011, 0x450c1d07, 0x04160607,
  0x04051408, 0x12040111, 0x380f1dad, 0x02432ba4,
  0x1f3f0113, 0x150210ad, 0x0c1245be, 0x270c1d60,
  // [4570]
  0x45010c12, 0x38010faf, 0x141904a4, 0x45011213,
  0x17002214, 0x251e2311, 0x0c290112, 0x450c01a4,
  0x450f1808, 0x45000d14, 0x01051413, 0x29001421,
  0x38004335, 0x401d0821, 0x142b4512, 0x450f18af,
  // [4580]
  0x1f00181f, 0x081627ad, 0x14082712, 0x0f183809,
  0x082b1421, 0x400845af, 0x0d1704bc, 0x03020b13,
  0x380f3f21, 0x18170809, 0x050d3f12, 0x01170c07,
  0x38050860, 0x05031008, 0x03100209, 0x27212b09,
  // [4590]
  0x0f0d38be, 0x180c4012, 0x014506a4, 0x0d1701a4,
  0x0f1501a4, 0x040d01a4, 0x0c061907, 0x27292120,
  0x3f272922, 0x020c45af, 0x04170107, 0x080f45af,
  0x0c292113, 0x1c253022, 0x27294512, 0x02062107,
  // [45a0]
  0x191d4055, 0x27212911, 0x06171407, 0x21270c12,
  0x66160412, 0x0c001520, 0x013f1a12, 0x04000623,
  0x120f0112, 0x1f141821, 0x06010baf, 0x14000822,
  0x181f22bc, 0x18140d21, 0x21292711, 0x103f1821,
  // [45b0]
  0x036610ce, 0x010f4312, 0x05002207, 0x08171f09,
  0x06001712, 0x12031807, 0x22381807, 0x08210faf,
  0x05660d21, 0x10273809, 0x22212912, 0x180817be,
  0x0d184507, 0x15122955, 0x10021712, 0x270f01a4,
  // [45c0]
  0x020b06af, 0x10000312, 0x0b1d4507, 0x221901a4,
  0x161f2b09, 0x060119a4, 0x21272260, 0x38000607,
  0x08040608, 0x030b1011, 0x0f382112, 0x0b292720,
  0x010327a4, 0x231e0e21, 0x171501ac, 0x0f040107,
  // [45d0]
  0x30231eaf, 0x45010312, 0x150604ad, 0x231e0ebe,
  0x16040660, 0x29020b09, 0x27660360, 0x1d2104bb,
  0x04001614, 0x1e230e6f, 0x06150455, 0x081904af,
  0x060c1907, 0x080427af, 0x0b272121, 0x27065112,
  // [45e0]
  0x08270fa4, 0x15041621, 0x2b041212, 0x0f1d3809,
  0x0d001808, 0x29082712, 0x08051414, 0x22004521,
  0x14192112, 0x23301ebe, 0x01124555, 0x45042202,
  0x0c001011, 0x0d0129a4, 0x17190421, 0x66292b12,
  // [45f0]
  0x120c0111, 0x0c000121, 0x40080107, 0x05120cad,
  0x03660512, 0x251c1ead, 0x10150112, 0x05004308,
  0x2b0401af, 0x293f2714, 0x19100112, 0x250e2309,
  0x183827a4, 0x27291212, 0x301e1c13, 0x0c221513,
  // [4600]
  0x03661807, 0x0d140f09, 0x210451af, 0x15100d21,
  0x14194511, 0x22022b12, 0x0f160812, 0x05381407,
  0x05100b12, 0x212729be, 0x660b026f, 0x66021812,
  0x17380809, 0x22142114, 0x19182122, 0x141004be,
  // [4610]
  0x0f000c11, 0x05001f20, 0x2b1f0421, 0x04001f13,
  0x051f01af, 0x010d08ad, 0x06021912, 0x1f000423,
  0x060b01af, 0x01162207, 0x05011507, 0x430117af,
  0x2b000508, 0x43000108, 0x08191708, 0x051601ad,
  // [4620]
  0x012b3f12, 0x124506be, 0x2b216622, 0x40010607,
  0x050f0809, 0x43180108, 0x1e00231f, 0x27050612,
  0x120c17af, 0x01030555, 0x063f03be, 0x03052b12,
  0x43000102, 0x1f010513, 0x02192113, 0x120c01a4,
  // [4630]
  0x0e1e25ad, 0x450c1202, 0x450c0411, 0x220117a4,
  0x22001407, 0x45120507, 0x10000512, 0x05011faf,
  0x0f014002, 0x0b0c01af, 0x27050108, 0x18000507,
  0x18173f12, 0x04001910, 0x010617af, 0x230e1e20,
  // [4640]
  0x40171955, 0x041908ac, 0x14401d20, 0x2908046f,
  0x14400807, 0x15001712, 0x01151608, 0x14171660,
  0x0d451407, 0x10190107, 0x03002212, 0x060429ac,
  0x29182713, 0x2b1d40a4, 0x2b213fad, 0x451812af,
  // [4650]
  0x17001614, 0x190408af, 0x18040612, 0x0c010509,
  0x04001f14, 0x19000d14, 0x38010412, 0x12180dad,
  0x0d451813, 0x0b0f01a4, 0x104019a4, 0x18120d12,
  0x02190421, 0x19180411, 0x12453814, 0x66061012,
  // [4660]
  0x03190120, 0x40001908, 0x0d272960, 0x0b12185e,
  0x190b10af, 0x0c0b1f07, 0x270329af, 0x66032109,
  0x10160b12, 0x45120faf, 0x1921016f, 0x66210122,
  0x660301be, 0x29012113, 0x43380108, 0x3f000111,
  // [4670]
  0x06030121, 0x17012912, 0x060121ad, 0x06000c1f,
  0x190b01af, 0x12012912, 0x17080109, 0x29013faf,
  0x0c004523, 0x1d3801a4, 0x210301af, 0x0e2330be,
  0x27290113, 0x010f1fad, 0x0d161707, 0x01081609,
  // [4680]
  0x0f011f07, 0x19060411, 0x01003f08, 0x082201a4,
  0x0d0f51af, 0x291001af, 0x051f1512, 0x2b001f22,
  0x051f2baf, 0x66272960, 0x29153f12, 0x02186611,
  0x1c233060, 0x43002b11, 0x01160513, 0x1e302314,
  // [4690]
  0x08032212, 0x031f01af, 0x0b101508, 0x66083809,
  0x041840ad, 0x18400460, 0x27400460, 0x661918bb,
  0x12100313, 0x022701af, 0x01080d09, 0x02001409,
  0x0d001513, 0x0f003809, 0x0c1217a4, 0x21292722,
  // [46a0]
  0x17041913, 0x222129af, 0x162229af, 0x0c001820,
  0x291904af, 0x1d1708ac, 0x19041712, 0x18041960,
  0x190b04af, 0x192127af, 0x122221af, 0x060b1411,
  0x19101508, 0x2b001909, 0x21001609, 0x01020612,
  // [46b0]
  0x0d004511, 0x0f450107, 0x45001f14, 0x1d1504ac,
  0x040322bb, 0x01032207, 0x1d4019a4, 0x080106a4,
  0x1d001520, 0x1d220212, 0x301e1cad, 0x27222921,
  0x0b0419af, 0x196617a4, 0x16141707, 0x03660b60,
  // [46c0]
  0x03191d07, 0x190c0109, 0x45432707, 0x14002109,
  0x2b100460, 0x121d0c12, 0x38401911, 0x05086621,
  0x27183f60, 0x041d0c60, 0x040b2907, 0x0c3f0baf,
  0x17003f13, 0x156627af, 0x1d002912, 0x083f01af,
  // [46d0]
  0x3f001614, 0x011006a4, 0x084314ad, 0x1d191612,
  0x04000521, 0x21043f60, 0x17001514, 0x140b16ad,
  0x04171613, 0x0b061912, 0x03060b13, 0x0b401d07,
  0x221408a4, 0x2b1d04ad, 0x173f19bc, 0x06190412,
  // [46e0]
  0x05190112, 0x66170112, 0x224512be, 0x030c4307,
  0x06161912, 0x66000b23, 0x06000222, 0x05061f12,
  0x010c1007, 0x01001d12, 0x04192221, 0x40220611,
  0x0d0804ad, 0x01662212, 0x38120112, 0x04216612,
  // [46f0]
  0x0b001914, 0x04161912, 0x0c216613, 0x192104af,
  0x0b021209, 0x0d2b3821, 0x38050f12, 0x041408bc,
  0x270b0221, 0x15161921, 0x3f6618be, 0x0b662220,
  0x181701af, 0x021938ad, 0x16002708, 0x0c2b0108,
  // [4700]
  0x121d0512, 0x18000511, 0x0f272921, 0x292114ce,
  0x400c1808, 0x1f0501a4, 0x162b1712, 0x04020b11,
  0x01053f09, 0x020b66a4, 0x05042b55, 0x01451208,
  0x380f0dbc, 0x080d0baf, 0x402b1d12, 0x451206a4,
  // [4710]
  0x17000612, 0x080d3822, 0x17190411, 0x06012202,
  0x100b0121, 0x010b0207, 0x10183f12, 0x18190412,
  0x17020f09, 0x162b1f60, 0x0b0105ad, 0x1d001908,
  0x10292760, 0x0b221007, 0x40000108, 0x193f2113,
  // [4720]
  0x2b002711, 0x1e1c0e02, 0x150322a4, 0x12061dac,
  0x1f141812, 0x05000214, 0x38011902, 0x0d173812,
  0x10010baf, 0x301e2507, 0x1d1215bb, 0x081d3f13,
  0x18083fad, 0x10142221, 0x082b19af, 0x21000808,
  // [4730]
  0x15381712, 0x1d0819a4, 0x10012909, 0x031d0807,
  0x1d000807, 0x451d4022, 0x193f4021, 0x02271612,
  0x660d0509, 0x220617a4, 0x40221d14, 0x01001621,
  0x22001a13, 0x080d01a4, 0x0e1c30be, 0x1f272912,
  // [4740]
  0x10001814, 0x38221914, 0x17000f22, 0x38051712,
  0x0c270112, 0x29270122, 0x02100607, 0x1e301c09,
  0x01061f12, 0x040b0260, 0x06012b09, 0x01182b21,
  0x08040555, 0x01020308, 0x14100b09, 0x272b1f60,
  // [4750]
  0x1f004314, 0x38080507, 0x100b19a4, 0x160d1811,
  0x0d001522, 0x16181512, 0x270601af, 0x01062207,
  0x401d06bc, 0x271f01af, 0x170d0522, 0x190201af,
  0x0e1c2360, 0x0b000d07, 0x450418ad, 0x062b01af,
  // [4760]
  0x02052baf, 0x0b1416a4, 0x251c0e02, 0x2b050108,
  0x03061412, 0x2b000b14, 0x3f000413, 0x16273f12,
  0x3f272914, 0x0c271612, 0x40020112, 0x40001509,
  0x45000d20, 0x0b022712, 0x10000c11, 0x01020821,
  // [4770]
  0x01160c07, 0x401d19af, 0x0c001f0d, 0x12400cac,
  0x020412bb, 0x0c036614, 0x0f381807, 0x02101808,
  0x041840bb, 0x12401da4, 0x10021612, 0x22020b12,
  0x0c401d60, 0x233025bc, 0x430d01ad, 0x1d451214,
  // [4780]
  0x03000f20, 0x150419bc, 0x08120c07, 0x230e1e13,
  0x0c001d14, 0x29213f12, 0x2b0d0f21, 0x2b001408,
  0x0b380108, 0x03001720, 0x051817af, 0x18292709,
  0x300e1c6f, 0x1f030613, 0x231c3011, 0x40000d12,
  // [4790]
  0x401922af, 0x08223f12, 0x01060d07, 0x29081722,
  0x1f001709, 0x1d224013, 0x221d3f21, 0x401d1413,
  0x1d162221, 0x430501af, 0x020c01a4, 0x30000e33,
  0x1d3f2221, 0x22004020, 0x45380c08, 0x12001411,
  // [47a0]
  0x0c191614, 0x1f451811, 0x15272912, 0x22210607,
  0x0d001511, 0x1d664509, 0x1e230ebc, 0x06001923,
  0x06004021, 0x0e301ebc, 0x060b0222, 0x010c27af,
  0x22001512, 0x06272960, 0x0f001212, 0x40171d21,
  // [47b0]
  0x19042107, 0x02002907, 0x052b1d12, 0x0c272912,
  0x21166609, 0x223f29af, 0x27291d13, 0x030566ad,
  0x120d0f6d, 0x05001633, 0x22001014, 0x21001814,
  0x0f180511, 0x0c030107, 0x0d22086f, 0x05100407,
  // [47c0]
  0x0d032b08, 0x38012708, 0x161d1709, 0x0d401721,
  0x04000213, 0x0d124560, 0x0d0f1809, 0x0b080209,
  0x140f18ad, 0x14192114, 0x03451712, 0x0f0d4512,
  0x0d100612, 0x01050f12, 0x300e1c14, 0x21006609,
  // [47d0]
  0x12180507, 0x06151708, 0x1d000c02, 0x231e0ead,
  0x14040b12, 0x01002713, 0x120401ac, 0x0d1721ad,
  0x0f0d05a4, 0x121d1707, 0x270214af, 0x01001613,
  0x15182212, 0x400d2909, 0x10272982, 0x0f050821,
  // [47e0]
  0x020b0112, 0x0f2714af, 0x190417be, 0x192704ad,
  0x1d000c20, 0x181908bc, 0x17292722, 0x290f17a4,
  0x05041760, 0x040d1fa4, 0x1d403f12, 0x030f0107,
  0x1d181512, 0x03183f6f, 0x0d0f05af, 0x1e2523bc,
  // [47f0]
  0x1d080411, 0x17001414, 0x033f1860, 0x042b2207,
  0x03662112, 0x18000109, 0x0b061407, 0x036601a4,
  0x020119a4, 0x1d0c2708, 0x66031812, 0x0f290108,
  0x0b0516bb, 0x27006612, 0x120c2b12, 0x140b51a4,

  // [4800]
  0x03000213, 0x190608a4, 0x451d17af, 0x06042907,
  0x16023fad, 0x05011212, 0x12004311, 0x14431812,
  0x291d4022, 0x0b1402a4, 0x1d224021, 0x12450c14,
  0x050116a4, 0x66001712, 0x40031760, 0x66010560,
  // [4810]
  0x171d6607, 0x0d050109, 0x03004007, 0x06196607,
  0x08042255, 0x080105ad, 0x010512af, 0x12010512,
  0x1d001721, 0x010603a4, 0x17430108, 0x220f0d07,
  0x06010808, 0x081745af, 0x22001522, 0x0c081607,
  // [4820]
  0x16190f13, 0x2b0108ad, 0x0d0c2221, 0x0d0f2221,
  0x0f220d09, 0x02001011, 0x01042107, 0x1d172207,
  0x081601af, 0x12434514, 0x43141812, 0x22004011,
  0x0f164022, 0x082b1aaf, 0x43000511, 0x0d0f0caf,
  // [4830]
  0x0f220207, 0x02012212, 0x38004309, 0x05001207,
  0x40004533, 0x38000523, 0x04002112, 0x011d0407,
  0x400f3f21, 0x0f213f22, 0x01000c22, 0x030f0c08,
  0x1d000611, 0x0d001f08, 0x0d080f14, 0x430666ad,
  // [4840]
  0x06003811, 0x456606af, 0x12000f08, 0x08001212,
  0x18660112, 0x401d0412, 0x0c451807, 0x190f27af,
  0x06291608, 0x43001902, 0x1f000d12, 0x01222b07,
  0x380106a4, 0x40081d07, 0x08000420, 0x37001e10,
  // [4850]
  0x02182408, 0x0f270155, 0x170d2207, 0x01080209,
  0x08451212, 0x080c0107, 0x38160108, 0x251c3007,
  0x0f0d19a4, 0x012b1f12, 0x042b01a4, 0x066616a4,
  0x19020b07, 0x050122bb, 0x153f1920, 0x15041611,
  // [4860]
  0x17001920, 0x1d001522, 0x060145a4, 0x17272908,
  0x300e1c02, 0x38000d10, 0x15403faf, 0x08190413,
  0x40060812, 0x183819bb, 0x0d400b12, 0x2b003823,
  0x18062bbe, 0x14272907, 0x01121712, 0x150c1721,
  // [4870]
  0x29270612, 0x190b1812, 0x66000620, 0x0b190460,
  0x06041455, 0x19011812, 0x401d1812, 0x0d160155,
  0x05381813, 0x0c154507, 0x06100108, 0x02002b13,
  0x10450112, 0x02160c55, 0x05081607, 0x66190321,
  // [4880]
  0x10002b20, 0x251c2333, 0x14004512, 0x1f001021,
  0x0b141f22, 0x03004513, 0x16193f12, 0x19660360,
  0x05081755, 0x02002713, 0x43380511, 0x301c0ebe,
  0x19000114, 0x66042bbb, 0x14042912, 0x212b0112,
  // [4890]
  0x29042714, 0x03271412, 0x38270812, 0x06002913,
  0x0c002111, 0x1d000812, 0x45001821, 0x0f180512,
  0x1d001220, 0x164512ac, 0x0e1c1e22, 0x38140fa4,
  0x061217ad, 0x231c25bc, 0x0f3812af, 0x0d051807,
  // [48a0]
  0x01081712, 0x38050d11, 0x400f1212, 0x45051d12,
  0x12451623, 0x1d0c0dac, 0x01400c34, 0x40061dac,
  0x30231c13, 0x05193f09, 0x3f2b4313, 0x222b29a4,
  0x40081d09, 0x12100cad, 0x1d450c11, 0x16190509,
  // [48b0]
  0x381d27af, 0x450229a4, 0x0d180f09, 0x04430507,
  0x38082112, 0x02000412, 0x19043f12, 0x19042112,
  0x14000813, 0x0d063855, 0x14120d07, 0x030b0211,
  0x05010412, 0x15190413, 0x25231e02, 0x17004014,
  // [48c0]
  0x05012707, 0x190106ad, 0x04003822, 0x0c121da4,
  0x0b270609, 0x01380511, 0x23253011, 0x22401d55,
  0x14451f12, 0x0c011d12, 0x1d0c0609, 0x12384511,
  0x27220112, 0x18000521, 0x100c4509, 0x1f002222,
  // [48d0]
  0x06031f21, 0x19001613, 0x0b0d01a4, 0x18292711,
  0x231e1c08, 0x40121d08, 0x38000502, 0x661803af,
  0x14124511, 0x01181912, 0x29192213, 0x381006ad,
  0x06000114, 0x0c3f1512, 0x382b06ad, 0x12051812,
  // [48e0]
  0x2b060211, 0x22190112, 0x06031913, 0x14380112,
  0x29161921, 0x1627296f, 0x45122911, 0x19002223,
  0x0b0c1211, 0x06190107, 0x124514af, 0x180f1fad,
  0x10062b12, 0x0c001020, 0x0d0c1f55, 0x0d0f2bbb,
  // [48f0]
  0x22000307, 0x22141960, 0x16041713, 0x04192121,
  0x0b1904ad, 0x660b1921, 0x14450dad, 0x02010b02,
  0x05141955, 0x12000608, 0x19182208, 0x04000322,
  0x190445a4, 0x271d40af, 0x18004521, 0x01272920,
  // [4900]
  0x10006621, 0x0f184512, 0x14221912, 0x18061212,
  0x27292134, 0x06291f12, 0x3f4301af, 0x296606bc,
  0x18002220, 0x380b0611, 0x0d0f17bb, 0x011f0612,
  0x03002b09, 0x081701ad, 0x160121bc, 0x0d272955,
  // [4910]
  0x0e301e08, 0x05002208, 0x1e000e20, 0x18050112,
  0x0b6601a4, 0x12161dad, 0x05060307, 0x21000309,
  0x03196612, 0x03161423, 0x02120112, 0x1f000f12,
  0x27192112, 0x15270f11, 0x12050f09, 0x08190108,
  // [4920]
  0x1d0f0509, 0x08004512, 0x061004a4, 0x231c3021,
  0x180206ac, 0x0117051f, 0x1d174022, 0x080f0512,
  0x3f1d4022, 0x100b02a4, 0x45294012, 0x43000f07,
  0x29036634, 0x14180bce, 0x010f05af, 0x08380d12,
  // [4930]
  0x126601af, 0x17221d12, 0x1d000814, 0x220b6614,
  0x0b000c08, 0x06001723, 0x1d080c21, 0x10400812,
  0x012b1608, 0x18000d1f, 0x0c0d1811, 0x0f0d3855,
  0x100619a4, 0x1e233002, 0x3800181f, 0x0c450daf,
  // [4940]
  0x30230e11, 0x03062207, 0x19000633, 0x17141907,
  0x0e002534, 0x04006611, 0x38002912, 0x012b0609,
  0x230e25af, 0x03001902, 0x0d001409, 0x19002208,
  0x060b0208, 0x384501ad, 0x0f082ba4, 0x192214ac,
  // [4950]
  0x22001022, 0x0e251cbc, 0x404512af, 0x21272920,
  0x181d1512, 0x16190b12, 0x17121921, 0x0c162712,
  0x191d0807, 0x10152121, 0x1d150821, 0x100319af,
  0x21171960, 0x38001d07, 0x16152114, 0x04191621,
  // [4960]
  0x020b19ce, 0x291619af, 0x18292121, 0x0c170407,
  0x3f1419af, 0x15001921, 0x18011920, 0x19041209,
  0x142b1911, 0x19000108, 0x19001420, 0x17010f08,
  0x010f0d09, 0x1d404523, 0x08041911, 0x02001609,
  // [4970]
  0x45121808, 0x0c001f09, 0x15120caf, 0x141245ad,
  0x03000807, 0x14451211, 0x231c3013, 0x0d081dad,
  0x10210308, 0x060f0b12, 0x0f380655, 0x170601a4,
  0x301e2560, 0x04000614, 0x181d4021, 0x40001022,
  // [4980]
  0x14012b08, 0x080518a4, 0x0b020421, 0x12061807,
  0x2b020baf, 0x12450d07, 0x086601af, 0x191d1f07,
  0x0b040808, 0x08190111, 0x04000820, 0x02401d07,
  0x0d001407, 0x45001508, 0x0f0d1fac, 0x10400407,
  // [4990]
  0x010b0407, 0x38171807, 0x01000d02, 0x0b011812,
  0x1400181d, 0x033822ac, 0x40000c11, 0x020b1912,
  0x1d124023, 0x010d2bac, 0x06101960, 0x431619ac,
  0x38190c20, 0x0d082108, 0x01060c12, 0x172b43a4,
  // [49a0]
  0x020d22a4, 0x14660312, 0x30001c09, 0x1d004523,
  0x081d01a4, 0x190140a4, 0x18060d60, 0x3f004514,
  0x380d3fbe, 0x104006af, 0x27294009, 0x061018ad,
  0x14451260, 0x380f0821, 0x38000810, 0x17010309,
  // [49b0]
  0x05020307, 0x1d0815ad, 0x01141612, 0x100b2212,
  0x66010309, 0x1f0d06bc, 0x171d12af, 0x661906af,
  0x04221914, 0x020b6609, 0x221604a4, 0x10181407,
  0x220610a4, 0x120c16a4, 0x0f032ba4, 0x2b270108,
  // [49c0]
  0x06660313, 0x0c183f07, 0x660b0314, 0x29006614,
  0x01291fad, 0x30251c11, 0x0f083809, 0x450d0f12,
  0x40001d33, 0x0f001f33, 0x0b223821, 0x401f1612,
  0x042118a4, 0x10180612, 0x082b01af, 0x456612af,
  // [49d0]
  0x2b1f0613, 0x011d4013, 0x04001721, 0x063817ad,
  0x05001536, 0x06036620, 0x120f0d12, 0x0d172b07,
  0x29000c11, 0x0d141f13, 0x05011714, 0x03000202,
  0x14041934, 0x170b0214, 0x220b1007, 0x43003812,
  // [49e0]
  0x22020b13, 0x45080da4, 0x1e253013, 0x10036614,
  0x010517a4, 0x100c0b12, 0x400d0f08, 0x10082212,
  0x01191008, 0x01185112, 0x12220607, 0x250e1e55,
  0x05120109, 0x01020b14, 0x451f1855, 0x10001d07,
  // [49f0]
  0x060319af, 0x1f004509, 0x10171f07, 0x03060221,
  0x0d0f2907, 0x2b000512, 0x1e2330bc, 0x03055112,
  0x02661f08, 0x430801ac, 0x2b1d0daf, 0x101d4013,
  0x1d401022, 0x0c191011, 0x66035112, 0x02030108,
  // [4a00]
  0x0c2b0111, 0x221d0f12, 0x662b01a4, 0x10000321,
  0x27002108, 0x16012bbe, 0x18222712, 0x061d0312,
  0x17001914, 0x12100bad, 0x06126612, 0x2b0301af,
  0x401d17af, 0x03182108, 0x0f031607, 0x18292713,
  // [4a10]
  0x0c0f08a4, 0x1c0e1ead, 0x19101d07, 0x22380509,
  0x27006613, 0x01182709, 0x0c150808, 0x1e1c0eac,
  0x12453f21, 0x1d3f2912, 0x43011607, 0x011d0fa4,
  0x27210109, 0x0e301e14, 0x15271621, 0x1d2729a4,
  // [4a20]
  0x00005c15, 0x16272914, 0x01000309, 0x29273f11,
  0x190b026f, 0x04270bbb, 0x66000433, 0x21016609,
  0x03192b07, 0x031f1012, 0x0d081612, 0x0c272960,
  0x01272213, 0x12290112, 0x27083fbc, 0x06030411,
  // [4a30]
  0x151722ad, 0x050601ac, 0x29210412, 0x1d403f14,
  0x14173809, 0x27083fad, 0x060b1707, 0x03003812,
  0x0f0d1f21, 0x17222907, 0x0d000812, 0x08401d13,
  0x3f271813, 0x3f1d4034, 0x40043f13, 0x210f08be,
  // [4a40]
  0x22000f12, 0x19220c55, 0x05011f07, 0x06046608,
  0x1c2330ad, 0x0f211660, 0x121f1912, 0x034021af,
  0x451218a4, 0x140f19ad, 0x0b041911, 0x0f002920,
  0x0f162b12, 0x29002b13, 0x08191709, 0x3f0b0808,
  // [4a50]
  0x210145af, 0x03001609, 0x45401d09, 0x0f190209,
  0x05001814, 0x0b192107, 0x05001821, 0x173f1208,
  0x38660112, 0x17010809, 0x06660355, 0x0d000607,
  0x0c030655, 0x161d4022, 0x180f0512, 0x180f0507,
  // [4a60]
  0x38051810, 0x10020614, 0x011245a4, 0x660206af,
  0x193f0421, 0x66041960, 0x450f0d60, 0x0e2523ac,
  0x0b380107, 0x163f0c14, 0x23250ea4, 0x01153f11,
  0x08293fbc, 0x19170422, 0x40081d21, 0x0c290d13,
  // [4a70]
  0x1d000d07, 0x22030608, 0x050d0109, 0x451d3809,
  0x06000f02, 0x1d001521, 0x030b51a4, 0x12220d11,
  0x12180609, 0x06051907, 0x450b0609, 0x02010d07,
  0x061d0109, 0x080f1d12, 0x010b02a4, 0x02081009,
  // [4a80]
  0x100b5107, 0x380314a4, 0x10140421, 0x43060112,
  0x231e0e02, 0x1c253013, 0x0c122b07, 0x100602a4,
  0x170119ac, 0x193f4512, 0x27003f22, 0x45211620,
  0x2b3f2921, 0x14000d13, 0x451d406f, 0x29451421,
  // [4a90]
  0x29004512, 0x19000d08, 0x01051808, 0x08181612,
  0x104508ad, 0x45080c07, 0x061f6612, 0x06192212,
  0x03660111, 0x012b0614, 0x66032b13, 0x0b060207,
  0x19292760, 0x160c38a4, 0x45221d12, 0x16080bac,
  // [4aa0]
  0x2b066621, 0x0c012207, 0x02221d12, 0x18380512,
  0x22002b07, 0x66031521, 0x02451508, 0x301c1eaf,
  0x66001533, 0x660c15af, 0x15000b13, 0x660c0611,
  0x03001520, 0x0b034308, 0x301e2520, 0x0b154511,
  // [4ab0]
  0x38170f13, 0x38010611, 0x18291612, 0x22000807,
  0x22000809, 0x401d2207, 0x0d002708, 0x18292760,
  0x40272912, 0x08003f13, 0x161545af, 0x40272933,
  0x01002212, 0x08002b08, 0x27403f13, 0x40002912,
  // [4ac0]
  0x050140bb, 0x40272913, 0x14161908, 0x011d2b07,
  0x01191f11, 0x01223f11, 0x12000207, 0x17001f14,
  0x02001602, 0x38190408, 0x04000302, 0x0f051912,
  0x661929af, 0x05001702, 0x0f171f21, 0x05000420,
  // [4ad0]
  0x40120412, 0x0f0d2707, 0x0d0f2b07, 0x1f3f4560,
  0x0c401921, 0x0f162b55, 0x192921af, 0x14451812,
  0x05000402, 0x0f001608, 0x140b12a4, 0x301e2314,
  0x45100260, 0x08061d07, 0x021045af, 0x0c050109,
  // [4ae0]
  0x10002107, 0x03020baf, 0x01432109, 0x30000e35,
  0x022b1fcf, 0x1d0b03ac, 0x02004008, 0x04000f12,
  0x100b5112, 0x40000211, 0x400c4512, 0x27040112,
  0x08006611, 0x19160dbc, 0x150c1612, 0x08170511,
  // [4af0]
  0x17061612, 0x17002111, 0x17103812, 0x05270113,
  0x0d020b12, 0x04011909, 0x0b026614, 0x05036611,
  0x0b081708, 0x032218ac, 0x0f060155, 0x0f141f12,
  0x0c020508, 0x1d040c09, 0x03296609, 0x29030112,
  // [4b00]
  0x03002b22, 0x381d0dbe, 0x380f0d22, 0x15160113,
  0x011629ac, 0x0d1d22a4, 0x1c231ece, 0x190415ad,
  0x142b0613, 0x180b1014, 0x250e2355, 0x12101d09,
  0x030506ac, 0x0b001812, 0x10661fad, 0x0e301ebe,
  // [4b10]
  0x2b002109, 0x08270108, 0x0b1901a4, 0x061001a4,
  0x01660308, 0x08013802, 0x14002213, 0x10000209,
  0x04452209, 0x17001411, 0x0f1d0407, 0x1d12400b,
  0x06011008, 0x06000d11, 0x231e256f, 0x22000107,
  // [4b20]
  0x08014507, 0x19010f07, 0x01381708, 0x04000821,
  0x05002707, 0x22000f09, 0x14026612, 0x06381f12,
  0x16272208, 0x171f0109, 0x27382113, 0x290627a4,
  0x18001608, 0x18002133, 0x272966be, 0x01081812,
  // [4b30]
  0x081715a4, 0x37004e1f, 0x29222723, 0x0f0143a4,
  0x181d40ac, 0x0d002214, 0x04031907, 0x14100b21,
  0x151017ac, 0x0f041511, 0x021916ad, 0x05143821,
  0x2b001023, 0x01001f08, 0x0f0c1d13, 0x17052220,
  // [4b40]
  0x2b0c0623, 0x08171f22, 0x380d51af, 0x16083882,
  0x21290409, 0x16060408, 0x2b0c1212, 0x0b013802,
  0x01000622, 0x060121a4, 0x660c2b09, 0x1c0e2513,
  0x2b000c21, 0x171905af, 0x01061555, 0x07005c0e,
  // [4b50]
  0x0c3f01af, 0x060c1507, 0x432b0811, 0x0d0f0107,
  0x0d194312, 0x43000520, 0x1d150409, 0x0f1917af,
  0x143f1f23, 0x14401909, 0x193f0412, 0x10080560,
  0x3f1d2109, 0x19212960, 0x0f173f34, 0x210c3f09,
  // [4b60]
  0x05191f12, 0x22042107, 0x100b1d08, 0x18190509,
  0x0b061023, 0x293f2122, 0x293f2120, 0x10040607,
  0x02051960, 0x060b1021, 0x40001207, 0x0f051808,
  0x03140607, 0x22191012, 0x060b1007, 0x1d190109,
  // [4b70]
  0x0d011909, 0x220618ad, 0x18000502, 0x014510ac,
  0x38401d07, 0x19401412, 0x19000602, 0x050d12a4,
  0x14451210, 0x30231e08, 0x300e1c60, 0x02000602,
  0x19030ba4, 0x12001007, 0x06010bad, 0x01036613,
  // [4b80]
  0x12451dbb, 0x18191022, 0x2b0601af, 0x1e1c2582,
  0x0b430107, 0x01020b09, 0x12044512, 0x0c001f08,
  0x020b6621, 0x17004021, 0x02100609, 0x121d2b09,
  0x010d08af, 0x020b01a4, 0x30001c22, 0x402729ad,
  // [4b90]
  0x0d000108, 0x21012b12, 0x400445af, 0x402b1dac,
  0x0d044012, 0x66060322, 0x0b182b55, 0x04010c07,
  0x30252311, 0x17060cbb, 0x030d1709, 0x40000111,
  0x272918af, 0x10222107, 0x03660113, 0x450f0109,
  // [4ba0]
  0x3f002b13, 0x15221621, 0x12270c12, 0x06221012,
  0x220b1011, 0x1e230ebb, 0x050129ad, 0x0d0f3860,
  0x401d1612, 0x0c4512a4, 0x25300ebe, 0x1d0445af,
  0x011706a4, 0x01172907, 0x2b1001a4, 0x1e251c20,
  // [4bb0]
  0x06171212, 0x060522ad, 0x1c1e2520, 0x100104ac,
  0x18401955, 0x0d0b0f07, 0x27002114, 0x14002908,
  0x45004311, 0x1e251c02, 0x40451612, 0x03401d07,
  0x451d1611, 0x452212a4, 0x21162912, 0x05003f12,
  // [4bc0]
  0x66211913, 0x1c0e3009, 0x380c1260, 0x231c30af,
  0x4519045e, 0x010d3fad, 0x06180411, 0x22292760,
  0x451d1612, 0x01120f07, 0x032729af, 0x1d403823,
  0x2b0145af, 0x29180cad, 0x05060809, 0x18000409,
  // [4bd0]
  0x08270308, 0x19060807, 0x0c190807, 0x17000111,
  0x152b16ad, 0x010c08a4, 0x43040112, 0x06140b6f,
  0x22010612, 0x02141007, 0x12106608, 0x19002708,
  0x03660109, 0x1e0e3060, 0x06452107, 0x082b01a4,
  // [4be0]
  0x02001711, 0x1e250e08, 0x27080f20, 0x1d380f02,
  0x45191607, 0x03014309, 0x181d1907, 0x43000307,
  0x00001403, 0x190204a4, 0x100651af, 0x0b000613,
  0x430d2907, 0x02220b07, 0x1e2330af, 0x04213faf,
  // [4bf0]
  0x06213fad, 0x06430112, 0x16124520, 0x0b101f09,
  0x451d4008, 0x06011607, 0x0119046f, 0x21041909,
  0x1f292720, 0x0f0412bc, 0x19380414, 0x08401d20,
  0x1d150c09, 0x40040cbc, 0x66020312, 0x0c0f4514,

  // [4c00]
  0x030201ac, 0x01210412, 0x1d030460, 0x27000d13,
  0x040801a4, 0x16191da4, 0x66000212, 0x251e23ac,
  0x03662bbb, 0x661f0baf, 0x02062121, 0x29380f13,
  0x29271212, 0x02031807, 0x0d0f2123, 0x19213f12,
  // [4c10]
  0x06141611, 0x15000412, 0x38271d12, 0x011406ac,
  0x181f1713, 0x12152260, 0x0c000d22, 0x12002212,
  0x14003f21, 0x12220ba4, 0x182238af, 0x16401d14,
  0x060b40ac, 0x04401d09, 0x191d1823, 0x1d0106af,
  // [4c20]
  0x401d1614, 0x1d140609, 0x40151d60, 0x100b0ca4,
  0x12011d11, 0x15401d12, 0x15161d14, 0x01030414,
  0x15000622, 0x02040112, 0x0d382912, 0x01290812,
  0x080f3f60, 0x03162255, 0x45120c07, 0x0b021011,
  // [4c30]
  0x030666a4, 0x1e0e2314, 0x21291708, 0x14004514,
  0x0c001720, 0x06380507, 0x03001521, 0x270d3f12,
  0x19380f60, 0x0d0805af, 0x02401212, 0x0d001f20,
  0x00001415, 0x12051707, 0x01060512, 0x12001614,
  // [4c40]
  0x380105ad, 0x04101812, 0x10192212, 0x04181407,
  0x042901a4, 0x010c2708, 0x40211607, 0x011619bc,
  0x1f0f2baf, 0x08181955, 0x0f173f60, 0x05221d02,
  0x0b451260, 0x050f0d12, 0x03196608, 0x2b661408,
  // [4c50]
  0x0f171807, 0x100218af, 0x38000b09, 0x302523af,
  0x400103a4, 0x0e3025af, 0x04000c13, 0x061803a4,
  0x16010fbb, 0x22292708, 0x02036609, 0x190b0607,
  0x1d16156f, 0x01271860, 0x29380f09, 0x06290111,
  // [4c60]
  0x102b0655, 0x450301ad, 0x12450cbb, 0x0f0d1613,
  0x38170313, 0x16151d60, 0x1d000d08, 0x17380108,
  0x08010512, 0x0e002533, 0x0f0d2b02, 0x08020d02,
  0x05271dad, 0x14001208, 0x05401d12, 0x01213f55,
  // [4c70]
  0x40661d09, 0x0d001414, 0x0f401d11, 0x060315af,
  0x06101612, 0x45180d08, 0x04161509, 0x05100112,
  0x16401d13, 0x40062b60, 0x213f0d12, 0x02380fa4,
  0x10124560, 0x011d04a4, 0x04021914, 0x15401dad,
  // [4c80]
  0x250e23bc, 0x2b003814, 0x38010407, 0x101219ad,
  0x2b191faf, 0x14000c14, 0x0c290312, 0x0f082b09,
  0x40153fac, 0x06032212, 0x38000110, 0x45051209,
  0x10001902, 0x17010808, 0x080129a4, 0x03002907,
  // [4c90]
  0x0f381421, 0x0f194507, 0x100b01a4, 0x0b1701af,
  0x10010302, 0x100251a4, 0x061766a4, 0x02170809,
  0x45020c12, 0x12001602, 0x100b06ac, 0x14001613,
  0x270121be, 0x15080621, 0x0f031fbe, 0x0d0f19af,
  // [4ca0]
  0x0b0214af, 0x050c1212, 0x1d1819ac, 0x0f290cad,
  0x04124508, 0x12451813, 0x06221810, 0x1e1c2321,
  0x2b220808, 0x04002707, 0x0f222bad, 0x29271f12,
  0x0d220812, 0x02192211, 0x0d083f21, 0x03180f11,
  // [4cb0]
  0x22060112, 0x04221907, 0x15001d07, 0x3f2208af,
  0x08011f55, 0x06080412, 0x04100655, 0x08380d6f,
  0x08190112, 0x19000c08, 0x12171d20, 0x120306a4,
  0x38080f14, 0x100618ab, 0x10401d09, 0x05181908,
  // [4cc0]
  0x0b400102, 0x1d0c4502, 0x380d17af, 0x0f050111,
  0x0b021409, 0x0d270cbc, 0x15002b23, 0x1d164009,
  0x1d002b21, 0x380119af, 0x15401d07, 0x171612af,
  0x181615be, 0x19160408, 0x38030108, 0x30251c08,
  // [4cd0]
  0x06001d09, 0x0d043faf, 0x27291921, 0x3f211f21,
  0x1f000421, 0x1f002113, 0x0f011512, 0x16040508,
  0x162b1521, 0x2b1f0411, 0x150416a4, 0x01061807,
  0x100f0107, 0x43000c13, 0x10146607, 0x0f384311,
  // [4ce0]
  0x19003822, 0x16000809, 0x0f0816a4, 0x1e300e02,
  0x04021009, 0x1f141814, 0x0c121407, 0x141006af,
  0x19272211, 0x012718bc, 0x45101908, 0x0e231ca4,
  0x0d050155, 0x66211012, 0x03016609, 0x3f292721,
  // [4cf0]
  0x3f380112, 0x06660409, 0x103f12a4, 0x141f0611,
  0x1d2b1912, 0x1c231e13, 0x40101d09, 0x2914216f,
  0x1d0419ad, 0x452717bb, 0x43010baf, 0x22001721,
  0x22172112, 0x22011712, 0x22001711, 0x01061907,
  // [4d00]
  0x19211722, 0x292717bc, 0x030105ad, 0x013810ad,
  0x2b000f09, 0x22380107, 0x0c4001a4, 0x66013812,
  0x1d001210, 0x0b222113, 0x02220307, 0x251c30be,
  0x040815a4, 0x1d2701ad, 0x292719be, 0x29270621,
  // [4d10]
  0x29270622, 0x01150409, 0x272906be, 0x08041655,
  0x16152712, 0x292b1412, 0x05013f12, 0x22002914,
  0x100b40a4, 0x292706cf, 0x1d27296f, 0x2b0f0d13,
  0x121d4010, 0x431f4512, 0x273f0414, 0x1d0f17a4,
  // [4d20]
  0x380f0409, 0x43401d02, 0x06001809, 0x170d0121,
  0x060419ad, 0x1f0f1760, 0x0b000236, 0x0f451208,
  0x05010820, 0x22001d02, 0x03001514, 0x080b1407,
  0x08000411, 0x170b0402, 0x020b1f22, 0x192101ad,
  // [4d30]
  0x080414a4, 0x0f0117ad, 0x06190812, 0x22000409,
  0x0f0d1722, 0x0b0619ac, 0x02060b55, 0x031716a4,
  0x041903bb, 0x14001007, 0x301c2514, 0x14060ba4,
  0x40003f13, 0x2b0d0f12, 0x0f0d2113, 0x08002207,
  // [4d40]
  0x160f0d6f, 0x0d0819ac, 0x210d0f6f, 0x0d381921,
  0x40451560, 0x08002112, 0x10041912, 0x084301ac,
  0x380408ad, 0x120c1902, 0x27452912, 0x1c230ead,
  0x18001921, 0x27291914, 0x01192755, 0x041914af,
  // [4d50]
  0x22102109, 0x03101407, 0x19401da4, 0x101618a4,
  0x08290209, 0x04432207, 0x17120dad, 0x16001421,
  0x01270607, 0x02011908, 0x45050109, 0x0f0d05ad,
  0x2b170baf, 0x0d000809, 0x29082b60, 0x1d4540ad,
  // [4d60]
  0x01380507, 0x1c0e1ebe, 0x01080511, 0x010b29a4,
  0x14181f12, 0x21010412, 0x21001213, 0x2b180412,
  0x14404512, 0x30251e14, 0x04022bac, 0x1f001909,
  0x1d002908, 0x12454011, 0x030106bb, 0x19020408,
  // [4d70]
  0x060d1521, 0x29223f12, 0x45121fac, 0x0c001522,
  0x08001f11, 0x3f290421, 0x14451255, 0x101727bc,
  0x050106bc, 0x06000c21, 0x06002223, 0x06292ba4,
  0x29011fbc, 0x060b2260, 0x172729be, 0x19031607,
  // [4d80]
  0x12432207, 0x12001920, 0x041410af, 0x02001413,
  0x04120112, 0x40002213, 0x190b16be, 0x1d0c01af,
  0x0b192712, 0x191629ad, 0x21060309, 0x010f05a4,
  0x12011760, 0x06102212, 0x100b19ce, 0x010f0820,
  // [4d90]
  0x06001023, 0x0e1e1cbb, 0x40120c55, 0x12142208,
  0x034301af, 0x662729af, 0x300e1e02, 0x02661012,
  0x10180655, 0x27173809, 0x170306a4, 0x27294014,
  0x401d04ad, 0x27001d08, 0x050b1907, 0x0c061012,
  // [4da0]
  0x1e233055, 0x04190807, 0x03011f12, 0x0d0445af,
  0x010519af, 0x40000213, 0x04000d21, 0x03661021,
  0x03001f13, 0x30003709, 0x10001620, 0x2b000c11,
  0x16452212, 0x220d0155, 0x01001021, 0x14100c08,
  // [4db0]
  0x2b003807, 0x14000c09, 0x010d12a4, 0x030b1607,
  0x231e2522, 0x0e253009, 0x45000f08, 0x066604a4,
  0x06050c09, 0x16451908, 0x38170daf, 0x22052bbb,
  0x0d270208, 0x05013807, 0x190866af, 0x251c1eac,
  // [4dc0]
  0x2b145112, 0x010f2155, 0x301c0e22, 0x381d0112,
  0x43010307, 0x03000209, 0x18106660, 0x080603af,
  0x05010f09, 0x30250ea4, 0x0c1840a4, 0x010f2209,
  0x02001612, 0x451201af, 0x0c0604ac, 0x053f0fbc,
  // [4dd0]
  0x100614bc, 0x120c0134, 0x1d1610ad, 0x151627af,
  0x45120c14, 0x0b006621, 0x0d020107, 0x010603ad,
  0x2b000821, 0x1e0e25ac, 0x16660faf, 0x150c04af,
  0x08050f21, 0x0b140107, 0x03661560, 0x43192907,
  // [4de0]
  0x10036612, 0x1d003807, 0x14041f13, 0x38431709,
  0x0b066608, 0x01660507, 0x17003f20, 0x19000b09,
  0x010d06af, 0x06080107, 0x1d080f12, 0x1d173faf,
  0x08051713, 0x0d003f21, 0x01660508, 0x060b01a4,
  // [4df0]
  0x15031612, 0x431f1421, 0x450c1907, 0x05660812,
  0x08051909, 0x0d1508af, 0x403f0509, 0x45140cad,
  0x402245a4, 0x1c003035, 0x0d0f0822, 0x080527af,
  0x1f124560, 0x15163860, 0x451243af, 0x150d0f12,
  // [4e00]
  0x0d012907, 0x1d400c22, 0x1c0e2520, 0x0d030812,
  0x454312af, 0x16041911, 0x0d010cac, 0x16080412,
  0x17140d08, 0x15401da4, 0x03161daf, 0x0d030807,
  0x100f386f, 0x03012bbc, 0x291d1008, 0x0f001d13,
  // [4e10]
  0x080f10be, 0x27291713, 0x43380111, 0x38100212,
  0x121d40be, 0x380f1060, 0x660b01a4, 0x660b0214,
  0x0f0d1409, 0x05001011, 0x0f1d1021, 0x292710af,
  0x050c0f07, 0x430103a4, 0x05381021, 0x0f051012,
  // [4e20]
  0x1d401407, 0x0c000f08, 0x43142712, 0x0f0d1fa4,
  0x15002209, 0x0d0c0112, 0x27023808, 0x1d102208,
  0x1d4017bc, 0x0c0106ad, 0x060d0409, 0x03002708,
  0x02100807, 0x431d1811, 0x011f2955, 0x012102ad,
  // [4e30]
  0x19212213, 0x161405a4, 0x40101907, 0x17121d07,
  0x1d12406b, 0x45121dbb, 0x100b2221, 0x036610af,
  0x10180212, 0x301c2509, 0x23302521, 0x05014511,
  0x01053821, 0x0c141612, 0x18162213, 0x18001420,
  // [4e40]
  0x173f1920, 0x18142112, 0x04145112, 0x2b001422,
  0x1f001434, 0x04140112, 0x17272221, 0x14030d21,
  0x102b01ac, 0x45030611, 0x04161413, 0x04190621,
  0x0d190414, 0x23001c23, 0x29006611, 0x38002111,
  // [4e50]
  0x01001909, 0x1e001c33, 0x021d6612, 0x04050f13,
  0x29010c12, 0x21151609, 0x181612af, 0x0c002120,
  0x66003f20, 0x00002415, 0x380103a4, 0x143f0812,
  0x45060107, 0x06010509, 0x0f053821, 0x19140b60,
  // [4e60]
  0x221401a4, 0x101d18af, 0x0c000414, 0x0b040c60,
  0x080d1f21, 0x1d0b1012, 0x43190112, 0x25231ead,
  0x19220307, 0x10001602, 0x66081921, 0x011008ac,
  0x10063f13, 0x0f001612, 0x05041612, 0x036651af,
  // [4e70]
  0x1d101907, 0x060b1013, 0x100419af, 0x14002b23,
  0x18061912, 0x01400808, 0x1d401607, 0x030406ad,
  0x08063fad, 0x180c16ac, 0x12104009, 0x04001d07,
  0x101d2208, 0x03270108, 0x0d2b05bc, 0x17190809,
  // [4e80]
  0x1d171960, 0x08191721, 0x05171912, 0x05083fa4,
  0x25302321, 0x19001734, 0x03180407, 0x21001913,
  0x0c080f14, 0x380f0109, 0x060c0812, 0x06016607,
  0x25003021, 0x1c302320, 0x220219ad, 0x0b041807,
  // [4e90]
  0x041d4055, 0x04662212, 0x271915af, 0x02061508,
  0x06121faf, 0x010814af, 0x18101412, 0x66272bbb,
  0x161d2212, 0x0f292b08, 0x020419bb, 0x05011907,
  0x0d190413, 0x08011907, 0x080519ad, 0x03062255,
  // [4ea0]
  0x0b1901af, 0x01190420, 0x04161522, 0x0f170513,
  0x2b002121, 0x03170512, 0x01214060, 0x08000120,
  0x101d01a4, 0x40061daf, 0x0c1d4008, 0x0e251c6d,
  0x19162111, 0x3f2204be, 0x2716216f, 0x30230ece,
  // [4eb0]
  0x02003812, 0x29100b13, 0x0f001512, 0x012b0312,
  0x194529a4, 0x141040af, 0x02060baf, 0x45401913,
  0x29194008, 0x0e252360, 0x0f401d12, 0x10002b14,
  0x043f1921, 0x140b0207, 0x3f042909, 0x221619af,
  // [4ec0]
  0x1f000623, 0x051f1721, 0x080d0f22, 0x080f0d14,
  0x06081d08, 0x29272bad, 0x1f001712, 0x192701af,
  0x0d211212, 0x45160612, 0x401d3f09, 0x101d19ad,
  0x0b100223, 0x182b0612, 0x3f2901a4, 0x401d0208,
  // [4ed0]
  0x3f0c0121, 0x400b10bc, 0x180805ad, 0x180c2112,
  0x0b051013, 0x66020b09, 0x190527a4, 0x0d045112,
  0x0f002114, 0x231c2511, 0x27104013, 0x15160fac,
  0x1d000f13, 0x17272909, 0x02080107, 0x66000f13,
  // [4ee0]
  0x0827296f, 0x060b0412, 0x08380c12, 0x03000d07,
  0x030c2b08, 0x0b102bac, 0x06024560, 0x192729bc,
  0x3f160f21, 0x180f2260, 0x661d4060, 0x663f2760,
  0x0d0f0813, 0x29013f12, 0x01060d08, 0x22080d11,
  // [4ef0]
  0x19012b07, 0x38140fac, 0x01000c20, 0x43010f08,
  0x191002a4, 0x010c0313, 0x21000512, 0x0d0f1fa4,
  0x02060102, 0x0b140809, 0x1d401623, 0x182b0420,
  0x171d406f, 0x05171da4, 0x251c1e11, 0x19051dbe,
  // [4f00]
  0x081d4020, 0x220f2b12, 0x29001621, 0x66401d60,
  0x401d18af, 0x0c000d10, 0x0f404512, 0x1d0f0caf,
  0x383f1212, 0x1d294020, 0x08010caf, 0x0f020112,
  0x12160c12, 0x451427ac, 0x190d2112, 0x1f1d4060,
  // [4f10]
  0x171d1907, 0x0f4512be, 0x660827a4, 0x1f004322,
  0x01050caf, 0x010b0220, 0x0b001d11, 0x12042260,
  0x061219bb, 0x180602af, 0x0f0d0509, 0x014012af,
  0x12001f08, 0x221d3809, 0x12184013, 0x661f0409,
  // [4f20]
  0x2530236f, 0x29043faf, 0x150116ac, 0x29002711,
  0x120f4312, 0x18451208, 0x020618ad, 0x40021d13,
  0x01002211, 0x08004509, 0x15292709, 0x66061f09,
  0x27103f13, 0x03186614, 0x14035112, 0x1d1951af,
  // [4f30]
  0x45181faf, 0x2b042209, 0x160466a4, 0x29220412,
  0x0f3818ac, 0x660b19af, 0x1d2927a4, 0x0f001209,
  0x1d0619af, 0x1e231c12, 0x1d0f0412, 0x06041920,
  0x0c041213, 0x0c010607, 0x19001d22, 0x02101912,
  // [4f40]
  0x10001921, 0x1d000420, 0x1d000511, 0x031912af,
  0x1e253023, 0x40000511, 0x38001721, 0x38102707,
  0x12451f08, 0x15030baf, 0x04031509, 0x082b01ac,
  0x38060107, 0x01002b21, 0x22040baf, 0x05120134,
  // [4f50]
  0x40002114, 0x450d0107, 0x080501ac, 0x43166607,
  0x10031507, 0x181245bb, 0x06012bbb, 0x12001412,
  0x270104bc, 0x15010312, 0x043f1914, 0x08000f13,
  0x18124521, 0x0c1d2955, 0x16121dbb, 0x033801af,
  // [4f60]
  0x451218bb, 0x4029276f, 0x1d3f1921, 0x040129ad,
  0x272b0109, 0x0b031921, 0x40124507, 0x010f03a4,
  0x2b000309, 0x03000821, 0x0e1e1c20, 0x05381660,
  0x19040c08, 0x0b191007, 0x1d191709, 0x2b060d08,
  // [4f70]
  0x40171921, 0x07005c30, 0x0c3805a4, 0x06180bad,
  0x66001709, 0x19291408, 0x401d18a4, 0x1f152160,
  0x120f0d07, 0x12000d13, 0x1d2238a4, 0x12003f11,
  0x45001512, 0x14121814, 0x05171207, 0x12000312,
  // [4f80]
  0x16030609, 0x17001212, 0x060121bb, 0x01226609,
  0x0c061a12, 0x66001613, 0x0c2b0409, 0x450d66be,
  0x1d1545af, 0x0d2b38be, 0x211614bc, 0x142b3f21,
  0x1d1629af, 0x17162baf, 0x1f221d21, 0x151d1212,
  // [4f90]
  0x27292260, 0x08660112, 0x19140c10, 0x3f0c29af,
  0x29151d08, 0x190621af, 0x18192109, 0x0b0619a4,
  0x0f2b3821, 0x2b041913, 0x03011907, 0x182b08be,
  0x250e1cbc, 0x450d03af, 0x163f10bc, 0x1d272908,
  // [4fa0]
  0x03063f21, 0x03160111, 0x01046609, 0x1d292713,
  0x020b12af, 0x10000f12, 0x0b100c21, 0x03401d13,
  0x04000510, 0x084540ad, 0x170c0411, 0x020b19bb,
  0x21120112, 0x08012b12, 0x06022bad, 0x220410be,
  // [4fb0]
  0x150d0611, 0x2b0121ac, 0x12272911, 0x0b15166f,
  0x27002b13, 0x161d19bc, 0x03056622, 0x2b120f55,
  0x1f005113, 0x05222ba4, 0x1c2330ac, 0x01272b09,
  0x0b661009, 0x10020107, 0x0d1d406f, 0x010b0612,
  // [4fc0]
  0x03010fad, 0x153f19be, 0x041819bc, 0x0c041907,
  0x14213f11, 0x12451912, 0x19160407, 0x2b663f08,
  0x17083809, 0x40271d12, 0x010c1faf, 0x03404512,
  0x38430402, 0x15211821, 0x0b0c2bad, 0x2b000408,
  // [4fd0]
  0x10400ba4, 0x14060309, 0x0b0315ad, 0x124045a4,
  0x03401d21, 0x221d3f12, 0x080538a4, 0x40171212,
  0x18451220, 0x021018bc, 0x04002b22, 0x05173808,
  0x121445ac, 0x45000f09, 0x0f002907, 0x1d0c1912,
  // [4fe0]
  0x012b0408, 0x042919ad, 0x140f4512, 0x38102907,
  0x220f38a4, 0x013808ac, 0x10211612, 0x03011709,
  0x380d1713, 0x0b020309, 0x38020121, 0x03386607,
  0x3f1f1921, 0x1f0521af, 0x05191f07, 0x40161dbe,
  // [4ff0]
  0x2b222121, 0x38001f21, 0x012119be, 0x060105bc,
  0x011f3822, 0x220c2707, 0x05431f12, 0x43000120,
  0x04013f11, 0x38002b20, 0x1f001614, 0x21222912,
  0x16000608, 0x02101721, 0x3f162121, 0x01000814,

  // [5000]
  0x16215112, 0x222b21af, 0x66000d13, 0x19000b34,
  0x182127af, 0x15011fad, 0x27142212, 0x21272209,
  0x0b660c12, 0x16002121, 0x19042708, 0x1d0112ac,
  0x0c182212, 0x29223f13, 0x27212221, 0x22060808,
  // [5010]
  0x0b226607, 0x12020b12, 0x0d140f60, 0x06170112,
  0x401701af, 0x121418bc, 0x06031508, 0x40170112,
  0x14000421, 0x01660312, 0x0b102b07, 0x0d000c12,
  0x040c2202, 0x0c000402, 0x040d1407, 0x043f19bc,
  // [5020]
  0x16124509, 0x0e2325bc, 0x012b66ad, 0x452215bb,
  0x22382b07, 0x660206be, 0x0f210d14, 0x12031909,
  0x0d452907, 0x1f272920, 0x29042113, 0x0d0f2113,
  0x272910af, 0x231c1e55, 0x0f270d09, 0x010f0512,
  // [5030]
  0x252330af, 0x05292721, 0x17000f07, 0x290f0d13,
  0x27660baf, 0x120d0f20, 0x18222709, 0x301e0ead,
  0x190406a4, 0x0f0c2709, 0x29211211, 0x30230e60,
  0x0d001907, 0x1d0117af, 0x1c300e11, 0x22171914,
  // [5040]
  0x010519a4, 0x01192107, 0x043f2112, 0x213f01af,
  0x450c1512, 0x193817bb, 0x193f1721, 0x17160112,
  0x03661714, 0x45060c11, 0x66031920, 0x401d17bc,
  0x22171921, 0x17192214, 0x661d1712, 0x401d1211,
  // [5050]
  0x66191712, 0x10040f11, 0x10041422, 0x0b100612,
  0x08382b12, 0x66191721, 0x17001922, 0x05002120,
  0x27011721, 0x2b270d12, 0x18000214, 0x10290b60,
  0x0f101409, 0x1d1838a4, 0x66050109, 0x17000d20,
  // [5060]
  0x0d450f12, 0x05000312, 0x27190d12, 0x100b04a4,
  0x43271d13, 0x030266a4, 0x05010f14, 0x0f1845a4,
  0x12001622, 0x3f004014, 0x04226607, 0x16000613,
  0x08192212, 0x02406614, 0x22270112, 0x02086612,
  // [5070]
  0x220b0212, 0x661022a4, 0x22006614, 0x19270212,
  0x05061602, 0x18220cac, 0x3f000b21, 0x661f3813,
  0x010d1712, 0x0d081709, 0x06031012, 0x29180112,
  0x06170107, 0x04001411, 0x451d1223, 0x17151807,
  // [5080]
  0x380106af, 0x15013860, 0x080b17ad, 0x05001d08,
  0x100b66af, 0x21292721, 0x0d0f38af, 0x17080108,
  0x02000133, 0x10292711, 0x050b0212, 0x45000308,
  0x011705bc, 0x270f3821, 0x0b050111, 0x290c1712,
  // [5090]
  0x04012712, 0x03066635, 0x0b271612, 0x3f1601af,
  0x40181755, 0x0b060255, 0x01272914, 0x45040521,
  0x01451521, 0x22143fac, 0x080301ad, 0x02060b07,
  0x04010607, 0x273f2912, 0x27211922, 0x2b3805af,
  // [50a0]
  0x08001507, 0x08002107, 0x292706bb, 0x1f000611,
  0x050f0d21, 0x0105226f, 0x0e251c23, 0x03120109,
  0x0f000533, 0x38001411, 0x19660422, 0x171d4007,
  0x0d081609, 0x01052bad, 0x08004513, 0x38011f12,
  // [50b0]
  0x220d0ba4, 0x66011f08, 0x3f012b21, 0x384516ad,
  0x0d000611, 0x451501a4, 0x0f0d29af, 0x01174007,
  0x14380d14, 0x1f210112, 0x0d170f09, 0x2b000522,
  0x66060c12, 0x301e2322, 0x0f1738be, 0x0f002b07,
  // [50c0]
  0x0f082bac, 0x17015112, 0x080f45ad, 0x16182209,
  0x38190608, 0x10272913, 0x0d451012, 0x061918ad,
  0x10000b20, 0x38061007, 0x40191d09, 0x16190608,
  0x0b000c12, 0x181d40be, 0x191d40be, 0x22450608,
  // [50d0]
  0x19042207, 0x10061608, 0x29190460, 0x12172708,
  0x1f3f1aa4, 0x06121d07, 0x17000508, 0x21140112,
  0x01000509, 0x2b3f1f13, 0x01270411, 0x03000514,
  0x0f1f2baf, 0x04011207, 0x17380d13, 0x0d292708,
  // [50e0]
  0x38004011, 0x29001613, 0x011404af, 0x290b27be,
  0x380801a4, 0x15004007, 0x062b6608, 0x0d430f07,
  0x06041808, 0x0f450813, 0x080f0308, 0x0d401d14,
  0x45161d09, 0x2b124522, 0x0f400d13, 0x401d0f21,
  // [50f0]
  0x12450302, 0x40220f20, 0x170f3809, 0x0b020411,
  0x2b001214, 0x661903af, 0x1d080f6f, 0x05270c12,
  0x38010507, 0x291d2112, 0x08003802, 0x25301eaf,
  0x08170fbe, 0x06401008, 0x40162213, 0x04194014,
  // [5100]
  0x08141807, 0x270c4060, 0x1d000821, 0x04292721,
  0x40224512, 0x1d220109, 0x16194012, 0x40082213,
  0x16402220, 0x19006609, 0x170108af, 0x27002935,
  0x10272933, 0x30001c23, 0x10272920, 0x0f053807,
  // [5110]
  0x0c172b12, 0x27292112, 0x02102209, 0x0f040d12,
  0x06152907, 0x01172709, 0x38450ca4, 0x661016bb,
  0x010f38ad, 0x08052bbc, 0x014512af, 0x160329a4,
  0x06101908, 0x10041f13, 0x18081912, 0x271d01a4,
  // [5120]
  0x1e003714, 0x1f661aaf, 0x45160407, 0x160c1d07,
  0x050806bc, 0x082701af, 0x080119bb, 0x0d000612,
  0x04210112, 0x12436609, 0x251c3055, 0x25233060,
  0x27014312, 0x66031909, 0x231e0e22, 0x06010560,
  // [5130]
  0x03662221, 0x191516ce, 0x1d050307, 0x17051fa4,
  0x212701af, 0x03660623, 0x400c1221, 0x19001633,
  0x014306ad, 0x1c231e09, 0x12271912, 0x212b1d21,
  0x1d012b12, 0x661d2bbb, 0x43001920, 0x402b1dad,
  // [5140]
  0x30230e20, 0x1d161511, 0x2b400221, 0x1d293f12,
  0x01081913, 0x27152912, 0x170819ad, 0x401008ad,
  0x3f270821, 0x060b0209, 0x05170814, 0x030205ad,
  0x02080b12, 0x17050821, 0x1f001735, 0x01141f13,
  // [5150]
  0x27100411, 0x380f1f12, 0x06020b09, 0x1f001613,
  0x0f004307, 0x0d0308a4, 0x14004307, 0x12003808,
  0x1e1c2520, 0x05000809, 0x43193fac, 0x161d406f,
  0x0c2b0821, 0x02104512, 0x0f000821, 0x0c1d4020,
  // [5160]
  0x0b661921, 0x01000d11, 0x190d1011, 0x160c0420,
  0x19104512, 0x10020608, 0x162b0cbe, 0x30002523,
  0x15000607, 0x020b1a12, 0x031f6655, 0x150c4508,
  0x273f2914, 0x19061007, 0x401d3f21, 0x01432b07,
  // [5170]
  0x02000f12, 0x1d401707, 0x0c3f40be, 0x141f12af,
  0x171f0111, 0x17001807, 0x1f0201af, 0x080127a4,
  0x01120309, 0x0e1e256f, 0x060c0108, 0x05002911,
  0x06002113, 0x1c0e1e11, 0x03451211, 0x0d004007,
  // [5180]
  0x0f060112, 0x05011713, 0x43012121, 0x43002107,
  0x012729ad, 0x2b210612, 0x2b0b1f12, 0x08162baf,
  0x660121af, 0x08002b22, 0x0d1d0821, 0x012106af,
  0x066640af, 0x29000313, 0x162b2712, 0x2b0f16be,
  // [5190]
  0x290518af, 0x060b1008, 0x100619ad, 0x01171d07,
  0x03401d08, 0x21401d12, 0x22041408, 0x1d2b1007,
  0x38153f21, 0x04211413, 0x0d002b12, 0x151d40be,
  0x2b0c0112, 0x0b1466ad, 0x04193807, 0x0c290812,
  // [51a0]
  0x05001013, 0x05012bad, 0x1d002b22, 0x021d0b12,
  0x40121813, 0x301e0e02, 0x663f1820, 0x251e3713,
  0x3f030621, 0x38100421, 0x0f000122, 0x1d121812,
  0x08001811, 0x05042912, 0x16401922, 0x0b041922,
  // [51b0]
  0x40011713, 0x061f51af, 0x171d0112, 0x2b000611,
  0x08011722, 0x10661812, 0x011708af, 0x0b6628af,
  0x1f000620, 0x021806af, 0x45190112, 0x02062113,
  0x08171613, 0x40170114, 0x12401dbc, 0x04030107,
  // [51c0]
  0x080f12af, 0x0b0203a4, 0x081d0ca4, 0x2b216613,
  0x0b661612, 0x66160212, 0x2b006621, 0x080d18bb,
  0x086602ad, 0x15003f11, 0x290f0d09, 0x08001f07,
  0x05001802, 0x401d0308, 0x06031402, 0x21292212,
  // [51d0]
  0x221451af, 0x1d001014, 0x03401d6f, 0x03020b23,
  0x196604ad, 0x01060314, 0x02180b22, 0x012b2112,
  0x170302be, 0x08041920, 0x451851a4, 0x06401212,
  0x17380214, 0x1f001221, 0x04061712, 0x010d0512,
  // [51e0]
  0x0d0f0607, 0x17053821, 0x0c211611, 0x18124009,
  0x160b0213, 0x040f1907, 0x12016607, 0x18004313,
  0x06660314, 0x05004513, 0x100c0baf, 0x1d122707,
  0x05000408, 0x453f0f22, 0x38010607, 0x10171912,
  // [51f0]
  0x12401d22, 0x14060112, 0x27060409, 0x3f662bbe,
  0x02000433, 0x1d400507, 0x382b14be, 0x0d4366a4,
  0x01021907, 0x14002712, 0x21030108, 0x66160109,
  0x04032212, 0x10051409, 0x02000607, 0x02220111,
  // [5200]
  0x020305af, 0x1e302521, 0x01031911, 0x08001621,
  0x10211d08, 0x450b0c12, 0x08181d09, 0x05001414,
  0x08000f21, 0x27010c12, 0x230e2555, 0x04180baf,
  0x0d000820, 0x0d011907, 0x03002113, 0x05031807,
  // [5210]
  0x17040107, 0x2b081712, 0x273f0460, 0x044016be,
  0x03160407, 0x380f1f11, 0x3f170121, 0x5c000711,
  0x17160812, 0x0c3f22ce, 0x14102221, 0x38100f12,
  0x2b000212, 0x14220421, 0x38002221, 0x192b38ad,
  // [5220]
  0x12001821, 0x2b0c0108, 0x10002713, 0x060440a4,
  0x01000602, 0x010b29ad, 0x02211609, 0x17000d09,
  0x15212212, 0x02001009, 0x031601a4, 0x30251ebe,
  0x150f01a4, 0x120f0d08, 0x29014321, 0x27162912,
  // [5230]
  0x190610a4, 0x2b036621, 0x38006613, 0x6605386f,
  0x0c002108, 0x400d4313, 0x380d1aaf, 0x16006612,
  0x19002b02, 0x0c0127a4, 0x17000623, 0x06002209,
  0x27052913, 0x430c0807, 0x08010308, 0x0f0b0107,
  // [5240]
  0x01270b09, 0x02080109, 0x0b180108, 0x40002209,
  0x29270baf, 0x100f0307, 0x060b1421, 0x06006609,
  0x191422a4, 0x02002b20, 0x14001f09, 0x12000c1d,
  0x1d3f4012, 0x06191060, 0x12144507, 0x181701a4,
  // [5250]
  0x1f053f12, 0x431d0112, 0x220401af, 0x011608ac,
  0x38004009, 0x27293fbc, 0x38402712, 0x052b1411,
  0x0f1d3f12, 0x0f380507, 0x0f010212, 0x30252314,
  0x0d170307, 0x3f0f2712, 0x230e2511, 0x400c18a4,
  // [5260]
  0x0f401dad, 0x22270412, 0x04052109, 0x03066609,
  0x450c1214, 0x0c124511, 0x29063f21, 0x17011812,
  0x1d191812, 0x082b0b12, 0x021410a4, 0x0c220513,
  0x14150c12, 0x16121d5e, 0x0d0c1207, 0x40001d32,
  // [5270]
  0x062202bc, 0x38141012, 0x0d0f3822, 0x0d1d0113,
  0x0d001411, 0x020b0da4, 0x38002b14, 0x05380609,
  0x10143809, 0x03002711, 0x0d381421, 0x66052b13,
  0x38000c11, 0x18021060, 0x2b001707, 0x10004507,
  // [5280]
  0x104003ad, 0x10021d07, 0x030d0109, 0x060c1909,
  0x101519af, 0x16023f11, 0x0b161512, 0x0e1c2314,
  0x0d0f1209, 0x0b1410af, 0x0b1d19ad, 0x0d452207,
  0x01054007, 0x250e3060, 0x12451d14, 0x19036660,
  // [5290]
  0x22020f09, 0x02451212, 0x1d2921a4, 0x450501a4,
  0x0c1d0112, 0x0c400413, 0x38006612, 0x451f1212,
  0x030b0609, 0x1d0c1812, 0x21010baf, 0x1d030112,
  0x0b432b07, 0x380d0cac, 0x66000d14, 0x1f001212,
  // [52a0]
  0x0f3851af, 0x451412af, 0x16296611, 0x3845126f,
  0x08660612, 0x401d0c21, 0x19000433, 0x1c252320,
  0x10001614, 0x16012baf, 0x161d4560, 0x380d5112,
  0x16001709, 0x0e301c55, 0x03001d08, 0x081003ad,
  // [52b0]
  0x2b0210af, 0x1c252302, 0x0f2b1709, 0x223817af,
  0x032b1455, 0x032b0209, 0x21011909, 0x0f0d17be,
  0x38101721, 0x38175112, 0x2b001f11, 0x0f381912,
  0x12101da4, 0x40181912, 0x273f16af, 0x191f0512,
  // [52c0]
  0x051801a4, 0x27002b11, 0x2b000d07, 0x01060d12,
  0x15160613, 0x0d150f13, 0x052b1f13, 0x164012af,
  0x1f003814, 0x1d4043be, 0x1f210509, 0x2b010809,
  0x01430512, 0x172b4313, 0x1c302311, 0x0d1f0460,
  // [52d0]
  0x0f451211, 0x01051f11, 0x01052b14, 0x10190109,
  0x21272bbb, 0x161512af, 0x2b171611, 0x170c04a4,
  0x18020455, 0x18190f08, 0x081604a4, 0x22000609,
  0x140422bc, 0x14212260, 0x271f29bb, 0x0f1022af,
  // [52e0]
  0x22042ba4, 0x124522af, 0x192214ad, 0x03001212,
  0x22061407, 0x210419be, 0x06142211, 0x04141922,
  0x1c0e2511, 0x06100812, 0x100612af, 0x45124002,
  0x22020bad, 0x04181921, 0x03211908, 0x01001812,
  // [52f0]
  0x021d0408, 0x080f1909, 0x222b01a4, 0x0b2b01af,
  0x1404196f, 0x10190421, 0x1d001921, 0x0d381608,
  0x1d001409, 0x1d010407, 0x05011914, 0x66430108,
  0x43012b07, 0x00002403, 0x3f002135, 0x292704be,
  // [5300]
  0x04272922, 0x191612a4, 0x0b020308, 0x27042920,
  0x03180255, 0x19661f60, 0x01432bad, 0x03292760,
  0x0e2325ac, 0x03002911, 0x66001513, 0x22061807,
  0x06180312, 0x40000612, 0x0b140608, 0x100b1408,
  // [5310]
  0x0f142212, 0x011d0612, 0x18451dad, 0x12451407,
  0x1d120311, 0x120c18ac, 0x0f083f21, 0x060218af,
  0x1d0c12a4, 0x021501a4, 0x12451009, 0x22050107,
  0x29190109, 0x1f0f0809, 0x0b021807, 0x45271809,
  // [5320]
  0x19001821, 0x0245126f, 0x19001d14, 0x021d40ac,
  0x21080fbc, 0x080f1f21, 0x251c3013, 0x050d1708,
  0x18100b20, 0x19000207, 0x18060cad, 0x10120b12,
  0x0d1f0f55, 0x0b1d4020, 0x0c292709, 0x380f1fbb,
  // [5330]
  0x1f2112af, 0x0f0838be, 0x1c250e13, 0x020501ad,
  0x101427af, 0x21451209, 0x03101212, 0x120c2b11,
  0x1d1529a4, 0x083801a4, 0x0f0601a4, 0x27141060,
  0x272918bc, 0x020618a4, 0x251c2320, 0x251e30ad,
  // [5340]
  0x212b6660, 0x43124507, 0x30252309, 0x18002b20,
  0x0f0512af, 0x03382b12, 0x40012b07, 0x221d4060,
  0x010521a4, 0x12001f13, 0x17000d11, 0x02180607,
  0x436601a4, 0x38451213, 0x19660108, 0x100b1411,
  // [5350]
  0x17002b20, 0x430d2712, 0x170538a4, 0x06430107,
  0x172b2712, 0x10012bad, 0x0c2127af, 0x102719af,
  0x43001736, 0x050d3812, 0x380108a4, 0x21000621,
  0x1d220ca4, 0x3f160c09, 0x0c401da4, 0x0d000814,
  // [5360]
  0x04000508, 0x16030413, 0x0f170207, 0x3f001f13,
  0x380f1709, 0x1c1e23ad, 0x400c29ac, 0x150d0809,
  0x100b1912, 0x19100208, 0x042719af, 0x080f2212,
  0x18380612, 0x03100509, 0x10046612, 0x01061d07,
  // [5370]
  0x400f1d07, 0x40001008, 0x0c401614, 0x0c0b12a4,
  0x0c4016cf, 0x060501ad, 0x012b0c07, 0x270429a4,
  0x450c4013, 0x1d0612ac, 0x400c2121, 0x45190caf,
  0x164501a4, 0x12150cad, 0x040f1509, 0x17040f14,
  // [5380]
  0x40043f12, 0x010c38af, 0x451205a4, 0x21000f13,
  0x3f000423, 0x04000d22, 0x12010cac, 0x2b0501a4,
  0x16660360, 0x1f660321, 0x190108a4, 0x27291708,
  0x19400409, 0x19000102, 0x0c451221, 0x120c0108,
  // [5390]
  0x12081da4, 0x04190509, 0x012b3811, 0x040d0f08,
  0x041d0809, 0x040d0f60, 0x01052155, 0x0f0d3f34,
  0x0c0806ac, 0x020318a4, 0x1e1c23ad, 0x0b041f20,
  0x0b001d08, 0x161d0fac, 0x080d0fbe, 0x0f002b14,
  // [53a0]
  0x0f270109, 0x251e1cbc, 0x1f010821, 0x16121daf,
  0x1e251c10, 0x66001508, 0x38000f02, 0x010818a4,
  0x03661d08, 0x0d011808, 0x10000422, 0x1e0e1c20,
  0x03661213, 0x04000c12, 0x1f003f11, 0x0e232560,
  // [53b0]
  0x03001414, 0x1d160321, 0x19101812, 0x17020b13,
  0x0c452755, 0x0b003f11, 0x27001409, 0x100118ad,
  0x22020514, 0x45401d14, 0x40451d60, 0x101d66bc,
  0x40451d21, 0x101d4011, 0x06191012, 0x0f1701a4,
  // [53c0]
  0x10031812, 0x66050621, 0x1e0e2322, 0x12451607,
  0x17001402, 0x14272960, 0x12162b55, 0x22001922,
  0x04051912, 0x18662212, 0x0b0127a4, 0x1e0e2513,
  0x06191fa4, 0x03060b07, 0x14001911, 0x0f001908,
  // [53d0]
  0x03061507, 0x020c0b07, 0x06010355, 0x05210c09,
  0x29060109, 0x22001423, 0x0f004020, 0x38221421,
  0x40272920, 0x27222908, 0x0e301e60, 0x012b2207,
  0x450c2960, 0x181640ad, 0x15000508, 0x14222908,
  // [53e0]
  0x08450107, 0x45381808, 0x0f272911, 0x06221914,
  0x0d381907, 0x0d164512, 0x12404507, 0x250e23bb,
  0x401645ac, 0x1d004509, 0x15001f20, 0x06032214,
  0x16151daf, 0x0b140414, 0x06083f13, 0x0b080ca4,
  // [53f0]
  0x03192207, 0x272b4512, 0x010f2ba4, 0x660c2b13,
  0x400c1214, 0x03000c23, 0x02180c20, 0x2b451212,
  0x213f2212, 0x05010607, 0x222714ad, 0x08001402,
  0x45271821, 0x151627a4, 0x10142b21, 0x03172212,

  // [5400]
  0x08192707, 0x06000302, 0x45120c55, 0x10000d02,
  0x190b27af, 0x0d192212, 0x0d121907, 0x301e1c08,
  0x19152755, 0x15001408, 0x011d4307, 0x273f1dbc,
  0x180f0d09, 0x220f0d08, 0x080f0111, 0x06002911,
  // [5410]
  0x180614ac, 0x21001d14, 0x2b1f1421, 0x0d1f2baf,
  0x010b4012, 0x0b0601a4, 0x2b0d0b12, 0x0d001834,
  0x230e1cbc, 0x660302bb, 0x0b2701ad, 0x29271f21,
  0x38212712, 0x040f0d60, 0x170f0dbb, 0x0d004023,
  // [5420]
  0x01184507, 0x0f0d0109, 0x0b021507, 0x172922be,
  0x662921bb, 0x0d290108, 0x382b1913, 0x151d10ad,
  0x0b061013, 0x010d0855, 0x1f2b21bb, 0x400c0312,
  0x0b050221, 0x120c4509, 0x021d0512, 0x050c1907,
  // [5430]
  0x06021021, 0x08170f07, 0x1f430111, 0x0f211d12,
  0x12010507, 0x0d171fbb, 0x430f01a4, 0x01031fbc,
  0x10040612, 0x06270111, 0x16001012, 0x08170155,
  0x19011fbc, 0x02002211, 0x03196660, 0x0d080509,
  // [5440]
  0x1f041920, 0x210501af, 0x04100660, 0x38001508,
  0x102b6608, 0x27210113, 0x40003f33, 0x1e302512,
  0x04100b12, 0x400d0f09, 0x17431d07, 0x16040809,
  0x40121d09, 0x1d172707, 0x02100b14, 0x401206a4,
  // [5450]
  0x0f001602, 0x66160112, 0x66001013, 0x020151af,
  0x2b1022af, 0x2b220613, 0x10022b12, 0x011738ad,
  0x0f272913, 0x0c381dad, 0x122b4512, 0x16001f33,
  0x0c060212, 0x0c102b12, 0x40001411, 0x100f6612,
  // [5460]
  0x194003ad, 0x010f0d11, 0x380104af, 0x0b1d04ac,
  0x10401d60, 0x010c1955, 0x161804ad, 0x14181608,
  0x04141912, 0x0c000820, 0x040c1612, 0x020b1612,
  0x0c660314, 0x011d04ac, 0x21160c12, 0x151405a4,
  // [5470]
  0x05080cad, 0x0c450f12, 0x14451212, 0x0f031612,
  0x0b451660, 0x66081620, 0x06401708, 0x144512af,
  0x1c232555, 0x01192907, 0x18211212, 0x161d45af,
  0x15063f12, 0x01180f08, 0x066603a4, 0x061d6612,
  // [5480]
  0x10451dad, 0x0d000508, 0x05150412, 0x10036613,
  0x141d01a4, 0x66100313, 0x23301c22, 0x386605af,
  0x661f15bb, 0x660151af, 0x10141f12, 0x01020322,
  0x121805ad, 0x1d001008, 0x18450dad, 0x14000d07,
  // [5490]
  0x10030111, 0x031014a4, 0x0d080f55, 0x380f0d6f,
  0x03190107, 0x0d172ba4, 0x081921be, 0x40191d14,
  0x18000d21, 0x04271960, 0x45140dbb, 0x14000d11,
  0x272919bc, 0x01000821, 0x10191412, 0x03120112,
  // [54a0]
  0x010c0fac, 0x06002b33, 0x0f001722, 0x38000d35,
  0x03011607, 0x2b000d21, 0x010d2921, 0x38050f21,
  0x2b0119bb, 0x1d0815bb, 0x2b003f08, 0x060210af,
  0x18004510, 0x380608a4, 0x16151021, 0x45002708,
  // [54b0]
  0x38000602, 0x37003009, 0x05036607, 0x27170112,
  0x0d0f0514, 0x05184512, 0x2b001008, 0x0b0c0207,
  0x180f05af, 0x0d180509, 0x1d0129a4, 0x0b001421,
  0x01080412, 0x0d000521, 0x0f1922ac, 0x191604af,
  // [54c0]
  0x191d4021, 0x08002123, 0x142b21af, 0x45121aaf,
  0x302325a4, 0x04151612, 0x06012b12, 0x14010608,
  0x18000607, 0x04194060, 0x05430307, 0x1e300e12,
  0x19002109, 0x0f0c2107, 0x121d2912, 0x1e230e55,
  // [54d0]
  0x2b401daf, 0x2b161021, 0x010619a4, 0x16181921,
  0x020b19ad, 0x10030655, 0x12181da4, 0x66031908,
  0x0f010309, 0x140b0422, 0x01182bad, 0x06004512,
  0x01000614, 0x21001509, 0x101f15af, 0x151006a4,
  // [54e0]
  0x0b0212a4, 0x0b020302, 0x02190bad, 0x38001011,
  0x06000213, 0x0c001f11, 0x0d380fbe, 0x02061060,
  0x060d2111, 0x1d121008, 0x12452213, 0x0b010208,
  0x12404514, 0x03124514, 0x06221410, 0x45122b13,
  // [54f0]
  0x03001d11, 0x06221207, 0x451d12a4, 0x0b192207,
  0x45120b07, 0x190618a4, 0x03061d09, 0x020b0412,
  0x1d124511, 0x22082b07, 0x01211808, 0x270c1809,
  0x16003f34, 0x0f381dac, 0x01140b12, 0x0b021aaf,
  // [5500]
  0x0f001514, 0x151651af, 0x23301c14, 0x151602af,
  0x08000208, 0x184508a4, 0x04191f08, 0x0c381d13,
  0x08271612, 0x012b0c22, 0x08180312, 0x0c2b2113,
  0x66210c60, 0x190c04ac, 0x12454022, 0x272b0cbb,
  // [5510]
  0x0b001d13, 0x2b272908, 0x0f001920, 0x222b0da4,
  0x40664512, 0x0d162b21, 0x291901bc, 0x0f002b21,
  0x0f0d2b21, 0x16190860, 0x29002b21, 0x124516ad,
  0x030438ad, 0x45050608, 0x010d1fac, 0x031f2bbc,
  // [5520]
  0x04060209, 0x45002b07, 0x38030107, 0x052b0111,
  0x01020607, 0x210c2b12, 0x10290609, 0x19084512,
  0x01162b60, 0x05430102, 0x060b16ad, 0x01083802,
  0x18121912, 0x010f3f12, 0x22001d14, 0x01382b11,
  // [5530]
  0x38052b07, 0x1c250e02, 0x0b014007, 0x2b0838af,
  0x01192b02, 0x66030121, 0x0c190407, 0x161d19bb,
  0x3f141921, 0x101d19af, 0x3f001513, 0x27030c12,
  0x19210408, 0x22041007, 0x180d0f12, 0x06004020,
  // [5540]
  0x081916bb, 0x29213f21, 0x0f19046f, 0x01101808,
  0x02101421, 0x14001207, 0x1c1e306f, 0x171d0107,
  0x17060107, 0x01001612, 0x0c0f0307, 0x0c020b07,
  0x22001520, 0x15223f13, 0x012714bb, 0x010838bc,
  // [5550]
  0x15003f14, 0x163f1521, 0x0f0416af, 0x061001ac,
  0x40451513, 0x174519ad, 0x0f170307, 0x0c1519af,
  0x38050813, 0x17012207, 0x040b3807, 0x0d080412,
  0x19050155, 0x0d0f1414, 0x180f0d08, 0x1d1240a4,
  // [5560]
  0x0f401507, 0x22004013, 0x08000f08, 0x06044508,
  0x080119bc, 0x1d0d1907, 0x0d0b0112, 0x0c1d04a4,
  0x170b1009, 0x060c2107, 0x21102712, 0x45401dbc,
  0x18050807, 0x1d272922, 0x141904af, 0x06002912,
  // [5570]
  0x66010322, 0x0f3f0d21, 0x01141011, 0x10051955,
  0x381d1709, 0x10004007, 0x06100b09, 0x06000414,
  0x0c1927af, 0x1f004514, 0x210122ac, 0x103f5112,
  0x08000611, 0x01001020, 0x1c250ebe, 0x0d660314,
  // [5580]
  0x21040faf, 0x0d060209, 0x08212712, 0x0d052107,
  0x40060408, 0x27001011, 0x250e1ead, 0x011d2212,
  0x180c0109, 0x17052109, 0x27660313, 0x010421af,
  0x04191660, 0x17000409, 0x22661912, 0x0b1402ad,
  // [5590]
  0x15065112, 0x03003809, 0x38002208, 0x1d063802,
  0x19661521, 0x03100208, 0x1f180faf, 0x40161d14,
  0x0f012155, 0x172221ad, 0x15221dbb, 0x17082912,
  0x160d0f14, 0x1d402907, 0x0c1d2bbc, 0x01213f60,
  // [55a0]
  0x01430f09, 0x100b0212, 0x2b1806ad, 0x451d4009,
  0x080f01ad, 0x0c2104af, 0x27004513, 0x1d1217a4,
  0x03100112, 0x174045af, 0x171d4020, 0x381f0f6f,
  0x3f010f14, 0x042905bb, 0x0f270dbc, 0x190b1013,
  // [55b0]
  0x040d08af, 0x0c032bad, 0x18001014, 0x172101af,
  0x19402755, 0x06012112, 0x020b19a4, 0x16190113,
  0x01000b20, 0x10180b21, 0x0f0d1708, 0x051804ad,
  0x0b060412, 0x14042211, 0x0b020412, 0x0c151621,
  // [55c0]
  0x030d0f12, 0x21004512, 0x17064507, 0x0b020108,
  0x04380f13, 0x0d000c02, 0x191529af, 0x0e1e25ac,
  0x0b0204af, 0x013f2160, 0x08051f07, 0x06181909,
  0x19061609, 0x10191d12, 0x0d042907, 0x38402bad,
  // [55d0]
  0x0f083f12, 0x0d0129ac, 0x101927be, 0x2b660313,
  0x080405af, 0x14000413, 0x1e250ebe, 0x14080d60,
  0x03140b12, 0x1d000f09, 0x0f081709, 0x0f1608ac,
  0x0d051daf, 0x161d4021, 0x08050412, 0x38050408,
  // [55e0]
  0x0b1910a4, 0x0c180809, 0x08066607, 0x08210512,
  0x17104002, 0x18660308, 0x16143f20, 0x0f380d21,
  0x15161d11, 0x19183fad, 0x04194008, 0x14000314,
  0x190403ad, 0x301c1e07, 0x01400555, 0x3f0c2912,
  // [55f0]
  0x03080513, 0x08036620, 0x171d22a4, 0x03000b14,
  0x100f01af, 0x15211612, 0x01380508, 0x66170baf,
  0x16002b14, 0x1c000e36, 0x162219a4, 0x051519ac,
  0x1d2b12a4, 0x04061011, 0x041d16a4, 0x180801ac,
  // [5600]
  0x0c191855, 0x1d181620, 0x18271421, 0x04291812,
  0x12450411, 0x1612456f, 0x40180413, 0x01121607,
  0x40041412, 0x16001809, 0x060b66ad, 0x0603666f,
  0x401f6613, 0x02001213, 0x060d0812, 0x29180409,
  // [5610]
  0x17190b09, 0x02036614, 0x100b0612, 0x0b046607,
  0x08004011, 0x0f1f05af, 0x06040507, 0x05030609,
  0x1f000422, 0x432b66ad, 0x1d082108, 0x19272908,
  0x16150411, 0x270301a4, 0x0c151709, 0x044566ac,
  // [5620]
  0x0d1916ad, 0x03660611, 0x66065112, 0x27036660,
  0x270d0f13, 0x0d380fac, 0x1d270d12, 0x03042911,
  0x0f036620, 0x06221807, 0x100319a4, 0x0d030f07,
  0x1d020b11, 0x0f0c4507, 0x042219af, 0x010f0d14,
  // [5630]
  0x431f0811, 0x161804a4, 0x08380f55, 0x0b011f12,
  0x15000f09, 0x0c1d17a4, 0x3f001221, 0x181719af,
  0x27016612, 0x18190612, 0x66001408, 0x05270607,
  0x0645125e, 0x0c1d2112, 0x0b2b1011, 0x100b1412,
  // [5640]
  0x02191512, 0x0b140213, 0x22010313, 0x060b1412,
  0x141f4311, 0x2b060412, 0x16030112, 0x18003813,
  0x03003813, 0x0d000f1a, 0x03150b21, 0x01140baf,
  0x0b016608, 0x66190621, 0x061f0412, 0x032b51af,
  // [5650]
  0x043f211f, 0x050306ac, 0x12184021, 0x100f2714,
  0x1f101921, 0x19163f12, 0x120f1808, 0x40001221,
  0x451204be, 0x66053833, 0x0d1029af, 0x451614a4,
  0x400d18ad, 0x0f1d27ac, 0x0e001e32, 0x45030560,
  // [5660]
  0x0c006614, 0x213801af, 0x05380d6f, 0x033f0112,
  0x010d0509, 0x19170607, 0x0d002208, 0x06194507,
  0x030d1007, 0x1d154512, 0x21001921, 0x0f021fbc,
  0x0d001714, 0x21403fa4, 0x16400fa4, 0x273f12af,
  // [5670]
  0x0b021055, 0x18000813, 0x19060b55, 0x1c1e2355,
  0x0d001922, 0x042722a4, 0x66272909, 0x292751af,
  0x03056660, 0x062b0b12, 0x02380b12, 0x03011007,
  0x061019ad, 0x0d0f1613, 0x0f050baf, 0x190f0daf,
  // [5680]
  0x12000504, 0x0d380511, 0x16011f08, 0x38042212,
  0x160f0d22, 0x0d0f16bc, 0x031251af, 0x19400608,
  0x27172212, 0x230e1e23, 0x22040609, 0x01450609,
  0x0b001613, 0x012204af, 0x29220421, 0x2b001411,
  // [5690]
  0x0b660321, 0x03292709, 0x060d1daf, 0x1d000613,
  0x40001811, 0x292114bc, 0x22000208, 0x22000d12,
  0x102b1611, 0x191f3f60, 0x3f0c1421, 0x213f0612,
  0x08050d09, 0x05191f22, 0x081d4012, 0x0d3829a4,
  // [56a0]
  0x38001802, 0x1445126d, 0x15000411, 0x27290111,
  0x0605156f, 0x1800051d, 0x2b173812, 0x04161f6f,
  0x0d180508, 0x0d0108a4, 0x10050420, 0x0b10066f,
  0x15000f08, 0x06021f13, 0x14040111, 0x030c0bac,
  // [56b0]
  0x04000c14, 0x1d000b13, 0x020b6620, 0x0b661812,
  0x06270baf, 0x040f0609, 0x0b180413, 0x020f0b07,
  0x2b060821, 0x22181409, 0x270f22af, 0x3f22216f,
  0x45031f11, 0x19272113, 0x270b01af, 0x0b000511,
  // [56c0]
  0x02002707, 0x450b05a4, 0x01170d55, 0x380366a4,
  0x01042108, 0x12030411, 0x21660312, 0x43040107,
  0x010d17a4, 0x2b0d1712, 0x0b1006af, 0x430538af,
  0x020b0613, 0x02041912, 0x05012b02, 0x010d3812,
  // [56d0]
  0x17380fbb, 0x0d0f1f20, 0x0d180507, 0x0d180512,
  0x04210555, 0x0d382ba4, 0x192721af, 0x080f0d21,
  0x271914af, 0x196627af, 0x0c662b12, 0x010d0fbb,
  0x02000611, 0x190b0421, 0x45121f08, 0x03193808,
  // [56e0]
  0x010b1055, 0x10001707, 0x22062112, 0x03041812,
  0x29220460, 0x2b211f12, 0x1c230e22, 0x0c000f07,
  0x0c061860, 0x06180c60, 0x08001709, 0x011205a4,
  0x180f3808, 0x434505ac, 0x1d400c07, 0x1c250eac,
  // [56f0]
  0x080f0d09, 0x21272908, 0x2b002907, 0x0b0c1007,
  0x43004507, 0x0f004021, 0x021d4012, 0x0f192160,
  0x02030b08, 0x020b2908, 0x0b1d3fad, 0x27014013,
  0x300e1c55, 0x1d2b3860, 0x160c1dac, 0x120f4012,
  // [5700]
  0x22043807, 0x0f3804bb, 0x04126607, 0x10660312,
  0x10030ba4, 0x30252307, 0x1c0e30ad, 0x10012121,
  0x04001f23, 0x012229ad, 0x29190413, 0x0b0203ac,
  0x16400dad, 0x38000f10, 0x140d0f12, 0x21000f22,
  // [5710]
  0x2b2204af, 0x40040812, 0x380429af, 0x05012907,
  0x17010f07, 0x01081713, 0x43004008, 0x1d004534,
  0x02406660, 0x1d2212af, 0x03081955, 0x1c3023af,
  0x1f000509, 0x010f0308, 0x17042b12, 0x04151621,
  // [5720]
  0x292b1f11, 0x1d0601a4, 0x15000414, 0x140108ad,
  0x2b1f15be, 0x06080409, 0x04180809, 0x0d0f2b08,
  0x05041812, 0x0f042112, 0x06190421, 0x04002114,
  0x161519a4, 0x060d1812, 0x17000c09, 0x2b1f1521,
  // [5730]
  0x180d0612, 0x0b050209, 0x190b0422, 0x0d081812,
  0x10291a12, 0x40451d22, 0x0d041708, 0x1d004522,
  0x08380f07, 0x03061008, 0x1c1e30a4, 0x18190460,
  0x17150613, 0x401619a4, 0x054512a4, 0x04660309,
  // [5740]
  0x01100611, 0x301c23af, 0x0b061021, 0x66002712,
  0x2b006622, 0x19061607, 0x2b000c02, 0x19150855,
  0x06081612, 0x66010609, 0x400b1d12, 0x03181911,
  0x06661611, 0x0f0d17af, 0x0f431f12, 0x1d1205a4,
  // [5750]
  0x03162107, 0x06276612, 0x061608a4, 0x010d1955,
  0x06661d12, 0x06196621, 0x16151809, 0x10146613,
  0x0c000311, 0x38001835, 0x05001810, 0x0b292755,
  0x1c300e55, 0x1d1966be, 0x1d041914, 0x12015107,
  // [5760]
  0x0b000122, 0x12451512, 0x0f0806af, 0x05451260,
  0x16121512, 0x1d6645af, 0x101d1907, 0x21430112,
  0x01022911, 0x43010ba4, 0x12151d12, 0x0b002b13,
  0x02080409, 0x08020b09, 0x08170308, 0x0e1e1c13,
  // [5770]
  0x12451921, 0x01080513, 0x04000514, 0x2b0105ac,
  0x050418ad, 0x0c030660, 0x27003812, 0x38290113,
  0x04161707, 0x380f0421, 0x0b040507, 0x050104af,
  0x03141911, 0x16004033, 0x02102207, 0x270301ad,
  // [5780]
  0x121d17af, 0x0b101d07, 0x17121d21, 0x16170420,
  0x014305a4, 0x66020b60, 0x17121d12, 0x66005108,
  0x21193f12, 0x2b1f3860, 0x17001413, 0x16030612,
  0x01661908, 0x1f0651af, 0x16001434, 0x120117be,
  // [5790]
  0x17006611, 0x010f0d12, 0x062b1f21, 0x2b0616bb,
  0x04016612, 0x2b060c21, 0x06010fa4, 0x02061909,
  0x43000f08, 0x0d663812, 0x080d45af, 0x16210d13,
  0x16214512, 0x12400821, 0x160c1260, 0x08380dac,
  // [57a0]
  0x061d4008, 0x08382ba4, 0x0e1e1c08, 0x0f081712,
  0x0c270111, 0x1d002208, 0x190f1660, 0x38102b11,
  0x16000f13, 0x120114ac, 0x43011912, 0x45012b07,
  0x12212755, 0x08020b11, 0x01190821, 0x38036612,
  // [57b0]
  0x141d29af, 0x14292711, 0x04271621, 0x08182909,
  0x2b190621, 0x451d1960, 0x122b01a4, 0x16401510,
  0x064301ac, 0x1d013807, 0x40380f60, 0x08011911,
  0x041f19bc, 0x191614af, 0x16001923, 0x17220555,
  // [57c0]
  0x04060da4, 0x45000509, 0x0d1419ad, 0x031f06af,
  0x18193f12, 0x042921bc, 0x01270813, 0x05170109,
  0x18173822, 0x2b0616a4, 0x431422a4, 0x1d1240bb,
  0x121d45bc, 0x0b100108, 0x121d4507, 0x08001407,
  // [57d0]
  0x124540bb, 0x27290b21, 0x21001614, 0x29021960,
  0x01004509, 0x163f1d09, 0x0c1215af, 0x170608bc,
  0x19124521, 0x050366ce, 0x30231e22, 0x0f003f13,
  0x0c003f23, 0x07005c18, 0x27002b20, 0x45000307,
  // [57e0]
  0x0f380807, 0x43013faf, 0x03061513, 0x38150112,
  0x2b003f20, 0x0f080307, 0x05080d07, 0x04001f07,
  0x17000114, 0x0d0f1f12, 0x431f0112, 0x3f212909,
  0x38222107, 0x272922bb, 0x032921ad, 0x1f190fad,
  // [57f0]
  0x0c001202, 0x0b100421, 0x012b1212, 0x1f041913,
  0x05222112, 0x21080f13, 0x010d0f13, 0x14060bbc,
  0x17190112, 0x01380c07, 0x292b3812, 0x17010c12,
  0x021451af, 0x03000211, 0x0f0829a4, 0x0d053821,

  // [5800]
  0x45170d07, 0x14000f11, 0x05380807, 0x10140b08,
  0x45430612, 0x0b190409, 0x04196655, 0x0d080f20,
  0x02036622, 0x17000514, 0x45001210, 0x00001803,
  0x16153f11, 0x45121512, 0x1e250e13, 0x19161520,
  // [5810]
  0x04100b14, 0x061904bc, 0x0d190412, 0x05041808,
  0x40121412, 0x29382721, 0x380d0812, 0x1905046f,
  0x01004007, 0x19180413, 0x0d0818a4, 0x08001009,
  0x43001f14, 0x100f0d12, 0x0f2b0d02, 0x02161dac,
  // [5820]
  0x16152208, 0x17031407, 0x0b2202be, 0x66220321,
  0x23302508, 0x08060f09, 0x06146609, 0x15164012,
  0x450d38af, 0x430d01a4, 0x0f002b12, 0x19032213,
  0x0c1216af, 0x061627a4, 0x10140b13, 0x08001613,
  // [5830]
  0x0d000835, 0x19291421, 0x0f1d27af, 0x191d27af,
  0x0d001810, 0x160f1722, 0x05010b07, 0x0d001408,
  0x211716be, 0x0f1445a4, 0x19180b09, 0x1d101408,
  0x191051af, 0x0f381808, 0x0f1805bb, 0x05380d08,
  // [5840]
  0x1d151612, 0x1e0e1cbe, 0x00000d0a, 0x0d0f18ad,
  0x45150c13, 0x1d0318a4, 0x03150c12, 0x02040107,
  0x40021021, 0x0c061509, 0x2b150c11, 0x45041812,
  0x06160cac, 0x01380808, 0x0c142707, 0x66031212,
  // [5850]
  0x1c003710, 0x190416bc, 0x19151655, 0x45000107,
  0x450f3807, 0x121845ad, 0x1e0e1c11, 0x18004523,
  0x0f451807, 0x45001721, 0x12451860, 0x01452709,
  0x01061455, 0x10036655, 0x0b192b60, 0x06021921,
  // [5860]
  0x061721a4, 0x0b126607, 0x19020b08, 0x02002113,
  0x19161707, 0x21001911, 0x2b001d08, 0x0b121007,
  0x40292711, 0x17452107, 0x03182907, 0x08001412,
  0x03270455, 0x02060107, 0x3f0c2b21, 0x02000410,
  // [5870]
  0x080d0f23, 0x1d0619ad, 0x1d1601af, 0x40083f12,
  0x0d0f2107, 0x17080d12, 0x38170560, 0x10020c09,
  0x270622a4, 0x08004507, 0x43050d12, 0x380d1421,
  0x16102707, 0x05006620, 0x19162b08, 0x401d4521,
  // [5880]
  0x22190607, 0x060d0807, 0x0d000609, 0x12061512,
  0x10001809, 0x2b151fa4, 0x0e1e23bc, 0x06051fad,
  0x19004011, 0x40100213, 0x37004e35, 0x0f160dac,
  0x1f150d12, 0x40000d07, 0x0f272920, 0x1f051614,
  // [5890]
  0x03664021, 0x18292721, 0x1e302513, 0x0d191407,
  0x38140daf, 0x17272213, 0x22100baf, 0x1f100b12,
  0x29210112, 0x66211512, 0x0b141022, 0x0f0d51a4,
  0x16124514, 0x05190108, 0x2b001913, 0x14050808,
  // [58a0]
  0x451216af, 0x1f002209, 0x06050823, 0x22291814,
  0x662b3f60, 0x10002911, 0x19292708, 0x0d124513,
  0x660c0312, 0x17002202, 0x03020d12, 0x1f001722,
  0x10010da4, 0x382b17a4, 0x011d0607, 0x380f0daf,
  // [58b0]
  0x401804af, 0x18451221, 0x45272911, 0x041022ad,
  0x0c0529a4, 0x060421a4, 0x451218ac, 0x192916ad,
  0x1d660b12, 0x43001814, 0x124518af, 0x22381408,
  0x22180155, 0x1f1218bb, 0x0f0d2907, 0x22000620,
  // [58c0]
  0x0d2b01a4, 0x0b000221, 0x66000422, 0x290f2212,
  0x08140407, 0x0c0f2214, 0x191d2260, 0x1d000c09,
  0x0b040212, 0x38272911, 0x27172908, 0x16040c12,
  0x040c666f, 0x663f2bbc, 0x0b000802, 0x14004021,
  // [58d0]
  0x01000823, 0x062101ad, 0x06170111, 0x29270409,
  0x122101ad, 0x0c0d2208, 0x25233009, 0x050401ad,
  0x1d452b12, 0x14121812, 0x121d1907, 0x101916ad,
  0x0c451f07, 0x141051a4, 0x01002920, 0x251e0eac,
  // [58e0]
  0x38010bad, 0x06011007, 0x06101409, 0x12012207,
  0x10000d09, 0x211f0112, 0x12036620, 0x0d1f16af,
  0x1d003f08, 0x05010207, 0x012127af, 0x032b01a4,
  0x06012712, 0x0b051007, 0x17401d09, 0x042b1912,
  // [58f0]
  0x16001021, 0x121001ac, 0x19001708, 0x0c1d0855,
  0x08124512, 0x04001508, 0x18084013, 0x06001522,
  0x29085112, 0x0c0b2707, 0x08050307, 0x221429a4,
  0x292127be, 0x05001413, 0x0d0f2109, 0x12170c08,
  // [5900]
  0x04161812, 0x29002112, 0x27221209, 0x122204a4,
  0x0b012121, 0x270616bb, 0x01004309, 0x43012712,
  0x29183809, 0x1d450112, 0x0d0151a4, 0x29021009,
  0x2b004508, 0x0b160621, 0x190203af, 0x17450109,
  // [5910]
  0x1d014509, 0x16451202, 0x19171855, 0x660d0808,
  0x1d151212, 0x19001714, 0x0c100108, 0x10006611,
  0x19060112, 0x061922af, 0x01052121, 0x030602ad,
  0x05660212, 0x050f0609, 0x10000d21, 0x38272913,
  // [5920]
  0x22272955, 0x18050f21, 0x191d40af, 0x1d0c12af,
  0x10382255, 0x451512af, 0x190c1daf, 0x450c18a4,
  0x17000f12, 0x0c121912, 0x40101d11, 0x03011912,
  0x19100308, 0x16271812, 0x0c1d1808, 0x0c121807,
  // [5930]
  0x03012113, 0x12180208, 0x02000634, 0x0f0d0407,
  0x1e302555, 0x40063860, 0x02002911, 0x041445af,
  0x04182b22, 0x0c040b22, 0x250e30bb, 0x06013f09,
  0x0b0408af, 0x1f003f13, 0x1d122b07, 0x1d000211,
  // [5940]
  0x05062b13, 0x12002121, 0x06031811, 0x271f0809,
  0x041f2b12, 0x3f662221, 0x2721296f, 0x0e251e21,
  0x0d0c0fa4, 0x14190408, 0x40192208, 0x1c301e08,
  0x030f0512, 0x451205ad, 0x0c0416a4, 0x0c191407,
  // [5950]
  0x12084012, 0x191427a4, 0x12450512, 0x0c662baf,
  0x100b0407, 0x0b0306ad, 0x180f2208, 0x22661212,
  0x1d1f45af, 0x120129ad, 0x03012908, 0x01270609,
  0x16403fad, 0x0b0c02ac, 0x053f01af, 0x2b1d0c12,
  // [5960]
  0x3f1d2121, 0x0b060321, 0x1d402712, 0x0d3f0112,
  0x40123f21, 0x403f45af, 0x27000108, 0x401d0112,
  0x011006bc, 0x080c1daf, 0x18401709, 0x213f0c20,
  0x02031608, 0x3f211d09, 0x02160409, 0x401d2121,
  // [5970]
  0x290127af, 0x1d122112, 0x0c662b08, 0x012b03a4,
  0x290d1f09, 0x10661f09, 0x0b141009, 0x291801af,
  0x01041920, 0x06212712, 0x18000b23, 0x21000609,
  0x012b27af, 0x3f6601a4, 0x10180111, 0x0c272b12,
  // [5980]
  0x0c0f2912, 0x211801af, 0x08003f21, 0x08001913,
  0x38170109, 0x1d401513, 0x10036608, 0x05001f1d,
  0x04000822, 0x02150b12, 0x03166609, 0x401d6655,
  0x01001702, 0x301e2523, 0x192129af, 0x14120fac,
  // [5990]
  0x0b190455, 0x380110a4, 0x010529a4, 0x21011d09,
  0x0b0212af, 0x0c270412, 0x210b01a4, 0x6604196f,
  0x1f380f12, 0x660b1014, 0x3f004013, 0x03215111,
  0x214301af, 0x0c1d08a4, 0x08153f12, 0x01005108,
  // [59a0]
  0x19664307, 0x2b000809, 0x100614ac, 0x29401212,
  0x1e003707, 0x16401daf, 0x40041508, 0x0f383f12,
  0x0b020608, 0x29001513, 0x183f1613, 0x141f0112,
  0x190b0208, 0x060d0821, 0x45030655, 0x151701af,
  // [59b0]
  0x080d0412, 0x101f0b12, 0x191d0413, 0x02101907,
  0x45292720, 0x0b000421, 0x140419bb, 0x0b0602a4,
  0x08000434, 0x38120faf, 0x04213fad, 0x1d291912,
  0x0f1201af, 0x05120112, 0x08051211, 0x17050813,
  // [59c0]
  0x2b0f3809, 0x050112bb, 0x17450f10, 0x43001d11,
  0x38000b07, 0x14001f23, 0x173806af, 0x08660b55,
  0x10001422, 0x40170c12, 0x06141f21, 0x450c1808,
  0x19120408, 0x10180455, 0x291d1213, 0x19663f13,
  // [59d0]
  0x29401d23, 0x08401d6f, 0x12180614, 0x02180112,
  0x3f1d4021, 0x08001d13, 0x29401d22, 0x186619bb,
  0x3f003814, 0x12404522, 0x021814af, 0x1d45406f,
  0x05380fa4, 0x15271908, 0x17404511, 0x19450407,
  // [59e0]
  0x03180609, 0x1d4015ad, 0x45004023, 0x43380107,
  0x08381912, 0x12164012, 0x12002211, 0x01161d14,
  0x0d0f43ab, 0x01101f12, 0x010f1707, 0x0d001012,
  0x031d17ac, 0x04222134, 0x38140612, 0x210401af,
  // [59f0]
  0x210422be, 0x04002135, 0x0f0d1f10, 0x0f190c12,
  0x042b06ad, 0x2b140514, 0x0c081909, 0x04291f14,
  0x0c162bad, 0x05023809, 0x17160caf, 0x430438af,
  0x2b212712, 0x06030cad, 0x17221d07, 0x042101af,
  // [5a00]
  0x2b060c12, 0x04225112, 0x210c01af, 0x40211212,
  0x06401d20, 0x01030821, 0x27211809, 0x180b0d12,
  0x0d001911, 0x0f061907, 0x21001d13, 0x12151913,
  0x10190b12, 0x1d024021, 0x401d0460, 0x212b2712,
  // [5a10]
  0x12404513, 0x19184510, 0x0d401d12, 0x04161907,
  0x121d4014, 0x140f0c07, 0x16181909, 0x14272112,
  0x08222708, 0x14151612, 0x0c000d14, 0x250e1c02,
  0x0c0601a4, 0x15191212, 0x0c0140a4, 0x12190c08,
  // [5a20]
  0x302325bb, 0x25230ebc, 0x1c0e30be, 0x662b1414,
  0x0f011709, 0x0d381408, 0x050601a4, 0x04190f07,
  0x02041407, 0x12010307, 0x01060b07, 0x10140408,
  0x06001004, 0x21000111, 0x27041f13, 0x292706be,
  // [5a30]
  0x100b0220, 0x06106612, 0x0d004510, 0x08142b11,
  0x08061fbc, 0x271629af, 0x020366af, 0x06011f12,
  0x2b170621, 0x0c0617af, 0x0c020613, 0x0d010508,
  0x27000614, 0x184540bc, 0x29052714, 0x17062913,
  // [5a40]
  0x300d386d, 0x05001711, 0x01030621, 0x21000422,
  0x08002120, 0x0c1d2121, 0x021922ad, 0x010866ad,
  0x19011007, 0x0b1904a4, 0x06402207, 0x10180207,
  0x03040508, 0x191f0413, 0x23301e13, 0x181d4009,
  // [5a50]
  0x21140c12, 0x221410af, 0x15041913, 0x21001712,
  0x0c140422, 0x29000320, 0x45271a12, 0x0b4012bc,
  0x402b45af, 0x01043fac, 0x2b000d12, 0x0d1d4021,
  0x03050f07, 0x0b2b38ad, 0x010f14a4, 0x66140ba4,
  // [5a60]
  0x06050102, 0x0b1d4012, 0x12171907, 0x011d1212,
  0x190217bb, 0x1c253014, 0x01171812, 0x0b0410a4,
  0x050108af, 0x030208ac, 0x21010860, 0x01030412,
  0x052b0109, 0x0b0206ad, 0x190466bb, 0x05000d11,
  // [5a70]
  0x04061911, 0x022216be, 0x0d0f0521, 0x222116be,
  0x0f0115ac, 0x3f401621, 0x22171612, 0x221d1621,
  0x032b14ad, 0x05080d09, 0x22161721, 0x221601af,
  0x06221521, 0x042b0c11, 0x16002235, 0x15171912,
  // [5a80]
  0x182927af, 0x0b660355, 0x38140509, 0x0d380109,
  0x21061608, 0x0b012bac, 0x01052b08, 0x290b66af,
  0x0d000411, 0x16041909, 0x1d014012, 0x04453fa4,
  0x120c1612, 0x1e3025ad, 0x180b0609, 0x080f3813,
  // [5a90]
  0x100401a4, 0x10005112, 0x17001d20, 0x23300eac,
  0x1d400112, 0x0d0b01a4, 0x1d00400d, 0x2b006623,
  0x380d01a4, 0x0d170808, 0x03661812, 0x03156613,
  0x43080507, 0x43000813, 0x05083820, 0x01430b07,
  // [5aa0]
  0x17001813, 0x0c4012af, 0x010345ad, 0x0c036612,
  0x21080212, 0x0f085112, 0x0f041607, 0x190804a4,
  0x06021821, 0x45121413, 0x0d3817af, 0x012229a4,
  0x29081560, 0x19001f22, 0x171905ac, 0x0f001409,
  // [5ab0]
  0x27170f20, 0x100c1d22, 0x171f1aaf, 0x2b001722,
  0x1f152b21, 0x38450fad, 0x19050412, 0x16000509,
  0x1d4012a4, 0x0c0601af, 0x0f041907, 0x30001c33,
  0x06011f07, 0x181f45af, 0x04191dac, 0x1f001912,
  // [5ac0]
  0x0b0205be, 0x21102221, 0x181f0f55, 0x18450fad,
  0x040f0112, 0x1d002913, 0x140f1f60, 0x0b081060,
  0x081d4013, 0x0c2b6660, 0x06036611, 0x020110ad,
  0x15192212, 0x450c2bac, 0x19002909, 0x19010fad,
  // [5ad0]
  0x1d161712, 0x05001209, 0x10030b08, 0x0c060155,
  0x23001e1f, 0x660327af, 0x451d04ad, 0x06380fac,
  0x03006634, 0x29662712, 0x0f1901ad, 0x0f030413,
  0x19042707, 0x660338af, 0x19220b12, 0x2b000314,
  // [5ae0]
  0x023f0baf, 0x21080d09, 0x030d0fac, 0x0f381408,
  0x1d224513, 0x21291412, 0x27011f12, 0x194540af,
  0x0f0d2b07, 0x18402b09, 0x38001211, 0x0f2701a4,
  0x22181d13, 0x220329af, 0x22660612, 0x40124520,
  // [5af0]
  0x1d400413, 0x01292709, 0x190b0202, 0x02012107,
  0x06150412, 0x12014512, 0x0c0210a4, 0x1d010ca4,
  0x14001f1f, 0x030f0508, 0x210f0d60, 0x190d1fad,
  0x0d381912, 0x010d0f55, 0x3f1d0baf, 0x011019ad,
  // [5b00]
  0x22001608, 0x2b2922af, 0x40221212, 0x16000c21,
  0x1d0c1607, 0x1d003f09, 0x2b400812, 0x25300e13,
  0x1f660221, 0x210201a4, 0x050b1023, 0x19020112,
  0x170b1055, 0x43006608, 0x0d0108bb, 0x1d400cbe,
  // [5b10]
  0x121d0c11, 0x0b010612, 0x380405a4, 0x1d001020,
  0x05290109, 0x3f0601af, 0x1d063f08, 0x15042955,
  0x01041960, 0x121d4022, 0x0e252321, 0x012b0b08,
  0x08000d22, 0x04003811, 0x38191508, 0x380d04bc,
  // [5b20]
  0x1d0117a4, 0x12194512, 0x040f1712, 0x0d0f1013,
  0x021d0112, 0x380c4512, 0x21291760, 0x1d1840af,
  0x3f1701af, 0x05081809, 0x0d1f0f21, 0x38161912,
  0x10041911, 0x0b190560, 0x01101702, 0x150529af,
  // [5b30]
  0x301c25a4, 0x0c0b01af, 0x0d660112, 0x45431222,
  0x27002220, 0x0c0f4512, 0x2b66036f, 0x40001520,
  0x0645126f, 0x0f001f14, 0x40000b13, 0x05001507,
  0x29000620, 0x290251a4, 0x010f08af, 0x010306ad,
  // [5b40]
  0x056618a4, 0x122b086f, 0x452b0412, 0x03001213,
  0x011705af, 0x15002212, 0x1d154013, 0x01272b12,
  0x0f385112, 0x122701a4, 0x27042209, 0x16001413,
  0x011006ac, 0x1d221612, 0x02011007, 0x08380607,
  // [5b50]
  0x233025a4, 0x100b2ba4, 0x103803a4, 0x1d192212,
  0x08171211, 0x3f1d1814, 0x14100608, 0x29001f33,
  0x381604bb, 0x0f190407, 0x40082212, 0x151629af,
  0x0c192b09, 0x02001908, 0x06291911, 0x0b3f0112,
  // [5b60]
  0x1e2330be, 0x19661faf, 0x05160da4, 0x17382b09,
  0x1d164007, 0x020b1011, 0x0f382709, 0x0d190f12,
  0x1d0601ad, 0x0b1027af, 0x210f0c12, 0x1d660314,
  0x0f0c1807, 0x02001021, 0x2b161521, 0x03060208,
  // [5b70]
  0x0d0f0102, 0x38100d21, 0x02041007, 0x230e1e22,
  0x02291a12, 0x3700301d, 0x081619ac, 0x01100c09,
  0x140506a4, 0x19000208, 0x19210412, 0x170f0d60,
  0x19000d13, 0x660b2712, 0x45084009, 0x15000f20,
  // [5b80]
  0x0d001008, 0x08380d07, 0x12011007, 0x172b0109,
  0x06001d08, 0x0f380809, 0x0d080507, 0x21660b13,
  0x01210634, 0x17081860, 0x400b04af, 0x0d170860,
  0x2b220622, 0x0f180682, 0x06040f21, 0x18002113,
  // [5b90]
  0x10002208, 0x0f1d1612, 0x0f0522af, 0x0f030512,
  0x10063821, 0x40010334, 0x062b0321, 0x080f0d11,
  0x100214af, 0x10003820, 0x38000614, 0x181003af,
  0x0c033812, 0x0d160f07, 0x12400da4, 0x450f0d11,
  // [5ba0]
  0x0f0d04be, 0x020d51af, 0x10171d02, 0x010540a4,
  0x150f01af, 0x0d0f3812, 0x162b6608, 0x1c003002,
  0x1d080507, 0x40041d12, 0x082701ad, 0x0b451212,
  0x22140207, 0x031910ac, 0x0f0d2755, 0x0f0d19ad,
  // [5bb0]
  0x01100b07, 0x100d0109, 0x14382b12, 0x25301e13,
  0x03120c07, 0x27000213, 0x0b030655, 0x02101f12,
  0x0f011707, 0x22192755, 0x221d1909, 0x661222af,
  0x0b172ba4, 0x66020309, 0x060b1012, 0x02100309,
  // [5bc0]
  0x08000620, 0x06272909, 0x020b6613, 0x30001f1f,
  0x03012107, 0x22000f07, 0x10142908, 0x01023809,
  0x0f662108, 0x43040307, 0x662901af, 0x66381412,
  0x0f002212, 0x22040655, 0x021d0109, 0x12000b07,
  // [5bd0]
  0x383f04bc, 0x3f2729cf, 0x14061020, 0x3f222122,
  0x38041907, 0x45041612, 0x1d0c2160, 0x052921af,
  0x272b1621, 0x0d171412, 0x380d0baf, 0x290c1d13,
  0x270f21be, 0x27292211, 0x211527af, 0x16000d09,
  // [5be0]
  0x01213fad, 0x022204bb, 0x0c1d1908, 0x04452b08,
  0x66190309, 0x181f1421, 0x10140607, 0x00001442,
  0x0d000402, 0x0c060112, 0x22061813, 0x17002220,
  0x03001408, 0x013843a4, 0x19030607, 0x050f0408,
  // [5bf0]
  0x180b04bb, 0x0f100b07, 0x10190213, 0x15080112,
  0x38001912, 0x401201a4, 0x12050b08, 0x43401912,
  0x401245ad, 0x01040507, 0x06383f12, 0x0d220834,
  0x40082912, 0x22151612, 0x271d29af, 0x04401621,

  // [5c00]
  0x271d3f21, 0x08066609, 0x06190455, 0x0b1804ad,
  0x120c1507, 0x291d40a4, 0x270c3f13, 0x18661912,
  0x403f0814, 0x05290155, 0x191d0107, 0x10011907,
  0x38001f10, 0x02100b60, 0x27000409, 0x401601af,
  // [5c10]
  0x062245ad, 0x0b1401bc, 0x220366cf, 0x021d45af,
  0x22034512, 0x032b6613, 0x661910be, 0x171d0c21,
  0x432901af, 0x38082bad, 0x0b380507, 0x15450c20,
  0x17450112, 0x06001f21, 0x01082113, 0x300e1e21,
  // [5c20]
  0x01031907, 0x43010802, 0x40180c14, 0x18401d08,
  0x101f3821, 0x271901af, 0x04661912, 0x38011208,
  0x450c1809, 0x05004334, 0x43000811, 0x171d1255,
  0x45160b02, 0x06101509, 0x04000f22, 0x17191502,
  // [5c30]
  0x030d08af, 0x19001409, 0x05430c12, 0x04000814,
  0x27291412, 0x011d0355, 0x45210d09, 0x04021012,
  0x210512af, 0x290f0112, 0x02012255, 0x170f01af,
  0x0d270f21, 0x17380102, 0x0f451faf, 0x12451faf,
  // [5c40]
  0x0f1f45ad, 0x01401da4, 0x43000807, 0x451f0f12,
  0x0d051908, 0x03170113, 0x102b38a4, 0x1e301c21,
  0x06101913, 0x01051613, 0x27161922, 0x17040fbb,
  0x19060412, 0x173f0112, 0x231e30bb, 0x40004511,
  // [5c50]
  0x161918a4, 0x190106af, 0x08401813, 0x212908af,
  0x29213fbb, 0x3f660121, 0x40153fce, 0x40001512,
  0x273f1d14, 0x22001008, 0x18401d21, 0x08401d22,
  0x1f002121, 0x17401d6f, 0x38020b13, 0x01194012,
  // [5c60]
  0x0d036614, 0x10080212, 0x050440ad, 0x0d001520,
  0x66180112, 0x150d16bc, 0x0d160808, 0x10151621,
  0x160d1860, 0x101516a4, 0x450f0d07, 0x16451509,
  0x3f001813, 0x0d161512, 0x161512a4, 0x161d456d,
  // [5c70]
  0x0d0f16ad, 0x40121d07, 0x05101509, 0x271d4013,
  0x10380b60, 0x10292714, 0x27060109, 0x0c221d12,
  0x191540a4, 0x66031912, 0x1d272907, 0x150119a4,
  0x05062b60, 0x21272914, 0x17384309, 0x121d3f12,
  // [5c80]
  0x05140613, 0x1d000b11, 0x1d1404be, 0x291727be,
  0x03660421, 0x170f0121, 0x400f29af, 0x29222134,
  0x401d046f, 0x17190108, 0x0e002522, 0x27290521,
  0x14011960, 0x27181912, 0x1f006621, 0x380c1721,
  // [5c90]
  0x17180608, 0x10182bbe, 0x29014309, 0x0b1814bc,
  0x0d053813, 0x30002502, 0x15401d13, 0x08000f20,
  0x192729af, 0x1f062b12, 0x222119ad, 0x19182712,
  0x041d4011, 0x03662912, 0x29151912, 0x22142b12,
  // [5ca0]
  0x29276621, 0x19003821, 0x290b0112, 0x19292712,
  0x12061d11, 0x102b1421, 0x662b2909, 0x1d001f08,
  0x01100207, 0x021f0112, 0x06143f12, 0x27430412,
  0x02080308, 0x0d0f1fad, 0x0f0508a4, 0x080b01a4,
  // [5cb0]
  0x0f1d0507, 0x08002222, 0x0d083814, 0x141243a4,
  0x05011807, 0x0c042b07, 0x102b0455, 0x050108a4,
  0x04661909, 0x01003f14, 0x082b1809, 0x171245be,
  0x01011207, 0x06100208, 0x02190611, 0x0d0f22a4,
  // [5cc0]
  0x08002109, 0x22101855, 0x14000d10, 0x221f18af,
  0x0f0d10af, 0x04660612, 0x380f2114, 0x0f100d13,
  0x19040808, 0x3f272913, 0x27382912, 0x0d0f19be,
  0x02151607, 0x05000433, 0x66051908, 0x050108ad,
  // [5cd0]
  0x0d081fad, 0x08001814, 0x010805af, 0x43061f12,
  0x380112a4, 0x19051f11, 0x0b1d1613, 0x19121dac,
  0x273829a4, 0x01141607, 0x38191007, 0x0d0f2209,
  0x22000f20, 0x15271f13, 0x01194512, 0x1d121921,
  // [5ce0]
  0x181d19ac, 0x270f2908, 0x19172107, 0x25300e55,
  0x08011860, 0x06000802, 0x080f2b08, 0x0d0f27af,
  0x0f0201ac, 0x30232560, 0x232530ac, 0x106651af,
  0x08030660, 0x160c15ac, 0x03001508, 0x05124520,
  // [5cf0]
  0x29661a12, 0x0c170807, 0x051903a4, 0x15160112,
  0x05000b13, 0x100b38bb, 0x14000123, 0x66005113,
  0x21450c21, 0x150416ad, 0x166615be, 0x10020bbc,
  0x221f0212, 0x190c45af, 0x1d1901a4, 0x171d01af,
  // [5d00]
  0x40081609, 0x164512ad, 0x01222107, 0x19122109,
  0x18271912, 0x3f170ca4, 0x08380f60, 0x043f18be,
  0x011945af, 0x291622cf, 0x212719bb, 0x05010daf,
  0x160415af, 0x0d004013, 0x01222922, 0x0d051f09,
  // [5d10]
  0x0f1d4008, 0x0f381809, 0x0b0610a4, 0x17020b23,
  0x10161908, 0x160f0d13, 0x22100dbc, 0x29042712,
  0x210427a4, 0x12401d23, 0x06032b55, 0x300e2302,
  0x17220512, 0x660c1d12, 0x02004511, 0x011d0c09,
  // [5d20]
  0x1d400f13, 0x0b080c07, 0x19160108, 0x0f451d09,
  0x05182b08, 0x160d0f12, 0x06032708, 0x16171d09,
  0x011705ad, 0x0c00181f, 0x17454021, 0x0f030dad,
  0x160f1912, 0x190c1712, 0x0d0518ad, 0x16031f11,
  // [5d30]
  0x0d0f1709, 0x0e231c22, 0x0f3f0560, 0x380f1fad,
  0x40080112, 0x18050daf, 0x080c3f08, 0x220d3f13,
  0x044001a4, 0x100d2207, 0x05661fad, 0x17162260,
  0x00003742, 0x0d002207, 0x38030607, 0x180d01af,
  // [5d40]
  0x0f220108, 0x0d0866a4, 0x1d4512be, 0x19001802,
  0x06182707, 0x10004012, 0x080b0107, 0x0b161055,
  0x020c2708, 0x220c4055, 0x14451208, 0x1d0c40ad,
  0x0f272112, 0x14062bad, 0x05010813, 0x194501af,
  // [5d50]
  0x253023ad, 0x2104196f, 0x16181d09, 0x17002907,
  0x124505af, 0x3f160408, 0x06030111, 0x1d041660,
  0x04380521, 0x140408be, 0x050d18ba, 0x044027af,
  0x1d161560, 0x191d1607, 0x151d4560, 0x15050655,
  // [5d60]
  0x0e253060, 0x0f0d0260, 0x19041512, 0x290d16a4,
  0x08004521, 0x06432207, 0x22000509, 0x100204ad,
  0x66162b12, 0x0f000d36, 0x04000513, 0x27001613,
  0x194045a4, 0x0c220808, 0x380c2107, 0x17080514,
  // [5d70]
  0x06191709, 0x0f121409, 0x16141522, 0x27452909,
  0x170122a4, 0x29142221, 0x27292bbe, 0x4038056f,
  0x27062908, 0x161d22ad, 0x151f19af, 0x0e301c60,
  0x0f161909, 0x30231e14, 0x190206a4, 0x061066a4,
  // [5d80]
  0x193f2120, 0x0f0d0855, 0x03020108, 0x25231e11,
  0x30231e09, 0x080d0109, 0x300e1e11, 0x08030112,
  0x060b03a4, 0x220427af, 0x020366ac, 0x011722a4,
  0x19062712, 0x0d000407, 0x10061209, 0x03171d07,
  // [5d90]
  0x03060c60, 0x190c0609, 0x19011d55, 0x1c1e3014,
  0x18061021, 0x19060b12, 0x06142b09, 0x0300381d,
  0x02031002, 0x230e1ebe, 0x142b0660, 0x01030f08,
  0x40161508, 0x12164555, 0x12000420, 0x21001820,
  // [5da0]
  0x0c1d6621, 0x061f3f08, 0x06221812, 0x18041613,
  0x04001633, 0x450b6609, 0x18292722, 0x0d17086f,
  0x300e2521, 0x12066612, 0x1d661f08, 0x1d180812,
  0x16000423, 0x66082709, 0x04211621, 0x12001509,
  // [5db0]
  0x12000814, 0x050c12ad, 0x1d170107, 0x19661008,
  0x220619af, 0x17000208, 0x1d0c03af, 0x3f040112,
  0x38000823, 0x400329af, 0x12101912, 0x03401d60,
  0x0c1916a4, 0x04181620, 0x401218ad, 0x18042212,
  // [5dc0]
  0x01001408, 0x03001910, 0x45020309, 0x45001533,
  0x06106608, 0x08180607, 0x04661512, 0x05150112,
  0x45150412, 0x30230e02, 0x226619af, 0x191504a4,
  0x190b1008, 0x020b40be, 0x16020ba4, 0x10121d02,
  // [5dd0]
  0x19000b07, 0x27171508, 0x08060155, 0x0b1d1912,
  0x45121408, 0x05004512, 0x23251c22, 0x12214509,
  0x150116ad, 0x0d151612, 0x01031960, 0x02001d12,
  0x22001f22, 0x66000513, 0x01121912, 0x04401dbc,
  // [5de0]
  0x27014512, 0x0c0f0daf, 0x2b011921, 0x02190112,
  0x40171912, 0x382b0102, 0x12450baf, 0x01051908,
  0x04061008, 0x2b020108, 0x04020102, 0x02010609,
  0x02380555, 0x01221f09, 0x01381711, 0x15001811,
  // [5df0]
  0x0b042207, 0x19221dac, 0x1f000c12, 0x1f000f14,
  0x03000f02, 0x1d036655, 0x120c3faf, 0x19030faf,
  0x0f170502, 0x29272b12, 0x301c2522, 0x400610cf,
  0x030c6608, 0x040601ad, 0x1d293faf, 0x030604a4,
  // [5e00]
  0x16124512, 0x030604be, 0x0f3f0112, 0x0c1d4055,
  0x1d271512, 0x060d2b12, 0x02000423, 0x380501be,
  0x1d1940be, 0x292740af, 0x0c001008, 0x011908ad,
  0x100b14ad, 0x224015af, 0x38001913, 0x08030621,
  // [5e10]
  0x0b1427af, 0x080306be, 0x16401512, 0x0f221420,
  0x08030613, 0x22210d12, 0x10000d20, 0x03080622,
  0x08030612, 0x02041009, 0x010c06af, 0x031018a4,
  0x0d0f3802, 0x66001413, 0x1d194012, 0x38002b09,
  // [5e20]
  0x38182212, 0x66002b08, 0x0f050612, 0x102b17ad,
  0x22661920, 0x0c0640bc, 0x050201af, 0x38080509,
  0x10000809, 0x0d051f07, 0x180b0214, 0x2b0d01a4,
  0x031014be, 0x382b16ad, 0x08052707, 0x05030807,
  // [5e30]
  0x01003809, 0x011021a4, 0x01062ba4, 0x19050d07,
  0x17083823, 0x153808a4, 0x0f221909, 0x012229af,
  0x66005112, 0x191d0507, 0x160f0821, 0x08003833,
  0x270d3809, 0x12661f08, 0x1c251ebb, 0x14001513,
  // [5e40]
  0x141d04ad, 0x0f041709, 0x1d0c1521, 0x16141512,
  0x1d151412, 0x301e1ca4, 0x66151660, 0x06050334,
  0x0e2530ac, 0x0f030607, 0x29271814, 0x25230e22,
  0x0b036611, 0x150318a4, 0x14000308, 0x1d0503a4,
  // [5e50]
  0x120d1f09, 0x0b036612, 0x0c121d02, 0x06101809,
  0x120218ad, 0x10380208, 0x292712af, 0x451916ad,
  0x03182212, 0x0212456d, 0x02450ba4, 0x12450c20,
  0x0f003f07, 0x020b1409, 0x061d3f13, 0x22140ba4,
  // [5e60]
  0x0e1e30ac, 0x0c663fad, 0x050d38a4, 0x14451860,
  0x010617a4, 0x45002907, 0x0f0102ac, 0x061f0111,
  0x40001720, 0x401712a4, 0x210b06af, 0x0b001712,
  0x01100309, 0x03061921, 0x01192712, 0x1f2b0409,
  // [5e70]
  0x10021512, 0x14061012, 0x17401208, 0x02100660,
  0x170c4008, 0x384017ad, 0x29221060, 0x03663f12,
  0x05000c12, 0x1d1019a4, 0x380812af, 0x38040807,
  0x19041f60, 0x171d0c07, 0x15400c12, 0x011006ad,
  // [5e80]
  0x22031907, 0x010f2b07, 0x01080411, 0x030517a4,
  0x051706ad, 0x04061620, 0x0e231ebc, 0x0d000414,
  0x08000514, 0x0d002b22, 0x04272908, 0x0d380107,
  0x124022a4, 0x040d1460, 0x160d0622, 0x21006612,
  // [5e90]
  0x38050fbc, 0x010c6608, 0x0f012bad, 0x140d0f1f,
  0x271d1912, 0x2b066609, 0x1d1945a4, 0x1d0305a4,
  0x10400209, 0x150c0f12, 0x16170f60, 0x051d01a4,
  0x18450d09, 0x12450c11, 0x0d172207, 0x120d0fad,
  // [5ea0]
  0x38171811, 0x0c162912, 0x14003807, 0x1d171812,
  0x030601a4, 0x030517ac, 0x02041907, 0x1e002533,
  0x660305af, 0x06101813, 0x01063f12, 0x0f272955,
  0x0b001707, 0x21002914, 0x0b005112, 0x25374e12,
  // [5eb0]
  0x231c0e02, 0x1d043f12, 0x01162b11, 0x1d2729ad,
  0x2b001022, 0x08010560, 0x1d153faf, 0x08012207,
  0x060b0107, 0x191504af, 0x040c2bbc, 0x0b401923,
  0x0f0d51af, 0x1d3801ad, 0x01051621, 0x451f0112,
  // [5ec0]
  0x1f0d21be, 0x14151922, 0x14001907, 0x1d140312,
  0x03041934, 0x05011708, 0x3f2101af, 0x021701af,
  0x17014007, 0x10012907, 0x22150f07, 0x01021807,
  0x10221421, 0x080f2baf, 0x170816a4, 0x450d1811,
  // [5ed0]
  0x17001209, 0x081d2112, 0x29212714, 0x2b1466ac,
  0x03002108, 0x383f0d11, 0x1d190c14, 0x292716af,
  0x29270f13, 0x0f081508, 0x0c161d07, 0x160666a4,
  0x050b66af, 0x43052207, 0x66160509, 0x041566be,
  // [5ee0]
  0x10160207, 0x04272921, 0x08053809, 0x0b1d0212,
  0x01051408, 0x1c1e3013, 0x2b041912, 0x080116af,
  0x17000f09, 0x15036608, 0x0f160109, 0x041419af,
  0x08001012, 0x380d1821, 0x10060808, 0x04161721,
  // [5ef0]
  0x19660b09, 0x66020b21, 0x661816af, 0x161422ac,
  0x06040b12, 0x66270112, 0x010f1dad, 0x030412af,
  0x23301cbb, 0x663f0c60, 0x18002209, 0x08190da4,
  0x29152721, 0x14030108, 0x43036608, 0x03182b09,
  // [5f00]
  0x3f290d14, 0x10060412, 0x21401d21, 0x27212914,
  0x21401da4, 0x22401d22, 0x161d4020, 0x2b272160,
  0x1d001808, 0x211d4023, 0x0c1d1712, 0x15660caf,
  0x1f030608, 0x25300e11, 0x38192111, 0x27150813,
  // [5f10]
  0x020b16af, 0x38400112, 0x020129af, 0x190d1009,
  0x0f050807, 0x011819af, 0x0b380112, 0x04023f11,
  0x16224008, 0x1d000f12, 0x10000d12, 0x05100613,
  0x04000f13, 0x2b0d0411, 0x45000c14, 0x15011602,
  // [5f20]
  0x301e2311, 0x171027af, 0x1f292712, 0x29151faf,
  0x0f430dad, 0x0f172207, 0x210d27af, 0x172129af,
  0x14191021, 0x66080408, 0x04010602, 0x0e1c236f,
  0x05190cac, 0x080c0507, 0x0f1d0107, 0x0b0d05a4,
  // [5f30]
  0x0b020614, 0x19171521, 0x0b184021, 0x45120c09,
  0x080f386f, 0x02050b12, 0x0c150621, 0x40060512,
  0x0d0b0260, 0x050117ad, 0x0b100321, 0x401d45ac,
  0x030b1012, 0x08171fac, 0x17452212, 0x0b190808,
  // [5f40]
  0x40451220, 0x100622af, 0x030618af, 0x38012b08,
  0x160622a4, 0x0d103809, 0x181d06ad, 0x66060312,
  0x14000c20, 0x12180413, 0x12451da4, 0x0c1d0421,
  0x03040202, 0x184045a4, 0x01291807, 0x22124512,
  // [5f50]
  0x06122b21, 0x300e1e23, 0x40031faf, 0x0c161012,
  0x0c060f13, 0x15011d12, 0x29162712, 0x17001d02,
  0x1f002b09, 0x0c0418ac, 0x05160108, 0x380d1621,
  0x220b0121, 0x04141612, 0x292b01a4, 0x013818a4,
  // [5f60]
  0x1c0e2523, 0x02210120, 0x18012213, 0x080d3809,
  0x221701af, 0x12451609, 0x142701bc, 0x02061907,
  0x04020b55, 0x2b161f12, 0x2b041f6f, 0x66030b21,
  0x1f000522, 0x19151623, 0x10020609, 0x05002b13,
  // [5f70]
  0x100c0f11, 0x010d1709, 0x06190121, 0x0c220611,
  0x01051f21, 0x19041f12, 0x191804af, 0x0c220421,
  0x66402909, 0x010621ac, 0x08170da4, 0x050817ad,
  0x01450413, 0x03190421, 0x060419af, 0x0d380f60,
  // [5f80]
  0x10060321, 0x290640af, 0x036622ad, 0x16274008,
  0x25301c02, 0x4e003733, 0x3f001920, 0x66061008,
  0x17021012, 0x061f6621, 0x06180b12, 0x010f0d55,
  0x384316a4, 0x0b120107, 0x0b0c18a4, 0x061808af,
  // [5f90]
  0x06000813, 0x191606ad, 0x030c06ad, 0x030b0407,
  0x06000820, 0x45066612, 0x1d1708a4, 0x121d2207,
  0x6619046f, 0x1d060821, 0x19040313, 0x03060820,
  0x012943ad, 0x01004320, 0x66190411, 0x04031912,
  // [5fa0]
  0x0b104312, 0x29001712, 0x0c002208, 0x0419666f,
  0x081229a4, 0x0e232520, 0x231e3013, 0x01001d11,
  0x10061f21, 0x451219af, 0x1d001922, 0x2b000509,
  0x12453f12, 0x020b45a4, 0x1d0b0ca4, 0x45002114,
  // [5fb0]
  0x0b402221, 0x0c120b13, 0x0b1601a4, 0x0c451821,
  0x120c4522, 0x66060b12, 0x0f043807, 0x0b062113,
  0x01060ca4, 0x170105ad, 0x451222ad, 0x010c2212,
  0x45221822, 0x27032221, 0x010b1012, 0x1e1c3008,
  // [5fc0]
  0x38080f02, 0x40273812, 0x050145ad, 0x40120c13,
  0x0d0f40af, 0x0f120d08, 0x0b102108, 0x012205ad,
  0x400c12ad, 0x08000409, 0x03400d07, 0x170f0d21,
  0x22000421, 0x220f3813, 0x451d2712, 0x101d40a4,
  // [5fd0]
  0x060b22ad, 0x061201af, 0x0f381707, 0x12160407,
  0x45016607, 0x1f002912, 0x03104514, 0x03381907,
  0x16001909, 0x0f010511, 0x66080560, 0x08061912,
  0x430f2b55, 0x12401d55, 0x29272bbc, 0x0d0122bb,
  // [5fe0]
  0x29192112, 0x661819bb, 0x27002133, 0x120d0b11,
  0x0f012707, 0x220d01af, 0x0d0508bb, 0x22000d20,
  0x43003f11, 0x0d001821, 0x042219be, 0x3f272911,
  0x1d401221, 0x170d1512, 0x021d0baf, 0x1d3f1913,
  // [5ff0]
  0x2b0801a4, 0x18061709, 0x0d0f1760, 0x250e23ad,
  0x12141807, 0x222b0607, 0x010d22a4, 0x19270655,
  0x062b14ad, 0x40141da4, 0x14400812, 0x051606a4,
  0x1d000822, 0x19292720, 0x21002211, 0x06012b13,

  // [6000]
  0x083f2121, 0x161d1212, 0x0f161721, 0x250e1e33,
  0x011f0620, 0x08174013, 0x17382712, 0x38002213,
  0x082b1f12, 0x1d051712, 0x080d1521, 0x10060bac,
  0x05170821, 0x10030108, 0x0f292760, 0x06040513,
  // [6010]
  0x08171507, 0x160801af, 0x19152909, 0x43031fa4,
  0x04191aa4, 0x1d4512a4, 0x0f0c0307, 0x0c151912,
  0x18035111, 0x0c001602, 0x100604af, 0x0b000809,
  0x06003814, 0x1d451912, 0x042229af, 0x0c120612,
  // [6020]
  0x10004511, 0x05003f22, 0x14220112, 0x0d1805a4,
  0x29270d13, 0x1f401daf, 0x221404be, 0x060112ad,
  0x140645bc, 0x221945ad, 0x1f0601af, 0x17011faf,
  0x1e302507, 0x121d40af, 0x0b181255, 0x140601ad,
  // [6030]
  0x431601a4, 0x0b010f07, 0x06011f09, 0x2b0166a4,
  0x01170d13, 0x17000d02, 0x15000112, 0x301c1e82,
  0x29222709, 0x272b0ba4, 0x29270b12, 0x152b0312,
  0x016603ad, 0x66020660, 0x06660b08, 0x140d1d09,
  // [6040]
  0x02142b07, 0x0e1c30bb, 0x04140611, 0x1d4540be,
  0x03100b08, 0x02660313, 0x12274507, 0x29381d08,
  0x060f3807, 0x0f0622a4, 0x14020b14, 0x10001402,
  0x450c0f33, 0x15050609, 0x080f0c09, 0x231e25be,
  // [6050]
  0x082b0612, 0x17453faf, 0x27152911, 0x194514ac,
  0x191504be, 0x02030612, 0x060266a4, 0x0d292714,
  0x270d21bb, 0x030401a4, 0x14180421, 0x0c0f1f12,
  0x08213fad, 0x0f1d1421, 0x19401614, 0x032b0607,
  // [6060]
  0x03290111, 0x1d0f0812, 0x1d080f13, 0x01290d55,
  0x0d081faf, 0x400f0d09, 0x0d1614bc, 0x08003812,
  0x050d0f12, 0x0f0c1421, 0x083f0521, 0x381d2112,
  0x0b1d10bb, 0x0b220c12, 0x212b01ad, 0x10000d07,
  // [6070]
  0x1d004034, 0x081f1daf, 0x124510ac, 0x01000b02,
  0x25301c55, 0x0d0414a4, 0x404501af, 0x151d1813,
  0x272b01af, 0x40121612, 0x08210109, 0x0d451811,
  0x250e1e02, 0x10142209, 0x21061412, 0x0d1845a4,
  // [6080]
  0x1f451821, 0x0f000d04, 0x22002109, 0x10380111,
  0x0f060812, 0x0f3f0660, 0x06041208, 0x0f060813,
  0x043812a4, 0x10012709, 0x01190402, 0x061d0807,
  0x220b0255, 0x150c04a4, 0x1d062709, 0x0f271d12,
  // [6090]
  0x27140814, 0x106629af, 0x0c013f11, 0x01292722,
  0x0f0d1021, 0x060f0808, 0x3f001f20, 0x10003814,
  0x14100112, 0x1c1e2311, 0x051f0d14, 0x0c0b1007,
  0x271f3f60, 0x100b06af, 0x21001f13, 0x061219ac,
  // [60a0]
  0x06661009, 0x2b003f22, 0x0f011a12, 0x22000622,
  0x19044507, 0x27121d09, 0x010f0c07, 0x120c1812,
  0x380401a4, 0x120c22af, 0x030610a4, 0x01181612,
  0x0c160512, 0x0c191707, 0x2714296f, 0x03660d11,
  };

COMPILE_ASSERT(24752 < (1 << 16), k_indirectbits_too_small);

extern const cld::CLDTableSummary kQuadTable_obj = {
  kQuadTable,
  kQuadTableInd,
  kQuadTableSize,
  arraysize(kQuadTableInd),
  kQuadTableKeyMask,
  kQuadTableBuildDate,
};

// End of generated tables
